Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["RB-SFA: High Harmonic Generation in the Strong Field Approximation \
via ",
  FontSize->24],
 StyleBox["Mathematica",
  FontSize->24,
  FontSlant->"Italic"]
}], "Title"],

Cell["\[Copyright] Emilio Pisanty 2014-2017. Licensed under GPL and \
CC-BY-SA.", "Text"],

Cell[CellGroupData[{

Cell["Quantum-orbit functionality (experimental)", "Section"],

Cell["\<\
The following is a suite of functions to calculate HHG spectra via \
quantum-orbit calculations, i.e. by using the saddle-point approximation on \
both temporal integrals. This function suite has been used for production \
calculations, and in general it is trustworthy in the results it produces. \
However, the details of the interface should not be considered fixed and are \
subject to later change; hence the mark as experimental for the time being. \
In addition, the documentation presented in this document is still under \
construction: the examples below show a reasonably complete use case from \
getting the action through to calculating a spectrum, at present with no \
explanatory text beyond the usage messages of the different functions. \
Further documentation will be added at a later date.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Specifications", "Subsection"],

Cell[TextData[{
 "The goal for this part of the package is to calculate the Fourier transform \
directly,\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["D",
      FontWeight->"Bold"], "(", "\[CapitalOmega]", ")"}], "=", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"\[DifferentialD]", "t"}], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "\[Infinity]"}], "t"], 
        RowBox[{
         RowBox[{"\[DifferentialD]", 
          RowBox[{"t", "'"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"2", "\[Pi]"}], 
            RowBox[{"\[Epsilon]", "+", 
             RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{
          StyleBox["d",
           FontWeight->"Bold"], "(", 
          RowBox[{
           StyleBox["\[Pi]",
            FontWeight->"Bold"], "(", 
           RowBox[{
            RowBox[{
             SubscriptBox[
              StyleBox["p",
               FontWeight->"Bold"], "s"], "(", 
             RowBox[{"t", ",", 
              RowBox[{"t", "-", 
               RowBox[{"t", "'"}]}]}], ")"}], ",", "t"}], ")"}], ")"}], " ", 
         "\[Times]", " ", 
         RowBox[{
          RowBox[{
           StyleBox["F",
            FontWeight->"Bold"], "(", 
           RowBox[{"t", "'"}], ")"}], "\[CenterDot]", 
          RowBox[{
           StyleBox["d",
            FontWeight->"Bold"], "(", 
           RowBox[{
            StyleBox["\[Pi]",
             FontWeight->"Bold"], "(", 
            RowBox[{
             RowBox[{
              SubscriptBox[
               StyleBox["p",
                FontWeight->"Bold"], "s"], "(", 
              RowBox[{"t", ",", 
               RowBox[{"t", "'"}]}], ")"}], ",", 
             RowBox[{"t", "'"}]}], ")"}], ")"}]}], "\[Times]", 
         RowBox[{"exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"S", "(", 
            RowBox[{
             RowBox[{
              StyleBox[
               SubscriptBox[
                StyleBox["p",
                 FontWeight->"Bold"], 
                StyleBox["s",
                 FontWeight->"Plain"]],
               FontWeight->"Bold"], "(", 
              RowBox[{"t", ",", 
               RowBox[{"t", "'"}]}], ")"}], ",", "t", ",", 
             RowBox[{"t", "'"}]}], ")"}]}], "]"}], "\[Times]", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"+", "\[ImaginaryI]"}], " ", "\[CapitalOmega]", " ", 
           "t"}]]}]}]}]}]}]}], TraditionalForm]]],
 ",\n\nvia a saddle-point approximation on the ionization and recombination \
times ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "'"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ", which gives a harmonic dipole of the form\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["D",
      FontWeight->"Bold"], "(", "\[CapitalOmega]", ")"}], "=", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{
      UnderscriptBox["\[Sum]", "s"], 
      RowBox[{
       SqrtBox[
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "\[Pi]"}], ")"}], "2"], 
         RowBox[{
          SuperscriptBox["\[ImaginaryI]", "2"], 
          RowBox[{"det", "(", 
           RowBox[{
            SubsuperscriptBox["\[PartialD]", 
             RowBox[{"(", 
              RowBox[{"t", ",", 
               RowBox[{"t", "'"}]}], ")"}], "2"], 
            SubscriptBox[
             RowBox[{"S", "(", 
              RowBox[{"t", ",", 
               RowBox[{"t", "'"}]}], ")"}], "s"]}], ")"}]}]]], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "\[Pi]"}], 
          RowBox[{"\[Epsilon]", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["t", "s"], "-", 
              SubscriptBox[
               RowBox[{"t", "'"}], "s"]}], ")"}]}]}]], ")"}], 
        RowBox[{"3", "/", "2"}]], " ", 
       RowBox[{
        StyleBox["d",
         FontWeight->"Bold"], "(", 
        RowBox[{
         StyleBox["\[Pi]",
          FontWeight->"Bold"], "(", 
         RowBox[{
          RowBox[{
           SubscriptBox[
            StyleBox["p",
             FontWeight->"Bold"], "s"], "(", 
           RowBox[{
            SubscriptBox["t", "s"], ",", 
            RowBox[{
             SubscriptBox["t", "s"], "-", 
             SubscriptBox[
              RowBox[{"t", "'"}], "s"]}]}], ")"}], ",", 
          SubscriptBox["t", "s"]}], ")"}], ")"}], " ", "\[Times]", " ", 
       RowBox[{
        RowBox[{
         StyleBox["F",
          FontWeight->"Bold"], "(", 
         SubscriptBox[
          RowBox[{"t", "'"}], "s"], ")"}], "\[CenterDot]", 
        RowBox[{
         StyleBox["d",
          FontWeight->"Bold"], "(", 
         RowBox[{
          StyleBox["\[Pi]",
           FontWeight->"Bold"], "(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             StyleBox["p",
              FontWeight->"Bold"], "s"], "(", 
            RowBox[{
             SubscriptBox["t", "s"], ",", 
             SubscriptBox[
              RowBox[{"t", "'"}], "s"]}], ")"}], ",", 
           SubscriptBox[
            RowBox[{"t", "'"}], "s"]}], ")"}], ")"}]}], "\[Times]", 
       RowBox[{"exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"S", "(", 
          RowBox[{
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["p",
               FontWeight->"Bold"], 
              StyleBox["s",
               FontWeight->"Plain"]],
             FontWeight->"Bold"], "(", 
            RowBox[{
             SubscriptBox["t", "s"], ",", 
             SubscriptBox[
              RowBox[{"t", "'"}], "s"]}], ")"}], ",", 
           SubscriptBox["t", "s"], ",", 
           SubscriptBox[
            RowBox[{"t", "'"}], "s"]}], ")"}]}], "]"}], "\[Times]", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"+", "\[ImaginaryI]"}], " ", "\[CapitalOmega]", " ", 
         SubscriptBox["t", "s"]}]]}]}]}]}], TraditionalForm]]],
 ",\n\nwhere the times ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "s"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"t", "'"}], "s"], TraditionalForm]]],
 " (and equivalently ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Tau]", "s"], "=", 
    RowBox[{
     SubscriptBox["t", "s"], "-", 
     SubscriptBox[
      RowBox[{"t", "'"}], "s"]}]}], TraditionalForm]]],
 ") are obtained via the saddle-point equations\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[PartialD]", "S"}], 
       RowBox[{"\[PartialD]", 
        RowBox[{"t", "'"}]}]], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["t", "s"], ",", 
        SubscriptBox[
         RowBox[{"t", "'"}], "s"]}], ")"}]}], "=", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[PartialD]", "S"}], 
       RowBox[{"\[PartialD]", "t"}]], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["t", "s"], ",", 
        SubscriptBox[
         RowBox[{"t", "'"}], "s"]}], ")"}]}], "=", "\[CapitalOmega]"}]}], 
   TraditionalForm]]],
 ",\n\nas described in detail in the original paper by Lewenstein et al. (",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
 StyleBox[ButtonBox["49",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
  FontWeight->"Bold"],
 ButtonBox[" no. 3, 2117 (1994)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
 "), or in e.g. M. Ivanov and O. Smirnova. ",
 StyleBox["Multielectron high harmonic generation: simple man on a complex \
plane",
  FontSlant->"Italic"],
 ". In T. Schultz and M. Vrakking (eds.), Attosecond and XUV Physics: \
Ultrafast Dynamics and Spectroscopy, pp. 201\[Dash]256 (Wiley-VCH, Weinheim, \
2014), ",
 ButtonBox["arXiv:1304.2413",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://arxiv.org/abs/1304.2413"], None},
  ButtonNote->"http://arxiv.org/abs/1304.2413"],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading the package", "Subsection"],

Cell[BoxData[
 RowBox[{"Needs", "[", 
  RowBox[{"\"\<RBSFA`\>\"", ",", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<RB-SFA.m\>\""}], 
     "}"}], "]"}]}], "]"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Getting the action and prefactor", "Subsection"],

Cell[BoxData["Quit"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"parameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "\[Rule]", 
      RowBox[{
       SqrtBox["int"], "0.053"}]}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"45.6", "/", "\[Lambda]"}]}], ",", 
     RowBox[{"int", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "800"}], ",", 
     RowBox[{"Ip", "\[Rule]", 
      RowBox[{"getIonizationPotential", "[", 
       RowBox[{"\"\<Helium\>\"", ",", "0"}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"prefactor", ",", "S"}], "}"}], "=", 
   RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"VectorPotential", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           FractionBox["F", "\[Omega]"], 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Omega]", " ", "t"}], "]"}]}]}], "}"}]}], "]"}]}], ",", 
     
     RowBox[{"FieldParameters", "\[Rule]", "parameters"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"CarrierFrequency", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"\[Omega]", "//.", "parameters"}], ")"}]}], ",", 
     RowBox[{"IonizationPotential", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ip", "//.", "parameters"}], ")"}]}], "\[IndentingNewLine]", 
     ",", 
     RowBox[{"DipoleTransitionMatrixElement", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"hydrogenicDTMERegularized", ",", "hydrogenicDTME"}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Verbose", "\[Rule]", "3"}], "\[IndentingNewLine]", ",", 
     RowBox[{"Simplifier", "\[Rule]", "Simplify"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.14342099999999999293542884970520390198`5.177212659565305", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{"#1", "-", "#2"}], ")"}]}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"0.9298245614035087`", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"0.057`", " ", "#2"}], "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"16.312711603570325`", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
             RowBox[{"16.312711603570325`", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.`", "\[VeryThinSpace]", "-", 
               RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", 
             "-", "#2"}]]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{"#1", "-", "#2"}], ")"}]}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"0.9298245614035087`", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"0.057`", " ", "#2"}], "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"16.312711603570325`", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
             RowBox[{"16.312711603570325`", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.`", "\[VeryThinSpace]", "-", 
               RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", 
             "-", "#2"}]]}], ")"}]}], ",", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"0.`", "\[VeryThinSpace]", "+", 
            RowBox[{"47.52531453766161`", " ", "\[ImaginaryI]"}]}], ")"}], 
          " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "#2"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{"#1", "-", "#2"}], ")"}]}]}]], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.9298245614035087`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
            FractionBox[
             RowBox[{
              RowBox[{"16.312711603570325`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
              RowBox[{"16.312711603570325`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", 
              "-", "#2"}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.9298245614035087`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "#2"}], "]"}]}], "-", 
            FractionBox[
             RowBox[{
              RowBox[{"16.312711603570325`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
              RowBox[{"16.312711603570325`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", 
              "-", "#2"}]]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "1.80712270039424565134134220685109928995`4.992387472634075", "+", 
            
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"0.9298245614035087`", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
               FractionBox[
                RowBox[{
                 RowBox[{"16.312711603570325`", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
                 RowBox[{"16.312711603570325`", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                   RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1",
                  "-", "#2"}]]}], ")"}], "2"]}], ")"}], "3"]]}], "}"}], "&"}],
      ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3.7919899780229263`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.114`", " ", "#1"}], "]"}]}], "-", 
         RowBox[{"3.7919899780229263`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.114`", " ", "#2"}], "]"}]}], "+", 
         RowBox[{"0.43228685749461365`", " ", "#1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
           "1.80712270039424565134134220685109928995`4.992387472634075", "+", 
            
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"16.312711603570325`", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
                RowBox[{"16.312711603570325`", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], ")"}], "2"], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                  RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", 
                "-", 
                RowBox[{"1.`", " ", "#2"}]}], ")"}], "2"]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"#1", "-", "#2"}], ")"}]}], "-", 
         FractionBox[
          RowBox[{"532.2091197225158`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1.`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#1"}], "]"}]}], "-", 
              RowBox[{"1.`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "#2"}], "]"}]}]}], ")"}], "2"]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "#1", "-", 
           
           RowBox[{"1.`", " ", "#2"}]}]], "-", 
         RowBox[{"0.43228685749461365`", " ", "#2"}]}], ")"}]}], "&"}]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "[", 
  RowBox[{"t", ",", "tt"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"0.43228685749461365`", " ", "t"}], "-", 
    RowBox[{"0.43228685749461365`", " ", "tt"}], "+", 
    RowBox[{"3.7919899780229263`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.114`", " ", "t"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "-", "tt"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
      "1.80712270039424565134134220685109928995`4.992387472634075", "+", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"16.312711603570325`", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
           RowBox[{"16.312711603570325`", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
           RowBox[{"1.`", " ", "tt"}]}], ")"}], "2"]]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"532.2091197225158`", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1.`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}], "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
      RowBox[{"1.`", " ", "tt"}]}]], "-", 
    RowBox[{"3.7919899780229263`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.114`", " ", "tt"}], "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prefactor", "[", 
   RowBox[{"t", ",", "tt"}], "]"}], "//", "Simplify"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       RowBox[{"47.52531453766161`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"t", "-", "tt"}], ")"}]}]}]], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.057`", " ", "tt"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.9298245614035087`", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "16.312711603570325`"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
         RowBox[{"16.312711603570325`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
         RowBox[{"1.`", " ", "tt"}]}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.9298245614035087`", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.057`", " ", "tt"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "16.312711603570325`"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
         RowBox[{"16.312711603570325`", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
         RowBox[{"1.`", " ", "tt"}]}]]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
      "1.80712270039424565134134220685109928995`4.992387472634075", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.9298245614035087`", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "16.312711603570325`"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
            RowBox[{"16.312711603570325`", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"0.`", "\[VeryThinSpace]", "-", 
              RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
            
            RowBox[{"1.`", " ", "tt"}]}]]}], ")"}], "2"]}], ")"}], "3"]]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "10"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Getting saddle points", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "GetSaddlePoints"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"GetSaddlePoints[\[CapitalOmega],S,{tmin,tmax},{\[Tau]min,\[Tau]\
max}] finds a list of solutions {t,\[Tau]} of the HHG temporal saddle-point \
equations at harmonic energy \[CapitalOmega] for action S, in the range \
{tmin, tmax} of recombination time and {\[Tau]min, \[Tau]max} of excursion \
time, where both ranges should be the lower-left and upper-right corners of \
rectangles in the complex \
plane.\\n\\nGetSaddlePoints[\[CapitalOmega]Range,S,{tmin,tmax},{\[Tau]min,\
\[Tau]max}] finds solutions of the HHG temporal saddle-point equations for a \
range of harmonic energies \[CapitalOmega]Range, and returns an Association \
with each harmonic energy \[CapitalOmega] indexing a list of saddle-point \
solution pairs {t,\[Tau]}.\\n\\nGetSaddlePoints[\[CapitalOmega]spec,S,{{{\!\(\
\*SubscriptBox[\(tmin\), \(1\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(1\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(1\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(1\)]\)}},{{\!\(\*SubscriptBox[\(tmin\), \
\(2\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(2\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(2\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(2\)]\)}},\[Ellipsis]}] uses multiple time domains and combines \
the solutions.\\n\\nGetSaddlePoints[\[CapitalOmega]spec,S,{{urange,vrange},\
\[Ellipsis]},IndependentVariables\[Rule]{u,v}] uses the explicit independent \
variables u and v to solve the equations and over the given ranges, where u \
and v can be any of \\\"RecombinationTime\\\", \\\"IonizationTime\\\" and \
\\\"ExcursionTime\\\", or their shorthands \\\"t\\\", \\\"tt\\\" and \\\"\
\[Tau]\\\" resp.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info63674213632-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
        "}"}], "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Omega]", ",", "Ip", ",", 
          SqrtBox[
           RowBox[{"2", "Ip"}]], ",", 
          FractionBox[
           SuperscriptBox["F", "2"], 
           RowBox[{"4", 
            SuperscriptBox["\[Omega]", "2"]}]], ",", 
          FractionBox[
           RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
        "parameters"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"\[CapitalOmega]Range", "=", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"Ceiling", "[", 
          RowBox[{"Ip", ",", "\[Omega]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Ceiling", "[", 
           RowBox[{
            RowBox[{"1.32", "Ip"}], "+", 
            RowBox[{"3.17", "U"}]}], "]"}], "+", 
          RowBox[{"5", "\[Omega]"}]}], ",", 
         RowBox[{"0.1", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"saddlePoints", "=", 
       RowBox[{"GetSaddlePoints", "[", 
        RowBox[{"\[CapitalOmega]Range", ",", "S", ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               FractionBox[
                RowBox[{
                 RowBox[{"0", "\[Degree]"}], "-", 
                 RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                "\[Omega]"], ",", 
               FractionBox[
                RowBox[{
                 RowBox[{"450", "\[Degree]"}], "+", 
                 RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                "\[Omega]"]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               FractionBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "90"}], "\[Degree]"}], "+", 
                 RowBox[{"0.6", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                "\[Omega]"], ",", 
               FractionBox[
                RowBox[{
                 RowBox[{"0", "\[Degree]"}], "+", 
                 RowBox[{"1.2", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                "\[Omega]"]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"180", "\[Degree]"}], "\[Omega]"], "+", 
                FractionBox[
                 RowBox[{
                  RowBox[{"0", "\[Degree]"}], "-", 
                  RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                 "\[Omega]"]}], ",", 
               RowBox[{
                FractionBox[
                 RowBox[{"180", "\[Degree]"}], "\[Omega]"], "+", 
                FractionBox[
                 RowBox[{
                  RowBox[{"450", "\[Degree]"}], "+", 
                  RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                 "\[Omega]"]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"180", "\[Degree]"}], "\[Omega]"], "+", 
                FractionBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "90"}], "\[Degree]"}], "+", 
                  RowBox[{"0.6", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                 "\[Omega]"]}], ",", 
               RowBox[{
                FractionBox[
                 RowBox[{"180", "\[Degree]"}], "\[Omega]"], "+", 
                FractionBox[
                 RowBox[{
                  RowBox[{"0", "\[Degree]"}], "+", 
                  RowBox[{"1.2", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
                 "\[Omega]"]}]}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
          "}"}], ",", 
         RowBox[{"IndependentVariables", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<t\>\"", ",", "\"\<tt\>\""}], "}"}]}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"Tolerance", "\[Rule]", 
          RowBox[{
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
         RowBox[{"Seeds", "\[Rule]", "75"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Jacobian", "\[Rule]", "FiniteDifference"}]}], 
        "\[IndentingNewLine]", "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"1", ";;", "3"}], "\[RightDoubleBracket]"}], "//", 
  "AbsoluteTiming"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}]}], "Input"],

Cell[BoxData["\<\"Fri 10 Feb 2017 17:17:59\"\>"], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11.34810300000000005127276381244882941246`7.075523182254745", ",", 
   RowBox[{"\[LeftAssociation]", 
    RowBox[{
     RowBox[{"0.912`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"8.606967005168286`", "\[VeryThinSpace]", "-", 
           RowBox[{"14.707989760797728`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.85014983295243`", "\[VeryThinSpace]", "-", 
           RowBox[{"40.97411440392983`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"63.722627594462914`", "\[VeryThinSpace]", "-", 
           RowBox[{"14.707989760797759`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.850149832952432`", "\[VeryThinSpace]", "-", 
           RowBox[{"40.97411440392986`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"12.245615698905132`", "\[VeryThinSpace]", "-", 
           RowBox[{"11.285995288896231`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"31.494082066597265`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.54646297451046`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"67.36127628819975`", "\[VeryThinSpace]", "-", 
           RowBox[{"11.28599528889629`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"31.494082066597265`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.54646297451051`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"137.4740176835973`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11658019540031508`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"108.7058292318411`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"82.3583570943027`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.1165801954003149`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"108.70582923184111`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"87.31522679800291`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12083732434029802`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"113.66233957629899`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"142.4308873872976`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12083732434014896`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"113.66233957629905`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40596881691825`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"184.9104244366461`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23233632108243676`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"154.3862465344917`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.985063633891322`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"129.79476384735148`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.2323363210824397`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"154.3862465344917`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"134.95690060852954`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.2115042067050331`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"159.54768443393`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.964399844301617`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"190.07256119782417`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.21150420670503398`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"159.54768443393`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.964399844301617`", " ", "\[ImaginaryI]"}]}]}], "}"}]}],
        "}"}]}], ",", 
     RowBox[{"0.9177000000000001`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"63.2740751970315`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.231847559132989`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.388201480646025`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.48085448472251`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"8.158414607737049`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.231847559132879`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.388201480646195`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.48085448472241`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"12.86646067134218`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.816178584119227`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.10766368142045`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.053003192490344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"67.9821212606368`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.816178584119315`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.107663681420476`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.053003192490436`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"136.7702066530049`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11776334712026203`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.9916707304329`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"81.65454606371028`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11776334712023807`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.9916707304329`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.41014295719714`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"143.20317083740107`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12356070149769953`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"114.42383835786649`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40448191262519`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"88.08751024810647`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12356070149769921`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"114.42383835786649`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.404481912625197`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"128.9984932224422`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23701538097059494`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"153.59811008119402`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.988167845040145`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"184.11415381173686`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23701538097059385`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"153.59811008119405`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"135.69899681389657`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.2096365908093363`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.29707986973403`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.961158174071347`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"190.81465740319118`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20963659080933794`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.29707986973403`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.96115817407135`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"0.9234`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"62.926170460370045`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.65814465684809`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.02649667251935`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.890884272646176`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"7.810509871075484`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.658144656848187`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.02649667251939`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.89088427264628`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"13.385569221277166`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.443606571400158`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.62046690403217`", "\[VeryThinSpace]", "-", 
           RowBox[{"36.6562412121443`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"68.50122981057183`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.443606571400174`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.62046690403224`", "\[VeryThinSpace]", "-", 
           RowBox[{"36.65624121214431`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"81.08582224927886`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.119053070614874`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.41258000537293`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410019527358276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"136.20148283857347`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11905307061487341`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.41258000537293`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"88.72623375924712`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12627795169569153`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"115.05163809511696`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.403027171273088`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"143.84189434854179`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12627795169569797`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"115.051638095117`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40302717127308`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"128.34122462191704`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.24124640092126007`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"152.9491533625454`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.990786350067832`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"183.45688521121164`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.24124640092127894`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"152.9491533625454`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.99078635006785`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"136.3007608380092`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20830597502517378`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.906109196267`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.95846638934123`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"191.41642142730385`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20830597502566991`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.906109196267`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.958466389341726`", " ", "\[ImaginaryI]"}]}]}], "}"}]}],
        "}"}]}]}], "\[RightAssociation]"}]}], "}"}]], "Output"],

Cell[BoxData["\<\"Fri 10 Feb 2017 17:18:10\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Length", "/@", 
   RowBox[{"saddlePoints", "\[LeftDoubleBracket]", 
    RowBox[{"1", ";;", 
     RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.01388888888888889], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxF13lUTlsYBvCvT3ETSZIylltEGrghSRMaKEVJkiIiFUVKaHUzVKQyRBGi
WxEypUgq6oaSlESXVgMiaVBp1HT3Pns5z7dWq/X756xz9n7fdz9b0dlzlYtQ
IBC0kj/6v8A3+9J4jSZ9AfdTMVA0bN30cj3sJ6GkEhAGl7y1bdR4BKtcPnrn
Yz38t1vm7ki5Zt7lWj+0l5r8tpKBxqBif6cPHFxgk5OUAFdFhgTZv4HnOWaY
jRD+4B2u0jQyWxP+0jal1NMJ1s1aFaUYAZ+mj8uEG1emTw5qgKdG+OycMLKF
94qfEda7leC9dklzixbCiVk546ZZw6+nVvQEuMH9Ie0V5QfgGfR1z8E2q6aT
FYMDHxgc/PQcTp5ov3lhNfzfAW/j052waF0YWYFW3prmV4YbK8MOdx83xurC
IbLvX3VZw/f2t92xcoerayQirx2EJYyVfYQx8PwbemvW3YWdpewWpObD3PLV
wBkfQvtduuCv+gnV2ZJtvKW5BYT1hpfHey2C3Txbggps4DNl4q5TPeCcBX8u
238IborVnVUWA8uL2kqqpcBLttEHwl6vjpRW1cAX/vondX43nH/2UdSJUT95
t/eX+dVPgxU2Ndsb6cHm+cMWnV8N+6kpTmn3gONP6YhYHIaLu6w/J56Hex22
Px1IgafnBl9d8wLmyuUjHBD20F28B77eWmrhLNXO+x1tz+mwMFNMWkYfVqev
ZwvbB2u/e7odDmqgDQLftXKP2XMBrkw77F9yDxafEOs4oxCeyxU0vOFLCekQ
OGzZd1Gt0R28028PIRUN18pMKviiD0vtm0cqENattgyP3gG7chsMk2JeaXYR
fixJdxhu8E4b21sIj6Pt8Rk20vv2PvkXvCNehKxgJ++YP+gHw8+2a5Evhtvo
dtjBk7W3kjeEl10MnJYbDPsK6RPhuK33vnunwUUv6Q/umf31lnItrBQ9eCKg
F7bqk/Mul+7i7b9xzmrNmXDSs+XzjxrCZaou8p/sYMHJgF4dL3hWZ3RlZAhs
t44OGPjwkxdxS+/Dt5VrD8UWwRV0HNTCw1pkTa36YPp218Z08+bGvSocOoU2
HHyflt9a+FP9mZQRO2FJy9unXY7AOqn55ISDt5CvHfcAPkU/9xWc9ZkWIFxv
qk5OLFjmlsnHfTI9vA3GbPz3jSrs4bcvcdZi+GwlPdDgPKOb26p2wi1X6YbA
E0fWqJ24DJvu6hlV/wDeXS7dZlgMX6Lj7ytcSHbjZz/cNdTprPnYXzjvuBeE
V7w+6TCwGObabR185Xyewp1dcKmgSigeCg+Q3d0YB88slHqekQ7b0u0tgQ+e
WXzMow6++YsOQPi9k6/lZNle3mJPj8/eowZzj1sCOxzP7VBxgI/Q49cbTl3b
8fBDKFyTTQcCPILGm4ew9lFDMrLgzXTcf4OPk3QQPQg/Sg8f2iLbx7tu0tVv
puqw9CHaIDA3XhxgNwsaOOAoUs3Jx+BckjbE4uFmf/25jhnweFrOr2FjE1ow
8K7kYxWugn7eF0fTAxhm+Q/uoMtnDCtweRDm4oYPzPIhnOC1iJzoMMuLcJ8O
PYFhlh9hGzF6Yg7wDuTyJHyjmD4QZvkSHsINaFidy5swTVeW4TDLn3CKOp34
MMuj8PCey2RCwyyfDvJ2JtPARR6O4PIqnEHLxRSu5fIrzMUrX5jlWdiVa2CY
5Vv4SSMNRDDLu3AYqQZPEYHBb7P8C6fTOCoHszwMk/CSp6AJs3wMj5JIu7LX
BGZ5GV5It98RZvkZ3vq2zk3VF2Z5Go6kcSocZvkafkyquTIBXs0FKJimj3mZ
MMvfsCxtyDcwy+OwUfGWt3XfYZbP4R00DghFeLO8DsecIz95mOV3+NlAyv42
TZjleZh243JTmOV7mKanBCeY5X3YjDaEL8zyP+wTKSdqGwGz+wAc100CSCLM
7gdw0frl+cOyYHZfgLtzN1/fUAaz+wPMjeMGmN0nYCuS/qSHCHmz+wXsTz93
PMzuG3DSmhdz8mbD7P4B/w9mlSZB
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.8906250000000001, 9.9},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0.912, 2.2800000000000002`}, {10., 12.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"data", "=", 
     RowBox[{"Compress", "[", "saddlePoints", "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Button", "[", 
    RowBox[{"\"\<Restore example saddle points\>\"", ",", 
     RowBox[{
      RowBox[{"Set", "[", 
       RowBox[{"saddlePoints", ",", 
        RowBox[{"Uncompress", "[", "data", "]"}]}], "]"}], ";", 
      "saddlePoints", ";"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 ButtonBox["\<\"Restore example saddle points\"\>",
  Appearance->Automatic,
  ButtonFunction:>($CellContext`saddlePoints = 
    Uncompress[
     "1:eJys3XlYDf//8PGiPa0iad/\
TvlNaTlKiTfuilUR7jqSFZClJEom0WNps0U4pSaWFtJAsRXtCEopKdL9O12/u33XfzXxnzvfyj+\
v6fK7Os5nO+/GeOTNzZkS3B1l7f6OhodnLCv8Y7N0btMPHM8QnKNB7CeV/0sE/\
1vv8d5KbQ6svr1b6ou+9DPnfZj57Q/73h/73vxjhH8OggGD/nWHk9mE+z3pNURL5A/vmrIO+\
CjWLf4R+vadf9pv1JHJYeX9jwYGNNXjNwZJLHId6LEnkacwmA9I8QLDJ6rrR4dFBGRJZRDd8JuCsFE\
pzS/KpNQei9Enk6/O3D31/vAG3+fr6OSnhV1tJZAP8ZgHBZtcqMWk5JU8S2Zc1XUjt9QP9xT/\
i3ulmIa+wjUQ+zlhyisZHHbcZypNq/fW8LYnsitn0oLZZwkF/\
W77TjkR2P6QwpPK1GqWpVxf3eIevC4n8qfv42S+78Jv7zzt2Nj+\
jrLsdVnMD0lzRQ6w5mx6gKia4i0RW8XOxVn3w7OHiH7mvXSTqYraDRH7C4iKqMIffdDt1oTRQy4NET\
sdvPiXYpN/JMH7pPTQjezz7z3A/RWnqxR2+GvsNmn/jD40O/MRvXt3b42ddC+ue/\
t80FyYFUYNvO1pcqZ0UznzfMcyTDYB9NspUlIYqosCQzeKV99wBgK2WNGYnPMAH/\
LlPsZzfSoRElsNsOiNNQ4LNa263K69UrgGdMy0yA1clUZoRdn5jjWwkGD+ytG1NsfiAlzWLLu/+\
C5NCP2YzCmnqEWzKavvH5a4CGNcSEgQeSKLBYPhwJG7/\
vDOJfPP1b5H53fiDQ8hBfsWQD0wKH2Nwm0UEm0H1Ih7RI7Ccpv005/\
KvPkRpjoV8lhVJB8DhCb4iCQQAX/dLqb9Ib08iq+M3Iwk2HabYr/\
8QBmxVoVNCMfatKDBc6mvuiatRYOzyPDNNAPDk0mHJa0sBWwpm0xVpzhNsavxMUnT7Cct5lbdZ0f3l\
E5Tm64s5tw8ze5HIOz+\
bhrITmBTa6Xblc72F5ezBb3ovai5MCmGsEjJRCdROCrUfxmsSQmFS0PMWs5/\
eqoQCw3ts54EmBgB8qf5rFNN3AnsKvmVmP3WFSeQQzOYepHmbYDNp31pbn8eyJHL2aJy3yKAESrMhL\
mufnyUA1tUyuTtvgw94jFVNikfEikTOx2y2I009gk2ayDSBKCMAXH2wkccwAg1w99FfZbveAuDcCnm\
WXwQA85uJJ5AZAPA5/GYeweaY+\
ZrMCEUAzJHsptO3pgalaRP8ntmiDgAH0o02yxMAnFzm2zIxC8v5C7NpjzT9CTZlfg1bfmahYKMTOri\
mHw3wLY/eUHchAGzzLk0+5w9+s46+6tmlcW8SeTMjbtORYNNpp8rLy8yw7jnFknKPb6ABNj179/\
VfAQC85kQOm9sUfnNqL6ONzReYFPZP4zbLFjUXJoX2l/\
ZjSpXUTgql5hIOJ6xgUhhkmc16x6CMAkPi4wEpqQptmIlX1qWvFzbCXRnbNI+/\
b1cIkchDmE05pDlPsCn8IPVguC4AdiJxH7hrgAY4Unl375ETAPhbe9dUlAw+\
YMt5L45zhXIksgVm8yDS/EKweaDwLpeIFEwKBvo7Hki9QAOsUle1w/0+\
ANb6KDL7iQDgt95FsXWUrVAwZlMVaWoTbOY5nk8JsIZJQbKXrkTlGCrgVpknJ0cA8BnjhvMt3vjNCe\
2rJp+WbYdR343VdEaaqQSbmUbfrD5MuJPIHebiZmVebSgw6vojTBSWAeCKaH9j/b/4Td+\
iVinpHpgUBv9ds3dGy9doNUwKV382hTjGoQEu+DTU2KsAgKue37pSO4nfTGfiHJ3+\
A5OCRylWsw1prlvUXJgUZK6cKOz/SO2k0OQoaOu4UpBE1pQQi5fbhga4l9YuNH0fAJ5O5AsP34QP+\
PhwN+1FFZho1mI2B5DmDMHmspOmnhsdYVKoHD2zx7RUHKU5uVSZJ6oaAN/ISef6QYsPuC7wt/\
znWHkSuRyz+RtpXifYrJjq0W4YBcAOOrURxkpou9BMpRP09zMBsP+\
j5UI9BADrtLJFSLLARBOM2WSmtnmGq4K0ai9MCi92OHXG96EBLu2VmIticCWRo7K3LPMlANjrguolf\
UGYFFr/XbNrf/6A11MAnP6hOzJ/CA2w816arqLf8GujpYOn2wkAPv48v3l7G0w0/\
m1Yze1IcyvBJmMcw9p3y3bDLOKUt6YuAA2wWs0zx3kdACwTtttTg8Ck4BeuXLFmDUw0G51xm7KLmgu\
TwiHfqpDkVeNUTgoBws0sHisAcH2W5Qna62iAG+4dUw7RAsCrt//oYPPHB/xd+\
nh6kroA7NNgNpuQJg/BZsxyYSHxPTApbLzNevy6Bhpg7bXXq+\
99BcDar32tOHsNcJsBxReW95srkMg++E1Dgs2n/r/kcidsSORr/\
j1rWBLRAPNbx3snHgXAW3t8Vz4lAJj2ccdyhh6YaO5gNgWobc7xGf3aKQ+j3mtImM5P/\
xFKU6PM5zOXBAA2f1mlQUcAcN3K99+9zsBEk4zZXIs0LQg2B8pDN9sVAuC0/\
dHt8SrtKDB0LwTq7R2DVckQ5rJ3ncdvsvmdEXtfCRPNNGZTD2leItjk4169okETAOc70lUoO6IBvnB\
C73PXFsrn/3M9icU/8JtlIhNnw1fDRBOL2UzFbi5MCq/\
Uv64z2gSTAgs1k8Jpke4j9HMWJPKO8zqvaL+iAQ5u9uikWQqAx2djRJtO4QPepMLrUuXDDx/\
yMJvRSHOEYPNWjWbakTiYFJQiAt6fqBVDO9D4sVOGSciARN77fUKH8SE+4EJ+\
u8keJkUSWRGzeQBpkgk272l4Rmi3A2Be9ZDrq76iAVZ+\
mm9u6geAL3NmbSgnAFjLYuUM2xuYaLgwmyrUNm1DtsTnacOoP3f9TrLmVTTAP+\
Pop7v0AfB4yR2HtJ34zfCno6tGbsOk0HcHq/\
kXafYTbF5Q4k6USoZJ4byx7Fh2MBrgk0MZnpLvYVUElBKXfSAAeLdUb73xbZgU6DGbCUiTf1FzAZvS\
vOifn/uoxaZ4/KzZryHAtuVWldUmFRWUAVdqz/lbqEMLNqhfg2LVb+PDEPR+\
fmNL0WoS2QqzWYE07xNsVo78scy/BNhSnOw233dEg/\
HLr2AZ7RaAAXsj5aZX8WEImyVmyd4HbHcwm9NI049gc09Q7GXVx4CtNayWUxD1INbhpxkrTtsCjB+\
qd3uzCcC4/\
cjD8G8tYOvCbB6lthm0WiL3bxPAeCXQI2LMUIvSrCYZ0ak4A4xR6WvtcgRgvODf3a5qAiP0OWbzIdL\
8SLB5b++PbX6XAcaXn166woVoMD5+WdJ1rh1+reQO/2XBNBq4zbVPtKuC9gNg51+\
4TalFzQVssc22j67nUItt90WxkGdtgI3ZN5c3IwgNhu3oalWabIBxN592+\
u4TfBjM09YjvxkBGwNm05Pa5m+/\
dVmdJYCNZ8JqRd5PUZSm0TkGaZYQgPG1rL4tPAYfhmTodvWAHUok8krM5iakOU6wKdQSX6x8B2D4zk\
Rz525Dg5Ecc8adRx9gbPlDXplIAMbNEP5XT+8DYDf8phnB5sujT+\
UU7WA0BQZwio8HosE4a9b1yHsvwCjLbWAu98Jv7vv0advUAABegtk8hzTvEmzef+\
MnLn0WsB1JfZHpMYEGg1PS711GHawK7YWGtzMEsOmflzP94ALY9mI2ubCbC9jeJx+\
PcX5BLTZhc9WP2lWAre/\
7rtvnb6Ju2R4uPcEaBjA2vetsvjhCYJcvpT1xlx8fidyM2axGmnoEm8vZHNjHlyiTyHa5D2tF0tFgc\
Md3BQdnAAxmKQ3VTX74MCL7DA6JNQFgN8zmcqS5jGCzI2PTvrFCgGGx7KnKqtNoMLRpNVqvyQIM9cz\
JJfsJwIgSGBzfkwaAtwpiNc2RJjfBZgmLN2uJJ4wm3ugK3aPdaDDCE/\
fP5J8EGJPa7IF6BGCoTgvzz/\
8GbJxHsJoHkOY4wWZHSLC1vSHACEwLGq5S6UCBMb77JKvYPViVOCbpBzG0+NjoNrNfc4sBwKn/\
TXMBm6bb/c3LlnylEttWp8T8sjerSOTvtn+6bg6gwTi95/Dfp5YAo30dK8dKWmPclblI/\
ymf7iYAnsRsJiHN5wSbjMUST0q6AcZ7fRorQyM0GNIF7aOBdQDjB92ztghrfBjGNgNaalYA+\
DVmUxZpThBs1rHMlaYdBxhDqvkmgXVoMFgjufjEeAEGrfVYuRsBGH+\
X276OvgaAKzWwmmxIc86KWHOVuM/AywAYTbKDtPyuZnUoTUUd+gj5bIDh+\
KnIq3oHfvO3jFTzRh4HElkas6mMNJ0INku+nsufCwMYkyy8ttEhaDA63XOVOG7Bqhi8DH/\
BswQfm1LtQdezsgB4Br+5YVFzAdspmS9s1crUYtMr/\
ha91wqwnUuMmVRbpYoy4MatNt4bXgMw6g8PPnJcjQ+\
jPDh011wqYDuL2fyJNOsINp08pjiujAM2526zGIdJEZSm5oHV02ofAYY/\
x4GiD9r4MBKWSVoNZQA2Y8zmWqTpTbApyX3rQvglgHEgs3bq6jTqZ7akXb5edJTTHjIaxkYEYPAw3l\
RL2AeAi1KxmkeQZijBZphWz8yIHMAYr11+/vUjNBhjp4Me0N8HGLsKe83WEoDhKFc/mxcOI7QHs/\
mF2uZzRd6r4dwAw428ufR7ORoMNWvJIJvL8GvV3pfJXCeAjSnP02LCn3J6JgSruRZpai9qLmAb/\
i78PMidWmz2R5d/mosDGI2MtCWRpmgwshQCWDgYAEZEkT5vrCo+DPtNb1P2d/\
CSyA2YzRxqm80mo8azNNYkcnym9Ykn19BgdBeojg2xbSCR6X9dzvWRwIdhdmdC3nwEsJ3AbPYizaUE\
m9pN3GUKXgDDeqDqRYEi2hE5bSVRJvvvTiSywsH9pbIEYFSQ3R2fpFBOUfRjNdcjTSWCzW0SX01oDA\
Fbd5VNqpNOPUpTR/rnBpt2gCFXqhxxfTt+s/mKeZZaDIzQ/aW4TV2Czb/\
WurVyngCDNzGA5DyPBuP9HZdl/\
cnwa3czBlWTluJja4hrjZuYdYNdffym76LmAjadB9bnRROpxVYbHzbf6ggwJLZwnqw+\
gAajtFT2NevQOhKZjhx4v3IzPowm002vPoQDYF7MZjnS/\
LuHWDP1YtzsLQUVEnnsWu0XcXc0GLLlj0yvqACMg+\
fW0w2y48O4ZGgx28ENgCcwm4rUNsPHt7D52QC2E45hUyk70WD8rnGuHegDGMor9Vg4CMB4HRNJ53MK\
sN13xmrOIU15gs0L2Z5TsUkwmjwms/\
vNqtBgDCroS8iNAIxcXRsVLgIwptfwfs1zAsDn8Zt5BJs3aC9y9Q0CjLf37F792fQcBUbsxRfJ+\
XGwKpfzT6b0EsBGPp0Vm20HgOvvYjXjkGbqouYCtnOU4yNV1GK7tOnXkhw/yqF/AZE+\
xXw0GDKbjlvcrAMYGokMztwe+DByfaZdCkdWwuyO2VRDmtoEm+tb3kaq7wVspHkm/3k+\
NBgFKVtDDtkCjARZAbH1syT884HtWavVJQCbNmazCGnGE2zePTqnbx4DMPx0dybYZKLB+\
Pp6y7uZNoCRoVVi+p3A9atrP5kdUzMEwNGYzW/UNi/R8fvfTIfR9Pg3d9+aDY9RmnQC55Wu/\
HalnNDPyQn2xG8yjJ3o+RIE2Noxm/TUNo2Tx9rMtwAM4yWN7VLJaDCuHorbnH8QVkXv+\
o6yGDp8bE7MCjnqzwCwEWYzG2nqL2ouYBuzKheK+UwtNu+qJ8nkCIAxuE5m/\
a83aDBY6lvSa3IARoaudN2lffgwfp/p2CzgBoDH8JtZBJtvApY5cd8DbDE/K/\
s5C4XRTpRHqT26EAowZF5c1HAdwYdxZ93XM3IagO02ZvMY0pQn2BRt+swRrgYwei1/\
3Rh9iQbDbvca01MPAUaqkWRkJwEY+d+\
f0gcfBMAbHLGa9kjzOMGmVPOqY8MxAOP2ycrikFY0GDo2zcW1nDAmj4XFTjz2wG8q7h3Qz8ujbA7wm\
zEEm5OFz4TE9AFbwcmAHLF+NBj9S6MfviLDrz0av1xVnR4fW+\
nGrwbv7sJCNMZjNQeQ5qFFzQVsYon79vCzTVCJ7TZnQbmeFcDIfyQztp5BDWXANSXykOSOAwzuzrhC\
cjw+DPriuyyxywHwbczmU2qbv1Q5n/vOALY7zKXFX1TQYJzXebf99wWAkZp0/PjaF/\
gwfq5RLnxkBNjuYTbTkGYaweYFe9s6JQnAFjL8i9ueA+3wt+PANf4zBQDDpH3nxTICMD5oRbs/\
3QfYLuE3NxNsLrVKu3u4CEbTmGtrcI1nA0rz8bAq11VJGJN3zmrzchKA0X4sbk9GOgB+\
itlsoLbZua9t9MkVeMHdlumYjaovUGC83ffyuPRuWBVN+\
UTVMQLYYpt1v69SB8DZmM1upKmxqLmAzeJHok2IBLXY7j4vyAwqWkEii6+\
cMhBQQYMhdSG05akvZZdPhGln5iUCn9nU2T//\
3giABTCbqkhzLcGmEZPigb92ACP1Zg8DX4UQSpN50nO+ohxgNN69/vp+\
DT4MnXzGJW7aqrDJxmwuQ5oNBJs0lSeVnAMBhjTTvFDmZtTzV5YmnL8vA4y29Rx5KQRgPHH022G+\
AgC7YzYjqG3OyL7YZlgFo2mu4lRr0RwajOVL6zRMtGGcXzMXnDN3x29Wr5utFC4CbC/\
vYzVXIs0cgs3z3kkCE/HwgtUrzLk+xKLBOFVxYuacK+VqD/\
Gun3cY8LF9MBBKkFsD2Fgwm4lIU3JRcwFbuON1jWfrqcW2Oqmkqd4GsKWcs9lf4owGo1Mu4etxS4CR\
N8wvKl+MD2NvfmCSsRZgy8RsdiHNfILNArreTsYIgMHjseuDlBEajH00lvL9rwEGr4HO2Js7+\
DB2vB+cGN0JgDUxm2FIU4Bg8x3vmhXNDABDjWnnlYfH0GBYSpRsqU0CGBcDyi+HEIARn+\
bLtGoXAJbFb6YRbHLx7XOPbAAYH2yTdJdcaURpStjxjdVZwDh36Z13jXLDb0qkJyl8a4AR+\
scOqymJNJ0INkPrZk+Q9sELHpy/IBTYiwaDOdBqyWobylVi9+6/P8iIj80++EWtjRBgu/\
XfNBew5T54xCtlQy22J0YtxTKzPCTyl2A9X76jaDAmW69VmGgAjKbJkwdlH+\
PDWFNXxLZcEbCNYDZp2v6n+Zhgc9+qQfnj+wDGq5gvz8pfCqI0t7ldazkwDTBunzVWOJGJD2N2rLs+\
uhwAP8dsuiDNOwSbaxNuCaVPw3Ie+6n9/GENGoxV1fVsvYcBxr3H/\
MesCcC41ynHRutBOXeH2eRDmncJNgt3LY+53w3Yeja03Tpq1oTSHLokLyO8A8Z5L413+2VX/\
GZIrXtNUgeM0HLM5gjS7CfYFLVWqCp0hxf4h4l1meh0osDY3XOAtohySaZtAXmPMxM+\
ttv3xrpPLgdsTphNX+zmArYOse6ZKF9qsR2fzn23OQewOeaelNtxEw1G9/\
uvzLP8FGzaR4qzXuHDiJ5ZpuYgDtg8MJt9SPMZwWaldcCF98dgEHdZju2M9EWD8bAxwPkCryGJzLzp\
8K7qBHwYy7vogt5PAbb3mM0apMlCsPmyesndqk+wnHfrs7dc+YMGo2LYLmHLXoDh3qK+\
VYkADIbAV6+\
5nChXkPy75qOx7a7SPTCaNgoos0subUZpitTWGXjth3HebW9TUuiC3zSv4nv4YQIAq2A2xZDmO4LNZ\
/2n32tsgRcwtgQJTWaiwdDS0rthqwer0k4X5m3MjI/t8LxgQCsTYLuE33yxqLmA7c/xye5Xh6k+\
QNLmQMvCBzB+/Z0Lzm5Hg1H85Tdf/FKA4ewy3pb5ER/\
GiZtzln1WAJh5HqvZjjR3Emyal7cyqauqkch/V12pl1iKBmM2d0xEWxNgJB+eTgw+gA/D9Gnvnx/\
JAIOPD6s5hzTPE2zqk7TfSr+D5jotn4kd69GuorBj2lD71wtgJP+\
xp2ElAKNS8YfvJmvApo7ZtKe2Ge7YqcPG4Ag6BdZP/KpHg3Hu3nnpzJOUrRCP/\
pqCbQTOB2qTBO6PwAjd/O+aaQY+xx+rwwvYSt2P/aF7iXaLjTdbh+bV4NcqGq0uNGTBx+ZTEG+\
w8u9OEnk5ZjMfu7mAbQ3laq2L1GJrfiYsmL8EYHxSezfxaQoNRrxYosjHz2tJZC6bpk/iv/\
FhSKnPRYhzAOAhzGYC0mQj2HzfbHbraRYMYg/jW7PkywJoRzi1gvwCbAFGjWHz2Qv++DAuFR+\
pPhsAgF0wmy1Is5pgU/LoB97LpgCj88zf72wRaDD+aira/bQHGI936icNE/\
iiJ89HMfVXbbDujZjNeWqbakuVZ9T5AVvA7re2a5OfoDRXGzOcenEZxnl7exbLRWcCN4/iDJw1/\
wYjdA9+s4Ng882ltwZuPwCGlenOxwxkNBhCXAerb6+\
BX6sitC3OlhUfW4QIc5ydMCyEHX5TdVFzAZuttfSVE4XUYtN07TqYQQ8w9Jyd801Wq6MMuCeKLAzML\
wHG3cuPDXSWbcJdmT0rv6mF3F1OIutgNl9R2+zNyYj0KYIBlxTQ+ElWHw3GRxL/\
rXVkgCG2LmCdvCs+jDyh2nnm64AtDrM5jjRFCDYPi3P8eVwLy2nO5Vp/\
tQINRha3YaT8ZoDBZyL2u5oADJcrrgdWGgFg73/X3N3D9e0D5T4KS/\
xCzbcGPUVr0j7l4SqFMbmswrfLz4nAvVLS94/\
sVgbAVb5YzWykyUawybGSpaabGV7wOO6n0pNhNBjDqx9aOAnDqggLvYyOXIaPLZuv2/XqKAD+\
hNkcQZqii5oL2KLvkY4MNFKLbbl/yE76AIAR5LhH/\
okuGgzayDKpd9UAw8d017YvAvgwvjcy5ATOmf+nJh3S9CXY7OXS+Nz+EAaxqo+\
qPe8AP0pzlf1wStZpgLH2/u0/0hb4MK4+F6++1g/Y1mI2V1PbTPo2Rr6lR9my0VjyiM+\
iwfBNjRnJWA8wuIvL1l8gAOPTY4VPX8tg3Z9jNv2oba53iGY5xbCDRE5MrWwfc25BaZaF3Ylwb6Kc+\
1U3vSThiN8knbHlKzECbGcwm3eR5hOCTf75Q9/MJ11JZGmrGWERzy4UGB4PaLL+\
8AAMZdnb5yvZ8LGtYT8f+vYdYFvz3zQXsOULOHut76UW2/\
Cgluy5HwDjQ6NxaaQHGoz84BZh5xsAI1iiRUhXAR/\
GO1O2CypSAPgLZrMEae4l2DyWM3glbLU6ibwhbOdypjg0GDViq0lF+QCjP//5/\
DF9fBiODMPi9K0wiB0wm3VIc5BgM70kht/qBjSDR9+\
0pKxHuz5w6WR7iaEiwCDlapkFEoDhM5rK6rIOAJ/4hNWkQ5o6BJuj83xTgtsAhv3ko1O0js9Qmg/\
CN1U39QCMep2rXx7a4zeT2HeEbeACwBFTWM1qpFlHsLkiqGsT3QuAYdnk+pN+\
GA0GE5dXbgoLwDhcP2a6igMf288amnNX3wNgN8wmM3ZzAdvrw3uNz/\
2kFptfry9vWz83ibxxmtdv9xE0GJbMKrn7zgGMHmvnUWVdfBhO543eMn4GwGaYza1Ic4Bg8zbtkFKc\
NWBjrfbz7lBGg+G3LU3Ftxlg6NDPjuiq4MPIFsxlZO4BGN8fYDUDkOY6gs0VXs/\
ZRjKgqfszgePvQTQYc35FLoKiAKPVNkpqIwEYeaSHx6RUAZvVv2ue0z6wrTQYsM3nDtT27m5Fab483\
rjV4RvAuKQwc13LDr85InfuFpsAYDt+HavZhTTTCDZ//HLNedoEMLr55TmvkV+\
hwNCP5uEQoAEYr77LNaVw4mNLYaHfytcEgF/9N80FbHQfEmS+sH2jEtsdY9JM/\
QDAODTvfygtGw0GD88fV6logJE8wZ3+zAwfBvN2Ekf5ZQB8ALO5EmmeJdjcUJKm1fsRBnH+\
fvUQ057VKM1yh5z9z4cBRoLb405zcXwY6o73f/\
WdAMDXMJtV1DZ1ztxJvJUEyzn5IlbN4xHqVujyqVtSPJSLhrtG61YRgKHloGDELA/YZv5dk+\
QyGjgpBTC+rThwyiypDe27Z12KJisZ3EnkspaEwQQb/\
KZZusTA4VgAPILZnECapQSbpO6LgTXFgO2ZsUjYbtbXKDCGXIM3npzyJJF76XSWanHjY9OZEytb/\
gCwXcRsDiPN94uaC9iUzfJYjCWpxbaLZde6xreAbfJt50b+\
ejQYY525DTv8AYZuiWoBrwuB3chDoUxP3AHbFGbzK9LUI9gs38R/\
PaEGYOT1VT21ikeDwRTdWTJOu5FEVjtx365wBYEjh1+LJeN/AYwCzCYz0lQn2Hyanl58iXI+\
sMiUq76GHu1i3LSL+UUujABj8nSo4BiBm94c7hF/\
tUQKsF3Hb04RbH68sZPhjwpgO2IQPdK2ux1ta2lfk8bFDzA451/llVgRuJGupjBXcgZgK8Fs/\
qW2uURxheXeDMA2Z+DhMV2IBqOYXkDn3SeAIUIq+\
8PIg48tM9dD8ksRYBPagNUsQZrCi5oL2FyKHo5d0qEW284b+ceHRQFGzQd58x+DaDDE71/\
nlXICGLsFLust98OHkdZmfp3lBQC+i9mUQpo7CDabtq1iXEZvQyIr3l1GW6eNBkO2sk+\
mThBgBF99ZevJhA/DaLZQ4dxPAGyB2VREmiEEm1vTBIa4RACGu0/\
5IQlTNBgmSjXVVbMwJuPPP5SrJgDDh/\
dUS1UYANbCb54k2JTWem2rqAvYDr91fB26qgPt299PdnrbKwOMGt/\
TeXmWBO7xaEd3Z6oYFuIcZvMYtc2GDs5dXTGALT9z08T2nW9QYDg/\
lHBm7QMY9j6CbCwr8bEd2u9WdCkPsOXgNx0WNRewHV/5pvWXDbXYnJInbp98CjAyyvSiZP/vt+T+\
n63uyISStzHAqLl3jKM+HB/Grsba0i/DXCRyKmaThDSrCTbVjt/74s0N2C7bvbGP/sKH0tRg3P/\
YRgtgcJmPid7/qY/bnLym0DQvpwGfMTCbmkiTlWDT/X6x99IAgCEj0+\
yQdAYNhmvrbaeN4zAm85WnRxIJwHjqp6SisRoAq2I23ZDmLYLNLa+9WZJMAFuDBMOTy2/\
QYITcot38wwhg8LrtfO1ijt90Txblq2iGhfiG2dyHNFcQbEpb6ei/DQRsWZVHyxXl3qLAuM5fYsj+\
EmCEP1y/0WQVgXuQrA3JFEkHbHseYDVvIM1Di5oL2Eoivxdu9aMWm39HG0fTLYARWWcn0SSKBuMA09\
YjguoAw8wjNFMhDh9Gprr1jHE9AI7CbEYhTUuCzcMBc7UZwoDtCGlzSEAWGgxb5rMKObYAQ0jdWZr0\
Dh+GgoGB4CsPwHYKs+lIbfOU4WadYE/ANvdHOpj5DRqMYy5u2t/6YUxmnP9m7EYAxvbC2XQ/HsA2/\
e+akp5M9eN98ALZ3VW5ewqeozRzTArbp7cBjFX3fAeebCHwfTb9t72ytgBYGbOZS21zb8jHrQEOgG3\
kXbjbMfputKORM0/y3jUDjAb/Z3Stq/GxvWzaIuV7GrB9+2+aC9h6+\
1iTbxyhFptLQKCyy17A9qnKYskLfTQYpz7F0BuLAYz8W+aiNufxYfAzeR/\
UegDYhjCbZ5HmdYJNc9FP5gXygM21okMi2AkNxqWPMbX3ggBG1vIha4t6fBhOnNMmoimAzRu/\
mUewuXrSSJ3WnnJSm2evcIoo2tdM1t7dvfHRSxjnJzhWG8oTgHGdaYa3lB2wbcVvxhNs5mzWark5DS\
+QM4znHM98gdLMlxVkjyADDFKHmunAJvxmYMn3QSYPwKaJ2byDNPUJNvd88FPbcxRgcKbSCe+\
aRoNRUEf/LagaYNydJ7fdEMTHVlwk5xdJuS2zURpWsxhpVi9qLmBjNZbctySNWmyGPQWnknUA2/\
6xOHcrVzQY8aV+\
Um85AcaRjTSpa3PwYfzSYPfxuAvYIjCbiUjzGMGmWOk1zStagM3nxkmRYG40GNxLf984E0/\
Z5QuNL3t/Cx9Gwbbxz0NNgG07ZpMHaTIQbEqFquazMQOMnhveX9f5ocHwp9l7pJiyt/\
Uq6sDzaQL3TlzZVu5SugUA/8BsBiDNLoJNe+3mAQ1/gDHHETxkeLMTpfn22TLHUyco9zJd+\
npz0kb85n6HkWY6LicSmYcTq9lDbXNZxYfBMSmAsbnD3IyR+R0KjHjVu18qigGG0PuaveMi+\
NhEPzd/XbMfAAfhN4UXNRewrb2l57CtiFpsNXRLRSsKAMa5FRw8myPQYPj//\
FzZOa9JIvPbnGt6V4QPo8La3tyJEQCnYDZDkaYgwSbr68K1MnMAo4PvVrf9s1Von9lGaTvVcwFGa8n\
Bls/J+DC0bVKZ9xgD4FbM5jqk2UKwed9Ge8/+pYDtofSBzNkyNBh8ZQpidQ8Axq89Dz/\
XEYChF980clwfsDVjNldT29z0MurHwzDARmPBtsS0+yVKs13T2sH8KsDI/np/\
rpKE33Q4ZfV5lSxg6zTHbeYQbH6eMzuQywbYFMVqxPT03qPAuCvzRv9OHsD4++Lom1IJfGzcp+bWx/\
oCNn1hrOY9pPljUXMB23ZOR63SJmqxpSof0ja4AdiOh+omPzyPBuOta/\
Sc8leAccTffrPJQ3wYO4rW8qW94CSRYzCbvUgzmmDzaMOZmQlFeEGV3hIXjng0GE5bvWhyHgKMXN+\
y0OAD+DDeJHJqi1PuhHUfs+mKNHMINkdie4T6f8No+spfzd9Hi/YFSpes9uBvRQCjsFI85hQBGIU+\
yuIR6oBtFrPpSm3zpEzSUeaNAOPFmm0WG7VfoX0O/P3l0NsKWBVLdotsQx38Zr/YJf3yGADs/e+\
alYlfO478cIHPV0fSms2v9qLAyAkJydVJAxj6eayNQmvwsc28fDYS4grYJv6b5gK2hVuQ9FGLzce3Z\
8bwKsA45i80VVGMBkM/bTbk03sY57H+AcfCW/BhVDUmh/\
7MogDGbJKQZhzBpmfKPYlyd4DRpntzeawJGowk9a11/W8AxuFNLZ937cSHkd+\
nkLPRExbiFX7zCMHmWJj8oRNrAEZJesuZrxZoMBrMGF6vzwMYqXlHztkRgCF+/\
nXEBOVBkMWYzUakeZFg0+1Gr7h6MsA4uLa9n73zNUpz+qavmusL+LWjj9dITGsS+\
Ea5xnIzWncAzKuF1fyDNAcJNt/Tigo6vwZswVqbN5y83IcCw3u508jWUwBjd4bAtm2K+\
NjiT3sn9FkCtqP4TZ9FzQVs99/G/9n5i1psnewXNIyDAVusw+2/\
Oq1oMCqYdtP8aYUxGfVgsHLvG3wYmwRYq7syAFs4ZrMKaYYRbB6+fIVLxR+\
wXTBcXnOdCQ3GMft9JyZ+AIz3wt9Knlngw5Bhfu4gkwwLkYHf7CPYzJisO1wqBNi+\
XGR3U8pEg1EZq9F9JQ1gRDSYcggQgNHJFXyQfwRGqFwaVrMKaYYTbDIWfO+\
1uArYnmw78Vy58i1K0ztC5zvTOPxa25OGh1KUCXyfjaRVrxkJ2M46YjV3IU0Pok3asJHbBpRzYnMra\
zhS+lFgjBftXN9xCGA0Vtam3VHHxxY5YtgxWQmACzCbE9jNBWwj+\
jm91ezfqcRm0LVH7QwJsLHtll5j/hENRv3QhxqvhzAmha5qsWmN4MPQ3Ncg2HcesLH+u+bBw58+\
XqmHFwwZvTPzfsKLdqLc+\
Ub6czYjEnmfesOVzHX4MC48kNI8HQaABzCbskiTTLBZn8j52KMbRtPIJTbevDE0GF8a+\
VcInwYYroFHPvURuAV34h6v5pnlAHgQszmONF0INuNPhanJFwK20J8ZSvtY36E031yNv8ZJDx8/\
u9JmHctk8Ju9fzb6fUsFbMGYzbfUNpMjHmxnvQQwZl8d2bX64QAKDP+r7Z3pewCGmo35SJQOPrbhp+\
pKFaqUL4++xmoGIE2NRc0FbNwLNyGhFpsbt6/\
nSm7AZpx48vr4Uk20I4c21nxChTDO694lhTz9TmA38kBMHecZ8//\
UPEdt06Iq83PxFLwg9MZkxZ1TaDBcLMTF4qUBxqVutsYXYvgwTBOS7744BtiCMZuuSDOdYPP55UD6h\
+2ATYJ2NsFZF+0+HAfpb2uUHaVs2drur84hACPjSC2zIzNg+\
0yD1YxCmpEEm2aZIclzDwGbf3LO2qcTvShNpjjeKRrK6b3eOROXMiH8ppegrtzZcsDWch6ryYw0XxB\
srh+m6dGJAmzuckusstWGUGAUfdjfc2Q7ZTdyi+SFQGN8bFqHuz53iAG2Hf9NcwGbHsur7GBdarGF+\
bGvT2rmIJEfRuzcIymEBiOJ9tw1yaswzovPH2qTn8eHISXK/Nv7JGCrx2+\
WEm3uKyjYLrWWRD7AeZRurzUaDJM2F2k+A4CxgpE53J8NH0b07IVr80k2hJorCTZf+\
v1kbv1rRSLTOtg/tTmNBmPyghLN9jCA8btu5bmdBGCwncii12gAwJ/tsZpT1DbPDw9r0HUANkd/S/\
37b/vRDuQU5n1cIQEwlspmbjjCReD247eFg6++\
daJ8uMdquiLNJQSbSw03N9C4ALYDxSP3nvKOoMBIEHtVb2QNMDYsmf2VZIOPTahwtq+\
EC7BVlGA1TyFN00XNBWy+QRMxzbbUYkt4FSPXHwMwtlv81p1aiwZDPiRPP+wswNj/I6XXjdUEd2X+\
dLzZoLYHALthNpWR5j6CzXsKmRw8mQBD5bMdd+\
4qNBgN5Tlph50BRppHsIHXtB5uk35DvWWpPQBWxGw2Uds0YAq/9KgSYKi7NK++\
OIAGY7NmwmaJAMpu5KYNWyQJwGD93JLlPAmAZTGbW6htSnC3WnyYBxjzoYaOBnuGUJo/\
a6ON7mgAjMlkFWWheTXc5m1eXclrgwD4B35zimCzUSpzyWlNwLbVyqFHoHAUBYbYF5emGBLAkMkIGh\
3ciY9tSZbE/\
OxfLxLZ0gGrKYk07RY1F7CldDLvFvOnFltGkXzfn9UAYxP997OeVmgw9Do5P3AfAxiBoVfMdvDiw4i\
j3/byYDQANsFsbqC2WZD3/QPXDcD267rv5bV9K1GagwkB1o/\
3Agwh0uT7e4P4MEYkVxfdiqXcXOUGVnMIaUoSbA7ZGj2Y+wgwmL6sWKq6Fu2mN8obn/\
6c9QQYhzKDlAcJPFyCn/ytfEcRAGbHb0YTbLYaHrh+\
YBpgBIXQiOzeMorS9Dk6eslpM8BI35ze7DmID2OXr5nd2TXOJHIJZtMXaaYSbPIYnZ/l+AQwZitJ2+\
hOjqGdgBZvNy2Rp1zHGJfSmHgYH9u8f/RM+\
TIA7IzZTEKaEYuaC9geaYlviTxKLbZDPQxJ6yMBhnxxeF2ALxoMupne9u/7AMZ2/\
4K89eL4MLxFP8W/\
aWAnkeUwm1zUNqeuNMaZ3QUYJYYuCkI30GAYq3iwjyQAjOhbqiSvNnwYIfTvBWdLAXAZZnMTtc2Lm9\
ZalfQCNl1xLXOpU2gwPpdU/B6yBxj6MjZalwnAaPMaNFt9jbK1/\
HdNUmiCmDMnDOKJ1NhJ7YfjKE37rS+zB90Bxt+\
HBY2qpfgwTNv8N5s7AbY7mE0HpElTQ6xp8XR9z4uebSQyQ6VAWGP0NxQY1jmJGUtWAgy5XfR9twrxs\
RlO/vATfA7r/vs+\
VtMGu7mA7cslHfnONGqxJWtYMvGFUg7Ty3BOCRxF3bL9ZXBesZty5PDap10fFfFhBBYHcRSFALb9mE\
19apt31yQlP6uhXBtZvn/\
SbC8aDL2d2uHDuQDD9S9PtHclPox5lST3tGEAvB2zSUKaHgSbadKN7kMZAMNi7A591BAaDLazhU79p\
gBD9LOQgxMBGF4s/F4HXwLgnZhNdqQpRrBJtvl7ZMdpgBGjXKM8UDaF0jTcbEy7PxxgFF/b4edhjw/\
Dbp2d/k45GMRdmM2NSPM2waYkk3T2n7vQPM998OHgq18oMCr41Zk3z0GzbgfTpB+7Jm5z+Y+\
rW87lAeA6/GbDouYCNj46e3aFYqoP/bNe/MuzB7CFZI+\
IkdPRYBg38DOEOQOME4VrfwZo48PYyMYWEiwB2PbhN+\
MJNruGloieagFsMiZGXeV6aDAajQ7JPq4GGOuH4gYqr+HDiBLalpLKQ3mIAWbzCdIkEWzqH85Y+\
ugsYLtR/y7KQBftdm636CKFvpIAxqPKg5FEnlHG7DXB6PwUsBVgNvOpbX7XtOsWNoRBHPf7TcuVUhr\
S4h/5W1dZ9vc0DDiGMsatx6+p4jYrtv69/7qa8qzhGawmXf3/NNUJNnd3P3yoeBmWc+\
5y1WbWBlqU9+\
jpav7T6cOU79aqufmpPsDHlnfxxdGfoYAtNAur2YE0Jxc1F7Bt9KEcIaEWWzi3j5GiP2Cz15kSCS5B\
g2GR6HVglTnAsG66l/PECB9GSzRbP10XG2xiMJvWSNOBYJMlycFriyHAaDDeZuXAigZDxnb+\
WuwrgLF1aXyH5zl8GNq0tee0XgPgdszmGqRpRbAp5T1mVxAH2KRjb9qEX0CD8V7QYQebJsAYFUi80E\
jgGWUTJiRnk0eATRKz2Ys0PxJsRnz+e9TrNcDYHRXW57KVEQVGY/\
Pe6HUZMOCqV65frdqvgtt0Ovby4bAlwLh8CKvZhDTTCDY/\
VzyYtD0LzS92R5YrbWdCeY9WFfD76byBZi2rRU7I0bW4zcv2bV82uAK2v/jN+kXNBWzBrXHP3/\
dRi21TIuNJlxMAo+bk40t8T9FglKgqxEzqAwx1Y7EyGit8GNYlTDU7dgHgSsxmKdJUJdhMWZJV+\
mIQYLSstgsVerMCpfmsTGeX3ATAyF2z963dYXwY+1NeDRbvAcDvMZutSPMmwSaN60DUnSjAtu6Ahq/\
iDzQY/e7sZuvlKLuRtT3pkQRgNOtrHt10D7BVYDYHkKYwwabvbqWcTcOATfy0SFAHKxsKjKRwv/\
69WTDgTrV07p1Qx4fRXvvF0sEeYNDiN88QbOZneFSu2wowKvsC/\
ZiF2FHeo92nYvh6nkNT2bXmV5bSOtzmD5fY7raTsJxhmE1fpCmzqLmALUMtq3TtNLXYijeaepZuBxh\
7zs2t2TOABmMdvQsjixrAuOQ678jlgg/DOEf5srceAA7BbGohzcsEm41F3nouXwHbM/\
rWd3TX0WAw1xe0ljIZk8j99KdvpQTiwyBZf2J5eRmwteE3Bwk2nza0ltrfBhiuqrU/\
fbai3ahURkecIUwEYHiVu4UpEIBBOxRR+CAEAK//d02TPZpKg2OAjUslasfPGU4UGJ/\
up6TJ5VGwhZRF7buqjH/\
aY9OeFZLOMIjlMZtjSDOWYNMnRfd5qAlgM8g467jxKBfKexTvMNw53wrNZW+\
CjFnq8LFtfTM5Mn4clnMFZvMk0qRZ1FzA1pRaeT6J4weV2N60Rqosn1oGn6+\
YbymHz6DB8JPUZ3CQopzUrmwo/uOND8PpV5CssBsADsRs+\
iPNOwSbu89WFZc8ozzQLdbwMm0YGozi8K+aEqIA40x0P5ewCz6M5wbbRl/\
M2vynZinSPEuwqeq2SnZfNmCLuPI0SqMADUa4CldT7QqAcV/ZT+AdgQcC+kTWS/b4Ajaff9cU4h/\
pn/wG2C4eSdE/IbIcBcZa4W9q+ddhwMXJMs0qi+DDkBNoHr/\
tAoO4FLO5DmkeIdhsnjIN0jcEbGsVpI2Zbi5HeY9+\
cH3m2tZCOWoqcOuF9kYt3GY08wENmxhYTnPM5iTSXCr4/zcXsE3+\
6Qz7KEUtNr5oK3mb24Ctn893qTrnWpRffEQ94fIbPoBhwTDc1bAHH0aQtaBsthNgG/\
h3TSWOhlSr34DNoLzBZNlmNBiub2o+R2gBjL+3xH993YwPY+\
nVd57rGWxJZCPMpjvSpMkn1lSUjZHKugjY3MqMe9I40O4KfD4is301K8AwHi0NjScAw2uTihizJ2Bz\
+XfNtuc/6DKnABt3pnf8QbYVKDASJ+Lbo27CgNsZ+P7gjKMS/t9z2pLmiBsM4qkM3GYIwWahQ+Nl/\
6OUrVBKd738BbT3KKZmx02vJ9Dss7/Z9PYePjbFswOGZH0ArI7ZPI40Rxc1F7CJ7Bh33qBHLbb+\
43sj9e0ABoPsllfZUmgwVtKdYk5iAxh9AzdbAg4QOBr5qtRg1S4AzIrZXIU0hwg2p+\
zf2yRzAYxU9V2vBPjR/kDiSzkV7lsBDC+6L+4M6/Bh/\
Blp8iiS0YIPZJhNKaTpS7Ap7mE61XMasL2wWmGQswcNxu1oTe9DNADj/BrDfRoEYDgf/\
DVh6ADY4jCbd5BmCsGmUdO9zp3TgM2cJSTn+7OVaEcjD4oEDN+CASfFtl73RKwi/q7+d5XdI+\
4Ao5EVq8kY9T/NkGXEmuWMdOwxOgDj0uarOh0OaFf52HGlXHrbBE3jL/vt/4po4zbDuF/T/\
TwMy7kfs2mPNPUWNRewmTUx6qbbUYvtrkzhO1sxgLFBM7XxiQ4aDPoTIWfCaAHG+VfSp3/\
E4sP4paNm9GMrADbEbDIgzXMEm1tErp9/\
aQcw8k5uLJQb50FpPnZ5qTToAzDC3Ol9PaTwYWyRtPfsEQDApZjNZqQZTrBpw3xo6KQ5wFCSzNd2eY\
kGo/2gR9fXKQcS+Z6nL/17Ao+\
6FRx7PioRC4AtMJsdSPMuweaKFAvatFnA1s9PX9XtuwoFhujV0talt2HAbeiVuthTr4DblHY6GEXjC\
YO4BbMpjjTNCDZd76xdpaAN2KxCWwdGJ9G+BkXmypW62AjN8WtlTx8exsf2bPgb85NoWE4nzOY+\
pDmxqLmALUxBVHjSn1psmmof+Obes8L2clnUq5vWaDByx19dPDOlAT/C/YPN6Qw+jNzbP8sfmFFu+\
IPZvENt81U4X2HNEcDW1qSRplKLBkN5eFTo12GAsTeye8scDz6M25HF0rwygG0As6mKNMMINs98VnQ\
OPwAwtqwYL3umjXa/+/HPCvv8PgOMHMP65ccIwGhk6rbrMwTAR/5d81yXiuUIBUbk+Lvkc5/\
4UGDYK0VKfKXAKG67MjXFiQ/j++l7WTvnAHA0ZtMBaRYSbP5ed+LK80OwnEsO9kS3haDd2/\
Oqaj7nyQZottb5T2d242N7ZOttpLcOAM8ewGpmIc2WRc0FbNlntWnNj1GLrXVrJPclE4Bxb9nhH0a7\
0WAwSZhcfPMRYPweGVS4nI4PY423SjFtJgAux2yyIc05gs3rpprs+woAm7Tr9D3pC2gw2BMf8/+\
6CDAepQpYvF6KD0OsUEt/oxpgE8FsciHNaoLNlvqr19+\
QAZsTE2kpXRYajLHY2oxvfQDj1l7pBGkCMJYOmOeQtAGb5r9rducta8jdDoM4ce/\
1iRYrfhQYEae83pTegQGncl78wpXd8vgHHpQDkob+\
ALY0zGYk0pQj2Pxhp1uRoQkwdn7q6lfvQXsewzMv6a9Zj6FZ9nSrTonSetxmakXIW1oK4GzMZjvSfL\
youYCt7ZfNYG46tdhst82eT94I2JbdHPieeRANRupNJj7L9wCjJamyuSEXH0Yqh9iskwtg48dsViLN\
twSbHc/G/052A7a/cW+OMAagwbiir6c/VAQwAqd8Or9/18Vt3mrftd5Lz/Y/\
Na9S2ywa7FLPp9zyN8z09VsWVrSHSxS39OYf7gIYjKWXnJoIPMQ9skFWy8iHsrXEbJZQ21z7niRlsg\
MGXNaHsJUrcgRQYHAxj/a7FsCA+5Uc0aH4RA6/\
efnl1jXzFGz4zd8Em8I0amSLKMoVJO7DljcU0Z4O+\
yVN7umresrXdm7aB3VF4WNjHqwY1dAAwKmYzXGk+enG/\
99cwPbbJeDx32JqsbkUJJ7LJFFuqJo5nFp6Fg3G9pa+\
konnAGND2aPi9gICX7Gx2PViRgCw7cds7kaaBgSbtRXbqzcwacOk8Kr18RNDNBjHfkumPWwGGOvc11\
hvGcCHcePpxlv7NwM2RsxmPNJUI9jctb9pj5g0YBujMfcc34cGw4I+goW/\
BWConXT39iYAQ8VZILTS3YryJHmspiW1TReRDz0vKNiS1yr8UR8SRIGhYropfIICI7A/VNRKHR/\
GYXGxahINDOLT+\
M1ggs3seqOpOTVoqv0qaJoMFEJ5jzZtF9klToGx4Ui3bUEzPrYvE2HTRQdh3TfgN40XNRewSdfGXnN\
4Qi22a1s/53S9ZyGRD5nNppy8hgYjq5huxYNGgDHUaVv0oAIfxv6veZ6VOpSLmzGbOUhzgGDTYVQ0z\
EMdsP2I/ZHqx48Go9p3TCO+H2AIbg+0eNeBD8PiQinfIVvb/\
9SsRZoCBJt2bN5PsgQBW57dTvnKATQYl6dthR88Ahhvt9Wk0xKAITxR0breHrBlYzavUNss6VPhVqe\
FQSz2vu68F48wCgwz1eUCewphwPU3X6z9nSuLf8T473isuRcMYkn85gDBpk+\
GXqs0BYZ71X1Dy8vCKO/\
ROW2tjYfroHmhor29jlMHt5nB33FlVBXW3RWzmYI0UxY1F7AtPOW3n1psvGeOuIytAxjaZZ1xElVoM\
GgEeH4VVwEMz86gmMQ6fBjNvrnWI1cBsD5mkx5p7iTYbDVyMNnqAdgERj1dh36gnYg0nldaYTRDwdY\
/43nzEYHdyPFHbJHugE0Gs7kZaQoTbI7299x9bAYwfiWqmERZoT026V7iNadd9wDGlWGFgYuuBLDNx\
xXL8wDggX/\
XPJwVmFBOgeGkIH53Hb8ICoywnFmBQQqMSksjOjshfBgd0iqCLEtgEEdjNiOR5nmCzf0vlHi/\
q0CzX+mmdJ2HCNrnK75ctvFayqVVfRIPom3xsTlOB5zIPwDr3oPZ7ECaUouaC9iiEir8mGeo/\
sz2h0VT2BtglI0EzEe3o8F4Xiwv3lEEMApTJT8YPsOHYfSp/JOSBgAuxGy+Rpp3CDavyA6x+\
PsCjL5sjwqlZ2gwIouN1b9xbiKRHSQtNAuL8GHka/\
Tp8CQA4B7M5iGkaUuwGV9lmvWQBWC4OwTqGNWiwXif/\
1iO7zbAEJUUEVUiAMPm8uU8R0MAbIPfFCPYNEg3ZGiiwPDifGM0losGo0/OgHZzEQy4dRuEV9/\
IWIPb1On5Fc27EwaxK2azH2nqEmxmH/\
FX4KFgS44zOHTyMxqMYOOVOrsoMJJ0kmlJKfjYxiwTzulSsKXgN88uai5gu/\
ntufl2zkkqsVlFcvGGyQE22dff92cNocHYosUevPIawChOW378fRc+\
DAnr5rAYFcCmgd8sJ9jctdna/s49gNHxouecyTU0GOcsqk+clgEYj3NfHvtyFR/\
GmQLSGet9APg9ZvM80mwi2Ew+wb56UgtgZDEKMJ9ejfaMMrGSNtbnWQBjKI5d/5ELgQuR8+\
6v2EYLgC//u2bpuuue/hQYTb/\
qyWOyoigwtCv9qnIoMNq3BId7iuDDULHNadyzFGA04Dc7CTZt2q9PvI6kHDm8byZ+JVgU5T1yl+Z5+\
+kRZStkPDVk9gIf256jucNblGE5czGbHtjNBWxd9mNKldLUYqM7VhI+\
pgAwsg2yPOOn0WBEfLN4dDgDYLjptbC79+HD2HexVHL0G/N/akZS2+\
Sfm4gTGQRshfGyK2WPoMFI5XvJIEoCGM5zq1d6nsWHoesyKqgUDdge4TfdCDZVOeIT/\
v5yg61QNvNtVjs0GNvYd+\
09kwowuoN2iG4lAGPu27ukC8oA2Bmz6YI03xJs7pEJrS6nYPNpDbKsuYkGQ+kO0+tfFBh2DwVT/\
l6Xwd9TUCMdZqGDQbwDv+lEsLmHj33ZQQq2hKGrMnETaDB+f1dx2U+\
BoXLTWOkDO4GPDyuCBZKVYDmT8Jtqi5oL2JZU0XPz6FOLrZN56od3BcA4OJYmqL1sHcovPvLiEgP3W\
YARkKMl2vARHwbryQveXrILD9bAasYiTX+CzZTZcw/\
82dfDC4QYLre5osHYlv35Qp4DwNDL5XzEfBT/j/\
5uG5fckpOALQyz6Yo0SQSbH7rbT9wYB2y9v6X5riShwdDz2NVrnwgwQocD87u3Ebj9eLVE4gZpwFaP\
39xPsCl7WLfoHAXGW/bd+7slxVBg0BhMJRoWw4Ar/\
7ZJa7kmPgyVtpCuPxTAnZhNWqRZTbDJvsNi6ydFWM6UI0sV7vmJobxHe+YbY1gpMExoX0UameC/R+\
KkP7kyFMAnMZtkpLlxUXMBmyLlAhJ7arF9NzYKHjsM2Gqfpc8XC6PBKN20an3DcYAhkz7jzPMDH8a7\
RJfqMSnAdh+zeR9pihFsWjjHPj+nBdh+i3c0q2ujwejcOSEhGgQwDCx2+Y7sxf+jPykxV25JAWxz+\
M0NBJu2G/lTJwUpFyLXjUjZPkODkf40u030GMD4fcqxbgcBGCc9G5O3DQPgs/+\
uGS15ZRs3PQxiwar+xqsZaDC234zpi6PAMHgdymLQKI1/OkE075aONwxiEczmDqRJIthUS317/\
20ENCtePeI4M4AGY/fxJ3Z5NdAsNSmdOX8I/z1SXs4cYUEBfB+z6YPdXMDmHLuu63EA1dg+\
udLHiAMMB757Fj9V0WDo6GZ6ZR4EGGwbSqy3zOHD8GLa1hdsCoCdMZsbkCYHwSYjjWlGmhdg60ti2G\
XHiwbjfdfjM2diAUZ6+relP73w/+\
ja76qzTl2hfGbDbA4gzVSCzTTWeDWeHoDxiCX5jxIr2tM3Lf5ca/gWDjBelHKajDoTuOp//\
N3a2zxW/6lpiTQ7CTaN3AulYijYrBtNtH05xFFgPEvdeKmJAiPwQsZLDRd8GHp6ilyhFGy2mM1WpOl\
PsHnKbmbfWQo2lxsWLf524ijvUa4w84wxBcY9l5t1dGX479HQKeOJBwqw7k6YzTykeXdRcwFbzGerc\
qEYarHxfnTpGVsBMPZ4zhjRG6PB+HFGP/\
n8XoCROuJ9cTf9ZtyVoWEWeiwvAoDJmM1JapvTJcZTxrcAxtqp/giFKW6UZt+\
B7OrpTIDBtIsnYa09/h+\
deZvvyKHTAFgVszmANBkINitCeyefPwdsLLwSK3W2oMEQOHdgc0MQZTcygMTvQwDGUSe1GT9WwDa5E\
qspSG2z6kdR2U0KjO+mzwUOR6HBqAqgDV1aAgPO/\
l102I1JKdzmhif3gsYpgMfwm24EmzYcLdZrKTAuVLQVn69Hg5F+\
WLhm7CHlQuQ5trHiUfz3yGiljrQlBXA6ZjMDaU4sai5gK9rql7Y/g1psy9O8tjj1M1HuWkW/\
ot8RDUZ8d0lfoQ/AqDlTfj+IHR8Gx7G/JwcFANsO/\
GYdweaHubLU6TLAJqioub7iBRqM7HhynEMZwGC/\
uIHt5ib8P3pjlHSI8X3AxoTZzEOazASbsddpvS80A7Yneob6h+\
PRYHSdCey9tBNgzJatExhxwoex9aSdr/ISwPYMs/kKaf4m2Ow33u1syQCD2Gfl2+\
drPqHBsDM0ndGiwHj2ZPN6lyR8GMtUWeS6KYB34Tc7CDYT//\
BEVsjDci4LPShjrSyB8h5VZMzwXqDAGPkzbfloNf71q9tPeaznpGDj+G+\
aC9jelR070F5CLbY2yT9j1/kAxrG71/ri/dBgTNx7FvTZHWDsKNXQ9eDFh6F+\
18K54DbTf2pOIk0vgk2BR9O/\
s2oAG7t1MNtUMRoMnwNSzXdaAMbKzqOZZlr4MC6eVqWdGAJs3JjNAGqbH2cf8M9ObyWRyz+\
dvcrUggaj8vgbrshtAMP4RJ+\
MOwEYIqt8eT1rAPAbzGYV0txEsMmgEt5znYKt6VOx9hVrCRQYXJ682f4UGD9NDA6tUMKHIXyNe4xxl\
9d/anJT2zzHVhpsSMEmZR3C1p2KBuOsifwxIwoMaa1RfTNTfGx+\
K5Q1X4bDcv60wmpeQJpci5oL2Jj5L7mteUottt9O+w4dWAnYmJRc6pZGocE420fnb2QPMJ7Yns/\
SFsGH0THdcXg0ArAtxWymIM0Ggs3XZaQE46eALWey7ti7s2gwtktxO84PAowufXo3ITl8GCe2W2+\
I4tAhUZ7zhNH0QprPCTbTxScvN30FbLm6WvXd7GgPcZfRnPRztgIYNM+\
uCnY64sN4QbqSrnQPsF3BbMpS21TaHtfwm4LtbbB5K185GoxVvTw96RQYxkfL72S1S+I2S/\
VXe6pQsPViNvmQpgHBpq4f+51MCowrpS7vvP+iwWjsupL2q5oCw/\
MJY0AEPjajimCPTjlY92zMZhPS5F7UXMCmEX2PdGSAWmxsD4bfuy4HbOxmHc/\
MktBgtJovYa42AxguvLO75mXwYXDLvg77awLYlmE2n1PbfCLEOPJdC2D8lovyCNqLBsMxQ4tly2+\
AcbarJEJIkMBWaEihbPAlAKaTx2o6Ic3zBJu7o1iOL7kDMOLWl5yhs0GDUeZ6OUJnE+\
UACb3dy40EYKh6up1MHwHA4ZjNu0jzOcHm62HrQQcKDN+\
znokNqyVRYLCHMv5tpMBYt9XUvSsEH0bEnZknJowwiIMxmxxIU51gM8rWO8WPAsPSOCVN0lMS5T36E\
KNFc5sCY2Xne1ft6/\
jYetadMPGhADbCbH5EmpyLmgvYPIbbxbpnqMV2J2255mdegGF2341xVxYaDJlm9SO2hgDjz15RhgIV\
fBh8IRU3zTgBsClmU57a5vrHU30RfQAjn/Ng/DVbNBifra8Wn+Y2ody6v3eNGQc+\
DM4rUimWXgC4BLM5hjSXE2xe+FUT9CYHsBU+mHI5lYoGI/WYZouILsBovy+\
3psgBH4bnW54Q8jvKrilm8yK1zXh/x6NJFBjK/A/rOiLQYCyb3W3/bWHLdj4x/Tg/Poy+\
jUceRlIAK/67porS1b1MFGxk8rHTGx6hwXCxU/\
LeSYHxefT9g6ZOfGxqeXn31lKwheI3vyxqLmBL2PKJTp1rikpsq462fL7+gZFEljkYGmhTigbjpLP/\
aiZtyoXI27O/bdbGh5G5ZEWsCRtgW4PZTECaHgSbKybiwpZ9Bmz+Bc0rjmqiwTjcmSbWsQZgFGV+\
uJVHiw8j3HTvj5REwOaJ2TyCNPMJNq033P1m1gkwWj/1j0T3osHo3L99gkENYBwPvDixigCME+\
7bv5SkA+D6f9c01bgY8oKCTVrwxOXtr9FgtNIekllVCgOOjfOT6Zl6CdymwQ2xdZkUbKL4TS6CzVcp\
3XtvylK+nZDZOT4kJIXyHiWV/z4uQoFhe/RMqSwN/mO9Yt/\
U3WOiYJP8b5oL2MoLln5IkKEWmxfNAJ1qOWCz+8k+w92ABkOI9QD/a2XK12FqhNPbN+\
DD2Oecx2vFAtisMZsi1DYdM+4Npk4Bttwca935VWgwFNw4ZDkMAIa4/\
pctCpP418jFzSlcaSwHbHmYTWWkKUawGb7tU+qZswDjR8Byr0/SL1BgbLL5sn9cBmAYca+\
nPWCPD8NQTy9T9ikA/obZNEGaxgSb63SjubmZYBAfa2V6lKEmhQKjtpW+QIcCg/\
O1bXlHED6MdQorj1dRsEVhNuuQ5kqCzUSzlSJWFGzqDZuclCPQYKQuv73m/\
QPKt6p1vwjtkcXHNqjez9YT5kWo2bCouYBtiEeweVifWmwJ7bOih08AttQrDCl5r9BgbDna/\
7JOmnIwoyQwyNAUH0boh/3M3oyALf3fNbMY7E6I0NiRyF7PH2/nm0O7saZhadOFLY4AI1o3ybl3BB/\
G7dxszZEBwOaD3zxMsHlf/x0nay3AWK3BcfTlHjQY7r0XJruEAEbyyyrFt3YEbj/ucmIZ+\
QQA5v93zQwn+t43FBi0ievzriSgwXB9ESfoToEh+\
EFQSFYQH8aS8261ZhTA2E03pClMsEm7xjC2iAKj3sjYwugFGgzr7FMrL1FgNJ9Vd79lg4/\
tqfpbzrk1sJyN+M2WRc0FbJwRmrf0HKjF1qI3sPLMNsDG//2wDMdHNBj1POQrT4QAxjqNZ6+\
ybPBhuLg1MB2nA2zi+E1dgs2Xn5zaslkAG+nlcba2XjQYM+\
HlWseCAIapVdHaqjf4MA5q3rP4sUyXRN6K2ZxDmpYEm8/\
zOj58KQdsPlxvyRYP0GC0r5iYfsgDMFRVqreoEYDBXH9w0DYasLngN9UINtumIv2nKNhWbOdnTRhEg\
1FMG3n1EAXGqYY5u6gWcdymT6vpu6MUbOyYzRKkeY5gUzHvz6ebFBjXpqVPGshKo7xH8nksIh4UGBY\
jX058iMTHVtJv+yOOAvgmZlMBaVouai5g0+m1PHUhkFps3gzsoy6KgM2o3fCs+SwajDtPlr3+\
vAJg5DAzan/dhg/j1eo3j0toKQ9DxGwWIs08gs07VrsPTmgCjDmOpo+\
C9Wgwpm303lXFAgxWXR2TuhZ8GNkqDPziKwDwX8zmLNJkIdj8uGRD9fMCwNayYf6jJ0sn2gGSqzKrb\
rAADAaWUonjtgTOs4mMV2jtB2ytmM2L1DZJos/\
tOXbDgNP2fKwdsU4aBUZbssCOSxQYNLf3HS89iA9ji+\
R00T0KNg38JiPBZnVhtfx2Cgxm020upENoMMKWtwpIUGDkv1BJUM3Gx2a8scPVlQKYDbMZjjTvLGou\
YNu98BgbarGdftfz4/NfM9iN/\
EVzczurFsovviRm1SvFBjCqNl2alvHChxGtuqWpl5bxPzULkOZ9gs3J77Qdl4QBRrBtYePSG2gwWlc\
HWE5lAoyBsunZHw/xYczYO9j1egDgIMxmO7VN8S2rVCryANuZWxyKgk5oMLYrfxs+\
QwMwJuqbTry0IXCT1l318iKBgC0Zv/mdYPPiY/nYUQoMQ8tZ22Mn0WA8qlwXW0mBwZek9aFUGR/\
G7j1jNdIUwCT8pgDBZkNkLrsuBZtb4MiA83M0GDVkmtGPVdAcjow0S23Gx2b/\
9pLocgo2T8zmI6Q5sqi5gC35xhGrzZnUYhs2ilu5oouBRA4rvEOyFECD8YzPWSjy/7B23/FYfo/\
jx0t2koyohCQrW5qySooQGjJKCZFdyYrIbiAUUgkhRYUyisqIEqlsKcpsyCgJ8Tvnfvyuf76d63Ou+\
/2o/3vd4zpP9zXOdS5GACPm2pD7Dkc8jFelT7bKTwHAJ0ibDfQ27dV07J5GABipFncS/\
c6jYLBaGVrK3Qcw3jEfrNLPo7DL9/\
XkLn5pAPgqaZOdaLZRbB742NGRfAVg27Iudcn5mygYtk6GY15juzXcdZcVbxaiACN+\
JryVxQZg0ydt2hHNrRSb24zbn6tBGFUnfoY/fYeC8VijXLoZwjh6ItXPvkcU2zQPZY9fyAYGcSW+\
eYJic+qx/ViNJGi6lavtyFwuidhGErVZVvcgDEG5z8+Wf8djSxxk91oEATuTNiWJ5qK/\
mjRsjznhc2zoxXZO5pX5eBbAZru8VoRXFgXju9pJhv7JVfD5wmZMtsfwMNbK8p08+\
Rtg20faHCeanhSb3qVXtOLzATZ79w7Ps8dQMBRCVjYcfglgPNAPlq1Px8NoOmvCcW4VwGZJ2lQimrk\
Umx/3xB8MjwXYvn7plSufRMFw9ffssPoKYOy+lb/0gDEehsDxzfuGzAG2j/\
jmHorNag6rczshNicfJQMdGUkEjGtaFk7DEIZ59+uJkssUsE3xCGtBbPakzWSiuZ9is2/\
6U0ooxHZTbv5itaMoGGz+SvbeEEbgqbYL39k0sM35nFsNf50Anz2dtMlO3qRh+3L0Pt9kDb3YdBq/\
6jWNARhZ8dmcuRtRMF4Ezpt2HAUw/\
LxN2Rx88TDSsrdtCz4FAGeQNuvobVbdFNs7Sx3AYK3zTlxpjoKhfasq4MYneHy1ofe+\
dyIexmalj8dt3gPAzKTNrUSTlWLT+\
Fq6pfsZgK3hQ9nZGsNG1DWx7iz5LR8BDOFYmbYrRhSusz0y3ttqDLA1/rsmdyWH/\
hEIY7myU6iUNwqGM8NjO/b78MEa8mKB10zwMMTcLMTsIeBl+KYdxeYrmSsnmiCM5+AgUOEpCkYp++\
fezRBG5OrVXwaW4LHZqZ4f1YaA6/DNqL+aNGz8rXW/TD7Ri237ZrcHBbsBDI/+/\
GopAxSMN6eXhbF9ATCqd6Y3WgThYeQaPHZf9wMAdiZtNhDNSorNfDafa27bADYey9C9ZlooGAmp2at\
6JgCM39schrefx8OYuLchUppV7X81k+\
ht8pZddTIPBNjU6tM4Cm6gYCwNZw2QagEwnj7IU23YQeEC9Add+\
7JtAJsKaVOIaJZTbO7kVbzhC2HcfzyQ5/0MBUMrVFhRFMKQVV8aOcWBh+\
E294HBBQg4H99UoNhcEzZRxAxhKHYu+hU1TwqxjZ7z5j3lgjCYL282CJbFYys0ftv2AAKWJW2+\
IJqMfzVp2LTU+ltvT9CLLcpN/\
176MIBxyiKRxXcfCgb3IkvBko8AxjEuy1K1s3gY7O4m187IAsDepE0eoulCsZlT36fVZQKw7ak5qsg\
vjYJRruXySJJ7m4a7o7Ou15ZAPIyO2kHBAUWAzYy0WUFvM6NhpeJmL4CtPX9K6+\
IfFAyGYVcb9joAw+z8S0ZGCjA+DDfL3NLY97+ajERzL8XmbvV5YpEQW5jzR47tC6QQMOxkvN+\
vhTAEEtteVVQtwzaPH3DeXgCxheCbiyk2K1+vfPlcAjRHzGbK3UxRMLh8cz51PIQLv0a31Feq4bH5/\
fpiHQ+xjZE2F5A3adicU2c/YuIeoxNb7+Pvon8YAYy2jal+N51RMDS7S9aHtgEY4+\
2cfFyxeBgOq0OfL/0OAJeQNnWJZh/FJotZe3aKOYDh8vpLqRU3CoaQwpcBVykAo37T3O+\
2HngYRaOiGYb7AODTpE0RotlMsfmY/+sWGVeALc/N+6z3niYEjJi95q795QDG8daiQRlDPIxfq+\
K1YtYAbPdIm7FE8xjFZjuncl4yxLb82Ju0bDMUjNLw5kADCOOc5lG2gdN4GKdnFTu00X7ZjpI1nxDN\
MYrNU8zzGCMhNp56x+sfr6NgdAuOr70NYYz1ztG6Y4jH9i763Yw3xMb1X5o0bIms8B4berGtYDnqf/\
UrgHFMu7091w8FI7DAwc7uDYCRXtQl+\
foyHkZ0ze0A1g4mAIO0GUo0Uyg2swonXpsGA2xdP4oeq0xyIZrOQRciSzUADKXXPlPZDngYB2ukFUo\
OA2yfSJvuRFOBYnOb1uRWbzkAQ3bW0sUeeSgYbzLuriovAjCcruvmGRjgYfCsMNTnsQOAl+\
CbrhSbNysUre9BbPU2KoE5KSgY+\
tkh8tYQRsqCO9NmmngYwo4FLyYhNnVbsqYh0VxHsXmpcVJtN8QW9LXj4sgACoaDjuMdHwgj95K9orY\
VhWO23yZX9kFs/6lJw/bMadWpAg16sSl0flySdR/AqF+uWx1/\
HgWj42qwtOULeDayOHNLYCoehtvhhQmSn7f/r+\
ZHepvmXdZa0kcBjIH5ldxx3SgYo853ArhN4S4fw0OTJfvxMGK4PiyedwcA/k7a/\
EE0XSg2LdiOfRy3BDDWCayYvrygGQFjmunG5sQ7AEbuzhQWe308jBhxkff7VwDAy/\
9d07fgdMQSdjCIW1TXF1gMoGBkbzT84QFhuHJc2ztvFh7G3s/8m55CwG/wTQ+KzcOToTKbIIycYK+\
COwrSiG101ej46u0Qxvum5h8Rrnhsia3WlsIQcC6++eGvJg3bCFyj1ZRebJt69r9/2AdgLNET7ze/\
ioLhe3AW1+EyAGNoYLJw+S08DNtsb9f35wHgZaRNP6I5QrFZ1KEs+LQFwOgUkyw8WYeCIbIs+\
6KTC4BhMWfznRwTPIx03iKtSycB4FbS5nKiuYdiU1U379omQQBDWm5m3Sx3FIzQudGKTjcAjBeJU0k\
+2/EwmGRZ0t7tBIDl8c0aik3LS1et6iEMUZkGj0o5aQSMja+\
TPoRDGKr6uZdGH4tgm6cXRFeug4AX4Jv6FJtCp+\
20PouD5vla0TUSHigY3uMfSpdCGMrftLJPn8JjW1nPdk0SAiZv+\
pA3adiE1tpttnehF9ugBPci0x6ATWklU/tUNvLM4Z6jGaHFAMbEbMPq+\
7l4GGwtV5ekHAbYFEibzURznGJTWOHRRcYwAOPdSpvXg4UoGB81D2TUhwAYifmz39htpXAyQ0/\
D0YNBHRyvkjZ7iWY8xaYk+0vpFTwAW3rc+tqCBhQMie0vzmy4DGB0+\
juKhOjhYYx8FZYv1YM3j5I2JeltOn83qH4PsTEPBkr8dEfBCIlIm74MYYhzjv6aHYCHkfF0OHY3xMZ\
E2gwlmhIUm+aJsW8fQGzbhzVP2hSjYHz1v79+qBhOmJ6/Wk8pCo/thXlyHyfEZkra/\
EY0hf9q0rDpXjklXhZCL7bPcv6Nw1oARjgjm6pvCQqGiuXY6Ye5AEbZOPPDtcV4GPtk7/L++\
QgAnyNtriWaFRSbm14cSZOTATDsHuVd70tFwYiX3hOpehXAsD5lH7plIx5G1fyqNPcLALD9v2v2dj1\
fwsgOsA033ahsWdeCgLFG2ucjYzSAIX/\
m4vowXQqLtFYsFbmiBbBNkjbXEk0Fis3wRynBXyG2oO1Cx37dR8E42BpsmQ1hBG4SOyK7CQ+\
j3TxhvjvEZolv3qDYHItMGQ+C2AR+Rqp4/EHBMLm3+Eo5hMHM+fJCwjU8tku7JSZ+\
esBJ2KTNneRNGjYPBniKhF5szw+Lub1YCrAFenGktL1EwTB8N7lhzi0AY7PP+cbbT/\
EwJk85XM3qBNh8SZvGRFOLYtPBqPLAl10Am06643m7SBSMGKWlsrn3AQyGT1dSdZXwMC64LW3oSgLY\
dpE2LxJNForN4s9B3F7rAIytFVk7vK+jYLBVeZVXhwAYt7baRAZso/\
DLxqLI2TkLAF5P2mQnmtkUmyZdIqm/\
ITZNqx6z5l8oGOOL7VhKIQzN4cDgI8x4GEdvxOmehdh2kTYniKY8xeb1ZPeaDghjubr4/\
kPqKxHbqGpaqe0ShLFskbrwoxw8tnli6y7vhIBVSJvVRFP8ryYN23W7vM9H79OLbeKgSbvkb0bwezl\
Tc03gHQpGYZ6s/b5UAOPyIXsz7ucU7tR2nRds9X77/2oWE81Eis385+e0c/\
wBNo3KGGFnHxSM8ztiDyrVAhhH2RPmHJPAw0iLnH/OOANg20LajCSaxyg2t1mEJBX+stRw35TIUpc/\
txUB4/CXpQ9DfAGM+\
U8LSty2Ujgbqd6WbKQAAPORNu2JJhfFpthBjb03IIzvAawbrq1diYChnnueuY62G5k1+\
OlQnDC2maPuIc1sD2B0kjY1iKYGxaaPdGn6CgjjTT2r2fpTKBiVCix9jhBGQ6igbVIJHlvrchWjZxB\
wE2nzGXmThq32JfxHL7atg36L2BsBtnaDeRWrv6Bg6A/oZb68DGCs1tKJsK/\
Hw9gjNRQv9A5ge0batCWachSb/\
nzPfnreBNg6YwNmTdqhYHBaaPGVdgMYV2dZnSsTxMO4mLJ0XeU9gK0X30ym2HQ/\
4ndIXALA2HWNqfu6JwrGnSd8O9XcAYxMfbb9pjp4GFlh0lbnBgHgvaTNu/\
Q2N108I8YNYVxh6eg09UTBkFvsdagDwsjq4K4dFsbDMJ5/\
RL8EAs4kbcoTzXiKTf6yzwF3IIzXumajs5+gYMgsdSnSov2yvZQoVn2Jx/\
bLVop1fAV4nz34pvhfTRq234q9OSu66cV2W6dq65F7ABvbWEWCygQKxhb2eQn6sQDG3RHetNxmPIyB\
nO5b3a0AGytpU5fe5qkjgpvWPwIwqvRzZnHuQsHIUM2Q2z0FYPD0qSms5qZwMmPd06X6bwHgStLmba\
LJTbF5kSfs59hSgC1dwijOoh8FI0ZxHf93OwCjW4ybRWULHkatwqphyx6ALZe0GUs0eyg2jcviE5ZC\
bGK7PkXNK0DBuGj5VeorhOG5rUfZ8bYQtulsF7ymAWJbhm/\
6UWzmdVXsTIDYvqkedK2YRsGwnvyjswjC2C44pn+tDY9NPr0juwZi+4Fv6v/\
VpGETuzQT5TdJL7Y5h5ivbDsPsD0QWZ/Jx7Ye8cJ7ls5633kWwPB1mtfz7T0eRmGyZHRu8/b/\
1XQgmiEUm6YSD51l/gAY1y8l82ZooWD0m8YlTfLoarhv6ODsqWPBw5jXZ8af+wwAjiFtDhBNFYrNn/\
O39Uq9AzCs6xNNZ5u3IWC8qjI/E28JYLR83r+JRRsP4/FI0ucyXgDYmbRZT2/\
zxFOVaEmIjXll2YJnP1AwIgzZ9k/Qdvl49xwrX4+\
HUWTzWPwzxDaHtHmGaG6h2LxkHhKaDGG054fFR6jKILaR3cRQ+FARvADNo7f6WT+\
VicgJT09DwOTNw+RNGrYdUwJHm7l/\
0YmN7cnupWGNAMaZAsmjzfwoGFrcroIhwQDGosfPw5b04mGM7u3fn3IEAD5H2txGNAUpNh9Zrt9xlk\
dDw11UjmHPMwUUjEeJ54zurAQwFmqF5Jz9g3+QOd/258tlXwNssqTNUqIpQLG5u+x5S/\
hcAGNCQk4ppx4F402roMp6EwAj3bcnsW4THsbZD8cbht4AwHMlsc1Mis3DT+\
25lSE2H69d9yMUZRAwfF+bzWV9AAacsW1uVd+\
Lpdhmoo2E1AzE5oVv7qbY1Jf8HewBscno2ZRaeKFg5NcIn6iGMMadNzrmjeGxlae8eeIMscmSNu+\
TN2nYfA8o7VKQphfbHJm94jZvATa1L13ePuIoGIMxW6dU/QCMXO0dzzd8w8PYumj+\
kPs2gE2JtDlENG9TbM72XtZyqx3ACJfqYHMURsE4fkhY230TgHF9UWyCyygeRlzR58JwSQA4mLTpQT\
SvUWxyVJia6DEAbDWfc14FbmtHwDBrvX/x7VYA49fCgHMRWhSOr7oYDXOfA2y3/2WzQo9nLhjE/L8/\
W1k7oWDIHf6kwkeDcYFB5YUFHsZG/8LlGyFgPnxzH8WmUNXiy/\
oQ27Mfk1Va91EwgrsGWa5DGGf4pV8dZtTENle6W+\
uZQWwVpM0QohnxV5OGLfOZ3ppwTXqxFYGfyEIJACNb64gqgwoKxhuZKQmmEwBG6LrlHwx+\
4GFMbLU4ve319v/VbCCaIRSbLx4/3xm5EcDYPMkYH8+\
JgvGkafsxbXMAw8GrquTEAB7G0j9c6XK9ALA6abOcaNpRbPJE6TfPGzHUcM8IV05PrkTBWB39TP6QG\
oDxreNEzHpNCs+/7jHuc3oCsD0gba4hmoMUm65ycjVbIIwCx/\
LYPZkoGGp7pHqWQRjFge8DLYYEsc2b6ncTxSFgCs1Sis3twUVmWyCMP15qqzcPoWA8lNyk4g1hpPZ4\
i/cvwGM7+O1Z0QoIeIq0+YhopvzVpGFrWGmz6KMpvdiCBpJ3uzEDbN80kxQdN6FgPEs/\
sv29C4ARG2Ewe9ckhRn628o4VF4BbF9Im3VEM5pic5md29yrxgCb7XpL2YSp+\
YhmUe1ol9RRACNzpnzjjQ94GNX1h2Y/GALY/Embj4jmLYrNBakpMssLAAzJyd/\
cK7XfIWBcXCp88osygMF2t0fwvToeRt7cbwc8PxjCPwrYJjvF5v4FksvWQRgq4V/dnT+\
iYBS6awrLQRgpmS7S0cF4GHr8Dpw7IGAlfDOTYrP2SXHjtBh4n3rRvSsPS8sitlEh54lxEwjj4Gvt5\
crCeGwMLnn9ShCw7n9p0rDNivabXO9KL7bzy4f1EnvmgP2kR+tfFxkhd/\
ni6gSqDwMYrEuP2xgw6GI/TPp2/iSJWoAt6d8157GvsdKaBDD0np04v6ADBWMxg+\
olkTMAhqpnhc54Ix5Gdivf8wd2APAWfHMjxab1uiCrxpcAxsWvE3461SgYinah44elAAx/\
DpHoY2p4GP3rBm+9zgaAE/\
5ds4Ivc8QUwpjHHFyZs0QWAcPvVcvAOghDa3esnrkgHoYJZ9qALgTMSdr0J5oaFJtSUQGfWiA2B5Hi\
o/etUTCMsnboyUEYTferD+jJ4LHdbbr4XRhiO4JvNv/VpGGTGbvUERNKL7YubmaOZTUABks/X+SX/\
SgYon+S1MoOABiMzh3qG9jwMLRDO3QVKwFgdtKmGNFkothccEloQwMTPN322lcpqRQFg7GMPU06FcD\
YNSmz0O0lHsb90W6/Nl+A7T1pk4lo7qHYvLmYr395McCW554RvNSwAzWPsfe0wDsh8FF07rIb/\
FGlcIIk68F3zzSArZW0KUVv8/7i3j/mEEb/Wm9G4Z0oGGeOb9TVhjCS3Gel5OQvwTbHljz3PQAB9+\
GbKRSb2mHWLXkQGyPzthClJBSMvO5xCTYIQ3xrpYPSOjy20jcsDvMgNvJmPnmThs3U/\
N7jr1fpxVZgYzh/1Q0AQ0hV5N1sZxSMC1Nebi/\
NAIzBjJPlS7jwMF4o6K9d9hwAXkTavEg0P1NslmodmOfIBe+43OO8d8N1FAyREl/\
hbQ8BjJlJ2aH55XgYXHoOy9kvAGz2pE1RojlFsRm5+LW/wGUA45CHuHBzKwpGphP/\
js284KOMH7TIOLEBDyN3YhurdYbh/2reJJq/\
KTZdm8zu2UMYl6pemlWeQcHYrmSrvYN2fPVNy8ffAA8jK5LNzhECjiVt6hPNCorNRtHZJpPHwfu89U\
sxsuctCkb/6dGw7kLQZPd4kj+\
gjcd2XHJ3ViQEfJO0OUA02f5q0rAFPXlxXfsBvdh6eqttkoMBNkOVMPE/\
PigYZj7Cdr0mAMa0HIvo0EI8jI7q/D8SVQCbLmnTimhOUmw+\
Fh3P3ZIBYNzlULw5HISCEWlnK3nyLYAxb9BLurEID+OinOQu9iVghBbgm1wUm+\
3L5tZExwIYD23d6pIPv0fAcC4J4LzOBl52h+qbno/rKEytylHsuhMNAL/\
5d025qShZXwhjge3hWxllKBhaN35/MIMw/MwSsssGFmOb+\
WevxrrRrt2RNjcRzbMUmx81Bw0dIYyP9hNuDexyiG2UPcVv/\
wTC4JiRuOFujMd2Tr72xgAE3EvazCFv0rDdWdF9+motvdjkHjKuV6mEa5Aw1bd2hCOxleo2z9eHM/\
RvD58pXEphl4+jWvqYLQB8krRpSW/zaj6fQvQjgM2ER1S5zB4FY9mp9p6qLwBG98H5kk/v4mGE/\
HoQc2cFGKGOpE1RotlLscmiN3/VnQCAbVnow7c3J1EwxqInSoenweFn2DHDLWpr8TCKy/\
Li1MIAttn/\
rum6M1LaC8IoVkmIqxlHwYi6slPIBsKovn0y0ikEDyPzjPveMxDwbXyzm2JTf6fJk20QWyp/\
UB2jJgrGwI+I8iQII6vaKrpuHx5bReGMZQvEdpG0+YVoZvzVpGFrj/\
hj86ubXmzNTQq62ToARrFW9760S8jdyA83fbZugdfErgcrHBfDw2jTmazZWg4AF/\
y7ZmbJDX0LBQDjHIu+911DFIxGw9JQaUY9DferDxeZN2TgYXRrjKZ+fg0A+\
5E2m4lmAsWmmL2tRrEzwBYdnGQtFvMBtcZj3+FqlR8Axs6YvvGw1XgYz40+\
LKnwA9ji8M1dFJsbbvV5nILYTklJeq2Wk0PAkHwXyegCYcRavPt+\
XAwPQ2Pd8pEEiM0X34yn2HQUWTUqAbEpnJVi8vVAweg4WBjjBWGornjyeNoBj+21kOuJKohNGd/c+\
FeTho1laOHWHVP0YvNYujnm4FMA43ayoqDRDRSMzkUv5kepAxgPAns3iq/Ew/\
BVKC3dJgUAp5I2u4nmXYpNi73dQjv7AAyXaWPvJ6tRMNi09uikCwIYx5s/a8+/\
hofRt01o7oINcGVT0iYn0XSh2LynPd1zzxxgs5EuH07h70TAeCy08JzjAICRHV4vXLYKD2O+\
xq1B9eMAm/2/a3KFiZ8MhdjSKsW9vx1EwfihF3zRk/YrJPmJ8035ImxzYCR5OgNiS8U3eyk20/\
QfdTJDbH9YItar30LBeLfGoHE3hHGe2f0w4wk8NieVVYMPIDYWVmwz6q8mDRucP3KTZ5xObAtUvKJ1\
5gIYzU+LjnfnomD4djAb9a6FF6DtBbtqFCkcX9W6uAY+BoDbSJt+\
RDOMYvNqpKBpnTacIqHJd2dMCAUj3v+\
nnaoKgKHlyeXrfhEP4013Z2HdFAA8QNq8SjRVKTYPeYvwxG0F2Ga1zr+4/DAKRnKOhUPc+\
13wnq51df1KeBj2ZqrB944AbJz4piLF5pHRGI3zEFvkLbegnxdRMBpLG5oDIIwLDmaXPA/\
hYaQ89wm+D7FlkTabiaYFxeZ41OXSdAhDV57D3OQDCoZh6JqgVRDGUIf+g85APLZixjMBvcvB+\
zQgbe4gmiN/NWnY9hVv42BYSS+2rDOrW9O+MYARKiNRu+8JCsbLFK9pXSUA47zF0i22a/EwpFK/\
bM4sAdhUSZv1RPMsxWZ9TW5F7A6AbRnfuqWmrCgYVZoJawb1AQyRY2Gp0+\
fwMJQt510w59bUcBclbb6gt6moNZB9UAVgy7IUsFd6iILRx2RceOctgDGkz8wypYCHYViabCxwEGBL\
/3dNy23vz5ZBGByxQwYmL1Aw3qr210RAGMkOvvFWzHgYusraFbEQMOe/\
a2ppruy5CLEtWCEkVMItj9pLEoxP4oYwNjy8XBV7Ho/NwCar7hnENp+\
02UPepGGLELYeNNOiF9uiN79H3j4EMBQcOwOe1KJg5Lp9bilZCWBIrGq69FMND0PAZ1Hx/nqG/\
9V8QjRlKDa/BRv1HDIH2Ibyksw/j3AimkZJmfNLbAGMz2v5PfKD8TCcXuu+\
nZQA2L6RNo3pbcZeehCzSBRgCxl2f/idqwt1nU3tyPPiagBDquLgwwk5PIzZ9qGVR00BtpP/\
rul6UWTuZQjD5UbCvrl/UDC6hn4dj4EwAkPUTwXcFMA2b86PW/wKAnbCNyMoNl+\
Uhj7NgDAMGdaxBWijYEh7VC8eLgDNhdw1OcsS8dhmDybsC4WA9f9Lk4btQZBvfd5eerFNOgjaeOQBG\
Eaui4fZ2lEwfHiepqitADDERZVneWvjYYjMzrJkKgaAd5E2TxFNaYrNmiIeE3VbgI1vfuuVvPcoGBn\
hd3Zl+QMY969XlMWexMOQWvcq5+5GgE0E3yyg2Czgiowv5ATY4r8u5/KzR8F4t1bw8/\
0SAEN1zbrnn2TwMC7cGNUpNwDYzuObGyk2Ne7zrWqHMMq9N7KJyssjYFwvmdd6GcIw42Bb+\
FYfD0N1oJP/OgRcRtpMIZoWFJsBnl9NwiG2KxO33VNPoGAc4jOefAVh7LUTPBp2A4/tne5LCU+\
ILQXfNPurScP2cSAul8ONXmzhy98cVi0EMFQkPx/f0I+CId43JlwrBGAIdEpkjurhYRRHX+\
XvuwgAy5I2Fehtqhybf1vMDWC7H/\
39cXENCoYap4xvQTyAYZlz2iX5OB7GZPYzKx8TgO0hvmlFsfmr2z9EbdIA/FFIB384K1Ewih+\
6WiXn7oKTNzx/35emMDdy/\
lc1Zm2AbRlp8yHRHKDYdBUMft8LsRVeFfG8bIWCMRnIOp4KYUTVPj6uP8qPbTYkCXxLp11OIG1OEc0\
wis2hi7/8j0BsQz/WB0neRME4J/Z1/R0II5FFfcGLu3hsvG2vN9pDbCP/\
pUnDxml4J9YmjF5sBiksvz0fAGy/nHfZ7/qJguFuyLbQXgDAmAorKDhojIcx329s8V1vhv/\
V9CSakxSbEyLT8pb2AAbLNR0TlmIUDFVjuzm99wAMMWN2nxYnPIx82VsxfLSFO0ibG4nmCorNX6eHB\
bP6ALbRZX0jqcs/ImBIC1474gWXPsmMWDntIomHofxBjF11A8A2gG/\
eothcsKpEaARim6qyzfKJRsE4JXit8RaEobB59dyBBDyMtMxV525DbP+w+fJn1xUzCOPaJ/+\
NvG0oGP5Wnk3nIYyPLz759D2kMOu/jl/DAAK+Sto8Rd6kYVufX+\
1Reo1ebDyv4keL8wG2e7rWoqYMGxAvfDf3qx43N4CxUXRqV5UpHoaRLlvFq30A203SZh7RXEuxmbki\
3nmPP8BmESKWff0mCsauBAvvNTXw+Er/w/RGWzyMuQrjudyhAJsxaXMP0eyn2NwmNjJ/\
4i3AxnKBd9e5YBSMLUyxmzTgol5nV+135RLHwzCXvzHnkCLAxv7vmkKy/\
hP3IIywfJMTz56iYBQLWx/Lo82NnOg+d1UTD4Nxo/HvKQg4FN+\
8SrFZycscqQhh6Hcs3qDCpIDaS9KeVeMMYVS/0k7qeobHNi2wV3s7BGyEb774q0nDZrvooyl/\
Ab3Ymq6EqDHkwXvPwlaObZqPgvGSaVZE9VwAQ6VF9uay/XgYsat73TdvAtjukTbriOZaik0vY+\
4iwQsARqhf2diFRBSMRSx3/LO7AYzSvjTFN/\
vwMIIdXnofidP8X83FRLOEYjP97nEW2ScAG8PMlw9fPqNg1HV6CPyIAjBa9jyrjVuOhxHx09b/\
pATAxoJvtlJs9ncsW1MAsSmI2kT5D6NgRFiVNxVDGI4Jg1O2nxdim4lXL7mzcAAYcqTNM0TTlWLTPP\
2JHR/E1vlE3JV/KQpGzrFcPkMIw3t2lnHRazy25wceKKpBbB/+\
S5OG7QK8w6aOXmyrXG0vcEgCGImlPWsWCaJghLTNSjzDBGDcHL7Z5GaDh+Fy3e+JwT0A+\
CJpM4xoZlBsbjya+zjxFoCRMXuHes9ZFIzMZXfKtk0DGEXGmfYX9+BhNO4ONl91BQB+iG+\
WUG36RVzVvA2wtdg5WQ2ZfELAOGYvzh0bDGAYfVrqMS2Ch5FqMfwidCnAVkva9KC3ybhOUvsRxCYUk\
qa5i0sBAUNDk3PmKYQhk2p3eUMsHsbbnWnnF0Bs5E1NoqlAsSnkHlL5WxQ0bRtHgnJXoWAYmXTmyUM\
YKRJNHi7v8Nhu6SRYKUBsNv+\
lScNW8ol36fMeerG16zRaJd8BMEwLfq1tkUTB8P0ys8V8RlnDPf3kb4bCI3gYK5vrL4nPY/\
hfzXNEM5tis1xY4EHvU4Bt9MGsqNRTKBjLGN0YOQXAR2muKBU+\
uwMPY5Fs4W6zTIDtC2lTlGg2UGx6q3+TCeQBMO7/\
ub371RMUjNxvtw2FvQEMEzGtzK1CeBghmwMPro4HgHPwzV0Um3oMe4yWQBgfglotb0igYGi9Pfq9Gs\
JQPf7uK586HsbTyADxpxDwO3xzO8Xmgu43qe8htrLySHnW7SgYixomU7ggDD/\
ZUy2MfXhsaacevxKF2P5Tk4ZtYKvczLI/9GL7FRrAED0yW8Pd3GTOtgAVFIx3Qrst1/\
wGMPweNxv9cMPDGDQ+\
xfIrG4xQM9JmJ9H0p9j8Y7bPOTIPwOhafYqh7TjyV0j6h8CUInhZo1jvkfxteBjnfA717GgBgD+\
RNrOI5g6KTeGgvO4jbABbY8QWo6eK3QgYe2pv9cY6AxhXGr76uS/Bw3hdy/\
mGLQhgq8c3r1JshuXsLRWD2NrvhZfdU0PBqHrJkvUKwuhP58r9/pkP2/\
zQw9BRCbFRaH6l2LzMaDZdDrGpbvjCt9gaBaPcNa5zGDbfqj5Q9x7GYxvgmnOSD2Kj0Gz4q0nDxpuj\
0+XN+5tObKURC64Y3wajieHj6H1eLRSMrxMJWcKjAIaD+dpecU8KcyOZ4sx1WwDgWaRN5sn/\
33Si2BxdE9rdNghgaMXxtcU5omBczLXs59sOPsq37RU3uTdRmO1R9N2poRQAXkvajKe3uUm8UWrzjI\
WGu6/HaZM5GSgY4RUlH0cPAhincuZ/\
8xKg8AB7bmOLYheAzQHfDKDYlO5hfH0TDuKIqCt1A16oAZe0zczhLRxwDhs0nOon8YNYMcDUlhUO4v\
B/13yVddjhBQRcK7SI2XcXCvCFPeUKTbDJajzaU3YJD/jw2hWtsvAPzWvSZgzRHDf6v00aNg2eA+\
VvV9KL7ULFRRWjUgDj+wT7ywsGKBjjwXF/eL4BGAt19D8a+uFhFKbfY8/\
LAiN0CN9cTLGZeENcSvoFgJH1s+FazyEUDKk6bVdLW/\
CyyqE96zNUKaxBwvXTLIRJS8M9mbS5kmgqUGx623Xt32IOYLzSu6nTLNKDgNGV+\
mrzhj0AxtKCkiILPjyMH/VJK9l/AsBNpM2PRFOQYpPDZJA/\
CmILO5HV5RmFghFqz612n7ZeiMzkYlZmLWxz2dra8MljAEYEvplFsemyw7S+\
DmJ772V6l8kRBWP5o5Dgd7DJu66iOFwbjy3jNOON1RAbhabAX00aNkdP7xsym+\
jF1s2qLJOWBrA1vvvaOGmGPJlxTlWctw/A+\
H7qrJ1LEB7GpMOS9QI3wQh9Q9qMIJqDFJuPV9ybvUsQwFjRq6vVug8F4+yMQGXDKfCyaz35ao+\
txsNYeDfIN7oRAF6Fb66n2Lzw/KHU7S0A24SliH/\
QNRQMv5UuDA568AK0VoyPADcexiyGCK6SzwAb1z6ypj/R7KfYXPli/\
ysPiC23XuV5dToKxoj0tb2X4IBT+yY3tYwLD+\
PeaHDPIMR2l7Q5SjRVKTZPlx3geguxib5et2FHIApG2tfFWR9pF8oX215S+\
8GLbdbb8a9Qh9hWkDZvEM1TfzVp2OI7YkKDzejFNlH35ZPmGYDt0J7bgjvsUDAYDVN/\
CncBGAFR9y8GR+\
BhHPh1kS8wA4xQB9ImK9EModicn9qhP7cLwKjnF1oXaIaCUet8jsfvMnjZkw8TSk8q4GHcnWudtlUZ\
AP5O2qwjmqcpNnVdlX8MKAJs4ck2WqbLexEwet/PZ/JXh4/ylo2IyeKkMGm4sfKneSfAdo+\
02U80Ayk2eVLqRi0htoXOsiNtj1Aw+ot/F3vRrrPlvy8RWoyHcWN/yYmPEBs/\
vnmFYvPy01kyzRDbtL43j2U8CsbBEaXkftrk5rdtvO9S8dhm2e6y0IHYxkmb1kQz/\
68mDVuFVrb9ezd6sVXl17NJuQNsJ7Wb+iKPomA0n/\
y5cU07gJH1pinyQhQexkPtn6FDN8AI9SFtttDbVPrhKWqtC2BIvFmTPboHBaNth0yKOZwMI9IYlVUh\
jYex41L/2fivALA0abOd3mZfdfRgTyOAYV3FdjT9NgqGQZO2lJcygPHkqZgE11w8jAN7anr+\
CALAJ0mbhkTzMcWmqGtrgDbEtv5a/6O7b1AwLhcoWlnQJiKX8rLMLMfDyH5WptYEsW0gbSbR2/y9/\
KpYO8R2vUAzQTYHBWO3hpP9IGxOafZOWuzEY3skHaVvCLFdwzdnaf3fJg3bUAZcpZVebN6NZ3yt0+\
DNo0m+Jx/6o2BcSHF6s7cRwGiKMXa/eJHCpOG760xM9wLAt0ibMfQ2m/\
yalNePAxgxSYvTtZAwrN8MvnGBa8N2O/q7bF+Bh6FRvtM1/QAAHEratCGanRSbNe/\
ZuHpZAIxYNQutFxv6EDDi3o5t3CMBZ3tsb1q0hQUPI4nj3hyzGgA4Cd88R7FZ2T6+\
9gWEUa5ZelKvHwVjef8RHXXaRGQPKa9yWTwMk0RtD1kI+Bm+\
aUGxmT8dNfmetuSeT6FIeTkKxuJvO1l+wCYjT6PWIyY8NoXO45O7ITY2fJPrryYNm+\
C8TtmoZHqx9XoFnazTADBKF2qKvj2DgnGjbnto6CsAI2bik0V0Eh4GZ6DCh7YUMEKfkDYziWYsxebH\
1d90hufs0XDvK5TaGGKKgvFJ65tYyVfwsiesS1YLiOBh7FUOjOf1AtgGSJu99DbvG9QqFTwBMB6NvZ\
wRf42CcU41cI7AEgDj26qzTNvm4GHMHNRyTh7RB39FSJvnieZnis2OhIZDpRBbNuOFk7f/\
oGBozu1yFoUD7qUH813HNRSOrxb+qeWD2HLwzVqKTbEi4dyPtGllPbEjQq0oGLZNB31+085Gjhya+\
7OAB9vk3hVzeB/EFoJvcv3VpGHb6v57/kABvdgSAxr0IyQBtkKv/YuaL6FgqF1/o/\
jkOYARVZHqdDoFDyMsUCVp93U435K0uYVonqXYFCtY0VY6H2BrelXe3GyOgsGrJbR6C6s+\
3EXp9l25BA/\
jnfLooztRANtb0uZConmKYjPFqcVp6j7Atok3kkHKqR8BY8GiLuliTgAjKF5FiW9GGdtsSTbtlu4Ab\
yKah6zJTTTPUGzaG3OETC8DA87s5N6JBm5FxGfXefiugQkOuI+\
ZNlqTGngY9WvePcmFgP9h89bkrks2EMYFxeTtWoMoGB13pp9Nw6ZkQU0ywxE8NjeOgG29EHDMf2nSs\
B1r5h7RfEUvttp9jVERXACbW2BBWlUqCoZTgkrmnAoA40szR5ljJh6GZZRNctM1eKaCtHmMaA5RbOb\
sqGFJWwKwXbFda29yAAVDcZ9o5TwxMCZZhByWRCzEw/huqybgnQmw3SdtKhFNdorNopmAjaerwH+\
453A5dwvXAGqp8I7HO1UZAIyM+8vOpk/\
gYfAtdUqUvAUAXyZtXiKaNyk2BeXT9TIgjIPJCRLPJFAwjto8OjEAH+9UX8VR5qKLh8GgmXy5DwI+\
QNo8Rm/z49C7sgEIo+GX8kG5OYoIGGPT/l/mwNkeSS7txzuF8NjOVcyLcKRdZ8M30/\
5q0rBdU5VpSOylF5u78qxWs6sABq9HE+ONOygYufcuPzUqBTAmsmad0M/BwzgY5b+\
4bnyWhvsC0mYhvc3nw63Tx58AGAkGNSX89igY+\
ZUL8xZqgHHOI3HOZC03HobgwkWT1yUA4BTSZgHR5KXYtD+kGL0+GZ6mn915f/\
ZDFIyou7FcV37u1HCPz2NOGP+Jh2F9nn1lxj3wJhbgmwkUm+\
siGDleQxjRYh1yAaooGKImg7tqIYyF4UyPXpjgYRSatMxJgoCj/l0z0Ftf+BvEZh1x16KbHwUjkEn+\
MyuEcVdLc3nEW278L3DzoNZRiM2KtHmaaD76q0nDVnNd+8HoH3qx3fD+\
UGnSBWA0Ws7ycnmIghGgxbM7qxDAYA+qyVyRT2FZBKUHyp+SAOB60mYQ0WSh2Hxm+/\
pLkTKAMVdUpn7LURSMn9p2TIcswJicpdzctp4TD0MoRrfzRgsALETaHCOacyg2L0ypLVWMA9jabVV0\
+p0+I2C8nPegva0fwGg47n2EeRgPo7B0xabYy/BNHCZr1hHNKorNnEnx/\
igIY6uemAKLEQrG4fIhp3sQhlbqm0IOSzwMhbbrDcUQ8GbSphPR1KDYTJTnqfCCMAbufzW3kUHBWJe\
kXTEPwti5v8NmMgyP7XD6h/1DEPB/atKw/WLeH7+\
db4JObOIh748tfgGwqQyvVZeoQsFwkTirNi8PwPhzQfLozyI8jB7R9Ksu8OKUEGnzLtGcodiMGN+\
wlWMYwChcNWclM3LSsFJMbN+4JxiT2W/tBi6y42H4LXoh/E0dAC4mba4hmlkUm2O9jTM6weA/\
xHRfK7ko9QUBQ27bCZEf7QBGfe+V2Bdf8DDyuC5NskcAwG9Jm/JEs45ic7f+\
1EgahPHJ30Brrw0Kxiceo9I4CENx4Lrqals8DB2Vnb+CIeAefFOJYvPDotjgUQiDw+\
yaR64GCkbY9Hdvbggjc7PSUgV1PLbQhb7zT0HAFJq3/2rSsInSppDQi01deC/\
rrEQAY7Xi9tiXb1Awdoi/\
3umdDSci92oPP3qMhyGuz8m1LA8AViJtmhJNX4rNdxZHP9xi26ThzibkbeofiYJhGfThdkscGOdHwv\
fqGrPgYdyosfmiuh1gYyZt7iOaDhSbIe8y2575ARi9Ecf1igZRME5dNlbpqwMwxMzu8qj34mGk+\
v0ueewM3oTgGbLmaaK5jGIzmF1ewQfCkFnjd9TTCwXD+\
VeWtjeEcfaWT5WOCx5Gw697hyIhYEnSpgvRPEOxmdiwP3oMYqvTLC9+uRMFoy1Mfz4/\
hNHSMrBNbGwBtjl9hkciBGKrIW22E83uv5o0bAavoy2mN9GLTSvu8f7YeIAtpKgpb/\
97FAzvqICjwxkARt3G6o2+lRSeYpN9PMQ2adb/\
avoQzVcUm3WbwhxDRQG2BO2fBzqvo2Ckrah4zZwHxuTvuDjno4wUHoaoPnQvyxRgq8Q3GS5Say5S+\
7nX+ijAlqikPj2v9CsCxgOdlRa5TwEMI/5Vmyw78TAqNS88Gt8DT7Pim8YUm2+\
CvCS8IYzTziee25xDwagrymDYD2E8O+fSqOmJh8H0+kK0KwQc8O+\
aw00yQb8htvNJP2XvH0bBsHRwC1wCYYx/cOZoyMZjy4rK5jgLsZ3FNxk7/2+\
Ths179S21Peb0YmN4sb92IBjA2Fut39I5gILBu3yuh3sKgHGhqM5duYbC1Ko1crEylwBgC9KmANGMp\
dj016zvWWMDYLRrnj9oUYCCwfBW4k9IPRiTLoa+gbMZ8DCit25tuL4BAH5O2pxDNB0pNr8+\
fsf2wQ5gO/Anhs0u/hsCxmX1B09N8gGMjZlq5Uvb8DActQ8IDsGzNPqkzSR6m/LfRNbZQGzrV/\
zWFL2OgrEh8s/oJggj6Hfpe7EAPIxVwbaLbSE2BdKmKtE8RbHZY8FWFg1hPHB9Vevoi4KxSs+\
6URjCiApISN1gi8fGWdK2bwoCptCM/atJw5Z+uULkrju92MaYzeOq4wCMwdksG3b8RMEYEUxb+\
ycJwPhxZOzmx3o8jCfVMp03XQDgH6TNcaI5QbGZxXGStdcNYPO+ulleph4F4/\
s2ntmWg2BMvmpsDmGchYfR//76oumdAJsnaXOIaNZRbLIsnfqQIgX+w/DyZ4ez/QZRF6DrBU8+\
TwcwTjH6W3m+xcMoXpl1ZK0FANyDbwZQbPIrJD03hzBUlnG/\
zclHwWD87iwgBWHU7WYyHQ7HwxjXOntpBwS8hrTJRDTrKTYnDNVFZyCMi2bro35EomBw9AuziUEY/\
alOR/YI47E9Dnyz9RIETN6cR96kYXsz6z0DWwS92ES1xZ7c2AtgNAyr8+\
bMUkV8QYMR2vHRlwCM7S8sp8KbKGDzMzM5HAsAV5M2fxBNHYrNqv4ei2vOAIb+\
J12ByK8oGDsmy9vOchhouPNEX3cKnl6PbSYtEM564AcAG5A2d9HbDM0fHnbaAWBo5Y53f3L7joCxLG\
80ckECgJGi5PbL+iWFYza5M1/ncQPAQaRNUaJ5nWLz5W6Fq0YQm/x2tyMc1SgYpuPPnTkhjIey+\
3IzLuBhWEXla6hCbAr45iOKzdXzJF7NdgDvM/jTE2v9VBSMstQEIUkIQ+zPQPvyVi5888/\
1lCSIjbxZTjRF/mrSsE3b/Oo+\
cJ1ebFyvk0rnxgAYzNtXXJ6Yi4LhUH3DXf4CgPF5Vmag1DsKF7Udth17twkAntEja3oQzT6KzdOrHh\
2+dQbA8LiuX1XDgVoq3OJx7b3FKwGMAsE1G87/\
oYBNTqQtLAwAPkHaPEA0H1BsMt87NNtvM8Bm0RqhE7duCAGD9dvNXqkzAMaBB6ImTRV4GNck3ObKTY\
Bt5EjaZCOaVhSbjdXpSpIQhsX3eyMb2lEwLnT2/RzNh7tSxuHmWy/\
jYbAclbqkAwFbkTZjiGYcxeZCuZn66xAGT2GbvOcDFIwf84sWykAYW2t7Q6/E4LGl39hlywgB/\
6cmDZt0DVdVcSG92FQuKbDpy82Ck8BamVbzo2B4KyinN50FMEalZ+162oWH8WnTl6rcaDA4+\
EmbvkRzjGKTaUCxtyQFwJhexqGuqIiCIfT9WyO7LoARmHhXRpoCjKIFlYOV8QAwryi2GUKxGW+\
wecR2LZw0/DBgf9dTFIwxhmt7uU4CGG/qG5krHuFhVBxU+DbTBb7PKNLmL6L5lmIz40XgEV6ILWF+\
2ja1QRQMA4fbt1shjLoN80rfpuJhDB29lLcRYiNvGtLbPHIspJ8ZwkiYXtV4/\
DkKBrOT5QhtcR4L3TmCTw3w2G7UWDWmQ8DJpE02oqnxV5OGbTd8iE09vdjeBTdFjQkAbPaPToZbiaJ\
gjExzcoeGAhiezoJnjPrwMN6k2FhZRoHBcYi0yTHz/5veFJuVC9Q+\
a5YAbH5z584WMEPByP3K9fCAPYAx7SDcbUMBxmLxmiGWdIDNh7SZTzQnKTa3HrzFLSEDsB3bfaUx3H\
gYAWPpmPCdMmcA40fUI02RfDwMsYhp2VPwscmjpE0hovmFYvPZlpgRZQhjvXi0Lu9sJcRnzzzEdOEx\
hHHw6h5N3dt4GHtcvQdmQcDypM2bRHMfxab9Y9l7tyCMLvZfsjrvUDBsRS1zlWnX2ZqTLc+\
w47EZDTruZoOAm0ibdkSz4a8mDVtg3KYzjn30Ygvo8hRtmQOwredYZeYti4KxcD/\
rRY1AAKNrWkO17SseRki1v9fcSHjLNGlTgGh2Umw+E3xrIdACsHl/OLnvUyjyKTYNnSPLwwGMdv/\
zlw0pHF8l3uKTPpoHsIWTNquJ5nuKTfW3iRa37oLPbn86vmnPVxSMq3euXVWzAjA8/EYuv8vCw2gO+\
X3zkTAArEravEY0vSk2b9qqmUjT5ka6nHxeyoOCwaH0Oe0GhGFx5N222/l4GIJ367O+icBl5/\
DNfRSber9KbO5CbDsz5nB+G0TBcJQP2bMGwnhi02Qycm4+tqnJfv/uXIjNCN9s+\
atJw5Y9YeFUOU0vtq6NM4wl58DgWCAhfev0WhQMx7RL3HNOwmM2pk3+5iN4GEecO/\
O7OmbU3flJm65Es59iU+BQ3h62pwDGcErSb4aHKBgqu6dEd98EMPrPZu7/\
NYOHUXGOs3DzKNw1JW2uIZqfKTZz9J/+WcEDYBz982C5bNQIAoa7+eXGACMAoz2+vr0/\
GQ9j0Eqa0Q9eSjHFN99TbP6ubslugzA+\
z7aNVRNHwViy27z7DA2bjvK6iUd4GIuOljWIQMDkTUF6m1apc8bnQRi/JNZsOjxbCQHDP+7qx/\
UQBtf11gFOVjy2CCnzH/m0O7VJm6eIJutfTRq21v0ehkILJ+nE5jM4/\
sPtLLwmtu9Kju8mFAyZO62H604AGC3Hzjg0/qJw71nAwnz/\
fIDNCt9so9hkjyo68oJzs4b7CZ9Nvj9GUTAepd8am3oOFyPm6zF2oXBNbENPmOLLOgD4PL7JRLGZeW\
NJ8Y+T4PtMibE6xaI+ioChX/B4OlwLwEi+WZyrdBEPY+\
5QkekBZgA4lLRpQDRTKDa5fX8OVUFst7p8jsauRcEQYT9o6A5hqMYoO6+\
qpLAswssdHvwQWw5pcxnR3EixyXJOc18RhMHqmRJXxIOC8f3hoZ1qEMYpS8to29Oc2KZI45gMFwTMR\
tocIpphfzVp2JgqIxVPyNKLTXK4boP0GTiPkakrzsYABcP0xBnvFHcAY1XpIt6tf/\
AwRpqbzoedAdhESZu2RFOFYvNEQJ5VyTsAY++q+\
vKURVyI5vn8CPalXwAMgUWzJmqY8DCCqjlf3JYGgK1JmxeI5hKKzX3nrBQ5DoHvc1tIYzTjBBJbJc/\
LncoAxp3lKa43IvAw+q0teJ1+gwGXTtrcQTSzKDazjeLd70NsqesspJ7qomBcb57fY0qDsWS+\
tnktHob7GtE1nBBbIb65hWKz1kh8BzeE4WhYXtW1AgXjU21ktibtl623Mmx0Zh62aR2SnFYCAR/\
BN0X+atKw0c6PbKYXW5RiZeLEQQAjXOVQtNpeFIySUiZpfycA45hXSHQegx72w8xYy73sCYdTwEibz\
+htltge/za4BcDoa1v5/YUqCkYcv3h9MYchOA68s/qCGIVJw5fqbd3ffwaAO0mbiUSzg2Lz+\
BumdJ2vYEPqeNYq25b9QMBYvEyaqXM5gPFSuyJbyg8P47RD3s6n28D3+Zi0KUQ0n1Js/\
urXUEyF2Dr7tI9WWqBg3F7rl6YOYVScOsLv0oiHwX/\
aYyETxNZF2swmmpUUm426l6ufQhgWxUUXu9agYPRx1w9uhjAEDimvuXsSj405f/lBXgjYHN+U/\
KtJw2YRWfZT0oJebA7z0lY3rAfYfA4X1LMcQsHI6VtrdugwgLF6mGmcnxUPo91sXkJaGBgc3qTNfHq\
bBX2z4mKsAbZWbt5PL61RMNZv+m7bJgdgiNQouMXMx8PgjZZ5pvAbYOsibarT2yx8UHD3+\
3swOLYz86heSviJenDhg/REKV4A4/X6h5/TXPEwGJT5HRbIg+9TG998Q7EZvCaWZ+\
ooGHBip7ezpTijYHhsrDsrDmEEunmrunZQmIhs5LsyGgKWxDeDKDb3eG2rqYTYwhf7FBdtQ8HQ0Xol\
sBXC6EyYlr40xYFt6tR4Wy+E2MJIm1uJZv9fTRq2sB/\
tzQFH6cV25S7vCx4egC22MzrwqTMKhur3zEEjawDjY5KDxfF5eBi/PmTG2YaCwRFJ2txMb3PPgu8/\
kk4BbIovt+lxRqJgSJ9UtPM3AjAaLH2cVlO4q/\
rTjeUe91lMNdyXkzZXEs3XFJsHO1sED70Gg8M0Y0W8QsAYAkbCooon8owAxtTsGYnfB/\
AwLEL2ak3wgO9zOp2seYVozmag1mR17d7vD2FITIdd3XMKBWNkteSVeRAGYwkX2/\
4ePIysLdWyoxBwxR+y5h+i2fSIWlOg+\
95OAQjD8xlDr4M5CkbVawUZPQhj1j0dgVRfPLaJrILs5xCwB77J+leThi1/78+itgh6sekynb6/\
MgRsSPXPTQ1HvFAwtofb1+jsg7t8IRJva7jxMM6Z760s+\
DKt7r6RtGlENN0pNjdbBK9xWghgHN7cnTP7MQpG+\
2BT4u1jAMbStsfb5YUo3Kntl3uC4yoAbEfa7CCaghSbAitYPb3H9TTcHXLMLk17/\
0LAcKob4h4eNdFwfyR+\
8wSjMR5GufzdNWnlYHDYkDadiWYJxaaMnXCtE8TWPHdrV280CgaP7cOGH3lgwIXvffRqwzc8DKUym0\
OfITbyJi+9zdkcuqsXQ2xe9qeqfjqiYNSrX5AyoF2AFrjYXPdnLrZZM9HnWguxeeKbW/\
9q0rB1lnImKafQi23L2UXXSysADI7RxB/\
MQSgY9paLG7X3Ahg7rxi7LhHAw6hnPvB1NAgAZiFtOhNNY4rNRhHbIx8fAhg+\
Jz8USvxAwVBe9vGqdTyAoeMtoZQmQWFxHtn9iqYrAGBP0qYK0dSm2Cx0+/M0+h3Axnn34Dzm8HHUw+\
YPcZc7fgIwOt5yRCZr4GHwNmW9u3MfDA5G0qYUvc1yzg9uFhCbp/Vqnx2pKBg2d0qU3kEYmbatncw/\
8TCm4yofdEFs7qRNW6KZRrF5zegxqyDEtmxzEKu5HwrG2b1nFhhBGKZ+\
YYf4TuGxsYa84XsNsYmSNs8Rza1/NWnYOMQk/c4W0Yttle82ucen4WN+PSU5Y86jYDQd/\
DSktxPAqB1L1zm0lAKMtZLvxa8CwKOkzWaiWUOx+bZpedXxVQCGwVxxEy75Bai/\
mh8z7dIeARjTwsJznihROPV/9PvFpW0AsA5pcyHR/\
EOxqadZkxWaATakU1dRaVj2b9TcyBa75pQ3AMbnY4MHUmTxMKS3qu3TfAIA25A22YjmF4rNJO0tYq0\
Qxvk5ZxbE5aNgPDI+8qAcwvBRTY94MkXhV8i5c7seBByLb/pRbPLPDn+\
5FGI7fETK4HIkCsbSkzndJhBGPFPsO7c5eGzj3TZXGiA28qYQeZOGbW24plVPPb3Y6of0mL6fADBy3\
jLqcyWgYHSbuTGaGQIYL6ZCHNNF8TB+\
JAS6nAsEgMmbvfQ23SU67hWPAxhx05vMzV1RMHzqba47dgEYHhuP5uaq42GM3E3cWbHJFM6RI2sGEk\
0vis0kkyWJZ1Ph0xNTipVZv0wgYJRkanjHPgUw5rtZN7cK4GEwVhVtlU0Ag6Pq3zVz1b5YrIcwpCPl\
te9XomAUpDPvvwVhOMTuXmTPuAm/3bP1btdDwCv/XVOiY1GgMMQmK6q2riAZBUOxJSx1N+\
0xvx2vT34IZcc2F10JZW2B2GRIm0rkTRq2Q4NmWmr99GJb8ZY1g88YYBNu/\
dHul4qCoXZ45KeLLoBRfGZ6uEsCD4MlICptXwDAtoS0qUU0Cyk2VXcxtmqYABgclRmJhYUoGJ03Y4+\
az9kB/liH/zK9Z4CHMc/1bnEev7aGOxdps4vepsirPh+\
vEPj406yeBO3NU6jjK5WgfZvvAhjNquL3FjDgYVQxJhelRsAHrpM2XYhmK8VmncfrZCmI7dqH3tx7T\
SgYL5qbV8ZAGK3NK5pnceBhzHmhZlANsSXjm20Um2/P8pq2Qxj5dg62d+6hYKikphjspd2p7dV2Y+\
88PDamXZ1SyyDgB6TN1USz/68mDVukyTGxSzP0YgtJUi5Tgo9p8d43u+d9NgpG/1Pu2+\
e0AYzxmYrPC2XxMGQ2OZonyADAPqTNz0RzgmLzbK5DVO9BgO1l8e2QXlZuRPNT8MZe1YUAhkK+86+\
f+/EwbkmflJpZrU2pqUixef7Q3qgF9gDbh2aDCtVHfxAwGro61xdcBTCszmY9nz+ghG0GvGop/+\
4DBtwYabOFaO6n2HzpfY7tCYQx/MltNKIPBSM/S0bQB8KoTz7MEcaDh2Hd4sy/CAL+gW++\
odi0MOo6+552AfrtTuegMhQM873+\
vea062y3suvbY9iwTd2CLRWiEJsDvin5V5OG7WHhOeahhVN0YnMxaHvqyQJgLL/\
kE61QiIKxPuD3vDwNACNIWd1eWwkP4xOHXQmbPwC8grSpSjRDKDbvjb+\
YHbkbwBC477fszgEUjMSmh5YmUgAGz4/\
GO6VH8TCiEqJ9c9wBYD7SZhLR5KbYvH57xk7ACQwOwfYjd/\
h3zyBgfGEqMftxFsB4VVPbFleLh9EklNFyUA8A/\
tRG1vxKNN9SbOqFZj5mhTAUu3Mva46jYHBpmcpbQxiCJ67MTC/Gw9A0zuoogICV/\
l1zLL04owtiW9RY2bP6LQpG2rcrR/\
bRrrMNpl86sASPjf9gnpEYxEbevEHepGHrW5rRv1WOXmwsIvvPfIJz+a4az2Y/\
VoaCcTtce07nBgDDzTHA32kNHsbavHencj/+UXdPJG3eJZrOFJsHiipfGXoAbHfyz8p+\
LEfB6Lj1Zm+sKoDBErlszfYICssi/D7/6XwgwJZD2nxPNFkpNj8lmh6U2AcGx0z5+\
YwzEbNQp5Wvv1Rj9gEwwh4u5LC+g4dhNmlae0oWYPuGb0ZQbIamOcaPC4P3yaL+SrWJVRnx2T/\
25h7SgzDsGnx/2ojiYXyw4nhxB2Jj/\
ndNxgqbm90Qm4rLc8uqTygYYn8831vRftkMTt7tTWXFNq8Mhb1ZAbH9pyYNG/fpJy+\
ua9ONrSl02RNfgK14cYDHzZfIX7Zw9mO8a+Axm6qReqQqHobe0VFt7VKA7RG++\
Yhi833tztfeFwAMBp6fjXoKPIjmviCr08OGAIazfdq6D6l4GDsOGN2SuAgAc5I2rYimO8Vmg8yWm1K\
G8KENFw0E1vjNRmzIzqAstcnDAIaNqO751efxMDYIrzIPng+weZA2u4imPcXmFyb5ugwIQ+++\
4aFti1Awet4mPFSGMJo8WRVLpPAwkgfvJfdDwNtJm71Es5lic92d5At9EJuz/yvr1T9QMK5Oh6hb0+\
ZGKht8tZXFY1tnK64jAbGRN6+\
RN2nY1Ppbb09Y0ItN9ottpXwigLFdWW26vgm5BglX3dYdSgAG506J4ixNPIwqt9PHr/\
nAybikzSF6m/PmOrv8vA9g9OhfW5SRgYKx6ZepmKk1gCHuyeyR/\
wQP44modd6BFAD4N2lTh2hKU2zqhV56La8BBkf3lkie4FAGxIYcCX7P1bsbwJhV7HrqrT0exsqGplv\
Rw7pgH5G0OUo051BsCpdFD1yD2BbvUU+\
6LIWCETjHRVkQwtBalDjKqIiHwW53orkFYltC2jxNNDdRbK7b03dHEsIoznwREMSojPjsuS7rI20gD\
Ku03NXvC1jwJ9uiRQ99hoDvkTbziGbyX00aNgf90fMmx+\
jFpswndTLAG8CY49tQ9bkTBWNVRZBDjCw8Tb9JcfaTLXgY5aZLil09AGAm0qYK0ayh2FzHpuEQ1Qiw\
DU9sbjsjzYtoKv251HXXA8DwEnnnPdOJh9G47KWCfK4pfJ44WXMV0fSk2DwTdPd43VsA47jlws3pGX\
MQG1JuKfuC95vhBWgdVSVmLTwM//\
1Bqw0UweDwJm0qEM12is2ZyfINzyGMoeXbjtSuQ8GQm5VQwwhhuLsM+\
25ci4dxmaNwSTztpAtpU57e5tDsJKFvtBMkQ/\
pqubwoGA9nZtfZ0S5AW72P3boJjy1mvtg8aQj4PzVp2C7mcrjdPkMvtpTDp+VsvQA2vtWqv8c+\
o2B4Xo0s65AEMKZUTFa80sPDCHxm08NsArDxkDa9ieYExabryl2Ha54CGCL2Ohf2FqFgaN3RG/\
gQDmDckFLc0s2oim2eEDRurf4BAK8mbW4mmrcpNu1jH/\
sfeQCwJY1fDjD7wIjYkJrhfgtmlAAMC3WvoKyFeBhH+\
s48TILPPUvENy0pNktXp78sgtgGnRt2ftiGgrGiIPD0t1x4TSxfc66dOh7GLGmpQ1EQG6sLWVOaaHp\
QbFYaFZR9h9gmhG8KPhFDwThRuHXKnrYsglG1WMorZmzTr0Bx/\
0qIbQzfrP6rScNWxi9uwpRKL7Yow4+cw/IAxpKc2oKfP5DrhRgUrZcHb8k945LUmpYdeBift7/y1/\
eE98iRNjmJZibFZmDMU397ni1A0qmRPct28iGaQd91qiqT4Gn6U0dPu8rgYUz0nn245DUAnE/\
aDCGaKhSbpZX7Zq/mBYOD4dCR5go5ZsSGXMsxEHJ4GYBx8JbIrdw+\
RWxzvpHN3KsJAHCfNVlzHdG0o9is/qYcnkXDtlCk9fVeFAwj/\
ctmTRCG8Vm19oAteBinmFzLwiC2IdKmMb3NNR4H02UgjAUTc67krELByBHzWOwIYdQPmQv2WeCxrX0\
lYDQCAVNotvzVpGEb9FVX2VdML7aaS952a04AGAk1myX7plEw4lOVS0KFAYw3D9h12ndROJlxS49Rb\
h4AHEfavEZv01PJdy1jJ4AR/rUiLGYCBUMj9PZvjTsAxir2pltxe/AwgqSTvdYrAsBx+\
OZ6ik05ObkpFWZ43OI7r31LHAtiQwbl3R7dwAVgKAuPcMjex8P4toxx9tWTANtcfFOFYvPLRLjrZYg\
t7LrF8Rv2KBhqY7t2PIYwfjtISp7Xx8Pg41iyOgBiu0na1CKarEeoNUtY97/\
4AWHMNvFU9duMgvH52KCkM23WP19eNc8XJmxz8gLTJ1kImJW0+YVo1vP+3yYN2+KPpvwFr+\
nFtn3KJOHR5yl194SQCuca1o2IL8iRL25V32J4NnInq02LGR6GUZvou+\
UeAHAcadOdaBZSbLJ1bo6wHwTYLki/\
2jV2ayGiyXjKV0HhKYCR5LQyaUUIHkZasOJSJgOALRnfvEaxWSJUxplyEMB4ICBS6bSADbEh9/\
XqZibOGGu4C9bGZev442FclJk3p3DcTMP9Cr65jGLz54+agLMQW+\
2WylQzLxSM2bVShzIhjJwTLSvP7sTDWMj2qNQLYntF2mQgmncoNrfG2vHJQxjci1cel9+\
JgmGawi3pSlvwp37POTFvPDazucvlf0HAXKTNvUSz/\
q8mDdsWHficX3qxXXrul3G5GmDL39yWk8KNgvF+V9MZ/YUARpbMcPKr/XgYxQqxDdzHAbZ/2JS/\
4iSuPAWwvX4Q6iFlx49olr4s7jn2BsCQ5JaffFOAhzE2E7gr3h5gmyRtlhFNFYpNRuNh/\
fatANus0YXNv5PZERty6Y0tK1O/AxhLPXdUGW7Bw1j/LC2l4QvANjZC1hQimiIUmw++\
Ln90EmLbOFnQPhyGgjGaEx0XDWHcHasR8jXHwxhn7Dd3h9isSZs/\
iWYZxeYNyzcbFSC2XKtDpWXWKBjTkRoC7rSHIY6d+8THjsfGc3Xc/zfEdgffrP6rScPmfvtM++FZf+\
jEVrikWofxGIAhJhQw10kQBYNhyjCneAFcds7FmP3pITwMH6mpeS/SAWBx0uYcepvr+AMSXp4GMOR+\
t6oUSgsgmlcYv7/8+RHA0G3aNajyFQ+jIdNxqz7bXrDfSdq8Sm/z/\
b4JPTcFgG3c1O04gyYHYkPeKLj23LkTwHhRLb8wmx0PI337zevXPgBsrfjmK4pNddkyIReIbUPQy+\
gj/6+1+/7rKXocON5GpZK20t470d5USBqEkEQRUaHsaMhoSMqoJKKiJFpWqWSkiJYWTUVLpVBU33Ou\
z/vzA+d+z31/HvwBr8f7ds/T+\
77PPffcCygYckKcnQcgjDnG6roubngYprI6M7dDbPtJm0q0pi7FZtnSiHWaENsrr5Rw3d0oGAuVqsd\
2Qxi6bclrOuNYsM31B3YW/\
ITYyJuLyJsEtkuzrhcUC9KL7QXTsTuWxwCMgxyyqUpyKBiuxveOq80EMOIW7M/\
K8MTDCHbrVPmxCwDeT9rcTGteoNicEWidEpoAsN3WE2n7NoKC8XFBeWzSMIBx/\
2eFS42UEbZZsP6N7U1+gO0JabOb1iyg2HRuvpMsVwNgBJvcZ9UcmIk4kbVPVGq4qwCM/\
Uemn22o0MBfSgVw2B0RBoC3kjbraM3DFJvyU81prhDb1NUenRepKBgBjHOWb4YwGA0/\
3dLyxMPQilxYtQliY0gmawbSmkwUm6HL3/tqQWx6bU/szwShYAgek3rlB2HcU1oSHa6Cx/\
YukOvTBMRmRNoUojUv/NUksJX5F14WUacXW7Wb7iGezQCb+\
cT15CZ1FIy9hRIsN6YDGOLdu69G78TDCJnQOzjgC5/+Jm0eoDVFKTYFvn/\
Qs5AEMDpWqDjIlgojmrc3C2RuY7Q33TX3Ttc0lbV4GEXZ7ofuZQPAY6TNLFpTimIzcnrD+\
tksAIadUjcT23VuxIkcKcx6H1UKf7PNnea+KgIPI/DKhZs+ZQDwAdLmD1pTgGLz86LMm+\
sgjG7XDUbT81EwVhVZ1C2DMKqjk3LGvPEwLu/MWuMAAU+\
SNtfQmh8oNnWnsQbMg9iqp40eenUGBWPPj+DovcS30OSQBcdjZnxzaD0Dw0z4Ant80/\
qvJoFtFG5BYkkvthUzFip1+wAYle+dpY7qoWDwuI9wK7HA31fRs7/s2k1hNrJ5/\
3o5CwD4JWlzNq2ZRrFpkJG3TFAFYAt/\
O7nv9DkR1CWfsf4vO24Aw1BbQftRDB7GjLn811zLALZ8fNOaYrPSbv2Q2uBi012XhXSmz7zDg8I2Zx\
nDaD6AETHzskyqDR5G4lPnPQGPAbYz+OYZik1VvgCNhRDGx+NDXCrPUDASu7n260AY8+\
0rj2T742HcE+I/txICHiBtXqM19Sk2R6PeszFBGDes+g70J6Fg3DdYsmQ/\
hKFxR1N3vQMem8C7hYHaEHAqvqn7V5PAJmE2tKliPb3YIj+9WXxcCsCwC+\
BbKGSBgrHcdvT8nSkt012N1v3Xlu3Dw7hbnKLZ7g0ALyNtOtDb5ORLnqW8AGAzKLc7kbJtDqKZ6dRZ\
6SQKYJgu7z86sxIPI72/X/nEe4BtKb65kGJz+\
5AqQ9l7gI3x1ICiwplZiBPpHtrap5sBYHgf6BQ05cDD6Od/\
cnBpHsA2jbTpQWvupNjMDBCNsYUwcu1GBbRrUTCWKU3XkYQwGheXmLkexsOQaw1XWQABZ5M2bWnNBo\
rNdR0zfjFDbOJvP+cO3UbBuHLk6cgBYuZwrfrSI11M2OZihqaD8yE2MXzz019NAptNCrulrB+\
92LRC1E627AQwtnhLKF6zQU79P9U/\
afITwCjauLZK6jCF32y6ZfpaTACwO2nTh9YspNh8tTWM1XQQ3hNz797LYyKKaB7lOOERogBgOOQuaM\
2bYYz/xnjrOxlqAgAnkTYDac2VFJurXfmXVN4CME61ZT464MuLOJFlnSEeK644wFub/\
hsFzqpjm2ahVQlvKgBgH3wzjWLT4JPCMgUII8huQ4FEJwqGjkkhNweE0cudqswQgodxP2jbNSsI+\
B82m/OYdy6AMAxOvo5tLETBmAq1iD4EYQwqztq+8yAeW5Ld2lZWCDiEtDnz+H+a9fJ/Ngls+\
zjgJiT0Yjv+q1pNrv2nya7oZ0uHpJ1QMD7aqr+t/gZg8D4OODYciIfh0PhaoWUHAHyWtNlFb1P/\
hKTcAmsAo9L3snMmrxiieeu2/bqP8wCMPQ/Wd21YiIcxo65nRSKjlemuKtJmJq3pT7HpW++\
Rql4AYMxe/029y2424kTuE094a3AewNhWbx5QzI2H4XNyQ+\
XkdQCYj7R5gN6mx83UZ6YQRkpm3ZbhYRQMnmclTKN34OVZwtkdZ0/\
hYZzTST4jAgGn4ZtaFJufF4yt0iH2eDRWO5r2CgUjrpBbOoDYfpx/93n5WXhsCXaWOdMgtuP45om/\
mgS2az5G7O+S6cUWzqmk6FYCsNm8+fjw/\
AYUjH3Fket3DgMYcSymFY9C8TDenroyvc0LYPuHzUU5vmyL7AC2ir2OGfGdKBg5z2stjxsDGDen+\
kaLAvAwJNXC+B/NAtiaSJv5tOYtis1k04MKrzIBtoVLEpxD1fgQJ/\
LFW4mLbREAhr7j9VM8EWrY5smCz6dfJQJsTqTNMlpTnWJzOMl+jBPC+\
HHz2f4bjNqIY09WvcndAmF0JEYuEDmDh8HXEjCuBwFTaHZSbArWf9XTJZZrKW+\
sX9uMgrHccXfqEeIycqCtNTWVEdv8Hm2wbwbExoNv1v/\
VJLC9qXXqU39IL7bNA5maH68CbPxZJalTW1Eworw2i3IPABg2L+\
xyAsPwMNrufJT4uB1gEyBtxtDbXL/\
niHm2BIDBZ1ulqpgzF9G0Dzlyfp81gJEkqc129R4ehvu73oSiVQDwXNKmA615lWLzpq1qlNoFACNH6\
K1Txgx+xIlc91jHRucYgMG2eovbbg48jM9uTIqnrwDA50ibLrTmHIrNd9GRwVNzwYA7c8h7hSUPCoZ\
8PMeCMgiDIeh8Tsx5PIxpqy+ZzIPY/\
mGTU1KJTw9iC6qOmRrpQcH4ZZUrHkhsqGqwdmufMR7bsEyaCgfElk7aZLb+T7Ne788mge2Xvs/\
rE1X0YhNunfTs3QZg3B4wql67CwXjlM2MX7mfAQydBypLzaLwMFxza1ZkBgPAmaTN07TmAorNRJfGw\
lwXOEFS13a69qg4oiksGVL+3B7A8Hvtklk/\
hIdRGbQu9JIaAGxI2hSht9nkv4lpXSyA0WKrpPquDQXjg7vhTrXDAMZrMZ+rxmGq2Oa1+ve/+\
KIB4Hf4ZhXF5u5jd2NVIIyiqG9OZXNRMBKqjvplQxh54pl8zIl4GLf776kPQ8BP8c17FJtBDW+\
6CGxvLJpX7BlDwWA6JRIeRHyzdbx1Ga5jwDYrYkffckJsFfjm4F9NAptC0smsts/\
0Yqs32dP81RNgm//dcF3GQeQ6xqVSvW4fAYwrpSKJP2MoXPLdOpr8aDPARt70ozWTKDa/\
Wq7deNYAwFiwSPqplKwEoinhO9Ya5AxgCG8dGlqkZIJt3ilak6HhDgGTNiVpTVGKzRPiq3XnnALYGr\
mze9PzBBAnctXGm4z3/Rzgs7XPubM48TB+qdSf3xMOsNWTNtfQmjYUm/t/ef+SJW5Aa/p/\
0FJFwdCUSHl1CcLQ1mgMcr+Gh/Goad5EJ8RG3tSit7lE+NRWLgjj4x2T+Y3TtBHHfo2lqy+\
Y2KR1Xz5Lvjcem+\
WcOXf1iUdsSJs3aM36vX82CWwrWJOj9Rkn6cTG92ZQi9sSwLgcrOk6FIKCcTUysZ6/\
DcAIlVF7kHURD2Og6IvP5FYAOIm0mUJvc2HUobeG2wGMZvaHKnNPoGCoHOlmyncDMNyvdYvWbMTDEO\
tKSk+3AoC7SJuqtOY2is0ba699yz0CsKl7pUoPHBdEnMjwAo7msp0Axp4Wh5bh0yrYJsfSyW9mxwE2\
OXxzP8Vm+U2P3ncQxqdznJbBBigYceYixicgDJldWkqPbuJhMG4+\
uVscAu75d82htBeD3BDb8Jnyn3ICKBhaOavNjxFPaqedvKEzA4+Nb5O+\
vwHE1o9vHv2rSWA7uu3RnrNC9GKzWGIkwQFhzB2b80spEgVjwZvc7NfNcJr+\
gFWGayIeRvf4FdHr8gCwGGlTl9YsothclF625qcDgLGuTiZqyWcUDLtdqet9tgEY4fcu1++\
5gIfROByV1ukDAPuTNh1ozXiKzcivQ1d2BTnDdWjqS/\
evFEKcyCjmuLcrtgIYW09MhEnz42FkZYTZCPoDwJ6kzTO05gmKzcDUR2MvIbZde3q6HixGwbB0Cni2\
C8KojurQnnYHD8PFLWdcCGLbS9q0pjXrKDYFpWdtnwWxGc+\
5zLhWBgXjUv6d8FBiJyyGF04dllOPcU3lJJd5hhDbEtLmFVrT9K8mgS29Es6Q0IvNZWhxh/\
AWgO1LToTNmvMoGLalXdsj6gGMkVr+QI5kClP/HxYEHJ4BsPWSNh1pzWGKzVzG63c1/\
QGMwKL5GYnWkojmCqZPXA98AYyigZsnxV/jYUy+\
GNoRux4APopvPqXYZHWIEp44DLAF3a9WNRAXRpxIznt6T23dAIwdbjxzHBOUsc0EzxcGKjsAto34Zh\
DFpv34NflCiO3xN1ehxlUoGMeL/TzWQxgs5QsqLPPxMErD0s7wEr8D/10zyrPoHS/EdnjJ+CV/\
LRSMrxvVKo5DGFEcyv2lhyax2Nwt8j4T2A6QNkdozTd/NQls77S/6C6yohdbZfKG/\
ed7x0128S9J33EoCQUj9eTooH0NgFGcK7joTioexikd6WwlD7jVAmkzjdYspNjsZL7KErYFwLC8u1p\
OKAUFg8EtUD5xH4Bx/uaHn1sYTbFNRfGJwyoHAeDF/645cefg2/\
r9ANv8ze0e6h9RMNQ3p6TcWgfviU2zqzgpi4cRoXg5vWMzwCaFb+\
6l2DxoL67LCWG8tP6i3uaOgrFNMkXMGsJoXndB6GABHkbRseg9dyDgctLmdnqb7Yc1dPggtuluS+\
UOmKJgHF/CzniSeJ5t7R527pwJLLaoZTsvGkFss0mbp2hNjb+\
aBDbmuOlzEl3oxXbBtGTe8CuAzSdL7WDMDRSMXzI9WqJvAIy50xJYHDLwMHbbfDth5A6w7SZtMsj+\
pylJsbmPrdy31wdgY229XnSfUQrRXLz9W77sEXv4yqi0BPM5eBh7ks7kNB8B2JhJm0toTVGKzechHU\
vV1sNp+ujksrWpIogTabp+yH3rKgBDPj7LvCxLCT8T23JJctIPAI4nbS6iNSUoNq2f/\
Wy5BmGIJCwPfLMbBWOvTn6vFoTx6/Yls2tP8DAeD1X3s0LAc/DNCYrN+\
evvmhtDGNlDBgPutigYLeuOKJ8ifrNV3S541PcLi23epXsn+SHgHHzT568mgU1tSnLimx+\
92M75dtSFZwFsye6eUVfuomCITOOW6isHMOxEnpT3Z+FhjK/\
kdnGA75Wm0LSn2ORmfuNeuh9g2yiYNHxyLQpGzf4H7auPARjdBoVeSdp4GIVzY9QWh6z5p03jtqvzP\
HYBGAbPmqNfuc9BnMgDHwza/\
B0ADDvpDF0uYzyM2Sf6vSdXAsDzSJuHac3VFJsrtwbfndoFBvHcR8EuaYEoGML1Dm/\
EiN9sjhw7S8rwMPZkO3tegIDVSZsitGYzxaai861KAQhjYkuBlf46FIyz3U+\
XhhHbIrhPqpfJ4bFlPcz4SAD+n5oENufNBi3LI+jFZuDME+VxFmCzO2r5IvkhCobYpS+\
Zxc8BjKjoIykhuXgYpgX1yp6bALblpE0JWvMMxaY71wF+qSAr+\
MSuWs2ZbBQM5ULGIeMwAMNF5otA8DI8DE8ZT7Z9JwC2cnzTnWLz0c6ULqvlAMY9h3Lj8xKiiBPpcLO\
r8u0yAEP7wpoa+1eK2GbsiqkBdm8A+P6/a+Zv6Ds2BrFt1mwT9DyNglHUIFM+\
HcJ4UNT4pLYSD8P8qgpPOMTmQtp8SmvmUWwWeoYGmUAYOtr8wd89UTCqbvK5hRO/2arfJ6u7/\
cRis8lznSEEAVuQNmtpzdaqP5sEttCyFcVp1+\
jF1lFsHRXgD7DV5toYxZeiYNzpcXqZ8ATAuLD8fJLAAzyMw0cbewPdALYq0mYerXmOYrPr7a2N3KcA\
tu5H2kuaZ0gjmlYS/Fs/RAEYb8vvfu5zx8NQYgvO2BkOsHX9u6ZEEv/\
Hru0AxvRZ69tfv0PBsBUzvrVrMYCRoNR165QLHkYta3XVlDUAzETaXE5rJlNs9ktVbvkKsa0dE/\
3FewkF4w5LU9PXLPi/+yeTrR9q8TBuKgxXH4HY1pM2c2lNRorNIT0pHWEIo/\
XQp4FLe1EwtLuSdkYQN6BL/ff0Jo5jscUqbxE2hYDbSJvzac03fzUJbHfVdiYzPqIXm/\
UnRc6aNQDbBsekGSdeoWCcU7V1P/wYwFhvf+\
1pciEexu2T988nbATY1pM2L9CazhSbdyIFJmLPAGxHurM8/FxQMHIWjooZnQMwBHd+vtZ6GA/\
j9Gadcc0ogC0E3xSm2Owv2HpM1ALAsO716Q0PE0OcyK1z3yU7LoLYdE9euDWkgG2qHnI1Ht0KAJvim\
0kUm59O96/\
qh9gE3jmtTrmJgnGQWZapBcKQPpt5pLmJwvbjTOo5uyE2WdJmAK2pRLGpFeN3k4ARvNOqXvUYCsZb9\
0TfSGKannWI70fzGBabNofJGhEI+DRps4bWTGL5s0lg+3D2+\
DHnanqxKX9pMPAwAtgWKLFabatDwWg6Ncd300MA40csv6TKEwrfQjN0FO+\
7AmzapM1mWvMbxeZ9RWGLZ2cBjNhzbwc976BgPLuYbOMaD2Aoc9903BiLhzFDuDGy8AIAvJe0+\
YLWlKbYfFXa4BxrBLC9nMep2WswF3EiO6dZHvA2AzCmPVtskBmKh3FpSuiGpofzP216s3M4dUNspmY\
y+6TvoWD8cMwxeglhMMe0qL5pw8O49d0zawvEZkLa/\
Elv8zszk88c4jebwr1TqdEoGGKnTbafJvblj37FbS+Kx3ae5918Mwh4HN80/atJYGMfS9qS3UMvNo+\
qr87akgAbj08rl3kLCsajUtMW23w4GzmsXnj7OR4GU4N63LsNABsXabOI3qala+pm9fMA2/\
U1VRzPmWQQTY5Lxck2SQCG9/A29V0ZFC75Qr+\
9jboMsKWQNjnpbR6pPr74wiYAYxmPsBnLZxSMJauPBBYbARi7jNeEHBHDw4jyyo930wWALfHNvRSbj\
CUqL9YSN7WH4q6feoqCMaVrGJkLYZi/\
qI29342HkeDdt7ENAt6Nb1pQbIoM335IwKi2MbPjSELB6PHKXRtFXEausGQbXvcDi43xefZBUQi4mb\
TZR2se/atJYFvg8mAxJ9MUndjGenanGbECbMFn9Q9wf0Ju+DO2/4pJNoAh28mVplaBh/\
G0Ib7zuwvARt50o7e5xdzkzuwUAKN9luvoRQcUjGkvd6xmuw5gpAS6nRJ4goexo3BpjU8cANxH2mSn\
NdMoNlcr5boengdgXOqa/344WhxxIvc9GA9ZpA9g1ESFT83Ok8c2N91ly5DdCABH4ZuNFJsrvzH/\
XA6xJQutVWyuQsEIyfD9mgRheAy1N1zox8N4NmP1wSaIjbx5jNbcQrHJWRN3SAzCqFbb47vmFgqG6k\
N1izPE1P+87Nt1id+x2K7skzY0h4Br/\
5cmgc3tSbWyuzC92Oa4RTCJQBjsrMVXqgaRl3yej27Mvw1g1G68/\
jntDR7Gy9FrHoGfx0x2cZA2W2nNGopN54GH6RGXAIwgve7aL0koGFmOHvPO3AAw+\
uL3PLZvwMNYdFXcdVkGAByGbw5QbAYoXb5X5wJgNEpkvPokKoE4kV4WUY++\
L4CLhguSBVzs8DBOi3Ttb1EDgBvwzWUUm3f7AqwXQmwehheXCLWiYDg7cOwIhzCub8qYs/\
Mrhf1CQviv1kJs7v+uadDsmE/AaMr2nx/9AAVj7nCzZDTxzeY4Uj/e9g2LzTT+\
5665EDCFJsOKP5sEtkiF/pmFGvRim355ZtPkKwCDZfT5pbAxFIzQxfN7NNIBDP0rhRFza/\
EwPFI1BozWA8CspM0TtKYhxaYIp5uPxV0AI/Wmf2JtPwrGyIewS4O3AIzi+A1y8l8oYJN+\
n30iCQDOIG2O0polFJtfeeXT0tYBbMaLKuze70TBkLk9+\
rhmHoDxJj7a1K5PDts81Du6OlgJYNMlbcrRmvUUm4tuqmfpQmxxRfLLTfpRMFy2F4/\
vhTBGwtUP6Y1RmKbv6K+\
thNgukjY30NuMOS20QZxYG9nA2Z77HAWDwb7nOwEjyaltk7McHpuHk5uqBQRMoZn1V5PA9gC+\
5deaXmyJJ11sc+\
8CbIVsNqH6TMaIP5BwrPVKzVQAw7t5MvF0A4UdkdXKr2xaB7A9JG2K0ppeFJvJhxZ9HM8H2GZOdAyu\
0pNFXfLZdd+Uvwu/hVrkOeJYzLDNE022OzcnA2xc+\
OYXis2mHbMnN8kBGGlupg83PUbBWBN272CDBoBRlF4p/f4kHoZsTe74BWcA+\
AZp05nWLKDYvLAnXeAlhBEtcfSg/TgKxoKyZQmbIIyulc/m/JzEw/\
hZflNTlXgglbSpQ2t2UmwOKnknEjC6+\
q48LK1BwfD6FPz0LPEtZF9gObR9FIstXVfLTIJ4koC0uYPWtLP7s0lg6xwWr/LeQC+\
2AdOHgmFrAQyjsa+\
7WthRMCKHTr9fkAxX6PN0yv96j4ex4Y0r57XzALAxafMMrfmEYrNIQXXhvgKA7a1QKndwMArGyt7VM\
np5AEZn7s/UW8J4GOfvlIhJp6yh1PxIsTn7io339dVwv5CXm31OcEkiTmQJ12l5ZjU4Te9dnPldAQ/\
j3jSz7kNSiyk1r1JsDvoer5CEMMyaynmXT5uPOHbfku32yyGMr+uVRbJZFuK/\
hZ4Lby4lZjhJm7tozWGKzcNZF9kXEpu07rNnfdyGgmFwreZUDAFjw+\
2wh3dHsNhKLY4LS0Jsuvim619NAhvPar2cF/70YrN327skxxlgK1vEe/DAbBQMw+gGP7PLAIbW/\
Wdam9vxMLb/6tz08hDAVoFvzqPYPCgxL/lxCdwvRORwtVsFCoZfu0CU/AMAY/\
7G7xLuangYe24tevUsDWBrwzd1KDZHZEsYX84FMDobHTxXrUPBOB3SYLRcGcCw3JKucLZMFts01Ij4\
Ve4EAPeRNhNoTX2KzZvKG44KQGza/P1OunwoGHPk64UNIIwovoBzG9nxMHyusRYWQmw6+\
GY0xebN1Qy7CGxfW78wXB9AwWBbyWYdS9yAjjOxyx3/isUmGrPiE4GtD980jf+\
zSWAzLHA4JxlJL7bhVxHaLWsAtvM5KbkcoigY6+\
TkZ9nHAxieIY1lz7vwMKJ87qbIuwFsMaRNV1pzK8WmuWdbbs1zgK1fdM11Jj45RHPHBnG90QI4G7ll\
ReATczyMhrcJTvbpcDaStLmT3uZR3fUv2VcCGCVna9Sa01AwpPQ19jxUADBCZwwYJm/\
Hwzi7wO2S1RwAuJS0KU1vU5bRSOY+hLHya+iJmZIoGGXz7UflIIytWZa32XjwMPg/\
vrLhgICdSJsvac1tFJsf84tqCGx3S3i/+\
P9EwVh632yCgOG6tL600QKP7YJD7S0piI28uYy8SWDbKuW178B1erF5jiS/\
4YDYXnVv0Dsrg4IR8irjqvt5AGMFm/p3uV48DG+\
TvYoPrQC2l6TNE7SmA8Vmj3P1ltJbAMZVlpCDO5xRMJiUHs+/Vgxg3Ii8eb/cCQ9jy0Hb+\
gcVAHAavnmTYnOG0WoVV0eArVXoeJ3kCApGTVVzziI5AOPuDAYmUW48jBsmqzcOCwJsNaTNd7RmCcV\
mzo/Ic9kQ2+w7rN2vVVEwJqLOdfBCGNPZDgRd5cfDmF/jq8kAsYmTNidpzZkUm/d+mW+\
ThjDcWIS550+\
fj7rkC828eY6YjZReqqIQOYzF9iP8u9YiCJhCk0HmzyaBLQYuIHlEL7Zz3vcsQlQBDK/\
3CaKzVFEwbvK+ETtyFsCIdM8qDfxCAcaEn7D+agDYG9+\
MotgMNa8W8nsLYBjEzWq4dRkFgzNryY4FTwEMk96JxKPb8DAOFPKfkMwCgA3xTVOKzZJzIwkv7QG2V\
T4OTPOMpRAncrqepHCfNIBxevO8iaFsGWxT+GuU+XM+\
gM2JtMlOa0ZSbB7b0qs6KgYGsZRfStYhfRSMb9qenZO3wYA7YHJYdf4cPAyXknK+\
TAj4HzYXvCgKJ2B4pGtdbuFDwZDz2W13nnj2bKdz08WGISw23d21YjIQ8GbSpgKt6fpXk8BW1JdoqF\
JDL7bk5XUztq0CMKS27vQ7Nh8Fo69fzv/\
SaQCjlEXBsP4rHkZrSsnyoNkAsCRp8wu9zX3aQ3O23QUwtjSwVr7qQMHY8kH60q0XAMbWg+\
49nYfxMILUTpmy1VlRanpSbBp8s7hvbQdvQG890yZ8HAWD7bFmZ4YkgNHsJCQj4oyHwX5X/\
eCTWQBbKGlzGq3ZRbEpfKM0MQ3C4O0KkBK0QsF4vSPsew+E4eOn+\
KpQAg9j2vz3Zj0QsAxps4bWPECx6ROt005gK/Pe2uwviYJxWStvgIAhMbxIV0UOj+\
3mtCcvCGzPSZtJtKbpX00CW5/9vbnHeunFZsh3KyHeCWCbcfnCmkEjFIy8Cv/\
LRWHwpra80RalH3gYDAbxN3PGfpj8P80qWvMDxWZqEKfn5RyALfPCrck6OXlE8xyrzHqOCgBjREhK7\
2cUHkbry6JGn0b42A6++Y1i8/\
0VfaMGW4DNsNRrXutrFAwl7fKAUHEAQ2lqbvNJRjyM5TPEgju5ADYt0qYKrbmAYrPuc69XC4ShGRyy\
L9ERBUPodZHoOwiDXaXysIkcHkYos412MgT8D5tMp0y3y0IYvrOTmX6qomAsuxB/\
7ALxLXR47YOm3YNYbAmO/vMsIWAKzaN/NQls4U1bGbwZGUzpw7bp+feK1ysBtsWLYj7YW6JgjF/\
Ojvh0HMBYF+u3fN8vPIyWxKFskVaAzZ60OUlrulBsVrB5XSzJA9jYjCsSqraiYFjyBUjbV8J9+\
bmnzXyWjIehVH3EIP8DwMZO2rSiNZ0oNsv8tjMcXAawyW/mWHKaXxpxIguu2e3eKwZghAUN/\
1hwUxrblLsTMEOBE2BTJG0W0ponKTY/Ks+vvQRhBBaf7ed1RcGIkX3t+\
ATCUMrWW5uvjIdxVr8wswYCDsY3VSg2de6fO0rAeBJw18ZLHwXDK8iK/yIB4xl/9eJjX/\
CXkSsDWeUg4GJ8s+ivJoFNKtLPd85MerHpGM16nf0MwDBSjBK+aYuC4Tk4qc0fAmCs0l4wWcxgg/\
0DrSp9EcsMARuQNrfRmispNi1O2RXW3APYwk6t8iu7gYLRVa5kfbQKwOjoFH1llYeHIdZofaypHWCL\
JG1+prdZMDY2EDYDwBDYb8elsRYFI098w7aAOQCG167e+4Ir8DAERRS/\
qtgAwGykzfu0ZgDF5oyaX2wvIYx1Q/4P93ihYOzbtz/hNoQR7nX3qJwmHkbSvhWBFyDgf9jc/\
uhOGYGt6tqKkZeWKBicg82XfsO4Nf5wuuwAFtvVtfnnCWzkzZnkTQLbPdOg9udC9GKzeGc5rLcCwNh\
8cJf4mBNy5vBHyknLowDG7JQnh6ax4mHkx1WvP3ILAN5I2gynNXkoNr9bFlbVPQDYVJaHf3nyGQVjt\
sHAtLhauMfjEa9nQS8o/GZzlMls6QLYNEibfPQ2S6dNzRlYAmA8ihxmLr+MgiGu80I+ThjA+FbT+\
kxqSgrbnFN73ZRrGpz6J21K0Jo9FJu3bRz8HkNsIv19IqX7UDDav538Fg9h5H1nnhGxAA9jWPuI7lm\
I7R82H2vNlpKHMDZpGmoJOiKxsQaIxxG/r8Y2HOl/1ofF9jO1hcsKAt6Ibx79q0lgs/\
0a6bhHhl5sRm3RLw/\
FABgvxBpZTDagYPiUyh49dAjAyGg2r7GegYex923Ge19HAPgZaXMXrZlOsRkiLBjytAfA0N6qzftSQ\
QHR3POA+fjlegDjoeBHlf2NeBhjN/ILyh4BwHr45iOKzbeV/rEFiwG2jDdPlm3tQMEYn/\
h4vEwQwBiciFBZno6Hoe0eO+8WC8CWim+OUWweEtg+lgOxZZ+\
9bcF4DAUjYeT5xhMQxoJFh7l6DfAwGi6GjUdAbDn/\
rtktpmtHwDjCJGhsvwEF4xmPTdxvbBrS4UPbevH32eaWXiMAB5I2n5M3CWwd1+\
NLJTToxWYlsdgx3QHACOkV/3BwC3I20kliZv4+AIM18/\
7M0Jl4GJ0PRAPSDwLAR0mbA7QmA8XmJ7vZdyIHALbKOwwnOjxQMNZ9OFh9pgnA0Cx0EFXtw8NIfzp/\
RWYhwFaFb2pRbL65Kx4eZw2/\
2XS57nLLySBOZPsso8McAgCG2ry81TGr8TC0lLsltjABbLn4pgHFpuVzu+cnIIw+\
ngNeKmdQMFTafr3fA2GMnBm5aWqGh7HKdzT6JgTcT9pUpbf5RbQqgsD2xjvGdv92FIyYmC1c8cQln6\
elN9esHiy2G6I/xBUgttekzVhaU2Lbn00C2/7VafNfGdCL7XPQ9U72TQAG49iqx7e9UTBGqt1lv+\
2BN6A3cWs9noWHcczjsG2XPQBMoelIsTlR7ldoOAywbQhpSxa8hoIRYObU7fsBwPj+\
aP3FpAk8jAXM3c7HigC2baTNo7TmOMUm71ilYYgVwLZDdyDxxRYUjBvlblwb+ACMK10yAj1seBj5+\
VZB+gwA21p8M5di89v6K2ZJEMb3Ea7yRZeQ2Ey/btsIYWxd+\
vJ7hCUexvmClMRgCPgHvulJseky0HSWgLFu4/aLp/eiYIwvHjxIwDDdrFNtdP8TFls5a+lzAvD/\
1CSwcXPkpuy3ohdbytOHXnFLALbvFQ6PGvcil2tlDRTo+\
cIb0ItmLhnhx8NIECp8KQWxkTddac1Iis2Pux8eX14CYFwws3Xf0YqCYZq34aZpG1yILBQRXctljm2\
uuzVX6O0oAJyAb3ZRbOrPaRiQnbQ23RXtnqAWl4aCcWqG+IonvACGcfCVE9Z5kthm7U2hr/\
stAeBzpM1wWlOXYlPnjATrOYhthZhxzLIbKBj1V/yn20IYN9/\
3zqxeSmHmcJXH0QCIjUIznWJTN0l6koBxXsfVMSYYBeO2AmvH728hedEj+\
zd1Y7HpS8czKELAF0ibWbQmw19NAtv1gmJBOUe6p/75DI+v0QLYXKITP/06goIR3dVUHrgDwAiW2+\
AiK4KHITAn+\
omrHcBmR9pMojUPU2zGzV0UPLMUYFOc7nuod44ioumxsPnrZAeA4fbVqu2VOB7GcyYt7mVjAJsyvrm\
JYlPEZZeQwi+\
AbaZZvHLYJxQMXdWSvTqzAIylJd0KaR54GJY2H6cdXASwCZI2DWhNE4rNzi1y78MgtjM+\
PT8tclEwBuId8/QhDE6vOlYeezyMCHNPr/3EYzv/rvlBnE3TGmKzDl2Sdfw0CoaHV6lFwu99+\
WWdHnJ3YbEdk3L1ILBRaLr+\
1SSwGcDXs7nQi01WYlGqlQjAdt3ixCqBEygYn9T9F772hJvzdJ3d6zAXD8N7U7R20nKA7Rpps4/\
epqhjWPOdXwCGLK+67QUnFIw8Z+bwW13wxRp5VUvCNPAwSp8NfX78dM0/\
bR5lVSkzGQfYpscX812Vl0WcSO2utDsPuOHayM6sIkYhPIwf4uatoQsBti9xZM0FtOZbik2eXyfd9k\
AYl3dyz1csRsEoKFm1Rx7C4PW7+H2hEx5Gb+\
OWskAImLxZSG9zROGoK4Ft5jWRDs94FAznuKWJBIzWtA6niYJOLLZs7RVPCWzkzXW0psSNP5sEtrdS\
TWMB2+jFpiWjYr6ZCWCTrBQVlY9CwZC1UBUT9wAwro6JJR6UwsM4He8p3GYLsEmQNhVozSsUmw4J/\
VcZGMAgNm6e/mN/FAqGbrGj6rLP8EHPd4sCuc3wMFx7pZZteQ6wmeGbgxSbE/Iabdt/gM8ZkiMq+\
dEdBSPO4JOVDReAoXCpzsP2pQS2qaO5sC/BAmA7RNpMoDW1KDYvvkh284bYxM8/\
852oQN4Tu2pvzgdhBLs1jPuuxcP4tTu+bC/EJkHa3E9rhlBsvqq5Hk5gG+JuETNIRcG4H5o//\
BvGptQ4vZ0dWGybwy+LKUFsg6TNB+RNAtuW2u5tyv70YouI9a3M7Pluskt+\
vtJi9QsoGIqC55fucQMw3DocG5Pk8DBEnlfvkIbYlEmbSrTmJorNwe/\
fffSZwSB2lqt0PFeGgiEqVnrsQy+AcSz9kMw6ezwMDWEFbZYygG09aVOM3ublpqcr0r+\
BzzlNLdXCORkF4wSLWEQvJ5zMeBp78PhhPAw2Du6UR+YA24QqtvmYYvO4+\
f73OyCM9ak2HUX1KBj37/FIMEIY1mxVcudd8TBabkd7bYOA/\
2Fz9nJPbwJGWGbZmZ93UTBerJExu0T8vup6v2KbRDsWm3zeqVwCcDhp8yWtWfTxzyaBbeL4SNO7QHq\
xmfVeUt2yDMDovGw6pJaEgmGj5P30lYsWfO+\
Zj3aJEh7GCpG8F3LVAHAbadOW1jxJsTmNpcvclQ0MYmUH5Z/\
DjEqI5qH5NTpuAwBG1sKfJbs2UpjMEBcXO/8SYNPAN+\
9QbJq0RClNjIDPybu4Wm1aKwrGi8vOLec5AAymTyPXUjTxMN6Fj0R9NAPYZpE2y2hNVopNxb3zjroT\
6xjvsD3Y3YmCYbrTfeZAJhhwD1nWROe442GIvX3AsplYb0naNKO3uf/SuwcENpVWbe/\
0QhSMvphbJwkYEp/3VZ2sacViW/\
XerInApopvmv7VJLCd1WdcFhJBL7Zz966vyLAB2Ar3ZMvJpaFg8L2OPaq8Fm74cz4mp0WNwjR96e0b\
5Q8BtsekTQFaU49iM8qw4LBEBYDxIH98SaweCob2paCm+kEAI+\
b5y8YVvngYOcZSLLtnABglpM35tOY5ik19+6n9rl9B05zv06qhOXKoy0jL+\
al27HC5lvjVc0tfiWObNU/TdQUhNgN8M4BiU2HOHBNnCEOD87iswCAKRi+\
PJHsThCGg2ur4chsehnrCpkuuELDav2uejudmUIbYNvqmfVzyEgVjv+\
DOit8w7LKGZfhb8JeRze8nCGzkzQPkTQKbItxc6yK92J5Eiw8mXAMwHF3jfvJloWBw7eXeHbEKwHAX\
f+o2poWHwaLT8GF4KQC8At/0oNisyL4dtZsTXp7ZHfYI8kHBcBtQnDL/CmBcq1/\
ayByIhyH6nbk06RUAzINvplBsCsgnaNibAhjO7ZrjYqtQMAZfdTrxzwAwrq2XUZnUxcMonN3qWTMEj\
t0J30yj2GQJdgq3g9huSEWvSPuJglH5il/\
gBYSRVbQ3sN6bwjebHWPpWojtHzY99803IbDN3fJBurEWBWOT9NEZicTSqh3epydCmrHY3rz0EVsMs\
Ynjm0V/NQlsjy+LqL+/Ri+21wrP58RFAGxy66oCf+\
ajYGTysJz96ghgdHb3W3Lr4GHk7F7wQh9ikyVtZtGa7RSbecMdTkKVAEbZ9dX6j1NQMDLWWStcGYWT\
GTxTEoFReBgM6d55btxgEJeTNm/R2zyUqz/\
7rAl8ze8Em0j0GRQMjlmHPT9Og9iGuN6uSZmLbYZpiKmvHgSf8xy+\
mUGxWb6r96sThLFmjrSf0rQFiGOPTRfQzIUwtt94o9GyBw/\
D9YVSnyUETN48R2t6UWxe8PPaR2CrTX2+ak0b8j7bxgnT3zB+LUyN/tGAxbZ1Mac+ge0DaTOL1mT4+\
WeTwLbSQT7pZBa92DzeumSW+\
ANs7zMnXzY8RsHYvrKwbr0dgDFrqHWrpAEexphGOWfIEoCtmbTpRW9TxctqgRkvGHBXNvocsWtGwSh\
i1675+h3AaDluwfD6Mh7GsurKc8ffAMA38M02is0NGnsDm40BNofeK8cdylEweC/\
quRWxARgvuuoKHPnxMBzkznH0DoBjX0Ha5KM1Syk250QyqjpAbG4bfXISeFEwJkO+O1+FMHSSjPd+\
2I+HMTnp5GIEsVFo6lJs7h+\
oSyew5QdFZb7oQ8Fo7prc9RtG8NuYBu93WGz1x4odCWz3SJvvyZsEth4W7VkLHtGLbUlemLKAK8DG2\
n3y0+3nKBhHlNK1K2zgOkb+VW/\
UTfAwpC7kpL1eDLCxkDZDaU1Gis3GdMWn3PxgwCXNOFegP0sZ0WQ1L9xnMA5gSF3heNSbiYch89X0w\
8BbgC2dtMlGa8pQbN6LEFgW3g8+56aGqrZNLPKIExnq1lh+\
nRXAGJ8UO992TAzb5NusI6UKAW8lbZ6gNfsoNvOPxbfPgzB2cwwaT4mhYJxkjjh7GsL4ZPHAsy4AD2\
PvW2nvZcRe//+\
uqWh8ZRsBY77A9RUKP1AwZuhcukzAMJ3Qbn3eU4PfXWvDuQYCsBFpk53WPPrzzyaB7Wg+\
fMaGXmzjK+qEYhYDbJ5vUnoPVyJhTK1ONl4MYCj6DYboW1BYQdI/\
94IIxLaNtHmC1lSm2DxUxDazUhAM4of5s2yDFqFgrPF8HrLvF4Bxe9OJsKYCPAy/w+\
pBttUAWzFp05nWvEOxOS7YciXECC5E/nHywktDFIyWDm7dWBYAo/P0iq1j30WxzdBRdxuDPnDs+\
fjmAMXmy4n7+5SI59mk15k6KKJgrIrLaDwEYQhLdog+\
D8bDCJw574E18TwbaXM1rSlEsTm39GEAga3zXK7fPuYFKBhLBp/\
9hqHJYezoWYXFxrK9nFEFYuvANxm0/mwS2AS2LfsaWU0vNmHVKxMG8wA25c32Hy3eoWCka+\
4Vzl0E9wv5qB1pZoWHUW+x6N0Wa4BNk7SZQWu+oNj0cEm5dUQEDLipK6wuyvtRMPauf+\
qaPgn3C7lVfjGxAg9jm82RqpQagG3i3zXF9DrutBsCbApJhl9O7UF+\
s90dMY5kBjCiIq8lntmOh1Ghs9Prew84djl8M4Zi85C5n4QkxMZSmdcRq42CoRCoorENwghMZ7yedQ\
IPo/E2D9dCiI2NtKlIawZRbG5jkIwisDXsfWB4nwsFY+lp7s+/sW3/\
INpRV4nFdqkjVobAVo9vMnj92SSwZYjCF/3Si+\
2Gjq9bnhWA0Z69vIuxBbmOcVdthLo5nMxwivm6cCmFFSSp4ptmigHAraTN6/\
Q2n1rsMJISAwPu9NrMQb0MFAyWBCPvGgYw4BZe2ci2oAkPY85jN5EftQBbJGmTjd4mf4ufcNFn8Dlj\
58pPpaWjYOxaeTYgigk0neulWK60zsE2Szi3TLeCgM+\
SNnfTmi4UmyOuZxoEIbbutbaOL01QMMJvd5xdBWHYK84QOBtBYd/\
Ix4nbTCC2f9g88JrPnIAR5vejukcYBePq0Cy2ywS2Hxz3NNtfYrG1+LUmEoDPkzZT/9sc/\
rNJYDOv9Kjt7qEXG+O18flsEFtEpdZUfhcKRrvWpu+\
3jAEMVYMtjxYux8M4oLWsZto0gI282UFrqlFs6h3yehHzCQzibxI77iu0owYcN8PeuHhGuAzqqsXDu\
avwA27F2vYNdwzAIJ4kbfLQmkIUm1PncpLM3wHAancD2+58QAE2D9WeOQJhTN5t+3j1Mx7wma88S/\
LFwbFrkDYtaM0pis3ndY8r9SEMRrXie1+WIL+F6m+\
wLoIwvkVdDN4ZjYexJqo6mQsCJm8q0dvcvN3DmcAmHsLiPlMWBWOgcebc3zAWi+\
cFjDzFYrNbOCOdwCZP2hz6b3PRn00CW33gbsuYb/Ri8z7b+\
V5p6JvJrvGUVaYeAygYBtzqyzQMAIxzfQNfTB3xMKZvsLJdZQkAT5I2jWnNixSbc7isvu3phhMkYSK\
fZwopoP53F7A0uA2/hbbWRuozVYpgm4uuVfpLQmyXSZt7aM2dFJtnXQzWmEiBz/\
ljmlrXOR4VxLHnNEZHs8PJDN38veZd3/EwgioWp4XWA8ADpM08WnM+\
xaaREtMRVghD8iyjEZsTCsbCzauOaUEYL9YwMlqcx8N4IL3KaAEELPHvmreVb+\
YQMMSuPheS1EDByNAR1vwN4/Hkm7yZxfjlWvppOwjA5M1b/20W/dkksO3UPppvysRIJ7aq7au4/\
JsANsuu7vuc31AwPpt5hObpwEs+\
LqdYvVV4GOWjL1NvLALYrEibPbRmB8UmY802edcuMIgjzrPNX7cMBeP0IXeu8inw+\
8pB9oy1hTUehu7xjdzn9eFzYqTNKFrTkGKTTc3Qp7QBbkw0djCqzwwFo2ZTkIMQvCeW5uIuyshG4V3\
VkhKfH8iAY4/\
DNzMoNnWTO7f9EoWXZwfXTOfaiIKxyPsprwSEMd3U5ApPAoVnz1ytszUhNvKmJa05g2JTm+\
H7QQLGkaggQTkDFIzVBxabEDAYgjxkItfew2K7H/n2IQE4grS59r9Nvz+bBDaW7nCF/\
pn0YvMbejr66SnAlv+\
q8WD6BHIyQ2BFnKk2gDH1JStbbS0exrgnm8nEQoDtHmkzi9ZkGqTWNOaT7V75EQy4baNxkoJBKBgLK\
pOfDsDJjIRUth8NJcLY5upU4y+\
zILa1pE19WrOQYrMuRE37VyPAtoOXzy5vFwoGe0FJvBhc7TEVdGjbyGw8DONKFl8leXDsvvgmYzC15\
sE3ezVVIYwSoZ3m07xQMIJLXt2aCWEk/WLe+\
y4JD6Mo2GLLVwiYvBlCb5P79c5jBLZvPm9PiFqiYJQkZlv/hrHnycLdDrew2JL9IooIbCMUmv5/\
NglscRfBP2F6sQkOHedxgDBWsn6LNWc1QfyBuNw2Hn2tAWCc6pqwl9iAh6FU+\
002OAsAXo1vRlJs9rlZtJzRAzB4rx3lNc9DwRB+3CsgAmHIVBlcKzTGw/AKU3u+\
shMMYn7SpgitOZdiMzeqYGOkImgmGyrt+X4VBaN29Ns9EbhoWPRGtEixJB7GmY+nVNSa1/\
zTpqHJy3wFiG3LJgveYX8UjDlvlzj9vAUG3K/B7Jjz1/EwzDZ+2t0DsW3FNycpNk+\
xKJ8isCkuvX2WxR4Fw0jVa9lvGDHOEaqzYrDY2qJ6SwhsCqRN4/82L/\
zZJLBp2KSwW8rSi61yzXKthfEAxuj214JVnCgYiT9na7iqwsmMTNm9XJvwMIxye4TSLOC2CKTNq7Sm\
BsUmc4V1ugDE9oVP26b1MwrGx6ZfD20mAAzz6iv9nx8KYZtx6/\
U2bOgAMPrwTTuKzfaF4nLdyqC5OJRHNbsKBaO9tG+Qeya8AS08MGurOh5G2uOHkc7vAbYl/\
65pNy5jKQOxfThhkvg6EAXjc7Yg52cII+j5Vk77mxT2eHx3KaoNYmshbfbQ2zxlMPYbRsv+/\
S4f1qJgPDY6/h8YOcsHg5ZFm+CaLWssfwN+T9os+m8z488mge3Z5N2Dwxr0YiuPK7+tHAqwyba/\
4HHmQ8EwNOC6MqoIYBiX/FQc88DDWHi+bsWUOVwb+e+abBsGJZN0AbZSqaDREVFFxB/\
IVlNpVyi8Af1mzdm8Ffp4GEnBJ2x2tQMYL0iby2nNCorNOqmt0vPVQHNJ8d2IPkZVxLHbfX4fOgEf9\
FzyJUO1xxAP44qaa0TghzWUmkspNtMC1QvqIYxYMzXOS+EoGDdleSrrIIyX079+Yb5NYV/+\
yh3N4hDwOXyzgmLzw+Envy/5chm+ct30QMFoOCC0+DcMD4u4ZoMMLLbQD42/L03zKDS3/\
dkksK2787gv0ZBebCm/vmnr+QJslTxzohrnoGDI7Ocqj5QDMGzzjH1bt+FhOA5PFa2C2F79u+\
YHpj18ahAb09IvQsHLUTCaFeaOP/sJYFhPWUr8uC+I/9+9/LRmZBuAwULafE9rLqTYXFZ2+f4+\
DdBs9foVnqKBgrHEKuNBBw+AsW2nnIX1EjyMFsZDq5NbADbOHWRNG1rTn2KzecRzrBJiy+ZZGLj+\
PAqGyhGey6UQhklKk11WNh4G+4ywA3MgtrukTVV6m/Hcqx4R2CzKrV5u8UXBuCwzz/Q3DDt+h6Px+\
VhsDExMhwls5M2k/zaX/9kksA1tqli/\
1JpebG9c5Z3vmMGHR5UrrjlKo2B8ihq4riwNYAhEXHAs3YmHcaKic43XOgC4nbQ5SGsKUWwej4vPvd\
sKBvH7YPaUiEAUjPVayYJcEIbAzb7jr/\
TxMA727Hcq0gGAW0ibLvQ269qTxYpaAQxtC6VpnS4oGLzGwmUlcCes6axWEsGr8DCMwr5Y3NUCx26I\
b7JTbBrfF1n0HGJ7uENSiucqCsat7NGDdyEMjQPupk738DAMtm+SEITYHpA2M+\
ltup2v8SZg2Ndx5woeQsEImN2j9RtG3/kk0dAiLLZlzkW5BGBH0uYR8iaB7bhAw+\
vvjvRiiwsSFuOE2ObdyV3/VAkF44NHsmKFONwJa+\
bld9d2UfjNxqZ4r9QKYNMibfbSmkEUmx3jvQVOEMbz0YxdgtkoGMYlPmfWwkXDoS5fg18/\
EsDPRj48EtLSAgbxM3wznGKz8Jvs9Po2gO3FnemPU8NRMPTTfvTGwT0ec/S7w+\
I342HMyv4q1K4NPmcpadOQ1sym2KzV+PCKF8KQbajlzc1AwTBbdsk9CcIYKIisHH2Eh+\
G3kCepEAImb5rT2zx0kOMWAeO9hcPX+6EoGJ8eLJf8DUPhdbCY7lMstuKGbS4E4A/45tG/\
mgQ2sbKPJtc20IttutXbHrN5AAaPdEiZuhYKRo6Poa2PKIDRz1/\
DHOSPh5Famsm21RQA5iJtPqA1Byg2892qpIYWAGxSL+UNpTtRMApNf2ncHgMwWgX92kZM8DCYwmxs+\
SA2SdLmY1qznWIzw1bdrLcdvpNgh8SGkfsoGJK9G5y94O7Fke1iltG+eBi9bmxh03Ws/7+\
mFL3NkOkdQVwQm1lzu79NPgqGh+fHtZEQhqA/L/fpYjyMt1+\
F2fMgNgt8U4hic59PszUB47jziTTbMygYTCr+HL+\
xPZEOre4ow2Krt1x4lQD8PzUJbNkHh7PsttOLLfTz+siOuQDb9cf536L1UDB6TDo4hIQBjJH+6x/\
WHsDDeKBYPvupCcB2lbQ5QGsOU2xeFdLccBpis1XbmJbNp4T4A605vaxkOoQh5PHsin4pP/\
6S79uM53YfwCC2wTclKDbrU0I+\
yerBFSSmVQcqulAwdH3eWusIwVUpdRHTtwbgYST7DHwZ6wCAf5I29WhNb4rNErbpwbcgDLNRY9+\
6YhSMpNwMl0MQxvZaT26pZ3gYDLzOJuwQ8FrSZjKtuY9ic+luU/Xfy7V8k77XxqNgyAt5D/\
1eNBzlILz85GssNjNr/9jfT2r/L00C22K1KckJf3qxBfG5mElDGIba178OmKJgHOBucn7CD/\
cgOee9UysADyPR/KHpDXYAWJ+0eYjW1KPYdCvemxLzHgxiuwttluULUTA+VdXN3voDwNBIl/\
9xcTEexqeJbltNCHgpvmlMsXnGmOuQvgH4nDVym05rzVZDHHtuw+bPP+EbZw4duR0qFoaHccQwW4/\
l45p/2lzWpMzMBmGMeq+WcaxAwdD3qtqxDcI4eu5Va+ZLCusYL6azX4eAyZsGtGYgxea2nbdm/b6p/\
YyB2S4FBcOremn1bxjnVuvYxbzFYqt6mhFKYBsjbe74b/\
P8n00CW0srx9kbQfRiO8BhcCX626jJrgXL/F9bWKNgBDgenbeLF17yCey/\
zxqEh1HG6xYeZAwAz8c3v1BsynvGVtbNBzAarKrOeO1BwXDTW/\
6tAj5VveR7rNXMN3zYZuv5qtSWZgCjkbS5ida0pth8da4o3NIINPmujLEomqBg3DPo2/\
4Avkstz0tgZ/Z5PIxLWznN2bsANt5/\
17S9XJeUAGHUKwvdLalDwZC0X3ByNYQRbaNzdn4lHoa5i9lrRgj4HzatPfQGiQc9ty0+\
1fcoCwXju5PYnd8PjxaYPeptrcZiKyoe9iOwbSdt/qA1i/5qEtj8zgqxOEXSi+\
1Yf4Td5XaAbeNVpdgzy5HfQkutI2W44WqPiu9Pa4/\
hYTTdaB5qNwLYXEmbAbTmaYrNhrBLJzUhjK9f+\
gcuJqNgsO2PMtSBMJwS7kucXoWHId1xoOgIBDyMb66m2FxZ0a7E2Q1gXLWIUL+7DQWDL0Fgchd8S+\
jEvGwPpWt4GCYuO1yWmMAtIUibAvQ2d3xYuygGYmO26zSQbUPBKM68l2UJYeSkuy3Iq8bDqJ4ITprw\
BYN4NmmzhNZ8RLHp3jT2ksDmaRVfK/oQBWOTxcip3zAsrowGKtVhsdn+\
cthEYNv6vzQJbByWsn5McfRia9AqGHz9GmAbMLmwst4JBeP1uaJNjRwAhlQ2V9zVk3gYrDIfdi6E2P\
pIm2/obT4+7T3zVBPcj3Hz5qyVVSgYka/\
8H6Z8AzDScgZNRFpnY5sCHzcxqUBs3PjmXYpNd8FXmpZm4HO+tSxb/iYWBUNs5HS5LHz/\
tUPdrNnBWXgYPWnRfOyfAOBq0uZceps3gt/vH4MwjvdfbT/\
Qi4LB76jfqQ1hFL143aBRj4ch0cP1IwwCTiBtCtGaLyk2T42+syVgrJ7N2+\
L9FAWjr73V9fc3G9fOyyK+\
9VhsH14xXyUAryFt9pM3CWxXfmh2ZV6nF9vcOBlZyYcA21wbLzEhFxSM2PLIjLPTAQyerNcGXhEUFg\
1vCGRINQTYBEmbcbQmB8Xm7cTS758awSA+KHCX/\
yqDMuIPlGj0ZPEcCCNlcHfYDU88jEivyL1N2gDbAXwzi2JTburWQn0L8Dn1h9rPHitCwVjVM3eySgL\
AeNgcw1P4CA/jpSjzXJbPANuCf9e0n1t6LxjCKIx69OzJKArGvfAEaWkIY7r94/\
DrzXgYz8R0nUch4HukzQe0JhvFpsiXMF0CG0vMcsW8ShSMTOWvWr9/\
X4mOrirIacRimyza7kdgYyVt3qY1Tf9qEth00o1Xrb1DL7avNl7RsakAW/wN5XE7d+\
TaSG6fjXascI/HxgV3tM7gYdQm9CazQ2yJ/\
67JbFrFbQuxRcl72QSqoWDkfZ96HAO3nWsViZmlO8KLbeoZxTJHQmwRpM18WrOLYrPh08PN4xCG5oX\
NQjU9KBgJe4oKDkhBGBtufW96gYdhdV68Sm4RfHiUtJlIaz6g2PwVZ3f8IMSmUjJ3OgODDqLJq1C8c\
xaE4frAyIWvDQ9DeF2A2RDEpoZvbqTY7O7fJ0FgY3+qV/OlAQXjQbE+\
428Y632TfEebsdguFi5aRGCbTtp8SGsWrfuzSWB7tX7pi2kF9GLr+R70QTkGYCs+\
N28syAv5LZSte5CHCcB4UKzN8C0GD0PVwcbJ2wBge4pvPqLYVBTfIH6/AQy4gnuMvqNrUTBK4jx+\
8EIYas1c04qP4GFUZKwNs4DYSkmbT2hNUYrNFNF4Xk4r8DlHP/d/KuBTRxx7TWSxhpgMgLFMgWfd+\
xo8jLD0MZb+HgB4jLRZR2/T3+TUpt0Q29K9xs/U2VEwLnidejqVAfd43C6y/\
vBHCk9qq8Wr90NspqTNeFpzK8Xm84dpbAQ2I3njKdFOFAyZsWflv/\
f6v3f5vfG8Fiy2Nc7XZxHYDEibsrRmUf6fTQKbG89qvZwXdE+\
QjDfz1eoDGPcXP5DP3I2C4fCmerh6UhNcHWRfU8u7QOGd2mwXsjqOAsCT+GYfxWZI/\
fjIz3kARrvS7tMMJ1EwzM1fvI4dATCKXPY/\
NeHEw0j0vzSsCAF3kzYX0pqZFJumd4uEm3vhzKFCD8MiYxQMBrV3Bx/\
IAhimAp8qSlrxMHiVFA17rOGjQPimOcVmZtt+mc8QRu1uEQlHPhQMKZEm+QEII6m5/3zrZzwM+\
RSrZdshYPKmNL3N/pxLjcRe/yckV5QZDSBvQNenRBMwXLPkVQTyW7HYeD/L9BLbj58kbTLTmkf/\
ahLYfpRsvulaQy+27Z/57zzaAWBEnayMrjqAgsHTZV4c9xPA0GZwMN+dgIdx/\
3NrswEEHE7a5KM1tSg2m+Sy5PMhtpkdU8nXclEw6jT3SohBGHInH5fdvjgL21wye/rqpHowiDlIm+\
9oTTWKzWMlIUHFS0DTbcDQZvsWFIzpMdolDvJwr5RR1trwPjyMAwEDj573AcDupE12WlORYjNnLpvE\
R4jtV7yR9ra5KBh2HudimyGMaXeFxYwH8DDmS7gu3ASxjZM2HWhNNopNpdffXhEwqh2m7Bx+\
oGCsEfq88vc3m/33RInqNiw28SNmSQRg8qYzrSnxV5PAFunnO2dmK73YvolfT0/\
WAzA2LFxvNRiIglF/+FLL5h8AxrjBd1PVJDwM1+yEk3nOALAzadMk4D/NrxSbXx+\
YSYhCGLEK5fEdbSgYllOaFWlwX/72i3l3ORXwMLLGKzj8IGAKzS6KTU/hJdOy+\
gGMWsGuVK0oFAwx2STZLgUAw65r5k+\
DH3gY7j8MBKNtwLE3kTbn0pr2FJsb7qRbr4UwuHSLJfwUUDCmxi5zlUMYOq/\
LxmOHKaz26FaWaoOAuf9dczJc/jaBbVqtfY4zkw7iHI0rJvD/\
fgkGzym7kv52LLY3v666EdjkSJtTtGbr7D+bBDYZhYDw+730Ynt+\
9FfnGysAI1lKwWHaSRSM2xU8VlqjAMbOIGONzmQ8jN1zjwZwQsBXSZtZtOYOis260m9il96BAeefvG\
/l45kqiD/QmCjPXV0Ig5O1xMQhnwfbvHok9dR8iI28OU5v08r2LE/\
sAMCmtfhSe8I9FIy45tBne5TgJq3BV4vfMOMHnKTba8V1tuDYNUmb8fQ2L8W8U3oPYVQpLmfeo4WC0\
TDQFH0fwvBwGTX+9A3fZOFkdnaEgKvxza0Um43TaiQJGLd3DfCs4kTB8NB+/\
fb3m0f9mAom2Tqx2E7yFkUSgO+QNreQNwlsDxpPTbh/pxdbh72GN8d8gC1W8M1jwSjkqv/\
VLYNMwwDGtdxi/gupeBiTj946+OsCbOfxzVSKzRP7wyN/aAEYBeNFV/\
T0UDBybnhnVwwDGOPBJ5cfssLDSL5XJCsNAT/EN5lCqDX3t0V98f8CsAUkuRekt6JgVB3iKp1Uho/\
DtESkLuXGD7jQE2Xd4nbW/1+zmtbkoNiUiTDZtxTCMOCTGfMwRMEYqFCTSoMwZrdu+\
K79E99UrR3Va4CA/2Gzg7frPfFK3vmv2EOsBJDYhCJO/YbhH+/\
YMPcjFttMoTIvAtsCfFNi759NAptdxPmdvMxMdGLby8As16YDYDB/eZMgeR4FoyLJta5uAMA4XcD+\
3TodD8OgeHWtuxQA/\
GOArPmG1gyj2OxmustUCLGtmjFlsWIzCsYlr867myGMRzkBBTPvcGObm8o5uDLrwCBeStq8TGuOUGw\
O+Hccem8PmoNTnP4aLBqIY4+MljMMUQUwTu37JH9LBD/gMuvFHqwcBIC//Ltm183dy2shjOt+\
s8RtLVEw1p84/OgchGEkEad5aArfPKdrkGwBAWfim2YUm3wqPecIbK/3+iqpSKBgDPt2mRAwkhw/+\
a+c34XFdl1m6WICWyW+WfRXk8DWZXKtpZCLXmxGw8dGbSA2wfqgUZlEFIzxJwxDt3oBjOSnZxu+\
ZeJhtI3lPW3hBtgESJsTtGYSxWYS/2SmEYSxUihvmOc0CkZnl3wMA4Htae/\
M5houbHOagnL1MQjYiLT5kdZUeUatyRQ9e3asI/ic9ppj7C2CKBijbheWsqrDe2L2xg9GZSlsEdc1/\
5jmEMBm9++aK3LfNBpAGKq5R84o2qFg8By5tfEYhHFCm/lnAfMibHORp/H2txCwyr9r+\
kfayhAwBphDJFiVUDAKL3YPxRMwCnkP+y/pxmLLmRq0IQB/wTdb/\
2oS2A7BJ2xE6MW26VHql30TIya7hAZE6iSvo2DsUzXVP/EJwtj/vOTKXTwM+321hfcXAMDi+\
OZ1is3dG13b39aCQTwvdNZq3/soGPoe7IZJQxAb+\
7Sfa8dnYpuDy5r7lkNsWvhmEcXm4bobVZYr4RpOe8btbsooGLn1/FxBGnBbBM27VbKaeBj+\
0xnd2YcBtmHSZh6tuZViMzLbIuIVhLFR2sdrbA0Kxin/a7P2QBhrd5a5jk/Dw+\
he3DRXGwJ2JW2G0ZrOFJsljewMBIwiRqOgqnkoGK0pl5IIGBIXBLNMXD5hsf062DRhBQFTaLr+\
1SSw8V4vKBaUoxebn5rfEXkIo7cgfYlQBgrGCtPsdPePAAaTGeO9xXl4GANHE5k1ewHgHtLmKnqbqb\
4ngrdBbKqGLrx7O1AwlFndoywgjL7wTzKhkngYHE4+RqIQmwRpU4XW1I2g1gz3+\
uDVCmG0hjWsf2iMgmEbbJU4rglXkCwQbzcyxMO4kbi5fdgJHHsnvllIsdlQv8BbBcK4PRBQXrAJBaP\
4onWFG4QhZ93rrcmJh8F90De3DAI+\
Rtp8QWvyUmzafhyrJWAYj2hujzFCwdjow29DwDDVYrLN8fmMxeZ+yypLAQI2xTdd/\
2oS2NJWvdQq1aQX25TJkPa5+\
QDb8TLZDdOzUTCOsjKZWLYDGDb7IwoH7uNhLL4rkT2tAWALJG0epzUXU2xqpiz0ngaxWdgE5EjPVEX\
NHB7n3NcD33/dvJpng+MSTmxzuY9tdo8mwGaCb3ZSbPqxH9tycTX4nL1pF6/32KNgjNxv4PeeB5+\
qrtJ1MrbCw9h1deft7K8AcD9pc5TWjKLYXDiR2/EUwpjB+bHMfwcKxk//o2fsIQyBZbrzN/HgYTi+\
f1wuAwGTN3/RmoIUm5axdzIIbAf0Yr8tsUJe8kWuHYkjfrMpyZ18F9iDxeY0M389gY28+\
ZjWdP2rSWAzZn+X7GNEL7Zg8w/NrBBb6fTV4sP3UTAuNHX3K7YAGA63bzRFFeBhpDEVZ/\
16BrAVkjbjaM3lFJtqnS+C02rAIM7kXPVs3wIUjB+sTxtjIIz60IOZj/Zw4P/\
XPB1l9BBiS8Y3WY5Ta5ZKtx/TdwafMyHv6+\
TgZhSMnqETES3aAMaw0Y2L8g4U3lGmfsk4ZARgiydtDtKagxSbr7Y4aotBGM2zDwTJ7EXBqJnQ2mgK\
YVj+tC84zYeHEVgyJVgCATf9u2aeEnsQgW1ht47JNzsUDK/1hy7+\
xvZ51YmMM71YbDq6W6cT2MxJmztoTdf/NP8PYCwjuQ=="]; $CellContext`saddlePoints; 
   Null),
  Evaluator->Automatic,
  Method->"Preemptive"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Global saddle-points map", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "saddles"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"saddles", "=", "saddlePoints"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Map", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Apply", "[", 
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Tooltip", "[", 
                   RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}], "]"}], ",", 
                    
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}], "}"}]}], "]"}]}], 
                 "\[IndentingNewLine]", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}], 
              "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[CapitalOmega]", ",", 
               RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]tt)\>\"", ",", "\"\<Im(\[Omega]tt)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Map", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Apply", "[", 
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Tooltip", "[", 
                   RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", "t"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}], "}"}]}], "]"}]}], 
                 "\[IndentingNewLine]", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}], 
              "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[CapitalOmega]", ",", 
               RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Map", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Apply", "[", 
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Tooltip", "[", 
                   RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "\[Tau]"}], "+", " ", 
                    RowBox[{"0.1", " ", "\[ImaginaryI]", " ", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}]}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}], "}"}]}], "]"}]}], 
                 "\[IndentingNewLine]", "]"}], "]"}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{
                RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}], 
              "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[CapitalOmega]", ",", 
               RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Re(\[Omega]\[Tau])\>\"", ",", "\"\<Im(\[Omega]\[Tau])\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{
        TagBox[
         TooltipBox[PointBox[{-1.0968614211836956`, 1.4971691046585303`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4905971192945886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8383554163654704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210240003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.4905971192945886, -0.8383554163654704], 
            Complex[1.5874585404782842`, -2.3355245210240003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0447312324060967`, 1.4971691046585298`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.632189772884385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8383554163654666`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210239963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.632189772884385, -0.8383554163654666], 
            Complex[1.5874585404782884`, -2.3355245210239963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0971625829584521`, 1.4968466580800113`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.6980000948375882, -0.6433017314670934], 
            Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0444300706313414`, 1.4968466580800108`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.8395927484273833`, -0.6433017314670934], 
            Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.5018059118396891`, 1.1700244588063096`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.6944263543752545`, 0.006645071137818129], 
            Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6397867417501044`, 1.1700244588063096`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.8360190079650485`, 0.006645071137818026], 
            Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.5017854283628758`, 1.1700279500517285`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.976967927486167, 0.006887727487396918], 
            Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.639807225226917, 1.1700279500517285`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[8.118560581075961, 0.0068877274873969585`], 
            Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.401714513166993, 1.1829054568301065`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.398301539299036, -0.01324317030169907], 
            Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7398781404228012`, 1.1829054568301065`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.53989419288883, -0.01324317030169899], 
            Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7399179755419685`, 1.1829150513430053`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.834135988275976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01205573978218699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.094218012734007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.834135988275976`, -0.01205573978218699], 
            Complex[9.094218012734007, -1.1949707911251923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4016746780478258`, 1.1829150513430056`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.692543334686185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.012055739782186827`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.09421801273401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.692543334686185, -0.012055739782186827`], 
            Complex[9.09421801273401, -1.1949707911251923`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0960978517558209`, 1.496193394758603}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.46502963264100744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.868215310870579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291823`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.46502963264100744`, -0.868215310870579], 
            Complex[1.5611274843968284`, -2.3644087056291823`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0454948018339727`, 1.496193394758603}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6066222862308037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8682153108705755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291787`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.6066222862308037`, -0.8682153108705755], 
            Complex[1.5611274843968312`, -2.3644087056291787`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0967485715744627`, 1.495499002677154}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.7333882582665036, -0.6165221792948049], 
            Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.044844082015331, 1.4954990026771537`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.8749809118562997`, -0.6165221792948034], 
            Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.5012161060031892`, 1.1700906593460907`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[4.654309125631486, 0.006712510785854934], 
            Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6403765475866035`, 1.1700906593460907`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.795901779221279, 0.006712510785854963], 
            Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6404219513334717`, 1.170098429005005}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[8.162580737731858, 0.007042959985370651], 
            Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.5011707022563219`, 1.170098429005005}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[5.020988084142068, 0.007042959985368871], 
            Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4021781609488528`, 1.1828156904519647`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.352914113679207, -0.013509876715323901`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7394144926409398`, 1.1828156904519647`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.494506767269, -0.013509876715323853`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7395019194070571`, 1.1828367302459344`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.876435471981889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011949285676122938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.136933552574833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.876435471981889`, -0.011949285676122938`], 
            Complex[9.136933552574833, -1.1947860159220576`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.402090734182737, 1.1828367302459344`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.734842818392103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01194928567613202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.13693355257484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.734842818392103, -0.01194928567613202], 
            Complex[9.13693355257484, -1.1947860159220667`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0953112476823026`, 1.4952661581004916`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4451990626513003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.540510310333603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3877804035408325`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.4451990626513003, -0.8925142454403411], 
            Complex[1.540510310333603, -2.3877804035408325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0462814059074903`, 1.495266158100492}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5867917162410965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5405103103336057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.387780403540836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.5867917162410965`, -0.8925142454403441], 
            Complex[1.5405103103336057`, -2.387780403540836]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0452034856727574`, 1.4941201745224164`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.9045700992025902`, -0.5952855745698094], 
            Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0963891679170357`, 1.494120174522416}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.7629774456127986, -0.5952855745698065], 
            Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.500625192097362, 1.17015713808447}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[4.621891868208896, 0.006786025025047798], 
            Complex[6.122517060306257, -1.163371113059422]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6409674614924308`, 1.17015713808447}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.763484521798694, 0.006786025025048383], 
            Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.5005480471445807`, 1.1701703920092206`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[5.05739532427709, 0.007197843246654808], 
            Complex[6.557943371421671, -1.162972548762566]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6410446064452129`, 1.1701703920092206`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[8.198987977866883, 0.007197843246654797], 
            Complex[6.557943371421671, -1.162972548762566]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4026519382158162`, 1.1827237771013548`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.315449803449272, -0.01375104485251276], 
            Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7389407153739764`, 1.1827237771013546`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.457042457039066`, -0.013751044852512806`], 
            Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4025048564206946`, 1.182759143616015}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.769143367766525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011873440576434954`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.17164822418722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.19463258419245`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.769143367766525, -0.011873440576434954`], 
            Complex[9.17164822418722, -1.19463258419245]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7390877971690997`, 1.182759143616015}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.910736021356321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011873440576436094`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.171648224187221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1946325841924512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.910736021356321`, -0.011873440576436094`], 
            Complex[9.171648224187221, -1.1946325841924512`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0945080247482581`, 1.4943796703340055`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4287165628002437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.523224587548502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4079083765075175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.4287165628002437, -0.9135287061735121], 
            Complex[1.523224587548502, -2.4079083765075175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0470846288415356`, 1.4943796703340053`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5703092163900387`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735095`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5232245875485029`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.407908376507515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.5703092163900387`, -0.9135287061735095], 
            Complex[1.5232245875485029`, -2.407908376507515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.045515325524576, 1.4927176614778297`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.93075079131323, -0.5773156862277917], 
            Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0960773280652174`, 1.49271766147783}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.7891581377234371, -0.5773156862277916], 
            Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6415598616528695`, 1.170223958104622}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.735547972440535, 0.006863336573144897], 
            Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.500032791936924, 1.1702239581046223`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[4.593955318850742, 0.0068633365731448895`], 
            Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6416750690250668`, 1.1702438309113217`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[8.231005147885755, 0.0073549519610065905`], 
            Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4999175845647268`, 1.170243830911322}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[5.089412494295966, 0.007354951961001998], 
            Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4031353168487857`, 1.1826298514755766`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.282554763488937, -0.01397986959845826], 
            Complex[8.685690080337723, -1.196609721074035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7384573367410063`, 1.1826298514755766`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.42414741707873, -0.0139798695984579], 
            Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4029178290658042`, 1.1826821042449285`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.798795489744536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01181529831920876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.798795489744536, -0.01181529831920876], 
            Complex[9.20171331881034, -1.194497402564137]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.73867482452399, 1.1826821042449285`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.94038814333433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011815298319208752`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.94038814333433, -0.011815298319208752`], 
            Complex[9.20171331881034, -1.194497402564137]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0936921793397578`, 1.4935289027559584`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4144938153406103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.508185994680368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4258284901011864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.4144938153406103, -0.9322995873452282], 
            Complex[1.508185994680368, -2.4258284901011864`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0479004742500355`, 1.4935289027559577`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5560864689304044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452297`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5081859946803688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4258284901011873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.5560864689304044`, -0.9322995873452297], 
            Complex[1.5081859946803688`, -2.4258284901011873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0958084485167499`, 1.491296260033016}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.813020240902394, -0.5615718710865851], 
            Complex[1.908828689419144, -2.052868131119601]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.045784205073043, 1.4912962600330162`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.9546128944921874`, -0.5615718710865847], 
            Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4994386686134773`, 1.170291158898574}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[4.569036631840206, 0.006943461497604872], 
            Complex[6.068475300453683, -1.163347697400969]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6421539849763163`, 1.170291158898574}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.710629285429999, 0.00694346149760476], 
            Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4992792804249542`, 1.1703187646377389`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[5.118506250669166, 0.007515591774090762], 
            Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6423133731648394`, 1.170318764637739}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[8.260098904258959, 0.007515591774090756], 
            Complex[6.61778553109412, -1.162803172863648]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.403628075771506, 1.1825339738020837`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.252703058118813, -0.014202465960727835`], 
            Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7379645778182866`, 1.1825339738020832`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.39429571170861, -0.014202465960725278`], 
            Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7382625096524005`, 1.1826054959126457`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.966914215304485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011769056829642613`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.966914215304485`, -0.011769056829642613`], 
            Complex[9.228651705652085, -1.1943745527422884`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.403330143937394, 1.182605495912646}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8253215617147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011769056829649287`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.8253215617147, -0.011769056829649287`], 
            Complex[9.228651705652094, -1.1943745527422953`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0487261657722, 1.4927102038651812`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.543518627975134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4947924622029343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.543518627975134, -0.9494075862605201], 
            Complex[1.4947924622029343`, -2.4421177901257014`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0928664878175935`, 1.4927102038651816`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.40192597438534255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.494792462202936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.40192597438534255`, -0.9494075862605198], 
            Complex[1.494792462202936, -2.4421177901257014`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0460134876232585`, 1.4898593936430988`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.976762799482182, -0.5474736791133854], 
            Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0955791659665355`, 1.4898593936430984`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.835170145892391, -0.5474736791133877], 
            Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4988426539199966`, 1.1703587685295225`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[4.5463246331431195`, 0.007025882918871681], 
            Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.642749999669796, 1.1703587685295227`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.687917286732913, 0.007025882918871702], 
            Complex[6.045167287063117, -1.163332885610651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.642959637221158, 1.1703952273655902`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[8.287084479515974, 0.007680628289981289], 
            Complex[6.644124842294815, -1.162714599075609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4986330163686357`, 1.1703952273655907`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[5.145491825926181, 0.007680628289980853], 
            Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7374624995014827`, 1.182436165339691}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.366639367283945`, -0.014422357660350082`], 
            Complex[8.629176867782464, -1.196858523000041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.40413015408831, 1.1824361653396909`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.225046713694154, -0.01442235766034999], 
            Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4037421484563606`, 1.1825292375518723`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.849565759088899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011731532239340082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.25330790754526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912124`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.849565759088899, -0.011731532239340082`], 
            Complex[9.25330790754526, -1.1942607697912124`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.737850505133432, 1.1825292375518723`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.991158412678699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011731532239331113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.253307907545267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.991158412678699`, -0.011731532239331113`], 
            Complex[9.253307907545267, -1.1942607697912035`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.092033007219986, 1.491920745919518}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.39063568307703384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.457137190679493`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.39063568307703384`, -0.9652164447599751], 
            Complex[1.4826686902970199`, -2.457137190679493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.049559646369807, 1.4919207459195185`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.532228336666828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.45713719067949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.532228336666828, -0.9652164447599713], 
            Complex[1.4826686902970212`, -2.45713719067949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0953868558011925`, 1.4884096660678892`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.8559867126628703, -0.5346576120369388], 
            Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0462057977886, 1.488409666067889}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.997579366252664, -0.5346576120369394], 
            Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4982446187751601`, 1.1704268085713438`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[4.5253142371097725`, 0.007110298008162873], 
            Complex[6.023558855884933, -1.163316510563181]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6433480348146325`, 1.1704268085713438`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.666906890699567, 0.007110298008162871], 
            Complex[6.023558855884935, -1.163316510563181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4979786180017496`, 1.1704732639588975`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[5.170878634413056, 0.007850743160533592], 
            Complex[6.668857252414806, -1.162622520798364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.643614035588044, 1.1704732639588975`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[8.312471288002852, 0.00785074316053409], 
            Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4046415915053132`, 1.1823364227607005`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.199056007873823, -0.014641876121436175`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7369510620844812`, 1.1823364227607005`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[10.340648661463618`, -0.014641876121436062`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.050399325526527, 1.4911582438253355`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5219614272863144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9799721862678735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.471130430093209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[3.5219614272863144`, -0.9799721862678735], 
            Complex[1.4715621017597873`, -2.471130430093209]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0911933280632666`, 1.4911582438253355`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.38036877369652167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9799721862678751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4711304300932104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.38036877369652167`, -0.9799721862678751], 
            Complex[1.4715621017597882`, -2.4711304300932104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.046363275051912, 1.4869491423816577`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.017318225749185, -0.5228778864146391], 
            Complex[1.970954950697273, -2.009827028796297]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.095229378537882, 1.486949142381658}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.8757255721593927, -0.52287788641464], 
            Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.497644458620054, 1.170495296539726}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.5056658326490995`, 0.007196517077880139], 
            Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6439481949697388`, 1.1704952965397262`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.6472584862388935`, 0.007196517077880152], 
            Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4973158679916807`, 1.1705529279620166`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[5.19501091123548, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6442767855981126`, 1.1705529279620166`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[8.336603564825275, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.405162499478943, 1.1822347250851228`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.174373102447971, -0.014862729232274653`], 
            Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7364301541108498`, 1.1822347250851228`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[10.315965756037766`, -0.014862729232274637`], 
            Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.051243935550233, 1.4904207943031338`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5125370745305697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9938506052393002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.484271399542434`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[3.5125370745305697`, -0.9938506052393002], 
            Complex[1.4612931389803365`, -2.484271399542434]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0903487180395601`, 1.490420794303134}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.37094442094077773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9938506052392997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803379`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4842713995424335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.37094442094077773`, -0.9938506052392997], 
            Complex[1.4612931389803379`, -2.4842713995424335`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0464877181840464`, 1.4854795097098192`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.036161628380458, -0.5119589442981466], 
            Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0951049354057478`, 1.4854795097098192`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.8945689747906652, -0.5119589442981493], 
            Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6445505683004957`, 1.1705642472412046`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.628730822140306, 0.0072844163322486775`], 
            Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4970420852892976`, 1.1705642472412046`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.487138168550514, 0.007284416332243672], 
            Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.496644512512578, 1.1706342807319507`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[5.2181348551047995`, 0.008208588338762854], 
            Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6449481410772144`, 1.1706342807319507`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[8.359727508694593, 0.008208588338762687], 
            Complex[6.714779367617378, -1.162425692393188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4056930458564796`, 1.182131037333787}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.1507421714555965`, -0.015086273942248003`], 
            Complex[8.556435217312076, -1.197217311276035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.735899607733313, 1.182131037333787}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[10.29233482504539, -0.015086273942248], 
            Complex[8.556435217312078, -1.197217311276035]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0895002106859724`, 1.489706775942226}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3622285720771921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0069826142874234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.3622285720771921, -1.0069826142874234`], 
            Complex[1.4517287827631644`, -2.4966893902296494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.052092442903821, 1.4897067759422264`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.503821225666987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.006982614287426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296525`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[3.503821225666987, -1.006982614287426], 
            Complex[1.4517287827631657`, -2.4966893902296525`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0950119789930932`, 1.4840021770794485`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.9126523619522108, -0.5017701062164057], 
            Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0465806745967, 1.4840021770794485`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.054245015542006, -0.5017701062164085], 
            Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4964374220929535`, 1.1706336735867482`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.469552623884141, 0.007373913179256361], 
            Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.64515523149684, 1.1706336735867482`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.611145277473936, 0.007373913179256576], 
            Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6456283893157198`, 1.1707173911723614`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[8.382027043209192, 0.008397467701836855], 
            Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4959642642740738`, 1.1707173911723616`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[5.240434389619399, 0.00839746770183686], 
            Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7353592072201784`, 1.1820253125041496`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[10.269564843263957`, -0.01531366326459591], 
            Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4062334463696151`, 1.1820253125041498`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.127972189674163, -0.015313663264596189`], 
            Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0886486635147157`, 1.4890147831792446`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3541186043574641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.44276726787218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.508483683764771`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.3541186043574641, -1.0194689005855264`], 
            Complex[1.44276726787218, -2.508483683764771]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.052943990075078, 1.4890147831792442`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4957112579472582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4427672678721806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5084836837647715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[3.4957112579472582`, -1.0194689005855273`], 
            Complex[1.4427672678721806`, -2.5084836837647715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0949491544685939`, 1.482518341348761}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.9300797102089358, -0.4922109148816913], 
            Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0466434991211986`, 1.482518341348761}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[4.071672363798729, -0.49221091488169333`], 
            Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6457622529384726`, 1.170703587113633}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[7.5943652547457265`, 0.0074649522520338], 
            Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.495830400651321, 1.170703587113633}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[4.452772601155936, 0.007464952252033912], 
            Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.64631785003024, 1.1708023358369288`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[8.40364445944282, 0.008593772293729832], 
            Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4952748035595536`, 1.170802335836929}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[5.262051805853028, 0.008593772293729816], 
            Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4067839600187142`, 1.1819174925824536`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[7.1059154551031405`, -0.015545933419028879`], 
            Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7348086935710791`, 1.1819174925824536`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[10.247508108692935`, -0.01554593341902805], 
            Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0877947979425238`, 1.4883435805782301`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3465339039238557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.031388938053689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631919`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.3465339039238557, -1.031388938053689], 
            Complex[1.4343287018663795`, -2.519732518631919]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.053797855647269, 1.48834358057823}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4881265575136493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0313889380536854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631915`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[3.4881265575136493`, -1.0313889380536854`], 
            Complex[1.4343287018663806`, -2.519732518631915]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0949152590361233`, 1.4810290328377034`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.9469329539089921, -0.48320212310888055`], 
            Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0466773945536696`, 1.4810290328377036`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.088525607498785, -0.4832021231088809], 
            Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6463716948320208`, 1.1707739983365557`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.5782835412454626`, 0.0075574969911607935`], 
            Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4952209587577727`, 1.1707739983365557`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.436690887655669, 0.007557496991163237], 
            Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4945757779611735`, 1.1708891992948665`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[5.283100441464033, 0.008798133065178963], 
            Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.64701687562862, 1.1708891992948665`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[8.424693095053826, 0.00879813306517896], 
            Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4073448868889171`, 1.1818075089410556`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.084454398670628, -0.015784060035230123`], 
            Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7342477667008755`, 1.1818075089410556`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[10.226047052260421`, -0.01578406003523005], 
            Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0869392277544114`, 1.487692069955706}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33940979143382616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0428068062799807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.530498876235687`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.33940979143382616`, -1.0428068062799807`], 
            Complex[1.4263490191882378`, -2.530498876235687]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0546534258353817`, 1.487692069955706}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4810024450236203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0428068062799816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5304988762356877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[3.4810024450236203`, -1.0428068062799816`], 
            Complex[1.4263490191882389`, -2.5304988762356877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0466834407035526`, 1.4795351481161685`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.104870714597597, -0.4746798749981737], 
            Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.094909212886241, 1.4795351481161685`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.9632780610078037, -0.47467987499817715`], 
            Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4946090388791018`, 1.1708449169930497`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.421221515937318, 0.0076515243225991425`], 
            Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6469836147106918`, 1.1708449169930497`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.5628141695271145`, 0.007651524322598731], 
            Complex[5.915830554816423, -1.163193392670451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4938668011572593`, 1.170978074710212}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[5.303672866164795, 0.009011228909084937], 
            Complex[6.797539667322055, -1.161966845801127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.647725852432534, 1.170978074710212}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[8.445265519754589, 0.009011228909084963], 
            Complex[6.797539667322055, -1.161966845801127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4079165676323857`, 1.1816952823007194`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.063493070122277, -0.01602899750358731], 
            Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.733676085957407, 1.1816952823007194`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[10.20508572371207, -0.016028997503587203`], 
            Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0860824800162823`, 1.4870592660043076`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33269344666361156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.418775926679894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5408343661536397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.33269344666361156`, -1.0537751001493318`], 
            Complex[1.418775926679894, -2.5408343661536397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0555101735735093`, 1.4870592660043074`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.474286100253405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4187759266798956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5408343661536392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[3.474286100253405, -1.0537751001493318`], 
            Complex[1.4187759266798956`, -2.5408343661536392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0949300377280016`, 1.478037474296155}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.9791691098460469, -0.46659179640833603`], 
            Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0466626158617918`, 1.4780374742961553`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.12076176343584, -0.46659179640833626`], 
            Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.493994587069257, 1.170916352220469}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.406294309063904, 0.007747021157202576], 
            Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6475980665205356`, 1.170916352220469}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.547886962653699, 0.00774702115719995], 
            Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4931474509023812`, 1.171069064618027}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[5.323846388854408, 0.00923379877093513], 
            Complex[6.816993839756789, -1.161835265847092]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6484452026874121`, 1.1710690646180273`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[8.465439042444201, 0.009233798770935121], 
            Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.408499384202991, 1.1815807223508816`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.042951411025012, -0.016281708942805718`], 
            Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7330932693868009`, 1.1815807223508814`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[10.184544064614805`, -0.016281708942805753`], 
            Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0563676427600566`, 1.4864442777496367`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4679337359736433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.06433764500318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[3.4679337359736433`, -1.06433764500318], 
            Complex[1.4115660932135865`, -2.5507819227528166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.085225010829738, 1.4864442777496367`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32634108238384935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0643376450031767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.32634108238384935`, -1.0643376450031767`], 
            Complex[1.4115660932135874`, -2.5507819227528135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0466158130836756`, 1.4765367074931348`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.13624377018248, -0.4588942798973108], 
            Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.094976840506117, 1.476536707493134}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.9946511165926878, -0.45889427989730874`], 
            Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4933775521611368`, 1.1709883126870055`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.391851102143664, 0.007843982012263403], 
            Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6482151014286568`, 1.1709883126870055`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.533443755733459, 0.007843982012263152], 
            Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6491753872892059`, 1.1711622819000642`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[8.485279549606197, 0.009466654168547486], 
            Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4924172663005877`, 1.1711622819000642`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[5.343686896016404, 0.009466654168547547], 
            Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.409093761624542, 1.1814637270716994`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.022761264330782, -0.01654319107188898], 
            Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7324988919652515`, 1.1814637270716994`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[10.164353917920575`, -0.016543191071888914`], 
            Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0843672174547476`, 1.4858462941359671`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32031592905730694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4046831465120544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5603777298614023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[0.32031592905730694`, -1.0745314357254354`], 
            Complex[1.4046831465120544`, -2.5603777298614023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0572254361350457`, 1.4858462941359663`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4619085826471014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.404683146512056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.560377729861402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[3.4619085826471014`, -1.0745314357254354`], 
            Complex[1.404683146512056, -2.560377729861402]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.046543852813575, 1.4750334671609007`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.151354705396683, -0.4515505457349306], 
            Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.095048800776218, 1.4750334671609002`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[1.009762051806893, -0.45155054573492875`], 
            Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4927578851512358`, 1.1710608066908614`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.377843050837108, 0.007942407351021055], 
            Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.648834768438557, 1.1710608066908614`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.5194357044269005`, 0.007942407351021058], 
            Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4916757443684578`, 1.1712578509767424`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[5.363251612071681, 0.009710692858210855], 
            Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6499169092213348`, 1.1712578509767424`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[8.504844265661474, 0.009710692858210806], 
            Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4097001706915273`, 1.1813441817705232`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.002863505905769, -0.016814496662831985`], 
            Complex[8.412563676597296, -1.198158678433355]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7318924828982654`, 1.1813441817705232`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[10.144456159495563`, -0.016814496662831836`], 
            Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0580832057822573`, 1.4852645726118512`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4561794165348236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501943`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.398096210752566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5696526277620455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[3.4561794165348236`, -1.0843880551501943`], 
            Complex[1.398096210752566, -2.5696526277620455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.083509447807536, 1.4852645726118505`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3145867629450303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3980962107525663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.569652627762044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[0.3145867629450303, -1.0843880551501937`], 
            Complex[1.3980962107525663`, -2.569652627762044]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0951451607294451`, 1.4735283074287826`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[1.024534313536096, -0.4445292235923795], 
            Complex[2.119679474265541, -1.918057531021162]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0464474928603473`, 1.4735283074287822`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.166126967125889, -0.44452922359237873`], 
            Complex[2.119679474265542, -1.918057531021161]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4921355387215662`, 1.1711338422367736`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.3642286676832285`, 0.00804230239670521], 
            Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6494571148682273`, 1.1711338422367736`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[7.5058213212730225`, 0.008042302396705316], 
            Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.650670317741964, 1.1713559092447527`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[8.52418379610039, 0.00996691431009624], 
            Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4909223358478294`, 1.1713559092447527`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[5.382591142510598, 0.009966914310096187], 
            Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4103191315804102`, 1.1812219578228558`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[6.983205922649462, -0.017096756417673678`], 
            Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7312735220093824`, 1.1812219578228556`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[10.124798576239256`, -0.017096756417673668`], 
            Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0826520080189628`, 1.484698429945023}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30912680858594205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939347333651805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[0.30912680858594205`, -1.0939347333651805`], 
            Complex[1.3917788166049048`, -2.5786331633102035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0589406455708312`, 1.4846984299450237`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4507194621757376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939347333651823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[3.4507194621757376`, -1.0939347333651823`], 
            Complex[1.3917788166049063`, -2.5786331633102058`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.046327436410052, 1.4720217262117419`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.180588479578346, -0.43780329333443724`], 
            Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0952652171797415`, 1.472021726211741}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[1.0389958259885552`, -0.43780329333443724`], 
            Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4915104668614694`, 1.1712074270960608`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.350972359395372, 0.008143676269233574], 
            Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6500821867283233`, 1.1712074270960608`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[7.492565012985164, 0.008143676269233487], 
            Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4901564401882263`, 1.1714566088024065`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[5.401751028707841, 0.010236437677199473`], 
            Complex[6.891907468896068, -1.161220171125207]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.651436213401567, 1.1714566088024065`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[8.543343682297635, 0.01023643767719948], 
            Complex[6.891907468896068, -1.161220171125207]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7306414351805275`, 1.181096911088837}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[10.105334252708913`, -0.017391201699304026`], 
            Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4109512184092652`, 1.181096911088837}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[6.963741599119119, -0.017391201699304113`], 
            Complex[8.374692817528384, -1.198488112788141]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.081795168531823, 1.4841472347267401`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30391290545435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1031951533323334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.385708073986173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[0.30391290545435, -1.1031951533323334`], 
            Complex[1.385708073986173, -2.587342388059074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.05979748505797, 1.4841472347267397`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4455055590441432`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1031951533323339`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3857080739861731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[3.4455055590441432`, -1.1031951533323339`], 
            Complex[1.3857080739861731`, -2.587342388059074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0461843385556375`, 1.4705141726331532`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.194763527568909, -0.43134927949335283`], 
            Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0954083150341558`, 1.4705141726331528`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[1.0531708739791161`, -0.43134927949335167`], 
            Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6507100290262455`, 1.1712815688544405`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[7.479635970943437, 0.008246541346654087], 
            Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4908826245635478`, 1.1712815688544402`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.338043317353644, 0.008246541346654037], 
            Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.489377399579972, 1.1715601185194695`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[5.4207729647332625`, 0.010520523036427932`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6522152540098207`, 1.1715601185194695`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[8.562365618323055, 0.010520523036427927`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4115970648354652`, 1.1809688799576648`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[6.944427656372562, -0.01769918937958054], 
            Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7299955887543268`, 1.180968879957665}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[10.086020309962356`, -0.017699189379580486`], 
            Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0606534845111466`, 1.4836104011786775`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.440517518589483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[3.440517518589483, -1.1121900734843542`], 
            Complex[1.3798640340783366`, -2.5958004746630317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0809391690786452`, 1.4836104011786788`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.29892486499969306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843577`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[0.29892486499969306`, -1.1121900734843577`], 
            Complex[1.3798640340783381`, -2.5958004746630365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0955738419034178`, 1.4690060531470506`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[1.0670807469468007`, -0.42514662876555165`], 
            Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0460188116863756`, 1.4690060531470504`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.208673400536594, -0.42514662876555215`], 
            Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6513406860142938`, 1.171356274950616}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[7.4670073159977095`, 0.008350912786614366], 
            Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4902519675755006`, 1.1713562749506157`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.325414662407916, 0.008350912786611275], 
            Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4885844918762254`, 1.1716666265261573`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[5.439695778207934, 0.010820596844492497`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6530081617135672`, 1.171666626526157}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[8.581288431797727, 0.010820596844492403`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7293352827575448`, 1.1808376829517861`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[10.06681689057666, -0.018022230071644385`], 
            Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4122573708322497`, 1.1808376829517861`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[6.925224236986869, -0.01802223007164421], 
            Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0615084308009783`, 1.4830873839795504`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4357376210557065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.120937815790952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6040251997705024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[3.4357376210557065`, -1.120937815790952], 
            Complex[1.3742291902547281`, -2.6040251997705024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.080084222788814, 1.4830873839795506`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2941449674659141`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1209378157909546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.604025199770505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[0.2941449674659141, -1.1209378157909546`], 
            Complex[1.3742291902547281`, -2.604025199770505]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0458314299869196`, 1.4674977366426467`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.222336896739361, -0.41917722203755803`], 
            Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0957612236028735`, 1.4674977366426465`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[1.0807442431495686`, -0.4191772220375579], 
            Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4896184521947609`, 1.171431552707784}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.3130627762344576`, 0.00845680816400054], 
            Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6519742013950327`, 1.171431552707784}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[7.454655429824251, 0.008456808164000526], 
            Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6538157313980222`, 1.1717763432189274`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[8.600148900521386, 0.011138282794836918`], 
            Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4877769221917714`, 1.1717763432189274`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[5.458556246931596, 0.011138282794836883`], 
            Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4129329108411504`, 1.180703115797952}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[6.906093661793765, -0.01836202115462416], 
            Complex[8.319026572634915, -1.199065136952576]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7286597427486416`, 1.180703115797952}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[10.047686315383556`, -0.018362021154624195`], 
            Complex[8.319026572634915, -1.199065136952576]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0792305196094003`, 1.4825776739009553`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2895575630554191`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1294546532828313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.612032327183787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[0.2895575630554191, -1.1294546532828313`], 
            Complex[1.3687880826648193`, -2.612032327183787]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.062362133980393, 1.4825776739009564`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4311502166452144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.129454653282832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6120323271837886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[3.4311502166452144`, -1.129454653282832], 
            Complex[1.3687880826648213`, -2.6120323271837886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0959699203583582`, 1.4659895587415224`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[1.0941780694739518`, -0.41342498695323976`], 
            Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.045622733231434, 1.4659895587415228`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.2357707230637445`, -0.41342498695324215`], 
            Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.488982035096316, 1.1715074093596352`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.300966771833883, 0.008564247194411541], 
            Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6526106184934766`, 1.1715074093596352`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[7.442559425423676, 0.008564247194411552], 
            Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4869538129038884`, 1.171889504910906}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[5.47738980371477, 0.011475439606775242`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6546388406859052`, 1.171889504910906}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[8.618982457304563, 0.011475439606775252`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4136245435637642`, 1.1805649478407965`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[6.886999703988066, -0.01872048627707082], 
            Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7279681100260285`, 1.1805649478407965`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[10.02859235757786, -0.018720486277070698`], 
            Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.063214424411191, 1.4820807940932987`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.426741405743924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377551213057147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327329`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[3.426741405743924, -1.1377551213057147`], 
            Complex[1.3635269813327329`, -2.6198359153990136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0783782291786017`, 1.4820807940932992`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2851487521541328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1377551213057142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[0.2851487521541328, -1.1377551213057142`], 
            Complex[1.3635269813327346`, -2.6198359153990136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.096199423577162, 1.4644818254465939`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[1.107397162145414, -0.4078755867501416], 
            Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.04539323001263, 1.4644818254465939`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.248989815735208, -0.4078755867501412], 
            Complex[2.203596585722578, -1.872357412196735]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6532499804032557`, 1.171583852072019}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[7.430700722955541, 0.008673251522090992], 
            Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.488342673186538, 1.171583852072019}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.289108069365748, 0.008673251522090971], 
            Complex[5.777450742552286, -1.162910600549928]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6554784618891856`, 1.1720063782953083`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[8.637823823216573, 0.011834207760463409`], 
            Complex[6.982345361327388, -1.160172170534845]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.486114191700607, 1.1720063782953085`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[5.496231169626781, 0.011834207760463395`], 
            Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4143332237390713`, 1.1804229176332028`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[6.867906939037359, -0.019099823463292427`], 
            Complex[8.28224016277643, -1.199522741096495]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7272594298507222`, 1.1804229176332028`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[10.009499592627153`, -0.019099823463292497`], 
            Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0640651503319596`, 1.4815962968997258`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4224987798606765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6274485670330767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[3.4224987798606765`, -1.1458522701333511`], 
            Complex[1.3584336295287167`, -2.6274485670330767`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.077527503257833, 1.481596296899727}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2809061262708882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.627448567033079`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[0.2809061262708882, -1.1458522701333518`], 
            Complex[1.3584336295287214`, -2.627448567033079]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.045143400512621, 1.462974816264852}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.262007600278324, -0.4025161677361105], 
            Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.096449253077174, 1.4629748162648513`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[1.1204149466885311`, -0.40251616773611126`], 
            Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4877003234776143`, 1.171660887961159}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.277470052807503, 0.008783844556995735], 
            Complex[5.765170376285118, -1.162877043404163]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.653892330112179, 1.171660887961159}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[7.419062706397297, 0.008783844556995738], 
            Complex[5.765170376285118, -1.162877043404163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6563356763727834`, 1.1721272659455275`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[8.656707602013043, 0.012217067867222313`], 
            Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4852569772170092`, 1.1721272659455275`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[5.515114948423251, 0.012217067867222332`], 
            Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.415060016359264, 1.1802767274817774`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[6.8487801366438275`, -0.019502564592186727`], 
            Complex[8.263840153003091, -1.199779292073964]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7265326372305287`, 1.1802767274817771`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[9.990372790233621, -0.01950256459218661], 
            Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0649141757852982`, 1.4811237611032317`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.41841120976327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1537578719399622`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.634881633043194`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[3.41841120976327, -1.1537578719399622`], 
            Complex[1.3534970339779715`, -2.634881633043194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0766784778044955`, 1.4811237611032304`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2768185561734762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1537578719399602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6348816330431903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[0.2768185561734762, -1.1537578719399602`], 
            Complex[1.3534970339779717`, -2.6348816330431903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.044873698898493, 1.4614687868986669`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.274836204246599, -0.39733515240586165`], 
            Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0967189546913008`, 1.4614687868986669`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[1.1332435506568057`, -0.39733515240586337`], 
            Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6545377106113686`, 1.1717385241090856`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[7.4076304429802775`, 0.00889605134985899], 
            Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.487054942978425, 1.1717385241090856`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.266037789390484, 0.008896051349858974], 
            Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6572116919289983`, 1.1722525131521495`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[8.675668864524779, 0.012626914319474911`], 
            Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4843809616607944`, 1.1722525131521495`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[5.5340762109349875`, 0.012626914319474934`], 
            Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.725786539671919, 1.1801260366487187`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[9.971176318841339, -0.019931649951741043`], 
            Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4158061139178737`, 1.180126036648719}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[6.829583665251546, -0.019931649951741116`], 
            Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.06576137884017, 1.480662789532383}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4144686707126652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.348707291872495`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[3.4144686707126652`, -1.1614825918531306`], 
            Complex[1.348707291872495, -2.6421453813855136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0758312747496237`, 1.480662789532383}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2728760171228721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3487072918724958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[0.2728760171228721, -1.1614825918531306`], 
            Complex[1.3487072918724958`, -2.6421453813855136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.044584555407561, 1.459963971580155}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.287486632822467, -0.39232206847656975`], 
            Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0970080981822332`, 1.4599639715801547`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[1.1458939792326737`, -0.3923220684765709], 
            Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4864064885986414`, 1.1718167675768096`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.254797798340199, 0.009009898497034034], 
            Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6551861649911512`, 1.17181676757681}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[7.396390451929997, 0.009009898497033932], 
            Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.658107863949964, 1.1723825165049406`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[8.694743750598732, 0.013067149229433986`], 
            Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4834847896398293`, 1.1723825165049406`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[5.553151097008939, 0.013067149229433903`], 
            Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7250197961161677`, 1.1799704528032402`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[9.951873534557844, -0.020390522922278387`], 
            Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4165728574736258`, 1.1799704528032404`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[6.810280880968052, -0.020390522922278664`], 
            Complex[8.226853738441678, -1.200360975725519]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0666066500586178`, 1.4802130069664265`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.410662097155336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1690361304484036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6492491374148304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[3.410662097155336, -1.1690361304484036`], 
            Complex[1.3440554470967183`, -2.6492491374148304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0749860035311751`, 1.480213006966427}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2690694435655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1690361304484052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.649249137414832`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[0.2690694435655443, -1.1690361304484052`], 
            Complex[1.3440554470967194`, -2.649249137414832]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.097316275416021, 1.458460585107794}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[1.1583762613396105`, -0.38746740648134814`], 
            Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.044276378173772, 1.4584605851077943`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.299968914929404, -0.38746740648134725`], 
            Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4857549170635265`, 1.1718956254156432`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.243737858735289, 0.009125414068990397], 
            Complex[5.729492775798816, -1.162770211346653]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.655837736526267, 1.1718956254156434`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[7.3853305123250825`, 0.009125414068990404], 
            Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6590257214441, 1.1725177347818592`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[8.713970117564823, 0.013541803645186434`], 
            Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4825669321456934`, 1.1725177347818594`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[5.57237746397503, 0.013541803645186435`], 
            Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4173617625729185`, 1.1798095211614357`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[6.790833471518203, -0.020883251810279654`], 
            Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7242308910168733`, 1.1798095211614354`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[9.932426125107996, -0.020883251810279745`], 
            Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0741427624234956`, 1.4797740582922105`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.26539060743652637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1764273433249663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.339533369860022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[0.26539060743652637`, -1.1764273433249663`], 
            Complex[1.339533369860022, -2.656201401617177]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.067449891166297, 1.479774058292211}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4069832610263204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.176427343324966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3395333698600238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[3.4069832610263204`, -1.176427343324966], 
            Complex[1.3395333698600238`, -2.656201401617177]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0976430987532786`, 1.4569588246327918`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[1.1706995721155862`, -0.382762500281366], 
            Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.043949554836515, 1.4569588246327918`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.31229222570538, -0.3827625002813669], 
            Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4851001848374208`, 1.1719751046769844`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.232846848694921, 0.009242627557842213], 
            Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6564924687523725`, 1.1719751046769844`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[7.374439502284718, 0.00924262755784085], 
            Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4816256542869652`, 1.1726587029310958`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[5.591795614755318, 0.014055695951277704`], 
            Complex[7.073421269042283, -1.158603006979818]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6599669993028283`, 1.1726587029310958`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[8.733388268345113, 0.014055695951277626`], 
            Complex[7.073421269042284, -1.158603006979818]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.723418102154984, 1.1796427105293465`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[9.912793375391814, -0.02141468876524509], 
            Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4181745514348096`, 1.1796427105293468`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[6.771200721802021, -0.021414688765245018`], 
            Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.068291013894189, 1.4793456068744564`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4034246691397003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1836643421288453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.663009949003302`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[3.4034246691397003`, -1.1836643421288453`], 
            Complex[1.3351336552455113`, -2.663009949003302]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0733016396956048`, 1.4793456068744566`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2618320155499074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.183664342128846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455122`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6630099490033023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[0.2618320155499074, -1.183664342128846], 
            Complex[1.3351336552455122`, -2.6630099490033023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0979881996247098`, 1.455458871233648}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[1.1828723362728408`, -0.378199426130277], 
            Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0436044539650835`, 1.4554588712336483`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.324464989862636, -0.3781994261302779], 
            Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4844422480543258`, 1.1720552124208197`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.222114609872632, 0.009361569840391626], 
            Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6571504055354678`, 1.17205521242082}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[7.363707263462426, 0.009361569840391621], 
            Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4806589748563324`, 1.1728060502638156`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[5.611449146258794, 0.014614641743299664`], 
            Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.66093367873346, 1.1728060502638153`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[8.753041799848587, 0.014614641743299649`], 
            Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4190131933123733`, 1.1794693951321642`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[6.751338660172414, -0.021990680088691934`], 
            Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7225794602774194`, 1.1794693951321646`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[9.892931313762208, -0.021990680088691875`], 
            Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.069129938964966, 1.4789273331079273`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.399979476133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[3.399979476133, -1.1907545804380442`], 
            Complex[1.330849537168034, -2.6696819135459715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.072462714624827, 1.4789273331079291`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.258386822543207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[0.258386822543207, -1.1907545804380446`], 
            Complex[1.330849537168034, -2.6696819135459737`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0983512272638332`, 1.4539608913103004`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[1.1949023158791763`, -0.3737709168766501], 
            Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0432414263259595`, 1.4539608913103002`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.336494969468971, -0.3737709168766498], 
            Complex[2.293253543143011, -1.82773180818695]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4837810624542787`, 1.1721359557231514`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.211531832555506, 0.009482273153986658], 
            Complex[5.695312895009785, -1.162653682569165]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6578115911355147`, 1.1721359557231514`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[7.3531244861453, 0.009482273153988793], 
            Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.661928038507105, 1.1729605244765766`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[8.77297862441228, 0.015225736181981687`], 
            Complex[7.111050585905176, -1.157734788294595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4796646150826884`, 1.1729605244765768`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[5.631385970822487, 0.015225736181981623`], 
            Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7217126979120094`, 1.1792888306110796`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[9.872791686074075, -0.02261834895605743], 
            Complex[8.151078988162066, -1.201907179567137]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.419879955677785, 1.1792888306110798`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[6.731199032484283, -0.022618348956057268`], 
            Complex[8.151078988162068, -1.201907179567137]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0716260583874921`, 1.4785189331256299`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2550487565900203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1977049272038123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.676223860329442`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[0.2550487565900203, -1.1977049272038123`], 
            Complex[1.3266748149775125`, -2.676223860329442]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0699665952023, 1.4785189331256294`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.396641410179813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977049272038105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.67622386032944`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[3.396641410179813, -1.1977049272038105`], 
            Complex[1.3266748149775132`, -2.67622386032944]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0987318475746586`, 1.452465037823688}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[1.2067966853478913`, -0.369470288610321], 
            Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0428608060151343`, 1.4524650378236883`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.348389338937685, -0.36947028861032294`], 
            Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.483116583324458, 1.1722173416825046`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.201089957665183, 0.009604771083122505], 
            Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6584760702653347`, 1.1722173416825046`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[7.342682611254977, 0.009604771083122523], 
            Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.478639932846058, 1.173123023897275}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[5.651659582251507, 0.0158977403597609], 
            Complex[7.130299515097565, -1.157225283537514]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6629527207437356`, 1.1731230238972747`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[8.793252235841303, 0.01589774035976148], 
            Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7208151836379026`, 1.17910012179434}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[9.852320685804424, -0.02330648209651281], 
            Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.42077746995189, 1.1791001217943402`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[6.7107280322146305`, -0.02330648209651286], 
            Complex[8.13150550216652, -1.202406603890853]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.070791734844558, 1.4781201176416032`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.25181205566632714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[0.25181205566632714`, -1.204521729892243], 
            Complex[1.3226037905108852`, -2.682641847533846]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.070800918745235, 1.4781201176416028`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3934047092561204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[3.3934047092561204`, -1.204521729892243], 
            Complex[1.3226037905108854`, -2.682641847533846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0424629114739075`, 1.4509714514021208`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.3601547494422475`, -0.3652913776086266], 
            Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0991297421158872`, 1.4509714514021206`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[1.2185620958524552`, -0.36529137760862845`], 
            Complex[2.317691837968342, -1.816262829010749]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4824487654441583`, 1.1722993774256536`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.190781092718281, 0.009729098555121772], 
            Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6591438881456353`, 1.1722993774256536`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[7.332373746308075, 0.009729098555121761], 
            Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6640108165591583`, 1.173294641576374}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[8.813923320576674, 0.016641620135819556`], 
            Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4775818370306344`, 1.1732946415763739`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[5.6723306669868805`, 0.016641620135819466`], 
            Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4217088171019867`, 1.1789021786210783`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[6.689864686007544, -0.024066068896217683`], 
            Complex[8.11157350310953, -1.202968247517296]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7198838364878077`, 1.1789021786210783`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[9.831457339597339, -0.02406606889621767], 
            Complex[8.11157350310953, -1.202968247517296]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0716328523527796`, 1.4777306109104262`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.39026406618571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3186312138329304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.688941479956369`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[3.39026406618571, -1.2112108690459429`], 
            Complex[1.3186312138329304`, -2.688941479956369]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.069959801237014, 1.4777306109104273`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.248671412595918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.318631213832932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6889414799563705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[0.248671412595918, -1.2112108690459433`], 
            Complex[1.318631213832932, -2.6889414799563705`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0420480464034774`, 1.4494802613323103`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.3717973845316225`, -0.36122848586285683`], 
            Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0995446071863157`, 1.44948026133231}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[1.2302047309418311`, -0.3612284858628565], 
            Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6598150905568931`, 1.1723820701126724`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[7.322190592979878, 0.009855291843704485], 
            Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4817775630328995`, 1.1723820701126724`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.180597939390085, 0.00985529184370446], 
            Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4764866742464757`, 1.1734767268460082`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[5.693469206036438, 0.01747131387776226], 
            Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.665105979343317, 1.173476726846008}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[8.835061859626233, 0.017471313877762306`], 
            Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7189150127134505`, 1.1786936545956053`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[9.81013140250469, -0.02491106937082747], 
            Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4226776408763422`, 1.1786936545956055`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[6.668538748914897, -0.024911069370827682`], 
            Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0691303088034474`, 1.477350149788395}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24562192744249728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2177778056554163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6951279554438115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[0.24562192744249728`, -1.2177778056554163`], 
            Complex[1.3147522362459447`, -2.6951279554438115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0724623447863455`, 1.4773501497883945`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3872145810322905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2177778056554156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.69512795544381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[3.3872145810322905`, -1.2177778056554156`], 
            Complex[1.3147522362459452`, -2.69512795544381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.041616500591175, 1.4479915864500457`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.38332300838, -0.35727633379543705`], 
            Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.099976152998618, 1.4479915864500457`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[1.2417303547902065`, -0.3572763337954378], 
            Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4811029297010834`, 1.1724654269413926`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.170533730780807, 0.009983388579384763], 
            Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6604897238887093`, 1.1724654269413928`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[7.312126384370602, 0.009983388579384756], 
            Complex[5.651636660481892, -1.162482038362008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.475350076333024, 1.1736709733336637`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[5.715157284805061, 0.018404853311322064`], 
            Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6662425772567686`, 1.1736709733336637`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[8.856749938394854, 0.01840485331132207], 
            Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.423688300261557, 1.1784728587856867`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[6.646667892120967, -0.025859535214795407`], 
            Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7179043533282357`, 1.1784728587856865`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[9.78826054571076, -0.02585953521479562], 
            Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0683033033301512`, 1.476978482883704}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24265906608433005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2242276224707753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7012061053544794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[0.24265906608433005`, -1.2242276224707753`], 
            Complex[1.3109623694144812`, -2.7012061053544794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0732893502596412`, 1.4769784828837045`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3842517196741237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2242276224707729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.701206105354477`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[3.3842517196741237`, -1.2242276224707729`], 
            Complex[1.3109623694144825`, -2.701206105354477]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1004241029306554`, 1.4465055359431653`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[1.253144354246581, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.041168550659138, 1.4465055359431653`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.394737007836374, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4804248184026618`, 1.172549455151349}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.16058217684066, 0.010113427765967319`], 
            Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6611678351871315`, 1.1725494551513491`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[7.302174830430454, 0.010113427765967268`], 
            Complex[5.641006995243322, -1.162436027385382]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4741667509430407`, 1.1738795482784525`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[5.737492944039841, 0.019466046203823834`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.667425902646752, 1.1738795482784525`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[8.879085597629635, 0.019466046203823823`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4247460788635689`, 1.1782376265169778`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[6.624153849873985, -0.02693529265819097], 
            Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7168465747262254`, 1.1782376265169778`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[9.76574650346378, -0.02693529265819088], 
            Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0674788256425587`, 1.4766153697848625`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23977862401903308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2305650601795397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3072574496615919`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.707180429964402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[0.23977862401903308`, -1.2305650601795397`], 
            Complex[1.3072574496615919`, -2.707180429964402]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0741138279472335`, 1.4766153697848623`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.381371277608826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.230565060179537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.307257449661592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7071804299643993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[3.381371277608826, -1.230565060179537], 
            Complex[1.307257449661592, -2.7071804299643993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.100888192845177, 1.4450222100775578`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[1.2644517756377363`, -0.34968498034029766`], 
            Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.040704460744615, 1.445022210077558}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.40604442922753, -0.3496849803402998], 
            Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.479743181389402, 1.1726341620272602`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.1507374166916415`, 0.010245449802525813`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6618494722003916`, 1.1726341620272602`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[7.292330070281435, 0.010245449802525817`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4729301874376595`, 1.1741052886346302`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[5.76059559895939, 0.020687085496539206`], 
            Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6686624661521339`, 1.1741052886346302`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[8.902188252549184, 0.020687085496539234`], 
            Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.425857478981056, 1.177985123279133}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[6.600876998505349, -0.028170551750252844`], 
            Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7157351746087366`, 1.1779851232791327`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[9.742469652095146, -0.028170551750257837`], 
            Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0749357415443748`, 1.4762605803581343`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.378569348204635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.30363360666026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7130551295714294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[3.378569348204635, -1.2367945492132952`], 
            Complex[1.30363360666026, -2.7130551295714294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0666569120454183`, 1.4762605803581346`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23697669461484225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132955`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3036336066602605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.71305512957143`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[0.23697669461484225`, -1.2367945492132955`], 
            Complex[1.3036336066602605`, -2.71305512957143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0402244831197045`, 1.4435417008553584`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.417250010699276, -0.3460369658605059], 
            Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1013681704700888`, 1.4435417008553582`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[1.275657357109484, -0.34603696586050564`], 
            Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4790579701663649`, 1.172719554902103}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.140993976808082, 0.01037949651040012], 
            Complex[5.620051946974447, -1.162340058391703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6625346834234278`, 1.1727195549021028`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[7.282586630397876, 0.010379496510400103`], 
            Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4716322332556833`, 1.1743520096788433`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[5.78461388785291, 0.022112751073540098`], 
            Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.66996042033411, 1.1743520096788436`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[8.926206541442703, 0.02211275107353916], 
            Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4270306452077102`, 1.1777115361272346`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[6.5766885062096785`, -0.02961010826063084], 
            Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7145620083820834`, 1.1777115361272346`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[9.718281159799472, -0.029610108260631186`], 
            Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0757550588717337`, 1.4759138941061436`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3758422947494764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3000872358777424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7188341319212634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[3.3758422947494764`, -1.2429202378151198`], 
            Complex[1.3000872358777424`, -2.7188341319212634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0658375947180594`, 1.4759138941061443`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2342496411596838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.300087235877743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.718834131921264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[0.2342496411596838, -1.2429202378151196`], 
            Complex[1.300087235877743, -2.718834131921264]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1018637948326029`, 1.442064092613194}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[1.286765557155954, -0.34248200518323674`], 
            Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0397288587571896`, 1.4420640926131938`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.428358210745746, -0.34248200518323846`], 
            Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.478369135448276, 1.1728056411598093`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.131346734197311, 0.010515611164854463`], 
            Complex[5.609715869645587, -1.162290029994955]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6632235181415176`, 1.1728056411598096`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[7.272939387787106, 0.010515611164854442`], 
            Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6713301874647748`, 1.1746250124900501`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[8.95133006145241, 0.023807487220115792`], 
            Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4702624661250188`, 1.1746250124900501`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[5.809737407862617, 0.023807487220115758`], 
            Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4282759921950465`, 1.177411566209715}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[6.5513985958381715`, -0.03131842125415489], 
            Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7133166613947461`, 1.177411566209715}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[9.692991249427967, -0.0313184212541546], 
            Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0765717515196322`, 1.4755750995808241`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3731867257580617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2489460168942261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7245211164750502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[3.3731867257580617`, -1.2489460168942261`], 
            Complex[1.2966149742384296`, -2.7245211164750502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.065020902070162, 1.475575099580823}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23159407216826933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.248946016894224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.724521116475047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[0.23159407216826933`, -1.248946016894224], 
            Complex[1.2966149742384314`, -2.724521116475047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1023748357415464`, 1.4405894625672462`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[1.297780579877745, -0.33901638456087957`], 
            Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0392178178482463`, 1.4405894625672457`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.439373233467538, -0.3390163845608803], 
            Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4776766271164938`, 1.1728924282376276`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.121790883866403, 0.010653838531129443`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6639160264732995`, 1.1728924282376276`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[7.263383537456196, 0.010653838531129386`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.468807234137829, 1.174931963813554}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[5.836214897718771, 0.02586798658403449], 
            Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6727854194519636`, 1.1749319638135542`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[8.977807551308572, 0.025867986584037196`], 
            Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.711985489035876, 1.1770775489114365`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[9.6663510144975, -0.033392197154710215`], 
            Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4296071645539172`, 1.1770775489114365`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[6.5247583609077076`, -0.03339219715471046], 
            Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0642068590626783`, 1.475243993844854}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22900681949582008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2548755421085922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2932136785584984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7301195359534463`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[0.22900681949582008`, -1.2548755421085922`], 
            Complex[1.2932136785584984`, -2.7301195359534463`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0773857945271152`, 1.475243993844854}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.370599473085614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.254875542108594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.293213678558499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.730119535953448`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[3.370599473085614, -1.254875542108594], 
            Complex[1.293213678558499, -2.730119535953448]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1029010733128444`, 1.4391178813109795`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[1.3087063974214082`, -0.33563662492447366`], 
            Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0386915802769487`, 1.4391178813109793`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.450299051011202, -0.3356366249244736], 
            Complex[2.411607470734253, -1.774754506235453]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6646122594134538`, 1.1729799236281604`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[7.253914563567924, 0.010794224904694137`], 
            Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4769803941763398`, 1.1729799236281606`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.11232190997813, 0.010794224904694102`], 
            Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4672481393507069`, 1.1752845235948637`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[5.864383522178553, 0.028447097632704994`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6743445142390858`, 1.1752845235948637`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.005976175768346, 0.028447097632704935`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.431042553233109, 1.17669782632629}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[6.496430480050892, -0.03598429729320658], 
            Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7105501003566845`, 1.1766978263262902`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.638023133640685, -0.035984297293206895`], 
            Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0633954874979343`, 1.4749203819764722`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22648491887905142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464206`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.735632635522893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[0.22648491887905142`, -1.2607122535464206`], 
            Complex[1.2898804063769855`, -2.735632635522893]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.078197166091859, 1.4749203819764722`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.368077572468845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7356326355228924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[3.368077572468845, -1.2607122535464201`], 
            Complex[1.2898804063769864`, -2.7356326355228924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.038150356055889, 1.4376494132706217`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[4.461139423570387, -0.33233946229789096`], 
            Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1034422975339049`, 1.4376494132706221`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[1.319546769980594, -0.3323394622978922], 
            Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4762803847145511`, 1.1730681348811098`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[4.102935560194785, 0.010936818155564383`], 
            Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6653122688752415`, 1.1730681348811098`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[7.244528213784578, 0.010936818155564378`], 
            Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6760330782287778`, 1.1757016080477805`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.036310546964627, 0.031803157852373865`], 
            Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4655595753610149`, 1.1757016080477807`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[5.894717893374835, 0.031803157852374093`], 
            Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7089848956661684`, 1.176253484194999}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.607532848271008, -0.039353071187373335`], 
            Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4326077579236258`, 1.176253484194999}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[6.465940194681216, -0.03935307118737327], 
            Complex[7.898547952604841, -1.215606555382372]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.079005847307416, 1.4746040766131985`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365618246173949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7410634699329792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[3.365618246173949, -1.2664593933197807`], 
            Complex[1.2866123988665321`, -2.7410634699329792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0625868062823773`, 1.4746040766131983`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22402559258415555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.741063469932979`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[0.22402559258415555`, -1.2664593933197807`], 
            Complex[1.2866123988665328`, -2.741063469932979]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0375943457266397`, 1.4361841171228251`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.471897917269896, -0.3291218303014387], 
            Complex[2.434303571543256, -1.765305947424264]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.103998307863154, 1.436184117122825}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[1.3303052636801032`, -0.3291218303014382], 
            Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.475576545856664, 1.173157069604741}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.093627822786881, 0.011081667776607964`], 
            Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6660161077331286`, 1.173157069604741}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[7.235220476376673, 0.01108166777660797], 
            Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.677887917009857, 1.176216630951062}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.069506749440478, 0.03641303093548226], 
            Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4637047365799356`, 1.1762166309510627`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[5.927914095850698, 0.036413030935491676`], 
            Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.434339577767964, 1.1757111106138294`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[6.432591283080759, -0.043975393800888975`], 
            Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7072530758218287`, 1.1757111106138292`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.574183936670554, -0.04397539380088848], 
            Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.06178083166499, 1.4742948975305918`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22162623389028935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2721200213365198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.746414918867112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[0.22162623389028935`, -1.2721200213365198`], 
            Complex[1.2834070655552792`, -2.746414918867112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0798118219248036`, 1.474294897530593}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3632188874800852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2721200213365205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7464149188671136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[3.3632188874800852`, -1.2721200213365205`], 
            Complex[1.2834070655552816`, -2.7464149188671136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.037023740728319, 1.434722046178387}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.482577920205066, -0.3259808444790341], 
            Complex[2.445554179476747, -1.760702890657421]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.104568912861474, 1.4347220461783867`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[1.3409852666152733`, -0.32598084447903347`], 
            Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4748688237241292`, 1.1732467354670708`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.084394906148223, 0.011228824935798519`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6667238298656641`, 1.1732467354670708`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[7.225987559738016, 0.011228824935798491`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6799625405777951`, 1.1768957422124682`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.106617372354673, 0.04326772266645232], 
            Complex[7.426654831776879, -1.133628019546016]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4616301130119984`, 1.1768957422124684`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[5.96502471876488, 0.0432677226664523], 
            Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7053011370254079`, 1.1750045574754662`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.536923681000955, -0.05084228149321134], 
            Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4362915165643848`, 1.175004557475467}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[6.395331027411176, -0.05084228149319564], 
            Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0806150761357847`, 1.4739926712525988`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3608770467672016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2776970294771413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7516897007297403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[3.3608770467672016`, -1.2776970294771413`], 
            Complex[1.2802619706314171`, -2.7516897007297403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0609775774540093`, 1.473992671252599}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21928439317740805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2776970294771406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.75168970072974`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[0.21928439317740805`, -1.2776970294771406`], 
            Complex[1.2802619706314173`, -2.75168970072974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0364387237371213`, 1.4332632487354378`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.4931826568685596`, -0.32291378822242134`], 
            Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.105153929852673, 1.4332632487354375`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[1.351590003278767, -0.32291378822242217`], 
            Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6674354901987927`, 1.1733371401967956`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[7.216825874002135, 0.011378342532423407`], 
            Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4741571633910007`, 1.1733371401967956`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.075233220412342, 0.01137834253242333], 
            Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.682324489011321, 1.1778903728540753`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.149127159726488, 0.05476808187732223], 
            Complex[7.466802670715167, -1.123122290976753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4592681645784733`, 1.177890372854075}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.007534506136697, 0.054768081877322586`], 
            Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4385311084286383`, 1.1739823954882143`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.352674562767395, -0.062354593032590215`], 
            Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7030615451611553`, 1.173982395488215}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.494267216357189, -0.062354593032578], 
            Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0814155983755485`, 1.4736972306904863`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.358590419010691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.756890385061134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[3.358590419010691, -1.2831931543706478`], 
            Complex[1.2771748206351425`, -2.756890385061134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0601770552142444`, 1.473697230690487}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21699776542089913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7568903850611353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[0.21699776542089913`, -1.2831931543706483`], 
            Complex[1.2771748206351434`, -2.7568903850611353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1057531846105015`, 1.4318077684050947`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[1.362122547573207, -0.319918100098616], 
            Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0358394689792916`, 1.431807768405095}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.503715201163001, -0.3199181000986165], 
            Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.668151144749763, 1.1734282915839576`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[7.207732014499435, 0.011530275257279964`], 
            Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4734415088400306`, 1.1734282915839576`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.066139360909642, 0.01153027525727997], 
            Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6849389425874308`, 1.1795758928575122`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.197298230159177, 0.07734359441247762], 
            Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4566537110023619`, 1.179575892857512}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.055705576569384, 0.07734359441247692], 
            Complex[7.512359287571745, -1.102232298445035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.700569125694485, 1.1722692563349006`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.445952310414624, -0.08494182361234351], 
            Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4410235278953083`, 1.1722692563349015`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.304359656824848, -0.08494182361233121], 
            Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0822133791427744`, 1.4734084148076874`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3563568325133555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2886109889360127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.274143453370581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7620194037437003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[3.3563568325133555`, -1.2886109889360127`], 
            Complex[1.274143453370581, -2.7620194037437003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0593792744470185`, 1.4734084148076874`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21476417892356292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.288610988936014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2741434533705815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.762019403743701`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[0.21476417892356292`, -1.288610988936014], 
            Complex[1.2741434533705815`, -2.762019403743701]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1063665110700036`, 1.430355644412234}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[1.3725858345799593`, -0.31699136241415216`], 
            Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.035226142519789, 1.4303556444122343`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.514178488169753, -0.31699136241415254`], 
            Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4727218029180233`, 1.173520197480349}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.057110093241812, 0.011684679656931263`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6688708506717702`, 1.173520197480349}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[7.198702746831605, 0.011684679656931228`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4545182673906123`, 1.182328529672797}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.097972756057953, 0.11902724764148631`], 
            Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687074386199182, 1.1823285296727972`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.239565409647748, 0.11902724764149018`], 
            Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.443037254323002, 1.169488914167868}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.261951376465343, -0.12663696940989244`], 
            Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6985553992667917`, 1.1694889141678682`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.403544030055139, -0.12663696940988678`], 
            Complex[7.704988630788347, -1.296125883577755]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0585842427544951`, 1.4731260683081975`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21258158513908437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.293952992832856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[0.21258158513908437`, -1.293952992832856], 
            Complex[1.2711658278935793`, -2.7670790611410534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0830084108352986`, 1.4731260683081984`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.354174238728878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2939529928328564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[3.354174238728878, -1.2939529928328564`], 
            Complex[1.2711658278935796`, -2.7670790611410547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0345989025285505`, 1.428906911873736}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.524575324820607, -0.31413129087274355`], 
            Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1069937510612426`, 1.4289069118737354`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[1.382982671230815, -0.31413129087274266`], 
            Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4719979872902957`, 1.173612865799659}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.04814233978115, 0.011841614202115778`], 
            Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6695946662994976`, 1.1736128657996592`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[7.189734993370944, 0.011841614202115805`], 
            Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4535434455400562`, 1.1852528928822323`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.120724694194671, 0.16611165996512534`], 
            Complex[7.574268139734727, -1.019141232917107]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6880492080497373`, 1.1852528928822323`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.262317347784464, 0.16611165996512323`], 
            Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6977019830130229`, 1.166536760948593}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.380653624650824, -0.17373265713467972`], 
            Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4438906705767707`, 1.166536760948593}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.239060971061035, -0.17373265713468317`], 
            Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0838006875998256`, 1.4728500413464258`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.352040703050758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[3.352040703050758, -1.2992215019455444`], 
            Complex[1.2682400154509323`, -2.7720715432919705`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0577919659899675`, 1.4728500413464263`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21044804946096587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509332`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[0.21044804946096587`, -1.2992215019455449`], 
            Complex[1.2682400154509332`, -2.7720715432919714`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1076347540637197`, 1.42746160205629}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[1.3933157460094145`, -0.3113357252023996], 
            Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.033957899526073, 1.4274616020562902`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.534908399599208, -0.3113357252023988], 
            Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6703226511956735`, 1.1737063045173513`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[7.180825821018505, 0.012001139360437759`], 
            Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4712700023941192`, 1.1737063045173515`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.039233167428713, 0.012001139360437396`], 
            Complex[5.510503169822832, -1.161705165156914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4531664322147952`, 1.1877411805488003`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.132202365530885, 0.2069539217818524], 
            Complex[7.58536879774568, -0.980787258766948]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.688426221374999, 1.1877411805488003`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.27379501912068, 0.20695392178184982`], 
            Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4441465847399895`, 1.1640206001025495`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.22744737065107, -0.21458598503237494`], 
            Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6974460688498072`, 1.16402060010255}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.369040024240906, -0.21458598503237647`], 
            Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0845902051942957`, 1.472580189256611}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3499543964575493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3044187370084819`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[3.3499543964575493`, -1.3044187370084819`], 
            Complex[1.2653641912632538`, -2.776998926265093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0570024483954983`, 1.472580189256612}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20836174286775633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.304418737008481`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[0.20836174286775633`, -1.304418737008481], 
            Complex[1.2653641912632545`, -2.776998926265093]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1082893769799231`, 1.426019742615635}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[1.4035876377924137`, -0.3086026206444544], 
            Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0333032766098698`, 1.426019742615633}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.545180291382208, -0.3086026206444535], 
            Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.671054866198798, 1.1738005216702665`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[7.171972430077165, 0.012163317673485156`], 
            Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4705377873909955`, 1.1738005216702667`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.030379776487371, 0.012163317673485264`], 
            Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6885796331805099`, 1.1898637733564665`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.280570529089989, 0.24191392575349288`], 
            Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.453013020409282, 1.1898637733564668`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.138977875500199, 0.24191392575349213`], 
            Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.444179198841299, 1.1618700523819143`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.22053837960052, -0.24955685318475593`], 
            Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6974134547484927`, 1.1618700523819145`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.362131033190314, -0.2495568531847539], 
            Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0562156927281066`, 1.4723163723001442`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20632093432967819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[0.20632093432967819`, -1.3095468114663624`], 
            Complex[1.2625366270577847`, -2.7818631837665064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.085376960861686, 1.4723163723001438`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.347913587919471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577851`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665047`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[3.347913587919471, -1.3095468114663606`], 
            Complex[1.2625366270577851`, -2.7818631837665047`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1089574839266938`, 1.4245813578188897`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[1.4138008239261344`, -0.3059300402110024], 
            Complex[2.522758307852828, -1.730511398029892]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.032635169663099, 1.4245813578188886`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.555393477515928, -0.3059300402110033], 
            Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.469801280117634, 1.1738955253559455`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.021579490524692, 0.012328213838552492`], 
            Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6717913734721597`, 1.173895525355946}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[7.163172144114486, 0.012328213838552503`], 
            Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6886370363669874`, 1.191728690498506}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.285085225476458, 0.27256109297706776`], 
            Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.452955617222807, 1.191728690498506}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.143492571886664, 0.27256109297706693`], 
            Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.697476552618887, 1.1599770999800387`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.357485218342608, -0.2802146897125705], 
            Complex[7.660008665723722, -1.440191789692609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.444116100970904, 1.1599770999800387`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.215892564752824, -0.2802146897125671], 
            Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.086160953214163, 1.472058455429283}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345916637483683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.314607738651282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.786666194080565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[3.345916637483683, -1.314607738651282], 
            Complex[1.2597556842695194`, -2.786666194080565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.05543170037563, 1.4720584554292833`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20432398389389064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3146077386512802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7866661940805635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[0.20432398389389064`, -1.3146077386512802`], 
            Complex[1.2597556842695206`, -2.7866661940805635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.109638946043191, 1.4231464687514912`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[1.4239576876222573`, -0.3033161476291157], 
            Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0319537075466023`, 1.4231464687514912`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[4.565550341212051, -0.3033161476291155], 
            Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4690604170355042`, 1.1739913237316546`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[4.012829747116558, 0.012495894795164358`], 
            Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6725322365542885`, 1.1739913237316546`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[7.154422400706351, 0.012495894795164308`], 
            Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4529454812008733`, 1.1934063028976165`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.146749395916181, 0.30000093008350615`], 
            Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6886471723889194`, 1.1934063028976165`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.288342049505975, 0.3000009300835058], 
            Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4440060279305913`, 1.1582713733139198`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.212506903993471, -0.30766500790256135`], 
            Complex[7.656512931924062, -1.465936381216481]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6975866256592023`, 1.1582713733139203`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.35409955758327, -0.30766500790255313`], 
            Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0546504714631983`, 1.4718063080659307`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2023693363760805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3196034383483597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.257019807839279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[0.2023693363760805, -1.3196034383483597`], 
            Complex[1.257019807839279, -2.7914097464142906`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0869421821265948`, 1.4718063080659305`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.343961989965874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.31960343834836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2570198078392791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[3.343961989965874, -1.31960343834836], 
            Complex[1.2570198078392791`, -2.7914097464142906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1103336413144058`, 1.4217150935100624`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[1.434060524745711, -0.30075920090048514`], 
            Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.031259012275387, 1.421715093510062}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.5756531783355054`, -0.30075920090048514`], 
            Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4683151331788349`, 1.1740879250130971`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.004128089376173, 0.012666429816627254`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6732775204109578`, 1.1740879250130971`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[7.145720742965965, 0.012666429816627278`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4529608296272483`, 1.1949415431340542`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.149229270200796, 0.3249638924276399], 
            Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6886318239625437`, 1.1949415431340542`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.290821923790588, 0.32496389242763857`], 
            Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6977218956560869`, 1.1567079410984846`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.351493051581292, -0.33263826942312025`], 
            Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4438707579337056`, 1.1567079410984842`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.209900397991501, -0.3326382694231228], 
            Complex[7.653771155925207, -1.489346210521607]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0877206486385878`, 1.4715598038942364`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.342048169184744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.342048169184744, -1.3245357428128088`], 
            Complex[1.2543275205461564`, -2.796095546707045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0538720049512058`, 1.4715598038942368`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20045551559495106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707046`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[0.20045551559495106`, -1.3245357428128093`], 
            Complex[1.2543275205461566`, -2.796095546707046]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0305511991805147`, 1.4202872473824493`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[4.585704203648775, -0.2982575464138705], 
            Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1110414544092788`, 1.4202872473824493`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[1.4441115500589816`, -0.29825754641387064`], 
            Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4675653621009008`, 1.1741853374728037`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.995472158184808, 0.012839890606854708`], 
            Complex[5.463037520285709, -1.161345446865949]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6740272914888925`, 1.1741853374728037`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[7.137064811774602, 0.012839890606854724`], 
            Complex[5.463037520285709, -1.161345446865949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.452990707859918, 1.1963644144601782`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.151192034362995, 0.34794816918875576`], 
            Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6886019457298762`, 1.1963644144601784`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.292784687952791, 0.34794816918876], 
            Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.697871412328034, 1.155256801334281}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.349405787878045, -0.35563266944840766`], 
            Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4437212412617586`, 1.1552568013342803`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.207813134288261, -0.3556326694484139], 
            Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.088496354864255, 1.4713188206659515`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.340173772683676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3294064022937957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597475`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.340173772683676, -1.3294064022937957`], 
            Complex[1.2516774178194212`, -2.8007252229597475`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0530962987255392`, 1.4713188206659513`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1985811190938835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.329406402293795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[0.1985811190938835, -1.329406402293795], 
            Complex[1.2516774178194228`, -2.8007252229597466`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1117622765325776`, 1.4188629430160065`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[1.454112902979397, -0.29580961355530405`], 
            Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.029830377057215, 1.4188629430160065`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[4.59570555656919, -0.2958096135553045], 
            Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6747816177712969`, 1.174283569438169}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[7.128452338640535, 0.013016351402742217`], 
            Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4668110358184965`, 1.1742835694381693`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.986859685050743, 0.013016351402742245`], 
            Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6885635388702838`, 1.1976959087554475`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.294383744285957, 0.36930769700429716`], 
            Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.453029114719509, 1.1976959087554473`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.152791090696166, 0.3693076970042951], 
            Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.698029178720739, 1.1538969633545817`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.347684294964536, -0.37700215031345224`], 
            Complex[7.649655116243796, -1.530899113668034]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4435634748690542`, 1.1538969633545815`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.2060916413747425`, -0.3770021503134528], 
            Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.089269303909028, 1.4710832400175344`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.338337466890455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.338337466890455, -1.3342170901139807`], 
            Complex[1.2490681629814273`, -2.805300330131515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0523233496807658`, 1.4710832400175349`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19674481330066165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[0.19674481330066165`, -1.3342170901139803`], 
            Complex[1.2490681629814275`, -2.805300330131515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0290966482999746`, 1.41744219057514}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[4.605659306489133, -0.2934139097675642], 
            Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1124960052898187`, 1.41744219057514}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[1.4640666528993398`, -0.29341390976756415`], 
            Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.466052084754429, 1.1743826292891217`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.9782884855315257`, 0.013195889082391367`], 
            Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6755405688353637`, 1.1743826292891217`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[7.119881139121318, 0.01319588908239133], 
            Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6885201041356674`, 1.1989513125919395`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.29571595421648, 0.3893033507690842], 
            Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4530725494541268`, 1.1989513125919395`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.154123300626686, 0.38930335076908473`], 
            Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.69819169817842, 1.1526131417618155`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.346231645579115, -0.3970075923331433], 
            Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4434009554113743`, 1.1526131417618155`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.204638991989324, -0.3970075923331428], 
            Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0515531537968965`, 1.4708529472981153`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19494532908188417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3389694073479312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2464984828787806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.809822354646047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[0.19494532908188417`, -1.3389694073479312`], 
            Complex[1.2464984828787806`, -2.809822354646047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.090039499792896, 1.4708529472981149`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.336537982671677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33896940734793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.246498482878781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.809822354646045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.336537982671677, -1.33896940734793], 
            Complex[1.246498482878781, -2.809822354646045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0283501090252565`, 1.4160249978890114`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[4.615567457703371, -0.2910690160160602], 
            Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1132425445645366`, 1.4160249978890105`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[1.4739748041135785`, -0.29106901601605945`], 
            Complex[2.587217348678115, -1.70709401390507]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4652884376779056`, 1.1744825254553934`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.9697564531622382`, 0.01337858327951261], 
            Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.676304215911888, 1.1744825254553937`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[7.111349106752032, 0.013378583279512458`], 
            Complex[5.435044890840143, -1.161103942175881]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4531188721094161`, 1.20014213290074}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.155253112689077, 0.4081334915298177], 
            Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6884737814803772`, 1.2001421329007407`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.296845766278874, 0.4081334915298239], 
            Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.698356834719948, 1.1513938307630045`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.344983328511988, -0.41584736171471265`], 
            Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4432358188698453`, 1.151393830763004}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.203390674922197, -0.41584736171471254`], 
            Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0507857062102843`, 1.4706278314075087`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19318145765365854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3436648871377261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.243967163863943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[0.19318145765365854`, -1.3436648871377261`], 
            Complex[1.243967163863943, -2.814292718545235]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0908069473795083`, 1.470627831407509}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.334774111243452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.343664887137726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2439671638639436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.334774111243452, -1.343664887137726], 
            Complex[1.2439671638639436`, -2.814292718545235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.027590849182423, 1.4146113705902201`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[4.62543195398277, -0.2887735826232172], 
            Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.11400180440737, 1.4146113705902197`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[1.483839300392978, -0.2887735826232169], 
            Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6770726319471416`, 1.174583266413371}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[7.102854207428718, 0.013564516504362785`], 
            Complex[5.425781575481577, -1.161018749909008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4645200216426517`, 1.1745832664133713`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.961261553838926, 0.013564516504362838`], 
            Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6884259255350798`, 1.2012772723139347`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.297817893725249, 0.42595292805234636`], 
            Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.453166728054712, 1.2012772723139358`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.156225240135477, 0.4259529280523631], 
            Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6985232375706762`, 1.1502301288294823`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.343894570793292, -0.4336762721416326], 
            Complex[7.645371333222616, -1.583906400971115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4430694160191173`, 1.150230128829482}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.202301917203499, -0.4336762721416338], 
            Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.091571652310636, 1.4704077846435297`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.333044700404312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323322`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.333044700404312, -1.348304998679792], 
            Complex[1.2414730480936764`, -2.818712783323322]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.050021001279157, 1.47040778464353}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19145204681451947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323323`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[0.19145204681451947`, -1.348304998679793], 
            Complex[1.2414730480936766`, -2.818712783323323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0268189526533744`, 1.4132013122452378`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[4.635254682829313, -0.286526325437767], 
            Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1147737009364185`, 1.413201312245238}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[1.4936620292395204`, -0.28652632543776696`], 
            Complex[2.608435730175939, -1.699727637683005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4637467619226254`, 1.174684860682482}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.952801820612012, 0.013753774271608805`], 
            Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6778458916671681`, 1.174684860682482}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[7.094394474201807, 0.013753774271608687`], 
            Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.688377416105138, 1.2023637780263299`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.298664434058157, 0.44288515307919907`], 
            Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4532152374846554`, 1.2023637780263299`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.1570717804683675`, 0.44288515307919946`], 
            Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4429026229204043`, 1.1491149898367783`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.201340564384264, -0.4506178210463805], 
            Complex[7.644243187304668, -1.599732810883159]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6986900306693893`, 1.1491149898367785`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.342933217974057, -0.45061782104638065`], 
            Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0492590326442481`, 1.4701927025579433`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18975599747025035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.352891150913283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[0.18975599747025035`, -1.352891150913283], 
            Complex[1.2390150301144984`, -2.8230838534712266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.092333620945545, 1.4701927025579438`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.331348651060044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3528911509132835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.331348651060044, -1.3528911509132835`], 
            Complex[1.2390150301144984`, -2.8230838534712275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1155581562484471`, 1.4117948244772747`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[1.503444825853813, -0.28432602230905957`], 
            Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.026034497341346, 1.4117948244772744`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[4.645037479443608, -0.2843260223090588], 
            Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4629685819451483`, 1.1747873168210954`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.9443753488495013`, 0.01394644523553293], 
            Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6786240716446452`, 1.1747873168210954`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[7.085968002439294, 0.013946445235532949`], 
            Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6883288349277574`, 1.2034073372264218`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.299409090344204, 0.45903052180506093`], 
            Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4532638186620361`, 1.203407337226422}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.15781643675441, 0.45903052180506065`], 
            Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6988566359161346`, 1.1480427276351441`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.342075512640728, -0.4667723681000823], 
            Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4427360176736588`, 1.1480427276351441`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.2004828590509335`, -0.46677236810008377`], 
            Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.093092860304868, 1.4699824838204374`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3296849140134457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3574246959370493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8274071797574867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.3296849140134457`, -1.3574246959370493`], 
            Complex[1.2365920537085775`, -2.8274071797574867`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0484997932849258`, 1.4699824838204374`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18809226042365237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3574246959370482`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.827407179757486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[0.18809226042365237`, -1.3574246959370482`], 
            Complex[1.2365920537085782`, -2.827407179757486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1163550983405515`, 1.4103919070822166`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[1.513189476842979, -0.2821715098398555], 
            Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0252375552492414`, 1.4103919070822162`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[4.654782130432774, -0.2821715098398547], 
            Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6794072503684923`, 1.1748906434218875`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[7.077572945323753, 0.014142621333044114`], 
            Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4621854032213013`, 1.1748906434218873`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.9359802917339604`, 0.01414262133304412], 
            Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6882805708297839`, 1.2044126157251178`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.300069789499112, 0.47447188989313444`], 
            Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4533120827600097`, 1.2044126157251178`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.15847713590932, 0.4744718898931343], 
            Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4425699855706464`, 1.1470086774222505`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.199710822382092, -0.4822227732417416], 
            Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.699022668019147, 1.1470086774222505`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.341303475971888, -0.4822227732417421], 
            Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0938493780185983`, 1.4697770300900472`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.328052486994904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.36190693217938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.234203108976306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.831683962269427`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.328052486994904, -1.36190693217938], 
            Complex[1.234203108976306, -2.831683962269427]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0477432755711948`, 1.469777030090047}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1864598334051111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3619069321793806`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2342031089763061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8316839622694276`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[0.1864598334051111, -1.3619069321793806`], 
            Complex[1.2342031089763061`, -2.8316839622694276`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0244281925478416`, 1.4089925581382403`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[4.664490377283739, -0.28006168039394375`], 
            Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.117164461041952, 1.4089925581382405`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[1.5228977236939458`, -0.280061680393945], 
            Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4613971452733998`, 1.174994849106633}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.927614856061183, 0.014342397934981635`], 
            Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6801955083163929`, 1.1749948491066329`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[7.069207509650976, 0.014342397934981436`], 
            Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4533597689593478`, 1.2053834960418555`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.1590677155468105`, 0.48927860682774], 
            Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6882328846304457`, 1.2053834960418555`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.300660369136605, 0.4892786068277399], 
            Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6991878695965157`, 1.1460089576583916`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.340603220742913, -0.497038390042908], 
            Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.442404783993277, 1.1460089576583914`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.199010567153125, -0.49703839004290984`], 
            Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0469894713119132`, 1.4695762458935284`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18485775832244397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[0.18485775832244397`, -1.3663391073422058`], 
            Complex[1.2318472296343572`, -2.8359153532357344`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0946031822778806`, 1.4695762458935284`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.326450411912238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.326450411912238, -1.3663391073422075`], 
            Complex[1.2318472296343572`, -2.8359153532357357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1179861839556284`, 1.4075967741096316`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[1.5325712660346489`, -0.2779954793374565], 
            Complex[2.650557449990277, -1.685592253447088]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.023606469634165, 1.4075967741096314`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[4.674163919624442, -0.2779954793374564], 
            Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4606037255593733`, 1.1750999425203748`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.9192772983115907`, 0.014545874006250778`], 
            Complex[5.379881023870964, -1.160554068514124]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6809889280304193`, 1.1750999425203748`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[7.060869951901384, 0.014545874006250832`], 
            Complex[5.379881023870965, -1.160554068514124]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4534067031313302`, 1.206323248968059}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.159599046539053, 0.5035094122855176], 
            Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6881859504584624`, 1.206323248968059}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.301191700128847, 0.503509412285517], 
            Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6993520698632367`, 1.145040298504278}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.339963828630122, -0.5112779620899647], 
            Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4422405837265568`, 1.145040298504278}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.198371175040328, -0.5112779620899686], 
            Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0462383717995123`, 1.4693800385102087`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18328511871069184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391664`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[0.18328511871069184`, -1.3707224211391664`], 
            Complex[1.2295234905102042`, -2.8401024596493754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0953542817902804`, 1.469380038510208}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.324877772300485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.324877772300485, -1.3707224211391649`], 
            Complex[1.2295234905102046`, -2.8401024596493727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1188202124095872`, 1.4062045499453315`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[1.5422117647034572`, -0.2759719024950626], 
            Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0227724411802064`, 1.4062045499453322`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[4.683804418293251, -0.2759719024950625], 
            Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6817875941959524`, 1.1752059323249153`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[7.052558574558201, 0.014753152275367028`], 
            Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.459805059393841, 1.1752059323249158`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.910965920968408, 0.014753152275367222`], 
            Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6881398827557619`, 1.2072346598860024`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.301672454837956, 0.5172145811965813], 
            Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4534527708340308`, 1.2072346598860018`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.160079801248174, 0.5172145811965714], 
            Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.442077495958373, 1.1440999155033493`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.197783928263984, -0.5249917680556042], 
            Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6995151576314196`, 1.1440999155033489`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.339376581853779, -0.5249917680556035], 
            Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0961026857382725`, 1.46918831786287}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3233336909542834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3750580278450637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.3233336909542834`, -1.3750580278450637`], 
            Complex[1.2272310052160105`, -2.8442463457079334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0454899678515204`, 1.4691883178628702`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18174103736449077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3750580278450635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[0.18174103736449077`, -1.3750580278450635`], 
            Complex[1.2272310052160111`, -2.8442463457079334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0219261561722446`, 1.4048158791726866`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[4.693413498234962, -0.2739899938041945], 
            Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.119666497417548, 1.4048158791726855`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[1.5518208446451707`, -0.27398999380419353`], 
            Complex[2.671487342062719, -1.678805872976879]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.459001059865691, 1.1753128271915805`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.9026790690591686`, 0.014964339414034983`], 
            Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6825915937241016`, 1.1753128271915805`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[7.044271722648962, 0.014964339414035013`], 
            Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4534978992617913`, 1.2081201235569359`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.160516992248921, 0.5304375419992584], 
            Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6880947543280014`, 1.2081201235569357`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.302109645838716, 0.5304375419992581], 
            Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4419155903263268`, 1.1431854147947558`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.197241770749233, -0.538223239963063], 
            Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6996770632634668`, 1.1431854147947558`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.338834424339028, -0.5382232399630629], 
            Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0447442498491215`, 1.469000996414286}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18022467413745052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.224968923986572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8483480350867416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[0.18022467413745052`, -1.3793470386724553`], 
            Complex[1.224968923986572, -2.8483480350867416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0968484037406716`, 1.469000996414286}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.321817327727244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2249689239865722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8483480350867407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.321817327727244, -1.3793470386724547`], 
            Complex[1.2249689239865722`, -2.8483480350867407`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1205249956489252`, 1.4034307539868358`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[1.5614000976502447`, -0.27204884315225314`], 
            Complex[2.68192509329917, -1.675479597139089]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0210676579408684`, 1.403430753986836}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[4.702992751240038, -0.27204884315225375`], 
            Complex[2.68192509329917, -1.67547959713909]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{1.6834010158378467`, 1.1754206357931765`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[7.036007780489124, 0.015179546227436098`], 
            Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.458191637751946, 1.175420635793177}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.894415126899331, 0.015179546227436329`], 
            Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6880506086458187`, 1.2089817164561358`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.302509011886752, 0.5432161176861714], 
            Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4535420449439749`, 1.2089817164561358`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.160916358296958, 0.5432161176861712], 
            Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4417549072154803`, 1.142294720779357}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.1967389220498434`, -0.5510102042411117], 
            Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.699837746374314, 1.1422947207793566`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.338331575639637, -0.5510102042411122], 
            Complex[7.638493829265324, -1.693304925020469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0440012077729932`, 1.4688179890690345`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17873522389447033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3835905239895683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[0.17873522389447033`, -1.3835905239895683`], 
            Complex[1.2227364316674634`, -2.8524085130586028`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0975914458167986`, 1.4688179890690338`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3203278774842637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.383590523989566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.3203278774842637`, -1.383590523989566], 
            Complex[1.2227364316674654`, -2.8524085130586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.020196984181804, 1.4020491653361915`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[4.712543738542191, -0.2701475843833519], 
            Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1213956694079894`, 1.4020491653361915`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[1.5709510849523987`, -0.27014758438335246`], 
            Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4573767014276684`, 1.1755293667950935`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.8861725150187785`, 0.015398887855965335`], 
            Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6842159521621252`, 1.1755293667950935`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[7.027765168608572, 0.01539888785596537], 
            Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6880074683685526`, 1.209821252808463}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.302875299750397, 0.5555834916479572], 
            Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.45358518522124, 1.2098212528084629`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.161282646160605, 0.5555834916479535], 
            Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4415954662787764`, 1.1414260200851492`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.1962705954158785`, -0.5633858475760002], 
            Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.699997187311018, 1.1414260200851496`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.337863249005673, -0.5633858475760003], 
            Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0432608312366285`, 1.468639213080251}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17727191460430375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3877895153924003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2205327458409323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8564287284726513`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[0.17727191460430375`, -1.3877895153924003`], 
            Complex[1.2205327458409323`, -2.8564287284726513`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0983318223531637`, 1.468639213080251}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3188645681940967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3877895153923996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.220532745840933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8564287284726504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.3188645681940967`, -1.3877895153923996`], 
            Complex[1.220532745840933, -2.8564287284726504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1222784866221516`, 1.4006711030043686`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[1.5804753396984255`, -0.26828539346253044`], 
            Complex[2.702753826320577, -1.668956496466899]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0193141669676415`, 1.400671103004369}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[4.722067993288219, -0.2682853934625311], 
            Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6850364968181137`, 1.1756390288454501`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[7.019542340843495, 0.015622483989198223`], 
            Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4565561567716798`, 1.1756390288454504`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.8779496872537016`, 0.015622483989198204`], 
            Complex[5.334505844025381, -1.160016544856252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4536273122543482`, 1.2106403285857692`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.1616198199314836`, 0.5675689693259762], 
            Complex[7.615247132185832, -0.643071359259793]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6879653413354445`, 1.2106403285857694`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.303212473521276, 0.5675689693259758], 
            Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4414372724251217`, 1.1405777175707952`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.195832788389601, -0.5753794785718529], 
            Complex[7.637270060814722, -1.715957196142648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.700155381164671, 1.1405777175707952`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.337425441979393, -0.5753794785718535], 
            Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.099069544072469, 1.4684645879610192`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3174266591507107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3919450076426472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2183571150782422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.3174266591507107`, -1.3919450076426472`], 
            Complex[1.2183571150782422`, -2.860409595603666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0425231095173253`, 1.4684645879610199`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1758340055609178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.391945007642646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.218357115078243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[0.1758340055609178, -1.391945007642646], 
            Complex[1.218357115078243, -2.860409595603666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0184192327504475`, 1.39929655568899}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[4.731567022892644, -0.26646148678673676`], 
            Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1231734208393456`, 1.3992965556889891`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[1.5899743693028523`, -0.26646148678673565`], 
            Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6858627465219707`, 1.1757496305642219`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[7.011337781577717, 0.015850459092959842`], 
            Complex[5.325475035055747, -1.159899171471262]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455729907067823, 1.1757496305642217`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.8697451279879247`, 0.015850459092959818`], 
            Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4536684287612416`, 1.211440356474314}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.161931218858729, 0.5791985860418423], 
            Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687924224828551, 1.211440356474314}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.303523872448524, 0.5791985860418385], 
            Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7003123335104553`, 1.1397484013590917`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.337014778473906, -0.5870171355873209], 
            Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.441280320079339, 1.139748401359092}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.1954221248841135`, -0.5870171355873215], 
            Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.0998046220047555`, 1.4682940354000973`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3160134393130587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.396057960481959`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.864351995882056`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.3160134393130587`, -1.396057960481959], 
            Complex[1.2162088173083034`, -2.864351995882056]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0417880315850379`, 1.4682940354000973`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17442078572326566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3960579604819585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8643519958820556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[0.17442078572326566`, -1.3960579604819585`], 
            Complex[1.2162088173083037`, -2.8643519958820556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1240804512345126`, 1.3979255110777091`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[1.5994496576990789`, -0.26467511963294016`], 
            Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0175122023552796`, 1.3979255110777091`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[4.741042311288872, -0.26467511963294066`], 
            Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866948006883018`, 1.1758611805312391`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[7.003150003118844, 0.016082942650415873`], 
            Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548978529014918`, 1.1758611805312391`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.861557349529051, 0.01608294265041592], 
            Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6878841086374778`, 1.2122225939728504`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.303812331602318, 0.5904955973399487], 
            Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4537085449523155`, 1.2122225939728504`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.162219678012526, 0.5904955973399484], 
            Complex[7.615928222964841, -0.621726996632902]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.700468057345703, 1.1389368147397192`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.336628388028364, -0.5983220770848241], 
            Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4411245962440906`, 1.1389368147397192`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.195035734438572, -0.5983220770848242], 
            Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.041055586129231, 1.4681274791817336`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17303157216407558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4001293003321469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2140871582933066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[0.17303157216407558`, -1.4001293003321469`], 
            Complex[1.2140871582933066`, -2.8682567795138803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1005370674605626`, 1.468127479181735}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3146242257538696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4001293003321456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.214087158293307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.3146242257538696`, -1.4001293003321456`], 
            Complex[1.214087158293307, -2.8682567795138803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.124999562625254, 1.39655795592182}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[1.6089026674977167`, -0.2629255847348713], 
            Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0165930909645393`, 1.39655795592182}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[4.75049532108751, -0.26292558473487176`], 
            Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6875327615386626`, 1.1759736872729671`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.994977543195845, 0.016320069418202337`], 
            Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4540598920511307`, 1.1759736872729671`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.8533848896060525`, 0.0163200694182023], 
            Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4537476763080104`, 1.2129881661979554`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.162487621687207, 0.6014808784641323], 
            Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6878449772817823`, 1.2129881661979556`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.304080275277004, 0.6014808784641332], 
            Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.700622570870154, 1.138141833364706}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.336263812328982, -0.609315181113391], 
            Complex[7.635641241458829, -1.747457014478097]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4409700827196394`, 1.1381418333647062`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.194671158739189, -0.6093151811133911], 
            Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1012668920059014`, 1.4679648451093048`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.313258362208889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.313258362208889, -1.4041599218900036`], 
            Complex[1.2119914702029877`, -2.8721247669993084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0403257615838926`, 1.4679648451093048`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17166570861909555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029881`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[0.17166570861909555`, -1.4041599218900036`], 
            Complex[1.2119914702029881`, -2.8721247669993084`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1259307454967142`, 1.3951938761077975`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[1.6183348420620054`, -0.2612122109807513], 
            Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.015661908093079, 1.395193876107797}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[4.7599274956518, -0.2612122109807508], 
            Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4532159193743954`, 1.176087159247943}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.8452263089759486`, 0.01656197969868379], 
            Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.688376734215398, 1.176087159247943}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.986818962565743, 0.016561979698683896`], 
            Complex[5.298442228350345, -1.159525179549259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.453785841955973, 1.2137380845635795`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.162737136528052, 0.6121732527479822], 
            Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6878068116338214`, 1.2137380845635795`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.304329790117846, 0.612173252747982], 
            Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4408167577241595`, 1.1373624465696326`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.194326278421569, -0.6200152737048314], 
            Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7007758958656332`, 1.1373624465696324`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.335918932011362, -0.6200152737048319], 
            Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.101994107438951, 1.4678060609325632`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.311915217718847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.408150689624686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.209921110279896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.875956750557249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.311915217718847, -1.408150689624686], 
            Complex[1.209921110279896, -2.875956750557249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0395985461508428`, 1.467806060932563}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17032256412905356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4081506896246843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2099211102798964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.875956750557247`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[0.17032256412905356`, -1.4081506896246843`], 
            Complex[1.2099211102798964`, -2.875956750557247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1268739960358536`, 1.3938332567271068`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[1.6277476075095596`, -0.2595343622253301], 
            Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.014718657553939, 1.3938332567271066`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[4.769340261099353, -0.2595343622253304], 
            Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4523658266886268`, 1.176201604830757}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.837080189128189, 0.016808819629533064`], 
            Complex[5.289446015816816, -1.159392785201224]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6892268269011668`, 1.176201604830757}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.978672842717983, 0.01680881962953298], 
            Complex[5.289446015816816, -1.159392785201224]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687769590110115, 1.214473262210035}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.30456268297077, 0.6225897638061416], 
            Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4538230634796767`, 1.2144732622100345`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.162970029380981, 0.6225897638061394], 
            Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7009280565070715`, 1.136597741945355}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.335591908744412, -0.6304394010704698], 
            Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4406645970827212`, 1.1365977419453552`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.193999255154619, -0.63043940107047], 
            Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.038873927821454, 1.467651056278275}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16900153176725363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4121024391848713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.879753495463146`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[0.16900153176725363`, -1.4121024391848713`], 
            Complex[1.2078754595887078`, -2.879753495463146]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1027187257683386`, 1.4676510562782756`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.310594185357048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.41210243918487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8797534954631456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.310594185357048, -1.41210243918487], 
            Complex[1.2078754595887096`, -2.8797534954631456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1278293161752426`, 1.3924760821446296`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[1.637142374648998, -0.2578914362102892], 
            Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0137633374145496`, 1.3924760821446294`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[4.778735028238791, -0.25789143621028987`], 
            Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6900831509445093`, 1.1763170322944347`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.970537783665925, 0.017060741491919468`], 
            Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.451509502645284, 1.1763170322944345`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.8289451300761326`, 0.017060741491919426`], 
            Complex[5.280454632721417, -1.159256290802515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4538593640406077`, 1.2151945268467637`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.1631878734954, 0.6327459028649584], 
            Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6877332895491859`, 1.2151945268467637`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.304780527085194, 0.6327459028649576], 
            Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.440513575102836, 1.135846892495916}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.193688485375648, -0.6406030569368893], 
            Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7010790784869567`, 1.1358468924959164`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.33528113896544, -0.6406030569368892], 
            Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.103440759192883, 1.4674997625840585`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3092946810361643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.883515741306371`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.3092946810361643`, -1.4160159787223123`], 
            Complex[1.205853921843281, -2.883515741306371]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.038151894396911, 1.4674997625840587`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1677020274463709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8835157413063706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[0.1677020274463709, -1.4160159787223117`], 
            Complex[1.205853921843282, -2.8835157413063706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0127959399432025`, 1.391122336066033}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[4.788113194449318, -0.256282863587831], 
            Complex[2.775317254506115, -1.647405199653864]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1287967136465915`, 1.3911223360660327`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[1.6465205408595256`, -0.2562828635878306], 
            Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6909458209918422`, 1.1764334497910687`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.962412401815591, 0.017317904038714253`], 
            Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4506468325979511`, 1.1764334497910687`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.820819748225798, 0.01731790403871422], 
            Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4538947677302392`, 1.215902631518789}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.163392045750655, 0.6426557999628854], 
            Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6876978858595542`, 1.2159026315187893`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.304984699340448, 0.6426557999628848], 
            Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4403636652203027`, 1.1351091458727407`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.193392563005682, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.70122898836949, 1.1351091458727411`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.334985216595475, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0374324335070848`, 1.4673521130352265`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1664234887985512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[0.1664234887985512, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1041602200827088`, 1.4673521130352265`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3080161423883445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.3080161423883445`, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0118164515455317`, 1.3897720016044284`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[4.79747614551083, -0.2547081070429694], 
            Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1297762020442608`, 1.389772001604428}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[1.6558834919210377`, -0.25470810704296915`], 
            Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6918149551263002`, 1.1765508653305405`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.954295327902444, 0.01758047284423772], 
            Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4497776984634931`, 1.1765508653305405`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.812702674312651, 0.0175804728442376], 
            Complex[5.262480372776144, -1.158970392486303]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687663354498061, 1.2165982636922328`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.305176410484561, 0.6523323858111223], 
            Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4539292990917323`, 1.2165982636922326`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.163583756894771, 0.6523323858111204], 
            Complex[7.617513055986503, -0.564265877881112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4402148404754676`, 1.1343838152897303`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.193110249156134, -0.660204284545775], 
            Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7013778131143251`, 1.1343838152897303`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.334702902745928, -0.6602042845457757], 
            Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0367155326281672`, 1.46720804250448}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1651653741234745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4237315302550273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8909395727595073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[0.1651653741234745, -1.4237315302550273`], 
            Complex[1.2018809067516416`, -2.8909395727595073`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1048771209616257`, 1.4672080425044802`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.306758027713268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4237315302550264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.890939572759507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.306758027713268, -1.4237315302550264`], 
            Complex[1.2018809067516425`, -2.890939572759507]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1307678008990376`, 1.3884250613466609`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[1.6652326038019236`, -0.2531666605106765], 
            Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.010824852690755, 1.3884250613466604`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[4.806825257391718, -0.2531666605106761], 
            Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4489019785759336`, 1.1766692867571427`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.8045925513977634`, 0.017848620677213583`], 
            Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.692690675013859, 1.1766692867571429`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.946185204987557, 0.017848620677213628`], 
            Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4539629827677436`, 1.2172820529684156`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.163764076292796, 0.6617875296457958], 
            Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6876296708220482`, 1.2172820529684156`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.30535672988259, 0.6617875296457956], 
            Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7015255797263569`, 1.133670271809743}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.334433100918964, -0.6696666607954201], 
            Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4400670738634365`, 1.1336702718097431`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.192840447329175, -0.6696666607954201], 
            Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0360011790990973`, 1.4670674874942782`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1639271613994279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[0.1639271613994279, -1.4275350319275484`], 
            Complex[1.1999283404985253`, -2.8946025194218263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.105591474490696, 1.4670674874942784`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3055198149892218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.3055198149892218`, -1.4275350319275477`], 
            Complex[1.1999283404985257`, -2.8946025194218263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0098211178273075`, 1.3870814974195786`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[4.8161618980011855`, -0.2516580484846366], 
            Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1317715357624867`, 1.3870814974195786`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[1.6745692444113933`, -0.251658048484637], 
            Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6935731060572334`, 1.1767887217239028`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.938080686504964, 0.018122527898744748`], 
            Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4480195475325601`, 1.1767887217239026`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.796488032915171, 0.018122527898744724`], 
            Complex[5.244507580447731, -1.158666193825158]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6875968103473002`, 1.2179545776709837`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.305526605913883, 0.6710321572939462], 
            Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4539958432424924`, 1.2179545776709835`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.16393395232409, 0.671032157293945], 
            Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4399203385901513`, 1.1329679377580293`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.192582182972333, -0.6789184304865281], 
            Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7016723149996422`, 1.1329679377580293`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.334174836562127, -0.6789184304865283], 
            Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.035289360136911, 1.466930386081749}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16270834735290776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650033`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[0.16270834735290776`, -1.4313033050832542`], 
            Complex[1.1979977074898187`, -2.8982336911650033`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1063032934528825`, 1.4669303860817497`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.304301000942701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.304301000942701, -1.4313033050832549`], 
            Complex[1.1979977074898187`, -2.8982336911650046`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1327874383022694`, 1.3857412915566514`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[1.6838947753228468`, -0.25018182541497563`], 
            Complex[2.816682213625116, -1.635923116971627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0088052152875226`, 1.3857412915566516`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[4.825487428912641, -0.2501818254149765], 
            Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.447130276031749, 1.1769091776643839`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.7883877807626547`, 0.018402382887287773`], 
            Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6944623775580436`, 1.1769091776643836`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.929980434352448, 0.01840238288728782], 
            Complex[5.235518056794405, -1.158506794777096]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6875647489352248`, 1.2186163705006785`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.305686882893223, 0.6800763528244194], 
            Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4540279046545685`, 1.2186163705006787`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.164094229303429, 0.680076352824419], 
            Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.439774608257796, 1.132276281067987}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.192334586512061, -0.6879696797720971], 
            Complex[7.632109194769857, -1.820245960840084]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7018180453319975`, 1.1322762810679872`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.333927240101854, -0.6879696797720991], 
            Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1070125907387394`, 1.4667966778659949`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3031011001724133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4350370377108632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.196088509433674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.901833715576858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.3031011001724133`, -1.4350370377108632`], 
            Complex[1.196088509433674, -2.901833715576858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.034580062851054, 1.466796677865995}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16150844658262048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4350370377108643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1960885094336744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9018337155768594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[0.16150844658262048`, -1.4350370377108643`], 
            Complex[1.1960885094336744`, -2.9018337155768594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1338155464088413`, 1.3844044251653094`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[1.6932105534745874`, -0.2487375751928472], 
            Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.007777107180952, 1.3844044251653096`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[4.834803207064381, -0.24873757519284634`], 
            Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4462340307019717`, 1.1770306617617174`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.7802904634285417`, 0.018688382492788227`], 
            Complex[5.226524494130514, -1.158342279268929]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6953586228878217`, 1.1770306617617174`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.921883117018336, 0.018688382492788213`], 
            Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6875334629267682`, 1.2192679234139303`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.305838315194185, 0.6889294464957751], 
            Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4540591906630251`, 1.21926792341393}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.164245661604394, 0.6889294464957759], 
            Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7019627965927964`, 1.1315948104030755`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.333689532777536, -0.6968297409230606], 
            Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4396298569969979`, 1.1315948104030757`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.192096879187743, -0.6968297409230599], 
            Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0338732742567465`, 1.4666663039176624`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16032699073407702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1942002649908234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9054032007098534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[0.16032699073407702`, -1.438736896792191], 
            Complex[1.1942002649908234`, -2.9054032007098534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.107719379333046, 1.466666303917662}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3019196443238705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.194200264990824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.905403200709853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.3019196443238705`, -1.438736896792191], 
            Complex[1.194200264990824, -2.905403200709853]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0067367492758055`, 1.3830708793953943`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[4.844110586443732, -0.24732491072033783`], 
            Complex[2.837373837167927, -1.630395790115732]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1348559043139885`, 1.3830708793953934`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[1.7025179328539397`, -0.2473249107203387], 
            Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4453306739213656`, 1.1771531809145912`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.772194754147412, 0.018980732522336802`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6962619796684277`, 1.177153180914591}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.913787407737206, 0.018980732522336733`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4540897243537045`, 1.2199096918514625`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.164388925515004, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6875029292360888`, 1.2199096918514625`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.305981579104797, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4394860595588896`, 1.130923070928693}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.191868361155921, -0.7055072687737808], 
            Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.702106594030904, 1.1309230709286935`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.333461014745714, -0.705507268773781], 
            Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1084236723023215`, 1.4665392067306668`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3007561813111055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4424035291838815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.908942735914548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[3.3007561813111055`, -1.4424035291838815`], 
            Complex[1.192332509008784, -2.908942735914548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0331689812874716`, 1.4665392067306673`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15916352772131243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.442403529183883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9089427359145503`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[0.15916352772131243`, -1.442403529183883], 
            Complex[1.192332509008784, -2.9089427359145503`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1359085627217376`, 1.3817406352091437`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[1.711818266170711, -0.24594347356467736`], 
            Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0056840908680553`, 1.381740635209144}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[4.853410919760504, -0.24594347356467788`], 
            Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6971725899625463`, 1.1772767416998926`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[6.90569198266763, 0.01927964825993098], 
            Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4444200636272473`, 1.1772767416998926`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[3.7640993290778377`, 0.019279648259930993`], 
            Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6874731254138242`, 1.2205420984195954`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.30611728283302, 0.7060963291837463], 
            Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4541195281759691`, 1.2205420984195954`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.164524629243228, 0.7060963291837459], 
            Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4393431913768184`, 1.1302606406313307`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.191648401446948, -0.7140103074539127], 
            Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7022494622129742`, 1.130260640631331}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.33324105503674, -0.7140103074539126], 
            Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0324671708066089`, 1.466415330175946}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15801762099250957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4460375624519293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1904847917991184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[0.15801762099250957`, -1.4460375624519293`], 
            Complex[1.1904847917991184`, -2.912452892627875]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1091254827831842`, 1.4664153301759464`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2996102745823035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.446037562451929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.190484791799119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.2996102745823035`, -1.446037562451929], 
            Complex[1.190484791799119, -2.912452892627875]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0046190746375654`, 1.3804136734531531`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[4.862705560115598, -0.24459293369624477`], 
            Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.136973578952228, 1.380413673453153}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[1.7211129065258053`, -0.2445929336962447], 
            Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4435020531148783`, 1.17740135033167}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.7560028654954856`, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.698090600474915, 1.17740135033167}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.897595519085279, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4541486239024193`, 1.2211655361083011`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.164653321403731, 0.7144256505494253], 
            Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6874440296873743`, 1.221165536108301}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.306245974993525, 0.7144256505494249], 
            Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4392012286051568`, 1.1296071271009607`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.191436429442565, -0.7223463488774431], 
            Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7023914249846368`, 1.1296071271009598`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.333029083032358, -0.7223463488774439], 
            Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1098248239714654`, 1.4662946194571398`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.298481502426376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620289`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1886566784549102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9159342251191687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.298481502426376, -1.4496396056620289`], 
            Complex[1.1886566784549102`, -2.9159342251191687`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0317678296183286`, 1.4662946194571393`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15688884883658272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.188656678454911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.915934225119166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[0.15688884883658272`, -1.4496396056620269`], 
            Complex[1.188656678454911, -2.915934225119166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1380510170991496`, 1.3790899749327667`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[1.7304032090806973`, -0.24327298931041993`], 
            Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0035416364906435`, 1.3790899749327663`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[4.871995862670491, -0.24327298931041968`], 
            Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4425764908247227`, 1.1775270126160398`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.747904039995082, 0.01989808875998759], 
            Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6990161627650706`, 1.1775270126160398`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.889496693584875, 0.019898088759987553`], 
            Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6874156209838347`, 1.2217803711152466`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.306368151840394, 0.722595044698084], 
            Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454177032605957, 1.2217803711152468`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.164775498250602, 0.7225950446980839], 
            Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7025325054489893`, 1.1289621647074088`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.332824581199281, -0.73052238420331], 
            Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.439060148140805, 1.1289621647074086`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.191231927609488, -0.7305223842033104], 
            Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.110521709112062, 1.466177021068103}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2973694573177923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4532102501286348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.2973694573177923`, -1.4532102501286348`], 
            Complex[1.1868477482057302`, -2.919387271196738]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0310709444777324`, 1.4661770210681033`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15577680372799887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4532102501286346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[0.15577680372799887`, -1.4532102501286346`], 
            Complex[1.1868477482057311`, -2.919387271196738]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1391409482014974`, 1.3777695204894282`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[1.739690532733481, -0.24198336673385532`], 
            Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.002451705388296, 1.377769520489428}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[4.881283186323276, -0.24198336673385487`], 
            Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.699949433472374, 1.1776537339016264`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.881394180284589, 0.020218096688815555`], 
            Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4416432201174194`, 1.1776537339016264`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.739801526694796, 0.020218096688815523`], 
            Complex[5.181444746812216, -1.157435637212811]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4542047746499094`, 1.2223869453331686`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.164891609869033, 0.7306110457745064], 
            Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687387878939884, 1.222386945333169}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.30648426345883, 0.730611045774511], 
            Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4389199276317326`, 1.1283254121133874`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.1910344252759195`, -0.738544949275635], 
            Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.702672725958061, 1.128325412113387}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.332627078865713, -0.7385449492756353], 
            Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.111216151489442, 1.4660624827521542`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.296273745297108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4567500701253233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9228125528774775`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.296273745297108, -1.4567500701253233`], 
            Complex[1.1850575938076657`, -2.9228125528774775`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0303765021003513`, 1.466062482752155}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1546810917073148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.456750070125323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.922812552877478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[0.1546810917073148, -1.456750070125323], 
            Complex[1.1850575938076662`, -2.922812552877478]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1402434504303887`, 1.376452291081521}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[1.7489762418071482`, -0.24072382041628856`], 
            Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0013492031594042`, 1.3764522910815207`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[4.8905688953969415`, -0.24072382041628823`], 
            Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.440702079035575, 1.1777815190250742`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.7316939954367316`, 0.020545637985933], 
            Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7008905745542178`, 1.1777815190250742`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.873286649026525, 0.020545637985932938`], 
            Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4542318696878953`, 1.2229855785483166`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.165002065498246, 0.738479772924393], 
            Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6873607839018974`, 1.2229855785483164`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.30659471908804, 0.7384797729243899], 
            Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7028121081139977`, 1.127696550076432}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.332436146868352, -0.7464201648848554], 
            Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4387805454757965`, 1.1276965500764324`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.190843493278558, -0.7464201648848559], 
            Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.029684489170987, 1.465950953462965}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1536013317951177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.92621057702186`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[0.1536013317951177, -1.4602596235588952`], 
            Complex[1.1832858209661048`, -2.92621057702186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1119081644188062`, 1.4659509534629642`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2951939853849117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.926210577021858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.2951939853849117`, -1.4602596235588936`], 
            Complex[1.1832858209661052`, -2.926210577021858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0002340442979794`, 1.3751382678692916`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[4.899854361345616, -0.23949413300958752`], 
            Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1413586092918147`, 1.3751382678692916`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[1.758261707755823, -0.23949413300958816`], 
            Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4397529000514586`, 1.1779103722511177`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.723580109977185, 0.020880984524095002`], 
            Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.701839753538335, 1.1779103722511177`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.865172763566979, 0.020880984524095033`], 
            Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6873343169188384`, 1.2235765703899117`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.306699891715693, 0.7462069660795199], 
            Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4542583366709552`, 1.2235765703899117`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.1651072381259, 0.7462069660795196], 
            Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4386419808123787`, 1.12707527949981}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.190658739339742, -0.7541537725552644], 
            Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7029506727774146`, 1.12707527949981}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.332251392929535, -0.7541537725552647], 
            Complex[7.629300720152121, -1.881229052055075]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0289948923519805`, 1.465842383327024}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15253715543722762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4637394526094687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.181532047789208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[0.15253715543722762`, -1.4637394526094687`], 
            Complex[1.181532047789208, -2.9295818359364927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1125977612378124`, 1.4658423833270233`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2941298090270217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4637394526094694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1815320477892093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.2941298090270217`, -1.4637394526094694`], 
            Complex[1.1815320477892093`, -2.9295818359364927`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9991061357435584`, 1.3738274323045088`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[4.90914096448451, -0.23829411553630825`], 
            Complex[2.910034828740951, -1.612121547840817]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1424865178462356`, 1.373827432304509}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[1.7675483108947163`, -0.2382941155363085], 
            Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4387955097995693`, 1.1780402972066422`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.7154585261603414`, 0.021224421666976207`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7027971437902243`, 1.1780402972066422`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.857051179750135, 0.021224421666976113`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4542841938599673`, 1.2241602020642195`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.165207468468805, 0.7537980178639989], 
            Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6873084597298253`, 1.2241602020642195`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.306800122058599, 0.7537980178639988], 
            Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.703088440081019, 1.1264613196988047`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.332072457649627, -0.7617511664534365], 
            Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4385042135087747`, 1.1264613196988047`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.190479804059834, -0.761751166453437], 
            Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0283076982909278`, 1.465736723607585}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15148820597915524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4671900843386563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.179795904270083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.932926807946241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[0.15148820597915524`, -1.4671900843386563`], 
            Complex[1.179795904270083, -2.932926807946241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1132849552988655`, 1.4657367236075842`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2930808595689487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4671900843386574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1797959042700832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9329268079462416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.2930808595689487`, -1.4671900843386574`], 
            Complex[1.1797959042700832`, -2.9329268079462416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9979653766437173`, 1.372519766225561}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[4.918430095749453, -0.2371236076506873], 
            Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1436272769460762`, 1.3725197662255608`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[1.776837442159661, -0.23712360765068694`], 
            Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.703762924796807, 1.1781712968080984`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.848920543658824, 0.02157624912441265], 
            Complex[5.145157618862018, -1.156595047683686]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4378297287929864`, 1.1781712968080984`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.707327890069032, 0.02157624912441267], 
            Complex[5.145157618862019, -1.156595047683686]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4543094588418968`, 1.2247367379015854`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.165303068434313, 0.761258002124613], 
            Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6872831947478968`, 1.2247367379015852`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.306895722024107, 0.7612580021246124], 
            Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4383672241428038`, 1.125854406854012}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.1903063574303445`, -0.7692174219206874], 
            Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7032254294469888`, 1.1258544068540122`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.33189901102014, -0.7692174219206883], 
            Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0276228936278806`, 1.4656339266700298`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1504541381679981`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1780770317958789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.936245957937765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[0.1504541381679981, -1.470612031267735], 
            Complex[1.1780770317958789`, -2.936245957937765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.113969759961912, 1.4656339266700298`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2920467917577914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.178077031795879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.936245957937766`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.2920467917577914`, -1.470612031267736], 
            Complex[1.178077031795879, -2.936245957937766]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.144780995492217, 1.3712152519587637`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[1.7861305049022496`, -0.23598247799562685`], 
            Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9968116580975763`, 1.3712152519587637`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[4.927723158492043, -0.23598247799562702`], 
            Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.436855371122298, 1.1783033731815569`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.6991868361460636`, 0.021936781873947247`], 
            Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7047372824674956`, 1.1783033731815566`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.840779489735858, 0.021936781873947195`], 
            Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4543341485487062`, 1.2253064267405018`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.165394324140473, 0.7685916995129604], 
            Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6872585050410873`, 1.2253064267405016`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.306986977730267, 0.7685916995129599], 
            Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7033616596069883`, 1.1252542926276017`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.331730749379409, -0.7765573210571958], 
            Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4382309939828053`, 1.1252542926276017`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.190138095789615, -0.7765573210571961], 
            Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0269404650020613`, 1.4655339459485839`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1494346176800629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4740057919276426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[0.1494346176800629, -1.4740057919276426`], 
            Complex[1.1763750826821242`, -2.9395397378762262`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.114652188587732, 1.4655339459485837`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.291027271269856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.474005791927643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.291027271269856, -1.474005791927643], 
            Complex[1.1763750826821242`, -2.9395397378762267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1459477907107125`, 1.3699138724267474`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[1.7954289167267061`, -0.23487062465998598`], 
            Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9956448628790804`, 1.3699138724267474`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[4.9370215703165, -0.23487062465998587`], 
            Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.435872244135823, 1.178436527574611}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.6910339852795406`, 0.022306351154756415`], 
            Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7057204094539706`, 1.1784365275746114`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.832626638869334, 0.022306351154756456`], 
            Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687234374311736, 1.2258695031691889`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.30707415214959, 0.7758036204842984], 
            Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4543582792780583`, 1.225869503169189}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.1654814985597985`, 0.7758036204842987], 
            Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7034971486239172`, 1.1246607429220432`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.331567392745953, -0.7837753757227326], 
            Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4380955049658761`, 1.124660742922043}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.18997473915616, -0.7837753757227331], 
            Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1153322545316633`, 1.4654367359143055`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2900219742624115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4773718513824372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9428085872967427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.2900219742624115`, -1.4773718513824372`], 
            Complex[1.1746897197307482`, -2.9428085872967427`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.02626039905813, 1.4654367359143052`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1484293206726183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.477371851382437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.942808587296742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[0.1484293206726183, -1.477371851382437], 
            Complex[1.1746897197307484`, -2.942808587296742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.99446486513871, 1.368615611264855}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[4.946326764964685, -0.2337879757412101], 
            Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1471277884510829`, 1.3686156112648549`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[1.8047341113748927`, -0.23378797574120985`], 
            Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7067125054900785`, 1.1785707602592412`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.824460596435171, 0.022685305540684226`], 
            Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4348801480997158`, 1.1785707602592412`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.6828679428453777`, 0.022685305540684448`], 
            Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6872107868746455`, 1.226426188642203}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.307157487430532, 0.7828980260257034], 
            Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454381866715149, 1.2264261886422028`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.1655648338407385`, 0.7828980260257037], 
            Complex[7.619946700555888, -0.443528162616499]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.703631913914755, 1.1240735367638}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.331408682475267, -0.7908758482666055], 
            Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4379607396750385`, 1.1240735367637995`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.189816028885474, -0.7908758482666055], 
            Complex[7.627776768560513, -1.914949385030405]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0255826824520298`, 1.4653422520443076`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1474379333583333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[0.1474379333583333, -1.4807106817278035`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1160099711377636`, 1.465342252044308}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2890305869481264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.2890305869481264`, -1.4807106817278028`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1483211235076392`, 1.3673204529466156`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[1.814047540666005, -0.23273449001922963`], 
            Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.993271530082154, 1.3673204529466154`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[4.955640194255799, -0.2327344900192291], 
            Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7077137777533633`, 1.1787060704246382`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.816279950289862, 0.023074012099830184`], 
            Complex[5.108566172536498, -1.155632058324808]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.43387887583643, 1.1787060704246382`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.6746872967000694`, 0.0230740120998302], 
            Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6871877276346632`, 1.2269766924870942`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.307237206941968, 0.7898789463823147], 
            Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4544049259551295`, 1.2269766924870944`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.165644553352178, 0.7898789463823163], 
            Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4378266813158467`, 1.1234924652969505`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.189661725604909, -0.7978627702556053], 
            Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7037659722739469`, 1.1234924652969505`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.331254379194702, -0.7978627702556061], 
            Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1166853517333557`, 1.4652504507921373`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.288052805190806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4840227425660197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.288052805190806, -1.4840227425660197`], 
            Complex[1.1713674534574503`, -2.9492731933581573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.024907301856438, 1.4652504507921371`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14646015160101253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.48402274256602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[0.14646015160101253`, -1.48402274256602], 
            Complex[1.1713674534574505`, -2.9492731933581573`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1495279399654437`, 1.3660283829194533`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[1.8233706764978728`, -0.2317101577484136], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.99206471362435, 1.366028382919453}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[4.9649633300876665`, -0.23171015774841372`], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4328682123398786`, 1.1788424560588717`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.6664906151164782`, 0.023472857648944835`], 
            Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7087244412499147`, 1.1788424560588717`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.808083268706271, 0.02347285764894464], 
            Complex[5.099358827456356, -1.155369598409927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454427471525755, 1.2275212128140656`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.165720863489107, 0.7967501980135657], 
            Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6871651820640368`, 1.2275212128140653`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.307313517078901, 0.7967501980135657], 
            Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7038993398969906`, 1.1229173308738125`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.331104260978192, -0.8047399594318435], 
            Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4376933136928036`, 1.1229173308738123`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.189511607388403, -0.804739959431843], 
            Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1173584096239533`, 1.4651612895592658`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2870883341211625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4873084814587765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1697299244972095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9524697710180425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.2870883341211625`, -1.4873084814587765`], 
            Complex[1.1697299244972095`, -2.9524697710180425`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0242342439658403`, 1.4651612895592654`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14549568053136955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.487308481458776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.16972992449721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9524697710180416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[0.14549568053136955`, -1.487308481458776], 
            Complex[1.16972992449721, -2.9524697710180416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.150748391572657, 1.3647393877519407`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[1.8327050129169915`, -0.23071500157543248`], 
            Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9908442620171352`, 1.3647393877519407`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[4.974297666506786, -0.2307150015754329], 
            Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4318479343654857`, 1.1789799138181523`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.6582764446551637`, 0.023882250111808095`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.709744719224307, 1.1789799138181523`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.799869098244956, 0.023882250111808064`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6871431361798572`, 1.2280599373397927`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.307386608861503, 0.8035153989801238], 
            Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454449517409937, 1.228059937339793}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.165793955271714, 0.8035153989801244], 
            Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7040320324038776`, 1.1223479462313808`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.330958121728596, -0.811511035101225], 
            Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.437560621185916, 1.122347946231381}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.189365468138804, -0.8115110351012247], 
            Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1180291580885333`, 1.4650747266676414`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.28613688777145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4905683343590643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1681077296829168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9556430610267057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.28613688777145, -1.4905683343590643`], 
            Complex[1.1681077296829168`, -2.9556430610267057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0235634955012611`, 1.4650747266676412`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1445442341816557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.490568334359063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.168107729682917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.955643061026704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[0.1445442341816557, -1.490568334359063], 
            Complex[1.168107729682917, -2.955643061026704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9896100114486002`, 1.3634534552940505`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[4.983644721854632, -0.22974907759194269`], 
            Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.151982642141193, 1.3634534552940498`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[1.8420520682648396`, -0.22974907759194238`], 
            Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.710774843596631, 1.1791184388822638`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.7916359615532285`, 0.024302619991773983`], 
            Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4308178099931625`, 1.179118438882264}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.6500433079634345`, 0.02430261999177399], 
            Complex[5.080861117956597, -1.15481581889049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4544710770679978`, 1.2285930441351087`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.1658640057650915`, 0.8101779829358522], 
            Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6871215765217955`, 1.228593044135109}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.307456659354887, 0.8101779829358526], 
            Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4374285887275748`, 1.1217841337438983`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.189223116150438, -0.8181794321268676], 
            Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7041640648622178`, 1.1217841337438983`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.330815769740232, -0.818179432126868], 
            Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.118697610375126, 1.4649907213332523`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.285198188727837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9587934473565816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.285198188727837, -1.4938027260233295`], 
            Complex[1.1665005783527111`, -2.9587934473565816`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0228950432146673`, 1.4649907213332527`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14360553513804464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.958793447356582`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[0.14360553513804464`, -1.4938027260233295`], 
            Complex[1.1665005783527118`, -2.958793447356582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1532308659777568`, 1.3621705748520434`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[1.8514133874083418`, -0.22881247653229805`], 
            Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.988361787612036, 1.3621705748520438`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[4.993006040998135, -0.22881247653229808`], 
            Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4297775981610568`, 1.1792580247945883`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.64178970149396, 0.024734421969833987`], 
            Complex[5.071567299655017, -1.154523602824754]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.711815055428736, 1.1792580247945883`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.783382355083752, 0.024734421969834053`], 
            Complex[5.071567299655017, -1.154523602824754]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4544921634594683`, 1.229120702304966}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.165931179342954, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.687100490130325, 1.229120702304966}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.307523832932748, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.704295451809858, 1.121225724743139}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.330677026418373, -0.824748413679325], 
            Complex[7.626381574608514, -1.945974138422464]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4372972017799364`, 1.1212257247431388`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.18908437282858, -0.8247484136793249], 
            Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.119363779696725, 1.4649092336406535`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.284271967799523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4970120704049878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.284271967799523, -1.4970120704049878`], 
            Complex[1.1649081881027983`, -2.9619213040456414`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0222288738930687`, 1.4649092336406537`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1426793142097304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4970120704049876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[0.1426793142097304, -1.4970120704049876`], 
            Complex[1.1649081881027992`, -2.9619213040456414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1544932483475856`, 1.3608907373798256`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[1.860790544062835, -0.2279053251278246], 
            Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9870994052422073`, 1.3608907373798247`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[5.0023831976526285`, -0.22790532512782422`], 
            Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7128656054220353`, 1.1793986632849174`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.775106746724161, 0.02517813664084302], 
            Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4287270481677583`, 1.1793986632849172`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.633514093134369, 0.025178136640842893`], 
            Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.45451278906429, 1.2296430726080232`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.165995628815023, 0.823208187778776], 
            Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6870798645255034`, 1.2296430726080239`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.307588282404819, 0.8232081877787825], 
            Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7044262072768797`, 1.1206725588990525`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.330541725135806, -0.8312210828762443], 
            Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.437166446312914, 1.1206725588990527`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.188949071546019, -0.8312210828762437], 
            Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1200276792274675`, 1.464830224518415}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.283357963703603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.500196771030314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.283357963703603, -1.500196771030314], 
            Complex[1.1633302844761357`, -2.965026995548729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0215649743623263`, 1.4648302245184155`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14176531011381055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5001967710303135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[0.14176531011381055`, -1.5001967710303135`], 
            Complex[1.1633302844761368`, -2.965026995548729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9858226676164228`, 1.3596139356888313`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[5.011777796806058, -0.2270277876307708], 
            Complex[3.025955129189635, -1.586641723319602]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1557699859733703`, 1.3596139356888313`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[1.8701851432162653`, -0.22702778763077072`], 
            Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.713926754449417, 1.1795403440730328`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.766807573328626, 0.02563427240203126], 
            Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4276658991403766`, 1.1795403440730323`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.625214919738834, 0.025634272402031196`], 
            Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4545329659033672`, 1.2301603080222792`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.166057496435186, 0.8295818632429409], 
            Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6870596876864263`, 1.2301603080222796`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.30765015002498, 0.8295818632429439], 
            Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.437036308782869, 1.120124483654361}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.188817056619653, -0.8376003934276774], 
            Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7045563448069236`, 1.1201244836543607`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.330409710209448, -0.8376003934276777], 
            Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.120689322099101, 1.4647536557154563`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2824559227648207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1617666006657197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.968110877073136`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.2824559227648207`, -1.5033572213576796`], 
            Complex[1.1617666006657197`, -2.968110877073136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.020903331490693, 1.464753655715456}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14086326917502792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.161766600665721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9681108770731357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[0.14086326917502792`, -1.5033572213576796`], 
            Complex[1.161766600665721, -2.9681108770731357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.157061287572112, 1.3583401646787814`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[1.8795988236639012`, -0.22618006752276323`], 
            Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.984531366017681, 1.3583401646787812`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[5.021191477253695, -0.2261800675227632], 
            Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7149987741240558`, 1.1796830546507568`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.7584832381419595`, 0.02610336750958422], 
            Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4265938794657385`, 1.1796830546507573`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.6168905845521655`, 0.0261033675095845], 
            Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4545527055583864`, 1.230672554262382}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.1661169148049755`, 0.8358650512460941], 
            Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6870399480314069`, 1.2306725542623822`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.30770956839477, 0.8358650512460974], 
            Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4369067761120415`, 1.1195813537074624`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.188688182392475, -0.8438891593891127], 
            Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7046858774777518`, 1.1195813537074621`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.33028083598227, -0.8438891593891124], 
            Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0202439321921053`, 1.4646794897782125`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13997294503955765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5064938051210208`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.160216877231663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9711732948992333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[0.13997294503955765`, -1.5064938051210208`], 
            Complex[1.160216877231663, -2.9711732948992333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.121348721397688, 1.4646794897782134`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2815655986293515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5064938051210213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1602168772316634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9711732948992347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.2815655986293515`, -1.5064938051210213`], 
            Complex[1.1602168772316634`, -2.9711732948992347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.983225279156869, 1.357069421591918}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[5.030625914253164, -0.22536240942454472`], 
            Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1583673744329248`, 1.3570694215919177`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[1.8890332606633722`, -0.22536240942454516`], 
            Complex[3.047400635096297, -1.582431831016463]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.425510706181644, 1.1798267800398852`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.6085394545164045`, 0.026585992320965875`], 
            Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7160819474081481`, 1.1798267800398856`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.750132108106198, 0.026585992320966013`], 
            Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4545720191909095`, 1.2311799502535616`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.166174007684912, 0.8420604340909559], 
            Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6870206343988832`, 1.2311799502535619`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.307766661274705, 0.8420604340909561], 
            Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4367778356687468`, 1.1190430305387107`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.188562312408357, -0.850090064112114], 
            Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7048148179210458`, 1.119043030538711}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.330154965998151, -0.8500900641121139], 
            Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0195867634292326`, 1.464607690028626}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13909409840205325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.158680861831286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[0.13909409840205325`, -1.5096068966583966`], 
            Complex[1.158680861831286, -2.974214586687023]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1220058901605605`, 1.464607690028626}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.280686751991847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1586808618312865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[3.280686751991847, -1.5096068966583966`], 
            Complex[1.1586808618312865`, -2.974214586687023]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1596884810390518`, 1.3558017062937204`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[1.8984901687203608`, -0.2245751012259816], 
            Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9819041725507414`, 1.3558017062937204`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[5.040082822310154, -0.22457510122598082`], 
            Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4244160843248561`, 1.1799715025230373`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[3.6001598574493725`, 0.027082751742796535`], 
            Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.717176569264938, 1.1799715025230375`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[6.7417525110391665`, 0.02708275174279656], 
            Complex[5.024575941774229, -1.152888750780241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4545909175606828`, 1.2316826285665503`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.166228890724623, 0.8481705716325338], 
            Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6870017360291107`, 1.2316826285665505`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.307821544314418, 0.8481705716325364], 
            Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7049431783414013`, 1.1185093819756964`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.330031972258514, -0.856205668471937], 
            Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4366494752483914`, 1.1185093819756962`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.1884393186687205`, -0.8562056684719376], 
            Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0189318122163058`, 1.4645382205428814`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13822649674521148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5126968612263973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[0.13822649674521148`, -1.5126968612263973`], 
            Complex[1.1571583089615174`, -2.9772350817692788`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.122660841373487, 1.464538220542882}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.279819150335005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.512696861226397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.279819150335005, -1.512696861226397], 
            Complex[1.1571583089615178`, -2.9772350817692788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9805677978520724`, 1.3545370215834658`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[5.049563958105735, -0.22381847645779873`], 
            Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1610248557377207`, 1.354537021583466}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[1.9079713045159428`, -0.22381847645779898`], 
            Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7182829473576118`, 1.1801172013441015`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.733342732673844, 0.027594287906544456`], 
            Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4233097062321813`, 1.1801172013441021`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.5917500790840515`, 0.02759428790654434], 
            Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686983242546615, 1.2321807158173408`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.307874325710909, 0.8541979088518956], 
            Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4546094110431786`, 1.2321807158173408`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.166281672121116, 0.8541979088518953], 
            Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7050709705345457`, 1.117980281793682}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.329911734551446, -0.8622384184423436], 
            Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4365216830552476`, 1.1179802817936821`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.188319080961654, -0.8622384184423437], 
            Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.123313587968056, 1.464471046130904}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2789625676809804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5157640553011698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.980235101432074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.2789625676809804`, -1.5157640553011698`], 
            Complex[1.1556489797129244`, -2.980235101432074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.018279065621738, 1.4644710461309036`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13736991409118712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.515764055301169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9802351014320725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[0.13736991409118712`, -1.515764055301169], 
            Complex[1.1556489797129252`, -2.9802351014320725`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1623767614617608`, 1.3532753735384757`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[1.9174784699871426`, -0.22309291692935715`], 
            Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9792158921280327`, 1.3532753735384755`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[5.059071123576937, -0.22309291692935682`], 
            Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7194014027991138`, 1.1802638523744433`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.724901013546819, 0.02812128309705345], 
            Complex[5.005499610747705, -1.15214256927739]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4221912507906802`, 1.1802638523744435`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.583308359957026, 0.02812128309705336], 
            Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4546275096463899`, 1.2326743330351946`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.166332453213396, 0.8601447828394871], 
            Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6869651439434037`, 1.2326743330351946`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.30792510680319, 0.860144782839487], 
            Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4363944476850388`, 1.1174556093477817`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.188201486255246, -0.8681906520799051], 
            Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.705198205904754, 1.1174556093477817`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.32979413984504, -0.8681906520799052], 
            Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.017628510770542, 1.4644061323165505`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13652413076420825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5188088268667397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.15415264153475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.98321495918329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[0.13652413076420825`, -1.5188088268667397`], 
            Complex[1.15415264153475, -2.98321495918329]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1239641428192506`, 1.4644061323165503`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.278116784354001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.518808826866739`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1541526415347505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9832149591832895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.278116784354001, -1.518808826866739], 
            Complex[1.1541526415347505`, -2.9832149591832895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.977848177082466, 1.3520167718964258`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[5.068606169162741, -0.22239885565995454`], 
            Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.163744476507328, 1.3520167718964256`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[1.927013515572947, -0.22239885565995451`], 
            Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.720532270957173, 1.1804114277405415`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.716425545723422, 0.02866446296210377], 
            Complex[4.995893274766249, -1.151746964778438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4210603826326211`, 1.180411427740542}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.5748328921336294`, 0.02866446296210389], 
            Complex[4.99589327476625, -1.151746964778438]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6869474305629428`, 1.2331635960019263`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.307973982610356, 0.8660134292433511], 
            Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4546452230268498`, 1.233163596001926}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.166381329020564, 0.8660134292433507], 
            Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4362677581082923`, 1.1169352492338576`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.188086428148008, -0.8740646059731705], 
            Complex[7.6243541862563, -1.990999855207028]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.705324895481501, 1.1169352492338573`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.329679081737801, -0.8740646059731706], 
            Complex[7.6243541862563, -1.990999855207028]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.124612518743218, 1.4643434453184787`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.277281586753582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.152669068010364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.277281586753582, -1.5218315156912805`], 
            Complex[1.152669068010364, -2.9861749610097594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0169801348465757`, 1.4643434453184785`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13568893316378858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1526690680103642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[0.13568893316378858`, -1.5218315156912807`], 
            Complex[1.1526690680103642`, -2.9861749610097594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.165128295372457, 1.3507612304806975`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[1.9365783436386594`, -0.22173678013483558`], 
            Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.976464358217336, 1.3507612304806973`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[5.078170997228454, -0.22173678013483544`], 
            Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7216759023193726`, 1.1805598954080907`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.707914469346525, 0.029224600034819193`], 
            Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4199167512704212`, 1.180559895408091}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.566321815756732, 0.029224600034819154`], 
            Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6869300930848505`, 1.2336486155651585`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.308021042319387, 0.8718059882315835], 
            Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4546625605049428`, 1.2336486155651585`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.166428388729593, 0.8718059882315833], 
            Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4361416036544397`, 1.1164190909754412`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.187973806370098, -0.8798624212060279], 
            Complex[7.624115410024538, -1.996281512181469]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7054510499353537`, 1.1164190909754415`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.329566459959892, -0.8798624212060276], 
            Complex[7.624115410024538, -1.996281512181469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.016333925094598, 1.464282952031671}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13486411354798725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[0.13486411354798725`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.125258728495195, 1.464282952031671}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2764567671377804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.2764567671377804`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1665285296616588`, 1.3495087676744777`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[1.9461749120921603`, -0.22110723592124693`], 
            Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9750641239281341`, 1.3495087676744777`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[5.087767565681953, -0.22110723592124715`], 
            Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.722832663423437, 1.1807092187168904`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.699365868995314, 0.02980251760487493], 
            Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.418759990166357, 1.1807092187168906`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.557773215405521, 0.029802517604874564`], 
            Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454679531079485, 1.2341294979279436`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.166473716138243, 0.877524510013052], 
            Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6869131225103084`, 1.2341294979279434`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.308066369728037, 0.8775245100130518], 
            Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7055766795931335`, 1.115907028734277}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.32945617991971, -0.8855861488792872], 
            Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4360159739966607`, 1.115907028734277}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.187863526329917, -0.8855861488792874], 
            Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0156898688221754`, 1.4642246200095725`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13404946982617044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5278119646888442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9920365846984165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[0.13404946982617044`, -1.5278119646888442`], 
            Complex[1.1497393386483457`, -2.9920365846984165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.125902784767617, 1.4642246200095719`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2756421234159636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5278119646888435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.992036584698415`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.2756421234159636`, -1.5278119646888435`], 
            Complex[1.1497393386483465`, -2.992036584698415]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.973647144527563, 1.3482594069501301`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[5.097397891796026, -0.2205108306846836], 
            Complex[3.123750747268463, -1.568770237634814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1679455090622306`, 1.3482594069501301`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[1.9558052382062334`, -0.22051083068468325`], 
            Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7240029378584962`, 1.1808593558600216`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.6907777698397455`, 0.030399093979211252`], 
            Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4175897157312973`, 1.1808593558600218`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.5491851162499515`, 0.030399093979211273`], 
            Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4546961434416268`, 1.2346063449168942`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.166517390057898, 0.8831709599557609], 
            Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868965101481652`, 1.2346063449168938`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.308110043647693, 0.8831709599557607], 
            Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7057017944523751`, 1.1153989610423558`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.329348152291017, -0.8912377552298729], 
            Complex[7.623646357838642, -2.006636716272229]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4358908591374175`, 1.1153989610423563`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.187755498701229, -0.8912377552298747], 
            Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.015047953401427, 1.4641684174468281`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1332448053607902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.530770365648672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830955003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[0.1332448053607902, -1.530770365648672], 
            Complex[1.1482927587622171`, -2.9949387830955003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1265447001883655`, 1.4641684174468275`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274837458950583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5307703656486717`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830954994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.274837458950583, -1.5307703656486717`], 
            Complex[1.1482927587622176`, -2.9949387830954994`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1693795823985345`, 1.3470131774613308`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[1.965471402661748, -0.21994823865092936`], 
            Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9722130711912573`, 1.3470131774613308`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[5.107064056251541, -0.21994823865093072`], 
            Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.416405526246223, 1.1810102592998388`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.540555479985998, 0.031015267178413904`], 
            Complex[4.956961006232221, -1.149994992121425]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7251871273435702`, 1.1810102592998388`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.682148133575791, 0.03101526717841391], 
            Complex[4.956961006232221, -1.149994992121425]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454712405988097, 1.2350792542307416`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.166559484680516, 0.8887472233381511], 
            Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868802476016957`, 1.2350792542307414`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.30815213827031, 0.888747223338151], 
            Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4357662493946903`, 1.1148947905535158`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.187649639046593, -0.8968191263829133], 
            Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7058264041951023`, 1.1148947905535158`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.329242292636387, -0.8968191263829126], 
            Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.127184487319168, 1.4641143131625942`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274042582367506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5337079659185715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.274042582367506, -1.5337079659185715`], 
            Complex[1.1468580950483382`, -2.997822279081166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0144081662706255`, 1.4641143131625947`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13244992877771303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.533707965918572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[0.13244992877771303`, -1.533707965918572], 
            Complex[1.1468580950483385`, -2.997822279081167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.970761534818717, 1.345770114706572}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[5.116768207416752, -0.21942020556585193`], 
            Complex[3.146006672598035, -1.565190320272424]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.170831118771076, 1.3457701147065713`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[1.9751755538269593`, -0.21942020556585135`], 
            Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4152070006996476`, 1.1811618751121893`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.531882200536309, 0.031652040121196476`], 
            Complex[4.947089201235956, -1.149509834990993]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.726385652890146, 1.181161875112189}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.673474854126102, 0.031652040121196295`], 
            Complex[4.947089201235956, -1.149509834990993]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868643267559915`, 1.235548319671038}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.308192723503184, 0.8942551097650254], 
            Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4547283268338027`, 1.2355483196710382`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.166600069913391, 0.8942551097650246], 
            Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4356421353888404`, 1.1143944238128876`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.187545867473453, -0.9023320727684235], 
            Complex[7.623188002862294, -2.016726496581311]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.705950518200953, 1.1143944238128878`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.329138521063246, -0.9023320727684233], 
            Complex[7.623188002862294, -2.016726496581311]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.013770494935669, 1.4640622765843974`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13166465378465506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.000687344535021`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[0.13166465378465506`, -1.5366250679506237`], 
            Complex[1.1454351487203238`, -3.000687344535021]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.127822158654124, 1.4640622765843978`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.273257307374448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0006873445350215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.273257307374448, -1.5366250679506237`], 
            Complex[1.1454351487203243`, -3.0006873445350215`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9692921448019527`, 1.3445302612739585`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[5.126512565878383, -0.21892755421211518`], 
            Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1723005087878409`, 1.3445302612739587`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[1.984919912288591, -0.2189275542121152], 
            Complex[3.157220421076432, -1.563457815486074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.727598956056335, 1.1813141422489608`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.664755753090322, 0.03231048635665902], 
            Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4139936975334577`, 1.181314142248961}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.5231630995005294`, 0.03231048635665899], 
            Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4547439138238305`, 1.2360136313565446`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.166639211685018, 0.8996963572765853], 
            Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868487397659613`, 1.2360136313565446`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.30823186527481, 0.8996963572765849], 
            Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7060741455596737`, 1.1138977710426565`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.329036761909217, -0.9077783332310709], 
            Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4355185080301205`, 1.1138977710426565`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.187444108319425, -0.9077783332310714], 
            Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.128457726618374, 1.4640122777325144`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.272481452587111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174738`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1440237259687367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.003534245149988`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[3.272481452587111, -1.5395219674174738`], 
            Complex[1.1440237259687367`, -3.003534245149988]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0131349269714203`, 1.4640122777325137`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13088879899731687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.144023725968737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0035342451499867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[0.13088879899731687`, -1.5395219674174727`], 
            Complex[1.144023725968737, -3.0035342451499867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.967804487693707, 1.3432936676787466`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[5.1362994292403545`, -0.21847119055042014`], 
            Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.173788165896087, 1.3432936676787464`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[1.9947067756505623`, -0.21847119055042036`], 
            Complex[3.168494941546649, -1.561764858229167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4127651532889667`, 1.1814669917075291`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[3.5143959213393177`, 0.03299175641234993], 
            Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7288275003008264`, 1.1814669917075293`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[6.655988574929111, 0.03299175641235], 
            Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4547591745448698`, 1.2364752759226942`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.166676972224923, 0.9050726361762731], 
            Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868334790449246`, 1.2364752759226945`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.308269625814717, 0.9050726361762732], 
            Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.435395358506763, 1.1134047459427387`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.187344289864064, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7061972950830304`, 1.1134047459427387`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.328936943453858, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.01250145002292, 1.4639642872048653`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13012218777282775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5423989534195135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[0.13012218777282775`, -1.5423989534195135`], 
            Complex[1.1426236377957477`, -3.0063632406243785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1290912035668725`, 1.4639642872048664`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.271714841362621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.542398953419513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.271714841362621, -1.542398953419513], 
            Complex[1.1426236377957488`, -3.0063632406243794`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.175294527823507, 1.3420603933068522`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[2.004538523616137, -0.21805211056251306`], 
            Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9662981257662862`, 1.3420603933068522`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[5.1461311772059295`, -0.21805211056251345`], 
            Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7300717724455676`, 1.1816203455938787`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.647170981866, 0.03369708483581625], 
            Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.411520881144225, 1.181620345593879}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.505578328276208, 0.03369708483581626], 
            Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4547741163360683`, 1.2369333367073785`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.166713410320053, 0.9103855526005633], 
            Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868185372537243`, 1.2369333367073783`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.308306063909846, 0.9103855526005625], 
            Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4352726782736545`, 1.1129152655051353`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.1872463440644, -0.9184774165528232], 
            Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.706319975316139, 1.112915265505135}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.328838997654197, -0.9184774165528234], 
            Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0118700518065102`, 1.4639182761623937`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12936464805013348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545256308683994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[0.12936464805013348`, -1.545256308683994], 
            Complex[1.1412346998566436`, -3.009174584846388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.129722601783285, 1.4639182761623937`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2709573016399287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5452563086839952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846389`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.2709573016399287`, -1.5452563086839952`], 
            Complex[1.1412346998566438`, -3.009174584846389]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9647725954512947`, 1.3408305074796951`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[5.156010276958656, -0.21767140788446362`], 
            Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1768200581384982`, 1.3408305074796951`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[2.014417623368864, -0.21767140788446343`], 
            Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7313322842569507`, 1.1817741160640707`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.6383005484916495`, 0.03442779801852971], 
            Complex[4.906968264234699, -1.147346318045541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4102603693328428`, 1.1817741160640705`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.4967078949018573`, 0.03442779801852968], 
            Complex[4.9069682642347, -1.147346318045541]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6868039072904113`, 1.2373878939241858`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.308341235139771, 0.9156366518516708], 
            Complex[7.621537327849359, -0.321751242072515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454788746299382, 1.2373878939241858`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.166748581549979, 0.9156366518516704], 
            Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4351504590415323`, 1.1124292498408201`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.187150206311988, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7064421945482613`, 1.1124292498408201`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.328742859901782, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.130351933478976, 1.4638742163149014`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270208665786776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.548094309756492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0119685260713935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.270208665786776, -1.548094309756492], 
            Complex[1.1398567323078, -3.0119685260713935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0112407201108176`, 1.4638742163149012`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12861601219698304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5480943097564914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0119685260713926`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[0.12861601219698304`, -1.5480943097564914`], 
            Complex[1.1398567323078006`, -3.0119685260713926`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1783652479401072`, 1.3396040906581876`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[2.0243466352667068`, -0.21733028233169743`], 
            Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9632274056496855`, 1.3396040906581876`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[5.1659392888564994`, -0.2173302823316979], 
            Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4089830794337166`, 1.1819282041262438`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.4877821024662152`, 0.035185322904060734`], 
            Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.732609574156076, 1.181928204126243}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.629374756056008, 0.03518532290406068], 
            Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548030713094067`, 1.237839024824116}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.166782538502952, 0.9208274215121246], 
            Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686789582280386, 1.2378390248241162`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.308375192092747, 0.9208274215121248], 
            Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7065639608230774`, 1.1119466220181595`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.328648468799225, -0.9289289945966074], 
            Complex[7.622084507976147, -2.040875616614767]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4350286927667169`, 1.11194662201816}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.1870558152094315`, -0.9289289945966069], 
            Complex[7.622084507976148, -2.040875616614767]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0106134427976707`, 1.463832079907348}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12787611686319877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5509132271850385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0147453070923866`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[0.12787611686319877`, -1.5509132271850385`], 
            Complex[1.1384895596608695`, -3.0147453070923866`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1309792107921224`, 1.4638320799073483`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2694687704529923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5509132271850388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.014745307092387`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.2694687704529923`, -1.5509132271850388`], 
            Complex[1.1384895596608702`, -3.014745307092387]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9616620359006434`, 1.3383812358066196`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[5.175920872451979, -0.21703004943242454`], 
            Complex[3.214258836551336, -1.555411285239044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1799306176891504`, 1.3383812358066198`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[2.034328218862186, -0.2170300494324249], 
            Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4076884445201667`, 1.1820824982824254`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.478798332845711, 0.03597119669747849], 
            Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.733904209069626, 1.1820824982824254`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.620390986435504, 0.03597119669747851], 
            Complex[4.886486777365879, -1.146111301584947]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6867755555670472`, 1.2382868038466883`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.30840798456442, 0.9259592943584085], 
            Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548170980227455`, 1.238286803846688}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.166815330974628, 0.9259592943584081], 
            Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.434907371641311, 1.1114673079119288`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.186963112364547, -0.9340656567439883], 
            Complex[7.621870484005858, -2.045532964655917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.706685281948481, 1.111467307911929}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.32855576595434, -0.9340656567439881], 
            Complex[7.62187048400586, -2.045532964655917]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.009988207802897, 1.4637918397065666`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12714480283990298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973077`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.017505165403874`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[0.12714480283990298`, -1.5537133256973077`], 
            Complex[1.1371330106428, -3.017505165403874]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1316044457868935`, 1.4637918397065677`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268737456429699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0175051654038723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.268737456429699, -1.5537133256973044`], 
            Complex[1.1371330106428055`, -3.0175051654038723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9600759343969185`, 1.3371620499406358`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[5.185957792848567, -0.21677215110365716`], 
            Complex[3.225881858451649, -1.553934201044293]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.181516719192875, 1.3371620499406358`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[2.0443651392587743`, -0.2167721511036576], 
            Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7352167864337187`, 1.182236872985964}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.611346515764966, 0.03678707771053715], 
            Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4063758671560753`, 1.1822368729859638`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.469753862175173, 0.036787077710537186`], 
            Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7068061655059004`, 1.1109912360620862`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.328464695790345, -0.9391447601963729], 
            Complex[7.621658530284444, -2.050135996258459]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4347864880838939`, 1.1109912360620862`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.186872042200558, -0.9391447601963707], 
            Complex[7.621658530284452, -2.050135996258457]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686761820702876, 1.2387313027612807`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.308439659740836, 0.931033651089264], 
            Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548308328869182`, 1.2387313027612805`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.166847006151044, 0.9310336510892632], 
            Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0093650031370596`, 1.4637534689884129`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12642191492445268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5564948643711098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0202483333595227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[0.12642191492445268`, -1.5564948643711098`], 
            Complex[1.1357869180615123`, -3.0202483333595227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1322276504527338`, 1.463753468988413}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268014568514247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.55649486437111`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.020248333359523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.268014568514247, -1.55649486437111], 
            Complex[1.1357869180615132`, -3.020248333359523]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1831241377564927`, 1.3359466558875899`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[2.054460273810074, -0.2165581676245985], 
            Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9584685158333004`, 1.3359466558875897`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[5.196052927399868, -0.21655816762459845`], 
            Complex[3.237584411566567, -1.552504823512188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4050447172256824`, 1.1823911868863113`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.460645854137856, 0.03763475749771081], 
            Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7365479363641099`, 1.1823911868863113`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.60223850772765, 0.037634757497710766`], 
            Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4346660347306186`, 1.110518337541556}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.186782551780801, -0.9441676368090823], 
            Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.706926618859174, 1.1105183375415557`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.328375205370595, -0.9441676368090878], 
            Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548442821488388`, 1.2391725907994695`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.166877608777316, 0.9360518228828759], 
            Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686748371440953, 1.2391725907994697`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.30847026236711, 0.9360518228828761], 
            Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.132848836703721, 1.463716941525286}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.267299955380531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0229750383238807`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.267299955380531, -1.559258096798595], 
            Complex[1.1344511186768103`, -3.0229750383238807`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0087438168860727`, 1.463716941525286}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12570730179073827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.02297503832388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[0.12570730179073827`, -1.559258096798594], 
            Complex[1.1344511186768111`, -3.02297503832388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9568391590740137`, 1.3347351942924115`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[5.206209272752708, -0.2163898310860751], 
            Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.184753494515779, 1.3347351942924108`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[2.0646166191629156`, -0.21638983108607387`], 
            Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4036943295828475`, 1.1825452808280361`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.4514713529124292`, 0.03851617446207811], 
            Complex[4.855165682495277, -1.144029106365958]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7378983240069454`, 1.1825452808280361`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.593064006502223, 0.038516174462077585`], 
            Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7070466491630236`, 1.110048545832322}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.32828724423658, -0.9491355712999281], 
            Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.434546004426769, 1.110048545832322}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.186694590646789, -0.9491355712999217], 
            Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6867352017268906`, 1.2396107347790484`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.308499834903161, 0.9410150937958542], 
            Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454857451862902, 1.2396107347790482`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.166907181313368, 0.9410150937958539], 
            Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.133468016378014, 1.4636822315740619`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2665934694544774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5620032712443408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.2665934694544774`, -1.5620032712443408`], 
            Complex[1.1331254530764636`, -3.0256855028184027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0081246372117791`, 1.4636822315740612`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12500081586468456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5620032712443406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[0.12500081586468456`, -1.5620032712443406`], 
            Complex[1.1331254530764638`, -3.0256855028184018`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1864054489657596`, 1.333527825907882}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[2.0748372986380015`, -0.2162690405227275], 
            Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.955187204624033, 1.3335278259078818`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[5.216429952227797, -0.21626904052272788`], 
            Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.402324001504694, 1.1826989755651818`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.442227275783197, 0.03943342913804209], 
            Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7392686520850986`, 1.1826989755651816`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.58381992937299, 0.03943342913804175], 
            Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4344263902186833`, 1.1095817967091959`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.186608110668219, -0.9540498035022783], 
            Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.70716626337111, 1.1095817967091957`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.328200764258014, -0.9540498035022821], 
            Complex[7.621034500886904, -2.063631600211478]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454870347898664, 1.240045799220364}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.166935764077781, 0.9459247030157971], 
            Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6867223056911294`, 1.240045799220364}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.308528417667576, 0.9459247030157971], 
            Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1340852012373577`, 1.4636493138643771`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.265894966794422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976763`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1318097655570643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.265894966794422, -1.5647306307976763`], 
            Complex[1.1318097655570643`, -3.028379944662053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0075074523524359`, 1.4636493138643776`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12430231320462909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.131809765557065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[0.12430231320462909`, -1.5647306307976756`], 
            Complex[1.131809765557065, -3.028379944662053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.188080701701171, 1.332324734215096}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[2.0851255699314044`, -0.21619787896744103`], 
            Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9535119518886213`, 1.3323247342150963`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[5.226718223521198, -0.2161978789674424], 
            Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4009329899339835`, 1.182852069145198}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.4329104054302233`, 0.04038880139063529], 
            Complex[4.833843395364207, -1.142463267754563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.74065966365581, 1.1828520691451987`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.574503059020016, 0.040388801390635574`], 
            Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4343071853460703`, 1.1091180281307045`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.186523065904121, -0.9589115304824511], 
            Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.707285468243723, 1.1091180281307047`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.328115719493917, -0.9589115304824558], 
            Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6867096776416257`, 1.2404778464555413`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.308556048970686, 0.9507818469782096], 
            Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548829759481676`, 1.2404778464555413`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.166963395380894, 0.9507818469782096], 
            Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.134700402966668, 1.4636181635872803`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2652043069761856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.2652043069761856`, -1.5674404135194786`], 
            Complex[1.1305039040095175`, -3.0310585771067586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0068922506231268`, 1.4636181635872798`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1236116533863979`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095248`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[0.1236116533863979, -1.5674404135194724`], 
            Complex[1.1305039040095248`, -3.0310585771067524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9518126562049785`, 1.3311261284280649`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[5.237077486695947, -0.21617863270584659`], 
            Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1897799973848153`, 1.3311261284280653`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[2.0954848331061537`, -0.21617863270584692`], 
            Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7420721450957446`, 1.1830043339085188`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.565110035519868, 0.04138476980950452], 
            Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3995205084940483`, 1.1830043339085197`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.423517381930075, 0.04138476980950441], 
            Complex[4.823037890424123, -1.141619564099015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7074042703551173`, 1.10865718013655}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.328032066063827, -0.9637219085312987], 
            Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.434188383234677, 1.10865718013655}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.186439412474038, -0.9637219085313011], 
            Complex[7.620627795708716, -2.072379088667851]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4548953415329267`, 1.240906936731121}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.166990111648028, 0.9555876813576081], 
            Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866973120568676`, 1.240906936731121}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.308582765237823, 0.9555876813576076], 
            Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.135313633173682, 1.463588756384217}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2645213529825936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.03372160896789`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.2645213529825936`, -1.5701328525836726`], 
            Complex[1.1292077198089117`, -3.03372160896789]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.006279020416114, 1.4635887563842214`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12292869939280154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0337216089678942`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[0.12292869939280154`, -1.5701328525836726`], 
            Complex[1.1292077198089157`, -3.0337216089678942`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9500885256298572`, 1.329932246946235}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[5.247511292414014, -0.21621381305374007`], 
            Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.191504127959936, 1.3299322469462351`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[2.1059186388242215`, -0.21621381305374038`], 
            Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3980857242601568`, 1.183155513039994}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.4140446945168277`, 0.042424033620649226`], 
            Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7435069293296361`, 1.183155513039994}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.555637348106621, 0.04242403362064838], 
            Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4340699774892993`, 1.1081991947511818`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.1863571084384, -0.9684820550389218], 
            Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7075226761004942`, 1.1081991947511818`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.327949762028192, -0.9684820550389235], 
            Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454907450010565, 1.2413331283045883`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.167015947533717, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866852035792277`, 1.2413331283045885`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.30860860112351, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0056677502011402`, 1.4635610683363465`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12225331750747458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5728081764136674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0363692447500137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[0.12225331750747458`, -1.5728081764136674`], 
            Complex[1.1279210677086149`, -3.0363692447500137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.135924903388653, 1.4635610683363471`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2638459710972687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5728081764136679`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.036369244750015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.2638459710972687`, -1.5728081764136679`], 
            Complex[1.1279210677086156`, -3.036369244750015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1932539361222496`, 1.328743361330418}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[2.116430696743796, -0.21630618103294583`], 
            Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9483387174675437`, 1.3287433613304183`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[5.258023350333589, -0.21630618103294588`], 
            Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3966277542716592`, 1.1833053165967147`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.4044886731783923`, 0.043509537491681564`], 
            Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7449648993181337`, 1.1833053165967153`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.546081326768186, 0.04350953749168187], 
            Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4339519618871137`, 1.1077440158930363`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.186276113687406, -0.9731930502608692], 
            Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7076406917026798`, 1.1077440158930363`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.327868767277202, -0.9731930502608676], 
            Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866733470086253`, 1.2417564775352328`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.308633589617479, 0.9650498513977598], 
            Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.454919306581168, 1.2417564775352328`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.1670409360276865`, 0.9650498513977598], 
            Complex[7.621960242608855, -0.276706626137473]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1365342250641253`, 1.4635350759541859`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2631780308024685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.575466608813974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.126643805738343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.03900168476816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.2631780308024685`, -1.575466608813974], 
            Complex[1.126643805738343, -3.03900168476816]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.0050584285256683`, 1.4635350759541867`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12158537721267502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754666088139742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1266438057383434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.039001684768161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[0.12158537721267502`, -1.5754666088139742`], 
            Complex[1.1266438057383434`, -3.039001684768161]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1950303190658118`, 1.3275597808917121`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[2.127024883972908, -0.21645877538292152`], 
            Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9465623345239813`, 1.3275597808917121`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[5.268617537562701, -0.21645877538292138`], 
            Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7464469918190846`, 1.1834534169226607`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.536438133786874, 0.04464449966811444], 
            Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3951456617707092`, 1.1834534169226611`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.3948454801970804`, 0.044644499668114825`], 
            Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.707758323218489, 1.107291589289035}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.327789043427426, -0.9778559389833152], 
            Complex[7.620030720208938, -2.08514752827235]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4338343303713053`, 1.107291589289035}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.186196389837632, -0.977855938983316], 
            Complex[7.620030720208938, -2.085147528272351]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866617372964796`, 1.242177038969738}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.30865776214308, 0.9697083109361536], 
            Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549309162933137`, 1.242177038969738}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.167065108553286, 0.9697083109361534], 
            Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.004451044015045, 1.4635107561675484`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12092475109102498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5781083690971813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.04161912526473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[0.12092475109102498`, -1.5781083690971813`], 
            Complex[1.1253757951060699`, -3.04161912526473]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.137141609574748, 1.463510756167548}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2625174046808185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5781083690971809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.041619125264729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.2625174046808185`, -1.5781083690971809`], 
            Complex[1.1253757951060703`, -3.041619125264729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9447584210754476`, 1.326381857999865}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[5.279297907015237, -0.2166749444176823], 
            Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1968342325143455`, 1.3263818579998652`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[2.137705253425444, -0.21667494441768215`], 
            Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.747954201433849, 1.1835994433436996`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.526703755378124, 0.045832443950467455`], 
            Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.393638452155945, 1.1835994433436998`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.3851111017883304`, 0.045832443950466685`], 
            Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4337170770449974`, 1.1068418623939869`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.186117900135718, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7078755765447962`, 1.1068418623939869`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.327710553725511, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549422840498412`, 1.2425948654228762`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.1670884950589855`, 0.974319711882344], 
            Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866503695399515`, 1.2425948654228762`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.30868114864878, 0.974319711882344], 
            Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1377470682171404`, 1.4634880863157818`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2618639683207284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5807336722064977`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1241169001035878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0442217585222795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.2618639683207284`, -1.5807336722064977`], 
            Complex[1.1241169001035878`, -3.0442217585222795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.003845585372653, 1.4634880863157815`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12027131473093523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.580733672206497`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.124116900103588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0442217585222786`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[0.12027131473093523`, -1.580733672206497], 
            Complex[1.124116900103588, -3.0442217585222786`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.94292595854457, 1.3252099942378486`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[5.29006869545568, -0.21695838232209166`], 
            Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.1986666950452238`, 1.3252099942378486`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[2.1484760418658873`, -0.21695838232209172`], 
            Complex[3.347142736911111, -1.54216837655994]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.392105068643895, 1.1837429760162148`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.3752813400511936`, 0.04707723610641603], 
            Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7494875849458982`, 1.1837429760162148`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.516873993640987, 0.047077236106415926`], 
            Complex[4.767386408695089, -1.136665739909799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.433600196165447, 1.1063947843145434`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.186040609368656, -0.9870414080668142], 
            Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7079924574243457`, 1.1063947843145436`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.32763326295845, -0.9870414080668136], 
            Complex[7.619640805534105, -2.093436192381357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549534146133523`, 1.2430100080536353`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.167111124103515, 0.9788850321593934], 
            Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866392389764404`, 1.243010008053636}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.308703777693312, 0.9788850321593942], 
            Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0032420413799856`, 1.4634670441382973`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11962494663556839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[0.11962494663556839`, -1.5833427288340611`], 
            Complex[1.1228669880155542`, -3.0468097729723587`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1383506122098077`, 1.4634670441382973`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2612176002253626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.2612176002253626`, -1.5833427288340611`], 
            Complex[1.1228669880155548`, -3.0468097729723587`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2005287927065205`, 1.32404464755377}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[2.15934167735015, -0.21731317057992383`], 
            Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9410638608832727`, 1.32404464755377}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[5.300934330939945, -0.21731317057992383`], 
            Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.390544387637713, 1.1838835387782198`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.365351805523236, 0.04838312541060397], 
            Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.75104826595208, 1.1838835387782194`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.50694445911303, 0.04838312541060556], 
            Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4334836821385069`, 1.105950305737408}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.18596448378006, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7081089714512874`, 1.105950305737408}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.327557137369855, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866283409783382`, 1.243422516437101}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.308725676524938, 0.9834052186894814], 
            Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549643126114553`, 1.243422516437101}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.167133022935145, 0.9834052186894809], 
            Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0026404008966956`, 1.4634476077653662`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11898552813518211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0493833533005414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[0.11898552813518211`, -1.5859357455351755`], 
            Complex[1.1216259290318777`, -3.0493833533005414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1389522526930973`, 1.4634476077653664`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.260578181724976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.049383353300541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.260578181724976, -1.5859357455351744`], 
            Complex[1.1216259290318786`, -3.049383353300541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2024216839171922`, 1.3228863405905453`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[2.170306785665302, -0.21774382534019746`], 
            Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9391709696726003`, 1.322886340590545}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[5.311899439255096, -0.21774382534019754`], 
            Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3889552138131371`, 1.184020590822548}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.3553179107369844`, 0.049754792118764775`], 
            Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7526374397766562`, 1.1840205908225483`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.496910564326778, 0.04975479211876483], 
            Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7082251240764754`, 1.1055083788614972`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.327482144581792, -0.9960461687506829], 
            Complex[7.619257020505317, -2.10155454761218]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4333675295133188`, 1.105508378861497}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1858894909919995`, -0.9960461687506831], 
            Complex[7.619257020505318, -2.10155454761218]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866176710480196`, 1.2438324386323736`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.308746871155384, 0.9878811887189863], 
            Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549749825417748`, 1.2438324386323738`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1671542175655905`, 0.9878811887189864], 
            Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0020406528605892`, 1.4634297557091838`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11835294330270157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5885129248386511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632907`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[0.11835294330270157`, -1.5885129248386511`], 
            Complex[1.1203935961632907`, -3.051942680547835]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.139552000729204, 1.4634297557091849`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.259945596892496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58851292483865`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.259945596892496, -1.58851292483865], 
            Complex[1.1203935961632925`, -3.051942680547835]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2043466046253615`, 1.3217356704088934`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[2.181376195232895, -0.2182553516597405], 
            Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9372460489644316`, 1.3217356704088938`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[5.322968848822688, -0.21825535165974055`], 
            Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7542563786430847`, 1.184153516976573}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.486767518902965, 0.0511974018142995], 
            Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3873362749467086`, 1.1841535169765731`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.345174865313174, 0.0511974018142957], 
            Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7083409206125306`, 1.1050689573338088`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.32740825352173, -1.000483060574067], 
            Complex[7.6190673329092, -2.105552017907876]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{-1.4332517329772636`, 1.1050689573338088`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.185815599931938, -1.000483060574068], 
            Complex[7.619067332909202, -2.105552017907877]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6866072248130584`, 1.2442398212467847`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.308767386428746, 0.9923138310722672], 
            Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549854287767352`, 1.2442398212467847`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.167174732838952, 0.992313831072267], 
            Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0014427862875899`, 1.463413466855192}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11772707887238294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5910744653534168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1191698651599729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0544879322086085`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[0.11772707887238294`, -1.5910744653534168`], 
            Complex[1.1191698651599729`, -3.0544879322086085`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.140149867302204, 1.4634134668551917`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2593197324621768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5910744653534166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.119169865159973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.054487932208608`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.2593197324621768`, -1.5910744653534166`], 
            Complex[1.119169865159973, -3.054487932208608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9352877799119723`, 1.3205933198612423`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[5.334147593347899, -0.21885330570991693`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2063048736778208`, 1.3205933198612425`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[2.1925549397581063`, -0.21885330570991673`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7559064370566704`, 1.1842816163308607`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.476510326898408, 0.05271666771536847], 
            Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.385686216533123, 1.1842816163308607`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.3349176733086154`, 0.052716667715368405`], 
            Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4331362873511135`, 1.1046319961887376`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.185742780764412, -1.004877451924907], 
            Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7084563662386807`, 1.104631996188737}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.327335434354206, -1.0048774519249142`], 
            Complex[7.618879068115525, -2.109509448113651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4549956555681354`, 1.244644709496656}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.167194592496085, 0.9967040073387544], 
            Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865969980216582`, 1.2446447094966562`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.30878724608588, 0.9967040073387546], 
            Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.0008467902716613`, 1.4633987204536416`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11710782416143134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.593620561871549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0570192823251907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[0.11710782416143134`, -1.593620561871549], 
            Complex[1.1179546144330925`, -3.0570192823251907`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.14074586331813, 1.4633987204536427`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258700477751228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5936205618715453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.057019282325188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.258700477751228, -1.5936205618715453`], 
            Complex[1.1179546144330978`, -3.057019282325188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.933294755267063, 1.319460070924297}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[5.34544091125561, -0.21954386620430968`], 
            Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2082978983227308`, 1.319460070924297}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[2.2038482576658165`, -0.2195438662043097], 
            Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3840035962697157`, 1.184404088909025}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.3245411337774544`, 0.05431892219952697], 
            Complex[4.70854473004717, -1.130085166709498]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.757589057320077, 1.184404088909025}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.466133787367247, 0.05431892219952709], 
            Complex[4.70854473004717, -1.130085166709498]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4330211875844063`, 1.1041974517906232`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.185671004827051, -1.0092301787755908`], 
            Complex[7.618692192411457, -2.113427630566214]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7085714660053872`, 1.1041974517906228`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.327263658416845, -1.009230178775591], 
            Complex[7.618692192411457, -2.113427630566214]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455005667051508, 1.2450471472648306`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.167213819234735, 1.0010525529976395`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865869865382848`, 1.2450471472648308`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.308806472824529, 1.0010525529976397`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-1.000252653984706, 1.4633854961114101`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1164950709944641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.596151405467845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[0.1164950709944641, -1.596151405467845], 
            Complex[1.1167477249791702`, -3.0595369015792553`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1413399996050866`, 1.46338549611141}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258087724584257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5961514054678452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.258087724584257, -1.5961514054678452`], 
            Complex[1.1167477249791709`, -3.0595369015792553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2103271797234791`, 1.3183368203574148`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[2.2152615870464745`, -0.2203339164903331], 
            Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9312654738663138`, 1.3183368203574148`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[5.356854240636268, -0.2203339164903332], 
            Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.382286878530116, 1.1845200200116413`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.314039845823023, 0.05601119898888117], 
            Complex[4.696326724353138, -1.12850882102276]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7593057750596772`, 1.1845200200116415`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.4556324994128165`, 0.05601119898888104], 
            Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7086862248387757`, 1.1037652817793195`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.327192898160455, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4329064287510185`, 1.1037652817793198`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.18560024457066, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865771863394972`, 1.2454471771551758`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.308825088355581, 1.0053602784840994`], 
            Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550154672502962`, 1.2454471771551758`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.16723243476579, 1.005360278484099], 
            Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.999660366676408, 1.4633737737840233`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11588871363063293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0620409573801792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[0.11588871363063293`, -1.5986671835961561`], 
            Complex[1.115549080307041, -3.0620409573801792`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.141932286913384, 1.4633737737840231`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.257481367220427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.062040957380181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.257481367220427, -1.5986671835961581`], 
            Complex[1.115549080307043, -3.062040957380181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2123943182999422`, 1.317224598123756}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[2.2268005544144556`, -0.22123113894674887`], 
            Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9291983352898505`, 1.317224598123756}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[5.36839320800425, -0.2212311389467491], 
            Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7610582245789832`, 1.184628361797253}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.445000873427293, 0.05780132763801389], 
            Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3805344290108104`, 1.184628361797253}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.3034082198375003`, 0.05780132763801396], 
            Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4327920060449164`, 1.103335445018596}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.185530473503019, -1.017813858605525], 
            Complex[7.618322479547935, -2.121149303624121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7088006475448771`, 1.1033354450185966`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.327123127092824, -1.0178138586055234`], 
            Complex[7.618322479547946, -2.12114930362412]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865675935099471`, 1.2458448405442555`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.308843113455703, 1.0096279702007276`], 
            Complex[7.622275519945756, -0.236216870343528]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550250600798462`, 1.2458448405442557`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.16725045986591, 1.0096279702007271`], 
            Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1425227359157137`, 1.4633635337679243`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.256881302283198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60116808018249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1143585663674842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.064531613950414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.256881302283198, -1.60116808018249], 
            Complex[1.1143585663674842`, -3.064531613950414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9990699176740798, 1.4633635337679245`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11528864869340531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6011680801824892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.114358566367485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0645316139504137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[0.11528864869340531`, -1.6011680801824892`], 
            Complex[1.114358566367485, -3.0645316139504137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9270916349625458`, 1.3161245890920883`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[5.380063608617472, -0.22224412353114406`], 
            Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.214501018627248, 1.3161245890920878`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[2.23847095502768, -0.2222441235311438], 
            Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3787445098205147`, 1.1847279115826053`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.292640497180628, 0.059698042168788046`], 
            Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7628481437692785`, 1.184727911582605}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.434233150770422, 0.05969804216878785], 
            Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4326779147761108`, 1.1029079015471879`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.185461666136161, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7089147388136834`, 1.1029079015471879`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.327054319725956, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550344493512168`, 1.2462401776303484`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.167267914426828, 1.013856391477559], 
            Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865582042385758`, 1.2462401776303484`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.308860568016621, 1.0138563914775585`], 
            Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9984812963824463, 1.463354756692947}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11469477510277208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.603654275715108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408055`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[0.11469477510277208`, -1.603654275715108], 
            Complex[1.1131760714852184`, -3.067009032408055]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1431113572073444`, 1.4633547566929477`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2562874286925667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.603654275715105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2562874286925667`, -1.603654275715105], 
            Complex[1.1131760714852224`, -3.067009032408053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9249435600872458`, 1.3150381586291193`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[5.39187137537774, -0.22338249250843517`], 
            Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2166490935025478`, 1.3150381586291193`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[2.250278721787946, -0.22338249250843553`], 
            Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7646773781879659`, 1.184817286252228}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.423323434867788, 0.061711105883242766`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.376915275401828, 1.1848172862522282`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2817307812779952`, 0.061711105883242925`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4325641503667563`, 1.1024826125323357`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.185393797936859, -1.0262403046082502`], 
            Complex[7.617957948303616, -2.128722917140586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7090285032230363`, 1.1024826125323355`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.326986451526654, -1.0262403046082496`], 
            Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865490148149482`, 1.2466332274799763`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.308877471091341, 1.0180462834838366`], 
            Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550436387748453`, 1.2466332274799765`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.167284817501548, 1.0180462834838364`], 
            Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1436981613063537`, 1.463347423514998}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.255699647599667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.606125947331712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1120014862933134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.255699647599667, -1.606125947331712], 
            Complex[1.1120014862933134`, -3.06947337084671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.99789449228344, 1.4633474235149988`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11410699400987415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6061259473317113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.112001486293314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[0.11410699400987415`, -1.6061259473317113`], 
            Complex[1.112001486293314, -3.06947337084671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9227521869647504`, 1.3139668827936113`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[5.403822532373675, -0.2246570435317341], 
            Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2188404666250434`, 1.3139668827936108`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[2.2622298787838817`, -0.2246570435317342], 
            Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.766547883749865, 1.1848948920661317`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.412265737666768, 0.06385145452602968], 
            Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3750447698399282`, 1.184894892066132}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.270673084076976, 0.06385145452602974], 
            Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4324507083474414`, 1.10205954022566}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.185326845280091, -1.030396405990655], 
            Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7091419452423504`, 1.1020595402256603`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.326919498869884, -1.030396405990655], 
            Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865400216257653`, 1.2470240280720963`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.308893840937472, 1.0221983660944407`], 
            Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550526319640273`, 1.2470240280720963`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.167301187347679, 1.0221983660944405`], 
            Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9973094949359221, 1.4633415155089324`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11352520873386833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.608583268903826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[0.11352520873386833`, -1.608583268903826], 
            Complex[1.1108347036697903`, -3.0719247844127584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1442831586538693`, 1.4633415155089313`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2551178623236616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6085832689038237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2551178623236616`, -1.6085832689038237`], 
            Complex[1.1108347036697925`, -3.0719247844127553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.221077173107132, 1.3129125839498217`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[2.274330474286138, -0.22607991328743204`], 
            Complex[3.49540764739327, -1.538992497237254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9205154804826614`, 1.3129125839498215`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[5.415923127875931, -0.22607991328743238`], 
            Complex[3.49540764739327, -1.538992497237254]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3731309263404174`, 1.1849588890480656`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2594613930506555`, 0.06613136000835836], 
            Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7684617272493757`, 1.184958889048066}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.401054046640449, 0.06613136000835822], 
            Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4323375843536073`, 1.1016386479212323`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.18526078540529, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7092550692361863`, 1.1016386479212323`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.326853438995084, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.68653122115152, 1.2474126163400958`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.3089096950579, 1.0263133387136967`], 
            Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550614324382742`, 1.2474126163400958`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.167317041468107, 1.0263133387136971`], 
            Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9967262939754451, 1.4633370142616386`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1129493247010233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[0.1129493247010233, -1.611026411118455], 
            Complex[1.1096756186764682`, -3.0743634253800933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.144866359614347, 1.4633370142616386`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.254541978290817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.254541978290817, -1.611026411118455], 
            Complex[1.1096756186764698`, -3.0743634253800933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2233613567236128`, 1.3118773727195494`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[2.2865864863773204`, -0.2276647637711871], 
            Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9182312968661799`, 1.3118773727195492`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[5.428179139967114, -0.22766476377118722`], 
            Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7704210836204086`, 1.1850071490350698`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.389682419157071, 0.06856461676025156], 
            Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3711715699693845`, 1.18500714903507}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.2480897655672782`, 0.06856461676025145], 
            Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.43222477412213, 1.1012198999156988`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.185195596375154, -1.0385978654970505`], 
            Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7093678794676628`, 1.1012198999156988`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.326788249964949, -1.0385978654970531`], 
            Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865226099632833`, 1.2477990282117282`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.30892505023899, 1.0303918810590929`], 
            Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550700436265103`, 1.2477990282117282`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.167332396649198, 1.0303918810590926`], 
            Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9961448791139301, 1.4633339016653035`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11237924938587697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.108524128499807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0767894432225034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[0.11237924938587697`, -1.6134555415571996`], 
            Complex[1.108524128499807, -3.0767894432225034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1454477744758638`, 1.4633339016653037`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.253971902975671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1085241284998075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.076789443222504`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.253971902975671, -1.6134555415571998`], 
            Complex[1.1085241284998075`, -3.076789443222504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2256952623834638`, 1.3108636972714853`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[2.2990036923040837`, -0.2294269927942462], 
            Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.915897391206329, 1.3108636972714849`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[5.440596345893878, -0.22942699279424578`], 
            Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7724282284186341`, 1.1850372063896213`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.378145113127533, 0.07116675231062962], 
            Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3691644251711594`, 1.1850372063896213`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.23655245953774, 0.07116675231062944], 
            Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7094803801017517`, 1.1008032614703513`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.326723910626667, -1.042644564958483], 
            Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4321122734880416`, 1.1008032614703516`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.185131257036874, -1.0426445649584837`], 
            Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865141847196436`, 1.2481832986471038`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.30893992258648, 1.034434653907242], 
            Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.45507846887015, 1.2481832986471038`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.1673472689966875`, 1.0344346539072418`], 
            Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9955652401393672, 1.463332159910855}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1118148922544208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[0.1118148922544208, -1.6158708247728453`], 
            Complex[1.1073801323937882`, -3.0792029846837004`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.146027413450426, 1.4633321599108555`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2534075458442144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2534075458442144`, -1.6158708247728455`], 
            Complex[1.1073801323937882`, -3.0792029846837012`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.228081221740402, 1.309874400972441}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[2.311587489979285, -0.23138396931833907`], 
            Complex[3.539668711719687, -1.54125837029078]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9135114318493907`, 1.3098744009724408`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[5.453180143569079, -0.23138396931833927`], 
            Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7744855234422623`, 1.1850462003498161`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.3664367655030105`, 0.07395526269357508], 
            Complex[4.591951242060748, -1.111090937656241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3671071301475313`, 1.1850462003498161`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2248441119132174`, 0.07395526269357484], 
            Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4320000783813807`, 1.100388698775022}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.185067746985585, -1.0466561075785734`], 
            Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.709592575208412, 1.100388698775022}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.32666040057538, -1.0466561075785734`], 
            Complex[7.617067825366967, -2.147044806353595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550867114260373`, 1.2485654616748578`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.16736167396946, 1.0384422998042997`], 
            Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6865059421637554`, 1.2485654616748578`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.308954327559254, 1.0384422998042997`], 
            Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.146605286674311, 1.4633317714815839`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2528488182990007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6182724223635778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.2528488182990007`, -1.6182724223635778`], 
            Complex[1.1062435316246895`, -3.0816041938451617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9949873669154823, 1.4633317714815843`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11125616470920796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6182724223635776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[0.11125616470920796`, -1.6182724223635776`], 
            Complex[1.1062435316246904`, -3.0816041938451617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2305216291036345`, 1.308912789344596}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[2.324342656755631, -0.2335552923600304], 
            Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9110710244861582`, 1.308912789344596}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[5.465935310345424, -0.23355529236003053`], 
            Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3649972609370349`, 1.1850308080734386`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.212959979911501, 0.07694987142173919], 
            Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7765953926527573`, 1.1850308080734382`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.354552633501294, 0.07694987142174026], 
            Complex[4.577957240848536, -1.108080936651698]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.709704468765626, 1.099976178913691}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.326597700119693, -1.0506331187508058`], 
            Complex[7.616893231354067, -2.150609297664497]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4318881848241682`, 1.0999761789136906`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.1850050465299, -1.0506331187508056`], 
            Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4550947744692657`, 1.2489455504265945`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.167375626411306, 1.0424154437428594`], 
            Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686497879120527, 1.2489455504265943`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.308968280001098, 1.042415443742859], 
            Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1471814042084056`, 1.4633327191469403`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.252295633626107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.620660493044881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.105114229417701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.252295633626107, -1.620660493044881], 
            Complex[1.105114229417701, -3.0839932121918214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9944112493813883, 1.46333271914694}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.110702980036313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6206604930448811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1051142294177012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[0.110702980036313, -1.6206604930448811`], 
            Complex[1.1051142294177012`, -3.0839932121918214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.233018903826367, 1.3079827070004018`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[2.3372730266129884`, -0.2359630690132302], 
            Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9085737497634256`, 1.3079827070004013`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[5.478865680202783, -0.23596306901323125`], 
            Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7787602845730819`, 1.1849871677042876`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.342488917419652, 0.08017280757570108], 
            Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3628323690167117`, 1.1849871677042876`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.20089626382986, 0.0801728075757009], 
            Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4317765889275107`, 1.0995656698317227`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.184943136659399, -1.0545762069524705`], 
            Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.709816064662282, 1.0995656698317222`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.326535790249194, -1.0545762069524702`], 
            Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551026610958833`, 1.2493235971697123`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.167389140580846, 1.04635469380724], 
            Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864899924939094`, 1.249323597169712}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.30898179417064, 1.04635469380724], 
            Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.993836877551217, 1.463334985956483}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11015525335407254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1039921309052896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0863701786757147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[0.11015525335407254`, -1.6230351927192315`], 
            Complex[1.1039921309052896`, -3.0863701786757147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1477557760385757`, 1.4633349859564835`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.251747906943866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.10399213090529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.086370178675715`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.251747906943866, -1.6230351927192315`], 
            Complex[1.10399213090529, -3.086370178675715]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2355754341022598`, 1.30708862462704}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[2.3503810623577226`, -0.23863220192231419`], 
            Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.906017219487533, 1.3070886246270397`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[5.491973715947518, -0.2386322019223144], 
            Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7809826160936353`, 1.1849107913888706`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.330243188435803, 0.08364909334179328], 
            Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3606100374961574`, 1.1849107913888708`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.18865053484601, 0.08364909334179278], 
            Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4316652868888176`, 1.0991571403046219`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.1848819990139186`, -1.0584859643603293`], 
            Complex[7.616547285902736, -2.157643104664951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7099273667009742`, 1.099157140304622}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.326474652603713, -1.058485964360329], 
            Complex[7.616547285902738, -2.157643104664951]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551103743254907`, 1.2496996333387003`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.167402230179722, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686482279264302, 1.2496996333387003`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.308994883769515, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9932642415137451, 1.4633385552340061`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1096129015635269`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6253966745436466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.102877143077272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0887352297776527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[0.1096129015635269, -1.6253966745436466`], 
            Complex[1.102877143077272, -3.0887352297776527`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1483284120760473`, 1.4633385552340057`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.25120555515332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6253966745436454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1028771430772724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0887352297776514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.25120555515332, -1.6253966745436454`], 
            Complex[1.1028771430772724`, -3.0887352297776514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.23819349558469, 1.3062357349604117`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[2.3636672947096224`, -0.24159066834690415`], 
            Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.903399158005103, 1.3062357349604115`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[5.5052599482994165`, -0.2415906683469046], 
            Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3583279624889977`, 1.1847964693034878`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.176222295931689, 0.08740682313953917], 
            Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7832646911007954`, 1.1847964693034878`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.317814949521482, 0.08740682313953926], 
            Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4315542749891224`, 1.0987505599082368`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.184821615854545, -1.062362967438099], 
            Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7100383786006703`, 1.098750559908237}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.326414269444339, -1.0623629674380988`], 
            Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455117917103725, 1.2500736895649893`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.167414908379169, 1.054133863773935], 
            Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864747364860686`, 1.250073689564989}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.309007561968963, 1.0541338637739348`], 
            Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9926933314319968, 1.4633434105717973`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10907584330050497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.091088499566983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[0.10907584330050497`, -1.6277450889951857`], 
            Complex[1.1017691747325018`, -3.091088499566983]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.148899322157797, 1.4633434105717977`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.250668496890299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0910884995669843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.250668496890299, -1.6277450889951866`], 
            Complex[1.1017691747325018`, -3.0910884995669843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2408751365289477`, 1.3054300547279403`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[2.3771295961517165`, -0.24486976056502352`], 
            Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.900717517060845, 1.3054300547279403`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[5.518722249741511, -0.24486976056502427`], 
            Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.785608585628156, 1.1846381677124258`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.30520636159325, 0.09147740408549994], 
            Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3559840679616366`, 1.1846381677124258`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.1636137080034565`, 0.09147740408549974], 
            Complex[4.519597775965093, -1.093160763626926]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.431443549590511, 1.0983458989903192`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.184761970036191, -1.0662077774973115`], 
            Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7101491039992827`, 1.0983458989903194`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.326354623625987, -1.0662077774973113`], 
            Complex[7.616205519626703, -2.164553676487631]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864673612851377`, 1.250445795705442}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.309019841434887, 1.0579749207033116`], 
            Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551252923046565`, 1.250445795705442}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.167427187845094, 1.0579749207033107`], 
            Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.149468516046954, 1.4633495358250663`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2501366524790782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6300805839344696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.093430119759536`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.2501366524790782`, -1.6300805839344696`], 
            Complex[1.1006681364321238`, -3.093430119759536]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9921241375428401, 1.4633495358250659`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10854399888928548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6300805839344692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0934301197595353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[0.10854399888928548`, -1.6300805839344692`], 
            Complex[1.1006681364321256`, -3.0934301197595353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2436220194611873`, 1.3046785263493106`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[2.3907622559358295`, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.897970634128606, 1.3046785263493106`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[5.532354909525623, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.353576664055477, 1.1844289272681492`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.1508305149179034`, 0.09589570953158899], 
            Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7880159895343162`, 1.1844289272681494`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.292423168507697, 0.09589570953158878], 
            Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7102595464561368`, 1.0979431286433745`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.326295698571451, -1.0700209412330057`], 
            Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4313331071336575`, 1.0979431286433743`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.184703044981658, -1.070020941233001], 
            Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864601508567196`, 1.2508159808695567`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.309031734351517, 1.0617843589087967`], 
            Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551325027330748`, 1.2508159808695567`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.167439080761725, 1.061784358908797], 
            Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.150036003433225, 1.4633569151065031`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2496099438875583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6324033046672912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.2496099438875583`, -1.6324033046672912`], 
            Complex[1.0995739404543334`, -3.095760219773794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9915566501565695, 1.4633569151065036`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10801729029776416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6324033046672906`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[0.10801729029776416`, -1.6324033046672906`], 
            Complex[1.0995739404543337`, -3.095760219773794]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2464352081914896`, 1.3039891082809558`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[2.404554826889628, -0.25253232740394693`], 
            Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.895157445398303, 1.3039891082809558`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[5.546147480479421, -0.25253232740394727`], 
            Complex[3.650990035081118, -1.556521435684903]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3511046600652281`, 1.1841607726676704`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.137883196665494, 0.10070007254234226`], 
            Complex[4.488987856730723, -1.083460700125328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7904879935245648`, 1.1841607726676706`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.279475850255287, 0.10070007254234241`], 
            Complex[4.488987856730723, -1.083460700125328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4312229441354425`, 1.0975422206787229`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.184644824657079, -1.07380299123558], 
            Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7103697094543509`, 1.0975422206787229`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.326237478246874, -1.0738029912355802`], 
            Complex[7.615867768792523, -2.171345211914303]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864531024630947`, 1.2511842734454512`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.309043252443763, 1.0655627106244419`], 
            Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551395511266987`, 1.2511842734454515`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.167450598853971, 1.065562710624442], 
            Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1506017939333173`, 1.463365532780986}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2490882946838866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6347133940043952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0984865007505693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.098078926785381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.2490882946838866`, -1.6347133940043952`], 
            Complex[1.0984865007505693`, -3.098078926785381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9909908596564765, 1.4633655327809865`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10749564109409336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6347133940043936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09848650075057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.09807892678538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[0.10749564109409336`, -1.6347133940043936`], 
            Complex[1.09848650075057, -3.09807892678538]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2493148892555024`, 1.3033708358129306`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[2.4184907299124174`, -0.2569954375693104], 
            Complex[3.66780561916792, -1.560366273382241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8922777643342912`, 1.3033708358129306`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[5.560083383502212, -0.2569954375693105], 
            Complex[3.667805619167921, -1.560366273382241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3485678429888446`, 1.1838246518564723`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.124788364875778, 0.1059320141880026], 
            Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.793024810600948, 1.1838246518564723`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.266381018465571, 0.10593201418800262`], 
            Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7104795964031188`, 1.0971431476017135`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.326179947138467, -1.077554446480185], 
            Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4311130571866764`, 1.0971431476017135`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.184587293548676, -1.0775544464801792`], 
            Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686446213431498, 1.2515507011247011`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.309054406998325, 1.069310494475782], 
            Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551464401582963`, 1.251550701124701}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.167461753408532, 1.069310494475782], 
            Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1511658970913765`, 1.46337537346042}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2485716299944873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1003863657798956`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.2485716299944873`, -1.6370109923194756`], 
            Complex[1.0974057329031106`, -3.1003863657798956`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9904267564984166, 1.4633753734604196`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10697897640469432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.100386365779895`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[0.10697897640469432`, -1.6370109923194756`], 
            Complex[1.0974057329031108`, -3.100386365779895]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8893326333988536`, 1.3028338247141251`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[5.5741382895514295`, -0.26193749411720274`], 
            Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2522600201909402`, 1.3028338247141253`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[2.4325456359616355`, -0.26193749411720374`], 
            Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3459672292427962`, 1.183410432384027}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.1115703808320068`, 0.11163556486001101`], 
            Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.795625424346997, 1.1834104323840275`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.2531630344218, 0.11163556486001082`], 
            Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.43100344294989, 1.096745882588027}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.1845304366407206`, -1.081275812794643], 
            Complex[7.615533879590611, -2.17802169538267]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7105892106399037`, 1.0967458825880272`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.326123090230514, -1.0812758127946427`], 
            Complex[7.615533879590611, -2.17802169538267]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551531724377065`, 1.2519152909260816`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.167472555293864, 1.0730282159476652`], 
            Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864394811520862`, 1.2519152909260816`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.309065208883657, 1.0730282159476647`], 
            Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9898643312103607, 1.4633864219987058`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1064672228736436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6392962376054825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[0.1064672228736436, -1.6392962376054825`], 
            Complex[1.0963315540840044`, -3.1026826596041883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.151728322379433, 1.4633864219987054`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.248059876463437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6392962376054834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.248059876463437, -1.6392962376054834`], 
            Complex[1.0963315540840044`, -3.1026826596041888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8863247477834828`, 1.3023891790741564`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[5.5882783610426285`, -0.267403671805992], 
            Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2552679058063119`, 1.3023891790741564`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[2.4466857074528354`, -0.2674036718059935], 
            Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3433054883853035`, 1.1829069935625791`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.098263114072366, 0.11785600339463051`], 
            Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7982871652044896`, 1.1829069935625791`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.23985576766216, 0.11785600339462998`], 
            Complex[4.44156860245767, -1.065050990167949]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7106985554325609`, 1.0963503994610053`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.32606689298445, -1.0849675833073058`], 
            Complex[7.61536833755189, -2.181317982768311]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4308940981572327`, 1.0963503994610049`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.184474239394659, -1.0849675833073054`], 
            Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864329030759833`, 1.2522780692182853`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.30907566856886, 1.076716367831864], 
            Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551597505138094`, 1.2522780692182853`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.1674830149790685`, 1.0767163678318639`], 
            Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9893035743919346, 1.463398663486841}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10596030862333504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0952638830152697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.104967929016111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[0.10596030862333504`, -1.64156926552927], 
            Complex[1.0952638830152697`, -3.104967929016111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1522890791978586`, 1.4633986634868419`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2475529622131285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09526388301527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.104967929016112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.2475529622131285`, -1.64156926552927], 
            Complex[1.09526388301527, -3.104967929016112]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8832589329223748`, 1.302048754496306}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[5.602458533258957, -0.2734383645589251], 
            Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2583337206674186`, 1.302048754496306}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[2.4608658796691665`, -0.2734383645589258], 
            Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3405874206219888`, 1.1823024632748214`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.084911660981808, 0.1246378257982292], 
            Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.801005232967805, 1.1823024632748214`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.226504314571602, 0.12463782579822859`], 
            Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4307850196084284`, 1.0959566726699577`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.184418687729288, -1.0886302388755988`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7108076339813643`, 1.0959566726699577`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.32601134131908, -1.0886302388755993`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551661768763977`, 1.2526390617416574`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.1674931425517565`, 1.08037543065552], 
            Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864264767133959`, 1.2526390617416574`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.309085796141549, 1.0803754306555196`], 
            Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9887444767139664, 1.463412083248145}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10545816321639523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.643830209484655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1072422927328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[0.10545816321639523`, -1.643830209484655], 
            Complex[1.0942026399303617`, -3.1072422927328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.152848176875826, 1.463412083248145}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2470508168061887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6438302094846542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.107242292732799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.2470508168061887`, -1.6438302094846542`], 
            Complex[1.0942026399303626`, -3.107242292732799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8801426299248631`, 1.301824723859007}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[5.616621151226328, -0.2800822323034732], 
            Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2614500236649304`, 1.3018247238590068`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[2.4750284976365355`, -0.28008223230347307`], 
            Complex[3.736478521301466, -1.58190695616248]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.337820442230631, 1.1815846522129752`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.071573707918281, 0.1320217921353984], 
            Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.803772211359162, 1.1815846522129752`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.213166361508075, 0.13202179213539816`], 
            Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4306762041688166`, 1.095564677269397}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.1843637680019645`, -1.092264248496479], 
            Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.710916449420976, 1.0955646772693972`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.325956421591757, -1.0922642484964793`], 
            Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864201996318084`, 1.2529982936290072`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.309095601324776, 1.0840058730914168`], 
            Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551724539579851`, 1.2529982936290074`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.167502947734983, 1.0840058730914166`], 
            Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.153405624671782, 1.4634266668335942`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2465533712085897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6460792006439566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0931477465368076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.109505867477551`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.2465533712085897`, -1.6460792006439566`], 
            Complex[1.0931477465368076`, -3.109505867477551]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9881870289180118, 1.4634266668335942`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10496071761879634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.646079200643956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.093147746536808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.10950586747755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[0.10496071761879634`, -1.646079200643956], 
            Complex[1.093147746536808, -3.10950586747755]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2646063477307077`, 1.301728904048973}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[2.4891027727434665`, -0.2873682998621285], 
            Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.876986305859085, 1.301728904048973}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[5.6306954263332605`, -0.2873682998621296], 
            Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8065776577524515`, 1.1807417271461693`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.199912728184141, 0.14004102546706554`], 
            Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3350149958373425`, 1.180741727146169}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.0583200745943513`, 0.1400410254670661], 
            Complex[4.393335070431694, -1.040700701679103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7110250048223246`, 1.0951743888991474`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.325902120580537, -1.0958700696995949`], 
            Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4305676487674672`, 1.0951743888991479`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.1843094669907455`, -1.0958700696995953`], 
            Complex[7.614877115758213, -2.191044458598743]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6864140694542373`, 1.2533557894255407`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.309105093493066, 1.0876081523510002`], 
            Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551785841355562`, 1.2533557894255407`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.167512439903273, 1.0876081523509995`], 
            Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9876312218158758, 1.4634424000172868`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10446790416412378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6483163680080417`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259799997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1117587680253287`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[0.10446790416412378`, -1.6483163680080417`], 
            Complex[1.0920991259799997`, -3.1117587680253287`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1539614317739164`, 1.4634424000172868`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2460605577539177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648316368008041`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259800008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.111758768025328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.2460605577539177`, -1.648316368008041], 
            Complex[1.0920991259800008`, -3.111758768025328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2677889862562104`, 1.3017718389315227`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[2.5030056270697787`, -0.29531732776612113`], 
            Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8738036673335818`, 1.3017718389315227`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[5.644598280659573, -0.29531732776612096`], 
            Complex[3.770794613325991, -1.597089166697644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.332184763990844, 1.1797631279505794`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.0452338697500734`, 0.14871638271009868`], 
            Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8094078895989483`, 1.1797631279505794`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.1868265233398665`, 0.1487163827100988], 
            Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7111333031944354`, 1.0947857837652883`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.325848425467212, -1.0994481489240884`], 
            Complex[7.614715122272777, -2.194233932689377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.430459350395359, 1.0947857837652883`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.18425577187742, -1.0994481489240884`], 
            Complex[7.614715122272779, -2.194233932689377]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686408083857565, 1.2537115731079582`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.309114281687616, 1.0911827145610287`], 
            Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551845697322283`, 1.253711573107958}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.167521628097823, 1.0911827145610276`], 
            Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9870770462891422, 1.4634592687920123`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10397965651895658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.65054183845496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[0.10397965651895658`, -1.65054183845496], 
            Complex[1.0910567028080986`, -3.114001107246972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.15451560730065, 1.4634592687920127`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2455723101087495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6505418384549597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.2455723101087495`, -1.6505418384549597`], 
            Complex[1.0910567028080993`, -3.114001107246972]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2709811186710442`, 1.3019617023151093`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[2.5166444532991594`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8706115349187489`, 1.3019617023151093`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[5.6582371068889525`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8122461100130425`, 1.1786406646453114`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.1740003848318254`, 0.15805167382144575`], 
            Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3293465435767513`, 1.178640664645312}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.032407731242035, 0.1580516738214428], 
            Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7112413474861696`, 1.0943988386218853`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.3257953238212, -1.1029989218798244`], 
            Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4303513061036222`, 1.0943988386218857`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.184202670231408, -1.1029989218798246`], 
            Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4551904130188706`, 1.254065668102763}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.167530521040912, 1.0947299951246656`], 
            Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686402240570922, 1.2540656681027629`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.309123174630706, 1.0947299951246658`], 
            Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.155068160301114, 1.4634772593649292`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2450885632391073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6527557367871826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.2450885632391073`, -1.6527557367871826`], 
            Complex[1.0900204029379934`, -3.116232996152112]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9865244932886794, 1.4634772593649292`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10349590964931504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.652755736787182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[0.10349590964931504`, -1.652755736787182], 
            Complex[1.0900204029379945`, -3.116232996152111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2741633942326351`, 1.3023031753120262`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[2.5299220300509884`, -0.31319809514055186`], 
            Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.867429259357157, 1.302303175312026}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[5.671514683640783, -0.31319809514055214`], 
            Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8150729915688857`, 1.1773696400320683`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.161531564303005, 0.16802967600526247`], 
            Complex[4.34645857273412, -1.009339964026806]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3265196620209074`, 1.1773696400320683`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.0199389107132126`, 0.16802967600526134`], 
            Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4302435130018614`, 1.094013530753476}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.184150149994408, -1.1065228138938465`], 
            Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7113491405879322`, 1.0940135307534757`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.325742803584212, -1.1065228138938557`], 
            Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863965373741345`, 1.2544180973038173`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.309131780739362, 1.098250419067798], 
            Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455196116215659, 1.2544180973038175`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.167539127149569, 1.098250419067797], 
            Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9859735538341508, 1.463496358153355}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10301659978814422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6549581857775262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0889901536222948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.118454543930881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[0.10301659978814422`, -1.6549581857775262`], 
            Complex[1.0889901536222948`, -3.118454543930881]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.155619099755642, 1.4634963581533549`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2446092533779374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6549581857775257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.088990153622295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1184545439308806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.2446092533779374`, -1.6549581857775257`], 
            Complex[1.088990153622295, -3.1184545439308806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8642776483570973`, 1.3027965316109555`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[5.684335924466961, -0.3230721172560274], 
            Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.277315005232697, 1.302796531610956}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[2.5427432708771702`, -0.3230721172560292], 
            Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.323724904076076, 1.1759497644229226`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.007922524597889, 0.17861007860412123`], 
            Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8178677495137172`, 1.1759497644229229`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.1495151781876825`, 0.1786100786041201], 
            Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7114566853332849`, 1.093629837958266}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.325690853055608, -1.1100202402427715`], 
            Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4301359682565093`, 1.0936298379582658`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.184098199465816, -1.1100202402427715`], 
            Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686390972096229, 1.2547688830891834`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.309140108138353, 1.1017444013712938`], 
            Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552016814935647`, 1.2547688830891832`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.167547454548559, 1.1017444013712936`], 
            Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9854242190135266, 1.4635165517806534`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1025416644037889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944393`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[0.1025416644037889, -1.6571493062137859`], 
            Complex[1.0879658834173156`, -3.1206658579944393`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.156168434576266, 1.4635165517806528`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2441343179935824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944384`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[3.2441343179935824`, -1.6571493062137856`], 
            Complex[1.0879658834173163`, -3.1206658579944384`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2804151386042075`, 1.3034371807829288`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.5550227978429705`, -0.33349241406049857`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8611775149855856`, 1.3034371807829288`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[5.696615451432764, -0.33349241406049873`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.320983060208273, 1.1743856123346503`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.996443980542599, 0.1897302873440814], 
            Complex[4.317427040750872, -0.984655324990569]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8206095933815196`, 1.1743856123346503`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.138036634132392, 0.18973028734408198`], 
            Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.430028669089267, 1.0932477385320032`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.1840468072888495`, -1.1134916064718126`], 
            Complex[7.614075476378116, -2.206739345003816]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7115639845005257`, 1.0932477385320034`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.325639460878643, -1.1134916064718128`], 
            Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686385542613994, 1.2551180473372854`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.309148164672497, 1.1052123472899034`], 
            Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552071109757996`, 1.2551180473372854`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.167555511082704, 1.1052123472899034`], 
            Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9848764799825815, 1.4635378270722244`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10207104216942726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.122867044014348`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[0.10207104216942726`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.122867044014348]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1567161736072116`, 1.4635378270722248`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2436636957592206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1228670440143484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[3.2436636957592206`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.1228670440143484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.283444552027566, 1.304215836628012}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.5666918389490667`, -0.3443779449095298], 
            Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8581481015622268`, 1.304215836628012}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[5.708284492538861, -0.3443779449095292], 
            Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8232793031057117`, 1.172686454142283}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.127164733575719, 0.20130934934495107`], 
            Complex[4.303885430470007, -0.971377104797332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3183133504840812`, 1.1726864541422832`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.9855720799859258`, 0.20130934934494918`], 
            Complex[4.303885430470007, -0.971377104797334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4299216127755852`, 1.0928672112525009`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.183995962437312, -1.1169373087010905`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7116710408142075`, 1.0928672112525006`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.325588616027105, -1.1169373087010908`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455212406739198, 1.2554656114424272`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.167563304328588, 1.1086546526584367`], 
            Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863802468505937`, 1.2554656114424272`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.309155957918382, 1.1086546526584367`], 
            Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.157262325625397, 1.4635601710515933`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2431973265232212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6614980349092643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[3.2431973265232212`, -1.6614980349092643`], 
            Complex[1.0859350008978244`, -3.1250582059608574`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9843303279643972, 1.4635601710515933`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10160467293342826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6614980349092632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[0.10160467293342826`, -1.6614980349092632`], 
            Complex[1.0859350008978255`, -3.1250582059608565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2863869531572396`, 1.3051193096596598`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.5777029731444694`, -0.35563571212946193`], 
            Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8552057004325522`, 1.3051193096596596`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[5.719295626734264, -0.3556357121294631], 
            Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8258606082521933`, 1.1708654635949698`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.1169469267372625`, 0.21325435309295884`], 
            Complex[4.291086318485069, -0.957611110502011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3157320453376002`, 1.17086546359497}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.9753542731474694`, 0.21325435309295854`], 
            Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.429814796643195, 1.092488235364768}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.183945654203009, -1.1203577339198187`], 
            Complex[7.613760450846203, -2.212845969284587]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7117778569465985`, 1.092488235364768}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.325538307792803, -1.1203577339198192`], 
            Complex[7.613760450846203, -2.212845969284587]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552175708155695`, 1.2558115963296934`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.16757084160569, 1.1120717041858348`], 
            Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686375082774224, 1.2558115963296934`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.309163495195484, 1.112071704185835], 
            Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1578068993409363`, 1.4635835709365852`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.242735151280391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.084928251939455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.127239446140108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[3.242735151280391, -1.6636558752035226`], 
            Complex[1.084928251939455, -3.127239446140108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9837857542488571, 1.4635835709365859`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10114249769059809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0849282519394552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1272394461401083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[0.10114249769059809`, -1.6636558752035224`], 
            Complex[1.0849282519394552`, -3.1272394461401083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8523627394815876`, 1.306131743395168}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[5.729624504719875, -0.3671682712416461], 
            Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2892299141082055`, 1.306131743395168}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.588031851130083, -0.3671682712416466], 
            Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3132515510777616`, 1.1689384815256945`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.965814938226205, 0.22546793870233256`], 
            Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8283411025120313`, 1.1689384815256945`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.107407591815999, 0.22546793870233275`], 
            Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.429708218070701, 1.0921107905667289`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.1838958721837285`, -1.1237532602689642`], 
            Complex[7.613604090254429, -2.215864050835693]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7118844355190923`, 1.092110790566729}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.325488525773522, -1.1237532602689644`], 
            Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863700483968251`, 1.2561560224692672`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.309170783576755, 1.11546387973771], 
            Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552226051929682`, 1.2561560224692672`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.167578129986962, 1.1154638797377099`], 
            Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1583499033976468`, 1.463608014135603}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2422771121440808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6658028510947214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303243`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[3.2422771121440808`, -1.6658028510947214`], 
            Complex[1.083927208746434, -3.1294108652303243`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9832427501921461, 1.4636080141356036`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10068445855428786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6658028510947218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[0.10068445855428786`, -1.6658028510947218`], 
            Complex[1.083927208746434, -3.1294108652303256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2919652034324578`, 1.3072360096435218`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.5976759196164494`, -0.3788808057418005], 
            Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.849627450157335, 1.307236009643522}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[5.7392685732062425`, -0.37888080574180155`], 
            Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8307125756840936`, 1.166922620563567}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.098549310734496, 0.2378553727309036], 
            Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3108800779056993`, 1.1669226205635674`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.9569566571447035`, 0.2378553727309031], 
            Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4296018744862171`, 1.0917348569954988`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.1838466062718, -1.1271242573129145`], 
            Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7119907791035764`, 1.091734856995499}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.325439259861593, -1.1271242573129148`], 
            Complex[7.613448480758017, -2.218859114308414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863651417728376`, 1.2564989098901889`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.309177829898688, 1.118831548607897], 
            Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552275118169558`, 1.2564989098901886`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.167585176308896, 1.1188315486078975`], 
            Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9827013072162403, 1.4636334882439852`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10023049872932865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6679390740730153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[0.10023049872932865`, -1.6679390740730153`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1588913463735526`, 1.4636334882439854`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2418231523191214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6679390740730151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[3.2418231523191214`, -1.6679390740730151`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2945885862953412`, 1.3084149874652116`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.606650933262854, -0.3906866010723904], 
            Complex[3.901239519558195, -1.699101588537602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8470040672944514`, 1.3084149874652118`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[5.748243586852646, -0.3906866010723917], 
            Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.308621839732442, 1.1648349861741165`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.9487637036120304`, 0.25033002218771455`], 
            Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8329708138573517`, 1.1648349861741167`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.0903563572018244`, 0.2503300221877129], 
            Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7120968902237481`, 1.091360415214188}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.325390500232961, -1.1304710863006695`], 
            Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4294957633660454`, 1.091360415214188}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.183797846643169, -1.1304710863006642`], 
            Complex[7.613293610009215, -2.221831501514852]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552322925917913`, 1.2568402781935855`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.167591987181104, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863603609980011`, 1.2568402781935857`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.309184640770896, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9821614168084022, 1.4636599810404525`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09978056248576549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[0.09978056248576549, -1.6700646538866686`], 
            Complex[1.0819419792941676`, -3.133724634927121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1594312367813915`, 1.4636599810404527`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.241373216075559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927122`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[3.241373216075559, -1.6700646538866692`], 
            Complex[1.0819419792941676`, -3.133724634927122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8444933974864997`, 1.3096525459021726`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[5.75657901938974, -0.4025104167837189], 
            Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2970992561032932`, 1.3096525459021724`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.6149863657999486`, -0.40251041678372024`], 
            Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.835115031044475, 1.162691693929424}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.08279928559293, 0.26281672672835754`], 
            Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3064776225453185`, 1.1626916939294247`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.9412066320031385`, 0.2628167267283543], 
            Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4293898822334064`, 1.0909874461992093`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.183749583746966, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7122027713563872`, 1.0909874461992093`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.32534223733676, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686355704208199, 1.2571801465653936`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.309191222585227, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552369493815946`, 1.2571801465653938`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.167598568995433, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9816230705206676, 1.46368748048364}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09933459513336479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624695`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[0.09933459513336479, -1.6721796985788298`], 
            Complex[1.0809576656540323`, -3.1358671790624695`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.159969583069126, 1.46368748048364}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240927248723158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[3.240927248723158, -1.6721796985788306`], 
            Complex[1.0809576656540323`, -3.1358671790624704`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8420935629077417`, 1.3109341697391195`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[5.7643133844056464`, -0.4142898642644478], 
            Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2994990906820525`, 1.3109341697391192`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.6227207308158538`, -0.41428986426444875`], 
            Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8371471253657656`, 1.1605072437468391`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.075839610164613, 0.27525317641875785`], 
            Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3044455282240284`, 1.1605072437468393`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.93424695657482, 0.27525317641875774`], 
            Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4292842286572085`, 1.0906159313280757`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.183701808295563, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.712308424932585, 1.0906159313280754`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.325294461885356, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552414840114574`, 1.2575185337885972`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.167604927934658, 1.128791084903274], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863511695783353`, 1.2575185337885975`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.309197581524451, 1.1287910849032743`], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.160506393620451, 1.4637159747087094`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240485196586656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6742843145233057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0799788029662047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138000289232015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[3.240485196586656, -1.6742843145233057`], 
            Complex[1.0799788029662047`, -3.138000289232015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9810862599693423, 1.4637159747087096`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0988925429968627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6742843145233064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079978802966205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.138000289232016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[0.0988925429968627, -1.6742843145233064`], 
            Complex[1.079978802966205, -3.138000289232016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8398007606786424`, 1.3122472597433967`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[5.771490138844717, -0.42597525546826004`], 
            Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3017918929111518`, 1.3122472597433967`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.629897485254924, -0.42597525546826037`], 
            Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3025217339005444`, 1.1582942196491404`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.927841247969024, 0.28758976049421764`], 
            Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8390709196892485`, 1.1582942196491404`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.069433901558818, 0.2875897604942178], 
            Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4291788002508572`, 1.0902458523676468`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.183654511255059, -1.1403700578948637`], 
            Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7124138533389353`, 1.0902458523676473`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.325247164844853, -1.1403700578948632`], 
            Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552458982685348`, 1.2578554582550099`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.16761106998075, 1.1320642574808064`], 
            Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863467553212579`, 1.25785545825501}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.309203723570544, 1.1320642574808066`], 
            Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9805509768344881, 1.46374545202404}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09845435339193638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6763786064594066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0790053302264244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1401240584834467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[0.09845435339193638, -1.6763786064594066`], 
            Complex[1.0790053302264244`, -3.1401240584834467`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1610416767553047`, 1.4637454520240396`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2400470069817295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6763786064594062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079005330226425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.140124058483446`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[3.2400470069817295`, -1.6763786064594062`], 
            Complex[1.079005330226425, -3.140124058483446]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8376099369809944`, 1.3135811856180986`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[5.778154476287738, -0.43752848511674675`], 
            Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3039827166087992`, 1.3135811856180988`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.636561822697944, -0.4375284851167467], 
            Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.30070116606876, 1.1560632368114137`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.921944339934747, 0.2997884495937316], 
            Complex[4.222645506003507, -0.856274787217682]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8408914875210336`, 1.1560632368114139`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.063536993524541, 0.2997884495937313], 
            Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.429073594671112, 1.0898771914628231`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.183607683836199, -1.1436236694349755`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7125190589186814`, 1.0898771914628231`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.325200337425992, -1.1436236694349757`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552501939030753`, 1.2581909379766125`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.167617000922771, 1.1353146500669256`], 
            Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863424596867174`, 1.2581909379766123`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.309209654512566, 1.1353146500669253`], 
            Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.161575440730376, 1.4637759009079965`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2396126281916615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6784626775258558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[3.2396126281916615`, -1.6784626775258558`], 
            Complex[1.0780371874612853`, -3.1422385784338522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9800172128594179, 1.463775900907995}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09801997460186761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6784626775258555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[0.09801997460186761, -1.6784626775258555`], 
            Complex[1.0780371874612855`, -3.1422385784338505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8355153308396206`, 1.3149271784298575`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[5.784351043372479, -0.448921436448157], 
            Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3060773227501732`, 1.3149271784298575`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.6427583897826854`, -0.4489214364481581], 
            Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8426146092289648`, 1.1538230491332258`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.058104266499389, 0.311821201539341], 
            Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2989780443608294`, 1.153823049133226}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.9165116129095963`, 0.31182120153934106`], 
            Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4289686096169663`, 1.0895099311256533`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.183561317485685, -1.1468548029005128`], 
            Complex[7.612529927102651, -2.236364734026166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7126240439728273`, 1.0895099311256522`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.325153971075487, -1.1468548029005257`], 
            Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552543726294334`, 1.2585249905964742`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.167622726364391, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863382809603593`, 1.2585249905964742`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.309215379954184, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9794849598501782, 1.4638073100057707`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09758935585487952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6805366292938224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1443439392995933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[0.09758935585487952, -1.6805366292938224`], 
            Complex[1.0770743157050577`, -3.1443439392995933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.162107693739614, 1.4638073100057707`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2391820094446726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6805366292938222`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.144343939299593`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[3.2391820094446726`, -1.6805366292938222`], 
            Complex[1.0770743157050588`, -3.144343939299593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3080817720599374`, 1.3162781360342575`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.648529805818011, -0.4601342612759221], 
            Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8335108815298558`, 1.3162781360342575`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[5.790122459407805, -0.4601342612759226], 
            Complex[3.95661157787795, -1.77641239731018]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{1.8442463646403904`, 1.151580743813152}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.053093127997606, 0.32366824142440104`], 
            Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2973462889494038`, 1.1515807438131522`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.911500474407813, 0.323668241424401], 
            Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7127288107612115`, 1.089144054224844}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.325108057467666, -1.1500637746045623`], 
            Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4288638428285827`, 1.0891440542248436`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.183515403877874, -1.1500637746045628`], 
            Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686334217462754, 1.2588576333992727`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.309220905320853, 1.1417483803738433`], 
            Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552584361270404`, 1.258857633399273}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.1676282517310606`, 1.1417483803738426`], 
            Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.162638443914744, 1.4638396681263017`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2387551008919058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6826005617990878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.076116656977162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1464402299253895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[3.2387551008919058`, -1.6826005617990878`], 
            Complex[1.076116656977162, -3.1464402299253895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9789542096750502, 1.463839668126302}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09716244730211258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.682600561799087`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0761166569771627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1464402299253886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[0.09716244730211258, -1.682600561799087], 
            Complex[1.0761166569771627`, -3.1464402299253886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3100021386460383`, 1.3176283944102223`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.653915808537619, -0.4711537472500261], 
            Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8315905149437552`, 1.3176283944102227`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[5.795508462127413, -0.4711537472500259], 
            Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8457928466810891`, 1.1493419700143042`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.048463866858473, 0.3353164289039027], 
            Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2957998069087038`, 1.1493419700143042`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.90687121326868, 0.33531642890390234`], 
            Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4287592920862422`, 1.0887795439756538`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.183469934906837, -1.1532508941175408`], 
            Complex[7.612229226993079, -2.242030438093195]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7128333615035514`, 1.0887795439756531`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.325062588496635, -1.1532508941175512`], 
            Complex[7.612229226993084, -2.242030438093204]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552623860413456`, 1.259188883321431}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.167633582276865, 1.1449323435024108`], 
            Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686330267548447, 1.2591888833214313`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.30922623586666, 1.1449323435024106`], 
            Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9784249542640309, 1.4638729642392583`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09673919999623987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.684654573573374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0751641542602708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1485275378126323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[0.09673919999623987, -1.684654573573374], 
            Complex[1.0751641542602708`, -3.1485275378126323`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.163167699325762, 1.463872964239259}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.238331853586033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6846545735733742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.075164154260271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.148527537812633`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[3.238331853586033, -1.6846545735733742`], 
            Complex[1.075164154260271, -3.148527537812633]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8297483324982404`, 1.318973498312344}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[5.800545503681592, -0.4819718787730359], 
            Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3118443210915538`, 1.3189734983123436`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.6589528500918, -0.48197187877303665`], 
            Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8472599724721497`, 1.147111168211903}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[6.044180057256696, 0.34675781913864817`], 
            Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2943326811176437`, 1.1471111682119028`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.9025874036669044`, 0.3467578191386486], 
            Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.712937698380446, 1.088416383930148}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.325017556268538, -1.1564164644600665`], 
            Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4286549552093482`, 1.088416383930148}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.183424902678746, -1.1564164644600665`], 
            Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552662239847245`, 1.2595187569608863`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.167638723091055, 1.1480947778478905`], 
            Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863264296050673`, 1.2595187569608863`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.30923137668085, 1.1480947778478905`], 
            Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9778971856083358, 1.4639071874720941`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0963195658706748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6866987616748745`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1506059491469687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[0.0963195658706748, -1.6866987616748745`], 
            Complex[1.0742167514790106`, -3.1506059491469687`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1636954679814577`, 1.4639071874720948`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237912219460468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.686698761674875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.15060594914697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[3.237912219460468, -1.686698761674875], 
            Complex[1.0742167514790106`, -3.15060594914697]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.827978726644874, 1.3203099896356545`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[5.805266648945746, -0.4925846278657947], 
            Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3136139269449207`, 1.3203099896356538`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.6636739953559614`, -0.49258462786579826`], 
            Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.848653367825116, 1.1448917818283744`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.04020866039606, 0.3579884536883503], 
            Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2929392857646773`, 1.1448917818283746`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.8986160068062667`, 0.3579884536883491], 
            Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.71304182353435, 1.0880545579678063`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.324972953094393, -1.159560782288886], 
            Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4285508300554441`, 1.088054557967806}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.1833802995046, -1.1595607822888863`], 
            Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552699515373575`, 1.2598472705865122`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.167643679104286, 1.1512359798388985`], 
            Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863227020524352`, 1.2598472705865122`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.309236332694079, 1.151235979838898], 
            Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9773708957598857, 1.4639423271071725`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09590349771937258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.688733221717992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1526755488251643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[0.09590349771937258, -1.688733221717992], 
            Complex[1.0732743934792583`, -3.1526755488251643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1642217578299072`, 1.4639423271071728`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237496151309166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6887332217179927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.152675548825165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[3.237496151309166, -1.6887332217179927`], 
            Complex[1.0732743934792588`, -3.152675548825165]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.82627644385129, 1.3216352217365332`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[5.809701663341314, -0.5029909709021079], 
            Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3153162097385034`, 1.3216352217365332`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.668109009751523, -0.50299097090211], 
            Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8499783042653692`, 1.1426864429123007`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.036519936690694, 0.36900737727295657`], 
            Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.291614349324425, 1.1426864429123011`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.8949272831009005`, 0.36900737727295585`], 
            Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4284469145192769`, 1.0876940502864647`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.183336117893254, -1.1626841380761952`], 
            Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7131457390705167`, 1.0876940502864645`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.32492877148305, -1.1626841380761932`], 
            Complex[7.611783032412532, -2.250378188362658]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552735702480735`, 1.260174440147205}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.167648455094579, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.68631908334172, 1.2601744401472053`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.309241108684372, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1647465767589895`, 1.4639783725789481`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237083602766982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0723370260079925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.154736420481273`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[3.237083602766982, -1.6907580479023252`], 
            Complex[1.0723370260079925`, -3.154736420481273]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9768460768308047, 1.463978372578948}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09549094917718823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023245`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.072337026007993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1547364204812727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[0.09549094917718823, -1.6907580479023245`], 
            Complex[1.072337026007993, -3.1547364204812727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3169560419951263`, 1.322947201772055}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.6722845561748567`, -0.5131921073476409], 
            Complex[3.989240598169983, -1.836139309119696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.824636611594667, 1.3229472017720547`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[5.81387720976465, -0.5131921073476412], 
            Complex[3.989240598169983, -1.836139309119696]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2903529815464114`, 1.1404971297989088`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.8914945952485174`, 0.37981585653752775`], 
            Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.851239672043382, 1.140497129798909}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.033087248838311, 0.3798158565375278], 
            Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7132494470579116`, 1.0873348453935727`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.324885004134527, -1.165786816282607], 
            Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.428343206531882, 1.0873348453935727`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.183292350544735, -1.1657868162826117`], 
            Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552770816351803`, 1.2605002812806474`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.167653055693024, 1.1574558417407834`], 
            Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863155719546132`, 1.2605002812806476`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.309245709282818, 1.1574558417407832`], 
            Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1652699325968765`, 1.4640153134712226`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2366745282905844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6927733330409118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.071404595693708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[3.2366745282905844`, -1.6927733330409118`], 
            Complex[1.071404595693708, -3.156788646512134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9763227209929172, 1.464015313471223}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09508187470079153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6927733330409114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0714045956937088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[0.09508187470079153, -1.6927733330409114`], 
            Complex[1.0714045956937088`, -3.156788646512134]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.823054741730652, 1.324244459741766}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[5.817817100281683, -0.5231908494724428], 
            Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3185379118591412`, 1.3242444597417655`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.67622444669189, -0.5231908494724435], 
            Complex[3.994762358551031, -1.847435309214209]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.289150676819392, 1.138325298068106}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.8882941565379943`, 0.3904167697900055], 
            Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8524419767704008`, 1.138325298068106}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.029886810127787, 0.39041676979000506`], 
            Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4282397040596935`, 1.0869769280977648`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.183248990343842, -1.1688690955240477`], 
            Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7133529495300999`, 1.0869769280977655`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.324841643933642, -1.168869095524045], 
            Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863121664025418`, 1.2608248093217689`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.309250138979012, 1.1605350642903134`], 
            Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552804871872524`, 1.260824809321769}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.16765748538922, 1.1605350642903134`], 
            Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9758008204772434, 1.464053139514452}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09467622955009732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6947791685877762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1588323081022285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[0.09467622955009732, -1.6947791685877762`], 
            Complex[1.0704770500273406`, -3.1588323081022285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1657918331125496`, 1.464053139514452}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2362688831398905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.694779168587776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.158832308102228`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[3.2362688831398905`, -1.694779168587776], 
            Complex[1.0704770500273408`, -3.158832308102228]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.320065934491101, 1.3255259413319713`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.679949913999627, -0.5329911517598123], 
            Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8215267190986917`, 1.325525941331971}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[5.821542567589421, -0.5329911517598128], 
            Complex[4.000015848490729, -1.858517093091784]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2880033027721522`, 1.1361719876999965`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.8853047593900265`, 0.4008141364346624], 
            Complex[4.173308062162179, -0.735357851265334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.853589350817641, 1.1361719876999965`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.02689741297982, 0.40081413643466185`], 
            Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7134562484860945`, 1.0866202835007164`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.324798683943808, -1.1719312487328415`], 
            Complex[7.611342435457713, -2.258551532233558]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4281364051036973`, 1.086620283500716}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1832060303540155`, -1.171931248732845], 
            Complex[7.611342435457713, -2.258551532233561]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863088652258924`, 1.2611480393109107`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.309254402126275, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455283788363901, 1.261148039310911}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1676617485364815`, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9752803675735038, 1.4640918405831223`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0942739697702223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6967756446647657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.069554337343726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1608674852478877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[0.0942739697702223, -1.6967756446647657`], 
            Complex[1.069554337343726, -3.1608674852478877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.16631228601629, 1.4640918405831227`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.235866623360016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6967756446647662`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0695543373437264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1608674852478886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[3.235866623360016, -1.6967756446647662`], 
            Complex[1.0695543373437264`, -3.1608674852478886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8200487815068902`, 1.3267909211366744`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[5.8250725348409, -0.5425977517885678], 
            Complex[4.00502375333401, -1.869388672925242]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.321543872082903, 1.3267909211366744`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.683479881251108, -0.5425977517885688], 
            Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2869070802539364`, 1.1340379098537245`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.8825075055343556`, 0.41101275787833075`], 
            Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8546855733358563`, 1.1340379098537245`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.024100159124149, 0.4110127578783314], 
            Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4280333076985936`, 1.086264896989286}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.183163463811437, -1.1749735433132202`], 
            Complex[7.611196771510031, -2.261238440302506]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7135593458911997`, 1.086264896989286}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.324756117401245, -1.1749735433132202`], 
            Complex[7.611196771510045, -2.261238440302506]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686305666993273, 1.2614699860017093`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.309258502946614, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552869865965197`, 1.2614699860017096`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.167665849356821, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.166831298960178, 1.4641314066931759`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2354677057637162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6987628500877325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.068636406803538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.162894256780908`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[3.2354677057637162`, -1.6987628500877325`], 
            Complex[1.068636406803538, -3.162894256780908]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9747613546296152, 1.464131406693176}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09387505217392343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6987628500877328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0686364068035386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1628942567809086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[0.09387505217392343, -1.6987628500877328`], 
            Complex[1.0686364068035386`, -3.1628942567809086`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3229751583574452`, 1.3280389328750908`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.6868312180069145`, -0.5520158986267104], 
            Complex[4.009806376364359, -1.880054831501801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8186174952323482`, 1.3280389328750908`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[5.8284238715967085`, -0.5520158986267112], 
            Complex[4.009806376364359, -1.880054831501802]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.855734094759337, 1.1319235166497295`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.021478203650236, 0.4210179459473799], 
            Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.285858558830457, 1.1319235166497295`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.8798855500604437`, 0.42101794594737985`], 
            Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7136622436778, 1.085910754227925}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.324713937709186, -1.1779962412914933`], 
            Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4279304099119927`, 1.085910754227925}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.183121284119393, -1.1779962412914966`], 
            Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6863025703007866`, 1.261790663868711}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.30926244553551, 1.1696531548443287`], 
            Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552900832890077`, 1.261790663868711}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.167669791945717, 1.1696531548443287`], 
            Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9742437740512024, 1.4641718279994984`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09347943432451934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.700740872392058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[0.09347943432451934, -1.700740872392058], 
            Complex[1.0677232083757218`, -3.1649127003915565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.16734887953859, 1.4641718279994977`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2350720879143124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7007408723920572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[3.2350720879143124`, -1.7007408723920572`], 
            Complex[1.0677232083757224`, -3.1649127003915547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3243629248491045`, 1.3292697135446334`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.6900189760399855`, -0.5612511491377956], 
            Complex[4.01438190088909, -1.890520862682429]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8172297287406878`, 1.3292697135446339`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[5.831611629629778, -0.5612511491377962], 
            Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.284854590499166, 1.1298290570165097`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.8774238656148396`, 0.4308353192168015], 
            Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8567380630906272`, 1.1298290570165102`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.019016519204634, 0.4308353192168009], 
            Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4278277098436392`, 1.0855578411513434`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.1830794848428505`, -1.180999599461101], 
            Complex[7.610907194686489, -2.266557440612444]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.713764943746155, 1.0855578411513431`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.324672138432646, -1.180999599461105], 
            Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552930798184576`, 1.2621100871147288`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.167673580276672, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862995737713367`, 1.2621100871147288`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.309266233866467, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.167865035288695, 1.464213094793462}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.234679728109072`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7027097978575507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1669228926510127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[3.234679728109072, -1.7027097978575507`], 
            Complex[1.0668146928203772`, -3.1669228926510127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9737276183010999, 1.4642130947934615`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0930870745192786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7027097978575496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.166922892651011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[0.0930870745192786, -1.7027097978575496`], 
            Complex[1.0668146928203786`, -3.166922892651011]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3257100272570141`, 1.3304831588689658`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.693056602464925, -0.5703092165540393], 
            Complex[4.018766629721939, -1.900792375423005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.815882626332779, 1.3304831588689656`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[5.834649256054719, -0.5703092165540443], 
            Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8577003502579712`, 1.1277546212423153`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.016701682863842, 0.4404706516054355], 
            Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.283892303331822, 1.127754621242315}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.8751090292740487`, 0.4404706516054349], 
            Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4277252056246483`, 1.0852061439574272`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.183038059703257, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7138674479651452`, 1.0852061439574272`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.32463071329305, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862966760539544`, 1.2624282696779499`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.309269871795374, 1.1756348399245429`], 
            Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552959775358392`, 1.2624282696779499`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.167677218205581, 1.1756348399245424`], 
            Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.973212879898857, 1.464255197500519}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0926979317732518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0659108116721088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.168924909033252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[0.0926979317732518, -1.7046697115327327`], 
            Complex[1.0659108116721088`, -3.168924909033252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1683797736909356`, 1.4642551975005187`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2342905853630466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.065910811672111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1689249090332523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[3.2342905853630466`, -1.7046697115327338`], 
            Complex[1.065910811672111, -3.1689249090332523`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8145735827492684`, 1.3316792878312398`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[5.837548783508502, -0.5791958590266288], 
            Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3270190708405252`, 1.3316792878312396`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.695956129918709, -0.5791958590266285], 
            Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.282969076074943, 1.1257001764416252`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.8729290323659913`, 0.4499297609478434], 
            Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.85862357751485, 1.1257001764416255`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[6.014521685955785, 0.4499297609478434], 
            Complex[4.155898108440934, -0.675770415493782]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4276228954167829`, 1.0848556491003873`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.182997002573542, -1.1869492982198684`], 
            Complex[7.610619897990325, -2.271804947320256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7139697581730104`, 1.0848556491003871`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.324589656163337, -1.186949298219872], 
            Complex[7.610619897990326, -2.271804947320259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4552987777666537`, 1.262745225238807}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.167680709474919, 1.1785973245423345`], 
            Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862938758231383`, 1.2627452252388067`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.309273363064712, 1.178597324542335], 
            Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.16889310216953, 1.4642981266778532`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2339046193933325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[3.2339046193933325`, -1.7066206972585347`], 
            Complex[1.0650115172238024`, -3.170918823936388]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9726995514202635, 1.4642981266778532`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09231196580353926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[0.09231196580353926, -1.7066206972585347`], 
            Complex[1.0650115172238028`, -3.170918823936388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.813300219311785, 1.332858214478831}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[5.840320998393064, -0.5879167986060267], 
            Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3282924342780076`, 1.3328582144788306`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.698728344803272, -0.5879167986060275], 
            Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2820825142870236`, 1.1236655947501377`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.8708731122295896`, 0.4592184279956057], 
            Complex[4.152955626516613, -0.664447166754532]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.859510139302769, 1.1236655947501377`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.012465765819384, 0.4592184279956062], 
            Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4275207774117307`, 1.0845063432841386`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.182956307473314, -1.1898961274694768`], 
            Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.714071876178063, 1.0845063432841386`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.324548961063108, -1.18989612746948], 
            Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553014818115646`, 1.2630609672266209`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.1676840577177385`, 1.1815412277835526`], 
            Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862911717782296`, 1.2630609672266209`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.309276711307533, 1.1815412277835524`], 
            Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.169405028092948, 1.464341873012074}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2335217906037683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7085628376914088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0641167625108199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[3.2335217906037683`, -1.7085628376914088`], 
            Complex[1.0641167625108199`, -3.1729047107034827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9721876254968451, 1.4643418730120743`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09192913701397513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7085628376914086`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06411676251082`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[0.09192913701397513, -1.7085628376914086`], 
            Complex[1.06411676251082, -3.1729047107034827`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3295322917050634`, 1.3340201255300457`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.7013829352654026`, -0.5964776632911527], 
            Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8120603618847293`, 1.3340201255300457`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[5.842975588855198, -0.5964776632911535], 
            Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.281230428296403, 1.1216506757177542`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.8689316042370305`, 0.4683423384869718], 
            Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.860362225293388, 1.1216506757177538`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.010524257826831, 0.4683423384869708], 
            Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.714173803759369, 1.0841582134559014`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.324508622154049, -1.1928245944888063`], 
            Complex[7.61033481839468, -2.276982807944708]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4274188498304246`, 1.0841582134559016`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.182915968564257, -1.1928245944888065`], 
            Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862885626427868`, 1.2633755088260255`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.309279920051315, 1.18446678667431], 
            Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553040909470067`, 1.2633755088260255`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.167687266461523, 1.1844667866743102`], 
            Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9716770948153945, 1.4643864273169689`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09154940648022836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7104962143258893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.063226501295623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.174882641642858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[0.09154940648022836, -1.7104962143258893`], 
            Complex[1.063226501295623, -3.174882641642858]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.169915558774398, 1.4643864273169682`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2331420600700214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7104962143258888`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0632265012956237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1748826416428573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[3.2331420600700214`, -1.7104962143258888`], 
            Complex[1.0632265012956237`, -3.1748826416428573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3307406328361906`, 1.3351652626022812`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.7039286208715065`, -0.6048839465011073], 
            Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8108520207536023`, 1.3351652626022812`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[5.8455212744613, -0.6048839465011082], 
            Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8611818405140266`, 1.119655164080114}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.008688465710948, 0.47730704263853474`], 
            Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2804108130757674`, 1.119655164080114}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.8670958121211547`, 0.477307042638535], 
            Complex[4.147506625196923, -0.642348121441579]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4273171109223617`, 1.0838112468000032`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.1828759801456865`, -1.1957349319176866`], 
            Complex[7.610193091068048, -2.27954617871769]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.714275542667431, 1.0838112468000032`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.32446863373548, -1.195734931917687], 
            Complex[7.61019309106805, -2.2795461787176903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686286047163997, 1.2636888629831808`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.30928299272165, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553066064257962`, 1.263688862983181}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.167690339131856, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9711679521174842, 1.464431780531296}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0911727359352858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7124209075166128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06234068805277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.176852688047909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[0.0911727359352858, -1.7124209075166128`], 
            Complex[1.06234068805277, -3.176852688047909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.170424701472309, 1.4644317805312956`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2327653895250794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.712420907516613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0623406880527706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1768526880479087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[3.2327653895250794`, -1.712420907516613], 
            Complex[1.0623406880527706`, -3.1768526880479087`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8096733724001268`, 1.3362939081184422`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[5.84796591957802, -0.6131409796537515], 
            Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3319192811896667`, 1.3362939081184417`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.7063732659882276`, -0.613140979653751], 
            Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2796218300135123`, 1.117678763851855}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.8653578945969786`, 0.48611792774323803`], 
            Complex[4.144979724610491, -0.631560836108617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.861970823576281, 1.1176787638518553`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.006950548186772, 0.4861179277432377], 
            Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4272155589649624`, 1.0834654307318894`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.182836336650298, -1.1986273679369637`], 
            Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7143770946248302`, 1.0834654307318898`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.324428990240092, -1.1986273679369637`], 
            Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862836241121018`, 1.2640010424117867`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.309285932645754, 1.1902637967550587`], 
            Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553090294776925`, 1.2640010424117867`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.167693279055961, 1.1902637967550591`], 
            Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9706601901989883, 1.4644779237166354`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09079908775532702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.714336996499808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[0.09079908775532702, -1.714336996499808], 
            Complex[1.0614592779543155`, -3.1788149202164435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.170932463390804, 1.4644779237166348`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23239174134512`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7143369964998079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[3.23239174134512, -1.7143369964998079`], 
            Complex[1.0614592779543162`, -3.1788149202164426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3330699105032782`, 1.337406374140596}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.708723978803601, -0.6212539145605391], 
            Complex[4.041793889306879, -1.958660288701135]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8085227430865154`, 1.3374063741405962`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[5.850316632393395, -0.6212539145605389], 
            Complex[4.04179388930688, -1.958660288701135]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8627308630954607`, 1.1157211494926285`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.0053034199324715`, 0.4947802005841794], 
            Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2788617904943318`, 1.1157211494926285`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.8637107663426793`, 0.49478020058417876`], 
            Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7144784613268562`, 1.0831207528923261`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.32438968622985, -1.201502126383065], 
            Complex[7.609911224902993, -2.284622879275391]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4271141922629382`, 1.0831207528923261`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.182797032640057, -1.201502126383065], 
            Complex[7.609911224902995, -2.284622879275391]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862812922798296`, 1.2643120595989}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.309288743055875, 1.193135699594645], 
            Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553113613099649`, 1.2643120595989001`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.167696089466082, 1.193135699594645], 
            Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9701538019096131, 1.4645248480552713`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09042842494596093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7162445594142677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.060582226855574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1807694074695387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[0.09042842494596093, -1.7162445594142677`], 
            Complex[1.060582226855574, -3.1807694074695387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1714388516801795`, 1.464524848055271}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2320210785357544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7162445594142668`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0605822268555747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.180769407469538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[3.2320210785357544`, -1.7162445594142668`], 
            Complex[1.0605822268555747`, -3.180769407469538]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.807398594124686, 1.338502993533955}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[5.852579851369116, -0.6292277131331433], 
            Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3341940594651076`, 1.3385029935339554`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.710987197779323, -0.6292277131331433], 
            Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2781291411648206`, 1.1137819747427737`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.8621480115494466`, 0.503298877159704], 
            Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8634635124249723`, 1.1137819747427737`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.003740665139239, 0.5032988771597035], 
            Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4270130091476687`, 1.0827772011417844`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.182758062802262, -1.2043594268588764`], 
            Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7145796444421249`, 1.0827772011417847`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.324350716392056, -1.2043594268588769`], 
            Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686279050481857, 1.264621926810569}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.309291427092525, 1.195990161608288], 
            Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553136031079372`, 1.264621926810569}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.167698773502733, 1.1959901616082875`], 
            Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1719438734373724`, 1.4645725448481286`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231653364718622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218398`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0597094912812492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1827162181699684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[3.231653364718622, -1.7181436733218398`], 
            Complex[1.0597094912812492`, -3.1827162181699684`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9696487801524158, 1.4645725448481315`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.090060711128834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.05970949128125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1827162181699844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[0.090060711128834, -1.7181436733218531`], 
            Complex[1.05970949128125, -3.1827162181699844`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8062995086897997`, 1.3395841129871577`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[5.854761420740972, -0.637067142498334], 
            Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3352931448999938`, 1.3395841129871577`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.7131687671511795`, -0.6370671424983351], 
            Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8641702028463107`, 1.1118608796026903`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.0022564620129675`, 0.5116787778163029], 
            Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2774224507434824`, 1.1118608796026905`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.860663808423174, 0.5116787778163023], 
            Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4269120079766193`, 1.0824347635550098`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.182719421945745, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7146806456131727`, 1.0824347635550098`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.324312075535536, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862768975542866`, 1.2649306560972853`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.309293987807608, 1.1988273980957402`], 
            Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455315756035508, 1.2649306560972853`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.167701334217814, 1.19882739809574], 
            Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9691451178833616, 1.4646210055127558`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08969591052854747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.058841028411909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.18465541974018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[0.08969591052854747, -1.7200344142274246`], 
            Complex[1.058841028411909, -3.18465541974018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1724475357064317`, 1.464621005512757}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231288564118341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0588410284119094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.184655419740182`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[3.231288564118341, -1.7200344142274249`], 
            Complex[1.0588410284119094`, -3.184655419740182]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8052241800336288`, 1.3406500875123513`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[5.856866656504023, -0.6447767740762016], 
            Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3363684735561647`, 1.3406500875123515`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.71527400291423, -0.6447767740762022], 
            Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2767403982306236`, 1.1099574958323968`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.8592528632013723`, 0.5199245263444046], 
            Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8648522553591682`, 1.1099574958323963`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.000845516791171, 0.519924526344405], 
            Complex[4.135993261432002, -0.5900329694879913]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4268111871327607`, 1.0820934284157555`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.1826811049972195`, -1.210022511784006], 
            Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7147814664570336`, 1.0820934284157553`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.324273758587013, -1.2100225117840062`], 
            Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686274832354128, 1.2652382592992673`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.309296428167405, 1.201647620337122], 
            Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553178212356657`, 1.2652382592992673`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.167703774577614, 1.201647620337123], 
            Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1729498454789833`, 1.464670221581342}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230926641549791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7219168570985053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1865870786798474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[3.230926641549791, -1.7219168570985053`], 
            Complex[1.0579767960708073`, -3.1865870786798474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9686428081108099, 1.4646702215813419`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0893339879599975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.721916857098505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.186587078679847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[0.0893339879599975, -1.721916857098505], 
            Complex[1.0579767960708075`, -3.186587078679847]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.337421252632831, 1.3417012761259104`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.717307750554921, -0.6523609855265123], 
            Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8041714009569616`, 1.3417012761259108`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.8589004041447135`, -0.6523609855265128], 
            Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2760817623773704`, 1.108071451270443}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.857910352423154, 0.5280405519418746], 
            Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8655108912124228`, 1.1080714512704433`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.999503006012947, 0.528040551941874], 
            Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4267105450239965`, 1.0817531842116896`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.182643106997762, -1.2128287152203816`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7148821085657961`, 1.0817531842116899`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.324235760587555, -1.2128287152203814`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862728537588085`, 1.2655447480515745`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.309298751055461, 1.204451035693495], 
            Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553197998309857`, 1.2655447480515745`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.167706097465667, 1.2044510356934945`], 
            Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9681418438950994, 1.464720184698777}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08897490881592815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7237910758842274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0571167527110277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1885112605830046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[0.08897490881592815, -1.7237910758842274`], 
            Complex[1.0571167527110277`, -3.1885112605830046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.173450809694693, 1.4647201846987778`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2305675624057217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7237910758842263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.057116752711029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.188511260583004`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[3.2305675624057217`, -1.7237910758842263`], 
            Complex[1.057116752711029, -3.188511260583004]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8031400544083191`, 1.3427380384718104`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.860867089220406, -0.6598239647344442], 
            Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3384525991814749`, 1.3427380384718108`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.7192744356306133`, -0.6598239647344449], 
            Complex[4.057727034812088, -2.002562003206256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2754454122810435`, 1.1062023732101671`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.8566318723517807`, 0.5360310932164641], 
            Complex[4.132077284632824, -0.570171279993703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8661472413087492`, 1.1062023732101667`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.998224525941575, 0.5360310932164654], 
            Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4266100800826327`, 1.0814140196294526`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.182605423099423, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7149825735071609`, 1.0814140196294526`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.324198076689216, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455321692924102, 1.2658501337890655`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.167708305685528, 1.2072378477042838`], 
            Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862709606656907`, 1.265850133789066}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.30930095927532, 1.2072378477042842`], 
            Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.173950435241724, 1.4647708866207587`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230211292644681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7256571435340284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.056260857402957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.190428030154787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[3.230211292644681, -1.7256571435340284`], 
            Complex[1.056260857402957, -3.190428030154787]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9676422183480696, 1.4647708866207583`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08861863905488769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.725657143534028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0562608574029573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.190428030154786`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[0.08861863905488769, -1.725657143534028], 
            Complex[1.0562608574029573`, -3.190428030154786]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8021291050864379`, 1.343760732198116}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.862770761740871, -0.6671697152100744], 
            Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3394635485033561`, 1.343760732198116}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.7211781081510784`, -0.6671697152100743], 
            Complex[4.060641656654434, -2.01093044740819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2748302989843854`, 1.1043498910228218`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.8554133945952374`, 0.543900203601609], 
            Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8667623546054073`, 1.1043498910228218`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.99700604818503, 0.5439002036016083], 
            Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7150828628249586`, 1.0810759235498728`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.324160702151756, -1.2183914626776438`], 
            Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4265097907648356`, 1.0810759235498728`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.182568048561961, -1.218391462677644], 
            Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455323501598187, 1.2661544277512033`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.1677104019634195`, 1.210008256181661], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862691519916058`, 1.266154427751203}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.309303055553212, 1.2100082561816605`], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9671439246326016, 1.4648223192119325`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08826514518945743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.727515132015846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.055409069822059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1923374512277785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[0.08826514518945743, -1.727515132015846], 
            Complex[1.055409069822059, -3.1923374512277785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1744487289571905`, 1.4648223192119325`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2298577987792507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.727515132015845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0554090698220604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1923374512277776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[3.2298577987792507`, -1.727515132015845], 
            Complex[1.0554090698220604`, -3.1923374512277776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.801137591935122, 1.34476971093542}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.86461513517684, -0.6744020624307271], 
            Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3404550616546713`, 1.34476971093542}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.7230224815870465`, -0.6744020624307276], 
            Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2742354479672007`, 1.1025136381787524`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.854251227099731, 0.5516517577146821], 
            Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8673572056225929`, 1.1025136381787526`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.995843880689525, 0.5516517577146818], 
            Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4264096755501212`, 1.080738885043328}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.1825309787497025`, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.301887288061049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7151829780396723`, 1.0807388850433284`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.324123632339496, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553252269173917`, 1.2664576409867079`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.167712388950775, 1.2127624573020033`], 
            Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862674266724016`, 1.2664576409867079`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.309305042540569, 1.212762457302003], 
            Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.966646955962176, 1.4648744744440725`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08791439427478234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[0.08791439427478234, -1.7293651123339018`], 
            Complex[1.0545613502369584`, -3.1942395867779743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.174945697627617, 1.4648744744440725`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2295070478645758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[3.2295070478645758`, -1.7293651123339018`], 
            Complex[1.0545613502369586`, -3.1942395867779743`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.800164621430121, 1.34576532275647}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.86640362080727, -0.6815246607732995], 
            Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3414280321596725`, 1.3457653227564705`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.724810967217476, -0.6815246607732999], 
            Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2736599524300998`, 1.100693253787374}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.8531419798044717`, 0.5592894583048513], 
            Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8679327011596927`, 1.1006932537873735`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.994734633394268, 0.5592894583048527], 
            Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.715282920648939, 1.080402893365248}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.324086862718293, -1.2238893126698196`], 
            Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4263097329408554`, 1.0804028933652483`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.1824942091285005`, -1.2238893126698194`], 
            Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455326869927298, 1.2667597843580762`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.167714269226694, 1.2155006436945395`], 
            Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862657836624946`, 1.2667597843580762`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.30930692281649, 1.2155006436945397`], 
            Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9661513056004137, 1.4649273443942974`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08756635389739194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.73120715454608`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1961344989403777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[0.08756635389739194, -1.73120715454608], 
            Complex[1.0537176594978057`, -3.1961344989403777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.175441347989379, 1.4649273443942974`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.229159007487185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7312071545460794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.196134498940377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[3.229159007487185, -1.7312071545460794`], 
            Complex[1.0537176594978062`, -3.196134498940377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7992093615684013`, 1.3467479090203915`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.868139358018381, -0.6885410007735715], 
            Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3423832920213918`, 1.346747909020392}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.7265467044285883`, -0.6885410007735716], 
            Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8684896863091012`, 1.0988883837525505`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.993675187934443, 0.5668168435275391], 
            Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2731029672806917`, 1.0988883837525507`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.852082534344649, 0.5668168435275388], 
            Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4262099614617623`, 1.0800679379517526`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.182457735262816, -1.2266143809612575`], 
            Complex[7.608667696724579, -2.30668231891301]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7153826921280313`, 1.0800679379517524`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.32405038885261, -1.2266143809612582`], 
            Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862642219344588`, 1.267060868545956}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.309308698890094, 1.2182230045272866`], 
            Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553284316553357`, 1.267060868545956}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.167716045300302, 1.2182230045272868`], 
            Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9656569668606385, 1.4649809212433296`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08722099216430315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.733041327780913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0528779590249415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1980222490242425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[0.08722099216430315, -1.733041327780913], 
            Complex[1.0528779590249415`, -3.1980222490242425`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1759356867291544`, 1.4649809212433296`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228813645754096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7330413277809138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052877959024942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1980222490242434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[3.228813645754096, -1.7330413277809138`], 
            Complex[1.052877959024942, -3.1980222490242434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.79827103648009, 1.3477178035240853`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.869825241082359, -0.6954544165180526], 
            Complex[4.071554204602269, -2.043172220042138]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3433216171097038`, 1.3477178035240855`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.7282325874925664`, -0.6954544165180527], 
            Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.272563703742505, 1.0970986816207915`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.8510700172747567`, 0.5742372943510567], 
            Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8690289498472876`, 1.0970986816207915`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.992662670864552, 0.5742372943510564], 
            Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4261103596594529`, 1.0797340084154219`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.1824215528129, -1.229323793839144], 
            Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7154822939303398`, 1.0797340084154217`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.324014206402694, -1.2293237938391435`], 
            Complex[7.608531912472354, -2.309057802254565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553299131112016`, 1.2673609040533935`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.167717719612997, 1.2209297255903704`], 
            Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686262740478591, 1.2673609040533935`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.309310373202791, 1.2209297255903702`], 
            Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9651639331054312, 1.465035197273779}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.086878277692393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0520422107978245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.199902897527961`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[0.086878277692393, -1.7348677002541821`], 
            Complex[1.0520422107978245`, -3.199902897527961]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1764287204843615`, 1.4650351972737785`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228470931282186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052042210797825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1999028975279598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[3.228470931282186, -1.7348677002541815`], 
            Complex[1.052042210797825, -3.1999028975279598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3442437319973233`, 1.3486753318987115`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.729871289280439, -0.7022680930260651], 
            Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.79734892159247, 1.3486753318987115`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.871463942870232, -0.7022680930260652], 
            Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2720414245160234`, 1.0953238091843571`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.850101776357696, 0.5815540419531228], 
            Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8695512290737692`, 1.0953238091843573`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.991694429947489, 0.5815540419531224], 
            Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4260109261019664`, 1.0794010945411947`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.182385657532068, -1.2320177339512255`], 
            Complex[7.608396583634034, -2.31141882849242]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.715581727487827, 1.0794010945411947`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.323978311121861, -1.232017733951227], 
            Complex[7.608396583634034, -2.311418828492422]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553313152872658`, 1.2676599012099539`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.167719294540649, 1.2236209893768326`], 
            Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862613383025276`, 1.2676599012099543`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.309311948130448, 1.2236209893768368`], 
            Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9646721977461887, 1.465090164868473}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08653817959803752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7366863392851428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153616`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[0.08653817959803752, -1.7366863392851428`], 
            Complex[1.0512103773442263`, -3.201776504153616]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1769204558436024`, 1.465090164868472}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2281308331878296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.736686339285139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153611`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[3.2281308331878296`, -1.736686339285139], 
            Complex[1.0512103773442272`, -3.201776504153611]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3451503143061683`, 1.3496208112013486`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.7314652823007664`, -0.7089850735194753], 
            Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7964423392836244`, 1.3496208112013484`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.87305793589056, -0.7089850735194753], 
            Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.870057214160368, 1.0935634368891871`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.990768013117869, 0.588770175004682], 
            Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.271535439429426, 1.0935634368891873`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.8491753595280755`, 0.5887701750046822], 
            Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4259116593783145`, 1.0790691862823862`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.182350045264077, -1.2346963807243223`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.715680994211479, 1.079069186282386}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.323942698853871, -1.2346963807243225`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862600144308344`, 1.2679578701757186`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.30931342598549, 1.2262969751610369`], 
            Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553326391589598`, 1.2679578701757186`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.167720772395696, 1.2262969751610366`], 
            Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9641817542426991, 1.465145816508811}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08620066748699956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[0.08620066748699956, -1.7384973113123776`], 
            Complex[1.0503824217296986`, -3.2036431278211883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.177410899347094, 1.4651458165088114`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227793321076793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296989`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[3.227793321076793, -1.7384973113123774`], 
            Complex[1.0503824217296989`, -3.2036431278211888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3460419986191394`, 1.350554549661692}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.733016857401756, -0.7156082665076033], 
            Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7955506549706537`, 1.3505545496616918`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.874609510991549, -0.7156082665076038], 
            Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.870547552065842, 1.0918172440877816`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.98988114978185, 0.5958886467685789], 
            Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2710451015239508`, 1.0918172440877818`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.848288496192057, 0.5958886467685786], 
            Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7157800954917433`, 1.078738273756824}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.323907365530383, -1.2373599104403945`], 
            Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4258125580980487`, 1.0787382737568234`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.182314711940597, -1.2373599104404132`], 
            Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686258767904639, 1.2682548209451625`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.309314809018922, 1.2289578590746733`], 
            Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553338856851545`, 1.268254820945162}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.16772215542913, 1.2289578590746735`], 
            Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1779000574870997`, 1.4652021447731618`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227458365034377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.20550282668249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[3.227458365034377, -1.7403006819093283`], 
            Complex[1.0495583075472772`, -3.20550282668249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9636925961026941, 1.4652021447731611`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08586571144458416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093272`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2055028266824883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[0.08586571144458416, -1.7403006819093272`], 
            Complex[1.0495583075472783`, -3.2055028266824883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.79467327358393, 1.351476846551469}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.876120794018037, -0.7221404526376908], 
            Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3469193800058639`, 1.351476846551469}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.734528140428245, -0.7221404526376912], 
            Complex[4.081447520434109, -2.07361729918916]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.270569803525362, 1.0900849191693633`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.847439080572326, 0.6029122819634529], 
            Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8710228500644306`, 1.0900849191693633`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.989031734162119, 0.6029122819634535], 
            Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4257136208908425`, 1.0784083472430945`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.182279653578758, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.715879032698951, 1.078408347243095}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.323872307168552, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553350558085392`, 1.2685507633509223`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.167723445832482, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862575977812542`, 1.2685507633509223`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.309316099422276, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9632047168814335, 1.465259142335282}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08553328202600917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.742096515799434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[0.08553328202600917, -1.742096515799434], 
            Complex[1.0487379989074426`, -3.207355658134716]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1783879367083596`, 1.4652591423352825`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227125935615802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7420965157994346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134717`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[3.227125935615802, -1.7420965157994346`], 
            Complex[1.0487379989074426`, -3.207355658134717]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7938096363846086`, 1.3523879921505317`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.877593760675199, -0.7285842912785059], 
            Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3477830172051852`, 1.3523879921505317`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.736001107085408, -0.7285842912785057], 
            Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.270108974658715, 1.0883661595933591`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.8466251568463186`, 0.6098437833604624], 
            Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.871483678931077, 1.0883661595933587`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.988217810436113, 0.6098437833604634], 
            Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4256148464060636`, 1.0780793971769094`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.182244866278791, -1.242642308546148], 
            Complex[7.607859712684855, -2.320721705723057]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7159778071837308`, 1.078079397176909}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.323837519868585, -1.242642308546154], 
            Complex[7.607859712684855, -2.320721705723063]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553361504559745`, 1.268845707067453}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.167724645739662, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862565031338197`, 1.268845707067453}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.309317299329457, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1788745434085155`, 1.4653168019627736`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2267960038368266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7438848768709785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[3.2267960038368266`, -1.7438848768709785`], 
            Complex[1.0479214604283111`, -3.209201678833752]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9627181101812778, 1.4653168019627743`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08520335024703361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7438848768709778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[0.08520335024703361, -1.7438848768709778`], 
            Complex[1.0479214604283116`, -3.209201678833752]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7929592180877234`, 1.3532882677886187`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.879030249816931, -0.7349423268176076], 
            Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3486334355020697`, 1.3532882677886189`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.7374375962271382`, -0.7349423268176083], 
            Complex[4.086071031729208, -2.088230594606227]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8719305758210323`, 1.0866606718472052`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.987437559449537, 0.616685738093365], 
            Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2696620777687606`, 1.0866606718472054`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.845844905859744, 0.6166857380933649], 
            Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7160764202774115`, 1.0777514141475621`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.323802999811543, -1.2452615144292978`], 
            Complex[7.607726579534131, -2.32301292857686]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.425516233312382, 1.0777514141475624`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.1822103462217495`, -1.245261514429298], 
            Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553371705388412`, 1.2691396616145785`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.167725757228776, 1.2368516153041005`], 
            Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862554830509522`, 1.2691396616145783`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.30931841081857, 1.2368516153040952`], 
            Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9622327696512636, 1.4653751165155728`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08487588757480041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7456658281915818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.047108657226064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[0.08487588757480041, -1.7456658281915818`], 
            Complex[1.047108657226064, -3.2110409447071544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1793598839385298`, 1.4653751165155733`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2264685411645937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7456658281915811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0471086572260642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[3.2264685411645937`, -1.7456658281915811`], 
            Complex[1.0471086572260642`, -3.2110409447071544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7921215242576274`, 1.3541779459458636`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.880431975347877, -0.7412169946624547], 
            Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3494711293321664`, 1.3541779459458636`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.7388393217580846`, -0.7412169946624545], 
            Complex[4.088310451090251, -2.095394940608318]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2692286067127467`, 1.0849681713454111`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.8450966332264747`, 0.6234406236721284], 
            Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.872364046877046, 1.0849681713454111`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.986689286816269, 0.6234406236721282], 
            Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7161748732924147`, 1.0774243888944977`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.3237687432571, -1.2478662783795624`], 
            Complex[7.607593869964685, -2.32529066727406]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4254177802973789`, 1.0774243888944979`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.182176089667306, -1.2478662783795629`], 
            Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553381169533872`, 1.269432636360937}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.16772678232385, 1.2394537927373115`], 
            Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862545366364052`, 1.269432636360937}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.309319435913645, 1.2394537927373108`], 
            Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1798439646031036`, 1.465434078944463}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.226143519508699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747439432022393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0462995549055958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.212873510966856`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[3.226143519508699, -1.747439432022393], 
            Complex[1.0462995549055958`, -3.212873510966856]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9617486889866901, 1.4654340789444629`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08455086591890591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474394320223927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.046299554905596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2128735109668556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[0.08455086591890591, -1.7474394320223927`], 
            Complex[1.046299554905596, -3.2128735109668556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3502965646432927`, 1.355057290398381}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.7402078833132797`, -0.7474106269426312], 
            Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7912960889465004`, 1.355057290398381}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.881800536903074, -0.7474106269426314], 
            Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2688080839963416`, 1.0832883822835297`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.8443787586507785`, 0.6301108136973931], 
            Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8727845695934517`, 1.0832883822835293`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.985971412240573, 0.6301108136973947], 
            Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.425319486067153, 1.0770983123039746`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.182142092951617, -1.2504567620199438`], 
            Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7162731675226397`, 1.0770983123039743`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.323734746541412, -1.2504567620199438`], 
            Complex[7.607461579018771, -2.327555074323918]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862536630087408`, 1.2697246405273381`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.309320376586301, 1.2420417043271583`], 
            Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553389905810519`, 1.2697246405273381`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.167727722996508, 1.2420417043271579`], 
            Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9612658619287017, 1.465493682289621}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0842282576226818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7492057498319649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0454941195513836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2146994321215856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[0.0842282576226818, -1.7492057498319649`], 
            Complex[1.0454941195513836`, -3.2146994321215856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.180326791661091, 1.4654936822896205`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225820911212475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7492057498319644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.045494119551384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2146994321215847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[3.225820911212475, -1.7492057498319644`], 
            Complex[1.045494119551384, -3.2146994321215847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3511101810397217`, 1.3559265563979424`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.7415447758580713`, -0.7535254579157126], 
            Complex[4.092654956897793, -2.109452014313655]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.790482472550071, 1.3559265563979424`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.883137429447864, -0.7535254579157123], 
            Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8731925949629857`, 1.0816210374580488`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.985282459919064, 0.6366985832782691], 
            Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2684000586268078`, 1.081621037458049}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.843689806329271, 0.6366985832782687], 
            Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4252213493459658`, 1.0767731754058245`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.182108352485272, -1.2530331242405153`], 
            Complex[7.607329701831238, -2.32980629964634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7163713042438276`, 1.076773175405825}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.323701006075066, -1.253033124240515], 
            Complex[7.607329701831238, -2.32980629964634]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686252861301002, 1.2700156831900122`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.309321234757373, 1.2446155088257416`], 
            Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553397922887907`, 1.2700156831900125`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.16772858116758, 1.2446155088257413`], 
            Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9607842822638821, 1.465553919679193}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08390803545469033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7509648423098307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[0.08390803545469033, -1.7509648423098307`], 
            Complex[1.0446923177185725`, -3.2165187619890236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1808083713259108`, 1.4655539196791934`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225500689044484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.750964842309831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[3.225500689044484, -1.750964842309831], 
            Complex[1.0446923177185734`, -3.2165187619890245`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.789680259857706, 1.356785990876864}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.884444051922338, -0.7595636290829754], 
            Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3519123937320872`, 1.3567859908768638`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.742851398332544, -0.7595636290829759], 
            Complex[4.094763792064631, -2.11634961995984]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2680041041606018`, 1.0799658780610615`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.8430283963083336`, 0.6432061141597183], 
            Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8735885494291913`, 1.0799658780610617`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.984621049898127, 0.643206114159718], 
            Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7164692847139307`, 1.0764489693703025`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.323667518341093, -1.255595521260306], 
            Complex[7.607198233627162, -2.332044490630609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4251233688758635`, 1.0764489693703032`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.182074864751301, -1.2555955212603063`], 
            Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455340522929389, 1.270305773283777}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.167729358708656, 1.247175362316046], 
            Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862521306604028`, 1.2703057732837766`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.30932201229845, 1.247175362316046], 
            Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.960303943823844, 1.4656147843278973`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0835901726004175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.752716769379781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.218331553707678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[0.0835901726004175, -1.752716769379781], 
            Complex[1.0438941164242617`, -3.218331553707678]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1812887097659486`, 1.4656147843278988`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2251828261902116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7527167693797805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2183315537076793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[3.2251828261902116`, -1.7527167693797805`], 
            Complex[1.0438941164242628`, -3.2183315537076793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3527035953131048`, 1.3576358326709912`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.744129061448893, -0.7655271940238008], 
            Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7888890582766885`, 1.3576358326709914`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.885721715038686, -0.7655271940238007], 
            Complex[4.096832656761998, -2.123163026694792]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8739728366645858`, 1.078322653456834}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.983985890278379, 0.6496354995683528], 
            Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2676198169252069`, 1.0783226534568342`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.842393236688587, 0.6496354995683534], 
            Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.425025543416335, 1.0761256855050252`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.182041626303249, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7165671101734585`, 1.0761256855050254`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.323634279893042, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686251470248025, 1.2705949196051105`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.309322711033374, 1.2497214182720298`], 
            Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553411833417669`, 1.2705949196051107`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.167730057443585, 1.249721418272031], 
            Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9598248404848249, 1.4656762695356542`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08327464265416494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.04309948313899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2201378597485255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[0.08327464265416494, -1.7544615902128715`], 
            Complex[1.04309948313899, -3.2201378597485255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.181767813104968, 1.4656762695356533`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.224867296243958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0430994831389901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2201378597485246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[3.224867296243958, -1.7544615902128715`], 
            Complex[1.0430994831389901`, -3.2201378597485246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3534841573769862`, 1.3584763127550676`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.745378994736478, -0.7714181229593412], 
            Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7881084962128069`, 1.358476312755068}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.886971648326271, -0.7714181229593432], 
            Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2672468143973132`, 1.0766911209459984`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.8417831165816425`, 0.6559887487872518], 
            Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8743458391924803`, 1.0766911209459982`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.983375770171436, 0.655988748787251], 
            Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.424927871743964, 1.0758033152519937`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.182008633763318, -1.260679031577555], 
            Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7166647818458296`, 1.0758033152519941`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.323601287353112, -1.2606790315775551`], 
            Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553417743512735`, 1.2708831308151451`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.167730679149904, 1.2522538276170248`], 
            Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862508792385207`, 1.2708831308151454`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.309323332739702, 1.2522538276170265`], 
            Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.182245687422502, 1.4657383686862342`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2245540732009284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561993632401343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[3.2245540732009284`, -1.7561993632401343`], 
            Complex[1.0423083857784268`, -3.2219377319263685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9593469661672926, 1.465738368686233}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08296141961113473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561993632401347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263676`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[0.08296141961113473, -1.7561993632401347`], 
            Complex[1.0423083857784274`, -3.2219377319263676`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3542544319983827`, 1.3593076544859068`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.746602352917594, -0.7772383070571701], 
            Complex[4.100856784915977, -2.136545961543077]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.78733822159141, 1.3593076544859064`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.888195006507387, -0.7772383070571703], 
            Complex[4.100856784915978, -2.136545961543077]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2668847337215234`, 1.0750710455219266`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.8411968997361448`, 0.6622677914714884], 
            Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8747079198682688`, 1.0750710455219263`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.982789553325939, 0.6622677914714878], 
            Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7167623009376995`, 1.0754818501847014`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.323568537410361, -1.2632004444906193`], 
            Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.424830352652094, 1.0754818501847019`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.181975883820568, -1.2632004444906197`], 
            Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862503568198186`, 1.271170415442569}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.309323879150051, 1.254772738780499], 
            Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553422967699756`, 1.271170415442569}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.167731225560259, 1.2547727387804994`], 
            Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9588703148355403, 1.4658010752459556`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08265047785970185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7579301461650303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.223731221410986`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[0.08265047785970185, -1.7579301461650303`], 
            Complex[1.0415207926952421`, -3.223731221410986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1827223387542523`, 1.4658010752459552`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2242431314494953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7579301461650294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2237312214109846`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[3.2242431314494953`, -1.7579301461650294`], 
            Complex[1.0415207926952428`, -3.2237312214109846`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3550147530849104`, 1.3601300738497375`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.7478002216867257`, -0.7829895624892164], 
            Complex[4.102814974771636, -2.143119636338954]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.786577900504883, 1.3601300738497377`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.88939287527652, -0.782989562489217], 
            Complex[4.102814974771636, -2.143119636338955]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8750594232342832`, 1.073462199622943}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.982226172350083, 0.6684744817167128], 
            Complex[4.1071667491158, -0.4049877179062303]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2665332303555106`, 1.0734621996229432`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.8406335187602902`, 0.6684744817167128], 
            Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7168596686392952`, 1.0751612820053194`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.323536026818966, -1.2657084915461236`], 
            Complex[7.606676358179671, -2.340869773551443]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4247329849504993`, 1.0751612820053196`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.1819433732291715`, -1.2657084915461239`], 
            Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553427513969417`, 1.2714567818864557`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.167731698363721, 1.2572782977532326`], 
            Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862499021928519`, 1.271456781886456}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.309324351953519, 1.2572782977532362`], 
            Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9583948804973057, 1.465864382762379}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08234179217386196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.759653995975626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[0.08234179217386196, -1.759653995975626], 
            Complex[1.0407366726711678`, -3.225518378738005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1831977730924867`, 1.4658643827623774`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223934445763656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7596539959756308`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[3.223934445763656, -1.7596539959756308`], 
            Complex[1.0407366726711693`, -3.225518378738008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3557654376157497`, 1.3609437797108246`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.748973622957287, -0.7886736342555815], 
            Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7858272159740434`, 1.3609437797108246`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.89056627654708, -0.7886736342555825], 
            Complex[4.104739060573037, -2.149617413966407]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8754006767606501`, 1.0718643628832527`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.981684623466656, 0.6746106018933713], 
            Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2661919768291434`, 1.0718643628832532`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.8400919698768647`, 0.6746106018933697], 
            Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4246357674650718`, 1.0748416025419574`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.181911098806735, -1.2682033164767692`], 
            Complex[7.606546866271806, -2.343044919018727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7169568861247224`, 1.0748416025419574`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.323503752396531, -1.2682033164767677`], 
            Complex[7.60654686627181, -2.343044919018725]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455343139018517, 1.2717422384190145`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.167732099207092, 1.2597706481409663`], 
            Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862495145712781`, 1.271742238419015}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.309324752796902, 1.2597706481409692`], 
            Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9579206572033735, 1.4659282848630426`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08203533770586706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7613709689565493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[0.08203533770586706, -1.7613709689565493`], 
            Complex[1.0399559949092405`, -3.227299253819592]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1836719963864195`, 1.4659282848630424`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2236279912956602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7613709689565495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[3.2236279912956602`, -1.7613709689565495`], 
            Complex[1.0399559949092407`, -3.227299253819592]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8757319919833184`, 1.0702773218848616`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.981163961744247, 0.6806778662591632], 
            Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2658606616064754`, 1.0702773218848614`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.8395713081544542`, 0.6806778662591643], 
            Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7850858668123624`, 1.3617489740590967`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.891716173221934, -0.7942921997868306], 
            Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3565067867774308`, 1.3617489740590962`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.750123519632142, -0.794292199786831], 
            Complex[4.106630306409572, -2.156041173845927]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7170539545522856`, 1.0745228037460035`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.323471711022448, -1.2706850606806674`], 
            Complex[7.606417756470162, -2.345207864426671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4245386990375086`, 1.0745228037460033`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.1818790574326545`, -1.2706850606806677`], 
            Complex[7.606417756470163, -2.345207864426671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553434604085804`, 1.2720267931882643`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.167732429696165, 1.2622499312165703`], 
            Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862491931812122`, 1.272026793188264}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.309325083285957, 1.26224993121657], 
            Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9574476390471889, 1.4659927752542257`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0817310899790139`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.763081120700618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2290738959548437`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[0.0817310899790139, -1.763081120700618], 
            Complex[1.039178729026203, -3.2290738959548437`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1841450145426045`, 1.4659927752542257`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223323743568807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7630811207006185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.229073895954844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[3.223323743568807, -1.7630811207006185`], 
            Complex[1.039178729026203, -3.229073895954844]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8760536655490998`, 1.0687008699122638`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.980663296755008, 0.6866779243621381], 
            Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.265538988040694, 1.0687008699122635`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.839070643165216, 0.6866779243621389], 
            Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.357239087006698, 1.3625458522550062`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.751250819947598, -0.7998468723371362], 
            Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7843535665830947`, 1.3625458522550065`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.892843473537392, -0.7998468723371351], 
            Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.424441778525006, 1.0742048776895323`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.181847246046556, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7171508750647866`, 1.0742048776895323`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.323439899636348, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553437163288179`, 1.2723104542206363`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.167732691396911, 1.2647162859707828`], 
            Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862489372609757`, 1.2723104542206363`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.309325344986703, 1.2647162859707826`], 
            Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1846168334253093`, 1.466057847719723}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2230216784704147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7647845061203178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[3.2230216784704147`, -1.7647845061203178`], 
            Complex[1.0384048450451053`, -3.230842353840041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.956975820164485, 1.4660578477197224`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08142902488062087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7647845061203167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840039`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[0.08142902488062087, -1.7647845061203167`], 
            Complex[1.0384048450451058`, -3.230842353840039]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.876365980176603, 1.0671348067112731`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.980181788615051, 0.6926123642464803], 
            Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2652266734131905`, 1.0671348067112731`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.838589135025258, 0.6926123642464805], 
            Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3579626109492815`, 1.3633346032702531`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.7523563814347085`, -0.8053392041803537], 
            Complex[4.11031899238399, -2.168673807450607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.783630042640511, 1.3633346032702531`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.893949035024502, -0.8053392041803533], 
            Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4243450047999704`, 1.0738878165627848`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.181815661646743, -1.275609861130944], 
            Complex[7.606160666446714, -2.349497677693729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7172476487898232`, 1.073887816562785}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.323408315236543, -1.2756098611309419`], 
            Complex[7.60616066644672, -2.349497677693727]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862487460608298`, 1.272593229423509}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.30932553942646, 1.2671698491615646`], 
            Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553439075289638`, 1.272593229423509}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.167732885836667, 1.2671698491615644`], 
            Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1850874588569025`, 1.4661234961196488`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222721772244943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589748`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[3.222721772244943, -1.7664811794589748`], 
            Complex[1.0376343133880408`, -3.2326046755786235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9565051947328909, 1.4661234961196488`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08112911865515363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[0.08112911865515363, -1.7664811794589725`], 
            Complex[1.0376343133880443`, -3.2326046755786213`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8766692055409044`, 1.0655789382530265`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.979718644368703, 0.6984827154726538], 
            Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2649234480488893`, 1.0655789382530265`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.8381259907789103`, 0.6984827154726537], 
            Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7829150352473249`, 1.3641154099233181`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.8950336681265165`, -0.8107706896206487], 
            Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3586776183424694`, 1.364115409923318}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.7534410145367234`, -0.8107706896206492], 
            Complex[4.112118632879193, -2.174886099543967]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.424248376749721, 1.0735716126717123`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.1817843012887375`, -1.2780531889506415`], 
            Complex[7.606032678038458, -2.351624801622354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7173442768400726`, 1.0735716126717125`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.323376954878531, -1.2780531889506412`], 
            Complex[7.606032678038458, -2.351624801622354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455344034747049, 1.2728751265876714`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.167733014505244, 1.2696107553621172`], 
            Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862486188427437`, 1.2728751265876717`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.309325668095038, 1.2696107553621176`], 
            Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9560357569715692, 1.4661897143892662`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08083134789749542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2343609086909946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[0.08083134789749542, -1.7681711943017286`], 
            Complex[1.0368671048690645`, -3.2343609086909946`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1855568966182237`, 1.4661897143892657`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222424001487289`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.234360908690994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[3.222424001487289, -1.7681711943017286`], 
            Complex[1.0368671048690654`, -3.234360908690994]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2646290545007475`, 1.0640330765039456`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.8376804610924062`, 0.7042904519630285], 
            Complex[4.102309515593154, -0.359742624540917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.876963599089044, 1.064033076503945}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.979273114682207, 0.7042904519630309], 
            Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.359384356828523, 1.364888449109056}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.7545054859170786`, -0.8161427678288303], 
            Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7822082967612691`, 1.3648884491090565`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.896098139506871, -0.8161427678288314], 
            Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4241518932762212`, 1.0732562584355896`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.181753162083825, -1.2804839792850273`], 
            Complex[7.605905055360047, -2.353740237720617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7174407603135722`, 1.0732562584355896`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.323345815673619, -1.2804839792850278`], 
            Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862485548801436`, 1.2731561533897244`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.309325732445826, 1.2720391370076072`], 
            Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553440987096498`, 1.2731561533897247`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.167733078856032, 1.272039137007607], 
            Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9555675011408362, 1.4662564965378329`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08053568954642111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7698546035862615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[0.08053568954642111, -1.7698546035862615`], 
            Complex[1.0361031906872573`, -3.2361111001240945`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1860251524489565`, 1.4662564965378329`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2221283431362147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.769854603586262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[3.2221283431362147`, -1.769854603586262], 
            Complex[1.0361031906872582`, -3.2361111001240945`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8772494067926553`, 1.0624970392022144`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.978844490816281, 0.7100369946836335], 
            Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2643432467971383`, 1.0624970392022146`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.8372518372264883`, 0.710036994683633], 
            Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7815095908845182`, 1.3656538920217647`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.897143175078252, -0.8214568255150104], 
            Complex[4.115633584193734, -2.187110717536775]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3600830627052753`, 1.3656538920217647`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.7555505214884586`, -0.8214568255150109], 
            Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7175371002940005`, 1.0729417463846898`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.32331489478747, -1.282902362593793], 
            Complex[7.605777794493471, -2.355844108978483]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4240555532957928`, 1.0729417463846898`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.181722241197679, -1.2829023625937932`], 
            Complex[7.605777794493473, -2.355844108978483]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862485534576859`, 1.2734363173944174`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.309325733896824, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553441001321066`, 1.2734363173944172`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.1677330803070305`, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.955100421541801, 1.466323836647474}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08024212087815223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[0.08024212087815223, -1.7715314596133194`], 
            Complex[1.0353425424199532`, -3.2378552962607934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.186492232047992, 1.4663238366474738`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.221834774467946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[3.221834774467946, -1.7715314596133196`], 
            Complex[1.0353425424199543`, -3.2378552962607934`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2640657897464236`, 1.0609706496411517`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.836839448260752, 0.7157237141721116], 
            Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.87752686384337, 1.0609706496411517`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.9784321018505455`, 0.7157237141721113], 
            Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3607739616195396`, 1.3664119043713532`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.7565768091900997`, -0.8267141994476596], 
            Complex[4.117350770809639, -2.193126103819013]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.780818691970253, 1.3664119043713534`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.898169462779893, -0.8267141994476594], 
            Complex[4.11735077080964, -2.193126103819013]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7176332978509388`, 1.072628069158018}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.323284189438796, -1.2853084672867803`], 
            Complex[7.605650891587858, -2.357936536444798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4239593557388546`, 1.072628069158018}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.181691535849006, -1.2853084672867796`], 
            Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455344039718769, 1.273715626056924}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.167733020241881, 1.276858845955496], 
            Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862486138710238`, 1.2737156260569238`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.309325673831674, 1.2768588459554961`], 
            Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9546345125159902, 1.46639172887207}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07995061950010503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.773201814057012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.034585132016095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.239593542929082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[0.07995061950010503, -1.773201814057012], 
            Complex[1.034585132016095, -3.239593542929082]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.186958141073803, 1.4663917288720705`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2215432730898983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7732018140570123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0345851320160955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2395935429290827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[3.2215432730898983`, -1.7732018140570123`], 
            Complex[1.0345851320160955`, -3.2395935429290827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.26379645829365, 1.0594537364597336`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.8364426585455744`, 0.7213519329214126], 
            Complex[4.100239116839224, -0.338101803538321]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8777961952961422`, 1.0594537364597338`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.978035312135368, 0.7213519329214122], 
            Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7801353843813221`, 1.367162646592373}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.899177655127286, -0.8319161788285983], 
            Complex[4.119042270745964, -2.199078825420971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3614572692084712`, 1.367162646592373}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.7575850015374925`, -0.8319161788285991], 
            Complex[4.119042270745964, -2.199078825420972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4238632995496614`, 1.0723152195011063`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.181661043308228, -1.2877024197670905`], 
            Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7177293540401313`, 1.0723152195011063`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.323253696898021, -1.2877024197670908`], 
            Complex[7.60552434285789, -2.360017639268197]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455343918163203, 1.273994086725058}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.1677329000108365`, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862487354265896`, 1.273994086725058}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.30932555360063, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1874228851447937`, 1.4664601674361746`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2212538169345617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.24132588541108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[3.2212538169345617`, -1.7748657179749052`], 
            Complex[1.0338309317897683`, -3.24132588541108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9541697684450003, 1.466460167436175}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0796611633447683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749043`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2413258854110794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[0.0796611633447683, -1.7748657179749043`], 
            Complex[1.0338309317897687`, -3.2413258854110794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8780576166650225`, 1.057946133440395}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.977653518949829, 0.7269229276281969], 
            Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2635350369247706`, 1.057946133440395}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.836060865360036, 0.7269229276281965], 
            Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3621331916934059`, 1.3679062740457615`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.7585757179660733`, -0.8370640075328957], 
            Complex[4.120708909659479, -2.204970281578657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7794594618963873`, 1.3679062740457615`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.900168371555867, -0.8370640075328958], 
            Complex[4.120708909659479, -2.204970281578657]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7178252699037433`, 1.072003190263868}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.32322341448604, -1.2900843444730699`], 
            Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4237673836860494`, 1.072003190263868}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.181630760896252, -1.2900843444730699`], 
            Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862489174413793`, 1.2742717066414342`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.30932537452151, 1.2816299944237615`], 
            Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455343736148415, 1.2742717066414342`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.167732720931719, 1.2816299944237621`], 
            Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1878864698396656`, 1.4665291466339385`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.220966384253502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7765232218179048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2430523684518433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[3.220966384253502, -1.7765232218179048`], 
            Complex[1.0330799144138363`, -3.2430523684518433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9537061837501273, 1.466529146633939}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07937373066370935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.776523221817905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.243052368451844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[0.07937373066370935, -1.776523221817905], 
            Complex[1.0330799144138367`, -3.243052368451844]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8783113344755131`, 1.0564476793141508`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.97728615034638, 0.7324379313144281], 
            Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.26328131911428, 1.056447679314151}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.8356934967565883`, 0.732437931314428], 
            Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3628019264303366`, 1.3686429372132638`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.759549546988155, -0.8421588862221198], 
            Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7787907271594565`, 1.3686429372132638`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.901142200577949, -0.8421588862221203], 
            Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7179210464706118`, 1.0716919743985005`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.323193339572983, -1.292454363919178], 
            Complex[7.605272293102371, -2.364146338317678]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4236716071191817`, 1.0716919743985007`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.181600685983191, -1.2924543639191768`], 
            Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686249159242732, 1.2745484929455693`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.309325137880622, 1.2839976681063674`], 
            Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553434943470607`, 1.2745484929455695`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.167732484290831, 1.2839976681063678`], 
            Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1883489006977705`, 1.46659866082807}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2206809536115193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7781743754399488`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[3.2206809536115193`, -1.7781743754399488`], 
            Complex[1.0323320529137487`, -3.2447730362680187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9532437528920217, 1.4665986608280708`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07908830002172706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7781743754399495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[0.07908830002172706, -1.7781743754399495`], 
            Complex[1.0323320529137487`, -3.2447730362680205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2630351068125485`, 1.0549582175730223`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.8353400095752215`, 0.7378981353300624], 
            Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8785575467772442`, 1.0549582175730219`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.976932663165016, 0.7378981353300635], 
            Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.363463662420717, 1.3693727818845618`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.760507048180339, -0.8472019743388879], 
            Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7781289911690756`, 1.3693727818845618`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.9020997017701315`, -0.8472019743388882], 
            Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.718016684756481, 1.0713815649574496`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.323163469577016, -1.2948125987358026`], 
            Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4235759688333116`, 1.0713815649574496`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.181570815987224, -1.2948125987358035`], 
            Complex[7.605146784820535, -2.366194163693253]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553431934216576`, 1.274824452675933}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.167732191343831, 1.2863535694098465`], 
            Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862494601681366`, 1.274824452675933}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.309324844933629, 1.286353569409846], 
            Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9527824703703334, 1.4666687044488012`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07880485029112587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325562994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[0.07880485029112587, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325562994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.18881018321946, 1.4666687044488018`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2203975038809194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325563003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[3.2203975038809194`, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325563003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2627962099694992`, 1.0534775962896732`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.8349998876116986`, 0.7433046912443027], 
            Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8787964436202937`, 1.0534775962896734`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.976592541201492, 0.7433046912443029], 
            Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.364118580785964, 1.370095949337179}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.7614487540168455`, -0.8521943919901349], 
            Complex[4.12556733480281, -2.222290341327314]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7774740728038292`, 1.3700959493371787`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.903041407606638, -0.852194391990135], 
            Complex[4.12556733480281, -2.222290341327314]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4234804678255462`, 1.0710719550914205`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.181541148373396, -1.2971591677080394`], 
            Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.718112185764248, 1.0710719550914203`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.323133801963191, -1.2971591677080403`], 
            Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862498195650244`, 1.2750995927719446`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.309324496906415, 1.2886978170110814`], 
            Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455342834024769, 1.2750995927719446`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.167731843316621, 1.2886978170110817`], 
            Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.189270322866432, 1.46673927199288}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2201160142359173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7814578285088363`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030845691369485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.248197100501716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[3.2201160142359173`, -1.7814578285088363`], 
            Complex[1.030845691369485, -3.248197100501716]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9523223307233655, 1.4667392719928756`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07852336064612488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.781457828508837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0308456913694903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2481971005017125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[0.07852336064612488, -1.781457828508837], 
            Complex[1.0308456913694903`, -3.2481971005017125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2625644460915877`, 1.0520056679441443`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.8346726399259916`, 0.7486587126323618], 
            Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8790282074982052`, 1.052005667944144}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.976265293515786, 0.7486587126323617], 
            Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.776825798381117, 1.3708125765093016`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.903967825152418, -0.8571372217260815], 
            Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3647668552086762`, 1.3708125765093016`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.762375171562624, -0.8571372217260823], 
            Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7182075504841867`, 1.0707631380474412`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.323104334242323, -1.2994941878134678`], 
            Complex[7.604896783758137, -2.370257325860909]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4233851031056075`, 1.0707631380474407`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.18151168065253, -1.2994941878134685`], 
            Complex[7.604896783758138, -2.370257325860909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.45534241679922, 1.275373920075922}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.167731441406146, 1.2910305277808336`], 
            Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862502367905727`, 1.275373920075922}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.309324094995942, 1.291030527780833], 
            Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1897293250620775`, 1.4668103580225778`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.219836464147169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.78309022476319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0301071390850915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.249900582785768`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[3.219836464147169, -1.78309022476319], 
            Complex[1.0301071390850915`, -3.249900582785768]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9518633285277165, 1.4668103580225778`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07824381055737564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7830902247631892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030107139085092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.249900582785767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[0.07824381055737564, -1.7830902247631892`], 
            Complex[1.030107139085092, -3.249900582785767]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8792530137604433`, 1.050542289257519}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.975950452868279, 0.7539612767642825], 
            Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2623396398293494`, 1.050542289257519}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.8343577992784867`, 0.7539612767642822], 
            Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3654086523433298`, 1.3715227961656589`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.7632867840386814`, -0.8620315102214068], 
            Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7761840012464636`, 1.371522796165659}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.904879437628475, -0.8620315102214064], 
            Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4232898736956134`, 1.0704551071669752`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.181482410380124, -1.3018177742589643`], 
            Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7183027798941808`, 1.0704551071669752`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.32307506396992, -1.3018177742589656`], 
            Complex[7.604772284075739, -2.372272881425941]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862507112115166`, 1.2756474413349752`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.309323640371, 1.2933518168205271`], 
            Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553419423782776`, 1.275647441334975}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.167730986781208, 1.2933518168205271`], 
            Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9514054583979749, 1.4668819571647125`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07796617978662179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7847164644296631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381845965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2515984215943754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[0.07796617978662179, -1.7847164644296631`], 
            Complex[1.0293716381845965`, -3.2515984215943754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1901871951918195`, 1.4668819571647183`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2195588333764196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7847164644296638`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.251598421594382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[3.2195588333764196`, -1.7847164644296638`], 
            Complex[1.0293716381846, -3.251598421594382]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{-1.2621216225930278`, 1.0490873210323426`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.8340549206827474`, 0.7592134262018864], 
            Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8794710309967648`, 1.0490873210323424`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.975647574272541, 0.7592134262018878], 
            Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7755485213908777`, 1.3722267370566548`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.905776705860623, -0.8668782698647188], 
            Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3660441321989154`, 1.3722267370566545`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.764184052270831, -0.8668782698647187], 
            Complex[4.130228184469746, -2.239105006921373]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4231947786298549`, 1.0701478558840807`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.18145333515529, -1.3041300405165688`], 
            Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7183978749599396`, 1.0701478558840807`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.323045988745086, -1.3041300405165683`], 
            Complex[7.604648113785146, -2.374277896400649]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455341411385833, 1.2759201632028616`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.167730480583245, 1.2956617974980968`], 
            Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862512422039606`, 1.2759201632028616`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.309323134173042, 1.2956617974980962`], 
            Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.190643938603453, 1.4669540641097194`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.21928310197127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7863365945159997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625719`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[3.21928310197127, -1.7863365945159997`], 
            Complex[1.0286391633678167`, -3.253290658625719]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9509487149863406, 1.4669540641097205`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0776904483814771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7863365945160001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625721`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[0.0776904483814771, -1.7863365945160001`], 
            Complex[1.0286391633678178`, -3.253290658625721]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2619102321940154`, 1.0476406279996031`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.8337635800647583`, 0.764416170309563], 
            Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8796824213957772`, 1.0476406279996031`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.975356233654551, 0.7644161703095629], 
            Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3666734484957992`, 1.372924524070941}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.765067416031943, -0.8716784802620265], 
            Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7749192050939935`, 1.372924524070941}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.9066600696217355`, -0.8716784802620264], 
            Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4230998169545768`, 1.0698413777236149`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.181424452619743, -1.3064310983584468`], 
            Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7184928366352175`, 1.0698413777236147`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.323017106209543, -1.3064310983584502`], 
            Complex[7.604524269574324, -2.376272476082065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553408244365962`, 1.2761920922417866`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.167729923927075, 1.2979605814829254`], 
            Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862518291531974`, 1.2761920922417873`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.309322577516868, 1.2979605814829327`], 
            Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.191099560607477, 1.4670266736106619`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2190092502600542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7879506614871665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0279096896525775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2549773350978284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[3.2190092502600542`, -1.7879506614871665`], 
            Complex[1.0279096896525775`, -3.2549773350978284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.950493092982317, 1.4670266736106607`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.077416596670261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7879506614871654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.027909689652578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.254977335097826`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[0.077416596670261, -1.7879506614871654`], 
            Complex[1.027909689652578, -3.254977335097826]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.879887341079722, 1.0462020786720443`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.975076026609326, 0.7695704866842142], 
            Complex[4.095188685529604, -0.27663159198783]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.261705312510071, 1.0462020786720443`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.8334833730195332`, 0.769570486684214], 
            Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.367296748998828, 1.3736162783816546`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.7659372952868275`, -0.8764330896595155], 
            Complex[4.133234044285656, -2.25004936804117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7742959045909652`, 1.373616278381655}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.907529948876621, -0.8764330896595154], 
            Complex[4.133234044285656, -2.25004936804117]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4230049877277704`, 1.0695356662994844`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.181395760456799, -1.3087210578909678`], 
            Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7185876658620232`, 1.0695356662994844`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.322988414046595, -1.3087210578909694`], 
            Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862524714535325`, 1.2764632349241656`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.309321971491423, 1.300248278779899], 
            Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455340182136262, 1.2764632349241656`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.167729317901629, 1.3002482787798992`], 
            Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9500385871123614, 1.4670997804823496`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07714460525703772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.789558711273773`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923693993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2566584917561223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[0.07714460525703772, -1.789558711273773], 
            Complex[1.0271831923693993`, -3.2566584917561223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1915540664774276`, 1.467099780482354}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2187372588468346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895587112737734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923694072`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.256658491756127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[3.2187372588468346`, -1.7895587112737734`], 
            Complex[1.0271831923694072`, -3.256658491756127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.880085940417347, 1.0447715452036126`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.974806567246683, 0.7746773225093266], 
            Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2615067131724467`, 1.0447715452036126`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.8332139136568895`, 0.7746773225093263], 
            Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3679141758285684`, 1.3743021175865286`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.7667940913479225`, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7736784777612242`, 1.3743021175865286`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.908386744937716, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4229102900189687`, 1.0692307153129397`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.181367256390402, -1.3110000275879252`], 
            Complex[7.604277546409371, -2.380230742900865]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7186823635708248`, 1.0692307153129395`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.322959909980197, -1.3110000275879254`], 
            Complex[7.604277546409373, -2.380230742900865]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686253168508105, 1.2767335976343384`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.30932131716045, 1.3025249977626072`], 
            Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553394850816883`, 1.2767335976343384`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.167728663570656, 1.3025249977626074`], 
            Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9495851921395899, 1.4671733796004447`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07687445501670612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7911607892803307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.258334168880775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[0.07687445501670612, -1.7911607892803307`], 
            Complex[1.0264596471562961`, -3.258334168880775]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1920074614502045`, 1.4671733796004447`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2184671086065006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.791160789280331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2583341688807756`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[3.2184671086065006`, -1.791160789280331], 
            Complex[1.0264596471562961`, -3.2583341688807756`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8802783643165757`, 1.0433489032547971`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.974547487118723, 0.779737595837812], 
            Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2613142892732176`, 1.0433489032547971`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.83295483352893, 0.7797375958378118], 
            Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7730667878374382`, 1.3749821558421012`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.909230841539049, -0.8858091496519155], 
            Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3685258657523545`, 1.3749821558421014`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.7676381879492564`, -0.8858091496519156], 
            Complex[4.136164053701611, -2.260791305494017]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7187769306807554`, 1.0689265185509056`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.322931591773996, -1.3132681143229277`], 
            Complex[7.604154661093239, -2.382194632873833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4228157229090372`, 1.0689265185509054`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.181338938184205, -1.3132681143229286`], 
            Complex[7.604154661093243, -2.382194632873834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862539197287283`, 1.2770031866702451`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.309320615563188, 1.3047908452057129`], 
            Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553387338610644`, 1.2770031866702451`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.167727961973395, 1.304790845205713], 
            Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1924597507263943`, 1.4672474659005221`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2181987806799732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.79275694039334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025739029953579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[3.2181987806799732`, -1.79275694039334], 
            Complex[1.025739029953579, -3.2600044062938625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9491329028633994, 1.4672474659005226`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07660612709017996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7927569403933397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0257390299535794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[0.07660612709017996, -1.7927569403933397`], 
            Complex[1.0257390299535794`, -3.2600044062938625`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2611279010912857`, 1.0419340318636496`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.8327057806325184`, 0.7847521968079433], 
            Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8804647524985074`, 1.0419340318636496`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.974298434222312, 0.7847521968079424], 
            Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3691319504567037`, 1.3756565039922595`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.768469952245414, -0.8904323517124777], 
            Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.77246070313309, 1.37565650399226}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.910062605835208, -0.8904323517124778], 
            Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7188713680998058`, 1.0686230698843615`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.32290345723042, -1.315525423400987], 
            Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4227212854899887`, 1.0686230698843615`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.18131080364063, -1.3155254234009877`], 
            Complex[7.604032089130619, -2.384148493285349]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553379290540773`, 1.277272008245059}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.167727214125249, 1.307045926316517], 
            Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862547245357153`, 1.2772720082450588`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.309319867715043, 1.3070459263165168`], 
            Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1929109394705977`, 1.4673220343772466`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2179322564695223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794347208989231`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025021316998925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2616692433664776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[3.2179322564695223`, -1.794347208989231], 
            Complex[1.025021316998925, -3.2616692433664776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9486817141192027, 1.4673220343772488`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07633960287973203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7943472089892278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0250213169989348`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2616692433664767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[0.07633960287973203, -1.7943472089892278`], 
            Complex[1.0250213169989348`, -3.2616692433664767`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2609474138356278`, 1.04052681332225}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.832466418480638, 0.7897219887964373], 
            Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8806452397541649`, 1.04052681332225}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.974059072070432, 0.7897219887964377], 
            Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3697325568025043`, 1.376325269691328}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.7692897357415935`, -0.8950134580602265], 
            Complex[4.139022292544098, -2.271338727751554]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.771860096787288, 1.376325269691328}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.910882389331387, -0.8950134580602268], 
            Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7189656767250145`, 1.0683203632667537`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.322875504189794, -1.3177720585893213`], 
            Complex[7.60390982746478, -2.386092421856075]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4226269768647772`, 1.0683203632667535`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.181282850600006, -1.3177720585893227`], 
            Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862555823577243`, 1.2775400684887797`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.309319074608208, 1.3092903447657454`], 
            Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455337071232069, 1.2775400684887797`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.167726421018415, 1.3092903447657456`], 
            Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9482316207780509, 1.467397080083491}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07607486404437007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.024306484822421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[0.07607486404437007, -1.7959316389421525`], 
            Complex[1.024306484822421, -3.2633287190256435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.193361032811742, 1.467397080083491}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2176675176341636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0243064848224217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[3.2176675176341636`, -1.7959316389421525`], 
            Complex[1.0243064848224217`, -3.2633287190256435`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8808199561852765`, 1.0391271330584038`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.973829078826883, 0.7946478095124517], 
            Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2607726974045164`, 1.0391271330584038`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.83223642523709, 0.7946478095124515], 
            Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3703278070642708`, 1.3769885575219303`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.770097875160309, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7712648465255223`, 1.3769885575219305`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.911690528750102, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4225327961471246`, 1.0680183927324483`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.181255076939699, -1.3200081221474058`], 
            Complex[7.603787873086824, -2.388026514879854]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7190598574426674`, 1.068018392732448}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.322847730529492, -1.3200081221474065`], 
            Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455336160958197, 1.2778073734497903`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.167725583622502, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862564926315964`, 1.2778073734497901`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.309318237212295, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1938100358433994`, 1.4674725981295038`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2174045460851777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7975102736315947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2649828717610987`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[3.2174045460851777`, -1.7975102736315947`], 
            Complex[1.0235945102417783`, -3.2649828717610987`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9477826177463945, 1.4674725981295038`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07581189249538411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.797510273631595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.264982871761099`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[0.07581189249538411, -1.797510273631595], 
            Complex[1.0235945102417785`, -3.264982871761099]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2606036261595204`, 1.0377348795223467`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.832015492909507, 0.7995304720360317], 
            Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8809890274302723`, 1.0377348795223467`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.973608146499301, 0.7995304720360318], 
            Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3709178191546298`, 1.3776464691078487`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.770894693249766, -0.9040526005333875], 
            Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7706748344351628`, 1.3776464691078485`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.912487346839559, -0.904052600533387], 
            Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7191539111284704`, 1.0677171523952222`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.322820134163065, -1.322233714856279], 
            Complex[7.603666223034595, -2.389950867251501]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4224387424613232`, 1.0677171523952218`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.181227480573279, -1.32223371485628], 
            Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553351987875864`, 1.278073929096375}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.16772470288514, 1.313747600858923], 
            Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862574548022062`, 1.2780739290963747`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.309317356474933, 1.3137476008589228`], 
            Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1942579536240956`, 1.467548583682077}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.217143323981706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.266631739631969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[3.217143323981706, -1.7990831559498917`], 
            Complex[1.0228853703576102`, -3.266631739631969]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9473346999656987, 1.4675485836820767`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07555067039191275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2666317396319684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[0.07555067039191275, -1.7990831559498914`], 
            Complex[1.0228853703576115`, -3.2666317396319684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8811525748765787`, 1.03634994407825}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.9733959801858845`, 0.8043707658042932], 
            Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2604400787132146`, 1.0363499440782498`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.8318033265960922`, 0.8043707658042935], 
            Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.371502706835134, 1.3782991032220786`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.771680499538499, -0.9085121854432784], 
            Complex[4.143183206373633, -2.286811288665357]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7700899467546587`, 1.3782991032220786`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.913273153128292, -0.9085121854432785], 
            Complex[4.143183206373633, -2.286811288665357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4223448149420628`, 1.0674166364467885`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.181200059449696, -1.32444893604715], 
            Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7192478386477308`, 1.067416636446789}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.32279271303949, -1.32444893604715], 
            Complex[7.603544874391759, -2.391865572493939]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553341852674808`, 1.2783397413182}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.167723779732554, 1.3159606384280345`], 
            Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862584683223119`, 1.2783397413182}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.309316433322348, 1.3159606384280351`], 
            Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9468878624121608, 1.4676250319637316`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07529118013665538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8006503283095583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0221790425488162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.26827536027329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[0.07529118013665538, -1.8006503283095583`], 
            Complex[1.0221790425488162`, -3.26827536027329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1947047911776236`, 1.467625031963735}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2168838337264507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8006503283095574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.022179042548827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.268275360273292`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[3.2168838337264507`, -1.8006503283095574`], 
            Complex[1.022179042548827, -3.268275360273292]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2602819377296066`, 1.0349722209003103`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.8315996437819138`, 0.8091694575484238], 
            Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.881310715860186, 1.0349722209003098`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.973192297371707, 0.8091694575484238], 
            Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3720825799143788`, 1.378946555890304}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.772455591040422, -0.9129327741202401], 
            Complex[4.1445381709548, -2.291879330010544]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7695100736754144`, 1.3789465558903045`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.914048244630215, -0.9129327741202411], 
            Complex[4.1445381709548, -2.291879330010546]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{-1.422251012734255, 1.0671168391553596`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.1811728115525035`, -1.3266538836292885`], 
            Complex[7.603423824286758, -2.393770722784648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7193416408555386`, 1.0671168391553596`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.322765465142302, -1.326653883629291], 
            Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455333120937392, 1.2786048159277632`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.167722815070127, 1.3181634132423612`], 
            Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862595326524015`, 1.2786048159277632`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.309315468659923, 1.3181634132423605`], 
            Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9464421000964433, 1.4677019382519396`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07503340437166661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.802211832650498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681099`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2699137709024373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[0.07503340437166661, -1.802211832650498], 
            Complex[1.0214755044681099`, -3.2699137709024373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1951505534933493`, 1.4677019382519398`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2166260579614594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8022118326504983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.269913770902438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[3.2166260579614594`, -1.8022118326504983`], 
            Complex[1.0214755044681103`, -3.269913770902438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2601290897363817`, 1.033601606873233}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.8314041736809603`, 0.8139272921843714], 
            Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8814635638534112`, 1.0336016068732332`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.972996827270754, 0.8139272921843711], 
            Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3726575444343296`, 1.3795889204899812`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.773220252914124, -0.9173150854995425], 
            Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7689351091554633`, 1.379588920489981}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.914812906503919, -0.9173150854995431], 
            Complex[4.145877797348456, -2.296904005989524]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4221573349928556`, 1.0668177548642397`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.181145734899095, -1.3288486541172821`], 
            Complex[7.603303069891951, -2.395666408981522]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7194353185969362`, 1.0668177548642392`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.322738388488887, -1.3288486541172835`], 
            Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553320063292323`, 1.2788691586618044`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.167721809782957, 1.3203560217257764`], 
            Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.686260647260562, 1.2788691586618048`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.30931446337276, 1.3203560217257788`], 
            Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1955952455265115`, 1.4677792978783022`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2163699795640026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.020774734037491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2715470083253844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[3.2163699795640026`, -1.8037677104470822`], 
            Complex[1.020774734037491, -3.2715470083253844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9459974080632856, 1.4677792978782953`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0747773259742065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0207747340374922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2715470083253804`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[0.0747773259742065, -1.8037677104470848`], 
            Complex[1.0207747340374922`, -3.2715470083253804`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8816112286416746`, 1.0322380014969061`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.972809310210266, 0.8186449936599097], 
            Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2599814249481192`, 1.0322380014969068`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.8312166566204735`, 0.8186449936599106], 
            Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7683649507440933`, 1.3802262878452334`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.9155674126696605`, -0.9216598178919517], 
            Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3732277028457007`, 1.3802262878452325`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.7739747590798687`, -0.9216598178919512], 
            Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4220637808827068`, 1.0665193779904552`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.181118827539914, -1.3310333426575782`], 
            Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7195288727070868`, 1.0665193779904545`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.322711481129714, -1.331033342657582], 
            Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455330841967467, 1.2791327751826869`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.167720764736373, 1.322538558935139], 
            Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862618116223256`, 1.2791327751826869`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.30931341832617, 1.3225385589351384`], 
            Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1960388721985193`, 1.4678571062278147`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.216115581642531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.27317510894289`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[3.216115581642531, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.27317510894289]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9455537813912737, 1.4678571062278156`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0745229280527381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.273175108942891`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[0.0745229280527381, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.273175108942891]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2598388370997253`, 1.0308813067950824`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.8310368434643864`, 0.8233232657606014], 
            Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8817538164900676`, 1.0308813067950824`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.9726294970541804`, 0.8233232657606012], 
            Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7677994994166613`, 1.3808587463177342`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.916312026387238, -0.925967649783973], 
            Complex[4.148512526970577, -2.306826396101707]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.373793154173132, 1.3808587463177338`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.774719372797445, -0.9259676497839711], 
            Complex[4.148512526970578, -2.306826396101705]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4219703495783593`, 1.0662217030234131`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.1810920875578015`, -1.3332080430544786`], 
            Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7196223040114333`, 1.0662217030234131`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.322684741147594, -1.3332080430544797`], 
            Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862630252205475`, 1.2793956710797434`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.309312334366247, 1.3247111185862175`], 
            Complex[7.6230493091457, 0.04531544750647416]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.455329628369246, 1.2793956710797434`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.167719680776454, 1.3247111185862182`], 
            Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{2.1964814383972593`, 1.4679353587380946`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2158628475327276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8068627500184498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[3.2158628475327276`, -1.8068627500184498`], 
            Complex[1.0193814091354683`, -3.2747981087565443`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-0.9451112151925454, 1.467935358738085}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07427019394292937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8068627500184438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565288`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[0.07427019394292937, -1.8068627500184438`], 
            Complex[1.0193814091354747`, -3.2747981087565288`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8818914303004093`, 1.029531427227883}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.972457148662774, 0.8279627928769886], 
            Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2597012232893843`, 1.0295314272278833`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.8308644950729818`, 0.8279627928769887], 
            Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7672386594189013`, 1.381486381893781}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.917047000797618, -0.9302392405994727], 
            Complex[4.149808341378717, -2.311725622493254]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3743539941708922`, 1.3814863818937806`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.775454347207829, -0.9302392405994732], 
            Complex[4.149808341378721, -2.311725622493254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.421877040263923, 1.0659247245235945`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.181065513067208, -1.3353728477954119`], 
            Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7197156133258704`, 1.0659247245235945`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.322658166657003, -1.3353728477954119`], 
            Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862642875452605`, 1.2796578518705939`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.309311212320324, 1.3268737930790047`], 
            Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553283660445337`, 1.2796578518705939`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.167718558730529, 1.326873793079005], 
            Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{-0.9446697046124136, 1.468014050898636}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0740191072038374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2764160433747036`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[0.0740191072038374, -1.8084019924760677`], 
            Complex[1.0186888118162511`, -3.2764160433747036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1969229489773796`, 1.4680140508986363`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2156117607936308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.276416043374702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[3.2156117607936308`, -1.8084019924760657`], 
            Complex[1.0186888118162514`, -3.276416043374702]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8820241697594327`, 1.0281882696079647`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.97229203538588, 0.8325642407352367], 
            Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.2595684838303614`, 1.028188269607965}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.8306993817960873`, 0.8325642407352367], 
            Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7666823381200647`, 1.382109278267698}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.9177725794310545`, -0.9344752314248252], 
            Complex[4.15109024131099, -2.316584509692523]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.3749103154697293`, 1.3821092782676978`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.776179925841262, -0.9344752314248258], 
            Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7198088014568969`, 1.0656284371212772`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.322631755803343, -1.3375278480756927`], 
            Complex[7.602822954346447, -2.40315628519697]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4217838521328958`, 1.0656284371212759`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1810391022135605`, -1.337527848075709], 
            Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{-1.4553270554962447`, 1.2799193230024304`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1677173994076595`, 1.3290266735224265`], 
            Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6862655980935486`, 1.2799193230024302`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.309310052997454, 1.3290266735224268`], 
            Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
          "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]tt)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]tt)\"", TraditionalForm]},
      ImageSize->800,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{
        TagBox[
         TooltipBox[PointBox[{0.4905971192945886, -0.8383554163654704}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4905971192945886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8383554163654704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210240003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.4905971192945886, -0.8383554163654704], 
            Complex[1.5874585404782842`, -2.3355245210240003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.632189772884385, -0.8383554163654666}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.632189772884385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8383554163654666`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210239963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.632189772884385, -0.8383554163654666], 
            Complex[1.5874585404782884`, -2.3355245210239963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.6980000948375882, -0.6433017314670934}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.6980000948375882, -0.6433017314670934], 
            Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8395927484273833`, -0.6433017314670934}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.8395927484273833`, -0.6433017314670934], 
            Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.6944263543752545`, 0.006645071137818129}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.6944263543752545`, 0.006645071137818129], 
            Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.8360190079650485`, 0.006645071137818026}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.8360190079650485`, 0.006645071137818026], 
            Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.976967927486167, 0.006887727487396918}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.976967927486167, 0.006887727487396918], 
            Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.118560581075961, 0.0068877274873969585`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[8.118560581075961, 0.0068877274873969585`], 
            Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.398301539299036, -0.01324317030169907}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.398301539299036, -0.01324317030169907], 
            Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.53989419288883, -0.01324317030169899}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.53989419288883, -0.01324317030169899], 
            Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.834135988275976`, -0.01205573978218699}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.834135988275976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01205573978218699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.094218012734007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.834135988275976`, -0.01205573978218699], 
            Complex[9.094218012734007, -1.1949707911251923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.692543334686185, -0.012055739782186827`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.692543334686185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.012055739782186827`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.09421801273401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.692543334686185, -0.012055739782186827`], 
            Complex[9.09421801273401, -1.1949707911251923`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.46502963264100744`, -0.868215310870579}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.46502963264100744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.868215310870579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291823`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.46502963264100744`, -0.868215310870579], 
            Complex[1.5611274843968284`, -2.3644087056291823`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6066222862308037`, -0.8682153108705755}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6066222862308037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8682153108705755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291787`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.6066222862308037`, -0.8682153108705755], 
            Complex[1.5611274843968312`, -2.3644087056291787`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.7333882582665036, -0.6165221792948049}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.7333882582665036, -0.6165221792948049], 
            Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8749809118562997`, -0.6165221792948034}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.8749809118562997`, -0.6165221792948034], 
            Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.654309125631486, 0.006712510785854934}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[4.654309125631486, 0.006712510785854934], 
            Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.795901779221279, 0.006712510785854963}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.795901779221279, 0.006712510785854963], 
            Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.162580737731858, 0.007042959985370651}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[8.162580737731858, 0.007042959985370651], 
            Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.020988084142068, 0.007042959985368871}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[5.020988084142068, 0.007042959985368871], 
            Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.352914113679207, -0.013509876715323901`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.352914113679207, -0.013509876715323901`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.494506767269, -0.013509876715323853`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.494506767269, -0.013509876715323853`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.876435471981889`, -0.011949285676122938`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.876435471981889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011949285676122938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.136933552574833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.876435471981889`, -0.011949285676122938`], 
            Complex[9.136933552574833, -1.1947860159220576`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.734842818392103, -0.01194928567613202}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.734842818392103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01194928567613202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.13693355257484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.734842818392103, -0.01194928567613202], 
            Complex[9.13693355257484, -1.1947860159220667`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.4451990626513003, -0.8925142454403411}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4451990626513003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.540510310333603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3877804035408325`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.4451990626513003, -0.8925142454403411], 
            Complex[1.540510310333603, -2.3877804035408325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5867917162410965`, -0.8925142454403441}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5867917162410965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5405103103336057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.387780403540836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.5867917162410965`, -0.8925142454403441], 
            Complex[1.5405103103336057`, -2.387780403540836]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9045700992025902`, -0.5952855745698094}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.9045700992025902`, -0.5952855745698094], 
            Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.7629774456127986, -0.5952855745698065}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.7629774456127986, -0.5952855745698065], 
            Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.621891868208896, 0.006786025025047798}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[4.621891868208896, 0.006786025025047798], 
            Complex[6.122517060306257, -1.163371113059422]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.763484521798694, 0.006786025025048383}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.763484521798694, 0.006786025025048383], 
            Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.05739532427709, 0.007197843246654808}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[5.05739532427709, 0.007197843246654808], 
            Complex[6.557943371421671, -1.162972548762566]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.198987977866883, 0.007197843246654797}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[8.198987977866883, 0.007197843246654797], 
            Complex[6.557943371421671, -1.162972548762566]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.315449803449272, -0.01375104485251276}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.315449803449272, -0.01375104485251276], 
            Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.457042457039066`, -0.013751044852512806`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.457042457039066`, -0.013751044852512806`], 
            Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.769143367766525, -0.011873440576434954`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.769143367766525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011873440576434954`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.17164822418722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.19463258419245`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.769143367766525, -0.011873440576434954`], 
            Complex[9.17164822418722, -1.19463258419245]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.910736021356321`, -0.011873440576436094`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.910736021356321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011873440576436094`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.171648224187221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1946325841924512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.910736021356321`, -0.011873440576436094`], 
            Complex[9.171648224187221, -1.1946325841924512`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.4287165628002437, -0.9135287061735121}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4287165628002437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.523224587548502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4079083765075175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.4287165628002437, -0.9135287061735121], 
            Complex[1.523224587548502, -2.4079083765075175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5703092163900387`, -0.9135287061735095}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5703092163900387`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735095`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5232245875485029`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.407908376507515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.5703092163900387`, -0.9135287061735095], 
            Complex[1.5232245875485029`, -2.407908376507515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.93075079131323, -0.5773156862277917}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.93075079131323, -0.5773156862277917], 
            Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.7891581377234371, -0.5773156862277916}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.7891581377234371, -0.5773156862277916], 
            Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.735547972440535, 0.006863336573144897}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.735547972440535, 0.006863336573144897], 
            Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.593955318850742, 0.0068633365731448895`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[4.593955318850742, 0.0068633365731448895`], 
            Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.231005147885755, 0.0073549519610065905`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[8.231005147885755, 0.0073549519610065905`], 
            Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.089412494295966, 0.007354951961001998}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[5.089412494295966, 0.007354951961001998], 
            Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.282554763488937, -0.01397986959845826}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.282554763488937, -0.01397986959845826], 
            Complex[8.685690080337723, -1.196609721074035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.42414741707873, -0.0139798695984579}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.42414741707873, -0.0139798695984579], 
            Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.798795489744536, -0.01181529831920876}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.798795489744536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01181529831920876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.798795489744536, -0.01181529831920876], 
            Complex[9.20171331881034, -1.194497402564137]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.94038814333433, -0.011815298319208752`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.94038814333433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011815298319208752`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.94038814333433, -0.011815298319208752`], 
            Complex[9.20171331881034, -1.194497402564137]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.4144938153406103, -0.9322995873452282}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4144938153406103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.508185994680368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4258284901011864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.4144938153406103, -0.9322995873452282], 
            Complex[1.508185994680368, -2.4258284901011864`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5560864689304044`, -0.9322995873452297}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5560864689304044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452297`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5081859946803688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4258284901011873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.5560864689304044`, -0.9322995873452297], 
            Complex[1.5081859946803688`, -2.4258284901011873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.813020240902394, -0.5615718710865851}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.813020240902394, -0.5615718710865851], 
            Complex[1.908828689419144, -2.052868131119601]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9546128944921874`, -0.5615718710865847}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.9546128944921874`, -0.5615718710865847], 
            Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.569036631840206, 0.006943461497604872}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[4.569036631840206, 0.006943461497604872], 
            Complex[6.068475300453683, -1.163347697400969]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.710629285429999, 0.00694346149760476}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.710629285429999, 0.00694346149760476], 
            Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.118506250669166, 0.007515591774090762}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[5.118506250669166, 0.007515591774090762], 
            Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.260098904258959, 0.007515591774090756}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[8.260098904258959, 0.007515591774090756], 
            Complex[6.61778553109412, -1.162803172863648]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.252703058118813, -0.014202465960727835`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.252703058118813, -0.014202465960727835`], 
            Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.39429571170861, -0.014202465960725278`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.39429571170861, -0.014202465960725278`], 
            Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.966914215304485`, -0.011769056829642613`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.966914215304485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011769056829642613`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.966914215304485`, -0.011769056829642613`], 
            Complex[9.228651705652085, -1.1943745527422884`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.8253215617147, -0.011769056829649287`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8253215617147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011769056829649287`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.8253215617147, -0.011769056829649287`], 
            Complex[9.228651705652094, -1.1943745527422953`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.543518627975134, -0.9494075862605201}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.543518627975134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4947924622029343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.543518627975134, -0.9494075862605201], 
            Complex[1.4947924622029343`, -2.4421177901257014`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.40192597438534255`, -0.9494075862605198}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.40192597438534255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.494792462202936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.40192597438534255`, -0.9494075862605198], 
            Complex[1.494792462202936, -2.4421177901257014`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.976762799482182, -0.5474736791133854}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.976762799482182, -0.5474736791133854], 
            Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.835170145892391, -0.5474736791133877}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.835170145892391, -0.5474736791133877], 
            Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.5463246331431195`, 0.007025882918871681}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[4.5463246331431195`, 0.007025882918871681], 
            Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.687917286732913, 0.007025882918871702}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.687917286732913, 0.007025882918871702], 
            Complex[6.045167287063117, -1.163332885610651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.287084479515974, 0.007680628289981289}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[8.287084479515974, 0.007680628289981289], 
            Complex[6.644124842294815, -1.162714599075609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.145491825926181, 0.007680628289980853}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[5.145491825926181, 0.007680628289980853], 
            Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.366639367283945`, -0.014422357660350082`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.366639367283945`, -0.014422357660350082`], 
            Complex[8.629176867782464, -1.196858523000041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.225046713694154, -0.01442235766034999}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.225046713694154, -0.01442235766034999], 
            Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.849565759088899, -0.011731532239340082`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.849565759088899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011731532239340082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.25330790754526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912124`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.849565759088899, -0.011731532239340082`], 
            Complex[9.25330790754526, -1.1942607697912124`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.991158412678699`, -0.011731532239331113`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.991158412678699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011731532239331113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.253307907545267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.991158412678699`, -0.011731532239331113`], 
            Complex[9.253307907545267, -1.1942607697912035`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.39063568307703384`, -0.9652164447599751}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.39063568307703384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.457137190679493`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.39063568307703384`, -0.9652164447599751], 
            Complex[1.4826686902970199`, -2.457137190679493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.532228336666828, -0.9652164447599713}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.532228336666828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.45713719067949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.532228336666828, -0.9652164447599713], 
            Complex[1.4826686902970212`, -2.45713719067949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.8559867126628703, -0.5346576120369388}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.8559867126628703, -0.5346576120369388], 
            Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.997579366252664, -0.5346576120369394}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.997579366252664, -0.5346576120369394], 
            Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.5253142371097725`, 0.007110298008162873}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[4.5253142371097725`, 0.007110298008162873], 
            Complex[6.023558855884933, -1.163316510563181]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.666906890699567, 0.007110298008162871}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.666906890699567, 0.007110298008162871], 
            Complex[6.023558855884935, -1.163316510563181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.170878634413056, 0.007850743160533592}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[5.170878634413056, 0.007850743160533592], 
            Complex[6.668857252414806, -1.162622520798364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.312471288002852, 0.00785074316053409}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[8.312471288002852, 0.00785074316053409], 
            Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.199056007873823, -0.014641876121436175`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.199056007873823, -0.014641876121436175`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.340648661463618`, -0.014641876121436062`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[10.340648661463618`, -0.014641876121436062`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.5219614272863144`, -0.9799721862678735}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5219614272863144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9799721862678735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.471130430093209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[3.5219614272863144`, -0.9799721862678735], 
            Complex[1.4715621017597873`, -2.471130430093209]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.38036877369652167`, -0.9799721862678751}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.38036877369652167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9799721862678751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4711304300932104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.38036877369652167`, -0.9799721862678751], 
            Complex[1.4715621017597882`, -2.4711304300932104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.017318225749185, -0.5228778864146391}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.017318225749185, -0.5228778864146391], 
            Complex[1.970954950697273, -2.009827028796297]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.8757255721593927, -0.52287788641464}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.8757255721593927, -0.52287788641464], 
            Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.5056658326490995`, 0.007196517077880139}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.5056658326490995`, 0.007196517077880139], 
            Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6472584862388935`, 0.007196517077880152}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.6472584862388935`, 0.007196517077880152], 
            Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.19501091123548, 0.00802653852897203}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[5.19501091123548, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.336603564825275, 0.00802653852897203}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[8.336603564825275, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.174373102447971, -0.014862729232274653`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.174373102447971, -0.014862729232274653`], 
            Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.315965756037766`, -0.014862729232274637`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[10.315965756037766`, -0.014862729232274637`], 
            Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.5125370745305697`, -0.9938506052393002}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5125370745305697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9938506052393002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.484271399542434`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[3.5125370745305697`, -0.9938506052393002], 
            Complex[1.4612931389803365`, -2.484271399542434]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.37094442094077773`, -0.9938506052392997}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.37094442094077773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9938506052392997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803379`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4842713995424335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.37094442094077773`, -0.9938506052392997], 
            Complex[1.4612931389803379`, -2.4842713995424335`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.036161628380458, -0.5119589442981466}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.036161628380458, -0.5119589442981466], 
            Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.8945689747906652, -0.5119589442981493}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.8945689747906652, -0.5119589442981493], 
            Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628730822140306, 0.0072844163322486775`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.628730822140306, 0.0072844163322486775`], 
            Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.487138168550514, 0.007284416332243672}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.487138168550514, 0.007284416332243672], 
            Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.2181348551047995`, 0.008208588338762854}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[5.2181348551047995`, 0.008208588338762854], 
            Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.359727508694593, 0.008208588338762687}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[8.359727508694593, 0.008208588338762687], 
            Complex[6.714779367617378, -1.162425692393188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.1507421714555965`, -0.015086273942248003`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.1507421714555965`, -0.015086273942248003`], 
            Complex[8.556435217312076, -1.197217311276035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.29233482504539, -0.015086273942248}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[10.29233482504539, -0.015086273942248], 
            Complex[8.556435217312078, -1.197217311276035]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.3622285720771921, -1.0069826142874234`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3622285720771921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0069826142874234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.3622285720771921, -1.0069826142874234`], 
            Complex[1.4517287827631644`, -2.4966893902296494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.503821225666987, -1.006982614287426}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.503821225666987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.006982614287426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296525`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[3.503821225666987, -1.006982614287426], 
            Complex[1.4517287827631657`, -2.4966893902296525`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9126523619522108, -0.5017701062164057}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.9126523619522108, -0.5017701062164057], 
            Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.054245015542006, -0.5017701062164085}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.054245015542006, -0.5017701062164085], 
            Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.469552623884141, 0.007373913179256361}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.469552623884141, 0.007373913179256361], 
            Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611145277473936, 0.007373913179256576}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.611145277473936, 0.007373913179256576], 
            Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.382027043209192, 0.008397467701836855}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[8.382027043209192, 0.008397467701836855], 
            Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.240434389619399, 0.00839746770183686}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[5.240434389619399, 0.00839746770183686], 
            Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.269564843263957`, -0.01531366326459591}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[10.269564843263957`, -0.01531366326459591], 
            Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.127972189674163, -0.015313663264596189`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.127972189674163, -0.015313663264596189`], 
            Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.3541186043574641, -1.0194689005855264`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3541186043574641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.44276726787218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.508483683764771`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.3541186043574641, -1.0194689005855264`], 
            Complex[1.44276726787218, -2.508483683764771]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4957112579472582`, -1.0194689005855273`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4957112579472582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4427672678721806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5084836837647715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[3.4957112579472582`, -1.0194689005855273`], 
            Complex[1.4427672678721806`, -2.5084836837647715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9300797102089358, -0.4922109148816913}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.9300797102089358, -0.4922109148816913], 
            Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.071672363798729, -0.49221091488169333`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[4.071672363798729, -0.49221091488169333`], 
            Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5943652547457265`, 0.0074649522520338}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[7.5943652547457265`, 0.0074649522520338], 
            Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.452772601155936, 0.007464952252033912}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[4.452772601155936, 0.007464952252033912], 
            Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.40364445944282, 0.008593772293729832}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[8.40364445944282, 0.008593772293729832], 
            Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.262051805853028, 0.008593772293729816}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[5.262051805853028, 0.008593772293729816], 
            Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.1059154551031405`, -0.015545933419028879`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[7.1059154551031405`, -0.015545933419028879`], 
            Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.247508108692935`, -0.01554593341902805}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[10.247508108692935`, -0.01554593341902805], 
            Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.3465339039238557, -1.031388938053689}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3465339039238557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.031388938053689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631919`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.3465339039238557, -1.031388938053689], 
            Complex[1.4343287018663795`, -2.519732518631919]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4881265575136493`, -1.0313889380536854`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4881265575136493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0313889380536854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631915`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[3.4881265575136493`, -1.0313889380536854`], 
            Complex[1.4343287018663806`, -2.519732518631915]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9469329539089921, -0.48320212310888055`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.9469329539089921, -0.48320212310888055`], 
            Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.088525607498785, -0.4832021231088809}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.088525607498785, -0.4832021231088809], 
            Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5782835412454626`, 0.0075574969911607935`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.5782835412454626`, 0.0075574969911607935`], 
            Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.436690887655669, 0.007557496991163237}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.436690887655669, 0.007557496991163237], 
            Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.283100441464033, 0.008798133065178963}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[5.283100441464033, 0.008798133065178963], 
            Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.424693095053826, 0.00879813306517896}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[8.424693095053826, 0.00879813306517896], 
            Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.084454398670628, -0.015784060035230123`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.084454398670628, -0.015784060035230123`], 
            Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.226047052260421`, -0.01578406003523005}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[10.226047052260421`, -0.01578406003523005], 
            Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.33940979143382616`, -1.0428068062799807`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33940979143382616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0428068062799807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.530498876235687`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.33940979143382616`, -1.0428068062799807`], 
            Complex[1.4263490191882378`, -2.530498876235687]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4810024450236203`, -1.0428068062799816`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4810024450236203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0428068062799816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5304988762356877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[3.4810024450236203`, -1.0428068062799816`], 
            Complex[1.4263490191882389`, -2.5304988762356877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.104870714597597, -0.4746798749981737}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.104870714597597, -0.4746798749981737], 
            Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9632780610078037, -0.47467987499817715`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.9632780610078037, -0.47467987499817715`], 
            Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.421221515937318, 0.0076515243225991425`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.421221515937318, 0.0076515243225991425`], 
            Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5628141695271145`, 0.007651524322598731}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.5628141695271145`, 0.007651524322598731], 
            Complex[5.915830554816423, -1.163193392670451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.303672866164795, 0.009011228909084937}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[5.303672866164795, 0.009011228909084937], 
            Complex[6.797539667322055, -1.161966845801127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.445265519754589, 0.009011228909084963}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[8.445265519754589, 0.009011228909084963], 
            Complex[6.797539667322055, -1.161966845801127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.063493070122277, -0.01602899750358731}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.063493070122277, -0.01602899750358731], 
            Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.20508572371207, -0.016028997503587203`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[10.20508572371207, -0.016028997503587203`], 
            Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.33269344666361156`, -1.0537751001493318`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33269344666361156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.418775926679894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5408343661536397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.33269344666361156`, -1.0537751001493318`], 
            Complex[1.418775926679894, -2.5408343661536397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.474286100253405, -1.0537751001493318`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.474286100253405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4187759266798956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5408343661536392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[3.474286100253405, -1.0537751001493318`], 
            Complex[1.4187759266798956`, -2.5408343661536392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9791691098460469, -0.46659179640833603`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.9791691098460469, -0.46659179640833603`], 
            Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.12076176343584, -0.46659179640833626`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.12076176343584, -0.46659179640833626`], 
            Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.406294309063904, 0.007747021157202576}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.406294309063904, 0.007747021157202576], 
            Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.547886962653699, 0.00774702115719995}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.547886962653699, 0.00774702115719995], 
            Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.323846388854408, 0.00923379877093513}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[5.323846388854408, 0.00923379877093513], 
            Complex[6.816993839756789, -1.161835265847092]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.465439042444201, 0.009233798770935121}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[8.465439042444201, 0.009233798770935121], 
            Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.042951411025012, -0.016281708942805718`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.042951411025012, -0.016281708942805718`], 
            Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.184544064614805`, -0.016281708942805753`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[10.184544064614805`, -0.016281708942805753`], 
            Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4679337359736433`, -1.06433764500318}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4679337359736433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.06433764500318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[3.4679337359736433`, -1.06433764500318], 
            Complex[1.4115660932135865`, -2.5507819227528166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.32634108238384935`, -1.0643376450031767`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32634108238384935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0643376450031767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.32634108238384935`, -1.0643376450031767`], 
            Complex[1.4115660932135874`, -2.5507819227528135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.13624377018248, -0.4588942798973108}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.13624377018248, -0.4588942798973108], 
            Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.9946511165926878, -0.45889427989730874`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.9946511165926878, -0.45889427989730874`], 
            Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.391851102143664, 0.007843982012263403}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.391851102143664, 0.007843982012263403], 
            Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.533443755733459, 0.007843982012263152}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.533443755733459, 0.007843982012263152], 
            Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.485279549606197, 0.009466654168547486}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[8.485279549606197, 0.009466654168547486], 
            Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.343686896016404, 0.009466654168547547}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[5.343686896016404, 0.009466654168547547], 
            Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.022761264330782, -0.01654319107188898}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.022761264330782, -0.01654319107188898], 
            Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.164353917920575`, -0.016543191071888914`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[10.164353917920575`, -0.016543191071888914`], 
            Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.32031592905730694`, -1.0745314357254354`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32031592905730694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4046831465120544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5603777298614023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[0.32031592905730694`, -1.0745314357254354`], 
            Complex[1.4046831465120544`, -2.5603777298614023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4619085826471014`, -1.0745314357254354`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4619085826471014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.404683146512056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.560377729861402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[3.4619085826471014`, -1.0745314357254354`], 
            Complex[1.404683146512056, -2.560377729861402]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.151354705396683, -0.4515505457349306}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.151354705396683, -0.4515505457349306], 
            Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.009762051806893, -0.45155054573492875`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[1.009762051806893, -0.45155054573492875`], 
            Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.377843050837108, 0.007942407351021055}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.377843050837108, 0.007942407351021055], 
            Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5194357044269005`, 0.007942407351021058}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.5194357044269005`, 0.007942407351021058], 
            Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.363251612071681, 0.009710692858210855}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[5.363251612071681, 0.009710692858210855], 
            Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.504844265661474, 0.009710692858210806}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[8.504844265661474, 0.009710692858210806], 
            Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.002863505905769, -0.016814496662831985`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.002863505905769, -0.016814496662831985`], 
            Complex[8.412563676597296, -1.198158678433355]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.144456159495563`, -0.016814496662831836`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[10.144456159495563`, -0.016814496662831836`], 
            Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4561794165348236`, -1.0843880551501943`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4561794165348236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501943`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.398096210752566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5696526277620455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[3.4561794165348236`, -1.0843880551501943`], 
            Complex[1.398096210752566, -2.5696526277620455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.3145867629450303, -1.0843880551501937`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3145867629450303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3980962107525663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.569652627762044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[0.3145867629450303, -1.0843880551501937`], 
            Complex[1.3980962107525663`, -2.569652627762044]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.024534313536096, -0.4445292235923795}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[1.024534313536096, -0.4445292235923795], 
            Complex[2.119679474265541, -1.918057531021162]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.166126967125889, -0.44452922359237873`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.166126967125889, -0.44452922359237873`], 
            Complex[2.119679474265542, -1.918057531021161]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.3642286676832285`, 0.00804230239670521}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.3642286676832285`, 0.00804230239670521], 
            Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5058213212730225`, 0.008042302396705316}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[7.5058213212730225`, 0.008042302396705316], 
            Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.52418379610039, 0.00996691431009624}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[8.52418379610039, 0.00996691431009624], 
            Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.382591142510598, 0.009966914310096187}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[5.382591142510598, 0.009966914310096187], 
            Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.983205922649462, -0.017096756417673678`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[6.983205922649462, -0.017096756417673678`], 
            Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.124798576239256`, -0.017096756417673668`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[10.124798576239256`, -0.017096756417673668`], 
            Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.30912680858594205`, -1.0939347333651805`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30912680858594205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939347333651805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[0.30912680858594205`, -1.0939347333651805`], 
            Complex[1.3917788166049048`, -2.5786331633102035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4507194621757376`, -1.0939347333651823`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4507194621757376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939347333651823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[3.4507194621757376`, -1.0939347333651823`], 
            Complex[1.3917788166049063`, -2.5786331633102058`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.180588479578346, -0.43780329333443724`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.180588479578346, -0.43780329333443724`], 
            Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0389958259885552`, -0.43780329333443724`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[1.0389958259885552`, -0.43780329333443724`], 
            Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.350972359395372, 0.008143676269233574}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.350972359395372, 0.008143676269233574], 
            Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.492565012985164, 0.008143676269233487}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[7.492565012985164, 0.008143676269233487], 
            Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.401751028707841, 0.010236437677199473`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[5.401751028707841, 0.010236437677199473`], 
            Complex[6.891907468896068, -1.161220171125207]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.543343682297635, 0.01023643767719948}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[8.543343682297635, 0.01023643767719948], 
            Complex[6.891907468896068, -1.161220171125207]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.105334252708913`, -0.017391201699304026`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[10.105334252708913`, -0.017391201699304026`], 
            Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.963741599119119, -0.017391201699304113`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[6.963741599119119, -0.017391201699304113`], 
            Complex[8.374692817528384, -1.198488112788141]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.30391290545435, -1.1031951533323334`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30391290545435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1031951533323334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.385708073986173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[0.30391290545435, -1.1031951533323334`], 
            Complex[1.385708073986173, -2.587342388059074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4455055590441432`, -1.1031951533323339`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4455055590441432`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1031951533323339`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3857080739861731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[3.4455055590441432`, -1.1031951533323339`], 
            Complex[1.3857080739861731`, -2.587342388059074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.194763527568909, -0.43134927949335283`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.194763527568909, -0.43134927949335283`], 
            Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0531708739791161`, -0.43134927949335167`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[1.0531708739791161`, -0.43134927949335167`], 
            Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.479635970943437, 0.008246541346654087}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[7.479635970943437, 0.008246541346654087], 
            Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.338043317353644, 0.008246541346654037}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.338043317353644, 0.008246541346654037], 
            Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.4207729647332625`, 0.010520523036427932`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[5.4207729647332625`, 0.010520523036427932`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.562365618323055, 0.010520523036427927`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[8.562365618323055, 0.010520523036427927`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.944427656372562, -0.01769918937958054}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[6.944427656372562, -0.01769918937958054], 
            Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.086020309962356`, -0.017699189379580486`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[10.086020309962356`, -0.017699189379580486`], 
            Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.440517518589483, -1.1121900734843542`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.440517518589483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[3.440517518589483, -1.1121900734843542`], 
            Complex[1.3798640340783366`, -2.5958004746630317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.29892486499969306`, -1.1121900734843577`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.29892486499969306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843577`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[0.29892486499969306`, -1.1121900734843577`], 
            Complex[1.3798640340783381`, -2.5958004746630365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0670807469468007`, -0.42514662876555165`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[1.0670807469468007`, -0.42514662876555165`], 
            Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.208673400536594, -0.42514662876555215`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.208673400536594, -0.42514662876555215`], 
            Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.4670073159977095`, 0.008350912786614366}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[7.4670073159977095`, 0.008350912786614366], 
            Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.325414662407916, 0.008350912786611275}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.325414662407916, 0.008350912786611275], 
            Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.439695778207934, 0.010820596844492497`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[5.439695778207934, 0.010820596844492497`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.581288431797727, 0.010820596844492403`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[8.581288431797727, 0.010820596844492403`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.06681689057666, -0.018022230071644385`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[10.06681689057666, -0.018022230071644385`], 
            Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.925224236986869, -0.01802223007164421}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[6.925224236986869, -0.01802223007164421], 
            Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4357376210557065`, -1.120937815790952}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4357376210557065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.120937815790952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6040251997705024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[3.4357376210557065`, -1.120937815790952], 
            Complex[1.3742291902547281`, -2.6040251997705024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2941449674659141, -1.1209378157909546`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2941449674659141`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1209378157909546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.604025199770505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[0.2941449674659141, -1.1209378157909546`], 
            Complex[1.3742291902547281`, -2.604025199770505]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.222336896739361, -0.41917722203755803`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.222336896739361, -0.41917722203755803`], 
            Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0807442431495686`, -0.4191772220375579}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[1.0807442431495686`, -0.4191772220375579], 
            Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.3130627762344576`, 0.00845680816400054}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.3130627762344576`, 0.00845680816400054], 
            Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.454655429824251, 0.008456808164000526}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[7.454655429824251, 0.008456808164000526], 
            Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.600148900521386, 0.011138282794836918`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[8.600148900521386, 0.011138282794836918`], 
            Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.458556246931596, 0.011138282794836883`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[5.458556246931596, 0.011138282794836883`], 
            Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.906093661793765, -0.01836202115462416}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[6.906093661793765, -0.01836202115462416], 
            Complex[8.319026572634915, -1.199065136952576]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.047686315383556`, -0.018362021154624195`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[10.047686315383556`, -0.018362021154624195`], 
            Complex[8.319026572634915, -1.199065136952576]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.2895575630554191, -1.1294546532828313`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2895575630554191`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1294546532828313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.612032327183787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[0.2895575630554191, -1.1294546532828313`], 
            Complex[1.3687880826648193`, -2.612032327183787]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4311502166452144`, -1.129454653282832}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4311502166452144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.129454653282832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6120323271837886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[3.4311502166452144`, -1.129454653282832], 
            Complex[1.3687880826648213`, -2.6120323271837886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0941780694739518`, -0.41342498695323976`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[1.0941780694739518`, -0.41342498695323976`], 
            Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.2357707230637445`, -0.41342498695324215`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.2357707230637445`, -0.41342498695324215`], 
            Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.300966771833883, 0.008564247194411541}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.300966771833883, 0.008564247194411541], 
            Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.442559425423676, 0.008564247194411552}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[7.442559425423676, 0.008564247194411552], 
            Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.47738980371477, 0.011475439606775242`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[5.47738980371477, 0.011475439606775242`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.618982457304563, 0.011475439606775252`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[8.618982457304563, 0.011475439606775252`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.886999703988066, -0.01872048627707082}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[6.886999703988066, -0.01872048627707082], 
            Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.02859235757786, -0.018720486277070698`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[10.02859235757786, -0.018720486277070698`], 
            Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.426741405743924, -1.1377551213057147`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.426741405743924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377551213057147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327329`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[3.426741405743924, -1.1377551213057147`], 
            Complex[1.3635269813327329`, -2.6198359153990136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2851487521541328, -1.1377551213057142`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2851487521541328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1377551213057142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[0.2851487521541328, -1.1377551213057142`], 
            Complex[1.3635269813327346`, -2.6198359153990136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.107397162145414, -0.4078755867501416}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[1.107397162145414, -0.4078755867501416], 
            Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.248989815735208, -0.4078755867501412}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.248989815735208, -0.4078755867501412], 
            Complex[2.203596585722578, -1.872357412196735]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.430700722955541, 0.008673251522090992}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[7.430700722955541, 0.008673251522090992], 
            Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.289108069365748, 0.008673251522090971}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.289108069365748, 0.008673251522090971], 
            Complex[5.777450742552286, -1.162910600549928]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.637823823216573, 0.011834207760463409`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[8.637823823216573, 0.011834207760463409`], 
            Complex[6.982345361327388, -1.160172170534845]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.496231169626781, 0.011834207760463395`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[5.496231169626781, 0.011834207760463395`], 
            Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.867906939037359, -0.019099823463292427`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[6.867906939037359, -0.019099823463292427`], 
            Complex[8.28224016277643, -1.199522741096495]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{10.009499592627153`, -0.019099823463292497`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[10.009499592627153`, -0.019099823463292497`], 
            Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4224987798606765`, -1.1458522701333511`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4224987798606765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6274485670330767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[3.4224987798606765`, -1.1458522701333511`], 
            Complex[1.3584336295287167`, -2.6274485670330767`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2809061262708882, -1.1458522701333518`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2809061262708882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.627448567033079`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[0.2809061262708882, -1.1458522701333518`], 
            Complex[1.3584336295287214`, -2.627448567033079]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.262007600278324, -0.4025161677361105}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.262007600278324, -0.4025161677361105], 
            Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1204149466885311`, -0.40251616773611126`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[1.1204149466885311`, -0.40251616773611126`], 
            Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.277470052807503, 0.008783844556995735}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.277470052807503, 0.008783844556995735], 
            Complex[5.765170376285118, -1.162877043404163]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.419062706397297, 0.008783844556995738}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[7.419062706397297, 0.008783844556995738], 
            Complex[5.765170376285118, -1.162877043404163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.656707602013043, 0.012217067867222313`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[8.656707602013043, 0.012217067867222313`], 
            Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.515114948423251, 0.012217067867222332`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[5.515114948423251, 0.012217067867222332`], 
            Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.8487801366438275`, -0.019502564592186727`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[6.8487801366438275`, -0.019502564592186727`], 
            Complex[8.263840153003091, -1.199779292073964]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.990372790233621, -0.01950256459218661}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[9.990372790233621, -0.01950256459218661], 
            Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.41841120976327, -1.1537578719399622`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.41841120976327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1537578719399622`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.634881633043194`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[3.41841120976327, -1.1537578719399622`], 
            Complex[1.3534970339779715`, -2.634881633043194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2768185561734762, -1.1537578719399602`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2768185561734762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1537578719399602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6348816330431903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[0.2768185561734762, -1.1537578719399602`], 
            Complex[1.3534970339779717`, -2.6348816330431903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.274836204246599, -0.39733515240586165`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.274836204246599, -0.39733515240586165`], 
            Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1332435506568057`, -0.39733515240586337`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[1.1332435506568057`, -0.39733515240586337`], 
            Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.4076304429802775`, 0.00889605134985899}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[7.4076304429802775`, 0.00889605134985899], 
            Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.266037789390484, 0.008896051349858974}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.266037789390484, 0.008896051349858974], 
            Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.675668864524779, 0.012626914319474911`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[8.675668864524779, 0.012626914319474911`], 
            Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.5340762109349875`, 0.012626914319474934`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[5.5340762109349875`, 0.012626914319474934`], 
            Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.971176318841339, -0.019931649951741043`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[9.971176318841339, -0.019931649951741043`], 
            Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.829583665251546, -0.019931649951741116`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[6.829583665251546, -0.019931649951741116`], 
            Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4144686707126652`, -1.1614825918531306`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4144686707126652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.348707291872495`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[3.4144686707126652`, -1.1614825918531306`], 
            Complex[1.348707291872495, -2.6421453813855136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2728760171228721, -1.1614825918531306`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2728760171228721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3487072918724958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[0.2728760171228721, -1.1614825918531306`], 
            Complex[1.3487072918724958`, -2.6421453813855136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.287486632822467, -0.39232206847656975`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.287486632822467, -0.39232206847656975`], 
            Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1458939792326737`, -0.3923220684765709}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[1.1458939792326737`, -0.3923220684765709], 
            Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.254797798340199, 0.009009898497034034}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.254797798340199, 0.009009898497034034], 
            Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.396390451929997, 0.009009898497033932}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[7.396390451929997, 0.009009898497033932], 
            Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.694743750598732, 0.013067149229433986`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[8.694743750598732, 0.013067149229433986`], 
            Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.553151097008939, 0.013067149229433903`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[5.553151097008939, 0.013067149229433903`], 
            Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.951873534557844, -0.020390522922278387`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[9.951873534557844, -0.020390522922278387`], 
            Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.810280880968052, -0.020390522922278664`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[6.810280880968052, -0.020390522922278664`], 
            Complex[8.226853738441678, -1.200360975725519]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.410662097155336, -1.1690361304484036`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.410662097155336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1690361304484036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6492491374148304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[3.410662097155336, -1.1690361304484036`], 
            Complex[1.3440554470967183`, -2.6492491374148304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2690694435655443, -1.1690361304484052`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2690694435655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1690361304484052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.649249137414832`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[0.2690694435655443, -1.1690361304484052`], 
            Complex[1.3440554470967194`, -2.649249137414832]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1583762613396105`, -0.38746740648134814`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[1.1583762613396105`, -0.38746740648134814`], 
            Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.299968914929404, -0.38746740648134725`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.299968914929404, -0.38746740648134725`], 
            Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.243737858735289, 0.009125414068990397}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.243737858735289, 0.009125414068990397], 
            Complex[5.729492775798816, -1.162770211346653]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.3853305123250825`, 0.009125414068990404}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[7.3853305123250825`, 0.009125414068990404], 
            Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.713970117564823, 0.013541803645186434`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[8.713970117564823, 0.013541803645186434`], 
            Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.57237746397503, 0.013541803645186435`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[5.57237746397503, 0.013541803645186435`], 
            Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.790833471518203, -0.020883251810279654`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[6.790833471518203, -0.020883251810279654`], 
            Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.932426125107996, -0.020883251810279745`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[9.932426125107996, -0.020883251810279745`], 
            Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.26539060743652637`, -1.1764273433249663`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.26539060743652637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1764273433249663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.339533369860022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[0.26539060743652637`, -1.1764273433249663`], 
            Complex[1.339533369860022, -2.656201401617177]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4069832610263204`, -1.176427343324966}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4069832610263204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.176427343324966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3395333698600238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[3.4069832610263204`, -1.176427343324966], 
            Complex[1.3395333698600238`, -2.656201401617177]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1706995721155862`, -0.382762500281366}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[1.1706995721155862`, -0.382762500281366], 
            Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.31229222570538, -0.3827625002813669}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.31229222570538, -0.3827625002813669], 
            Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.232846848694921, 0.009242627557842213}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.232846848694921, 0.009242627557842213], 
            Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.374439502284718, 0.00924262755784085}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[7.374439502284718, 0.00924262755784085], 
            Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.591795614755318, 0.014055695951277704`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[5.591795614755318, 0.014055695951277704`], 
            Complex[7.073421269042283, -1.158603006979818]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.733388268345113, 0.014055695951277626`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[8.733388268345113, 0.014055695951277626`], 
            Complex[7.073421269042284, -1.158603006979818]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.912793375391814, -0.02141468876524509}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[9.912793375391814, -0.02141468876524509], 
            Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.771200721802021, -0.021414688765245018`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[6.771200721802021, -0.021414688765245018`], 
            Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.4034246691397003`, -1.1836643421288453`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4034246691397003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1836643421288453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.663009949003302`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[3.4034246691397003`, -1.1836643421288453`], 
            Complex[1.3351336552455113`, -2.663009949003302]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2618320155499074, -1.183664342128846}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2618320155499074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.183664342128846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455122`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6630099490033023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[0.2618320155499074, -1.183664342128846], 
            Complex[1.3351336552455122`, -2.6630099490033023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1828723362728408`, -0.378199426130277}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[1.1828723362728408`, -0.378199426130277], 
            Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.324464989862636, -0.3781994261302779}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.324464989862636, -0.3781994261302779], 
            Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.222114609872632, 0.009361569840391626}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.222114609872632, 0.009361569840391626], 
            Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.363707263462426, 0.009361569840391621}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[7.363707263462426, 0.009361569840391621], 
            Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.611449146258794, 0.014614641743299664`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[5.611449146258794, 0.014614641743299664`], 
            Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.753041799848587, 0.014614641743299649`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[8.753041799848587, 0.014614641743299649`], 
            Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.751338660172414, -0.021990680088691934`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[6.751338660172414, -0.021990680088691934`], 
            Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.892931313762208, -0.021990680088691875`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[9.892931313762208, -0.021990680088691875`], 
            Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.399979476133, -1.1907545804380442`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.399979476133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[3.399979476133, -1.1907545804380442`], 
            Complex[1.330849537168034, -2.6696819135459715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.258386822543207, -1.1907545804380446`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.258386822543207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[0.258386822543207, -1.1907545804380446`], 
            Complex[1.330849537168034, -2.6696819135459737`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1949023158791763`, -0.3737709168766501}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[1.1949023158791763`, -0.3737709168766501], 
            Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.336494969468971, -0.3737709168766498}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.336494969468971, -0.3737709168766498], 
            Complex[2.293253543143011, -1.82773180818695]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.211531832555506, 0.009482273153986658}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.211531832555506, 0.009482273153986658], 
            Complex[5.695312895009785, -1.162653682569165]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.3531244861453, 0.009482273153988793}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[7.3531244861453, 0.009482273153988793], 
            Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.77297862441228, 0.015225736181981687`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[8.77297862441228, 0.015225736181981687`], 
            Complex[7.111050585905176, -1.157734788294595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.631385970822487, 0.015225736181981623`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[5.631385970822487, 0.015225736181981623`], 
            Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.872791686074075, -0.02261834895605743}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[9.872791686074075, -0.02261834895605743], 
            Complex[8.151078988162066, -1.201907179567137]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.731199032484283, -0.022618348956057268`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[6.731199032484283, -0.022618348956057268`], 
            Complex[8.151078988162068, -1.201907179567137]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.2550487565900203, -1.1977049272038123`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2550487565900203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1977049272038123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.676223860329442`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[0.2550487565900203, -1.1977049272038123`], 
            Complex[1.3266748149775125`, -2.676223860329442]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.396641410179813, -1.1977049272038105`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.396641410179813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977049272038105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.67622386032944`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[3.396641410179813, -1.1977049272038105`], 
            Complex[1.3266748149775132`, -2.67622386032944]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2067966853478913`, -0.369470288610321}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[1.2067966853478913`, -0.369470288610321], 
            Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.348389338937685, -0.36947028861032294`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.348389338937685, -0.36947028861032294`], 
            Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.201089957665183, 0.009604771083122505}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.201089957665183, 0.009604771083122505], 
            Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.342682611254977, 0.009604771083122523}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[7.342682611254977, 0.009604771083122523], 
            Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.651659582251507, 0.0158977403597609}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[5.651659582251507, 0.0158977403597609], 
            Complex[7.130299515097565, -1.157225283537514]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.793252235841303, 0.01589774035976148}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[8.793252235841303, 0.01589774035976148], 
            Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.852320685804424, -0.02330648209651281}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[9.852320685804424, -0.02330648209651281], 
            Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.7107280322146305`, -0.02330648209651286}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[6.7107280322146305`, -0.02330648209651286], 
            Complex[8.13150550216652, -1.202406603890853]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.25181205566632714`, -1.204521729892243}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.25181205566632714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[0.25181205566632714`, -1.204521729892243], 
            Complex[1.3226037905108852`, -2.682641847533846]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3934047092561204`, -1.204521729892243}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3934047092561204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[3.3934047092561204`, -1.204521729892243], 
            Complex[1.3226037905108854`, -2.682641847533846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.3601547494422475`, -0.3652913776086266}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.3601547494422475`, -0.3652913776086266], 
            Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2185620958524552`, -0.36529137760862845`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[1.2185620958524552`, -0.36529137760862845`], 
            Complex[2.317691837968342, -1.816262829010749]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.190781092718281, 0.009729098555121772}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.190781092718281, 0.009729098555121772], 
            Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.332373746308075, 0.009729098555121761}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[7.332373746308075, 0.009729098555121761], 
            Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.813923320576674, 0.016641620135819556`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[8.813923320576674, 0.016641620135819556`], 
            Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.6723306669868805`, 0.016641620135819466`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[5.6723306669868805`, 0.016641620135819466`], 
            Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.689864686007544, -0.024066068896217683`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[6.689864686007544, -0.024066068896217683`], 
            Complex[8.11157350310953, -1.202968247517296]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.831457339597339, -0.02406606889621767}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[9.831457339597339, -0.02406606889621767], 
            Complex[8.11157350310953, -1.202968247517296]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.39026406618571, -1.2112108690459429`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.39026406618571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3186312138329304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.688941479956369`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[3.39026406618571, -1.2112108690459429`], 
            Complex[1.3186312138329304`, -2.688941479956369]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.248671412595918, -1.2112108690459433`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.248671412595918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.318631213832932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6889414799563705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[0.248671412595918, -1.2112108690459433`], 
            Complex[1.318631213832932, -2.6889414799563705`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.3717973845316225`, -0.36122848586285683`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.3717973845316225`, -0.36122848586285683`], 
            Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2302047309418311`, -0.3612284858628565}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[1.2302047309418311`, -0.3612284858628565], 
            Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.322190592979878, 0.009855291843704485}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[7.322190592979878, 0.009855291843704485], 
            Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.180597939390085, 0.00985529184370446}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.180597939390085, 0.00985529184370446], 
            Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.693469206036438, 0.01747131387776226}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[5.693469206036438, 0.01747131387776226], 
            Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.835061859626233, 0.017471313877762306`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[8.835061859626233, 0.017471313877762306`], 
            Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.81013140250469, -0.02491106937082747}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[9.81013140250469, -0.02491106937082747], 
            Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.668538748914897, -0.024911069370827682`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[6.668538748914897, -0.024911069370827682`], 
            Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.24562192744249728`, -1.2177778056554163`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24562192744249728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2177778056554163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6951279554438115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[0.24562192744249728`, -1.2177778056554163`], 
            Complex[1.3147522362459447`, -2.6951279554438115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3872145810322905`, -1.2177778056554156`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3872145810322905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2177778056554156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.69512795544381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[3.3872145810322905`, -1.2177778056554156`], 
            Complex[1.3147522362459452`, -2.69512795544381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.38332300838, -0.35727633379543705`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.38332300838, -0.35727633379543705`], 
            Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2417303547902065`, -0.3572763337954378}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[1.2417303547902065`, -0.3572763337954378], 
            Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.170533730780807, 0.009983388579384763}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.170533730780807, 0.009983388579384763], 
            Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.312126384370602, 0.009983388579384756}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[7.312126384370602, 0.009983388579384756], 
            Complex[5.651636660481892, -1.162482038362008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.715157284805061, 0.018404853311322064`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[5.715157284805061, 0.018404853311322064`], 
            Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.856749938394854, 0.01840485331132207}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[8.856749938394854, 0.01840485331132207], 
            Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.646667892120967, -0.025859535214795407`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[6.646667892120967, -0.025859535214795407`], 
            Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.78826054571076, -0.02585953521479562}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[9.78826054571076, -0.02585953521479562], 
            Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.24265906608433005`, -1.2242276224707753`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24265906608433005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2242276224707753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7012061053544794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[0.24265906608433005`, -1.2242276224707753`], 
            Complex[1.3109623694144812`, -2.7012061053544794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3842517196741237`, -1.2242276224707729`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3842517196741237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2242276224707729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.701206105354477`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[3.3842517196741237`, -1.2242276224707729`], 
            Complex[1.3109623694144825`, -2.701206105354477]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.253144354246581, -0.35343001903737564`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[1.253144354246581, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.394737007836374, -0.35343001903737564`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.394737007836374, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.16058217684066, 0.010113427765967319`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.16058217684066, 0.010113427765967319`], 
            Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.302174830430454, 0.010113427765967268`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[7.302174830430454, 0.010113427765967268`], 
            Complex[5.641006995243322, -1.162436027385382]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.737492944039841, 0.019466046203823834`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[5.737492944039841, 0.019466046203823834`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.879085597629635, 0.019466046203823823`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[8.879085597629635, 0.019466046203823823`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.624153849873985, -0.02693529265819097}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[6.624153849873985, -0.02693529265819097], 
            Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.76574650346378, -0.02693529265819088}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[9.76574650346378, -0.02693529265819088], 
            Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.23977862401903308`, -1.2305650601795397`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23977862401903308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2305650601795397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3072574496615919`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.707180429964402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[0.23977862401903308`, -1.2305650601795397`], 
            Complex[1.3072574496615919`, -2.707180429964402]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.381371277608826, -1.230565060179537}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.381371277608826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.230565060179537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.307257449661592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7071804299643993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[3.381371277608826, -1.230565060179537], 
            Complex[1.307257449661592, -2.7071804299643993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2644517756377363`, -0.34968498034029766`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[1.2644517756377363`, -0.34968498034029766`], 
            Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.40604442922753, -0.3496849803402998}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.40604442922753, -0.3496849803402998], 
            Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1507374166916415`, 0.010245449802525813`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.1507374166916415`, 0.010245449802525813`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.292330070281435, 0.010245449802525817`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[7.292330070281435, 0.010245449802525817`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.76059559895939, 0.020687085496539206`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[5.76059559895939, 0.020687085496539206`], 
            Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.902188252549184, 0.020687085496539234`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[8.902188252549184, 0.020687085496539234`], 
            Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.600876998505349, -0.028170551750252844`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[6.600876998505349, -0.028170551750252844`], 
            Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.742469652095146, -0.028170551750257837`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[9.742469652095146, -0.028170551750257837`], 
            Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.378569348204635, -1.2367945492132952`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.378569348204635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.30363360666026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7130551295714294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[3.378569348204635, -1.2367945492132952`], 
            Complex[1.30363360666026, -2.7130551295714294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.23697669461484225`, -1.2367945492132955`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23697669461484225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132955`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3036336066602605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.71305512957143`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[0.23697669461484225`, -1.2367945492132955`], 
            Complex[1.3036336066602605`, -2.71305512957143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.417250010699276, -0.3460369658605059}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.417250010699276, -0.3460369658605059], 
            Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.275657357109484, -0.34603696586050564`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[1.275657357109484, -0.34603696586050564`], 
            Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.140993976808082, 0.01037949651040012}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.140993976808082, 0.01037949651040012], 
            Complex[5.620051946974447, -1.162340058391703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.282586630397876, 0.010379496510400103`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[7.282586630397876, 0.010379496510400103`], 
            Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.78461388785291, 0.022112751073540098`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[5.78461388785291, 0.022112751073540098`], 
            Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.926206541442703, 0.02211275107353916}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[8.926206541442703, 0.02211275107353916], 
            Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.5766885062096785`, -0.02961010826063084}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[6.5766885062096785`, -0.02961010826063084], 
            Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.718281159799472, -0.029610108260631186`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[9.718281159799472, -0.029610108260631186`], 
            Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3758422947494764`, -1.2429202378151198`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3758422947494764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3000872358777424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7188341319212634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[3.3758422947494764`, -1.2429202378151198`], 
            Complex[1.3000872358777424`, -2.7188341319212634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.2342496411596838, -1.2429202378151196`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2342496411596838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.300087235877743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.718834131921264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[0.2342496411596838, -1.2429202378151196`], 
            Complex[1.300087235877743, -2.718834131921264]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.286765557155954, -0.34248200518323674`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[1.286765557155954, -0.34248200518323674`], 
            Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.428358210745746, -0.34248200518323846`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.428358210745746, -0.34248200518323846`], 
            Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.131346734197311, 0.010515611164854463`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.131346734197311, 0.010515611164854463`], 
            Complex[5.609715869645587, -1.162290029994955]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.272939387787106, 0.010515611164854442`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[7.272939387787106, 0.010515611164854442`], 
            Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.95133006145241, 0.023807487220115792`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[8.95133006145241, 0.023807487220115792`], 
            Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.809737407862617, 0.023807487220115758`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[5.809737407862617, 0.023807487220115758`], 
            Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.5513985958381715`, -0.03131842125415489}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[6.5513985958381715`, -0.03131842125415489], 
            Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.692991249427967, -0.0313184212541546}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[9.692991249427967, -0.0313184212541546], 
            Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3731867257580617`, -1.2489460168942261`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3731867257580617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2489460168942261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7245211164750502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[3.3731867257580617`, -1.2489460168942261`], 
            Complex[1.2966149742384296`, -2.7245211164750502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.23159407216826933`, -1.248946016894224}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23159407216826933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.248946016894224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.724521116475047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[0.23159407216826933`, -1.248946016894224], 
            Complex[1.2966149742384314`, -2.724521116475047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.297780579877745, -0.33901638456087957`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[1.297780579877745, -0.33901638456087957`], 
            Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.439373233467538, -0.3390163845608803}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.439373233467538, -0.3390163845608803], 
            Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.121790883866403, 0.010653838531129443`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.121790883866403, 0.010653838531129443`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.263383537456196, 0.010653838531129386`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[7.263383537456196, 0.010653838531129386`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.836214897718771, 0.02586798658403449}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[5.836214897718771, 0.02586798658403449], 
            Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.977807551308572, 0.025867986584037196`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[8.977807551308572, 0.025867986584037196`], 
            Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.6663510144975, -0.033392197154710215`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[9.6663510144975, -0.033392197154710215`], 
            Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.5247583609077076`, -0.03339219715471046}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[6.5247583609077076`, -0.03339219715471046], 
            Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.22900681949582008`, -1.2548755421085922`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22900681949582008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2548755421085922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2932136785584984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7301195359534463`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[0.22900681949582008`, -1.2548755421085922`], 
            Complex[1.2932136785584984`, -2.7301195359534463`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.370599473085614, -1.254875542108594}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.370599473085614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.254875542108594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.293213678558499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.730119535953448`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[3.370599473085614, -1.254875542108594], 
            Complex[1.293213678558499, -2.730119535953448]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3087063974214082`, -0.33563662492447366`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[1.3087063974214082`, -0.33563662492447366`], 
            Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.450299051011202, -0.3356366249244736}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.450299051011202, -0.3356366249244736], 
            Complex[2.411607470734253, -1.774754506235453]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.253914563567924, 0.010794224904694137`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[7.253914563567924, 0.010794224904694137`], 
            Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.11232190997813, 0.010794224904694102`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.11232190997813, 0.010794224904694102`], 
            Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.864383522178553, 0.028447097632704994`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[5.864383522178553, 0.028447097632704994`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.005976175768346, 0.028447097632704935`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.005976175768346, 0.028447097632704935`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.496430480050892, -0.03598429729320658}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[6.496430480050892, -0.03598429729320658], 
            Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.638023133640685, -0.035984297293206895`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.638023133640685, -0.035984297293206895`], 
            Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.22648491887905142`, -1.2607122535464206`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22648491887905142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464206`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.735632635522893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[0.22648491887905142`, -1.2607122535464206`], 
            Complex[1.2898804063769855`, -2.735632635522893]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.368077572468845, -1.2607122535464201`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.368077572468845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7356326355228924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[3.368077572468845, -1.2607122535464201`], 
            Complex[1.2898804063769864`, -2.7356326355228924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.461139423570387, -0.33233946229789096`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[4.461139423570387, -0.33233946229789096`], 
            Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.319546769980594, -0.3323394622978922}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[1.319546769980594, -0.3323394622978922], 
            Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.102935560194785, 0.010936818155564383`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[4.102935560194785, 0.010936818155564383`], 
            Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.244528213784578, 0.010936818155564378`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[7.244528213784578, 0.010936818155564378`], 
            Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.036310546964627, 0.031803157852373865`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.036310546964627, 0.031803157852373865`], 
            Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.894717893374835, 0.031803157852374093`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[5.894717893374835, 0.031803157852374093`], 
            Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.607532848271008, -0.039353071187373335`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.607532848271008, -0.039353071187373335`], 
            Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.465940194681216, -0.03935307118737327}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[6.465940194681216, -0.03935307118737327], 
            Complex[7.898547952604841, -1.215606555382372]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.365618246173949, -1.2664593933197807`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365618246173949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7410634699329792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[3.365618246173949, -1.2664593933197807`], 
            Complex[1.2866123988665321`, -2.7410634699329792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.22402559258415555`, -1.2664593933197807`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22402559258415555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.741063469932979`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[0.22402559258415555`, -1.2664593933197807`], 
            Complex[1.2866123988665328`, -2.741063469932979]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.471897917269896, -0.3291218303014387}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.471897917269896, -0.3291218303014387], 
            Complex[2.434303571543256, -1.765305947424264]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3303052636801032`, -0.3291218303014382}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[1.3303052636801032`, -0.3291218303014382], 
            Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.093627822786881, 0.011081667776607964`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.093627822786881, 0.011081667776607964`], 
            Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.235220476376673, 0.01108166777660797}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[7.235220476376673, 0.01108166777660797], 
            Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.069506749440478, 0.03641303093548226}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.069506749440478, 0.03641303093548226], 
            Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.927914095850698, 0.036413030935491676`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[5.927914095850698, 0.036413030935491676`], 
            Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.432591283080759, -0.043975393800888975`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[6.432591283080759, -0.043975393800888975`], 
            Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.574183936670554, -0.04397539380088848}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.574183936670554, -0.04397539380088848], 
            Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.22162623389028935`, -1.2721200213365198`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22162623389028935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2721200213365198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.746414918867112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[0.22162623389028935`, -1.2721200213365198`], 
            Complex[1.2834070655552792`, -2.746414918867112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3632188874800852`, -1.2721200213365205`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3632188874800852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2721200213365205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7464149188671136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[3.3632188874800852`, -1.2721200213365205`], 
            Complex[1.2834070655552816`, -2.7464149188671136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.482577920205066, -0.3259808444790341}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.482577920205066, -0.3259808444790341], 
            Complex[2.445554179476747, -1.760702890657421]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3409852666152733`, -0.32598084447903347`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[1.3409852666152733`, -0.32598084447903347`], 
            Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.084394906148223, 0.011228824935798519`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.084394906148223, 0.011228824935798519`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.225987559738016, 0.011228824935798491`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[7.225987559738016, 0.011228824935798491`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.106617372354673, 0.04326772266645232}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.106617372354673, 0.04326772266645232], 
            Complex[7.426654831776879, -1.133628019546016]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.96502471876488, 0.0432677226664523}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[5.96502471876488, 0.0432677226664523], 
            Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.536923681000955, -0.05084228149321134}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.536923681000955, -0.05084228149321134], 
            Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.395331027411176, -0.05084228149319564}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[6.395331027411176, -0.05084228149319564], 
            Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3608770467672016`, -1.2776970294771413`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3608770467672016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2776970294771413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7516897007297403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[3.3608770467672016`, -1.2776970294771413`], 
            Complex[1.2802619706314171`, -2.7516897007297403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.21928439317740805`, -1.2776970294771406`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21928439317740805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2776970294771406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.75168970072974`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[0.21928439317740805`, -1.2776970294771406`], 
            Complex[1.2802619706314173`, -2.75168970072974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.4931826568685596`, -0.32291378822242134`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.4931826568685596`, -0.32291378822242134`], 
            Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.351590003278767, -0.32291378822242217`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[1.351590003278767, -0.32291378822242217`], 
            Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.216825874002135, 0.011378342532423407`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[7.216825874002135, 0.011378342532423407`], 
            Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.075233220412342, 0.01137834253242333}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.075233220412342, 0.01137834253242333], 
            Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.149127159726488, 0.05476808187732223}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.149127159726488, 0.05476808187732223], 
            Complex[7.466802670715167, -1.123122290976753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.007534506136697, 0.054768081877322586`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.007534506136697, 0.054768081877322586`], 
            Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.352674562767395, -0.062354593032590215`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.352674562767395, -0.062354593032590215`], 
            Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.494267216357189, -0.062354593032578}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.494267216357189, -0.062354593032578], 
            Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.358590419010691, -1.2831931543706478`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.358590419010691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.756890385061134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[3.358590419010691, -1.2831931543706478`], 
            Complex[1.2771748206351425`, -2.756890385061134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.21699776542089913`, -1.2831931543706483`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21699776542089913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7568903850611353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[0.21699776542089913`, -1.2831931543706483`], 
            Complex[1.2771748206351434`, -2.7568903850611353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.362122547573207, -0.319918100098616}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[1.362122547573207, -0.319918100098616], 
            Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.503715201163001, -0.3199181000986165}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.503715201163001, -0.3199181000986165], 
            Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.207732014499435, 0.011530275257279964`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[7.207732014499435, 0.011530275257279964`], 
            Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.066139360909642, 0.01153027525727997}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.066139360909642, 0.01153027525727997], 
            Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.197298230159177, 0.07734359441247762}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.197298230159177, 0.07734359441247762], 
            Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.055705576569384, 0.07734359441247692}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.055705576569384, 0.07734359441247692], 
            Complex[7.512359287571745, -1.102232298445035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.445952310414624, -0.08494182361234351}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.445952310414624, -0.08494182361234351], 
            Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.304359656824848, -0.08494182361233121}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.304359656824848, -0.08494182361233121], 
            Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3563568325133555`, -1.2886109889360127`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3563568325133555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2886109889360127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.274143453370581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7620194037437003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[3.3563568325133555`, -1.2886109889360127`], 
            Complex[1.274143453370581, -2.7620194037437003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.21476417892356292`, -1.288610988936014}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21476417892356292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.288610988936014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2741434533705815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.762019403743701`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[0.21476417892356292`, -1.288610988936014], 
            Complex[1.2741434533705815`, -2.762019403743701]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3725858345799593`, -0.31699136241415216`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[1.3725858345799593`, -0.31699136241415216`], 
            Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.514178488169753, -0.31699136241415254`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.514178488169753, -0.31699136241415254`], 
            Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.057110093241812, 0.011684679656931263`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.057110093241812, 0.011684679656931263`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.198702746831605, 0.011684679656931228`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[7.198702746831605, 0.011684679656931228`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.097972756057953, 0.11902724764148631`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.097972756057953, 0.11902724764148631`], 
            Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.239565409647748, 0.11902724764149018`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.239565409647748, 0.11902724764149018`], 
            Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.261951376465343, -0.12663696940989244`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.261951376465343, -0.12663696940989244`], 
            Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.403544030055139, -0.12663696940988678`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.403544030055139, -0.12663696940988678`], 
            Complex[7.704988630788347, -1.296125883577755]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.21258158513908437`, -1.293952992832856}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21258158513908437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.293952992832856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[0.21258158513908437`, -1.293952992832856], 
            Complex[1.2711658278935793`, -2.7670790611410534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.354174238728878, -1.2939529928328564`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.354174238728878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2939529928328564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[3.354174238728878, -1.2939529928328564`], 
            Complex[1.2711658278935796`, -2.7670790611410547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.524575324820607, -0.31413129087274355`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.524575324820607, -0.31413129087274355`], 
            Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.382982671230815, -0.31413129087274266`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[1.382982671230815, -0.31413129087274266`], 
            Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.04814233978115, 0.011841614202115778`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.04814233978115, 0.011841614202115778`], 
            Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.189734993370944, 0.011841614202115805`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[7.189734993370944, 0.011841614202115805`], 
            Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.120724694194671, 0.16611165996512534`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.120724694194671, 0.16611165996512534`], 
            Complex[7.574268139734727, -1.019141232917107]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.262317347784464, 0.16611165996512323`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.262317347784464, 0.16611165996512323`], 
            Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.380653624650824, -0.17373265713467972`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.380653624650824, -0.17373265713467972`], 
            Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.239060971061035, -0.17373265713468317`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.239060971061035, -0.17373265713468317`], 
            Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.352040703050758, -1.2992215019455444`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.352040703050758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[3.352040703050758, -1.2992215019455444`], 
            Complex[1.2682400154509323`, -2.7720715432919705`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.21044804946096587`, -1.2992215019455449`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21044804946096587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509332`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[0.21044804946096587`, -1.2992215019455449`], 
            Complex[1.2682400154509332`, -2.7720715432919714`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3933157460094145`, -0.3113357252023996}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[1.3933157460094145`, -0.3113357252023996], 
            Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.534908399599208, -0.3113357252023988}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.534908399599208, -0.3113357252023988], 
            Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.180825821018505, 0.012001139360437759`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[7.180825821018505, 0.012001139360437759`], 
            Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.039233167428713, 0.012001139360437396`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.039233167428713, 0.012001139360437396`], 
            Complex[5.510503169822832, -1.161705165156914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.132202365530885, 0.2069539217818524}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.132202365530885, 0.2069539217818524], 
            Complex[7.58536879774568, -0.980787258766948]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.27379501912068, 0.20695392178184982`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.27379501912068, 0.20695392178184982`], 
            Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.22744737065107, -0.21458598503237494`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.22744737065107, -0.21458598503237494`], 
            Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.369040024240906, -0.21458598503237647`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.369040024240906, -0.21458598503237647`], 
            Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3499543964575493`, -1.3044187370084819`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3499543964575493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3044187370084819`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[3.3499543964575493`, -1.3044187370084819`], 
            Complex[1.2653641912632538`, -2.776998926265093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.20836174286775633`, -1.304418737008481}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20836174286775633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.304418737008481`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[0.20836174286775633`, -1.304418737008481], 
            Complex[1.2653641912632545`, -2.776998926265093]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4035876377924137`, -0.3086026206444544}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[1.4035876377924137`, -0.3086026206444544], 
            Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.545180291382208, -0.3086026206444535}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.545180291382208, -0.3086026206444535], 
            Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.171972430077165, 0.012163317673485156`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[7.171972430077165, 0.012163317673485156`], 
            Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.030379776487371, 0.012163317673485264`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.030379776487371, 0.012163317673485264`], 
            Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.280570529089989, 0.24191392575349288`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.280570529089989, 0.24191392575349288`], 
            Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.138977875500199, 0.24191392575349213`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.138977875500199, 0.24191392575349213`], 
            Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.22053837960052, -0.24955685318475593`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.22053837960052, -0.24955685318475593`], 
            Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.362131033190314, -0.2495568531847539}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.362131033190314, -0.2495568531847539], 
            Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.20632093432967819`, -1.3095468114663624`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20632093432967819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[0.20632093432967819`, -1.3095468114663624`], 
            Complex[1.2625366270577847`, -2.7818631837665064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.347913587919471, -1.3095468114663606`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.347913587919471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577851`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665047`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[3.347913587919471, -1.3095468114663606`], 
            Complex[1.2625366270577851`, -2.7818631837665047`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4138008239261344`, -0.3059300402110024}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[1.4138008239261344`, -0.3059300402110024], 
            Complex[2.522758307852828, -1.730511398029892]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.555393477515928, -0.3059300402110033}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.555393477515928, -0.3059300402110033], 
            Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.021579490524692, 0.012328213838552492`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.021579490524692, 0.012328213838552492`], 
            Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.163172144114486, 0.012328213838552503`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[7.163172144114486, 0.012328213838552503`], 
            Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.285085225476458, 0.27256109297706776`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.285085225476458, 0.27256109297706776`], 
            Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.143492571886664, 0.27256109297706693`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.143492571886664, 0.27256109297706693`], 
            Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.357485218342608, -0.2802146897125705}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.357485218342608, -0.2802146897125705], 
            Complex[7.660008665723722, -1.440191789692609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.215892564752824, -0.2802146897125671}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.215892564752824, -0.2802146897125671], 
            Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.345916637483683, -1.314607738651282}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345916637483683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.314607738651282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.786666194080565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[3.345916637483683, -1.314607738651282], 
            Complex[1.2597556842695194`, -2.786666194080565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.20432398389389064`, -1.3146077386512802`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20432398389389064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3146077386512802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7866661940805635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[0.20432398389389064`, -1.3146077386512802`], 
            Complex[1.2597556842695206`, -2.7866661940805635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4239576876222573`, -0.3033161476291157}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[1.4239576876222573`, -0.3033161476291157], 
            Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.565550341212051, -0.3033161476291155}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[4.565550341212051, -0.3033161476291155], 
            Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.012829747116558, 0.012495894795164358`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[4.012829747116558, 0.012495894795164358`], 
            Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.154422400706351, 0.012495894795164308`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[7.154422400706351, 0.012495894795164308`], 
            Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.146749395916181, 0.30000093008350615`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.146749395916181, 0.30000093008350615`], 
            Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.288342049505975, 0.3000009300835058}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.288342049505975, 0.3000009300835058], 
            Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.212506903993471, -0.30766500790256135`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.212506903993471, -0.30766500790256135`], 
            Complex[7.656512931924062, -1.465936381216481]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.35409955758327, -0.30766500790255313`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.35409955758327, -0.30766500790255313`], 
            Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.2023693363760805, -1.3196034383483597`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2023693363760805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3196034383483597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.257019807839279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[0.2023693363760805, -1.3196034383483597`], 
            Complex[1.257019807839279, -2.7914097464142906`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.343961989965874, -1.31960343834836}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.343961989965874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.31960343834836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2570198078392791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[3.343961989965874, -1.31960343834836], 
            Complex[1.2570198078392791`, -2.7914097464142906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.434060524745711, -0.30075920090048514`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[1.434060524745711, -0.30075920090048514`], 
            Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.5756531783355054`, -0.30075920090048514`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.5756531783355054`, -0.30075920090048514`], 
            Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.004128089376173, 0.012666429816627254`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.004128089376173, 0.012666429816627254`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.145720742965965, 0.012666429816627278`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[7.145720742965965, 0.012666429816627278`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.149229270200796, 0.3249638924276399}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.149229270200796, 0.3249638924276399], 
            Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.290821923790588, 0.32496389242763857`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.290821923790588, 0.32496389242763857`], 
            Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.351493051581292, -0.33263826942312025`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.351493051581292, -0.33263826942312025`], 
            Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.209900397991501, -0.3326382694231228}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.209900397991501, -0.3326382694231228], 
            Complex[7.653771155925207, -1.489346210521607]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.342048169184744, -1.3245357428128088`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.342048169184744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.342048169184744, -1.3245357428128088`], 
            Complex[1.2543275205461564`, -2.796095546707045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.20045551559495106`, -1.3245357428128093`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20045551559495106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707046`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[0.20045551559495106`, -1.3245357428128093`], 
            Complex[1.2543275205461566`, -2.796095546707046]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.585704203648775, -0.2982575464138705}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[4.585704203648775, -0.2982575464138705], 
            Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4441115500589816`, -0.29825754641387064`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[1.4441115500589816`, -0.29825754641387064`], 
            Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.995472158184808, 0.012839890606854708`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.995472158184808, 0.012839890606854708`], 
            Complex[5.463037520285709, -1.161345446865949]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.137064811774602, 0.012839890606854724`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[7.137064811774602, 0.012839890606854724`], 
            Complex[5.463037520285709, -1.161345446865949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.151192034362995, 0.34794816918875576`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.151192034362995, 0.34794816918875576`], 
            Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.292784687952791, 0.34794816918876}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.292784687952791, 0.34794816918876], 
            Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.349405787878045, -0.35563266944840766`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.349405787878045, -0.35563266944840766`], 
            Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.207813134288261, -0.3556326694484139}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.207813134288261, -0.3556326694484139], 
            Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.340173772683676, -1.3294064022937957`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.340173772683676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3294064022937957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597475`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.340173772683676, -1.3294064022937957`], 
            Complex[1.2516774178194212`, -2.8007252229597475`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1985811190938835, -1.329406402293795}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1985811190938835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.329406402293795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[0.1985811190938835, -1.329406402293795], 
            Complex[1.2516774178194228`, -2.8007252229597466`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.454112902979397, -0.29580961355530405`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[1.454112902979397, -0.29580961355530405`], 
            Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.59570555656919, -0.2958096135553045}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[4.59570555656919, -0.2958096135553045], 
            Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.128452338640535, 0.013016351402742217`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[7.128452338640535, 0.013016351402742217`], 
            Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.986859685050743, 0.013016351402742245`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.986859685050743, 0.013016351402742245`], 
            Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.294383744285957, 0.36930769700429716`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.294383744285957, 0.36930769700429716`], 
            Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.152791090696166, 0.3693076970042951}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.152791090696166, 0.3693076970042951], 
            Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.347684294964536, -0.37700215031345224`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.347684294964536, -0.37700215031345224`], 
            Complex[7.649655116243796, -1.530899113668034]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.2060916413747425`, -0.3770021503134528}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.2060916413747425`, -0.3770021503134528], 
            Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.338337466890455, -1.3342170901139807`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.338337466890455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.338337466890455, -1.3342170901139807`], 
            Complex[1.2490681629814273`, -2.805300330131515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.19674481330066165`, -1.3342170901139803`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19674481330066165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[0.19674481330066165`, -1.3342170901139803`], 
            Complex[1.2490681629814275`, -2.805300330131515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.605659306489133, -0.2934139097675642}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[4.605659306489133, -0.2934139097675642], 
            Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4640666528993398`, -0.29341390976756415`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[1.4640666528993398`, -0.29341390976756415`], 
            Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9782884855315257`, 0.013195889082391367`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.9782884855315257`, 0.013195889082391367`], 
            Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.119881139121318, 0.01319588908239133}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[7.119881139121318, 0.01319588908239133], 
            Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.29571595421648, 0.3893033507690842}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.29571595421648, 0.3893033507690842], 
            Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.154123300626686, 0.38930335076908473`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.154123300626686, 0.38930335076908473`], 
            Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.346231645579115, -0.3970075923331433}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.346231645579115, -0.3970075923331433], 
            Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.204638991989324, -0.3970075923331428}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.204638991989324, -0.3970075923331428], 
            Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.19494532908188417`, -1.3389694073479312`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19494532908188417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3389694073479312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2464984828787806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.809822354646047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[0.19494532908188417`, -1.3389694073479312`], 
            Complex[1.2464984828787806`, -2.809822354646047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.336537982671677, -1.33896940734793}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.336537982671677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33896940734793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.246498482878781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.809822354646045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.336537982671677, -1.33896940734793], 
            Complex[1.246498482878781, -2.809822354646045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.615567457703371, -0.2910690160160602}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[4.615567457703371, -0.2910690160160602], 
            Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4739748041135785`, -0.29106901601605945`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[1.4739748041135785`, -0.29106901601605945`], 
            Complex[2.587217348678115, -1.70709401390507]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9697564531622382`, 0.01337858327951261}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.9697564531622382`, 0.01337858327951261], 
            Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.111349106752032, 0.013378583279512458`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[7.111349106752032, 0.013378583279512458`], 
            Complex[5.435044890840143, -1.161103942175881]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.155253112689077, 0.4081334915298177}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.155253112689077, 0.4081334915298177], 
            Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.296845766278874, 0.4081334915298239}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.296845766278874, 0.4081334915298239], 
            Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.344983328511988, -0.41584736171471265`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.344983328511988, -0.41584736171471265`], 
            Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.203390674922197, -0.41584736171471254`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.203390674922197, -0.41584736171471254`], 
            Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.19318145765365854`, -1.3436648871377261`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19318145765365854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3436648871377261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.243967163863943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[0.19318145765365854`, -1.3436648871377261`], 
            Complex[1.243967163863943, -2.814292718545235]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.334774111243452, -1.343664887137726}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.334774111243452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.343664887137726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2439671638639436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.334774111243452, -1.343664887137726], 
            Complex[1.2439671638639436`, -2.814292718545235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.62543195398277, -0.2887735826232172}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[4.62543195398277, -0.2887735826232172], 
            Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.483839300392978, -0.2887735826232169}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[1.483839300392978, -0.2887735826232169], 
            Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.102854207428718, 0.013564516504362785`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[7.102854207428718, 0.013564516504362785`], 
            Complex[5.425781575481577, -1.161018749909008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.961261553838926, 0.013564516504362838`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.961261553838926, 0.013564516504362838`], 
            Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.297817893725249, 0.42595292805234636`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.297817893725249, 0.42595292805234636`], 
            Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.156225240135477, 0.4259529280523631}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.156225240135477, 0.4259529280523631], 
            Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.343894570793292, -0.4336762721416326}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.343894570793292, -0.4336762721416326], 
            Complex[7.645371333222616, -1.583906400971115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.202301917203499, -0.4336762721416338}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.202301917203499, -0.4336762721416338], 
            Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.333044700404312, -1.348304998679792}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.333044700404312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323322`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.333044700404312, -1.348304998679792], 
            Complex[1.2414730480936764`, -2.818712783323322]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.19145204681451947`, -1.348304998679793}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19145204681451947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323323`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[0.19145204681451947`, -1.348304998679793], 
            Complex[1.2414730480936766`, -2.818712783323323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.635254682829313, -0.286526325437767}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[4.635254682829313, -0.286526325437767], 
            Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4936620292395204`, -0.28652632543776696`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[1.4936620292395204`, -0.28652632543776696`], 
            Complex[2.608435730175939, -1.699727637683005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.952801820612012, 0.013753774271608805`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.952801820612012, 0.013753774271608805`], 
            Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.094394474201807, 0.013753774271608687`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[7.094394474201807, 0.013753774271608687`], 
            Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.298664434058157, 0.44288515307919907`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.298664434058157, 0.44288515307919907`], 
            Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1570717804683675`, 0.44288515307919946`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.1570717804683675`, 0.44288515307919946`], 
            Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.201340564384264, -0.4506178210463805}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.201340564384264, -0.4506178210463805], 
            Complex[7.644243187304668, -1.599732810883159]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.342933217974057, -0.45061782104638065`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.342933217974057, -0.45061782104638065`], 
            Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.18975599747025035`, -1.352891150913283}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18975599747025035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.352891150913283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[0.18975599747025035`, -1.352891150913283], 
            Complex[1.2390150301144984`, -2.8230838534712266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.331348651060044, -1.3528911509132835`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.331348651060044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3528911509132835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.331348651060044, -1.3528911509132835`], 
            Complex[1.2390150301144984`, -2.8230838534712275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.503444825853813, -0.28432602230905957`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[1.503444825853813, -0.28432602230905957`], 
            Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.645037479443608, -0.2843260223090588}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[4.645037479443608, -0.2843260223090588], 
            Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9443753488495013`, 0.01394644523553293}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.9443753488495013`, 0.01394644523553293], 
            Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.085968002439294, 0.013946445235532949`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[7.085968002439294, 0.013946445235532949`], 
            Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.299409090344204, 0.45903052180506093`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.299409090344204, 0.45903052180506093`], 
            Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.15781643675441, 0.45903052180506065`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.15781643675441, 0.45903052180506065`], 
            Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.342075512640728, -0.4667723681000823}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.342075512640728, -0.4667723681000823], 
            Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.2004828590509335`, -0.46677236810008377`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.2004828590509335`, -0.46677236810008377`], 
            Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3296849140134457`, -1.3574246959370493`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3296849140134457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3574246959370493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8274071797574867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.3296849140134457`, -1.3574246959370493`], 
            Complex[1.2365920537085775`, -2.8274071797574867`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.18809226042365237`, -1.3574246959370482`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18809226042365237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3574246959370482`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.827407179757486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[0.18809226042365237`, -1.3574246959370482`], 
            Complex[1.2365920537085782`, -2.827407179757486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.513189476842979, -0.2821715098398555}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[1.513189476842979, -0.2821715098398555], 
            Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.654782130432774, -0.2821715098398547}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[4.654782130432774, -0.2821715098398547], 
            Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.077572945323753, 0.014142621333044114`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[7.077572945323753, 0.014142621333044114`], 
            Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9359802917339604`, 0.01414262133304412}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.9359802917339604`, 0.01414262133304412], 
            Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.300069789499112, 0.47447188989313444`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.300069789499112, 0.47447188989313444`], 
            Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.15847713590932, 0.4744718898931343}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.15847713590932, 0.4744718898931343], 
            Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.199710822382092, -0.4822227732417416}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.199710822382092, -0.4822227732417416], 
            Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.341303475971888, -0.4822227732417421}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.341303475971888, -0.4822227732417421], 
            Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.328052486994904, -1.36190693217938}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.328052486994904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.36190693217938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.234203108976306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.831683962269427`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.328052486994904, -1.36190693217938], 
            Complex[1.234203108976306, -2.831683962269427]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1864598334051111, -1.3619069321793806`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1864598334051111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3619069321793806`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2342031089763061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8316839622694276`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[0.1864598334051111, -1.3619069321793806`], 
            Complex[1.2342031089763061`, -2.8316839622694276`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.664490377283739, -0.28006168039394375`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[4.664490377283739, -0.28006168039394375`], 
            Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5228977236939458`, -0.280061680393945}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[1.5228977236939458`, -0.280061680393945], 
            Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.927614856061183, 0.014342397934981635`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.927614856061183, 0.014342397934981635`], 
            Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.069207509650976, 0.014342397934981436`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[7.069207509650976, 0.014342397934981436`], 
            Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1590677155468105`, 0.48927860682774}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.1590677155468105`, 0.48927860682774], 
            Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.300660369136605, 0.4892786068277399}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.300660369136605, 0.4892786068277399], 
            Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.340603220742913, -0.497038390042908}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.340603220742913, -0.497038390042908], 
            Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.199010567153125, -0.49703839004290984`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.199010567153125, -0.49703839004290984`], 
            Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.18485775832244397`, -1.3663391073422058`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18485775832244397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[0.18485775832244397`, -1.3663391073422058`], 
            Complex[1.2318472296343572`, -2.8359153532357344`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.326450411912238, -1.3663391073422075`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.326450411912238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.326450411912238, -1.3663391073422075`], 
            Complex[1.2318472296343572`, -2.8359153532357357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5325712660346489`, -0.2779954793374565}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[1.5325712660346489`, -0.2779954793374565], 
            Complex[2.650557449990277, -1.685592253447088]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.674163919624442, -0.2779954793374564}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[4.674163919624442, -0.2779954793374564], 
            Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9192772983115907`, 0.014545874006250778`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.9192772983115907`, 0.014545874006250778`], 
            Complex[5.379881023870964, -1.160554068514124]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.060869951901384, 0.014545874006250832`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[7.060869951901384, 0.014545874006250832`], 
            Complex[5.379881023870965, -1.160554068514124]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.159599046539053, 0.5035094122855176}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.159599046539053, 0.5035094122855176], 
            Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.301191700128847, 0.503509412285517}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.301191700128847, 0.503509412285517], 
            Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.339963828630122, -0.5112779620899647}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.339963828630122, -0.5112779620899647], 
            Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.198371175040328, -0.5112779620899686}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.198371175040328, -0.5112779620899686], 
            Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.18328511871069184`, -1.3707224211391664`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18328511871069184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391664`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[0.18328511871069184`, -1.3707224211391664`], 
            Complex[1.2295234905102042`, -2.8401024596493754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.324877772300485, -1.3707224211391649`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.324877772300485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.324877772300485, -1.3707224211391649`], 
            Complex[1.2295234905102046`, -2.8401024596493727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5422117647034572`, -0.2759719024950626}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[1.5422117647034572`, -0.2759719024950626], 
            Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.683804418293251, -0.2759719024950625}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[4.683804418293251, -0.2759719024950625], 
            Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.052558574558201, 0.014753152275367028`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[7.052558574558201, 0.014753152275367028`], 
            Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.910965920968408, 0.014753152275367222`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.910965920968408, 0.014753152275367222`], 
            Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.301672454837956, 0.5172145811965813}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.301672454837956, 0.5172145811965813], 
            Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.160079801248174, 0.5172145811965714}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.160079801248174, 0.5172145811965714], 
            Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.197783928263984, -0.5249917680556042}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.197783928263984, -0.5249917680556042], 
            Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.339376581853779, -0.5249917680556035}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.339376581853779, -0.5249917680556035], 
            Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3233336909542834`, -1.3750580278450637`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3233336909542834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3750580278450637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.3233336909542834`, -1.3750580278450637`], 
            Complex[1.2272310052160105`, -2.8442463457079334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.18174103736449077`, -1.3750580278450635`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18174103736449077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3750580278450635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[0.18174103736449077`, -1.3750580278450635`], 
            Complex[1.2272310052160111`, -2.8442463457079334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.693413498234962, -0.2739899938041945}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[4.693413498234962, -0.2739899938041945], 
            Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5518208446451707`, -0.27398999380419353`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[1.5518208446451707`, -0.27398999380419353`], 
            Complex[2.671487342062719, -1.678805872976879]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9026790690591686`, 0.014964339414034983`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.9026790690591686`, 0.014964339414034983`], 
            Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.044271722648962, 0.014964339414035013`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[7.044271722648962, 0.014964339414035013`], 
            Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.160516992248921, 0.5304375419992584}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.160516992248921, 0.5304375419992584], 
            Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.302109645838716, 0.5304375419992581}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.302109645838716, 0.5304375419992581], 
            Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.197241770749233, -0.538223239963063}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.197241770749233, -0.538223239963063], 
            Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.338834424339028, -0.5382232399630629}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.338834424339028, -0.5382232399630629], 
            Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.18022467413745052`, -1.3793470386724553`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18022467413745052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.224968923986572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8483480350867416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[0.18022467413745052`, -1.3793470386724553`], 
            Complex[1.224968923986572, -2.8483480350867416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.321817327727244, -1.3793470386724547`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.321817327727244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2249689239865722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8483480350867407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.321817327727244, -1.3793470386724547`], 
            Complex[1.2249689239865722`, -2.8483480350867407`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5614000976502447`, -0.27204884315225314`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[1.5614000976502447`, -0.27204884315225314`], 
            Complex[2.68192509329917, -1.675479597139089]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.702992751240038, -0.27204884315225375`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[4.702992751240038, -0.27204884315225375`], 
            Complex[2.68192509329917, -1.67547959713909]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{7.036007780489124, 0.015179546227436098`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[7.036007780489124, 0.015179546227436098`], 
            Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.894415126899331, 0.015179546227436329`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.894415126899331, 0.015179546227436329`], 
            Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.302509011886752, 0.5432161176861714}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.302509011886752, 0.5432161176861714], 
            Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.160916358296958, 0.5432161176861712}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.160916358296958, 0.5432161176861712], 
            Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1967389220498434`, -0.5510102042411117}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.1967389220498434`, -0.5510102042411117], 
            Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.338331575639637, -0.5510102042411122}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.338331575639637, -0.5510102042411122], 
            Complex[7.638493829265324, -1.693304925020469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.17873522389447033`, -1.3835905239895683`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17873522389447033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3835905239895683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[0.17873522389447033`, -1.3835905239895683`], 
            Complex[1.2227364316674634`, -2.8524085130586028`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3203278774842637`, -1.383590523989566}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3203278774842637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.383590523989566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.3203278774842637`, -1.383590523989566], 
            Complex[1.2227364316674654`, -2.8524085130586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.712543738542191, -0.2701475843833519}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[4.712543738542191, -0.2701475843833519], 
            Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5709510849523987`, -0.27014758438335246`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[1.5709510849523987`, -0.27014758438335246`], 
            Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8861725150187785`, 0.015398887855965335`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.8861725150187785`, 0.015398887855965335`], 
            Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.027765168608572, 0.01539888785596537}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[7.027765168608572, 0.01539888785596537], 
            Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.302875299750397, 0.5555834916479572}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.302875299750397, 0.5555834916479572], 
            Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.161282646160605, 0.5555834916479535}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.161282646160605, 0.5555834916479535], 
            Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1962705954158785`, -0.5633858475760002}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.1962705954158785`, -0.5633858475760002], 
            Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.337863249005673, -0.5633858475760003}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.337863249005673, -0.5633858475760003], 
            Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.17727191460430375`, -1.3877895153924003`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17727191460430375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3877895153924003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2205327458409323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8564287284726513`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[0.17727191460430375`, -1.3877895153924003`], 
            Complex[1.2205327458409323`, -2.8564287284726513`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3188645681940967`, -1.3877895153923996`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3188645681940967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3877895153923996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.220532745840933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8564287284726504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.3188645681940967`, -1.3877895153923996`], 
            Complex[1.220532745840933, -2.8564287284726504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5804753396984255`, -0.26828539346253044`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[1.5804753396984255`, -0.26828539346253044`], 
            Complex[2.702753826320577, -1.668956496466899]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.722067993288219, -0.2682853934625311}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[4.722067993288219, -0.2682853934625311], 
            Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.019542340843495, 0.015622483989198223`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[7.019542340843495, 0.015622483989198223`], 
            Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8779496872537016`, 0.015622483989198204`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.8779496872537016`, 0.015622483989198204`], 
            Complex[5.334505844025381, -1.160016544856252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1616198199314836`, 0.5675689693259762}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.1616198199314836`, 0.5675689693259762], 
            Complex[7.615247132185832, -0.643071359259793]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.303212473521276, 0.5675689693259758}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.303212473521276, 0.5675689693259758], 
            Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.195832788389601, -0.5753794785718529}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.195832788389601, -0.5753794785718529], 
            Complex[7.637270060814722, -1.715957196142648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.337425441979393, -0.5753794785718535}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.337425441979393, -0.5753794785718535], 
            Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3174266591507107`, -1.3919450076426472`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3174266591507107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3919450076426472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2183571150782422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.3174266591507107`, -1.3919450076426472`], 
            Complex[1.2183571150782422`, -2.860409595603666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1758340055609178, -1.391945007642646}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1758340055609178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.391945007642646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.218357115078243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[0.1758340055609178, -1.391945007642646], 
            Complex[1.218357115078243, -2.860409595603666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.731567022892644, -0.26646148678673676`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[4.731567022892644, -0.26646148678673676`], 
            Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5899743693028523`, -0.26646148678673565`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[1.5899743693028523`, -0.26646148678673565`], 
            Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.011337781577717, 0.015850459092959842`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[7.011337781577717, 0.015850459092959842`], 
            Complex[5.325475035055747, -1.159899171471262]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8697451279879247`, 0.015850459092959818`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.8697451279879247`, 0.015850459092959818`], 
            Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.161931218858729, 0.5791985860418423}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.161931218858729, 0.5791985860418423], 
            Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.303523872448524, 0.5791985860418385}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.303523872448524, 0.5791985860418385], 
            Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.337014778473906, -0.5870171355873209}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.337014778473906, -0.5870171355873209], 
            Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1954221248841135`, -0.5870171355873215}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.1954221248841135`, -0.5870171355873215], 
            Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3160134393130587`, -1.396057960481959}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3160134393130587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.396057960481959`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.864351995882056`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.3160134393130587`, -1.396057960481959], 
            Complex[1.2162088173083034`, -2.864351995882056]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.17442078572326566`, -1.3960579604819585`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17442078572326566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3960579604819585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8643519958820556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[0.17442078572326566`, -1.3960579604819585`], 
            Complex[1.2162088173083037`, -2.8643519958820556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5994496576990789`, -0.26467511963294016`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[1.5994496576990789`, -0.26467511963294016`], 
            Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.741042311288872, -0.26467511963294066`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[4.741042311288872, -0.26467511963294066`], 
            Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.003150003118844, 0.016082942650415873`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[7.003150003118844, 0.016082942650415873`], 
            Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.861557349529051, 0.01608294265041592}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.861557349529051, 0.01608294265041592], 
            Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.303812331602318, 0.5904955973399487}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.303812331602318, 0.5904955973399487], 
            Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.162219678012526, 0.5904955973399484}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.162219678012526, 0.5904955973399484], 
            Complex[7.615928222964841, -0.621726996632902]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.336628388028364, -0.5983220770848241}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.336628388028364, -0.5983220770848241], 
            Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.195035734438572, -0.5983220770848242}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.195035734438572, -0.5983220770848242], 
            Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.17303157216407558`, -1.4001293003321469`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17303157216407558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4001293003321469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2140871582933066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[0.17303157216407558`, -1.4001293003321469`], 
            Complex[1.2140871582933066`, -2.8682567795138803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3146242257538696`, -1.4001293003321456`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3146242257538696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4001293003321456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.214087158293307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.3146242257538696`, -1.4001293003321456`], 
            Complex[1.214087158293307, -2.8682567795138803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6089026674977167`, -0.2629255847348713}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[1.6089026674977167`, -0.2629255847348713], 
            Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.75049532108751, -0.26292558473487176`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[4.75049532108751, -0.26292558473487176`], 
            Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.994977543195845, 0.016320069418202337`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.994977543195845, 0.016320069418202337`], 
            Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8533848896060525`, 0.0163200694182023}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.8533848896060525`, 0.0163200694182023], 
            Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.162487621687207, 0.6014808784641323}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.162487621687207, 0.6014808784641323], 
            Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.304080275277004, 0.6014808784641332}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.304080275277004, 0.6014808784641332], 
            Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.336263812328982, -0.609315181113391}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.336263812328982, -0.609315181113391], 
            Complex[7.635641241458829, -1.747457014478097]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.194671158739189, -0.6093151811133911}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.194671158739189, -0.6093151811133911], 
            Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.313258362208889, -1.4041599218900036`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.313258362208889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.313258362208889, -1.4041599218900036`], 
            Complex[1.2119914702029877`, -2.8721247669993084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.17166570861909555`, -1.4041599218900036`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17166570861909555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029881`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[0.17166570861909555`, -1.4041599218900036`], 
            Complex[1.2119914702029881`, -2.8721247669993084`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6183348420620054`, -0.2612122109807513}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[1.6183348420620054`, -0.2612122109807513], 
            Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.7599274956518, -0.2612122109807508}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[4.7599274956518, -0.2612122109807508], 
            Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8452263089759486`, 0.01656197969868379}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.8452263089759486`, 0.01656197969868379], 
            Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.986818962565743, 0.016561979698683896`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.986818962565743, 0.016561979698683896`], 
            Complex[5.298442228350345, -1.159525179549259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.162737136528052, 0.6121732527479822}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.162737136528052, 0.6121732527479822], 
            Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.304329790117846, 0.612173252747982}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.304329790117846, 0.612173252747982], 
            Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.194326278421569, -0.6200152737048314}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.194326278421569, -0.6200152737048314], 
            Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.335918932011362, -0.6200152737048319}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.335918932011362, -0.6200152737048319], 
            Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.311915217718847, -1.408150689624686}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.311915217718847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.408150689624686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.209921110279896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.875956750557249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.311915217718847, -1.408150689624686], 
            Complex[1.209921110279896, -2.875956750557249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.17032256412905356`, -1.4081506896246843`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17032256412905356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4081506896246843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2099211102798964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.875956750557247`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[0.17032256412905356`, -1.4081506896246843`], 
            Complex[1.2099211102798964`, -2.875956750557247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6277476075095596`, -0.2595343622253301}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[1.6277476075095596`, -0.2595343622253301], 
            Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.769340261099353, -0.2595343622253304}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[4.769340261099353, -0.2595343622253304], 
            Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.837080189128189, 0.016808819629533064`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.837080189128189, 0.016808819629533064`], 
            Complex[5.289446015816816, -1.159392785201224]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.978672842717983, 0.01680881962953298}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.978672842717983, 0.01680881962953298], 
            Complex[5.289446015816816, -1.159392785201224]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30456268297077, 0.6225897638061416}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.30456268297077, 0.6225897638061416], 
            Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.162970029380981, 0.6225897638061394}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.162970029380981, 0.6225897638061394], 
            Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.335591908744412, -0.6304394010704698}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.335591908744412, -0.6304394010704698], 
            Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.193999255154619, -0.63043940107047}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.193999255154619, -0.63043940107047], 
            Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.16900153176725363`, -1.4121024391848713`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16900153176725363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4121024391848713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.879753495463146`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[0.16900153176725363`, -1.4121024391848713`], 
            Complex[1.2078754595887078`, -2.879753495463146]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.310594185357048, -1.41210243918487}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.310594185357048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.41210243918487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8797534954631456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.310594185357048, -1.41210243918487], 
            Complex[1.2078754595887096`, -2.8797534954631456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.637142374648998, -0.2578914362102892}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[1.637142374648998, -0.2578914362102892], 
            Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.778735028238791, -0.25789143621028987`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[4.778735028238791, -0.25789143621028987`], 
            Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.970537783665925, 0.017060741491919468`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.970537783665925, 0.017060741491919468`], 
            Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8289451300761326`, 0.017060741491919426`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.8289451300761326`, 0.017060741491919426`], 
            Complex[5.280454632721417, -1.159256290802515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1631878734954, 0.6327459028649584}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.1631878734954, 0.6327459028649584], 
            Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.304780527085194, 0.6327459028649576}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.304780527085194, 0.6327459028649576], 
            Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.193688485375648, -0.6406030569368893}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.193688485375648, -0.6406030569368893], 
            Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.33528113896544, -0.6406030569368892}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.33528113896544, -0.6406030569368892], 
            Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3092946810361643`, -1.4160159787223123`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3092946810361643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.883515741306371`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.3092946810361643`, -1.4160159787223123`], 
            Complex[1.205853921843281, -2.883515741306371]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1677020274463709, -1.4160159787223117`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1677020274463709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8835157413063706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[0.1677020274463709, -1.4160159787223117`], 
            Complex[1.205853921843282, -2.8835157413063706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.788113194449318, -0.256282863587831}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[4.788113194449318, -0.256282863587831], 
            Complex[2.775317254506115, -1.647405199653864]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6465205408595256`, -0.2562828635878306}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[1.6465205408595256`, -0.2562828635878306], 
            Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.962412401815591, 0.017317904038714253`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.962412401815591, 0.017317904038714253`], 
            Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.820819748225798, 0.01731790403871422}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.820819748225798, 0.01731790403871422], 
            Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.163392045750655, 0.6426557999628854}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.163392045750655, 0.6426557999628854], 
            Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.304984699340448, 0.6426557999628848}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.304984699340448, 0.6426557999628848], 
            Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.193392563005682, -0.6505203737511226}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.193392563005682, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.334985216595475, -0.6505203737511226}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.334985216595475, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1664234887985512, -1.419892090137794}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1664234887985512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[0.1664234887985512, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3080161423883445`, -1.419892090137794}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3080161423883445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.3080161423883445`, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.79747614551083, -0.2547081070429694}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[4.79747614551083, -0.2547081070429694], 
            Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6558834919210377`, -0.25470810704296915`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[1.6558834919210377`, -0.25470810704296915`], 
            Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.954295327902444, 0.01758047284423772}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.954295327902444, 0.01758047284423772], 
            Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.812702674312651, 0.0175804728442376}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.812702674312651, 0.0175804728442376], 
            Complex[5.262480372776144, -1.158970392486303]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.305176410484561, 0.6523323858111223}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.305176410484561, 0.6523323858111223], 
            Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.163583756894771, 0.6523323858111204}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.163583756894771, 0.6523323858111204], 
            Complex[7.617513055986503, -0.564265877881112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.193110249156134, -0.660204284545775}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.193110249156134, -0.660204284545775], 
            Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.334702902745928, -0.6602042845457757}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.334702902745928, -0.6602042845457757], 
            Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1651653741234745, -1.4237315302550273`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1651653741234745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4237315302550273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8909395727595073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[0.1651653741234745, -1.4237315302550273`], 
            Complex[1.2018809067516416`, -2.8909395727595073`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.306758027713268, -1.4237315302550264`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.306758027713268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4237315302550264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.890939572759507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.306758027713268, -1.4237315302550264`], 
            Complex[1.2018809067516425`, -2.890939572759507]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6652326038019236`, -0.2531666605106765}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[1.6652326038019236`, -0.2531666605106765], 
            Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.806825257391718, -0.2531666605106761}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[4.806825257391718, -0.2531666605106761], 
            Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8045925513977634`, 0.017848620677213583`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.8045925513977634`, 0.017848620677213583`], 
            Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.946185204987557, 0.017848620677213628`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.946185204987557, 0.017848620677213628`], 
            Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.163764076292796, 0.6617875296457958}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.163764076292796, 0.6617875296457958], 
            Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30535672988259, 0.6617875296457956}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.30535672988259, 0.6617875296457956], 
            Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.334433100918964, -0.6696666607954201}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.334433100918964, -0.6696666607954201], 
            Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.192840447329175, -0.6696666607954201}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.192840447329175, -0.6696666607954201], 
            Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1639271613994279, -1.4275350319275484`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1639271613994279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[0.1639271613994279, -1.4275350319275484`], 
            Complex[1.1999283404985253`, -2.8946025194218263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3055198149892218`, -1.4275350319275477`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3055198149892218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.3055198149892218`, -1.4275350319275477`], 
            Complex[1.1999283404985257`, -2.8946025194218263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.8161618980011855`, -0.2516580484846366}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[4.8161618980011855`, -0.2516580484846366], 
            Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6745692444113933`, -0.251658048484637}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[1.6745692444113933`, -0.251658048484637], 
            Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.938080686504964, 0.018122527898744748`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.938080686504964, 0.018122527898744748`], 
            Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.796488032915171, 0.018122527898744724`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.796488032915171, 0.018122527898744724`], 
            Complex[5.244507580447731, -1.158666193825158]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.305526605913883, 0.6710321572939462}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.305526605913883, 0.6710321572939462], 
            Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16393395232409, 0.671032157293945}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.16393395232409, 0.671032157293945], 
            Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.192582182972333, -0.6789184304865281}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.192582182972333, -0.6789184304865281], 
            Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.334174836562127, -0.6789184304865283}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.334174836562127, -0.6789184304865283], 
            Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.16270834735290776`, -1.4313033050832542`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16270834735290776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650033`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[0.16270834735290776`, -1.4313033050832542`], 
            Complex[1.1979977074898187`, -2.8982336911650033`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.304301000942701, -1.4313033050832549`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.304301000942701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.304301000942701, -1.4313033050832549`], 
            Complex[1.1979977074898187`, -2.8982336911650046`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6838947753228468`, -0.25018182541497563`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[1.6838947753228468`, -0.25018182541497563`], 
            Complex[2.816682213625116, -1.635923116971627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.825487428912641, -0.2501818254149765}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[4.825487428912641, -0.2501818254149765], 
            Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7883877807626547`, 0.018402382887287773`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.7883877807626547`, 0.018402382887287773`], 
            Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.929980434352448, 0.01840238288728782}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.929980434352448, 0.01840238288728782], 
            Complex[5.235518056794405, -1.158506794777096]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.305686882893223, 0.6800763528244194}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.305686882893223, 0.6800763528244194], 
            Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164094229303429, 0.680076352824419}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.164094229303429, 0.680076352824419], 
            Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.192334586512061, -0.6879696797720971}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.192334586512061, -0.6879696797720971], 
            Complex[7.632109194769857, -1.820245960840084]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.333927240101854, -0.6879696797720991}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.333927240101854, -0.6879696797720991], 
            Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3031011001724133`, -1.4350370377108632`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3031011001724133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4350370377108632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.196088509433674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.901833715576858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.3031011001724133`, -1.4350370377108632`], 
            Complex[1.196088509433674, -2.901833715576858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.16150844658262048`, -1.4350370377108643`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16150844658262048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4350370377108643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1960885094336744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9018337155768594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[0.16150844658262048`, -1.4350370377108643`], 
            Complex[1.1960885094336744`, -2.9018337155768594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.6932105534745874`, -0.2487375751928472}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[1.6932105534745874`, -0.2487375751928472], 
            Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.834803207064381, -0.24873757519284634`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[4.834803207064381, -0.24873757519284634`], 
            Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7802904634285417`, 0.018688382492788227`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.7802904634285417`, 0.018688382492788227`], 
            Complex[5.226524494130514, -1.158342279268929]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.921883117018336, 0.018688382492788213`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.921883117018336, 0.018688382492788213`], 
            Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.305838315194185, 0.6889294464957751}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.305838315194185, 0.6889294464957751], 
            Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164245661604394, 0.6889294464957759}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.164245661604394, 0.6889294464957759], 
            Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.333689532777536, -0.6968297409230606}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.333689532777536, -0.6968297409230606], 
            Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.192096879187743, -0.6968297409230599}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.192096879187743, -0.6968297409230599], 
            Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.16032699073407702`, -1.438736896792191}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16032699073407702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1942002649908234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9054032007098534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[0.16032699073407702`, -1.438736896792191], 
            Complex[1.1942002649908234`, -2.9054032007098534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3019196443238705`, -1.438736896792191}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3019196443238705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.194200264990824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.905403200709853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.3019196443238705`, -1.438736896792191], 
            Complex[1.194200264990824, -2.905403200709853]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.844110586443732, -0.24732491072033783`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[4.844110586443732, -0.24732491072033783`], 
            Complex[2.837373837167927, -1.630395790115732]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7025179328539397`, -0.2473249107203387}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[1.7025179328539397`, -0.2473249107203387], 
            Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.772194754147412, 0.018980732522336802`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.772194754147412, 0.018980732522336802`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.913787407737206, 0.018980732522336733`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.913787407737206, 0.018980732522336733`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164388925515004, 0.697600091198504}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.164388925515004, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.305981579104797, 0.697600091198504}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.305981579104797, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.191868361155921, -0.7055072687737808}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.191868361155921, -0.7055072687737808], 
            Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.333461014745714, -0.705507268773781}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.333461014745714, -0.705507268773781], 
            Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.3007561813111055`, -1.4424035291838815`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3007561813111055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4424035291838815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.908942735914548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[3.3007561813111055`, -1.4424035291838815`], 
            Complex[1.192332509008784, -2.908942735914548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.15916352772131243`, -1.442403529183883}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15916352772131243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.442403529183883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9089427359145503`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[0.15916352772131243`, -1.442403529183883], 
            Complex[1.192332509008784, -2.9089427359145503`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.711818266170711, -0.24594347356467736`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[1.711818266170711, -0.24594347356467736`], 
            Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.853410919760504, -0.24594347356467788`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[4.853410919760504, -0.24594347356467788`], 
            Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.90569198266763, 0.01927964825993098}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[6.90569198266763, 0.01927964825993098], 
            Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7640993290778377`, 0.019279648259930993`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[3.7640993290778377`, 0.019279648259930993`], 
            Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30611728283302, 0.7060963291837463}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.30611728283302, 0.7060963291837463], 
            Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164524629243228, 0.7060963291837459}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.164524629243228, 0.7060963291837459], 
            Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.191648401446948, -0.7140103074539127}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.191648401446948, -0.7140103074539127], 
            Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.33324105503674, -0.7140103074539126}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.33324105503674, -0.7140103074539126], 
            Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.15801762099250957`, -1.4460375624519293`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15801762099250957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4460375624519293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1904847917991184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[0.15801762099250957`, -1.4460375624519293`], 
            Complex[1.1904847917991184`, -2.912452892627875]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2996102745823035`, -1.446037562451929}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2996102745823035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.446037562451929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.190484791799119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.2996102745823035`, -1.446037562451929], 
            Complex[1.190484791799119, -2.912452892627875]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.862705560115598, -0.24459293369624477`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[4.862705560115598, -0.24459293369624477`], 
            Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7211129065258053`, -0.2445929336962447}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[1.7211129065258053`, -0.2445929336962447], 
            Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7560028654954856`, 0.01958535502317048}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.7560028654954856`, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.897595519085279, 0.01958535502317048}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.897595519085279, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164653321403731, 0.7144256505494253}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.164653321403731, 0.7144256505494253], 
            Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306245974993525, 0.7144256505494249}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.306245974993525, 0.7144256505494249], 
            Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.191436429442565, -0.7223463488774431}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.191436429442565, -0.7223463488774431], 
            Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.333029083032358, -0.7223463488774439}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.333029083032358, -0.7223463488774439], 
            Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.298481502426376, -1.4496396056620289`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.298481502426376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620289`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1886566784549102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9159342251191687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.298481502426376, -1.4496396056620289`], 
            Complex[1.1886566784549102`, -2.9159342251191687`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.15688884883658272`, -1.4496396056620269`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15688884883658272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.188656678454911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.915934225119166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[0.15688884883658272`, -1.4496396056620269`], 
            Complex[1.188656678454911, -2.915934225119166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7304032090806973`, -0.24327298931041993`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[1.7304032090806973`, -0.24327298931041993`], 
            Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.871995862670491, -0.24327298931041968`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[4.871995862670491, -0.24327298931041968`], 
            Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.747904039995082, 0.01989808875998759}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.747904039995082, 0.01989808875998759], 
            Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.889496693584875, 0.019898088759987553`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.889496693584875, 0.019898088759987553`], 
            Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306368151840394, 0.722595044698084}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.306368151840394, 0.722595044698084], 
            Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164775498250602, 0.7225950446980839}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.164775498250602, 0.7225950446980839], 
            Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.332824581199281, -0.73052238420331}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.332824581199281, -0.73052238420331], 
            Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.191231927609488, -0.7305223842033104}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.191231927609488, -0.7305223842033104], 
            Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2973694573177923`, -1.4532102501286348`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2973694573177923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4532102501286348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.2973694573177923`, -1.4532102501286348`], 
            Complex[1.1868477482057302`, -2.919387271196738]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.15577680372799887`, -1.4532102501286346`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15577680372799887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4532102501286346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[0.15577680372799887`, -1.4532102501286346`], 
            Complex[1.1868477482057311`, -2.919387271196738]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.739690532733481, -0.24198336673385532`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[1.739690532733481, -0.24198336673385532`], 
            Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.881283186323276, -0.24198336673385487`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[4.881283186323276, -0.24198336673385487`], 
            Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.881394180284589, 0.020218096688815555`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.881394180284589, 0.020218096688815555`], 
            Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.739801526694796, 0.020218096688815523`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.739801526694796, 0.020218096688815523`], 
            Complex[5.181444746812216, -1.157435637212811]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.164891609869033, 0.7306110457745064}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.164891609869033, 0.7306110457745064], 
            Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30648426345883, 0.730611045774511}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.30648426345883, 0.730611045774511], 
            Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1910344252759195`, -0.738544949275635}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.1910344252759195`, -0.738544949275635], 
            Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.332627078865713, -0.7385449492756353}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.332627078865713, -0.7385449492756353], 
            Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.296273745297108, -1.4567500701253233`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.296273745297108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4567500701253233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9228125528774775`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.296273745297108, -1.4567500701253233`], 
            Complex[1.1850575938076657`, -2.9228125528774775`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1546810917073148, -1.456750070125323}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1546810917073148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.456750070125323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.922812552877478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[0.1546810917073148, -1.456750070125323], 
            Complex[1.1850575938076662`, -2.922812552877478]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7489762418071482`, -0.24072382041628856`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[1.7489762418071482`, -0.24072382041628856`], 
            Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.8905688953969415`, -0.24072382041628823`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[4.8905688953969415`, -0.24072382041628823`], 
            Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7316939954367316`, 0.020545637985933}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.7316939954367316`, 0.020545637985933], 
            Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.873286649026525, 0.020545637985932938`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.873286649026525, 0.020545637985932938`], 
            Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165002065498246, 0.738479772924393}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.165002065498246, 0.738479772924393], 
            Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30659471908804, 0.7384797729243899}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.30659471908804, 0.7384797729243899], 
            Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.332436146868352, -0.7464201648848554}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.332436146868352, -0.7464201648848554], 
            Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.190843493278558, -0.7464201648848559}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.190843493278558, -0.7464201648848559], 
            Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1536013317951177, -1.4602596235588952`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1536013317951177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.92621057702186`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[0.1536013317951177, -1.4602596235588952`], 
            Complex[1.1832858209661048`, -2.92621057702186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2951939853849117`, -1.4602596235588936`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2951939853849117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.926210577021858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.2951939853849117`, -1.4602596235588936`], 
            Complex[1.1832858209661052`, -2.926210577021858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.899854361345616, -0.23949413300958752`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[4.899854361345616, -0.23949413300958752`], 
            Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.758261707755823, -0.23949413300958816`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[1.758261707755823, -0.23949413300958816`], 
            Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.723580109977185, 0.020880984524095002`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.723580109977185, 0.020880984524095002`], 
            Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.865172763566979, 0.020880984524095033`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.865172763566979, 0.020880984524095033`], 
            Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306699891715693, 0.7462069660795199}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.306699891715693, 0.7462069660795199], 
            Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1651072381259, 0.7462069660795196}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.1651072381259, 0.7462069660795196], 
            Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.190658739339742, -0.7541537725552644}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.190658739339742, -0.7541537725552644], 
            Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.332251392929535, -0.7541537725552647}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.332251392929535, -0.7541537725552647], 
            Complex[7.629300720152121, -1.881229052055075]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.15253715543722762`, -1.4637394526094687`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15253715543722762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4637394526094687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.181532047789208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[0.15253715543722762`, -1.4637394526094687`], 
            Complex[1.181532047789208, -2.9295818359364927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2941298090270217`, -1.4637394526094694`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2941298090270217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4637394526094694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1815320477892093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.2941298090270217`, -1.4637394526094694`], 
            Complex[1.1815320477892093`, -2.9295818359364927`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.90914096448451, -0.23829411553630825`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[4.90914096448451, -0.23829411553630825`], 
            Complex[2.910034828740951, -1.612121547840817]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7675483108947163`, -0.2382941155363085}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[1.7675483108947163`, -0.2382941155363085], 
            Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7154585261603414`, 0.021224421666976207`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.7154585261603414`, 0.021224421666976207`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.857051179750135, 0.021224421666976113`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.857051179750135, 0.021224421666976113`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165207468468805, 0.7537980178639989}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.165207468468805, 0.7537980178639989], 
            Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306800122058599, 0.7537980178639988}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.306800122058599, 0.7537980178639988], 
            Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.332072457649627, -0.7617511664534365}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.332072457649627, -0.7617511664534365], 
            Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.190479804059834, -0.761751166453437}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.190479804059834, -0.761751166453437], 
            Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.15148820597915524`, -1.4671900843386563`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15148820597915524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4671900843386563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.179795904270083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.932926807946241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[0.15148820597915524`, -1.4671900843386563`], 
            Complex[1.179795904270083, -2.932926807946241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2930808595689487`, -1.4671900843386574`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2930808595689487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4671900843386574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1797959042700832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9329268079462416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.2930808595689487`, -1.4671900843386574`], 
            Complex[1.1797959042700832`, -2.9329268079462416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.918430095749453, -0.2371236076506873}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[4.918430095749453, -0.2371236076506873], 
            Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.776837442159661, -0.23712360765068694`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[1.776837442159661, -0.23712360765068694`], 
            Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.848920543658824, 0.02157624912441265}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.848920543658824, 0.02157624912441265], 
            Complex[5.145157618862018, -1.156595047683686]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.707327890069032, 0.02157624912441267}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.707327890069032, 0.02157624912441267], 
            Complex[5.145157618862019, -1.156595047683686]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165303068434313, 0.761258002124613}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.165303068434313, 0.761258002124613], 
            Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306895722024107, 0.7612580021246124}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.306895722024107, 0.7612580021246124], 
            Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1903063574303445`, -0.7692174219206874}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.1903063574303445`, -0.7692174219206874], 
            Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.33189901102014, -0.7692174219206883}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.33189901102014, -0.7692174219206883], 
            Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1504541381679981, -1.470612031267735}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1504541381679981`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1780770317958789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.936245957937765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[0.1504541381679981, -1.470612031267735], 
            Complex[1.1780770317958789`, -2.936245957937765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2920467917577914`, -1.470612031267736}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2920467917577914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.178077031795879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.936245957937766`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.2920467917577914`, -1.470612031267736], 
            Complex[1.178077031795879, -2.936245957937766]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7861305049022496`, -0.23598247799562685`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[1.7861305049022496`, -0.23598247799562685`], 
            Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.927723158492043, -0.23598247799562702`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[4.927723158492043, -0.23598247799562702`], 
            Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6991868361460636`, 0.021936781873947247`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.6991868361460636`, 0.021936781873947247`], 
            Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.840779489735858, 0.021936781873947195`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.840779489735858, 0.021936781873947195`], 
            Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165394324140473, 0.7685916995129604}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.165394324140473, 0.7685916995129604], 
            Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.306986977730267, 0.7685916995129599}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.306986977730267, 0.7685916995129599], 
            Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.331730749379409, -0.7765573210571958}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.331730749379409, -0.7765573210571958], 
            Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.190138095789615, -0.7765573210571961}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.190138095789615, -0.7765573210571961], 
            Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1494346176800629, -1.4740057919276426`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1494346176800629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4740057919276426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[0.1494346176800629, -1.4740057919276426`], 
            Complex[1.1763750826821242`, -2.9395397378762262`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.291027271269856, -1.474005791927643}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.291027271269856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.474005791927643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.291027271269856, -1.474005791927643], 
            Complex[1.1763750826821242`, -2.9395397378762267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7954289167267061`, -0.23487062465998598`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[1.7954289167267061`, -0.23487062465998598`], 
            Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.9370215703165, -0.23487062465998587`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[4.9370215703165, -0.23487062465998587`], 
            Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6910339852795406`, 0.022306351154756415`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.6910339852795406`, 0.022306351154756415`], 
            Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.832626638869334, 0.022306351154756456`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.832626638869334, 0.022306351154756456`], 
            Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30707415214959, 0.7758036204842984}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.30707415214959, 0.7758036204842984], 
            Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1654814985597985`, 0.7758036204842987}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.1654814985597985`, 0.7758036204842987], 
            Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.331567392745953, -0.7837753757227326}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.331567392745953, -0.7837753757227326], 
            Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18997473915616, -0.7837753757227331}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.18997473915616, -0.7837753757227331], 
            Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2900219742624115`, -1.4773718513824372`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2900219742624115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4773718513824372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9428085872967427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.2900219742624115`, -1.4773718513824372`], 
            Complex[1.1746897197307482`, -2.9428085872967427`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1484293206726183, -1.477371851382437}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1484293206726183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.477371851382437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.942808587296742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[0.1484293206726183, -1.477371851382437], 
            Complex[1.1746897197307484`, -2.942808587296742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.946326764964685, -0.2337879757412101}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[4.946326764964685, -0.2337879757412101], 
            Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8047341113748927`, -0.23378797574120985`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[1.8047341113748927`, -0.23378797574120985`], 
            Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.824460596435171, 0.022685305540684226`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.824460596435171, 0.022685305540684226`], 
            Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6828679428453777`, 0.022685305540684448`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.6828679428453777`, 0.022685305540684448`], 
            Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307157487430532, 0.7828980260257034}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.307157487430532, 0.7828980260257034], 
            Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1655648338407385`, 0.7828980260257037}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.1655648338407385`, 0.7828980260257037], 
            Complex[7.619946700555888, -0.443528162616499]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.331408682475267, -0.7908758482666055}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.331408682475267, -0.7908758482666055], 
            Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.189816028885474, -0.7908758482666055}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.189816028885474, -0.7908758482666055], 
            Complex[7.627776768560513, -1.914949385030405]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1474379333583333, -1.4807106817278035`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1474379333583333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[0.1474379333583333, -1.4807106817278035`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2890305869481264`, -1.4807106817278028`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2890305869481264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.2890305869481264`, -1.4807106817278028`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.814047540666005, -0.23273449001922963`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[1.814047540666005, -0.23273449001922963`], 
            Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.955640194255799, -0.2327344900192291}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[4.955640194255799, -0.2327344900192291], 
            Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.816279950289862, 0.023074012099830184`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.816279950289862, 0.023074012099830184`], 
            Complex[5.108566172536498, -1.155632058324808]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6746872967000694`, 0.0230740120998302}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.6746872967000694`, 0.0230740120998302], 
            Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307237206941968, 0.7898789463823147}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.307237206941968, 0.7898789463823147], 
            Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165644553352178, 0.7898789463823163}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.165644553352178, 0.7898789463823163], 
            Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.189661725604909, -0.7978627702556053}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.189661725604909, -0.7978627702556053], 
            Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.331254379194702, -0.7978627702556061}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.331254379194702, -0.7978627702556061], 
            Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.288052805190806, -1.4840227425660197`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.288052805190806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4840227425660197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.288052805190806, -1.4840227425660197`], 
            Complex[1.1713674534574503`, -2.9492731933581573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.14646015160101253`, -1.48402274256602}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14646015160101253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.48402274256602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[0.14646015160101253`, -1.48402274256602], 
            Complex[1.1713674534574505`, -2.9492731933581573`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8233706764978728`, -0.2317101577484136}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[1.8233706764978728`, -0.2317101577484136], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.9649633300876665`, -0.23171015774841372`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[4.9649633300876665`, -0.23171015774841372`], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6664906151164782`, 0.023472857648944835`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.6664906151164782`, 0.023472857648944835`], 
            Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.808083268706271, 0.02347285764894464}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.808083268706271, 0.02347285764894464], 
            Complex[5.099358827456356, -1.155369598409927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165720863489107, 0.7967501980135657}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.165720863489107, 0.7967501980135657], 
            Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307313517078901, 0.7967501980135657}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.307313517078901, 0.7967501980135657], 
            Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.331104260978192, -0.8047399594318435}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.331104260978192, -0.8047399594318435], 
            Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.189511607388403, -0.804739959431843}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.189511607388403, -0.804739959431843], 
            Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2870883341211625`, -1.4873084814587765`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2870883341211625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4873084814587765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1697299244972095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9524697710180425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.2870883341211625`, -1.4873084814587765`], 
            Complex[1.1697299244972095`, -2.9524697710180425`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.14549568053136955`, -1.487308481458776}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14549568053136955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.487308481458776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.16972992449721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9524697710180416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[0.14549568053136955`, -1.487308481458776], 
            Complex[1.16972992449721, -2.9524697710180416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8327050129169915`, -0.23071500157543248`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[1.8327050129169915`, -0.23071500157543248`], 
            Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.974297666506786, -0.2307150015754329}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[4.974297666506786, -0.2307150015754329], 
            Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6582764446551637`, 0.023882250111808095`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.6582764446551637`, 0.023882250111808095`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.799869098244956, 0.023882250111808064`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.799869098244956, 0.023882250111808064`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307386608861503, 0.8035153989801238}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.307386608861503, 0.8035153989801238], 
            Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165793955271714, 0.8035153989801244}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.165793955271714, 0.8035153989801244], 
            Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330958121728596, -0.811511035101225}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.330958121728596, -0.811511035101225], 
            Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.189365468138804, -0.8115110351012247}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.189365468138804, -0.8115110351012247], 
            Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.28613688777145, -1.4905683343590643`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.28613688777145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4905683343590643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1681077296829168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9556430610267057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.28613688777145, -1.4905683343590643`], 
            Complex[1.1681077296829168`, -2.9556430610267057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1445442341816557, -1.490568334359063}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1445442341816557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.490568334359063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.168107729682917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.955643061026704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[0.1445442341816557, -1.490568334359063], 
            Complex[1.168107729682917, -2.955643061026704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.983644721854632, -0.22974907759194269`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[4.983644721854632, -0.22974907759194269`], 
            Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8420520682648396`, -0.22974907759194238`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[1.8420520682648396`, -0.22974907759194238`], 
            Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.7916359615532285`, 0.024302619991773983`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.7916359615532285`, 0.024302619991773983`], 
            Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6500433079634345`, 0.02430261999177399}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.6500433079634345`, 0.02430261999177399], 
            Complex[5.080861117956597, -1.15481581889049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1658640057650915`, 0.8101779829358522}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.1658640057650915`, 0.8101779829358522], 
            Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307456659354887, 0.8101779829358526}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.307456659354887, 0.8101779829358526], 
            Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.189223116150438, -0.8181794321268676}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.189223116150438, -0.8181794321268676], 
            Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330815769740232, -0.818179432126868}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.330815769740232, -0.818179432126868], 
            Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.285198188727837, -1.4938027260233295`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.285198188727837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9587934473565816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.285198188727837, -1.4938027260233295`], 
            Complex[1.1665005783527111`, -2.9587934473565816`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.14360553513804464`, -1.4938027260233295`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14360553513804464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.958793447356582`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[0.14360553513804464`, -1.4938027260233295`], 
            Complex[1.1665005783527118`, -2.958793447356582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8514133874083418`, -0.22881247653229805`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[1.8514133874083418`, -0.22881247653229805`], 
            Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.993006040998135, -0.22881247653229808`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[4.993006040998135, -0.22881247653229808`], 
            Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.64178970149396, 0.024734421969833987`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.64178970149396, 0.024734421969833987`], 
            Complex[5.071567299655017, -1.154523602824754]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.783382355083752, 0.024734421969834053`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.783382355083752, 0.024734421969834053`], 
            Complex[5.071567299655017, -1.154523602824754]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165931179342954, 0.8167412118766469}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.165931179342954, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307523832932748, 0.8167412118766469}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.307523832932748, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330677026418373, -0.824748413679325}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.330677026418373, -0.824748413679325], 
            Complex[7.626381574608514, -1.945974138422464]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18908437282858, -0.8247484136793249}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.18908437282858, -0.8247484136793249], 
            Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.284271967799523, -1.4970120704049878`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.284271967799523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4970120704049878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.284271967799523, -1.4970120704049878`], 
            Complex[1.1649081881027983`, -2.9619213040456414`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1426793142097304, -1.4970120704049876`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1426793142097304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4970120704049876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[0.1426793142097304, -1.4970120704049876`], 
            Complex[1.1649081881027992`, -2.9619213040456414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.860790544062835, -0.2279053251278246}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[1.860790544062835, -0.2279053251278246], 
            Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.0023831976526285`, -0.22790532512782422`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[5.0023831976526285`, -0.22790532512782422`], 
            Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.775106746724161, 0.02517813664084302}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.775106746724161, 0.02517813664084302], 
            Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.633514093134369, 0.025178136640842893`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.633514093134369, 0.025178136640842893`], 
            Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.165995628815023, 0.823208187778776}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.165995628815023, 0.823208187778776], 
            Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307588282404819, 0.8232081877787825}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.307588282404819, 0.8232081877787825], 
            Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330541725135806, -0.8312210828762443}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.330541725135806, -0.8312210828762443], 
            Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188949071546019, -0.8312210828762437}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.188949071546019, -0.8312210828762437], 
            Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.283357963703603, -1.500196771030314}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.283357963703603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.500196771030314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.283357963703603, -1.500196771030314], 
            Complex[1.1633302844761357`, -2.965026995548729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.14176531011381055`, -1.5001967710303135`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14176531011381055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5001967710303135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[0.14176531011381055`, -1.5001967710303135`], 
            Complex[1.1633302844761368`, -2.965026995548729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.011777796806058, -0.2270277876307708}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[5.011777796806058, -0.2270277876307708], 
            Complex[3.025955129189635, -1.586641723319602]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8701851432162653`, -0.22702778763077072`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[1.8701851432162653`, -0.22702778763077072`], 
            Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.766807573328626, 0.02563427240203126}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.766807573328626, 0.02563427240203126], 
            Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.625214919738834, 0.025634272402031196`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.625214919738834, 0.025634272402031196`], 
            Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166057496435186, 0.8295818632429409}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.166057496435186, 0.8295818632429409], 
            Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30765015002498, 0.8295818632429439}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.30765015002498, 0.8295818632429439], 
            Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188817056619653, -0.8376003934276774}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.188817056619653, -0.8376003934276774], 
            Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330409710209448, -0.8376003934276777}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.330409710209448, -0.8376003934276777], 
            Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2824559227648207`, -1.5033572213576796`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2824559227648207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1617666006657197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.968110877073136`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.2824559227648207`, -1.5033572213576796`], 
            Complex[1.1617666006657197`, -2.968110877073136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.14086326917502792`, -1.5033572213576796`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14086326917502792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.161766600665721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9681108770731357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[0.14086326917502792`, -1.5033572213576796`], 
            Complex[1.161766600665721, -2.9681108770731357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8795988236639012`, -0.22618006752276323`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[1.8795988236639012`, -0.22618006752276323`], 
            Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.021191477253695, -0.2261800675227632}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[5.021191477253695, -0.2261800675227632], 
            Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.7584832381419595`, 0.02610336750958422}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.7584832381419595`, 0.02610336750958422], 
            Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6168905845521655`, 0.0261033675095845}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.6168905845521655`, 0.0261033675095845], 
            Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1661169148049755`, 0.8358650512460941}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.1661169148049755`, 0.8358650512460941], 
            Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30770956839477, 0.8358650512460974}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.30770956839477, 0.8358650512460974], 
            Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188688182392475, -0.8438891593891127}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.188688182392475, -0.8438891593891127], 
            Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.33028083598227, -0.8438891593891124}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.33028083598227, -0.8438891593891124], 
            Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13997294503955765`, -1.5064938051210208`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13997294503955765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5064938051210208`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.160216877231663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9711732948992333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[0.13997294503955765`, -1.5064938051210208`], 
            Complex[1.160216877231663, -2.9711732948992333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2815655986293515`, -1.5064938051210213`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2815655986293515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5064938051210213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1602168772316634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9711732948992347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.2815655986293515`, -1.5064938051210213`], 
            Complex[1.1602168772316634`, -2.9711732948992347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.030625914253164, -0.22536240942454472`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[5.030625914253164, -0.22536240942454472`], 
            Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8890332606633722`, -0.22536240942454516`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[1.8890332606633722`, -0.22536240942454516`], 
            Complex[3.047400635096297, -1.582431831016463]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6085394545164045`, 0.026585992320965875`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.6085394545164045`, 0.026585992320965875`], 
            Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.750132108106198, 0.026585992320966013`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.750132108106198, 0.026585992320966013`], 
            Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166174007684912, 0.8420604340909559}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.166174007684912, 0.8420604340909559], 
            Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307766661274705, 0.8420604340909561}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.307766661274705, 0.8420604340909561], 
            Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188562312408357, -0.850090064112114}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.188562312408357, -0.850090064112114], 
            Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330154965998151, -0.8500900641121139}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.330154965998151, -0.8500900641121139], 
            Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13909409840205325`, -1.5096068966583966`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13909409840205325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.158680861831286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[0.13909409840205325`, -1.5096068966583966`], 
            Complex[1.158680861831286, -2.974214586687023]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.280686751991847, -1.5096068966583966`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.280686751991847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1586808618312865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[3.280686751991847, -1.5096068966583966`], 
            Complex[1.1586808618312865`, -2.974214586687023]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8984901687203608`, -0.2245751012259816}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[1.8984901687203608`, -0.2245751012259816], 
            Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.040082822310154, -0.22457510122598082`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[5.040082822310154, -0.22457510122598082`], 
            Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6001598574493725`, 0.027082751742796535`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[3.6001598574493725`, 0.027082751742796535`], 
            Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.7417525110391665`, 0.02708275174279656}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[6.7417525110391665`, 0.02708275174279656], 
            Complex[5.024575941774229, -1.152888750780241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166228890724623, 0.8481705716325338}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.166228890724623, 0.8481705716325338], 
            Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307821544314418, 0.8481705716325364}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.307821544314418, 0.8481705716325364], 
            Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.330031972258514, -0.856205668471937}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.330031972258514, -0.856205668471937], 
            Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1884393186687205`, -0.8562056684719376}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.1884393186687205`, -0.8562056684719376], 
            Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13822649674521148`, -1.5126968612263973`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13822649674521148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5126968612263973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[0.13822649674521148`, -1.5126968612263973`], 
            Complex[1.1571583089615174`, -2.9772350817692788`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.279819150335005, -1.512696861226397}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.279819150335005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.512696861226397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.279819150335005, -1.512696861226397], 
            Complex[1.1571583089615178`, -2.9772350817692788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.049563958105735, -0.22381847645779873`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[5.049563958105735, -0.22381847645779873`], 
            Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9079713045159428`, -0.22381847645779898`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[1.9079713045159428`, -0.22381847645779898`], 
            Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.733342732673844, 0.027594287906544456`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.733342732673844, 0.027594287906544456`], 
            Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5917500790840515`, 0.02759428790654434}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.5917500790840515`, 0.02759428790654434], 
            Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307874325710909, 0.8541979088518956}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.307874325710909, 0.8541979088518956], 
            Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166281672121116, 0.8541979088518953}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.166281672121116, 0.8541979088518953], 
            Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329911734551446, -0.8622384184423436}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.329911734551446, -0.8622384184423436], 
            Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188319080961654, -0.8622384184423437}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.188319080961654, -0.8622384184423437], 
            Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2789625676809804`, -1.5157640553011698`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2789625676809804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5157640553011698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.980235101432074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.2789625676809804`, -1.5157640553011698`], 
            Complex[1.1556489797129244`, -2.980235101432074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.13736991409118712`, -1.515764055301169}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13736991409118712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.515764055301169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9802351014320725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[0.13736991409118712`, -1.515764055301169], 
            Complex[1.1556489797129252`, -2.9802351014320725`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9174784699871426`, -0.22309291692935715`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[1.9174784699871426`, -0.22309291692935715`], 
            Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.059071123576937, -0.22309291692935682`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[5.059071123576937, -0.22309291692935682`], 
            Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.724901013546819, 0.02812128309705345}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.724901013546819, 0.02812128309705345], 
            Complex[5.005499610747705, -1.15214256927739]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.583308359957026, 0.02812128309705336}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.583308359957026, 0.02812128309705336], 
            Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166332453213396, 0.8601447828394871}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.166332453213396, 0.8601447828394871], 
            Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30792510680319, 0.860144782839487}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.30792510680319, 0.860144782839487], 
            Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188201486255246, -0.8681906520799051}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.188201486255246, -0.8681906520799051], 
            Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32979413984504, -0.8681906520799052}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.32979413984504, -0.8681906520799052], 
            Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13652413076420825`, -1.5188088268667397`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13652413076420825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5188088268667397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.15415264153475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.98321495918329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[0.13652413076420825`, -1.5188088268667397`], 
            Complex[1.15415264153475, -2.98321495918329]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.278116784354001, -1.518808826866739}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.278116784354001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.518808826866739`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1541526415347505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9832149591832895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.278116784354001, -1.518808826866739], 
            Complex[1.1541526415347505`, -2.9832149591832895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.068606169162741, -0.22239885565995454`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[5.068606169162741, -0.22239885565995454`], 
            Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.927013515572947, -0.22239885565995451`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[1.927013515572947, -0.22239885565995451`], 
            Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.716425545723422, 0.02866446296210377}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.716425545723422, 0.02866446296210377], 
            Complex[4.995893274766249, -1.151746964778438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5748328921336294`, 0.02866446296210389}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.5748328921336294`, 0.02866446296210389], 
            Complex[4.99589327476625, -1.151746964778438]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.307973982610356, 0.8660134292433511}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.307973982610356, 0.8660134292433511], 
            Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166381329020564, 0.8660134292433507}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.166381329020564, 0.8660134292433507], 
            Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.188086428148008, -0.8740646059731705}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.188086428148008, -0.8740646059731705], 
            Complex[7.6243541862563, -1.990999855207028]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329679081737801, -0.8740646059731706}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.329679081737801, -0.8740646059731706], 
            Complex[7.6243541862563, -1.990999855207028]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.277281586753582, -1.5218315156912805`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.277281586753582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.152669068010364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.277281586753582, -1.5218315156912805`], 
            Complex[1.152669068010364, -2.9861749610097594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.13568893316378858`, -1.5218315156912807`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13568893316378858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1526690680103642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[0.13568893316378858`, -1.5218315156912807`], 
            Complex[1.1526690680103642`, -2.9861749610097594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9365783436386594`, -0.22173678013483558`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[1.9365783436386594`, -0.22173678013483558`], 
            Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.078170997228454, -0.22173678013483544`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[5.078170997228454, -0.22173678013483544`], 
            Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.707914469346525, 0.029224600034819193`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.707914469346525, 0.029224600034819193`], 
            Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.566321815756732, 0.029224600034819154`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.566321815756732, 0.029224600034819154`], 
            Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308021042319387, 0.8718059882315835}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.308021042319387, 0.8718059882315835], 
            Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166428388729593, 0.8718059882315833}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.166428388729593, 0.8718059882315833], 
            Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187973806370098, -0.8798624212060279}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.187973806370098, -0.8798624212060279], 
            Complex[7.624115410024538, -1.996281512181469]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329566459959892, -0.8798624212060276}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.329566459959892, -0.8798624212060276], 
            Complex[7.624115410024538, -1.996281512181469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13486411354798725`, -1.5248324535919475`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13486411354798725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[0.13486411354798725`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2764567671377804`, -1.5248324535919475`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2764567671377804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.2764567671377804`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9461749120921603`, -0.22110723592124693`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[1.9461749120921603`, -0.22110723592124693`], 
            Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.087767565681953, -0.22110723592124715`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[5.087767565681953, -0.22110723592124715`], 
            Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.699365868995314, 0.02980251760487493}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.699365868995314, 0.02980251760487493], 
            Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.557773215405521, 0.029802517604874564`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.557773215405521, 0.029802517604874564`], 
            Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166473716138243, 0.877524510013052}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.166473716138243, 0.877524510013052], 
            Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308066369728037, 0.8775245100130518}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.308066369728037, 0.8775245100130518], 
            Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32945617991971, -0.8855861488792872}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.32945617991971, -0.8855861488792872], 
            Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187863526329917, -0.8855861488792874}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.187863526329917, -0.8855861488792874], 
            Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13404946982617044`, -1.5278119646888442`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13404946982617044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5278119646888442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9920365846984165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[0.13404946982617044`, -1.5278119646888442`], 
            Complex[1.1497393386483457`, -2.9920365846984165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2756421234159636`, -1.5278119646888435`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2756421234159636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5278119646888435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.992036584698415`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.2756421234159636`, -1.5278119646888435`], 
            Complex[1.1497393386483465`, -2.992036584698415]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.097397891796026, -0.2205108306846836}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[5.097397891796026, -0.2205108306846836], 
            Complex[3.123750747268463, -1.568770237634814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9558052382062334`, -0.22051083068468325`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[1.9558052382062334`, -0.22051083068468325`], 
            Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.6907777698397455`, 0.030399093979211252`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.6907777698397455`, 0.030399093979211252`], 
            Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5491851162499515`, 0.030399093979211273`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.5491851162499515`, 0.030399093979211273`], 
            Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166517390057898, 0.8831709599557609}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.166517390057898, 0.8831709599557609], 
            Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308110043647693, 0.8831709599557607}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.308110043647693, 0.8831709599557607], 
            Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329348152291017, -0.8912377552298729}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.329348152291017, -0.8912377552298729], 
            Complex[7.623646357838642, -2.006636716272229]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187755498701229, -0.8912377552298747}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.187755498701229, -0.8912377552298747], 
            Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1332448053607902, -1.530770365648672}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1332448053607902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.530770365648672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830955003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[0.1332448053607902, -1.530770365648672], 
            Complex[1.1482927587622171`, -2.9949387830955003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.274837458950583, -1.5307703656486717`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274837458950583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5307703656486717`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830954994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.274837458950583, -1.5307703656486717`], 
            Complex[1.1482927587622176`, -2.9949387830954994`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.965471402661748, -0.21994823865092936`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[1.965471402661748, -0.21994823865092936`], 
            Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.107064056251541, -0.21994823865093072`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[5.107064056251541, -0.21994823865093072`], 
            Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.540555479985998, 0.031015267178413904`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.540555479985998, 0.031015267178413904`], 
            Complex[4.956961006232221, -1.149994992121425]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.682148133575791, 0.03101526717841391}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.682148133575791, 0.03101526717841391], 
            Complex[4.956961006232221, -1.149994992121425]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166559484680516, 0.8887472233381511}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.166559484680516, 0.8887472233381511], 
            Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30815213827031, 0.888747223338151}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.30815213827031, 0.888747223338151], 
            Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187649639046593, -0.8968191263829133}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.187649639046593, -0.8968191263829133], 
            Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329242292636387, -0.8968191263829126}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.329242292636387, -0.8968191263829126], 
            Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.274042582367506, -1.5337079659185715`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274042582367506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5337079659185715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.274042582367506, -1.5337079659185715`], 
            Complex[1.1468580950483382`, -2.997822279081166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.13244992877771303`, -1.533707965918572}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13244992877771303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.533707965918572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[0.13244992877771303`, -1.533707965918572], 
            Complex[1.1468580950483385`, -2.997822279081167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.116768207416752, -0.21942020556585193`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[5.116768207416752, -0.21942020556585193`], 
            Complex[3.146006672598035, -1.565190320272424]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9751755538269593`, -0.21942020556585135`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[1.9751755538269593`, -0.21942020556585135`], 
            Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.531882200536309, 0.031652040121196476`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.531882200536309, 0.031652040121196476`], 
            Complex[4.947089201235956, -1.149509834990993]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.673474854126102, 0.031652040121196295`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.673474854126102, 0.031652040121196295`], 
            Complex[4.947089201235956, -1.149509834990993]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308192723503184, 0.8942551097650254}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.308192723503184, 0.8942551097650254], 
            Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166600069913391, 0.8942551097650246}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.166600069913391, 0.8942551097650246], 
            Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187545867473453, -0.9023320727684235}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.187545867473453, -0.9023320727684235], 
            Complex[7.623188002862294, -2.016726496581311]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329138521063246, -0.9023320727684233}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.329138521063246, -0.9023320727684233], 
            Complex[7.623188002862294, -2.016726496581311]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13166465378465506`, -1.5366250679506237`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13166465378465506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.000687344535021`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[0.13166465378465506`, -1.5366250679506237`], 
            Complex[1.1454351487203238`, -3.000687344535021]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.273257307374448, -1.5366250679506237`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.273257307374448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0006873445350215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.273257307374448, -1.5366250679506237`], 
            Complex[1.1454351487203243`, -3.0006873445350215`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.126512565878383, -0.21892755421211518`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[5.126512565878383, -0.21892755421211518`], 
            Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.984919912288591, -0.2189275542121152}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[1.984919912288591, -0.2189275542121152], 
            Complex[3.157220421076432, -1.563457815486074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.664755753090322, 0.03231048635665902}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.664755753090322, 0.03231048635665902], 
            Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5231630995005294`, 0.03231048635665899}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.5231630995005294`, 0.03231048635665899], 
            Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166639211685018, 0.8996963572765853}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.166639211685018, 0.8996963572765853], 
            Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30823186527481, 0.8996963572765849}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.30823186527481, 0.8996963572765849], 
            Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.329036761909217, -0.9077783332310709}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.329036761909217, -0.9077783332310709], 
            Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187444108319425, -0.9077783332310714}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.187444108319425, -0.9077783332310714], 
            Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.272481452587111, -1.5395219674174738`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.272481452587111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174738`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1440237259687367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.003534245149988`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[3.272481452587111, -1.5395219674174738`], 
            Complex[1.1440237259687367`, -3.003534245149988]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.13088879899731687`, -1.5395219674174727`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13088879899731687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.144023725968737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0035342451499867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[0.13088879899731687`, -1.5395219674174727`], 
            Complex[1.144023725968737, -3.0035342451499867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1362994292403545`, -0.21847119055042014`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[5.1362994292403545`, -0.21847119055042014`], 
            Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9947067756505623`, -0.21847119055042036`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[1.9947067756505623`, -0.21847119055042036`], 
            Complex[3.168494941546649, -1.561764858229167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5143959213393177`, 0.03299175641234993}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[3.5143959213393177`, 0.03299175641234993], 
            Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.655988574929111, 0.03299175641235}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[6.655988574929111, 0.03299175641235], 
            Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166676972224923, 0.9050726361762731}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.166676972224923, 0.9050726361762731], 
            Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308269625814717, 0.9050726361762732}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.308269625814717, 0.9050726361762732], 
            Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187344289864064, -0.9131595788587061}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.187344289864064, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328936943453858, -0.9131595788587061}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.328936943453858, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.13012218777282775`, -1.5423989534195135`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13012218777282775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5423989534195135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[0.13012218777282775`, -1.5423989534195135`], 
            Complex[1.1426236377957477`, -3.0063632406243785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.271714841362621, -1.542398953419513}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.271714841362621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.542398953419513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.271714841362621, -1.542398953419513], 
            Complex[1.1426236377957488`, -3.0063632406243794`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.004538523616137, -0.21805211056251306`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[2.004538523616137, -0.21805211056251306`], 
            Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1461311772059295`, -0.21805211056251345`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[5.1461311772059295`, -0.21805211056251345`], 
            Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.647170981866, 0.03369708483581625}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.647170981866, 0.03369708483581625], 
            Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.505578328276208, 0.03369708483581626}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.505578328276208, 0.03369708483581626], 
            Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166713410320053, 0.9103855526005633}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.166713410320053, 0.9103855526005633], 
            Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308306063909846, 0.9103855526005625}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.308306063909846, 0.9103855526005625], 
            Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1872463440644, -0.9184774165528232}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.1872463440644, -0.9184774165528232], 
            Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328838997654197, -0.9184774165528234}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.328838997654197, -0.9184774165528234], 
            Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12936464805013348`, -1.545256308683994}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12936464805013348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545256308683994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[0.12936464805013348`, -1.545256308683994], 
            Complex[1.1412346998566436`, -3.009174584846388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2709573016399287`, -1.5452563086839952`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2709573016399287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5452563086839952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846389`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.2709573016399287`, -1.5452563086839952`], 
            Complex[1.1412346998566438`, -3.009174584846389]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.156010276958656, -0.21767140788446362`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[5.156010276958656, -0.21767140788446362`], 
            Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.014417623368864, -0.21767140788446343`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[2.014417623368864, -0.21767140788446343`], 
            Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.6383005484916495`, 0.03442779801852971}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.6383005484916495`, 0.03442779801852971], 
            Complex[4.906968264234699, -1.147346318045541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4967078949018573`, 0.03442779801852968}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.4967078949018573`, 0.03442779801852968], 
            Complex[4.9069682642347, -1.147346318045541]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308341235139771, 0.9156366518516708}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.308341235139771, 0.9156366518516708], 
            Complex[7.621537327849359, -0.321751242072515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166748581549979, 0.9156366518516704}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.166748581549979, 0.9156366518516704], 
            Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.187150206311988, -0.923733392361904}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.187150206311988, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328742859901782, -0.923733392361904}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.328742859901782, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.270208665786776, -1.548094309756492}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270208665786776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.548094309756492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0119685260713935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.270208665786776, -1.548094309756492], 
            Complex[1.1398567323078, -3.0119685260713935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12861601219698304`, -1.5480943097564914`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12861601219698304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5480943097564914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0119685260713926`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[0.12861601219698304`, -1.5480943097564914`], 
            Complex[1.1398567323078006`, -3.0119685260713926`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0243466352667068`, -0.21733028233169743`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[2.0243466352667068`, -0.21733028233169743`], 
            Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1659392888564994`, -0.2173302823316979}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[5.1659392888564994`, -0.2173302823316979], 
            Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4877821024662152`, 0.035185322904060734`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.4877821024662152`, 0.035185322904060734`], 
            Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.629374756056008, 0.03518532290406068}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.629374756056008, 0.03518532290406068], 
            Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166782538502952, 0.9208274215121246}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.166782538502952, 0.9208274215121246], 
            Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308375192092747, 0.9208274215121248}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.308375192092747, 0.9208274215121248], 
            Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328648468799225, -0.9289289945966074}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.328648468799225, -0.9289289945966074], 
            Complex[7.622084507976147, -2.040875616614767]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1870558152094315`, -0.9289289945966069}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.1870558152094315`, -0.9289289945966069], 
            Complex[7.622084507976148, -2.040875616614767]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12787611686319877`, -1.5509132271850385`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12787611686319877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5509132271850385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0147453070923866`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[0.12787611686319877`, -1.5509132271850385`], 
            Complex[1.1384895596608695`, -3.0147453070923866`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2694687704529923`, -1.5509132271850388`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2694687704529923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5509132271850388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.014745307092387`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.2694687704529923`, -1.5509132271850388`], 
            Complex[1.1384895596608702`, -3.014745307092387]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.175920872451979, -0.21703004943242454`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[5.175920872451979, -0.21703004943242454`], 
            Complex[3.214258836551336, -1.555411285239044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.034328218862186, -0.2170300494324249}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[2.034328218862186, -0.2170300494324249], 
            Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.478798332845711, 0.03597119669747849}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.478798332845711, 0.03597119669747849], 
            Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.620390986435504, 0.03597119669747851}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.620390986435504, 0.03597119669747851], 
            Complex[4.886486777365879, -1.146111301584947]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30840798456442, 0.9259592943584085}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.30840798456442, 0.9259592943584085], 
            Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166815330974628, 0.9259592943584081}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.166815330974628, 0.9259592943584081], 
            Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186963112364547, -0.9340656567439883}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.186963112364547, -0.9340656567439883], 
            Complex[7.621870484005858, -2.045532964655917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32855576595434, -0.9340656567439881}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.32855576595434, -0.9340656567439881], 
            Complex[7.62187048400586, -2.045532964655917]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12714480283990298`, -1.5537133256973077`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12714480283990298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973077`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.017505165403874`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[0.12714480283990298`, -1.5537133256973077`], 
            Complex[1.1371330106428, -3.017505165403874]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.268737456429699, -1.5537133256973044`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268737456429699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0175051654038723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.268737456429699, -1.5537133256973044`], 
            Complex[1.1371330106428055`, -3.0175051654038723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.185957792848567, -0.21677215110365716`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[5.185957792848567, -0.21677215110365716`], 
            Complex[3.225881858451649, -1.553934201044293]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0443651392587743`, -0.2167721511036576}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[2.0443651392587743`, -0.2167721511036576], 
            Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.611346515764966, 0.03678707771053715}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.611346515764966, 0.03678707771053715], 
            Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.469753862175173, 0.036787077710537186`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.469753862175173, 0.036787077710537186`], 
            Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328464695790345, -0.9391447601963729}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.328464695790345, -0.9391447601963729], 
            Complex[7.621658530284444, -2.050135996258459]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186872042200558, -0.9391447601963707}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.186872042200558, -0.9391447601963707], 
            Complex[7.621658530284452, -2.050135996258457]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308439659740836, 0.931033651089264}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.308439659740836, 0.931033651089264], 
            Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166847006151044, 0.9310336510892632}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.166847006151044, 0.9310336510892632], 
            Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12642191492445268`, -1.5564948643711098`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12642191492445268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5564948643711098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0202483333595227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[0.12642191492445268`, -1.5564948643711098`], 
            Complex[1.1357869180615123`, -3.0202483333595227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.268014568514247, -1.55649486437111}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268014568514247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.55649486437111`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.020248333359523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.268014568514247, -1.55649486437111], 
            Complex[1.1357869180615132`, -3.020248333359523]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.054460273810074, -0.2165581676245985}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[2.054460273810074, -0.2165581676245985], 
            Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.196052927399868, -0.21655816762459845`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[5.196052927399868, -0.21655816762459845`], 
            Complex[3.237584411566567, -1.552504823512188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.460645854137856, 0.03763475749771081}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.460645854137856, 0.03763475749771081], 
            Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.60223850772765, 0.037634757497710766`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.60223850772765, 0.037634757497710766`], 
            Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186782551780801, -0.9441676368090823}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.186782551780801, -0.9441676368090823], 
            Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328375205370595, -0.9441676368090878}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.328375205370595, -0.9441676368090878], 
            Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166877608777316, 0.9360518228828759}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.166877608777316, 0.9360518228828759], 
            Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30847026236711, 0.9360518228828761}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.30847026236711, 0.9360518228828761], 
            Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.267299955380531, -1.559258096798595}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.267299955380531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0229750383238807`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.267299955380531, -1.559258096798595], 
            Complex[1.1344511186768103`, -3.0229750383238807`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12570730179073827`, -1.559258096798594}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12570730179073827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.02297503832388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[0.12570730179073827`, -1.559258096798594], 
            Complex[1.1344511186768111`, -3.02297503832388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.206209272752708, -0.2163898310860751}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[5.206209272752708, -0.2163898310860751], 
            Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0646166191629156`, -0.21638983108607387`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[2.0646166191629156`, -0.21638983108607387`], 
            Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4514713529124292`, 0.03851617446207811}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.4514713529124292`, 0.03851617446207811], 
            Complex[4.855165682495277, -1.144029106365958]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.593064006502223, 0.038516174462077585`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.593064006502223, 0.038516174462077585`], 
            Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32828724423658, -0.9491355712999281}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.32828724423658, -0.9491355712999281], 
            Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186694590646789, -0.9491355712999217}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.186694590646789, -0.9491355712999217], 
            Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308499834903161, 0.9410150937958542}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.308499834903161, 0.9410150937958542], 
            Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166907181313368, 0.9410150937958539}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.166907181313368, 0.9410150937958539], 
            Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2665934694544774`, -1.5620032712443408`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2665934694544774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5620032712443408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.2665934694544774`, -1.5620032712443408`], 
            Complex[1.1331254530764636`, -3.0256855028184027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12500081586468456`, -1.5620032712443406`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12500081586468456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5620032712443406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[0.12500081586468456`, -1.5620032712443406`], 
            Complex[1.1331254530764638`, -3.0256855028184018`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0748372986380015`, -0.2162690405227275}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[2.0748372986380015`, -0.2162690405227275], 
            Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.216429952227797, -0.21626904052272788`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[5.216429952227797, -0.21626904052272788`], 
            Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.442227275783197, 0.03943342913804209}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.442227275783197, 0.03943342913804209], 
            Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.58381992937299, 0.03943342913804175}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.58381992937299, 0.03943342913804175], 
            Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186608110668219, -0.9540498035022783}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.186608110668219, -0.9540498035022783], 
            Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328200764258014, -0.9540498035022821}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.328200764258014, -0.9540498035022821], 
            Complex[7.621034500886904, -2.063631600211478]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166935764077781, 0.9459247030157971}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.166935764077781, 0.9459247030157971], 
            Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308528417667576, 0.9459247030157971}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.308528417667576, 0.9459247030157971], 
            Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.265894966794422, -1.5647306307976763`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.265894966794422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976763`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1318097655570643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.265894966794422, -1.5647306307976763`], 
            Complex[1.1318097655570643`, -3.028379944662053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12430231320462909`, -1.5647306307976756`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12430231320462909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.131809765557065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[0.12430231320462909`, -1.5647306307976756`], 
            Complex[1.131809765557065, -3.028379944662053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0851255699314044`, -0.21619787896744103`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[2.0851255699314044`, -0.21619787896744103`], 
            Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.226718223521198, -0.2161978789674424}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[5.226718223521198, -0.2161978789674424], 
            Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4329104054302233`, 0.04038880139063529}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.4329104054302233`, 0.04038880139063529], 
            Complex[4.833843395364207, -1.142463267754563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.574503059020016, 0.040388801390635574`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.574503059020016, 0.040388801390635574`], 
            Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186523065904121, -0.9589115304824511}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.186523065904121, -0.9589115304824511], 
            Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328115719493917, -0.9589115304824558}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.328115719493917, -0.9589115304824558], 
            Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308556048970686, 0.9507818469782096}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.308556048970686, 0.9507818469782096], 
            Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166963395380894, 0.9507818469782096}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.166963395380894, 0.9507818469782096], 
            Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2652043069761856`, -1.5674404135194786`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2652043069761856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.2652043069761856`, -1.5674404135194786`], 
            Complex[1.1305039040095175`, -3.0310585771067586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.1236116533863979, -1.5674404135194724`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1236116533863979`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095248`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[0.1236116533863979, -1.5674404135194724`], 
            Complex[1.1305039040095248`, -3.0310585771067524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.237077486695947, -0.21617863270584659`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[5.237077486695947, -0.21617863270584659`], 
            Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0954848331061537`, -0.21617863270584692`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[2.0954848331061537`, -0.21617863270584692`], 
            Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.565110035519868, 0.04138476980950452}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.565110035519868, 0.04138476980950452], 
            Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.423517381930075, 0.04138476980950441}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.423517381930075, 0.04138476980950441], 
            Complex[4.823037890424123, -1.141619564099015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.328032066063827, -0.9637219085312987}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.328032066063827, -0.9637219085312987], 
            Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186439412474038, -0.9637219085313011}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.186439412474038, -0.9637219085313011], 
            Complex[7.620627795708716, -2.072379088667851]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.166990111648028, 0.9555876813576081}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.166990111648028, 0.9555876813576081], 
            Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308582765237823, 0.9555876813576076}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.308582765237823, 0.9555876813576076], 
            Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2645213529825936`, -1.5701328525836726`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2645213529825936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.03372160896789`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.2645213529825936`, -1.5701328525836726`], 
            Complex[1.1292077198089117`, -3.03372160896789]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12292869939280154`, -1.5701328525836726`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12292869939280154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0337216089678942`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[0.12292869939280154`, -1.5701328525836726`], 
            Complex[1.1292077198089157`, -3.0337216089678942`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.247511292414014, -0.21621381305374007`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[5.247511292414014, -0.21621381305374007`], 
            Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1059186388242215`, -0.21621381305374038`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[2.1059186388242215`, -0.21621381305374038`], 
            Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4140446945168277`, 0.042424033620649226`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.4140446945168277`, 0.042424033620649226`], 
            Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.555637348106621, 0.04242403362064838}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.555637348106621, 0.04242403362064838], 
            Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1863571084384, -0.9684820550389218}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.1863571084384, -0.9684820550389218], 
            Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327949762028192, -0.9684820550389235}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.327949762028192, -0.9684820550389235], 
            Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167015947533717, 0.960343322941825}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.167015947533717, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30860860112351, 0.960343322941825}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.30860860112351, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12225331750747458`, -1.5728081764136674`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12225331750747458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5728081764136674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0363692447500137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[0.12225331750747458`, -1.5728081764136674`], 
            Complex[1.1279210677086149`, -3.0363692447500137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2638459710972687`, -1.5728081764136679`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2638459710972687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5728081764136679`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.036369244750015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.2638459710972687`, -1.5728081764136679`], 
            Complex[1.1279210677086156`, -3.036369244750015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.116430696743796, -0.21630618103294583`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[2.116430696743796, -0.21630618103294583`], 
            Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.258023350333589, -0.21630618103294588`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[5.258023350333589, -0.21630618103294588`], 
            Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4044886731783923`, 0.043509537491681564`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.4044886731783923`, 0.043509537491681564`], 
            Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.546081326768186, 0.04350953749168187}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.546081326768186, 0.04350953749168187], 
            Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186276113687406, -0.9731930502608692}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.186276113687406, -0.9731930502608692], 
            Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327868767277202, -0.9731930502608676}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.327868767277202, -0.9731930502608676], 
            Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308633589617479, 0.9650498513977598}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.308633589617479, 0.9650498513977598], 
            Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1670409360276865`, 0.9650498513977598}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.1670409360276865`, 0.9650498513977598], 
            Complex[7.621960242608855, -0.276706626137473]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2631780308024685`, -1.575466608813974}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2631780308024685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.575466608813974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.126643805738343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.03900168476816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.2631780308024685`, -1.575466608813974], 
            Complex[1.126643805738343, -3.03900168476816]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12158537721267502`, -1.5754666088139742`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12158537721267502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754666088139742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1266438057383434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.039001684768161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[0.12158537721267502`, -1.5754666088139742`], 
            Complex[1.1266438057383434`, -3.039001684768161]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.127024883972908, -0.21645877538292152`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[2.127024883972908, -0.21645877538292152`], 
            Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.268617537562701, -0.21645877538292138`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[5.268617537562701, -0.21645877538292138`], 
            Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.536438133786874, 0.04464449966811444}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.536438133786874, 0.04464449966811444], 
            Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3948454801970804`, 0.044644499668114825`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.3948454801970804`, 0.044644499668114825`], 
            Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327789043427426, -0.9778559389833152}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.327789043427426, -0.9778559389833152], 
            Complex[7.620030720208938, -2.08514752827235]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186196389837632, -0.977855938983316}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.186196389837632, -0.977855938983316], 
            Complex[7.620030720208938, -2.085147528272351]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30865776214308, 0.9697083109361536}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.30865776214308, 0.9697083109361536], 
            Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167065108553286, 0.9697083109361534}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.167065108553286, 0.9697083109361534], 
            Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.12092475109102498`, -1.5781083690971813`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12092475109102498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5781083690971813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.04161912526473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[0.12092475109102498`, -1.5781083690971813`], 
            Complex[1.1253757951060699`, -3.04161912526473]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2625174046808185`, -1.5781083690971809`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2625174046808185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5781083690971809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.041619125264729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.2625174046808185`, -1.5781083690971809`], 
            Complex[1.1253757951060703`, -3.041619125264729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.279297907015237, -0.2166749444176823}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[5.279297907015237, -0.2166749444176823], 
            Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.137705253425444, -0.21667494441768215`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[2.137705253425444, -0.21667494441768215`], 
            Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.526703755378124, 0.045832443950467455`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.526703755378124, 0.045832443950467455`], 
            Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3851111017883304`, 0.045832443950466685`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.3851111017883304`, 0.045832443950466685`], 
            Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186117900135718, -0.9824717320942182}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.186117900135718, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327710553725511, -0.9824717320942182}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.327710553725511, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1670884950589855`, 0.974319711882344}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.1670884950589855`, 0.974319711882344], 
            Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30868114864878, 0.974319711882344}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.30868114864878, 0.974319711882344], 
            Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2618639683207284`, -1.5807336722064977`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2618639683207284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5807336722064977`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1241169001035878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0442217585222795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.2618639683207284`, -1.5807336722064977`], 
            Complex[1.1241169001035878`, -3.0442217585222795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.12027131473093523`, -1.580733672206497}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12027131473093523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.580733672206497`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.124116900103588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0442217585222786`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[0.12027131473093523`, -1.580733672206497], 
            Complex[1.124116900103588, -3.0442217585222786`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.29006869545568, -0.21695838232209166`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[5.29006869545568, -0.21695838232209166`], 
            Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1484760418658873`, -0.21695838232209172`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[2.1484760418658873`, -0.21695838232209172`], 
            Complex[3.347142736911111, -1.54216837655994]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3752813400511936`, 0.04707723610641603}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.3752813400511936`, 0.04707723610641603], 
            Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.516873993640987, 0.047077236106415926`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.516873993640987, 0.047077236106415926`], 
            Complex[4.767386408695089, -1.136665739909799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.186040609368656, -0.9870414080668142}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.186040609368656, -0.9870414080668142], 
            Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32763326295845, -0.9870414080668136}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.32763326295845, -0.9870414080668136], 
            Complex[7.619640805534105, -2.093436192381357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167111124103515, 0.9788850321593934}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.167111124103515, 0.9788850321593934], 
            Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308703777693312, 0.9788850321593942}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.308703777693312, 0.9788850321593942], 
            Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11962494663556839`, -1.5833427288340611`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11962494663556839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[0.11962494663556839`, -1.5833427288340611`], 
            Complex[1.1228669880155542`, -3.0468097729723587`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2612176002253626`, -1.5833427288340611`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2612176002253626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.2612176002253626`, -1.5833427288340611`], 
            Complex[1.1228669880155548`, -3.0468097729723587`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.15934167735015, -0.21731317057992383`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[2.15934167735015, -0.21731317057992383`], 
            Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.300934330939945, -0.21731317057992383`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[5.300934330939945, -0.21731317057992383`], 
            Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.365351805523236, 0.04838312541060397}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.365351805523236, 0.04838312541060397], 
            Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.50694445911303, 0.04838312541060556}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.50694445911303, 0.04838312541060556], 
            Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18596448378006, -0.991565914361383}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.18596448378006, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327557137369855, -0.991565914361383}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.327557137369855, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308725676524938, 0.9834052186894814}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.308725676524938, 0.9834052186894814], 
            Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167133022935145, 0.9834052186894809}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.167133022935145, 0.9834052186894809], 
            Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11898552813518211`, -1.5859357455351755`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11898552813518211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0493833533005414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[0.11898552813518211`, -1.5859357455351755`], 
            Complex[1.1216259290318777`, -3.0493833533005414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.260578181724976, -1.5859357455351744`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.260578181724976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.049383353300541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.260578181724976, -1.5859357455351744`], 
            Complex[1.1216259290318786`, -3.049383353300541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.170306785665302, -0.21774382534019746`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[2.170306785665302, -0.21774382534019746`], 
            Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.311899439255096, -0.21774382534019754`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[5.311899439255096, -0.21774382534019754`], 
            Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3553179107369844`, 0.049754792118764775`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.3553179107369844`, 0.049754792118764775`], 
            Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.496910564326778, 0.04975479211876483}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.496910564326778, 0.04975479211876483], 
            Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327482144581792, -0.9960461687506829}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.327482144581792, -0.9960461687506829], 
            Complex[7.619257020505317, -2.10155454761218]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1858894909919995`, -0.9960461687506831}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1858894909919995`, -0.9960461687506831], 
            Complex[7.619257020505318, -2.10155454761218]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308746871155384, 0.9878811887189863}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.308746871155384, 0.9878811887189863], 
            Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1671542175655905`, 0.9878811887189864}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1671542175655905`, 0.9878811887189864], 
            Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11835294330270157`, -1.5885129248386511`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11835294330270157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5885129248386511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632907`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[0.11835294330270157`, -1.5885129248386511`], 
            Complex[1.1203935961632907`, -3.051942680547835]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.259945596892496, -1.58851292483865}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.259945596892496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58851292483865`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.259945596892496, -1.58851292483865], 
            Complex[1.1203935961632925`, -3.051942680547835]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.181376195232895, -0.2182553516597405}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[2.181376195232895, -0.2182553516597405], 
            Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.322968848822688, -0.21825535165974055`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[5.322968848822688, -0.21825535165974055`], 
            Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.486767518902965, 0.0511974018142995}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.486767518902965, 0.0511974018142995], 
            Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.345174865313174, 0.0511974018142957}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.345174865313174, 0.0511974018142957], 
            Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32740825352173, -1.000483060574067}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.32740825352173, -1.000483060574067], 
            Complex[7.6190673329092, -2.105552017907876]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{6.185815599931938, -1.000483060574068}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.185815599931938, -1.000483060574068], 
            Complex[7.619067332909202, -2.105552017907877]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308767386428746, 0.9923138310722672}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.308767386428746, 0.9923138310722672], 
            Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167174732838952, 0.992313831072267}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.167174732838952, 0.992313831072267], 
            Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11772707887238294`, -1.5910744653534168`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11772707887238294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5910744653534168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1191698651599729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0544879322086085`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[0.11772707887238294`, -1.5910744653534168`], 
            Complex[1.1191698651599729`, -3.0544879322086085`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2593197324621768`, -1.5910744653534166`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2593197324621768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5910744653534166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.119169865159973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.054487932208608`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.2593197324621768`, -1.5910744653534166`], 
            Complex[1.119169865159973, -3.054487932208608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.334147593347899, -0.21885330570991693`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[5.334147593347899, -0.21885330570991693`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1925549397581063`, -0.21885330570991673`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[2.1925549397581063`, -0.21885330570991673`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.476510326898408, 0.05271666771536847}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.476510326898408, 0.05271666771536847], 
            Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3349176733086154`, 0.052716667715368405`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.3349176733086154`, 0.052716667715368405`], 
            Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185742780764412, -1.004877451924907}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.185742780764412, -1.004877451924907], 
            Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327335434354206, -1.0048774519249142`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.327335434354206, -1.0048774519249142`], 
            Complex[7.618879068115525, -2.109509448113651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167194592496085, 0.9967040073387544}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.167194592496085, 0.9967040073387544], 
            Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30878724608588, 0.9967040073387546}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.30878724608588, 0.9967040073387546], 
            Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11710782416143134`, -1.593620561871549}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11710782416143134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.593620561871549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0570192823251907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[0.11710782416143134`, -1.593620561871549], 
            Complex[1.1179546144330925`, -3.0570192823251907`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.258700477751228, -1.5936205618715453`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258700477751228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5936205618715453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.057019282325188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.258700477751228, -1.5936205618715453`], 
            Complex[1.1179546144330978`, -3.057019282325188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.34544091125561, -0.21954386620430968`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[5.34544091125561, -0.21954386620430968`], 
            Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2038482576658165`, -0.2195438662043097}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[2.2038482576658165`, -0.2195438662043097], 
            Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3245411337774544`, 0.05431892219952697}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.3245411337774544`, 0.05431892219952697], 
            Complex[4.70854473004717, -1.130085166709498]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.466133787367247, 0.05431892219952709}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.466133787367247, 0.05431892219952709], 
            Complex[4.70854473004717, -1.130085166709498]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185671004827051, -1.0092301787755908`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.185671004827051, -1.0092301787755908`], 
            Complex[7.618692192411457, -2.113427630566214]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327263658416845, -1.009230178775591}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.327263658416845, -1.009230178775591], 
            Complex[7.618692192411457, -2.113427630566214]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167213819234735, 1.0010525529976395`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.167213819234735, 1.0010525529976395`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308806472824529, 1.0010525529976397`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.308806472824529, 1.0010525529976397`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1164950709944641, -1.596151405467845}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1164950709944641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.596151405467845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[0.1164950709944641, -1.596151405467845], 
            Complex[1.1167477249791702`, -3.0595369015792553`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.258087724584257, -1.5961514054678452`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258087724584257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5961514054678452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.258087724584257, -1.5961514054678452`], 
            Complex[1.1167477249791709`, -3.0595369015792553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2152615870464745`, -0.2203339164903331}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[2.2152615870464745`, -0.2203339164903331], 
            Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.356854240636268, -0.2203339164903332}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[5.356854240636268, -0.2203339164903332], 
            Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.314039845823023, 0.05601119898888117}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.314039845823023, 0.05601119898888117], 
            Complex[4.696326724353138, -1.12850882102276]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.4556324994128165`, 0.05601119898888104}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.4556324994128165`, 0.05601119898888104], 
            Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327192898160455, -1.013542052044059}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.327192898160455, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18560024457066, -1.013542052044059}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.18560024457066, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308825088355581, 1.0053602784840994`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.308825088355581, 1.0053602784840994`], 
            Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16723243476579, 1.005360278484099}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.16723243476579, 1.005360278484099], 
            Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11588871363063293`, -1.5986671835961561`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11588871363063293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0620409573801792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[0.11588871363063293`, -1.5986671835961561`], 
            Complex[1.115549080307041, -3.0620409573801792`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.257481367220427, -1.5986671835961581`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.257481367220427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.062040957380181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.257481367220427, -1.5986671835961581`], 
            Complex[1.115549080307043, -3.062040957380181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2268005544144556`, -0.22123113894674887`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[2.2268005544144556`, -0.22123113894674887`], 
            Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.36839320800425, -0.2212311389467491}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[5.36839320800425, -0.2212311389467491], 
            Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.445000873427293, 0.05780132763801389}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.445000873427293, 0.05780132763801389], 
            Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3034082198375003`, 0.05780132763801396}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.3034082198375003`, 0.05780132763801396], 
            Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185530473503019, -1.017813858605525}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.185530473503019, -1.017813858605525], 
            Complex[7.618322479547935, -2.121149303624121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327123127092824, -1.0178138586055234`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.327123127092824, -1.0178138586055234`], 
            Complex[7.618322479547946, -2.12114930362412]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308843113455703, 1.0096279702007276`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.308843113455703, 1.0096279702007276`], 
            Complex[7.622275519945756, -0.236216870343528]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16725045986591, 1.0096279702007271`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.16725045986591, 1.0096279702007271`], 
            Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.256881302283198, -1.60116808018249}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.256881302283198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60116808018249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1143585663674842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.064531613950414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.256881302283198, -1.60116808018249], 
            Complex[1.1143585663674842`, -3.064531613950414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.11528864869340531`, -1.6011680801824892`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11528864869340531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6011680801824892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.114358566367485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0645316139504137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[0.11528864869340531`, -1.6011680801824892`], 
            Complex[1.114358566367485, -3.0645316139504137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.380063608617472, -0.22224412353114406`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[5.380063608617472, -0.22224412353114406`], 
            Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.23847095502768, -0.2222441235311438}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[2.23847095502768, -0.2222441235311438], 
            Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.292640497180628, 0.059698042168788046`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.292640497180628, 0.059698042168788046`], 
            Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.434233150770422, 0.05969804216878785}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.434233150770422, 0.05969804216878785], 
            Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185461666136161, -1.0220463622527831`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.185461666136161, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.327054319725956, -1.0220463622527831`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.327054319725956, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167267914426828, 1.013856391477559}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.167267914426828, 1.013856391477559], 
            Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308860568016621, 1.0138563914775585`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.308860568016621, 1.0138563914775585`], 
            Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11469477510277208`, -1.603654275715108}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11469477510277208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.603654275715108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408055`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[0.11469477510277208`, -1.603654275715108], 
            Complex[1.1131760714852184`, -3.067009032408055]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2562874286925667`, -1.603654275715105}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2562874286925667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.603654275715105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2562874286925667`, -1.603654275715105], 
            Complex[1.1131760714852224`, -3.067009032408053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.39187137537774, -0.22338249250843517`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[5.39187137537774, -0.22338249250843517`], 
            Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.250278721787946, -0.22338249250843553`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[2.250278721787946, -0.22338249250843553`], 
            Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.423323434867788, 0.061711105883242766`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.423323434867788, 0.061711105883242766`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2817307812779952`, 0.061711105883242925`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2817307812779952`, 0.061711105883242925`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185393797936859, -1.0262403046082502`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.185393797936859, -1.0262403046082502`], 
            Complex[7.617957948303616, -2.128722917140586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326986451526654, -1.0262403046082496`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.326986451526654, -1.0262403046082496`], 
            Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308877471091341, 1.0180462834838366`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.308877471091341, 1.0180462834838366`], 
            Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167284817501548, 1.0180462834838364`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.167284817501548, 1.0180462834838364`], 
            Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.255699647599667, -1.606125947331712}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.255699647599667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.606125947331712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1120014862933134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.255699647599667, -1.606125947331712], 
            Complex[1.1120014862933134`, -3.06947337084671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.11410699400987415`, -1.6061259473317113`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11410699400987415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6061259473317113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.112001486293314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[0.11410699400987415`, -1.6061259473317113`], 
            Complex[1.112001486293314, -3.06947337084671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.403822532373675, -0.2246570435317341}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[5.403822532373675, -0.2246570435317341], 
            Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2622298787838817`, -0.2246570435317342}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[2.2622298787838817`, -0.2246570435317342], 
            Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.412265737666768, 0.06385145452602968}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.412265737666768, 0.06385145452602968], 
            Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.270673084076976, 0.06385145452602974}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.270673084076976, 0.06385145452602974], 
            Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185326845280091, -1.030396405990655}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.185326845280091, -1.030396405990655], 
            Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326919498869884, -1.030396405990655}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.326919498869884, -1.030396405990655], 
            Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308893840937472, 1.0221983660944407`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.308893840937472, 1.0221983660944407`], 
            Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167301187347679, 1.0221983660944405`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.167301187347679, 1.0221983660944405`], 
            Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11352520873386833`, -1.608583268903826}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11352520873386833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.608583268903826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[0.11352520873386833`, -1.608583268903826], 
            Complex[1.1108347036697903`, -3.0719247844127584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2551178623236616`, -1.6085832689038237`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2551178623236616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6085832689038237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2551178623236616`, -1.6085832689038237`], 
            Complex[1.1108347036697925`, -3.0719247844127553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.274330474286138, -0.22607991328743204`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[2.274330474286138, -0.22607991328743204`], 
            Complex[3.49540764739327, -1.538992497237254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.415923127875931, -0.22607991328743238`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[5.415923127875931, -0.22607991328743238`], 
            Complex[3.49540764739327, -1.538992497237254]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2594613930506555`, 0.06613136000835836}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2594613930506555`, 0.06613136000835836], 
            Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.401054046640449, 0.06613136000835822}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.401054046640449, 0.06613136000835822], 
            Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18526078540529, -1.034515366239107}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.18526078540529, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326853438995084, -1.034515366239107}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.326853438995084, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.3089096950579, 1.0263133387136967`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.3089096950579, 1.0263133387136967`], 
            Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167317041468107, 1.0263133387136971`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.167317041468107, 1.0263133387136971`], 
            Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1129493247010233, -1.611026411118455}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1129493247010233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[0.1129493247010233, -1.611026411118455], 
            Complex[1.1096756186764682`, -3.0743634253800933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.254541978290817, -1.611026411118455}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.254541978290817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.254541978290817, -1.611026411118455], 
            Complex[1.1096756186764698`, -3.0743634253800933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2865864863773204`, -0.2276647637711871}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[2.2865864863773204`, -0.2276647637711871], 
            Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.428179139967114, -0.22766476377118722`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[5.428179139967114, -0.22766476377118722`], 
            Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.389682419157071, 0.06856461676025156}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.389682419157071, 0.06856461676025156], 
            Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2480897655672782`, 0.06856461676025145}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.2480897655672782`, 0.06856461676025145], 
            Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185195596375154, -1.0385978654970505`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.185195596375154, -1.0385978654970505`], 
            Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326788249964949, -1.0385978654970531`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.326788249964949, -1.0385978654970531`], 
            Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30892505023899, 1.0303918810590929`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.30892505023899, 1.0303918810590929`], 
            Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167332396649198, 1.0303918810590926`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.167332396649198, 1.0303918810590926`], 
            Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11237924938587697`, -1.6134555415571996`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11237924938587697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.108524128499807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0767894432225034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[0.11237924938587697`, -1.6134555415571996`], 
            Complex[1.108524128499807, -3.0767894432225034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.253971902975671, -1.6134555415571998`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.253971902975671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1085241284998075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.076789443222504`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.253971902975671, -1.6134555415571998`], 
            Complex[1.1085241284998075`, -3.076789443222504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2990036923040837`, -0.2294269927942462}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[2.2990036923040837`, -0.2294269927942462], 
            Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.440596345893878, -0.22942699279424578`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[5.440596345893878, -0.22942699279424578`], 
            Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.378145113127533, 0.07116675231062962}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.378145113127533, 0.07116675231062962], 
            Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.23655245953774, 0.07116675231062944}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.23655245953774, 0.07116675231062944], 
            Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326723910626667, -1.042644564958483}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.326723910626667, -1.042644564958483], 
            Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185131257036874, -1.0426445649584837`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.185131257036874, -1.0426445649584837`], 
            Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30893992258648, 1.034434653907242}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.30893992258648, 1.034434653907242], 
            Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1673472689966875`, 1.0344346539072418`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.1673472689966875`, 1.0344346539072418`], 
            Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1118148922544208, -1.6158708247728453`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1118148922544208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[0.1118148922544208, -1.6158708247728453`], 
            Complex[1.1073801323937882`, -3.0792029846837004`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2534075458442144`, -1.6158708247728455`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2534075458442144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2534075458442144`, -1.6158708247728455`], 
            Complex[1.1073801323937882`, -3.0792029846837012`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.311587489979285, -0.23138396931833907`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[2.311587489979285, -0.23138396931833907`], 
            Complex[3.539668711719687, -1.54125837029078]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.453180143569079, -0.23138396931833927`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[5.453180143569079, -0.23138396931833927`], 
            Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.3664367655030105`, 0.07395526269357508}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.3664367655030105`, 0.07395526269357508], 
            Complex[4.591951242060748, -1.111090937656241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2248441119132174`, 0.07395526269357484}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2248441119132174`, 0.07395526269357484], 
            Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.185067746985585, -1.0466561075785734`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.185067746985585, -1.0466561075785734`], 
            Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32666040057538, -1.0466561075785734`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.32666040057538, -1.0466561075785734`], 
            Complex[7.617067825366967, -2.147044806353595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16736167396946, 1.0384422998042997`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.16736167396946, 1.0384422998042997`], 
            Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308954327559254, 1.0384422998042997`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.308954327559254, 1.0384422998042997`], 
            Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2528488182990007`, -1.6182724223635778`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2528488182990007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6182724223635778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.2528488182990007`, -1.6182724223635778`], 
            Complex[1.1062435316246895`, -3.0816041938451617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.11125616470920796`, -1.6182724223635776`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11125616470920796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6182724223635776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[0.11125616470920796`, -1.6182724223635776`], 
            Complex[1.1062435316246904`, -3.0816041938451617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.324342656755631, -0.2335552923600304}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[2.324342656755631, -0.2335552923600304], 
            Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.465935310345424, -0.23355529236003053`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[5.465935310345424, -0.23355529236003053`], 
            Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.212959979911501, 0.07694987142173919}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.212959979911501, 0.07694987142173919], 
            Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.354552633501294, 0.07694987142174026}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.354552633501294, 0.07694987142174026], 
            Complex[4.577957240848536, -1.108080936651698]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326597700119693, -1.0506331187508058`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.326597700119693, -1.0506331187508058`], 
            Complex[7.616893231354067, -2.150609297664497]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1850050465299, -1.0506331187508056`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.1850050465299, -1.0506331187508056`], 
            Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167375626411306, 1.0424154437428594`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.167375626411306, 1.0424154437428594`], 
            Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308968280001098, 1.042415443742859}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.308968280001098, 1.042415443742859], 
            Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.252295633626107, -1.620660493044881}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.252295633626107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.620660493044881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.105114229417701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.252295633626107, -1.620660493044881], 
            Complex[1.105114229417701, -3.0839932121918214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.110702980036313, -1.6206604930448811`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.110702980036313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6206604930448811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1051142294177012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[0.110702980036313, -1.6206604930448811`], 
            Complex[1.1051142294177012`, -3.0839932121918214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3372730266129884`, -0.2359630690132302}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[2.3372730266129884`, -0.2359630690132302], 
            Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.478865680202783, -0.23596306901323125`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[5.478865680202783, -0.23596306901323125`], 
            Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.342488917419652, 0.08017280757570108}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.342488917419652, 0.08017280757570108], 
            Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.20089626382986, 0.0801728075757009}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.20089626382986, 0.0801728075757009], 
            Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184943136659399, -1.0545762069524705`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.184943136659399, -1.0545762069524705`], 
            Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326535790249194, -1.0545762069524702`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.326535790249194, -1.0545762069524702`], 
            Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167389140580846, 1.04635469380724}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.167389140580846, 1.04635469380724], 
            Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30898179417064, 1.04635469380724}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.30898179417064, 1.04635469380724], 
            Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.11015525335407254`, -1.6230351927192315`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11015525335407254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1039921309052896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0863701786757147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[0.11015525335407254`, -1.6230351927192315`], 
            Complex[1.1039921309052896`, -3.0863701786757147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.251747906943866, -1.6230351927192315`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.251747906943866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.10399213090529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.086370178675715`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.251747906943866, -1.6230351927192315`], 
            Complex[1.10399213090529, -3.086370178675715]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3503810623577226`, -0.23863220192231419`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[2.3503810623577226`, -0.23863220192231419`], 
            Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.491973715947518, -0.2386322019223144}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[5.491973715947518, -0.2386322019223144], 
            Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.330243188435803, 0.08364909334179328}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.330243188435803, 0.08364909334179328], 
            Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.18865053484601, 0.08364909334179278}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.18865053484601, 0.08364909334179278], 
            Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1848819990139186`, -1.0584859643603293`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.1848819990139186`, -1.0584859643603293`], 
            Complex[7.616547285902736, -2.157643104664951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326474652603713, -1.058485964360329}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.326474652603713, -1.058485964360329], 
            Complex[7.616547285902738, -2.157643104664951]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167402230179722, 1.0502606417889433`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.167402230179722, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.308994883769515, 1.0502606417889433`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.308994883769515, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1096129015635269, -1.6253966745436466`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1096129015635269`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6253966745436466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.102877143077272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0887352297776527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[0.1096129015635269, -1.6253966745436466`], 
            Complex[1.102877143077272, -3.0887352297776527`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.25120555515332, -1.6253966745436454`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.25120555515332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6253966745436454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1028771430772724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0887352297776514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.25120555515332, -1.6253966745436454`], 
            Complex[1.1028771430772724`, -3.0887352297776514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3636672947096224`, -0.24159066834690415`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[2.3636672947096224`, -0.24159066834690415`], 
            Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.5052599482994165`, -0.2415906683469046}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[5.5052599482994165`, -0.2415906683469046], 
            Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.176222295931689, 0.08740682313953917}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.176222295931689, 0.08740682313953917], 
            Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.317814949521482, 0.08740682313953926}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.317814949521482, 0.08740682313953926], 
            Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184821615854545, -1.062362967438099}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.184821615854545, -1.062362967438099], 
            Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326414269444339, -1.0623629674380988`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.326414269444339, -1.0623629674380988`], 
            Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167414908379169, 1.054133863773935}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.167414908379169, 1.054133863773935], 
            Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309007561968963, 1.0541338637739348`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.309007561968963, 1.0541338637739348`], 
            Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10907584330050497`, -1.6277450889951857`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10907584330050497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.091088499566983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[0.10907584330050497`, -1.6277450889951857`], 
            Complex[1.1017691747325018`, -3.091088499566983]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.250668496890299, -1.6277450889951866`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.250668496890299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0910884995669843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.250668496890299, -1.6277450889951866`], 
            Complex[1.1017691747325018`, -3.0910884995669843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3771295961517165`, -0.24486976056502352`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[2.3771295961517165`, -0.24486976056502352`], 
            Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.518722249741511, -0.24486976056502427`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[5.518722249741511, -0.24486976056502427`], 
            Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.30520636159325, 0.09147740408549994}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.30520636159325, 0.09147740408549994], 
            Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1636137080034565`, 0.09147740408549974}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.1636137080034565`, 0.09147740408549974], 
            Complex[4.519597775965093, -1.093160763626926]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184761970036191, -1.0662077774973115`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.184761970036191, -1.0662077774973115`], 
            Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326354623625987, -1.0662077774973113`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.326354623625987, -1.0662077774973113`], 
            Complex[7.616205519626703, -2.164553676487631]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309019841434887, 1.0579749207033116`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.309019841434887, 1.0579749207033116`], 
            Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167427187845094, 1.0579749207033107`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.167427187845094, 1.0579749207033107`], 
            Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2501366524790782`, -1.6300805839344696`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2501366524790782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6300805839344696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.093430119759536`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.2501366524790782`, -1.6300805839344696`], 
            Complex[1.1006681364321238`, -3.093430119759536]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10854399888928548`, -1.6300805839344692`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10854399888928548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6300805839344692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0934301197595353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[0.10854399888928548`, -1.6300805839344692`], 
            Complex[1.1006681364321256`, -3.0934301197595353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3907622559358295`, -0.24850423935263424`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[2.3907622559358295`, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.532354909525623, -0.24850423935263424`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[5.532354909525623, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1508305149179034`, 0.09589570953158899}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.1508305149179034`, 0.09589570953158899], 
            Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.292423168507697, 0.09589570953158878}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.292423168507697, 0.09589570953158878], 
            Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326295698571451, -1.0700209412330057`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.326295698571451, -1.0700209412330057`], 
            Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184703044981658, -1.070020941233001}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.184703044981658, -1.070020941233001], 
            Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309031734351517, 1.0617843589087967`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.309031734351517, 1.0617843589087967`], 
            Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167439080761725, 1.061784358908797}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.167439080761725, 1.061784358908797], 
            Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2496099438875583`, -1.6324033046672912`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2496099438875583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6324033046672912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.2496099438875583`, -1.6324033046672912`], 
            Complex[1.0995739404543334`, -3.095760219773794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10801729029776416`, -1.6324033046672906`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10801729029776416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6324033046672906`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[0.10801729029776416`, -1.6324033046672906`], 
            Complex[1.0995739404543337`, -3.095760219773794]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.404554826889628, -0.25253232740394693`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[2.404554826889628, -0.25253232740394693`], 
            Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.546147480479421, -0.25253232740394727`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[5.546147480479421, -0.25253232740394727`], 
            Complex[3.650990035081118, -1.556521435684903]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.137883196665494, 0.10070007254234226`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.137883196665494, 0.10070007254234226`], 
            Complex[4.488987856730723, -1.083460700125328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.279475850255287, 0.10070007254234241`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.279475850255287, 0.10070007254234241`], 
            Complex[4.488987856730723, -1.083460700125328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184644824657079, -1.07380299123558}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.184644824657079, -1.07380299123558], 
            Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326237478246874, -1.0738029912355802`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.326237478246874, -1.0738029912355802`], 
            Complex[7.615867768792523, -2.171345211914303]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309043252443763, 1.0655627106244419`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.309043252443763, 1.0655627106244419`], 
            Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167450598853971, 1.065562710624442}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.167450598853971, 1.065562710624442], 
            Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2490882946838866`, -1.6347133940043952`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2490882946838866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6347133940043952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0984865007505693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.098078926785381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.2490882946838866`, -1.6347133940043952`], 
            Complex[1.0984865007505693`, -3.098078926785381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10749564109409336`, -1.6347133940043936`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10749564109409336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6347133940043936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09848650075057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.09807892678538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[0.10749564109409336`, -1.6347133940043936`], 
            Complex[1.09848650075057, -3.09807892678538]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4184907299124174`, -0.2569954375693104}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[2.4184907299124174`, -0.2569954375693104], 
            Complex[3.66780561916792, -1.560366273382241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.560083383502212, -0.2569954375693105}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[5.560083383502212, -0.2569954375693105], 
            Complex[3.667805619167921, -1.560366273382241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.124788364875778, 0.1059320141880026}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.124788364875778, 0.1059320141880026], 
            Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.266381018465571, 0.10593201418800262`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.266381018465571, 0.10593201418800262`], 
            Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326179947138467, -1.077554446480185}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.326179947138467, -1.077554446480185], 
            Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184587293548676, -1.0775544464801792`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.184587293548676, -1.0775544464801792`], 
            Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309054406998325, 1.069310494475782}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.309054406998325, 1.069310494475782], 
            Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167461753408532, 1.069310494475782}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.167461753408532, 1.069310494475782], 
            Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2485716299944873`, -1.6370109923194756`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2485716299944873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1003863657798956`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.2485716299944873`, -1.6370109923194756`], 
            Complex[1.0974057329031106`, -3.1003863657798956`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10697897640469432`, -1.6370109923194756`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10697897640469432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.100386365779895`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[0.10697897640469432`, -1.6370109923194756`], 
            Complex[1.0974057329031108`, -3.100386365779895]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.5741382895514295`, -0.26193749411720274`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[5.5741382895514295`, -0.26193749411720274`], 
            Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4325456359616355`, -0.26193749411720374`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[2.4325456359616355`, -0.26193749411720374`], 
            Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1115703808320068`, 0.11163556486001101`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.1115703808320068`, 0.11163556486001101`], 
            Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.2531630344218, 0.11163556486001082`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.2531630344218, 0.11163556486001082`], 
            Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1845304366407206`, -1.081275812794643}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.1845304366407206`, -1.081275812794643], 
            Complex[7.615533879590611, -2.17802169538267]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.326123090230514, -1.0812758127946427`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.326123090230514, -1.0812758127946427`], 
            Complex[7.615533879590611, -2.17802169538267]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167472555293864, 1.0730282159476652`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.167472555293864, 1.0730282159476652`], 
            Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309065208883657, 1.0730282159476647`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.309065208883657, 1.0730282159476647`], 
            Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1064672228736436, -1.6392962376054825`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1064672228736436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6392962376054825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[0.1064672228736436, -1.6392962376054825`], 
            Complex[1.0963315540840044`, -3.1026826596041883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.248059876463437, -1.6392962376054834`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.248059876463437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6392962376054834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.248059876463437, -1.6392962376054834`], 
            Complex[1.0963315540840044`, -3.1026826596041888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.5882783610426285`, -0.267403671805992}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[5.5882783610426285`, -0.267403671805992], 
            Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4466857074528354`, -0.2674036718059935}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[2.4466857074528354`, -0.2674036718059935], 
            Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.098263114072366, 0.11785600339463051`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.098263114072366, 0.11785600339463051`], 
            Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.23985576766216, 0.11785600339462998`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.23985576766216, 0.11785600339462998`], 
            Complex[4.44156860245767, -1.065050990167949]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32606689298445, -1.0849675833073058`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.32606689298445, -1.0849675833073058`], 
            Complex[7.61536833755189, -2.181317982768311]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184474239394659, -1.0849675833073054`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.184474239394659, -1.0849675833073054`], 
            Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30907566856886, 1.076716367831864}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.30907566856886, 1.076716367831864], 
            Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1674830149790685`, 1.0767163678318639`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.1674830149790685`, 1.0767163678318639`], 
            Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10596030862333504`, -1.64156926552927}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10596030862333504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0952638830152697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.104967929016111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[0.10596030862333504`, -1.64156926552927], 
            Complex[1.0952638830152697`, -3.104967929016111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2475529622131285`, -1.64156926552927}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2475529622131285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09526388301527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.104967929016112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.2475529622131285`, -1.64156926552927], 
            Complex[1.09526388301527, -3.104967929016112]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.602458533258957, -0.2734383645589251}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[5.602458533258957, -0.2734383645589251], 
            Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4608658796691665`, -0.2734383645589258}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[2.4608658796691665`, -0.2734383645589258], 
            Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.084911660981808, 0.1246378257982292}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.084911660981808, 0.1246378257982292], 
            Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.226504314571602, 0.12463782579822859`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.226504314571602, 0.12463782579822859`], 
            Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184418687729288, -1.0886302388755988`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.184418687729288, -1.0886302388755988`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32601134131908, -1.0886302388755993`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.32601134131908, -1.0886302388755993`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1674931425517565`, 1.08037543065552}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.1674931425517565`, 1.08037543065552], 
            Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309085796141549, 1.0803754306555196`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.309085796141549, 1.0803754306555196`], 
            Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10545816321639523`, -1.643830209484655}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10545816321639523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.643830209484655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1072422927328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[0.10545816321639523`, -1.643830209484655], 
            Complex[1.0942026399303617`, -3.1072422927328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2470508168061887`, -1.6438302094846542`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2470508168061887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6438302094846542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.107242292732799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.2470508168061887`, -1.6438302094846542`], 
            Complex[1.0942026399303626`, -3.107242292732799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.616621151226328, -0.2800822323034732}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[5.616621151226328, -0.2800822323034732], 
            Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4750284976365355`, -0.28008223230347307`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[2.4750284976365355`, -0.28008223230347307`], 
            Complex[3.736478521301466, -1.58190695616248]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.071573707918281, 0.1320217921353984}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.071573707918281, 0.1320217921353984], 
            Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.213166361508075, 0.13202179213539816`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.213166361508075, 0.13202179213539816`], 
            Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1843637680019645`, -1.092264248496479}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.1843637680019645`, -1.092264248496479], 
            Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325956421591757, -1.0922642484964793`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.325956421591757, -1.0922642484964793`], 
            Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309095601324776, 1.0840058730914168`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.309095601324776, 1.0840058730914168`], 
            Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167502947734983, 1.0840058730914166`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.167502947734983, 1.0840058730914166`], 
            Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2465533712085897`, -1.6460792006439566`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2465533712085897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6460792006439566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0931477465368076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.109505867477551`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.2465533712085897`, -1.6460792006439566`], 
            Complex[1.0931477465368076`, -3.109505867477551]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10496071761879634`, -1.646079200643956}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10496071761879634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.646079200643956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.093147746536808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.10950586747755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[0.10496071761879634`, -1.646079200643956], 
            Complex[1.093147746536808, -3.10950586747755]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4891027727434665`, -0.2873682998621285}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[2.4891027727434665`, -0.2873682998621285], 
            Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.6306954263332605`, -0.2873682998621296}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[5.6306954263332605`, -0.2873682998621296], 
            Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.199912728184141, 0.14004102546706554`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.199912728184141, 0.14004102546706554`], 
            Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0583200745943513`, 0.1400410254670661}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.0583200745943513`, 0.1400410254670661], 
            Complex[4.393335070431694, -1.040700701679103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325902120580537, -1.0958700696995949`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.325902120580537, -1.0958700696995949`], 
            Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1843094669907455`, -1.0958700696995953`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.1843094669907455`, -1.0958700696995953`], 
            Complex[7.614877115758213, -2.191044458598743]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309105093493066, 1.0876081523510002`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.309105093493066, 1.0876081523510002`], 
            Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167512439903273, 1.0876081523509995`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.167512439903273, 1.0876081523509995`], 
            Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10446790416412378`, -1.6483163680080417`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10446790416412378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6483163680080417`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259799997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1117587680253287`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[0.10446790416412378`, -1.6483163680080417`], 
            Complex[1.0920991259799997`, -3.1117587680253287`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2460605577539177`, -1.648316368008041}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2460605577539177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648316368008041`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259800008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.111758768025328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.2460605577539177`, -1.648316368008041], 
            Complex[1.0920991259800008`, -3.111758768025328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5030056270697787`, -0.29531732776612113`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[2.5030056270697787`, -0.29531732776612113`], 
            Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.644598280659573, -0.29531732776612096`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[5.644598280659573, -0.29531732776612096`], 
            Complex[3.770794613325991, -1.597089166697644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0452338697500734`, 0.14871638271009868`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.0452338697500734`, 0.14871638271009868`], 
            Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1868265233398665`, 0.1487163827100988}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.1868265233398665`, 0.1487163827100988], 
            Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325848425467212, -1.0994481489240884`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.325848425467212, -1.0994481489240884`], 
            Complex[7.614715122272777, -2.194233932689377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18425577187742, -1.0994481489240884`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.18425577187742, -1.0994481489240884`], 
            Complex[7.614715122272779, -2.194233932689377]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309114281687616, 1.0911827145610287`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.309114281687616, 1.0911827145610287`], 
            Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167521628097823, 1.0911827145610276`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.167521628097823, 1.0911827145610276`], 
            Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10397965651895658`, -1.65054183845496}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10397965651895658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.65054183845496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[0.10397965651895658`, -1.65054183845496], 
            Complex[1.0910567028080986`, -3.114001107246972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2455723101087495`, -1.6505418384549597`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2455723101087495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6505418384549597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.2455723101087495`, -1.6505418384549597`], 
            Complex[1.0910567028080993`, -3.114001107246972]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5166444532991594`, -0.3039330313949986}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[2.5166444532991594`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.6582371068889525`, -0.3039330313949986}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[5.6582371068889525`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1740003848318254`, 0.15805167382144575`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.1740003848318254`, 0.15805167382144575`], 
            Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.032407731242035, 0.1580516738214428}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.032407731242035, 0.1580516738214428], 
            Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.3257953238212, -1.1029989218798244`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.3257953238212, -1.1029989218798244`], 
            Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184202670231408, -1.1029989218798246`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.184202670231408, -1.1029989218798246`], 
            Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167530521040912, 1.0947299951246656`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.167530521040912, 1.0947299951246656`], 
            Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309123174630706, 1.0947299951246658`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.309123174630706, 1.0947299951246658`], 
            Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2450885632391073`, -1.6527557367871826`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2450885632391073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6527557367871826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.2450885632391073`, -1.6527557367871826`], 
            Complex[1.0900204029379934`, -3.116232996152112]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10349590964931504`, -1.652755736787182}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10349590964931504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.652755736787182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[0.10349590964931504`, -1.652755736787182], 
            Complex[1.0900204029379945`, -3.116232996152111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5299220300509884`, -0.31319809514055186`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[2.5299220300509884`, -0.31319809514055186`], 
            Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.671514683640783, -0.31319809514055214`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[5.671514683640783, -0.31319809514055214`], 
            Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.161531564303005, 0.16802967600526247`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.161531564303005, 0.16802967600526247`], 
            Complex[4.34645857273412, -1.009339964026806]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0199389107132126`, 0.16802967600526134`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.0199389107132126`, 0.16802967600526134`], 
            Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184150149994408, -1.1065228138938465`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.184150149994408, -1.1065228138938465`], 
            Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325742803584212, -1.1065228138938557`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.325742803584212, -1.1065228138938557`], 
            Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309131780739362, 1.098250419067798}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.309131780739362, 1.098250419067798], 
            Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167539127149569, 1.098250419067797}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.167539127149569, 1.098250419067797], 
            Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10301659978814422`, -1.6549581857775262`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10301659978814422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6549581857775262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0889901536222948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.118454543930881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[0.10301659978814422`, -1.6549581857775262`], 
            Complex[1.0889901536222948`, -3.118454543930881]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2446092533779374`, -1.6549581857775257`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2446092533779374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6549581857775257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.088990153622295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1184545439308806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.2446092533779374`, -1.6549581857775257`], 
            Complex[1.088990153622295, -3.1184545439308806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.684335924466961, -0.3230721172560274}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[5.684335924466961, -0.3230721172560274], 
            Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5427432708771702`, -0.3230721172560292}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[2.5427432708771702`, -0.3230721172560292], 
            Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.007922524597889, 0.17861007860412123`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.007922524597889, 0.17861007860412123`], 
            Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1495151781876825`, 0.1786100786041201}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.1495151781876825`, 0.1786100786041201], 
            Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325690853055608, -1.1100202402427715`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.325690853055608, -1.1100202402427715`], 
            Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.184098199465816, -1.1100202402427715`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.184098199465816, -1.1100202402427715`], 
            Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309140108138353, 1.1017444013712938`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.309140108138353, 1.1017444013712938`], 
            Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167547454548559, 1.1017444013712936`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.167547454548559, 1.1017444013712936`], 
            Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.1025416644037889, -1.6571493062137859`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1025416644037889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944393`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[0.1025416644037889, -1.6571493062137859`], 
            Complex[1.0879658834173156`, -3.1206658579944393`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2441343179935824`, -1.6571493062137856`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2441343179935824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944384`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[3.2441343179935824`, -1.6571493062137856`], 
            Complex[1.0879658834173163`, -3.1206658579944384`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5550227978429705`, -0.33349241406049857`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.5550227978429705`, -0.33349241406049857`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.696615451432764, -0.33349241406049873`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[5.696615451432764, -0.33349241406049873`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.996443980542599, 0.1897302873440814}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.996443980542599, 0.1897302873440814], 
            Complex[4.317427040750872, -0.984655324990569]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.138036634132392, 0.18973028734408198`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.138036634132392, 0.18973028734408198`], 
            Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1840468072888495`, -1.1134916064718126`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.1840468072888495`, -1.1134916064718126`], 
            Complex[7.614075476378116, -2.206739345003816]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325639460878643, -1.1134916064718128`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.325639460878643, -1.1134916064718128`], 
            Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309148164672497, 1.1052123472899034`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.309148164672497, 1.1052123472899034`], 
            Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167555511082704, 1.1052123472899034`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.167555511082704, 1.1052123472899034`], 
            Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10207104216942726`, -1.6593292169421239`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10207104216942726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.122867044014348`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[0.10207104216942726`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.122867044014348]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2436636957592206`, -1.6593292169421239`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2436636957592206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1228670440143484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[3.2436636957592206`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.1228670440143484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5666918389490667`, -0.3443779449095298}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.5666918389490667`, -0.3443779449095298], 
            Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.708284492538861, -0.3443779449095292}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[5.708284492538861, -0.3443779449095292], 
            Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.127164733575719, 0.20130934934495107`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.127164733575719, 0.20130934934495107`], 
            Complex[4.303885430470007, -0.971377104797332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9855720799859258`, 0.20130934934494918`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.9855720799859258`, 0.20130934934494918`], 
            Complex[4.303885430470007, -0.971377104797334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183995962437312, -1.1169373087010905`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.183995962437312, -1.1169373087010905`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325588616027105, -1.1169373087010908`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.325588616027105, -1.1169373087010908`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167563304328588, 1.1086546526584367`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.167563304328588, 1.1086546526584367`], 
            Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309155957918382, 1.1086546526584367`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.309155957918382, 1.1086546526584367`], 
            Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2431973265232212`, -1.6614980349092643`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2431973265232212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6614980349092643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[3.2431973265232212`, -1.6614980349092643`], 
            Complex[1.0859350008978244`, -3.1250582059608574`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10160467293342826`, -1.6614980349092632`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10160467293342826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6614980349092632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[0.10160467293342826`, -1.6614980349092632`], 
            Complex[1.0859350008978255`, -3.1250582059608565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5777029731444694`, -0.35563571212946193`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.5777029731444694`, -0.35563571212946193`], 
            Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.719295626734264, -0.3556357121294631}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[5.719295626734264, -0.3556357121294631], 
            Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1169469267372625`, 0.21325435309295884`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.1169469267372625`, 0.21325435309295884`], 
            Complex[4.291086318485069, -0.957611110502011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9753542731474694`, 0.21325435309295854`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.9753542731474694`, 0.21325435309295854`], 
            Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183945654203009, -1.1203577339198187`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.183945654203009, -1.1203577339198187`], 
            Complex[7.613760450846203, -2.212845969284587]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325538307792803, -1.1203577339198192`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.325538307792803, -1.1203577339198192`], 
            Complex[7.613760450846203, -2.212845969284587]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16757084160569, 1.1120717041858348`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.16757084160569, 1.1120717041858348`], 
            Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309163495195484, 1.112071704185835}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.309163495195484, 1.112071704185835], 
            Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.242735151280391, -1.6636558752035226`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.242735151280391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.084928251939455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.127239446140108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[3.242735151280391, -1.6636558752035226`], 
            Complex[1.084928251939455, -3.127239446140108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10114249769059809`, -1.6636558752035224`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10114249769059809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0849282519394552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1272394461401083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[0.10114249769059809`, -1.6636558752035224`], 
            Complex[1.0849282519394552`, -3.1272394461401083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.729624504719875, -0.3671682712416461}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[5.729624504719875, -0.3671682712416461], 
            Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.588031851130083, -0.3671682712416466}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.588031851130083, -0.3671682712416466], 
            Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.965814938226205, 0.22546793870233256`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.965814938226205, 0.22546793870233256`], 
            Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.107407591815999, 0.22546793870233275`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.107407591815999, 0.22546793870233275`], 
            Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1838958721837285`, -1.1237532602689642`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.1838958721837285`, -1.1237532602689642`], 
            Complex[7.613604090254429, -2.215864050835693]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325488525773522, -1.1237532602689644`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.325488525773522, -1.1237532602689644`], 
            Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309170783576755, 1.11546387973771}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.309170783576755, 1.11546387973771], 
            Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167578129986962, 1.1154638797377099`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.167578129986962, 1.1154638797377099`], 
            Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2422771121440808`, -1.6658028510947214`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2422771121440808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6658028510947214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303243`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[3.2422771121440808`, -1.6658028510947214`], 
            Complex[1.083927208746434, -3.1294108652303243`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.10068445855428786`, -1.6658028510947218`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10068445855428786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6658028510947218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[0.10068445855428786`, -1.6658028510947218`], 
            Complex[1.083927208746434, -3.1294108652303256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5976759196164494`, -0.3788808057418005}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.5976759196164494`, -0.3788808057418005], 
            Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.7392685732062425`, -0.37888080574180155`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[5.7392685732062425`, -0.37888080574180155`], 
            Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.098549310734496, 0.2378553727309036}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.098549310734496, 0.2378553727309036], 
            Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9569566571447035`, 0.2378553727309031}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.9569566571447035`, 0.2378553727309031], 
            Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1838466062718, -1.1271242573129145`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.1838466062718, -1.1271242573129145`], 
            Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325439259861593, -1.1271242573129148`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.325439259861593, -1.1271242573129148`], 
            Complex[7.613448480758017, -2.218859114308414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309177829898688, 1.118831548607897}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.309177829898688, 1.118831548607897], 
            Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167585176308896, 1.1188315486078975`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.167585176308896, 1.1188315486078975`], 
            Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.10023049872932865`, -1.6679390740730153`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10023049872932865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6679390740730153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[0.10023049872932865`, -1.6679390740730153`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2418231523191214`, -1.6679390740730151`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2418231523191214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6679390740730151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[3.2418231523191214`, -1.6679390740730151`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.606650933262854, -0.3906866010723904}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.606650933262854, -0.3906866010723904], 
            Complex[3.901239519558195, -1.699101588537602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.748243586852646, -0.3906866010723917}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[5.748243586852646, -0.3906866010723917], 
            Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9487637036120304`, 0.25033002218771455`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.9487637036120304`, 0.25033002218771455`], 
            Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.0903563572018244`, 0.2503300221877129}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.0903563572018244`, 0.2503300221877129], 
            Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325390500232961, -1.1304710863006695`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.325390500232961, -1.1304710863006695`], 
            Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183797846643169, -1.1304710863006642`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.183797846643169, -1.1304710863006642`], 
            Complex[7.613293610009215, -2.221831501514852]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167591987181104, 1.1221750717795362`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.167591987181104, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309184640770896, 1.1221750717795362`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.309184640770896, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09978056248576549, -1.6700646538866686`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09978056248576549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[0.09978056248576549, -1.6700646538866686`], 
            Complex[1.0819419792941676`, -3.133724634927121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.241373216075559, -1.6700646538866692`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.241373216075559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927122`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[3.241373216075559, -1.6700646538866692`], 
            Complex[1.0819419792941676`, -3.133724634927122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.75657901938974, -0.4025104167837189}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[5.75657901938974, -0.4025104167837189], 
            Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6149863657999486`, -0.40251041678372024`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.6149863657999486`, -0.40251041678372024`], 
            Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.08279928559293, 0.26281672672835754`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.08279928559293, 0.26281672672835754`], 
            Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9412066320031385`, 0.2628167267283543}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.9412066320031385`, 0.2628167267283543], 
            Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183749583746966, -1.1337941004170402`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.183749583746966, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32534223733676, -1.1337941004170402`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.32534223733676, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309191222585227, 1.1254948021761624`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.309191222585227, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167598568995433, 1.1254948021761624`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.167598568995433, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09933459513336479, -1.6721796985788298`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09933459513336479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624695`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[0.09933459513336479, -1.6721796985788298`], 
            Complex[1.0809576656540323`, -3.1358671790624695`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.240927248723158, -1.6721796985788306`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240927248723158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[3.240927248723158, -1.6721796985788306`], 
            Complex[1.0809576656540323`, -3.1358671790624704`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.7643133844056464`, -0.4142898642644478}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[5.7643133844056464`, -0.4142898642644478], 
            Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6227207308158538`, -0.41428986426444875`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.6227207308158538`, -0.41428986426444875`], 
            Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.075839610164613, 0.27525317641875785`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.075839610164613, 0.27525317641875785`], 
            Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.93424695657482, 0.27525317641875774`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.93424695657482, 0.27525317641875774`], 
            Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183701808295563, -1.1370936450243205`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.183701808295563, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325294461885356, -1.1370936450243205`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.325294461885356, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167604927934658, 1.128791084903274}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.167604927934658, 1.128791084903274], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309197581524451, 1.1287910849032743`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.309197581524451, 1.1287910849032743`], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.240485196586656, -1.6742843145233057`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240485196586656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6742843145233057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0799788029662047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138000289232015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[3.240485196586656, -1.6742843145233057`], 
            Complex[1.0799788029662047`, -3.138000289232015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0988925429968627, -1.6742843145233064`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0988925429968627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6742843145233064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079978802966205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.138000289232016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[0.0988925429968627, -1.6742843145233064`], 
            Complex[1.079978802966205, -3.138000289232016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.771490138844717, -0.42597525546826004`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[5.771490138844717, -0.42597525546826004`], 
            Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.629897485254924, -0.42597525546826037`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.629897485254924, -0.42597525546826037`], 
            Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.927841247969024, 0.28758976049421764`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.927841247969024, 0.28758976049421764`], 
            Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.069433901558818, 0.2875897604942178}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.069433901558818, 0.2875897604942178], 
            Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183654511255059, -1.1403700578948637`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.183654511255059, -1.1403700578948637`], 
            Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325247164844853, -1.1403700578948632`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.325247164844853, -1.1403700578948632`], 
            Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16761106998075, 1.1320642574808064`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.16761106998075, 1.1320642574808064`], 
            Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309203723570544, 1.1320642574808066`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.309203723570544, 1.1320642574808066`], 
            Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09845435339193638, -1.6763786064594066`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09845435339193638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6763786064594066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0790053302264244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1401240584834467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[0.09845435339193638, -1.6763786064594066`], 
            Complex[1.0790053302264244`, -3.1401240584834467`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2400470069817295`, -1.6763786064594062`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2400470069817295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6763786064594062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079005330226425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.140124058483446`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[3.2400470069817295`, -1.6763786064594062`], 
            Complex[1.079005330226425, -3.140124058483446]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.778154476287738, -0.43752848511674675`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[5.778154476287738, -0.43752848511674675`], 
            Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.636561822697944, -0.4375284851167467}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.636561822697944, -0.4375284851167467], 
            Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.921944339934747, 0.2997884495937316}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.921944339934747, 0.2997884495937316], 
            Complex[4.222645506003507, -0.856274787217682]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.063536993524541, 0.2997884495937313}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.063536993524541, 0.2997884495937313], 
            Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183607683836199, -1.1436236694349755`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.183607683836199, -1.1436236694349755`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325200337425992, -1.1436236694349757`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.325200337425992, -1.1436236694349757`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167617000922771, 1.1353146500669256`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.167617000922771, 1.1353146500669256`], 
            Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309209654512566, 1.1353146500669253`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.309209654512566, 1.1353146500669253`], 
            Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2396126281916615`, -1.6784626775258558`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2396126281916615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6784626775258558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[3.2396126281916615`, -1.6784626775258558`], 
            Complex[1.0780371874612853`, -3.1422385784338522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09801997460186761, -1.6784626775258555`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09801997460186761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6784626775258555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[0.09801997460186761, -1.6784626775258555`], 
            Complex[1.0780371874612855`, -3.1422385784338505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.784351043372479, -0.448921436448157}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[5.784351043372479, -0.448921436448157], 
            Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6427583897826854`, -0.4489214364481581}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.6427583897826854`, -0.4489214364481581], 
            Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.058104266499389, 0.311821201539341}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.058104266499389, 0.311821201539341], 
            Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9165116129095963`, 0.31182120153934106`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.9165116129095963`, 0.31182120153934106`], 
            Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183561317485685, -1.1468548029005128`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.183561317485685, -1.1468548029005128`], 
            Complex[7.612529927102651, -2.236364734026166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325153971075487, -1.1468548029005257`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.325153971075487, -1.1468548029005257`], 
            Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167622726364391, 1.1385425856735312`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.167622726364391, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309215379954184, 1.1385425856735312`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.309215379954184, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09758935585487952, -1.6805366292938224`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09758935585487952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6805366292938224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1443439392995933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[0.09758935585487952, -1.6805366292938224`], 
            Complex[1.0770743157050577`, -3.1443439392995933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2391820094446726`, -1.6805366292938222`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2391820094446726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6805366292938222`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.144343939299593`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[3.2391820094446726`, -1.6805366292938222`], 
            Complex[1.0770743157050588`, -3.144343939299593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.648529805818011, -0.4601342612759221}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.648529805818011, -0.4601342612759221], 
            Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.790122459407805, -0.4601342612759226}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[5.790122459407805, -0.4601342612759226], 
            Complex[3.95661157787795, -1.77641239731018]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{6.053093127997606, 0.32366824142440104`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.053093127997606, 0.32366824142440104`], 
            Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.911500474407813, 0.323668241424401}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.911500474407813, 0.323668241424401], 
            Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325108057467666, -1.1500637746045623`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.325108057467666, -1.1500637746045623`], 
            Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183515403877874, -1.1500637746045628`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.183515403877874, -1.1500637746045628`], 
            Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309220905320853, 1.1417483803738433`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.309220905320853, 1.1417483803738433`], 
            Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1676282517310606`, 1.1417483803738426`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.1676282517310606`, 1.1417483803738426`], 
            Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2387551008919058`, -1.6826005617990878`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2387551008919058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6826005617990878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.076116656977162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1464402299253895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[3.2387551008919058`, -1.6826005617990878`], 
            Complex[1.076116656977162, -3.1464402299253895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09716244730211258, -1.682600561799087}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09716244730211258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.682600561799087`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0761166569771627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1464402299253886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[0.09716244730211258, -1.682600561799087], 
            Complex[1.0761166569771627`, -3.1464402299253886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.653915808537619, -0.4711537472500261}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.653915808537619, -0.4711537472500261], 
            Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.795508462127413, -0.4711537472500259}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[5.795508462127413, -0.4711537472500259], 
            Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.048463866858473, 0.3353164289039027}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.048463866858473, 0.3353164289039027], 
            Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.90687121326868, 0.33531642890390234`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.90687121326868, 0.33531642890390234`], 
            Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183469934906837, -1.1532508941175408`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.183469934906837, -1.1532508941175408`], 
            Complex[7.612229226993079, -2.242030438093195]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325062588496635, -1.1532508941175512`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.325062588496635, -1.1532508941175512`], 
            Complex[7.612229226993084, -2.242030438093204]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167633582276865, 1.1449323435024108`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.167633582276865, 1.1449323435024108`], 
            Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30922623586666, 1.1449323435024106`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.30922623586666, 1.1449323435024106`], 
            Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09673919999623987, -1.684654573573374}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09673919999623987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.684654573573374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0751641542602708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1485275378126323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[0.09673919999623987, -1.684654573573374], 
            Complex[1.0751641542602708`, -3.1485275378126323`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.238331853586033, -1.6846545735733742`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.238331853586033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6846545735733742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.075164154260271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.148527537812633`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[3.238331853586033, -1.6846545735733742`], 
            Complex[1.075164154260271, -3.148527537812633]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.800545503681592, -0.4819718787730359}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[5.800545503681592, -0.4819718787730359], 
            Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6589528500918, -0.48197187877303665`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.6589528500918, -0.48197187877303665`], 
            Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.044180057256696, 0.34675781913864817`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[6.044180057256696, 0.34675781913864817`], 
            Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9025874036669044`, 0.3467578191386486}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.9025874036669044`, 0.3467578191386486], 
            Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.325017556268538, -1.1564164644600665`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.325017556268538, -1.1564164644600665`], 
            Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183424902678746, -1.1564164644600665`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.183424902678746, -1.1564164644600665`], 
            Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167638723091055, 1.1480947778478905`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.167638723091055, 1.1480947778478905`], 
            Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30923137668085, 1.1480947778478905`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.30923137668085, 1.1480947778478905`], 
            Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0963195658706748, -1.6866987616748745`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0963195658706748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6866987616748745`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1506059491469687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[0.0963195658706748, -1.6866987616748745`], 
            Complex[1.0742167514790106`, -3.1506059491469687`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.237912219460468, -1.686698761674875}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237912219460468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.686698761674875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.15060594914697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[3.237912219460468, -1.686698761674875], 
            Complex[1.0742167514790106`, -3.15060594914697]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.805266648945746, -0.4925846278657947}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[5.805266648945746, -0.4925846278657947], 
            Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6636739953559614`, -0.49258462786579826`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.6636739953559614`, -0.49258462786579826`], 
            Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.04020866039606, 0.3579884536883503}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.04020866039606, 0.3579884536883503], 
            Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8986160068062667`, 0.3579884536883491}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.8986160068062667`, 0.3579884536883491], 
            Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324972953094393, -1.159560782288886}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.324972953094393, -1.159560782288886], 
            Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1833802995046, -1.1595607822888863`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.1833802995046, -1.1595607822888863`], 
            Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167643679104286, 1.1512359798388985`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.167643679104286, 1.1512359798388985`], 
            Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309236332694079, 1.151235979838898}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.309236332694079, 1.151235979838898], 
            Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09590349771937258, -1.688733221717992}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09590349771937258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.688733221717992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1526755488251643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[0.09590349771937258, -1.688733221717992], 
            Complex[1.0732743934792583`, -3.1526755488251643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.237496151309166, -1.6887332217179927`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237496151309166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6887332217179927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.152675548825165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[3.237496151309166, -1.6887332217179927`], 
            Complex[1.0732743934792588`, -3.152675548825165]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.809701663341314, -0.5029909709021079}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[5.809701663341314, -0.5029909709021079], 
            Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.668109009751523, -0.50299097090211}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.668109009751523, -0.50299097090211], 
            Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.036519936690694, 0.36900737727295657`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.036519936690694, 0.36900737727295657`], 
            Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8949272831009005`, 0.36900737727295585`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.8949272831009005`, 0.36900737727295585`], 
            Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183336117893254, -1.1626841380761952`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.183336117893254, -1.1626841380761952`], 
            Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32492877148305, -1.1626841380761932`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.32492877148305, -1.1626841380761932`], 
            Complex[7.611783032412532, -2.250378188362658]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167648455094579, 1.154356239723236}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.167648455094579, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309241108684372, 1.154356239723236}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.309241108684372, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.237083602766982, -1.6907580479023252`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237083602766982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0723370260079925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.154736420481273`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[3.237083602766982, -1.6907580479023252`], 
            Complex[1.0723370260079925`, -3.154736420481273]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09549094917718823, -1.6907580479023245`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09549094917718823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023245`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.072337026007993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1547364204812727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[0.09549094917718823, -1.6907580479023245`], 
            Complex[1.072337026007993, -3.1547364204812727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6722845561748567`, -0.5131921073476409}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.6722845561748567`, -0.5131921073476409], 
            Complex[3.989240598169983, -1.836139309119696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.81387720976465, -0.5131921073476412}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[5.81387720976465, -0.5131921073476412], 
            Complex[3.989240598169983, -1.836139309119696]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8914945952485174`, 0.37981585653752775`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.8914945952485174`, 0.37981585653752775`], 
            Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.033087248838311, 0.3798158565375278}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.033087248838311, 0.3798158565375278], 
            Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324885004134527, -1.165786816282607}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.324885004134527, -1.165786816282607], 
            Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183292350544735, -1.1657868162826117`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.183292350544735, -1.1657868162826117`], 
            Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167653055693024, 1.1574558417407834`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.167653055693024, 1.1574558417407834`], 
            Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309245709282818, 1.1574558417407832`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.309245709282818, 1.1574558417407832`], 
            Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2366745282905844`, -1.6927733330409118`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2366745282905844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6927733330409118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.071404595693708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[3.2366745282905844`, -1.6927733330409118`], 
            Complex[1.071404595693708, -3.156788646512134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09508187470079153, -1.6927733330409114`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09508187470079153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6927733330409114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0714045956937088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[0.09508187470079153, -1.6927733330409114`], 
            Complex[1.0714045956937088`, -3.156788646512134]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.817817100281683, -0.5231908494724428}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[5.817817100281683, -0.5231908494724428], 
            Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.67622444669189, -0.5231908494724435}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.67622444669189, -0.5231908494724435], 
            Complex[3.994762358551031, -1.847435309214209]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8882941565379943`, 0.3904167697900055}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.8882941565379943`, 0.3904167697900055], 
            Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.029886810127787, 0.39041676979000506`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.029886810127787, 0.39041676979000506`], 
            Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183248990343842, -1.1688690955240477`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.183248990343842, -1.1688690955240477`], 
            Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324841643933642, -1.168869095524045}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.324841643933642, -1.168869095524045], 
            Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309250138979012, 1.1605350642903134`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.309250138979012, 1.1605350642903134`], 
            Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16765748538922, 1.1605350642903134`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.16765748538922, 1.1605350642903134`], 
            Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09467622955009732, -1.6947791685877762`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09467622955009732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6947791685877762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1588323081022285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[0.09467622955009732, -1.6947791685877762`], 
            Complex[1.0704770500273406`, -3.1588323081022285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2362688831398905`, -1.694779168587776}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2362688831398905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.694779168587776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.158832308102228`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[3.2362688831398905`, -1.694779168587776], 
            Complex[1.0704770500273408`, -3.158832308102228]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.679949913999627, -0.5329911517598123}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.679949913999627, -0.5329911517598123], 
            Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.821542567589421, -0.5329911517598128}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[5.821542567589421, -0.5329911517598128], 
            Complex[4.000015848490729, -1.858517093091784]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8853047593900265`, 0.4008141364346624}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.8853047593900265`, 0.4008141364346624], 
            Complex[4.173308062162179, -0.735357851265334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.02689741297982, 0.40081413643466185`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.02689741297982, 0.40081413643466185`], 
            Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324798683943808, -1.1719312487328415`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.324798683943808, -1.1719312487328415`], 
            Complex[7.611342435457713, -2.258551532233558]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1832060303540155`, -1.171931248732845}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1832060303540155`, -1.171931248732845], 
            Complex[7.611342435457713, -2.258551532233561]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309254402126275, 1.1635941800905014`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.309254402126275, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1676617485364815`, 1.1635941800905014`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1676617485364815`, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0942739697702223, -1.6967756446647657`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0942739697702223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6967756446647657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.069554337343726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1608674852478877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[0.0942739697702223, -1.6967756446647657`], 
            Complex[1.069554337343726, -3.1608674852478877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.235866623360016, -1.6967756446647662`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.235866623360016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6967756446647662`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0695543373437264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1608674852478886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[3.235866623360016, -1.6967756446647662`], 
            Complex[1.0695543373437264`, -3.1608674852478886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.8250725348409, -0.5425977517885678}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[5.8250725348409, -0.5425977517885678], 
            Complex[4.00502375333401, -1.869388672925242]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.683479881251108, -0.5425977517885688}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.683479881251108, -0.5425977517885688], 
            Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8825075055343556`, 0.41101275787833075`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.8825075055343556`, 0.41101275787833075`], 
            Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.024100159124149, 0.4110127578783314}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.024100159124149, 0.4110127578783314], 
            Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183163463811437, -1.1749735433132202`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.183163463811437, -1.1749735433132202`], 
            Complex[7.611196771510031, -2.261238440302506]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324756117401245, -1.1749735433132202`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.324756117401245, -1.1749735433132202`], 
            Complex[7.611196771510045, -2.261238440302506]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309258502946614, 1.1666334563353578`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.309258502946614, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167665849356821, 1.1666334563353578`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.167665849356821, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2354677057637162`, -1.6987628500877325`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2354677057637162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6987628500877325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.068636406803538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.162894256780908`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[3.2354677057637162`, -1.6987628500877325`], 
            Complex[1.068636406803538, -3.162894256780908]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09387505217392343, -1.6987628500877328`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09387505217392343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6987628500877328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0686364068035386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1628942567809086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[0.09387505217392343, -1.6987628500877328`], 
            Complex[1.0686364068035386`, -3.1628942567809086`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6868312180069145`, -0.5520158986267104}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.6868312180069145`, -0.5520158986267104], 
            Complex[4.009806376364359, -1.880054831501801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.8284238715967085`, -0.5520158986267112}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[5.8284238715967085`, -0.5520158986267112], 
            Complex[4.009806376364359, -1.880054831501802]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.021478203650236, 0.4210179459473799}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.021478203650236, 0.4210179459473799], 
            Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8798855500604437`, 0.42101794594737985`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.8798855500604437`, 0.42101794594737985`], 
            Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324713937709186, -1.1779962412914933`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.324713937709186, -1.1779962412914933`], 
            Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183121284119393, -1.1779962412914966`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.183121284119393, -1.1779962412914966`], 
            Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30926244553551, 1.1696531548443287`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.30926244553551, 1.1696531548443287`], 
            Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167669791945717, 1.1696531548443287`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.167669791945717, 1.1696531548443287`], 
            Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09347943432451934, -1.700740872392058}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09347943432451934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.700740872392058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[0.09347943432451934, -1.700740872392058], 
            Complex[1.0677232083757218`, -3.1649127003915565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2350720879143124`, -1.7007408723920572`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2350720879143124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7007408723920572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[3.2350720879143124`, -1.7007408723920572`], 
            Complex[1.0677232083757224`, -3.1649127003915547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6900189760399855`, -0.5612511491377956}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.6900189760399855`, -0.5612511491377956], 
            Complex[4.01438190088909, -1.890520862682429]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.831611629629778, -0.5612511491377962}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[5.831611629629778, -0.5612511491377962], 
            Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8774238656148396`, 0.4308353192168015}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.8774238656148396`, 0.4308353192168015], 
            Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.019016519204634, 0.4308353192168009}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.019016519204634, 0.4308353192168009], 
            Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1830794848428505`, -1.180999599461101}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.1830794848428505`, -1.180999599461101], 
            Complex[7.610907194686489, -2.266557440612444]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324672138432646, -1.180999599461105}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.324672138432646, -1.180999599461105], 
            Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167673580276672, 1.1726535322072742`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.167673580276672, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309266233866467, 1.1726535322072742`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.309266233866467, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.234679728109072, -1.7027097978575507`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.234679728109072`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7027097978575507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1669228926510127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[3.234679728109072, -1.7027097978575507`], 
            Complex[1.0668146928203772`, -3.1669228926510127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0930870745192786, -1.7027097978575496`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0930870745192786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7027097978575496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.166922892651011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[0.0930870745192786, -1.7027097978575496`], 
            Complex[1.0668146928203786`, -3.166922892651011]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.693056602464925, -0.5703092165540393}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.693056602464925, -0.5703092165540393], 
            Complex[4.018766629721939, -1.900792375423005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.834649256054719, -0.5703092165540443}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[5.834649256054719, -0.5703092165540443], 
            Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.016701682863842, 0.4404706516054355}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.016701682863842, 0.4404706516054355], 
            Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8751090292740487`, 0.4404706516054349}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.8751090292740487`, 0.4404706516054349], 
            Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.183038059703257, -1.183983869522754}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.183038059703257, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32463071329305, -1.183983869522754}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.32463071329305, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309269871795374, 1.1756348399245429`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.309269871795374, 1.1756348399245429`], 
            Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167677218205581, 1.1756348399245424`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.167677218205581, 1.1756348399245424`], 
            Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0926979317732518, -1.7046697115327327`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0926979317732518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0659108116721088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.168924909033252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[0.0926979317732518, -1.7046697115327327`], 
            Complex[1.0659108116721088`, -3.168924909033252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2342905853630466`, -1.7046697115327338`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2342905853630466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.065910811672111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1689249090332523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[3.2342905853630466`, -1.7046697115327338`], 
            Complex[1.065910811672111, -3.1689249090332523`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.837548783508502, -0.5791958590266288}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[5.837548783508502, -0.5791958590266288], 
            Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.695956129918709, -0.5791958590266285}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.695956129918709, -0.5791958590266285], 
            Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8729290323659913`, 0.4499297609478434}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.8729290323659913`, 0.4499297609478434], 
            Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.014521685955785, 0.4499297609478434}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[6.014521685955785, 0.4499297609478434], 
            Complex[4.155898108440934, -0.675770415493782]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182997002573542, -1.1869492982198684`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.182997002573542, -1.1869492982198684`], 
            Complex[7.610619897990325, -2.271804947320256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324589656163337, -1.186949298219872}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.324589656163337, -1.186949298219872], 
            Complex[7.610619897990326, -2.271804947320259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167680709474919, 1.1785973245423345`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.167680709474919, 1.1785973245423345`], 
            Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309273363064712, 1.178597324542335}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.309273363064712, 1.178597324542335], 
            Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2339046193933325`, -1.7066206972585347`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2339046193933325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[3.2339046193933325`, -1.7066206972585347`], 
            Complex[1.0650115172238024`, -3.170918823936388]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09231196580353926, -1.7066206972585347`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09231196580353926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[0.09231196580353926, -1.7066206972585347`], 
            Complex[1.0650115172238028`, -3.170918823936388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.840320998393064, -0.5879167986060267}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[5.840320998393064, -0.5879167986060267], 
            Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.698728344803272, -0.5879167986060275}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.698728344803272, -0.5879167986060275], 
            Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8708731122295896`, 0.4592184279956057}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.8708731122295896`, 0.4592184279956057], 
            Complex[4.152955626516613, -0.664447166754532]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.012465765819384, 0.4592184279956062}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.012465765819384, 0.4592184279956062], 
            Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182956307473314, -1.1898961274694768`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.182956307473314, -1.1898961274694768`], 
            Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324548961063108, -1.18989612746948}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.324548961063108, -1.18989612746948], 
            Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1676840577177385`, 1.1815412277835526`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.1676840577177385`, 1.1815412277835526`], 
            Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309276711307533, 1.1815412277835524`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.309276711307533, 1.1815412277835524`], 
            Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2335217906037683`, -1.7085628376914088`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2335217906037683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7085628376914088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0641167625108199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[3.2335217906037683`, -1.7085628376914088`], 
            Complex[1.0641167625108199`, -3.1729047107034827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.09192913701397513, -1.7085628376914086`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09192913701397513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7085628376914086`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06411676251082`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[0.09192913701397513, -1.7085628376914086`], 
            Complex[1.06411676251082, -3.1729047107034827`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7013829352654026`, -0.5964776632911527}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.7013829352654026`, -0.5964776632911527], 
            Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.842975588855198, -0.5964776632911535}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[5.842975588855198, -0.5964776632911535], 
            Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8689316042370305`, 0.4683423384869718}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.8689316042370305`, 0.4683423384869718], 
            Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.010524257826831, 0.4683423384869708}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.010524257826831, 0.4683423384869708], 
            Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324508622154049, -1.1928245944888063`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.324508622154049, -1.1928245944888063`], 
            Complex[7.61033481839468, -2.276982807944708]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182915968564257, -1.1928245944888065`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.182915968564257, -1.1928245944888065`], 
            Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309279920051315, 1.18446678667431}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.309279920051315, 1.18446678667431], 
            Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167687266461523, 1.1844667866743102`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.167687266461523, 1.1844667866743102`], 
            Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09154940648022836, -1.7104962143258893`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09154940648022836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7104962143258893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.063226501295623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.174882641642858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[0.09154940648022836, -1.7104962143258893`], 
            Complex[1.063226501295623, -3.174882641642858]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2331420600700214`, -1.7104962143258888`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2331420600700214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7104962143258888`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0632265012956237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1748826416428573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[3.2331420600700214`, -1.7104962143258888`], 
            Complex[1.0632265012956237`, -3.1748826416428573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7039286208715065`, -0.6048839465011073}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.7039286208715065`, -0.6048839465011073], 
            Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.8455212744613, -0.6048839465011082}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[5.8455212744613, -0.6048839465011082], 
            Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.008688465710948, 0.47730704263853474`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.008688465710948, 0.47730704263853474`], 
            Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8670958121211547`, 0.477307042638535}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.8670958121211547`, 0.477307042638535], 
            Complex[4.147506625196923, -0.642348121441579]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1828759801456865`, -1.1957349319176866`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.1828759801456865`, -1.1957349319176866`], 
            Complex[7.610193091068048, -2.27954617871769]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32446863373548, -1.195734931917687}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.32446863373548, -1.195734931917687], 
            Complex[7.61019309106805, -2.2795461787176903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30928299272165, 1.1873742336662831`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.30928299272165, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167690339131856, 1.1873742336662831`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.167690339131856, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0911727359352858, -1.7124209075166128`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0911727359352858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7124209075166128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06234068805277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.176852688047909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[0.0911727359352858, -1.7124209075166128`], 
            Complex[1.06234068805277, -3.176852688047909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2327653895250794`, -1.712420907516613}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2327653895250794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.712420907516613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0623406880527706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1768526880479087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[3.2327653895250794`, -1.712420907516613], 
            Complex[1.0623406880527706`, -3.1768526880479087`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.84796591957802, -0.6131409796537515}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[5.84796591957802, -0.6131409796537515], 
            Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7063732659882276`, -0.613140979653751}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.7063732659882276`, -0.613140979653751], 
            Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8653578945969786`, 0.48611792774323803`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.8653578945969786`, 0.48611792774323803`], 
            Complex[4.144979724610491, -0.631560836108617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.006950548186772, 0.4861179277432377}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.006950548186772, 0.4861179277432377], 
            Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182836336650298, -1.1986273679369637`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.182836336650298, -1.1986273679369637`], 
            Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324428990240092, -1.1986273679369637`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.324428990240092, -1.1986273679369637`], 
            Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309285932645754, 1.1902637967550587`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.309285932645754, 1.1902637967550587`], 
            Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167693279055961, 1.1902637967550591`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.167693279055961, 1.1902637967550591`], 
            Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09079908775532702, -1.714336996499808}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09079908775532702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.714336996499808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[0.09079908775532702, -1.714336996499808], 
            Complex[1.0614592779543155`, -3.1788149202164435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.23239174134512, -1.7143369964998079`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23239174134512`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7143369964998079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[3.23239174134512, -1.7143369964998079`], 
            Complex[1.0614592779543162`, -3.1788149202164426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.708723978803601, -0.6212539145605391}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.708723978803601, -0.6212539145605391], 
            Complex[4.041793889306879, -1.958660288701135]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.850316632393395, -0.6212539145605389}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[5.850316632393395, -0.6212539145605389], 
            Complex[4.04179388930688, -1.958660288701135]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.0053034199324715`, 0.4947802005841794}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.0053034199324715`, 0.4947802005841794], 
            Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8637107663426793`, 0.49478020058417876`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.8637107663426793`, 0.49478020058417876`], 
            Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32438968622985, -1.201502126383065}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.32438968622985, -1.201502126383065], 
            Complex[7.609911224902993, -2.284622879275391]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182797032640057, -1.201502126383065}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.182797032640057, -1.201502126383065], 
            Complex[7.609911224902995, -2.284622879275391]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309288743055875, 1.193135699594645}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.309288743055875, 1.193135699594645], 
            Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167696089466082, 1.193135699594645}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.167696089466082, 1.193135699594645], 
            Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.09042842494596093, -1.7162445594142677`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09042842494596093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7162445594142677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.060582226855574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1807694074695387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[0.09042842494596093, -1.7162445594142677`], 
            Complex[1.060582226855574, -3.1807694074695387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2320210785357544`, -1.7162445594142668`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2320210785357544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7162445594142668`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0605822268555747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.180769407469538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[3.2320210785357544`, -1.7162445594142668`], 
            Complex[1.0605822268555747`, -3.180769407469538]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.852579851369116, -0.6292277131331433}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[5.852579851369116, -0.6292277131331433], 
            Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.710987197779323, -0.6292277131331433}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.710987197779323, -0.6292277131331433], 
            Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8621480115494466`, 0.503298877159704}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.8621480115494466`, 0.503298877159704], 
            Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.003740665139239, 0.5032988771597035}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.003740665139239, 0.5032988771597035], 
            Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182758062802262, -1.2043594268588764`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.182758062802262, -1.2043594268588764`], 
            Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324350716392056, -1.2043594268588769`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.324350716392056, -1.2043594268588769`], 
            Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309291427092525, 1.195990161608288}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.309291427092525, 1.195990161608288], 
            Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167698773502733, 1.1959901616082875`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.167698773502733, 1.1959901616082875`], 
            Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.231653364718622, -1.7181436733218398`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231653364718622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218398`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0597094912812492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1827162181699684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[3.231653364718622, -1.7181436733218398`], 
            Complex[1.0597094912812492`, -3.1827162181699684`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.090060711128834, -1.7181436733218531`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.090060711128834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.05970949128125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1827162181699844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[0.090060711128834, -1.7181436733218531`], 
            Complex[1.05970949128125, -3.1827162181699844`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.854761420740972, -0.637067142498334}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[5.854761420740972, -0.637067142498334], 
            Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7131687671511795`, -0.6370671424983351}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.7131687671511795`, -0.6370671424983351], 
            Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.0022564620129675`, 0.5116787778163029}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.0022564620129675`, 0.5116787778163029], 
            Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.860663808423174, 0.5116787778163023}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.860663808423174, 0.5116787778163023], 
            Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182719421945745, -1.2071994848410685`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.182719421945745, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324312075535536, -1.2071994848410685`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.324312075535536, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309293987807608, 1.1988273980957402`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.309293987807608, 1.1988273980957402`], 
            Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167701334217814, 1.19882739809574}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.167701334217814, 1.19882739809574], 
            Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08969591052854747, -1.7200344142274246`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08969591052854747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.058841028411909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.18465541974018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[0.08969591052854747, -1.7200344142274246`], 
            Complex[1.058841028411909, -3.18465541974018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.231288564118341, -1.7200344142274249`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231288564118341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0588410284119094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.184655419740182`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[3.231288564118341, -1.7200344142274249`], 
            Complex[1.0588410284119094`, -3.184655419740182]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.856866656504023, -0.6447767740762016}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[5.856866656504023, -0.6447767740762016], 
            Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.71527400291423, -0.6447767740762022}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.71527400291423, -0.6447767740762022], 
            Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8592528632013723`, 0.5199245263444046}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.8592528632013723`, 0.5199245263444046], 
            Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.000845516791171, 0.519924526344405}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.000845516791171, 0.519924526344405], 
            Complex[4.135993261432002, -0.5900329694879913]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1826811049972195`, -1.210022511784006}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.1826811049972195`, -1.210022511784006], 
            Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324273758587013, -1.2100225117840062`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.324273758587013, -1.2100225117840062`], 
            Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309296428167405, 1.201647620337122}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.309296428167405, 1.201647620337122], 
            Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167703774577614, 1.201647620337123}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.167703774577614, 1.201647620337123], 
            Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.230926641549791, -1.7219168570985053`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230926641549791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7219168570985053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1865870786798474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[3.230926641549791, -1.7219168570985053`], 
            Complex[1.0579767960708073`, -3.1865870786798474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0893339879599975, -1.721916857098505}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0893339879599975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.721916857098505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.186587078679847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[0.0893339879599975, -1.721916857098505], 
            Complex[1.0579767960708075`, -3.186587078679847]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.717307750554921, -0.6523609855265123}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.717307750554921, -0.6523609855265123], 
            Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.8589004041447135`, -0.6523609855265128}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.8589004041447135`, -0.6523609855265128], 
            Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.857910352423154, 0.5280405519418746}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.857910352423154, 0.5280405519418746], 
            Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.999503006012947, 0.528040551941874}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.999503006012947, 0.528040551941874], 
            Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182643106997762, -1.2128287152203816`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.182643106997762, -1.2128287152203816`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324235760587555, -1.2128287152203814`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.324235760587555, -1.2128287152203814`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309298751055461, 1.204451035693495}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.309298751055461, 1.204451035693495], 
            Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167706097465667, 1.2044510356934945`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.167706097465667, 1.2044510356934945`], 
            Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08897490881592815, -1.7237910758842274`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08897490881592815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7237910758842274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0571167527110277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1885112605830046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[0.08897490881592815, -1.7237910758842274`], 
            Complex[1.0571167527110277`, -3.1885112605830046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2305675624057217`, -1.7237910758842263`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2305675624057217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7237910758842263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.057116752711029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.188511260583004`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[3.2305675624057217`, -1.7237910758842263`], 
            Complex[1.057116752711029, -3.188511260583004]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.860867089220406, -0.6598239647344442}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.860867089220406, -0.6598239647344442], 
            Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7192744356306133`, -0.6598239647344449}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.7192744356306133`, -0.6598239647344449], 
            Complex[4.057727034812088, -2.002562003206256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8566318723517807`, 0.5360310932164641}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.8566318723517807`, 0.5360310932164641], 
            Complex[4.132077284632824, -0.570171279993703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.998224525941575, 0.5360310932164654}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.998224525941575, 0.5360310932164654], 
            Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182605423099423, -1.215618298858686}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.182605423099423, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324198076689216, -1.215618298858686}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.324198076689216, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167708305685528, 1.2072378477042838`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.167708305685528, 1.2072378477042838`], 
            Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30930095927532, 1.2072378477042842`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.30930095927532, 1.2072378477042842`], 
            Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.230211292644681, -1.7256571435340284`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230211292644681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7256571435340284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.056260857402957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.190428030154787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[3.230211292644681, -1.7256571435340284`], 
            Complex[1.056260857402957, -3.190428030154787]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08861863905488769, -1.725657143534028}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08861863905488769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.725657143534028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0562608574029573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.190428030154786`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[0.08861863905488769, -1.725657143534028], 
            Complex[1.0562608574029573`, -3.190428030154786]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.862770761740871, -0.6671697152100744}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.862770761740871, -0.6671697152100744], 
            Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7211781081510784`, -0.6671697152100743}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.7211781081510784`, -0.6671697152100743], 
            Complex[4.060641656654434, -2.01093044740819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8554133945952374`, 0.543900203601609}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.8554133945952374`, 0.543900203601609], 
            Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.99700604818503, 0.5439002036016083}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.99700604818503, 0.5439002036016083], 
            Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324160702151756, -1.2183914626776438`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.324160702151756, -1.2183914626776438`], 
            Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182568048561961, -1.218391462677644}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.182568048561961, -1.218391462677644], 
            Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1677104019634195`, 1.210008256181661}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.1677104019634195`, 1.210008256181661], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309303055553212, 1.2100082561816605`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.309303055553212, 1.2100082561816605`], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08826514518945743, -1.727515132015846}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08826514518945743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.727515132015846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.055409069822059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1923374512277785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[0.08826514518945743, -1.727515132015846], 
            Complex[1.055409069822059, -3.1923374512277785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2298577987792507`, -1.727515132015845}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2298577987792507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.727515132015845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0554090698220604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1923374512277776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[3.2298577987792507`, -1.727515132015845], 
            Complex[1.0554090698220604`, -3.1923374512277776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.86461513517684, -0.6744020624307271}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.86461513517684, -0.6744020624307271], 
            Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7230224815870465`, -0.6744020624307276}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.7230224815870465`, -0.6744020624307276], 
            Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.854251227099731, 0.5516517577146821}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.854251227099731, 0.5516517577146821], 
            Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.995843880689525, 0.5516517577146818}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.995843880689525, 0.5516517577146818], 
            Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1825309787497025`, -1.2211484030177213`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.1825309787497025`, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.301887288061049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324123632339496, -1.2211484030177213`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.324123632339496, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167712388950775, 1.2127624573020033`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.167712388950775, 1.2127624573020033`], 
            Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309305042540569, 1.212762457302003}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.309305042540569, 1.212762457302003], 
            Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08791439427478234, -1.7293651123339018`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08791439427478234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[0.08791439427478234, -1.7293651123339018`], 
            Complex[1.0545613502369584`, -3.1942395867779743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2295070478645758`, -1.7293651123339018`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2295070478645758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[3.2295070478645758`, -1.7293651123339018`], 
            Complex[1.0545613502369586`, -3.1942395867779743`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.86640362080727, -0.6815246607732995}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.86640362080727, -0.6815246607732995], 
            Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.724810967217476, -0.6815246607732999}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.724810967217476, -0.6815246607732999], 
            Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8531419798044717`, 0.5592894583048513}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.8531419798044717`, 0.5592894583048513], 
            Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.994734633394268, 0.5592894583048527}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.994734633394268, 0.5592894583048527], 
            Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324086862718293, -1.2238893126698196`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.324086862718293, -1.2238893126698196`], 
            Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1824942091285005`, -1.2238893126698194`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.1824942091285005`, -1.2238893126698194`], 
            Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167714269226694, 1.2155006436945395`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.167714269226694, 1.2155006436945395`], 
            Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30930692281649, 1.2155006436945397`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.30930692281649, 1.2155006436945397`], 
            Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08756635389739194, -1.73120715454608}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08756635389739194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.73120715454608`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1961344989403777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[0.08756635389739194, -1.73120715454608], 
            Complex[1.0537176594978057`, -3.1961344989403777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.229159007487185, -1.7312071545460794`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.229159007487185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7312071545460794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.196134498940377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[3.229159007487185, -1.7312071545460794`], 
            Complex[1.0537176594978062`, -3.196134498940377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.868139358018381, -0.6885410007735715}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.868139358018381, -0.6885410007735715], 
            Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7265467044285883`, -0.6885410007735716}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.7265467044285883`, -0.6885410007735716], 
            Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.993675187934443, 0.5668168435275391}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.993675187934443, 0.5668168435275391], 
            Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.852082534344649, 0.5668168435275388}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.852082534344649, 0.5668168435275388], 
            Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182457735262816, -1.2266143809612575`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.182457735262816, -1.2266143809612575`], 
            Complex[7.608667696724579, -2.30668231891301]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32405038885261, -1.2266143809612582`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.32405038885261, -1.2266143809612582`], 
            Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309308698890094, 1.2182230045272866`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.309308698890094, 1.2182230045272866`], 
            Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167716045300302, 1.2182230045272868`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.167716045300302, 1.2182230045272868`], 
            Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08722099216430315, -1.733041327780913}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08722099216430315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.733041327780913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0528779590249415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1980222490242425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[0.08722099216430315, -1.733041327780913], 
            Complex[1.0528779590249415`, -3.1980222490242425`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.228813645754096, -1.7330413277809138`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228813645754096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7330413277809138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052877959024942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1980222490242434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[3.228813645754096, -1.7330413277809138`], 
            Complex[1.052877959024942, -3.1980222490242434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.869825241082359, -0.6954544165180526}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.869825241082359, -0.6954544165180526], 
            Complex[4.071554204602269, -2.043172220042138]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7282325874925664`, -0.6954544165180527}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.7282325874925664`, -0.6954544165180527], 
            Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8510700172747567`, 0.5742372943510567}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.8510700172747567`, 0.5742372943510567], 
            Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.992662670864552, 0.5742372943510564}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.992662670864552, 0.5742372943510564], 
            Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1824215528129, -1.229323793839144}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.1824215528129, -1.229323793839144], 
            Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.324014206402694, -1.2293237938391435`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.324014206402694, -1.2293237938391435`], 
            Complex[7.608531912472354, -2.309057802254565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167717719612997, 1.2209297255903704`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.167717719612997, 1.2209297255903704`], 
            Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309310373202791, 1.2209297255903702`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.309310373202791, 1.2209297255903702`], 
            Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.086878277692393, -1.7348677002541821`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.086878277692393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0520422107978245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.199902897527961`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[0.086878277692393, -1.7348677002541821`], 
            Complex[1.0520422107978245`, -3.199902897527961]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.228470931282186, -1.7348677002541815`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228470931282186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052042210797825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1999028975279598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[3.228470931282186, -1.7348677002541815`], 
            Complex[1.052042210797825, -3.1999028975279598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.729871289280439, -0.7022680930260651}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.729871289280439, -0.7022680930260651], 
            Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.871463942870232, -0.7022680930260652}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.871463942870232, -0.7022680930260652], 
            Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.850101776357696, 0.5815540419531228}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.850101776357696, 0.5815540419531228], 
            Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.991694429947489, 0.5815540419531224}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.991694429947489, 0.5815540419531224], 
            Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182385657532068, -1.2320177339512255`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.182385657532068, -1.2320177339512255`], 
            Complex[7.608396583634034, -2.31141882849242]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323978311121861, -1.232017733951227}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.323978311121861, -1.232017733951227], 
            Complex[7.608396583634034, -2.311418828492422]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167719294540649, 1.2236209893768326`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.167719294540649, 1.2236209893768326`], 
            Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309311948130448, 1.2236209893768368`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.309311948130448, 1.2236209893768368`], 
            Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08653817959803752, -1.7366863392851428`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08653817959803752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7366863392851428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153616`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[0.08653817959803752, -1.7366863392851428`], 
            Complex[1.0512103773442263`, -3.201776504153616]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2281308331878296`, -1.736686339285139}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2281308331878296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.736686339285139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153611`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[3.2281308331878296`, -1.736686339285139], 
            Complex[1.0512103773442272`, -3.201776504153611]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7314652823007664`, -0.7089850735194753}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.7314652823007664`, -0.7089850735194753], 
            Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.87305793589056, -0.7089850735194753}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.87305793589056, -0.7089850735194753], 
            Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.990768013117869, 0.588770175004682}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.990768013117869, 0.588770175004682], 
            Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8491753595280755`, 0.5887701750046822}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.8491753595280755`, 0.5887701750046822], 
            Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182350045264077, -1.2346963807243223`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.182350045264077, -1.2346963807243223`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323942698853871, -1.2346963807243225`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.323942698853871, -1.2346963807243225`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30931342598549, 1.2262969751610369`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.30931342598549, 1.2262969751610369`], 
            Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167720772395696, 1.2262969751610366`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.167720772395696, 1.2262969751610366`], 
            Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08620066748699956, -1.7384973113123776`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08620066748699956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[0.08620066748699956, -1.7384973113123776`], 
            Complex[1.0503824217296986`, -3.2036431278211883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.227793321076793, -1.7384973113123774`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227793321076793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296989`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[3.227793321076793, -1.7384973113123774`], 
            Complex[1.0503824217296989`, -3.2036431278211888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.733016857401756, -0.7156082665076033}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.733016857401756, -0.7156082665076033], 
            Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.874609510991549, -0.7156082665076038}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.874609510991549, -0.7156082665076038], 
            Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.98988114978185, 0.5958886467685789}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.98988114978185, 0.5958886467685789], 
            Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.848288496192057, 0.5958886467685786}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.848288496192057, 0.5958886467685786], 
            Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323907365530383, -1.2373599104403945`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.323907365530383, -1.2373599104403945`], 
            Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182314711940597, -1.2373599104404132`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.182314711940597, -1.2373599104404132`], 
            Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309314809018922, 1.2289578590746733`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.309314809018922, 1.2289578590746733`], 
            Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16772215542913, 1.2289578590746735`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.16772215542913, 1.2289578590746735`], 
            Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.227458365034377, -1.7403006819093283`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227458365034377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.20550282668249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[3.227458365034377, -1.7403006819093283`], 
            Complex[1.0495583075472772`, -3.20550282668249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08586571144458416, -1.7403006819093272`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08586571144458416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093272`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2055028266824883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[0.08586571144458416, -1.7403006819093272`], 
            Complex[1.0495583075472783`, -3.2055028266824883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.876120794018037, -0.7221404526376908}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.876120794018037, -0.7221404526376908], 
            Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.734528140428245, -0.7221404526376912}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.734528140428245, -0.7221404526376912], 
            Complex[4.081447520434109, -2.07361729918916]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.847439080572326, 0.6029122819634529}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.847439080572326, 0.6029122819634529], 
            Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.989031734162119, 0.6029122819634535}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.989031734162119, 0.6029122819634535], 
            Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182279653578758, -1.2400084963104758`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.182279653578758, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323872307168552, -1.2400084963104758`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.323872307168552, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167723445832482, 1.2316038141805976`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.167723445832482, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309316099422276, 1.2316038141805976`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.309316099422276, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08553328202600917, -1.742096515799434}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08553328202600917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.742096515799434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[0.08553328202600917, -1.742096515799434], 
            Complex[1.0487379989074426`, -3.207355658134716]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.227125935615802, -1.7420965157994346`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227125935615802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7420965157994346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134717`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[3.227125935615802, -1.7420965157994346`], 
            Complex[1.0487379989074426`, -3.207355658134717]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.877593760675199, -0.7285842912785059}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.877593760675199, -0.7285842912785059], 
            Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.736001107085408, -0.7285842912785057}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.736001107085408, -0.7285842912785057], 
            Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8466251568463186`, 0.6098437833604624}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.8466251568463186`, 0.6098437833604624], 
            Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.988217810436113, 0.6098437833604634}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.988217810436113, 0.6098437833604634], 
            Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182244866278791, -1.242642308546148}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.182244866278791, -1.242642308546148], 
            Complex[7.607859712684855, -2.320721705723057]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323837519868585, -1.242642308546154}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.323837519868585, -1.242642308546154], 
            Complex[7.607859712684855, -2.320721705723063]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167724645739662, 1.2342350105444317`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.167724645739662, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309317299329457, 1.2342350105444317`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.309317299329457, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2267960038368266`, -1.7438848768709785`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2267960038368266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7438848768709785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[3.2267960038368266`, -1.7438848768709785`], 
            Complex[1.0479214604283111`, -3.209201678833752]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08520335024703361, -1.7438848768709778`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08520335024703361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7438848768709778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[0.08520335024703361, -1.7438848768709778`], 
            Complex[1.0479214604283116`, -3.209201678833752]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.879030249816931, -0.7349423268176076}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.879030249816931, -0.7349423268176076], 
            Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7374375962271382`, -0.7349423268176083}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.7374375962271382`, -0.7349423268176083], 
            Complex[4.086071031729208, -2.088230594606227]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.987437559449537, 0.616685738093365}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.987437559449537, 0.616685738093365], 
            Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.845844905859744, 0.6166857380933649}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.845844905859744, 0.6166857380933649], 
            Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323802999811543, -1.2452615144292978`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.323802999811543, -1.2452615144292978`], 
            Complex[7.607726579534131, -2.32301292857686]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1822103462217495`, -1.245261514429298}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.1822103462217495`, -1.245261514429298], 
            Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167725757228776, 1.2368516153041005`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.167725757228776, 1.2368516153041005`], 
            Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30931841081857, 1.2368516153040952`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.30931841081857, 1.2368516153040952`], 
            Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08487588757480041, -1.7456658281915818`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08487588757480041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7456658281915818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.047108657226064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[0.08487588757480041, -1.7456658281915818`], 
            Complex[1.047108657226064, -3.2110409447071544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2264685411645937`, -1.7456658281915811`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2264685411645937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7456658281915811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0471086572260642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[3.2264685411645937`, -1.7456658281915811`], 
            Complex[1.0471086572260642`, -3.2110409447071544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.880431975347877, -0.7412169946624547}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.880431975347877, -0.7412169946624547], 
            Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7388393217580846`, -0.7412169946624545}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.7388393217580846`, -0.7412169946624545], 
            Complex[4.088310451090251, -2.095394940608318]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8450966332264747`, 0.6234406236721284}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.8450966332264747`, 0.6234406236721284], 
            Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.986689286816269, 0.6234406236721282}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.986689286816269, 0.6234406236721282], 
            Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.3237687432571, -1.2478662783795624`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.3237687432571, -1.2478662783795624`], 
            Complex[7.607593869964685, -2.32529066727406]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182176089667306, -1.2478662783795629`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.182176089667306, -1.2478662783795629`], 
            Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16772678232385, 1.2394537927373115`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.16772678232385, 1.2394537927373115`], 
            Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309319435913645, 1.2394537927373108`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.309319435913645, 1.2394537927373108`], 
            Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.226143519508699, -1.747439432022393}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.226143519508699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747439432022393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0462995549055958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.212873510966856`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[3.226143519508699, -1.747439432022393], 
            Complex[1.0462995549055958`, -3.212873510966856]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08455086591890591, -1.7474394320223927`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08455086591890591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474394320223927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.046299554905596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2128735109668556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[0.08455086591890591, -1.7474394320223927`], 
            Complex[1.046299554905596, -3.2128735109668556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7402078833132797`, -0.7474106269426312}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.7402078833132797`, -0.7474106269426312], 
            Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.881800536903074, -0.7474106269426314}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.881800536903074, -0.7474106269426314], 
            Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8443787586507785`, 0.6301108136973931}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.8443787586507785`, 0.6301108136973931], 
            Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.985971412240573, 0.6301108136973947}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.985971412240573, 0.6301108136973947], 
            Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182142092951617, -1.2504567620199438`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.182142092951617, -1.2504567620199438`], 
            Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323734746541412, -1.2504567620199438`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.323734746541412, -1.2504567620199438`], 
            Complex[7.607461579018771, -2.327555074323918]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309320376586301, 1.2420417043271583`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.309320376586301, 1.2420417043271583`], 
            Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167727722996508, 1.2420417043271579`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.167727722996508, 1.2420417043271579`], 
            Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0842282576226818, -1.7492057498319649`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0842282576226818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7492057498319649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0454941195513836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2146994321215856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[0.0842282576226818, -1.7492057498319649`], 
            Complex[1.0454941195513836`, -3.2146994321215856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.225820911212475, -1.7492057498319644`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225820911212475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7492057498319644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.045494119551384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2146994321215847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[3.225820911212475, -1.7492057498319644`], 
            Complex[1.045494119551384, -3.2146994321215847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7415447758580713`, -0.7535254579157126}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.7415447758580713`, -0.7535254579157126], 
            Complex[4.092654956897793, -2.109452014313655]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.883137429447864, -0.7535254579157123}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.883137429447864, -0.7535254579157123], 
            Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.985282459919064, 0.6366985832782691}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.985282459919064, 0.6366985832782691], 
            Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.843689806329271, 0.6366985832782687}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.843689806329271, 0.6366985832782687], 
            Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182108352485272, -1.2530331242405153`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.182108352485272, -1.2530331242405153`], 
            Complex[7.607329701831238, -2.32980629964634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323701006075066, -1.253033124240515}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.323701006075066, -1.253033124240515], 
            Complex[7.607329701831238, -2.32980629964634]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309321234757373, 1.2446155088257416`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.309321234757373, 1.2446155088257416`], 
            Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16772858116758, 1.2446155088257413`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.16772858116758, 1.2446155088257413`], 
            Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08390803545469033, -1.7509648423098307`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08390803545469033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7509648423098307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[0.08390803545469033, -1.7509648423098307`], 
            Complex[1.0446923177185725`, -3.2165187619890236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.225500689044484, -1.750964842309831}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225500689044484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.750964842309831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[3.225500689044484, -1.750964842309831], 
            Complex[1.0446923177185734`, -3.2165187619890245`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.884444051922338, -0.7595636290829754}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.884444051922338, -0.7595636290829754], 
            Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.742851398332544, -0.7595636290829759}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.742851398332544, -0.7595636290829759], 
            Complex[4.094763792064631, -2.11634961995984]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8430283963083336`, 0.6432061141597183}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.8430283963083336`, 0.6432061141597183], 
            Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.984621049898127, 0.643206114159718}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.984621049898127, 0.643206114159718], 
            Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323667518341093, -1.255595521260306}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.323667518341093, -1.255595521260306], 
            Complex[7.607198233627162, -2.332044490630609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182074864751301, -1.2555955212603063`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.182074864751301, -1.2555955212603063`], 
            Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167729358708656, 1.247175362316046}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.167729358708656, 1.247175362316046], 
            Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30932201229845, 1.247175362316046}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.30932201229845, 1.247175362316046], 
            Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0835901726004175, -1.752716769379781}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0835901726004175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.752716769379781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.218331553707678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[0.0835901726004175, -1.752716769379781], 
            Complex[1.0438941164242617`, -3.218331553707678]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2251828261902116`, -1.7527167693797805`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2251828261902116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7527167693797805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2183315537076793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[3.2251828261902116`, -1.7527167693797805`], 
            Complex[1.0438941164242628`, -3.2183315537076793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.744129061448893, -0.7655271940238008}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.744129061448893, -0.7655271940238008], 
            Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.885721715038686, -0.7655271940238007}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.885721715038686, -0.7655271940238007], 
            Complex[4.096832656761998, -2.123163026694792]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.983985890278379, 0.6496354995683528}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.983985890278379, 0.6496354995683528], 
            Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.842393236688587, 0.6496354995683534}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.842393236688587, 0.6496354995683534], 
            Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182041626303249, -1.2581441066874384`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.182041626303249, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323634279893042, -1.2581441066874384`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.323634279893042, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309322711033374, 1.2497214182720298`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.309322711033374, 1.2497214182720298`], 
            Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167730057443585, 1.249721418272031}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.167730057443585, 1.249721418272031], 
            Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08327464265416494, -1.7544615902128715`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08327464265416494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.04309948313899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2201378597485255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[0.08327464265416494, -1.7544615902128715`], 
            Complex[1.04309948313899, -3.2201378597485255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.224867296243958, -1.7544615902128715`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.224867296243958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0430994831389901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2201378597485246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[3.224867296243958, -1.7544615902128715`], 
            Complex[1.0430994831389901`, -3.2201378597485246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.745378994736478, -0.7714181229593412}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.745378994736478, -0.7714181229593412], 
            Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.886971648326271, -0.7714181229593432}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.886971648326271, -0.7714181229593432], 
            Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8417831165816425`, 0.6559887487872518}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.8417831165816425`, 0.6559887487872518], 
            Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.983375770171436, 0.655988748787251}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.983375770171436, 0.655988748787251], 
            Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.182008633763318, -1.260679031577555}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.182008633763318, -1.260679031577555], 
            Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323601287353112, -1.2606790315775551`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.323601287353112, -1.2606790315775551`], 
            Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167730679149904, 1.2522538276170248`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.167730679149904, 1.2522538276170248`], 
            Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309323332739702, 1.2522538276170265`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.309323332739702, 1.2522538276170265`], 
            Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2245540732009284`, -1.7561993632401343`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2245540732009284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561993632401343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[3.2245540732009284`, -1.7561993632401343`], 
            Complex[1.0423083857784268`, -3.2219377319263685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08296141961113473, -1.7561993632401347`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08296141961113473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561993632401347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263676`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[0.08296141961113473, -1.7561993632401347`], 
            Complex[1.0423083857784274`, -3.2219377319263676`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.746602352917594, -0.7772383070571701}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.746602352917594, -0.7772383070571701], 
            Complex[4.100856784915977, -2.136545961543077]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.888195006507387, -0.7772383070571703}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.888195006507387, -0.7772383070571703], 
            Complex[4.100856784915978, -2.136545961543077]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8411968997361448`, 0.6622677914714884}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.8411968997361448`, 0.6622677914714884], 
            Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.982789553325939, 0.6622677914714878}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.982789553325939, 0.6622677914714878], 
            Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323568537410361, -1.2632004444906193`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.323568537410361, -1.2632004444906193`], 
            Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181975883820568, -1.2632004444906197`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.181975883820568, -1.2632004444906197`], 
            Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309323879150051, 1.254772738780499}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.309323879150051, 1.254772738780499], 
            Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167731225560259, 1.2547727387804994`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.167731225560259, 1.2547727387804994`], 
            Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08265047785970185, -1.7579301461650303`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08265047785970185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7579301461650303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.223731221410986`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[0.08265047785970185, -1.7579301461650303`], 
            Complex[1.0415207926952421`, -3.223731221410986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2242431314494953`, -1.7579301461650294`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2242431314494953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7579301461650294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2237312214109846`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[3.2242431314494953`, -1.7579301461650294`], 
            Complex[1.0415207926952428`, -3.2237312214109846`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7478002216867257`, -0.7829895624892164}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.7478002216867257`, -0.7829895624892164], 
            Complex[4.102814974771636, -2.143119636338954]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.88939287527652, -0.782989562489217}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.88939287527652, -0.782989562489217], 
            Complex[4.102814974771636, -2.143119636338955]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.982226172350083, 0.6684744817167128}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.982226172350083, 0.6684744817167128], 
            Complex[4.1071667491158, -0.4049877179062303]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8406335187602902`, 0.6684744817167128}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.8406335187602902`, 0.6684744817167128], 
            Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323536026818966, -1.2657084915461236`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.323536026818966, -1.2657084915461236`], 
            Complex[7.606676358179671, -2.340869773551443]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1819433732291715`, -1.2657084915461239`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.1819433732291715`, -1.2657084915461239`], 
            Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167731698363721, 1.2572782977532326`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.167731698363721, 1.2572782977532326`], 
            Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309324351953519, 1.2572782977532362`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.309324351953519, 1.2572782977532362`], 
            Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08234179217386196, -1.759653995975626}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08234179217386196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.759653995975626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[0.08234179217386196, -1.759653995975626], 
            Complex[1.0407366726711678`, -3.225518378738005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.223934445763656, -1.7596539959756308`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223934445763656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7596539959756308`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[3.223934445763656, -1.7596539959756308`], 
            Complex[1.0407366726711693`, -3.225518378738008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.748973622957287, -0.7886736342555815}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.748973622957287, -0.7886736342555815], 
            Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.89056627654708, -0.7886736342555825}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.89056627654708, -0.7886736342555825], 
            Complex[4.104739060573037, -2.149617413966407]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.981684623466656, 0.6746106018933713}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.981684623466656, 0.6746106018933713], 
            Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8400919698768647`, 0.6746106018933697}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.8400919698768647`, 0.6746106018933697], 
            Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181911098806735, -1.2682033164767692`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.181911098806735, -1.2682033164767692`], 
            Complex[7.606546866271806, -2.343044919018727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323503752396531, -1.2682033164767677`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.323503752396531, -1.2682033164767677`], 
            Complex[7.60654686627181, -2.343044919018725]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732099207092, 1.2597706481409663`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.167732099207092, 1.2597706481409663`], 
            Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309324752796902, 1.2597706481409692`}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.309324752796902, 1.2597706481409692`], 
            Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08203533770586706, -1.7613709689565493`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08203533770586706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7613709689565493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[0.08203533770586706, -1.7613709689565493`], 
            Complex[1.0399559949092405`, -3.227299253819592]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2236279912956602`, -1.7613709689565495`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2236279912956602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7613709689565495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[3.2236279912956602`, -1.7613709689565495`], 
            Complex[1.0399559949092407`, -3.227299253819592]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.981163961744247, 0.6806778662591632}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.981163961744247, 0.6806778662591632], 
            Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8395713081544542`, 0.6806778662591643}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.8395713081544542`, 0.6806778662591643], 
            Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.891716173221934, -0.7942921997868306}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.891716173221934, -0.7942921997868306], 
            Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.750123519632142, -0.794292199786831}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.750123519632142, -0.794292199786831], 
            Complex[4.106630306409572, -2.156041173845927]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323471711022448, -1.2706850606806674`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.323471711022448, -1.2706850606806674`], 
            Complex[7.606417756470162, -2.345207864426671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1818790574326545`, -1.2706850606806677`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.1818790574326545`, -1.2706850606806677`], 
            Complex[7.606417756470163, -2.345207864426671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732429696165, 1.2622499312165703`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.167732429696165, 1.2622499312165703`], 
            Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325083285957, 1.26224993121657}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.309325083285957, 1.26224993121657], 
            Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0817310899790139, -1.763081120700618}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0817310899790139`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.763081120700618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2290738959548437`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[0.0817310899790139, -1.763081120700618], 
            Complex[1.039178729026203, -3.2290738959548437`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.223323743568807, -1.7630811207006185`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223323743568807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7630811207006185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.229073895954844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[3.223323743568807, -1.7630811207006185`], 
            Complex[1.039178729026203, -3.229073895954844]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.980663296755008, 0.6866779243621381}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.980663296755008, 0.6866779243621381], 
            Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.839070643165216, 0.6866779243621389}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.839070643165216, 0.6866779243621389], 
            Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.751250819947598, -0.7998468723371362}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.751250819947598, -0.7998468723371362], 
            Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.892843473537392, -0.7998468723371351}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.892843473537392, -0.7998468723371351], 
            Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181847246046556, -1.273153863272108}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.181847246046556, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323439899636348, -1.273153863272108}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.323439899636348, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732691396911, 1.2647162859707828`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.167732691396911, 1.2647162859707828`], 
            Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325344986703, 1.2647162859707826`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.309325344986703, 1.2647162859707826`], 
            Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2230216784704147`, -1.7647845061203178`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2230216784704147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7647845061203178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[3.2230216784704147`, -1.7647845061203178`], 
            Complex[1.0384048450451053`, -3.230842353840041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08142902488062087, -1.7647845061203167`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08142902488062087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7647845061203167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840039`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[0.08142902488062087, -1.7647845061203167`], 
            Complex[1.0384048450451058`, -3.230842353840039]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.980181788615051, 0.6926123642464803}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.980181788615051, 0.6926123642464803], 
            Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.838589135025258, 0.6926123642464805}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.838589135025258, 0.6926123642464805], 
            Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7523563814347085`, -0.8053392041803537}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.7523563814347085`, -0.8053392041803537], 
            Complex[4.11031899238399, -2.168673807450607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.893949035024502, -0.8053392041803533}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.893949035024502, -0.8053392041803533], 
            Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181815661646743, -1.275609861130944}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.181815661646743, -1.275609861130944], 
            Complex[7.606160666446714, -2.349497677693729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323408315236543, -1.2756098611309419`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.323408315236543, -1.2756098611309419`], 
            Complex[7.60616066644672, -2.349497677693727]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30932553942646, 1.2671698491615646`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.30932553942646, 1.2671698491615646`], 
            Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732885836667, 1.2671698491615644`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.167732885836667, 1.2671698491615644`], 
            Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.222721772244943, -1.7664811794589748`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222721772244943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589748`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[3.222721772244943, -1.7664811794589748`], 
            Complex[1.0376343133880408`, -3.2326046755786235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.08112911865515363, -1.7664811794589725`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08112911865515363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[0.08112911865515363, -1.7664811794589725`], 
            Complex[1.0376343133880443`, -3.2326046755786213`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.979718644368703, 0.6984827154726538}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.979718644368703, 0.6984827154726538], 
            Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8381259907789103`, 0.6984827154726537}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.8381259907789103`, 0.6984827154726537], 
            Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.8950336681265165`, -0.8107706896206487}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.8950336681265165`, -0.8107706896206487], 
            Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7534410145367234`, -0.8107706896206492}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.7534410145367234`, -0.8107706896206492], 
            Complex[4.112118632879193, -2.174886099543967]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1817843012887375`, -1.2780531889506415`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.1817843012887375`, -1.2780531889506415`], 
            Complex[7.606032678038458, -2.351624801622354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323376954878531, -1.2780531889506412`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.323376954878531, -1.2780531889506412`], 
            Complex[7.606032678038458, -2.351624801622354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167733014505244, 1.2696107553621172`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.167733014505244, 1.2696107553621172`], 
            Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325668095038, 1.2696107553621176`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.309325668095038, 1.2696107553621176`], 
            Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08083134789749542, -1.7681711943017286`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08083134789749542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2343609086909946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[0.08083134789749542, -1.7681711943017286`], 
            Complex[1.0368671048690645`, -3.2343609086909946`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.222424001487289, -1.7681711943017286`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222424001487289`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.234360908690994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[3.222424001487289, -1.7681711943017286`], 
            Complex[1.0368671048690654`, -3.234360908690994]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8376804610924062`, 0.7042904519630285}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.8376804610924062`, 0.7042904519630285], 
            Complex[4.102309515593154, -0.359742624540917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.979273114682207, 0.7042904519630309}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.979273114682207, 0.7042904519630309], 
            Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7545054859170786`, -0.8161427678288303}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.7545054859170786`, -0.8161427678288303], 
            Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.896098139506871, -0.8161427678288314}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.896098139506871, -0.8161427678288314], 
            Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181753162083825, -1.2804839792850273`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.181753162083825, -1.2804839792850273`], 
            Complex[7.605905055360047, -2.353740237720617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323345815673619, -1.2804839792850278`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.323345815673619, -1.2804839792850278`], 
            Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325732445826, 1.2720391370076072`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.309325732445826, 1.2720391370076072`], 
            Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167733078856032, 1.272039137007607}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.167733078856032, 1.272039137007607], 
            Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08053568954642111, -1.7698546035862615`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08053568954642111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7698546035862615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[0.08053568954642111, -1.7698546035862615`], 
            Complex[1.0361031906872573`, -3.2361111001240945`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2221283431362147`, -1.769854603586262}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2221283431362147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.769854603586262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[3.2221283431362147`, -1.769854603586262], 
            Complex[1.0361031906872582`, -3.2361111001240945`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.978844490816281, 0.7100369946836335}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.978844490816281, 0.7100369946836335], 
            Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8372518372264883`, 0.710036994683633}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.8372518372264883`, 0.710036994683633], 
            Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.897143175078252, -0.8214568255150104}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.897143175078252, -0.8214568255150104], 
            Complex[4.115633584193734, -2.187110717536775]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7555505214884586`, -0.8214568255150109}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.7555505214884586`, -0.8214568255150109], 
            Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32331489478747, -1.282902362593793}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.32331489478747, -1.282902362593793], 
            Complex[7.605777794493471, -2.355844108978483]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181722241197679, -1.2829023625937932`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.181722241197679, -1.2829023625937932`], 
            Complex[7.605777794493473, -2.355844108978483]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325733896824, 1.2744551244406346`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.309325733896824, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1677330803070305`, 1.2744551244406346`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.1677330803070305`, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.08024212087815223, -1.7715314596133194`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08024212087815223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[0.08024212087815223, -1.7715314596133194`], 
            Complex[1.0353425424199532`, -3.2378552962607934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.221834774467946, -1.7715314596133196`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.221834774467946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[3.221834774467946, -1.7715314596133196`], 
            Complex[1.0353425424199543`, -3.2378552962607934`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.836839448260752, 0.7157237141721116}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.836839448260752, 0.7157237141721116], 
            Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9784321018505455`, 0.7157237141721113}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.9784321018505455`, 0.7157237141721113], 
            Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7565768091900997`, -0.8267141994476596}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.7565768091900997`, -0.8267141994476596], 
            Complex[4.117350770809639, -2.193126103819013]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.898169462779893, -0.8267141994476594}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.898169462779893, -0.8267141994476594], 
            Complex[4.11735077080964, -2.193126103819013]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323284189438796, -1.2853084672867803`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.323284189438796, -1.2853084672867803`], 
            Complex[7.605650891587858, -2.357936536444798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181691535849006, -1.2853084672867796`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.181691535849006, -1.2853084672867796`], 
            Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167733020241881, 1.276858845955496}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.167733020241881, 1.276858845955496], 
            Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325673831674, 1.2768588459554961`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.309325673831674, 1.2768588459554961`], 
            Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07995061950010503, -1.773201814057012}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07995061950010503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.773201814057012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.034585132016095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.239593542929082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[0.07995061950010503, -1.773201814057012], 
            Complex[1.034585132016095, -3.239593542929082]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2215432730898983`, -1.7732018140570123`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2215432730898983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7732018140570123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0345851320160955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2395935429290827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[3.2215432730898983`, -1.7732018140570123`], 
            Complex[1.0345851320160955`, -3.2395935429290827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8364426585455744`, 0.7213519329214126}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.8364426585455744`, 0.7213519329214126], 
            Complex[4.100239116839224, -0.338101803538321]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.978035312135368, 0.7213519329214122}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.978035312135368, 0.7213519329214122], 
            Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.899177655127286, -0.8319161788285983}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.899177655127286, -0.8319161788285983], 
            Complex[4.119042270745964, -2.199078825420971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7575850015374925`, -0.8319161788285991}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.7575850015374925`, -0.8319161788285991], 
            Complex[4.119042270745964, -2.199078825420972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181661043308228, -1.2877024197670905`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.181661043308228, -1.2877024197670905`], 
            Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323253696898021, -1.2877024197670908`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.323253696898021, -1.2877024197670908`], 
            Complex[7.60552434285789, -2.360017639268197]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1677329000108365`, 1.2792504278412689`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.1677329000108365`, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30932555360063, 1.2792504278412689`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.30932555360063, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2212538169345617`, -1.7748657179749052`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2212538169345617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.24132588541108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[3.2212538169345617`, -1.7748657179749052`], 
            Complex[1.0338309317897683`, -3.24132588541108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0796611633447683, -1.7748657179749043`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0796611633447683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749043`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2413258854110794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[0.0796611633447683, -1.7748657179749043`], 
            Complex[1.0338309317897687`, -3.2413258854110794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.977653518949829, 0.7269229276281969}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.977653518949829, 0.7269229276281969], 
            Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.836060865360036, 0.7269229276281965}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.836060865360036, 0.7269229276281965], 
            Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7585757179660733`, -0.8370640075328957}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.7585757179660733`, -0.8370640075328957], 
            Complex[4.120708909659479, -2.204970281578657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.900168371555867, -0.8370640075328958}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.900168371555867, -0.8370640075328958], 
            Complex[4.120708909659479, -2.204970281578657]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32322341448604, -1.2900843444730699`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.32322341448604, -1.2900843444730699`], 
            Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181630760896252, -1.2900843444730699`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.181630760896252, -1.2900843444730699`], 
            Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30932537452151, 1.2816299944237615`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.30932537452151, 1.2816299944237615`], 
            Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732720931719, 1.2816299944237621`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.167732720931719, 1.2816299944237621`], 
            Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.220966384253502, -1.7765232218179048`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.220966384253502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7765232218179048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2430523684518433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[3.220966384253502, -1.7765232218179048`], 
            Complex[1.0330799144138363`, -3.2430523684518433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07937373066370935, -1.776523221817905}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07937373066370935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.776523221817905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.243052368451844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[0.07937373066370935, -1.776523221817905], 
            Complex[1.0330799144138367`, -3.243052368451844]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.97728615034638, 0.7324379313144281}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.97728615034638, 0.7324379313144281], 
            Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8356934967565883`, 0.732437931314428}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.8356934967565883`, 0.732437931314428], 
            Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.759549546988155, -0.8421588862221198}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.759549546988155, -0.8421588862221198], 
            Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.901142200577949, -0.8421588862221203}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.901142200577949, -0.8421588862221203], 
            Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323193339572983, -1.292454363919178}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.323193339572983, -1.292454363919178], 
            Complex[7.605272293102371, -2.364146338317678]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181600685983191, -1.2924543639191768`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.181600685983191, -1.2924543639191768`], 
            Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309325137880622, 1.2839976681063674`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.309325137880622, 1.2839976681063674`], 
            Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732484290831, 1.2839976681063678`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.167732484290831, 1.2839976681063678`], 
            Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2206809536115193`, -1.7781743754399488`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2206809536115193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7781743754399488`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[3.2206809536115193`, -1.7781743754399488`], 
            Complex[1.0323320529137487`, -3.2447730362680187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07908830002172706, -1.7781743754399495`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07908830002172706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7781743754399495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[0.07908830002172706, -1.7781743754399495`], 
            Complex[1.0323320529137487`, -3.2447730362680205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8353400095752215`, 0.7378981353300624}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.8353400095752215`, 0.7378981353300624], 
            Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.976932663165016, 0.7378981353300635}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.976932663165016, 0.7378981353300635], 
            Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.760507048180339, -0.8472019743388879}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.760507048180339, -0.8472019743388879], 
            Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9020997017701315`, -0.8472019743388882}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.9020997017701315`, -0.8472019743388882], 
            Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323163469577016, -1.2948125987358026`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.323163469577016, -1.2948125987358026`], 
            Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181570815987224, -1.2948125987358035`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.181570815987224, -1.2948125987358035`], 
            Complex[7.605146784820535, -2.366194163693253]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167732191343831, 1.2863535694098465`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.167732191343831, 1.2863535694098465`], 
            Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309324844933629, 1.286353569409846}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.309324844933629, 1.286353569409846], 
            Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07880485029112587, -1.7798192281074985`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07880485029112587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325562994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[0.07880485029112587, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325562994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2203975038809194`, -1.7798192281074985`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2203975038809194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325563003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[3.2203975038809194`, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325563003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8349998876116986`, 0.7433046912443027}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.8349998876116986`, 0.7433046912443027], 
            Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.976592541201492, 0.7433046912443029}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.976592541201492, 0.7433046912443029], 
            Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7614487540168455`, -0.8521943919901349}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.7614487540168455`, -0.8521943919901349], 
            Complex[4.12556733480281, -2.222290341327314]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.903041407606638, -0.852194391990135}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.903041407606638, -0.852194391990135], 
            Complex[4.12556733480281, -2.222290341327314]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181541148373396, -1.2971591677080394`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.181541148373396, -1.2971591677080394`], 
            Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323133801963191, -1.2971591677080403`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.323133801963191, -1.2971591677080403`], 
            Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309324496906415, 1.2886978170110814`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.309324496906415, 1.2886978170110814`], 
            Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167731843316621, 1.2886978170110817`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.167731843316621, 1.2886978170110817`], 
            Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2201160142359173`, -1.7814578285088363`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2201160142359173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7814578285088363`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030845691369485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.248197100501716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[3.2201160142359173`, -1.7814578285088363`], 
            Complex[1.030845691369485, -3.248197100501716]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07852336064612488, -1.781457828508837}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07852336064612488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.781457828508837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0308456913694903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2481971005017125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[0.07852336064612488, -1.781457828508837], 
            Complex[1.0308456913694903`, -3.2481971005017125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8346726399259916`, 0.7486587126323618}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.8346726399259916`, 0.7486587126323618], 
            Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.976265293515786, 0.7486587126323617}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.976265293515786, 0.7486587126323617], 
            Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.903967825152418, -0.8571372217260815}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.903967825152418, -0.8571372217260815], 
            Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.762375171562624, -0.8571372217260823}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.762375171562624, -0.8571372217260823], 
            Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323104334242323, -1.2994941878134678`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.323104334242323, -1.2994941878134678`], 
            Complex[7.604896783758137, -2.370257325860909]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18151168065253, -1.2994941878134685`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.18151168065253, -1.2994941878134685`], 
            Complex[7.604896783758138, -2.370257325860909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167731441406146, 1.2910305277808336`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.167731441406146, 1.2910305277808336`], 
            Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309324094995942, 1.291030527780833}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.309324094995942, 1.291030527780833], 
            Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.219836464147169, -1.78309022476319}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.219836464147169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.78309022476319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0301071390850915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.249900582785768`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[3.219836464147169, -1.78309022476319], 
            Complex[1.0301071390850915`, -3.249900582785768]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07824381055737564, -1.7830902247631892`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07824381055737564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7830902247631892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030107139085092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.249900582785767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[0.07824381055737564, -1.7830902247631892`], 
            Complex[1.030107139085092, -3.249900582785767]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.975950452868279, 0.7539612767642825}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.975950452868279, 0.7539612767642825], 
            Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8343577992784867`, 0.7539612767642822}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.8343577992784867`, 0.7539612767642822], 
            Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7632867840386814`, -0.8620315102214068}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.7632867840386814`, -0.8620315102214068], 
            Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.904879437628475, -0.8620315102214064}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.904879437628475, -0.8620315102214064], 
            Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181482410380124, -1.3018177742589643`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.181482410380124, -1.3018177742589643`], 
            Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32307506396992, -1.3018177742589656`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.32307506396992, -1.3018177742589656`], 
            Complex[7.604772284075739, -2.372272881425941]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309323640371, 1.2933518168205271`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.309323640371, 1.2933518168205271`], 
            Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167730986781208, 1.2933518168205271`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.167730986781208, 1.2933518168205271`], 
            Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07796617978662179, -1.7847164644296631`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07796617978662179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7847164644296631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381845965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2515984215943754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[0.07796617978662179, -1.7847164644296631`], 
            Complex[1.0293716381845965`, -3.2515984215943754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2195588333764196`, -1.7847164644296638`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2195588333764196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7847164644296638`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.251598421594382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[3.2195588333764196`, -1.7847164644296638`], 
            Complex[1.0293716381846, -3.251598421594382]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{2.8340549206827474`, 0.7592134262018864}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.8340549206827474`, 0.7592134262018864], 
            Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.975647574272541, 0.7592134262018878}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.975647574272541, 0.7592134262018878], 
            Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.905776705860623, -0.8668782698647188}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.905776705860623, -0.8668782698647188], 
            Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.764184052270831, -0.8668782698647187}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.764184052270831, -0.8668782698647187], 
            Complex[4.130228184469746, -2.239105006921373]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18145333515529, -1.3041300405165688`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.18145333515529, -1.3041300405165688`], 
            Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323045988745086, -1.3041300405165683`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.323045988745086, -1.3041300405165683`], 
            Complex[7.604648113785146, -2.374277896400649]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167730480583245, 1.2956617974980968`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.167730480583245, 1.2956617974980968`], 
            Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309323134173042, 1.2956617974980962`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.309323134173042, 1.2956617974980962`], 
            Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.21928310197127, -1.7863365945159997`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.21928310197127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7863365945159997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625719`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[3.21928310197127, -1.7863365945159997`], 
            Complex[1.0286391633678167`, -3.253290658625719]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0776904483814771, -1.7863365945160001`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0776904483814771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7863365945160001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625721`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[0.0776904483814771, -1.7863365945160001`], 
            Complex[1.0286391633678178`, -3.253290658625721]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8337635800647583`, 0.764416170309563}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.8337635800647583`, 0.764416170309563], 
            Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.975356233654551, 0.7644161703095629}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.975356233654551, 0.7644161703095629], 
            Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.765067416031943, -0.8716784802620265}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.765067416031943, -0.8716784802620265], 
            Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9066600696217355`, -0.8716784802620264}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.9066600696217355`, -0.8716784802620264], 
            Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181424452619743, -1.3064310983584468`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.181424452619743, -1.3064310983584468`], 
            Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.323017106209543, -1.3064310983584502`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.323017106209543, -1.3064310983584502`], 
            Complex[7.604524269574324, -2.376272476082065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167729923927075, 1.2979605814829254`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.167729923927075, 1.2979605814829254`], 
            Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309322577516868, 1.2979605814829327`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.309322577516868, 1.2979605814829327`], 
            Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2190092502600542`, -1.7879506614871665`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2190092502600542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7879506614871665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0279096896525775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2549773350978284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[3.2190092502600542`, -1.7879506614871665`], 
            Complex[1.0279096896525775`, -3.2549773350978284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.077416596670261, -1.7879506614871654`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.077416596670261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7879506614871654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.027909689652578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.254977335097826`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[0.077416596670261, -1.7879506614871654`], 
            Complex[1.027909689652578, -3.254977335097826]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.975076026609326, 0.7695704866842142}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.975076026609326, 0.7695704866842142], 
            Complex[4.095188685529604, -0.27663159198783]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8334833730195332`, 0.769570486684214}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.8334833730195332`, 0.769570486684214], 
            Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7659372952868275`, -0.8764330896595155}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.7659372952868275`, -0.8764330896595155], 
            Complex[4.133234044285656, -2.25004936804117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.907529948876621, -0.8764330896595154}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.907529948876621, -0.8764330896595154], 
            Complex[4.133234044285656, -2.25004936804117]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181395760456799, -1.3087210578909678`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.181395760456799, -1.3087210578909678`], 
            Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322988414046595, -1.3087210578909694`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.322988414046595, -1.3087210578909694`], 
            Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309321971491423, 1.300248278779899}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.309321971491423, 1.300248278779899], 
            Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167729317901629, 1.3002482787798992`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.167729317901629, 1.3002482787798992`], 
            Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07714460525703772, -1.789558711273773}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07714460525703772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.789558711273773`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923693993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2566584917561223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[0.07714460525703772, -1.789558711273773], 
            Complex[1.0271831923693993`, -3.2566584917561223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2187372588468346`, -1.7895587112737734`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2187372588468346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895587112737734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923694072`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.256658491756127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[3.2187372588468346`, -1.7895587112737734`], 
            Complex[1.0271831923694072`, -3.256658491756127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.974806567246683, 0.7746773225093266}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.974806567246683, 0.7746773225093266], 
            Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8332139136568895`, 0.7746773225093263}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.8332139136568895`, 0.7746773225093263], 
            Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7667940913479225`, -0.8811430162906054}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.7667940913479225`, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.908386744937716, -0.8811430162906054}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.908386744937716, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181367256390402, -1.3110000275879252`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.181367256390402, -1.3110000275879252`], 
            Complex[7.604277546409371, -2.380230742900865]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322959909980197, -1.3110000275879254`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.322959909980197, -1.3110000275879254`], 
            Complex[7.604277546409373, -2.380230742900865]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30932131716045, 1.3025249977626072`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.30932131716045, 1.3025249977626072`], 
            Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167728663570656, 1.3025249977626074`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.167728663570656, 1.3025249977626074`], 
            Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07687445501670612, -1.7911607892803307`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07687445501670612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7911607892803307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.258334168880775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[0.07687445501670612, -1.7911607892803307`], 
            Complex[1.0264596471562961`, -3.258334168880775]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2184671086065006`, -1.791160789280331}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2184671086065006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.791160789280331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2583341688807756`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[3.2184671086065006`, -1.791160789280331], 
            Complex[1.0264596471562961`, -3.2583341688807756`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.974547487118723, 0.779737595837812}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.974547487118723, 0.779737595837812], 
            Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.83295483352893, 0.7797375958378118}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.83295483352893, 0.7797375958378118], 
            Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.909230841539049, -0.8858091496519155}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.909230841539049, -0.8858091496519155], 
            Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7676381879492564`, -0.8858091496519156}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.7676381879492564`, -0.8858091496519156], 
            Complex[4.136164053701611, -2.260791305494017]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322931591773996, -1.3132681143229277`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.322931591773996, -1.3132681143229277`], 
            Complex[7.604154661093239, -2.382194632873833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181338938184205, -1.3132681143229286`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.181338938184205, -1.3132681143229286`], 
            Complex[7.604154661093243, -2.382194632873834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309320615563188, 1.3047908452057129`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.309320615563188, 1.3047908452057129`], 
            Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167727961973395, 1.304790845205713}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.167727961973395, 1.304790845205713], 
            Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2181987806799732`, -1.79275694039334}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2181987806799732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.79275694039334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025739029953579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[3.2181987806799732`, -1.79275694039334], 
            Complex[1.025739029953579, -3.2600044062938625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07660612709017996, -1.7927569403933397`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07660612709017996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7927569403933397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0257390299535794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[0.07660612709017996, -1.7927569403933397`], 
            Complex[1.0257390299535794`, -3.2600044062938625`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8327057806325184`, 0.7847521968079433}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.8327057806325184`, 0.7847521968079433], 
            Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.974298434222312, 0.7847521968079424}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.974298434222312, 0.7847521968079424], 
            Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.768469952245414, -0.8904323517124777}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.768469952245414, -0.8904323517124777], 
            Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.910062605835208, -0.8904323517124778}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.910062605835208, -0.8904323517124778], 
            Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32290345723042, -1.315525423400987}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.32290345723042, -1.315525423400987], 
            Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.18131080364063, -1.3155254234009877`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.18131080364063, -1.3155254234009877`], 
            Complex[7.604032089130619, -2.384148493285349]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167727214125249, 1.307045926316517}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.167727214125249, 1.307045926316517], 
            Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309319867715043, 1.3070459263165168`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.309319867715043, 1.3070459263165168`], 
            Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2179322564695223`, -1.794347208989231}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2179322564695223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794347208989231`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025021316998925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2616692433664776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[3.2179322564695223`, -1.794347208989231], 
            Complex[1.025021316998925, -3.2616692433664776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07633960287973203, -1.7943472089892278`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07633960287973203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7943472089892278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0250213169989348`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2616692433664767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[0.07633960287973203, -1.7943472089892278`], 
            Complex[1.0250213169989348`, -3.2616692433664767`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.832466418480638, 0.7897219887964373}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.832466418480638, 0.7897219887964373], 
            Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.974059072070432, 0.7897219887964377}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.974059072070432, 0.7897219887964377], 
            Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7692897357415935`, -0.8950134580602265}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.7692897357415935`, -0.8950134580602265], 
            Complex[4.139022292544098, -2.271338727751554]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.910882389331387, -0.8950134580602268}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.910882389331387, -0.8950134580602268], 
            Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322875504189794, -1.3177720585893213`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.322875504189794, -1.3177720585893213`], 
            Complex[7.60390982746478, -2.386092421856075]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181282850600006, -1.3177720585893227`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.181282850600006, -1.3177720585893227`], 
            Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309319074608208, 1.3092903447657454`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.309319074608208, 1.3092903447657454`], 
            Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167726421018415, 1.3092903447657456`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.167726421018415, 1.3092903447657456`], 
            Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07607486404437007, -1.7959316389421525`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07607486404437007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.024306484822421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[0.07607486404437007, -1.7959316389421525`], 
            Complex[1.024306484822421, -3.2633287190256435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2176675176341636`, -1.7959316389421525`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2176675176341636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0243064848224217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[3.2176675176341636`, -1.7959316389421525`], 
            Complex[1.0243064848224217`, -3.2633287190256435`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.973829078826883, 0.7946478095124517}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.973829078826883, 0.7946478095124517], 
            Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.83223642523709, 0.7946478095124515}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.83223642523709, 0.7946478095124515], 
            Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.770097875160309, -0.8995532789895441}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.770097875160309, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.911690528750102, -0.8995532789895441}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.911690528750102, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181255076939699, -1.3200081221474058`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.181255076939699, -1.3200081221474058`], 
            Complex[7.603787873086824, -2.388026514879854]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322847730529492, -1.3200081221474065`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.322847730529492, -1.3200081221474065`], 
            Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167725583622502, 1.311524202717574}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.167725583622502, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309318237212295, 1.311524202717574}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.309318237212295, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2174045460851777`, -1.7975102736315947`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2174045460851777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7975102736315947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2649828717610987`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[3.2174045460851777`, -1.7975102736315947`], 
            Complex[1.0235945102417783`, -3.2649828717610987`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07581189249538411, -1.797510273631595}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07581189249538411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.797510273631595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.264982871761099`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[0.07581189249538411, -1.797510273631595], 
            Complex[1.0235945102417785`, -3.264982871761099]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.832015492909507, 0.7995304720360317}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.832015492909507, 0.7995304720360317], 
            Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.973608146499301, 0.7995304720360318}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.973608146499301, 0.7995304720360318], 
            Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.770894693249766, -0.9040526005333875}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.770894693249766, -0.9040526005333875], 
            Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.912487346839559, -0.904052600533387}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.912487346839559, -0.904052600533387], 
            Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322820134163065, -1.322233714856279}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.322820134163065, -1.322233714856279], 
            Complex[7.603666223034595, -2.389950867251501]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181227480573279, -1.32223371485628}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.181227480573279, -1.32223371485628], 
            Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.16772470288514, 1.313747600858923}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.16772470288514, 1.313747600858923], 
            Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309317356474933, 1.3137476008589228`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.309317356474933, 1.3137476008589228`], 
            Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.217143323981706, -1.7990831559498917`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.217143323981706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.266631739631969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[3.217143323981706, -1.7990831559498917`], 
            Complex[1.0228853703576102`, -3.266631739631969]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07555067039191275, -1.7990831559498914`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07555067039191275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2666317396319684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[0.07555067039191275, -1.7990831559498914`], 
            Complex[1.0228853703576115`, -3.2666317396319684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9733959801858845`, 0.8043707658042932}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.9733959801858845`, 0.8043707658042932], 
            Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8318033265960922`, 0.8043707658042935}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.8318033265960922`, 0.8043707658042935], 
            Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.771680499538499, -0.9085121854432784}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.771680499538499, -0.9085121854432784], 
            Complex[4.143183206373633, -2.286811288665357]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.913273153128292, -0.9085121854432785}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.913273153128292, -0.9085121854432785], 
            Complex[4.143183206373633, -2.286811288665357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181200059449696, -1.32444893604715}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.181200059449696, -1.32444893604715], 
            Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.32279271303949, -1.32444893604715}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.32279271303949, -1.32444893604715], 
            Complex[7.603544874391759, -2.391865572493939]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167723779732554, 1.3159606384280345`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.167723779732554, 1.3159606384280345`], 
            Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309316433322348, 1.3159606384280351`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.309316433322348, 1.3159606384280351`], 
            Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07529118013665538, -1.8006503283095583`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07529118013665538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8006503283095583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0221790425488162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.26827536027329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[0.07529118013665538, -1.8006503283095583`], 
            Complex[1.0221790425488162`, -3.26827536027329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2168838337264507`, -1.8006503283095574`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2168838337264507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8006503283095574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.022179042548827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.268275360273292`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[3.2168838337264507`, -1.8006503283095574`], 
            Complex[1.022179042548827, -3.268275360273292]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8315996437819138`, 0.8091694575484238}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.8315996437819138`, 0.8091694575484238], 
            Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.973192297371707, 0.8091694575484238}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.973192297371707, 0.8091694575484238], 
            Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.772455591040422, -0.9129327741202401}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.772455591040422, -0.9129327741202401], 
            Complex[4.1445381709548, -2.291879330010544]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.914048244630215, -0.9129327741202411}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.914048244630215, -0.9129327741202411], 
            Complex[4.1445381709548, -2.291879330010546]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{6.1811728115525035`, -1.3266538836292885`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.1811728115525035`, -1.3266538836292885`], 
            Complex[7.603423824286758, -2.393770722784648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322765465142302, -1.326653883629291}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.322765465142302, -1.326653883629291], 
            Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167722815070127, 1.3181634132423612`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.167722815070127, 1.3181634132423612`], 
            Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309315468659923, 1.3181634132423605`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.309315468659923, 1.3181634132423605`], 
            Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.07503340437166661, -1.802211832650498}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07503340437166661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.802211832650498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681099`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2699137709024373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[0.07503340437166661, -1.802211832650498], 
            Complex[1.0214755044681099`, -3.2699137709024373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2166260579614594`, -1.8022118326504983`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2166260579614594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8022118326504983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.269913770902438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[3.2166260579614594`, -1.8022118326504983`], 
            Complex[1.0214755044681103`, -3.269913770902438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8314041736809603`, 0.8139272921843714}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.8314041736809603`, 0.8139272921843714], 
            Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.972996827270754, 0.8139272921843711}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.972996827270754, 0.8139272921843711], 
            Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.773220252914124, -0.9173150854995425}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.773220252914124, -0.9173150854995425], 
            Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.914812906503919, -0.9173150854995431}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.914812906503919, -0.9173150854995431], 
            Complex[4.145877797348456, -2.296904005989524]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181145734899095, -1.3288486541172821`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.181145734899095, -1.3288486541172821`], 
            Complex[7.603303069891951, -2.395666408981522]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322738388488887, -1.3288486541172835`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.322738388488887, -1.3288486541172835`], 
            Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167721809782957, 1.3203560217257764`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.167721809782957, 1.3203560217257764`], 
            Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30931446337276, 1.3203560217257788`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.30931446337276, 1.3203560217257788`], 
            Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2163699795640026`, -1.8037677104470822`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2163699795640026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.020774734037491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2715470083253844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[3.2163699795640026`, -1.8037677104470822`], 
            Complex[1.020774734037491, -3.2715470083253844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0747773259742065, -1.8037677104470848`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0747773259742065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0207747340374922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2715470083253804`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[0.0747773259742065, -1.8037677104470848`], 
            Complex[1.0207747340374922`, -3.2715470083253804`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.972809310210266, 0.8186449936599097}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.972809310210266, 0.8186449936599097], 
            Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8312166566204735`, 0.8186449936599106}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.8312166566204735`, 0.8186449936599106], 
            Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9155674126696605`, -0.9216598178919517}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.9155674126696605`, -0.9216598178919517], 
            Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7739747590798687`, -0.9216598178919512}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.7739747590798687`, -0.9216598178919512], 
            Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181118827539914, -1.3310333426575782`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.181118827539914, -1.3310333426575782`], 
            Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322711481129714, -1.331033342657582}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.322711481129714, -1.331033342657582], 
            Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167720764736373, 1.322538558935139}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.167720764736373, 1.322538558935139], 
            Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.30931341832617, 1.3225385589351384`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.30931341832617, 1.3225385589351384`], 
            Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.216115581642531, -1.805318002715075}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.216115581642531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.27317510894289`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[3.216115581642531, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.27317510894289]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.0745229280527381, -1.805318002715075}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0745229280527381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.273175108942891`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[0.0745229280527381, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.273175108942891]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8310368434643864`, 0.8233232657606014}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.8310368434643864`, 0.8233232657606014], 
            Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9726294970541804`, 0.8233232657606012}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.9726294970541804`, 0.8233232657606012], 
            Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.916312026387238, -0.925967649783973}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.916312026387238, -0.925967649783973], 
            Complex[4.148512526970577, -2.306826396101707]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.774719372797445, -0.9259676497839711}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.774719372797445, -0.9259676497839711], 
            Complex[4.148512526970578, -2.306826396101705]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1810920875578015`, -1.3332080430544786`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.1810920875578015`, -1.3332080430544786`], 
            Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322684741147594, -1.3332080430544797`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.322684741147594, -1.3332080430544797`], 
            Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309312334366247, 1.3247111185862175`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.309312334366247, 1.3247111185862175`], 
            Complex[7.6230493091457, 0.04531544750647416]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167719680776454, 1.3247111185862182`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.167719680776454, 1.3247111185862182`], 
            Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{3.2158628475327276`, -1.8068627500184498`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2158628475327276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8068627500184498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[3.2158628475327276`, -1.8068627500184498`], 
            Complex[1.0193814091354683`, -3.2747981087565443`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{0.07427019394292937, -1.8068627500184438`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07427019394292937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8068627500184438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565288`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[0.07427019394292937, -1.8068627500184438`], 
            Complex[1.0193814091354747`, -3.2747981087565288`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.972457148662774, 0.8279627928769886}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.972457148662774, 0.8279627928769886], 
            Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8308644950729818`, 0.8279627928769887}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.8308644950729818`, 0.8279627928769887], 
            Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.917047000797618, -0.9302392405994727}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.917047000797618, -0.9302392405994727], 
            Complex[4.149808341378717, -2.311725622493254]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.775454347207829, -0.9302392405994732}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.775454347207829, -0.9302392405994732], 
            Complex[4.149808341378721, -2.311725622493254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.181065513067208, -1.3353728477954119`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.181065513067208, -1.3353728477954119`], 
            Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322658166657003, -1.3353728477954119`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.322658166657003, -1.3353728477954119`], 
            Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309311212320324, 1.3268737930790047`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.309311212320324, 1.3268737930790047`], 
            Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.167718558730529, 1.326873793079005}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.167718558730529, 1.326873793079005], 
            Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{0.0740191072038374, -1.8084019924760677`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0740191072038374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2764160433747036`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[0.0740191072038374, -1.8084019924760677`], 
            Complex[1.0186888118162511`, -3.2764160433747036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2156117607936308`, -1.8084019924760657`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2156117607936308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.276416043374702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[3.2156117607936308`, -1.8084019924760657`], 
            Complex[1.0186888118162514`, -3.276416043374702]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.97229203538588, 0.8325642407352367}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.97229203538588, 0.8325642407352367], 
            Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8306993817960873`, 0.8325642407352367}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.8306993817960873`, 0.8325642407352367], 
            Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.9177725794310545`, -0.9344752314248252}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.9177725794310545`, -0.9344752314248252], 
            Complex[4.15109024131099, -2.316584509692523]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.776179925841262, -0.9344752314248258}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.776179925841262, -0.9344752314248258], 
            Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.322631755803343, -1.3375278480756927`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.322631755803343, -1.3375278480756927`], 
            Complex[7.602822954346447, -2.40315628519697]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1810391022135605`, -1.337527848075709}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1810391022135605`, -1.337527848075709], 
            Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1677173994076595`, 1.3290266735224265`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1677173994076595`, 1.3290266735224265`], 
            Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.309310052997454, 1.3290266735224268`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.309310052997454, 1.3290266735224268`], 
            Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
          "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->800,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{
        TagBox[
         TooltipBox[PointBox[{1.5874585404782842`, -2.4355245210240004`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4905971192945886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8383554163654704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210240003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.4905971192945886, -0.8383554163654704], 
            Complex[1.5874585404782842`, -2.3355245210240003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5874585404782884`, -2.3355245210239963`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.632189772884385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8383554163654666`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5874585404782884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210239963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.632189772884385, -0.8383554163654666], 
            Complex[1.5874585404782884`, -2.3355245210239963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7951626777960403`, -2.2401483895471044`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[0.6980000948375882, -0.6433017314670934], 
            Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.7951626777960417`, -2.1401483895471043`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[3.8395927484273833`, -0.6433017314670934], 
            Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.196232266214944, -1.2633793876684916`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.6944263543752545`, 0.006645071137818129], 
            Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.1962322662149445`, -1.1633793876684915`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.8360190079650485`, 0.006645071137818026], 
            Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.478753355849043, -1.2631402225643318`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[4.976967927486167, 0.006887727487396918], 
            Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.478753355849045, -1.1631402225643317`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[8.118560581075961, 0.0068877274873969585`], 
            Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.80001605246603, -1.2961486271318057`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.398301539299036, -0.01324317030169907], 
            Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.80001605246603, -1.1961486271318056`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.53989419288883, -0.01324317030169899], 
            Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.094218012734007, -1.1949707911251923`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.834135988275976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01205573978218699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.094218012734007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[10.834135988275976`, -0.01205573978218699], 
            Complex[9.094218012734007, -1.1949707911251923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.09421801273401, -1.2949707911251924`}],
          RowBox[{"{", 
            RowBox[{"15.999999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.692543334686185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.012055739782186827`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.09421801273401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {15.999999999999998`, {
            Complex[7.692543334686185, -0.012055739782186827`], 
            Complex[9.09421801273401, -1.1949707911251923`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.5611274843968284`, -2.4644087056291824`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.46502963264100744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.868215310870579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291823`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.46502963264100744`, -0.868215310870579], 
            Complex[1.5611274843968284`, -2.3644087056291823`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5611274843968312`, -2.3644087056291787`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6066222862308037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8682153108705755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5611274843968312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291787`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.6066222862308037`, -0.8682153108705755], 
            Complex[1.5611274843968312`, -2.3644087056291787`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8301368298409664`, -2.2120211819719593`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[0.7333882582665036, -0.6165221792948049], 
            Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8301368298409684`, -2.112021181971957}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[3.8749809118562997`, -0.6165221792948034], 
            Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.155525231634676, -1.2633781485602358`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[4.654309125631486, 0.006712510785854934], 
            Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.155525231634676, -1.1633781485602357`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.795901779221279, 0.006712510785854963], 
            Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.5221587863983865`, -1.1630554690196342`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[8.162580737731858, 0.007042959985370651], 
            Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.52215878639839, -1.2630554690196363`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[5.020988084142068, 0.007042959985368871], 
            Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.75509227462806, -1.2963255671672886`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.352914113679207, -0.013509876715323901`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.75509227462806, -1.1963255671672886`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.494506767269, -0.013509876715323853`], 
            Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.136933552574833, -1.1947860159220576`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.876435471981889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011949285676122938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.136933552574833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[10.876435471981889`, -0.011949285676122938`], 
            Complex[9.136933552574833, -1.1947860159220576`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.13693355257484, -1.2947860159220668`}],
          RowBox[{"{", 
            RowBox[{"16.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.734842818392103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01194928567613202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.13693355257484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.099999999999998`, {
            Complex[7.734842818392103, -0.01194928567613202], 
            Complex[9.13693355257484, -1.1947860159220667`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.540510310333603, -2.4877804035408326`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4451990626513003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.540510310333603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3877804035408325`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.4451990626513003, -0.8925142454403411], 
            Complex[1.540510310333603, -2.3877804035408325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5405103103336057`, -2.387780403540836}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5867917162410965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5405103103336057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.387780403540836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.5867917162410965`, -0.8925142454403441], 
            Complex[1.5405103103336057`, -2.387780403540836]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.859366613529833, -2.0894057490922258`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[3.9045700992025902`, -0.5952855745698094], 
            Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8593666135298341`, -2.1894057490922227`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[0.7629774456127986, -0.5952855745698065], 
            Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.122517060306257, -1.263371113059422}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[4.621891868208896, 0.006786025025047798], 
            Complex[6.122517060306257, -1.163371113059422]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.122517060306264, -1.1633711130594213`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.763484521798694, 0.006786025025048383], 
            Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.557943371421671, -1.262972548762566}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[5.05739532427709, 0.007197843246654808], 
            Complex[6.557943371421671, -1.162972548762566]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.557943371421671, -1.162972548762566}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[8.198987977866883, 0.007197843246654797], 
            Complex[6.557943371421671, -1.162972548762566]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.718101741665087, -1.2964748219538675`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.315449803449272, -0.01375104485251276], 
            Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.71810174166509, -1.1964748219538672`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.457042457039066`, -0.013751044852512806`], 
            Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.17164822418722, -1.2946325841924502`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.769143367766525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011873440576434954`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.17164822418722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.19463258419245`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.2, {
            Complex[7.769143367766525, -0.011873440576434954`], 
            Complex[9.17164822418722, -1.19463258419245]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.171648224187221, -1.1946325841924512`}],
          RowBox[{"{", 
            RowBox[{"16.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.910736021356321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011873440576436094`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.171648224187221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1946325841924512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.2, {
            Complex[10.910736021356321`, -0.011873440576436094`], 
            Complex[9.171648224187221, -1.1946325841924512`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.523224587548502, -2.5079083765075176`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4287165628002437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.523224587548502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4079083765075175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.4287165628002437, -0.9135287061735121], 
            Complex[1.523224587548502, -2.4079083765075175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5232245875485029`, -2.407908376507515}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5703092163900387`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735095`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5232245875485029`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.407908376507515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.5703092163900387`, -0.9135287061735095], 
            Complex[1.5232245875485029`, -2.407908376507515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8852354657886536`, -2.0700333477056216`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[3.93075079131323, -0.5773156862277917], 
            Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.8852354657886545`, -2.1700333477056217`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[0.7891581377234371, -0.5773156862277916], 
            Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.093988110787665, -1.1633606215314773`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.735547972440535, 0.006863336573144897], 
            Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.093988110787665, -1.2633606215314777`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[4.593955318850742, 0.0068633365731448895`], 
            Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.589330078860689, -1.1628888789503151`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[8.231005147885755, 0.0073549519610065905`], 
            Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.5893300788606926`, -1.26288887895032}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[5.089412494295966, 0.007354951961001998], 
            Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.685690080337723, -1.296609721074035}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.282554763488937, -0.01397986959845826], 
            Complex[8.685690080337723, -1.196609721074035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.685690080337725, -1.1966097210740347`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.42414741707873, -0.0139798695984579], 
            Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.20171331881034, -1.2944974025641371`}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.798795489744536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01181529831920876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[7.798795489744536, -0.01181529831920876], 
            Complex[9.20171331881034, -1.194497402564137]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.20171331881034, -1.194497402564137}],
          RowBox[{"{", 
            RowBox[{"16.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.94038814333433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011815298319208752`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.299999999999997`, {
            Complex[10.94038814333433, -0.011815298319208752`], 
            Complex[9.20171331881034, -1.194497402564137]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.508185994680368, -2.5258284901011865`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.4144938153406103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.508185994680368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4258284901011864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.4144938153406103, -0.9322995873452282], 
            Complex[1.508185994680368, -2.4258284901011864`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.5081859946803688`, -2.4258284901011873`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5560864689304044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452297`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.5081859946803688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4258284901011873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.5560864689304044`, -0.9322995873452297], 
            Complex[1.5081859946803688`, -2.4258284901011873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.908828689419144, -2.152868131119601}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[0.813020240902394, -0.5615718710865851], 
            Complex[1.908828689419144, -2.052868131119601]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9088286894191442`, -2.0528681311196006`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[3.9546128944921874`, -0.5615718710865847], 
            Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.068475300453683, -1.2633476974009692`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[4.569036631840206, 0.006943461497604872], 
            Complex[6.068475300453683, -1.163347697400969]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.068475300453683, -1.1633476974009693`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.710629285429999, 0.00694346149760476], 
            Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.61778553109412, -1.262803172863648}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[5.118506250669166, 0.007515591774090762], 
            Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.61778553109412, -1.162803172863648}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[8.260098904258959, 0.007515591774090756], 
            Complex[6.61778553109412, -1.162803172863648]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.656331133890319, -1.2967364397628116`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.252703058118813, -0.014202465960727835`], 
            Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.656331133890323, -1.1967364397628084`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.39429571170861, -0.014202465960725278`], 
            Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.228651705652085, -1.1943745527422884`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.966914215304485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011769056829642613`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.4, {
            Complex[10.966914215304485`, -0.011769056829642613`], 
            Complex[9.228651705652085, -1.1943745527422884`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.228651705652094, -1.2943745527422954`}],
          RowBox[{"{", 
            RowBox[{"16.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.8253215617147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011769056829649287`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.228651705652094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.4, {
            Complex[7.8253215617147, -0.011769056829649287`], 
            Complex[9.228651705652094, -1.1943745527422953`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4947924622029343`, -2.4421177901257014`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.543518627975134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4947924622029343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.543518627975134, -0.9494075862605201], 
            Complex[1.4947924622029343`, -2.4421177901257014`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.494792462202936, -2.5421177901257015`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.40192597438534255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.494792462202936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.40192597438534255`, -0.9494075862605198], 
            Complex[1.494792462202936, -2.4421177901257014`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9307493118589238`, -2.0373330727564842`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[3.976762799482182, -0.5474736791133854], 
            Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9307493118589267`, -2.137333072756486}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[0.835170145892391, -0.5474736791133877], 
            Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.045167287063116, -1.263332885610651}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[4.5463246331431195`, 0.007025882918871681], 
            Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.045167287063117, -1.163332885610651}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.687917286732913, 0.007025882918871702], 
            Complex[6.045167287063117, -1.163332885610651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.644124842294815, -1.162714599075609}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[8.287084479515974, 0.007680628289981289], 
            Complex[6.644124842294815, -1.162714599075609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.644124842294816, -1.26271459907561}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[5.145491825926181, 0.007680628289980853], 
            Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.629176867782464, -1.196858523000041}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.366639367283945`, -0.014422357660350082`], 
            Complex[8.629176867782464, -1.196858523000041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.629176867782464, -1.296858523000041}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.225046713694154, -0.01442235766034999], 
            Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.25330790754526, -1.2942607697912125`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.849565759088899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011731532239340082`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.25330790754526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912124`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[7.849565759088899, -0.011731532239340082`], 
            Complex[9.25330790754526, -1.1942607697912124`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{9.253307907545267, -1.1942607697912035`}],
          RowBox[{"{", 
            RowBox[{"16.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.991158412678699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011731532239331113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"9.253307907545267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.499999999999996`, {
            Complex[10.991158412678699`, -0.011731532239331113`], 
            Complex[9.253307907545267, -1.1942607697912035`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4826686902970199`, -2.557137190679493}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.39063568307703384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.457137190679493`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.39063568307703384`, -0.9652164447599751], 
            Complex[1.4826686902970199`, -2.457137190679493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4826686902970212`, -2.45713719067949}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.532228336666828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4826686902970212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.45713719067949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.532228336666828, -0.9652164447599713], 
            Complex[1.4826686902970212`, -2.45713719067949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9513735684640627`, -2.123067278104828}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[0.8559867126628703, -0.5346576120369388], 
            Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.951373568464064, -2.0230672781048282`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[3.997579366252664, -0.5346576120369394], 
            Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.023558855884933, -1.2633165105631812`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[4.5253142371097725`, 0.007110298008162873], 
            Complex[6.023558855884933, -1.163316510563181]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.023558855884935, -1.163316510563181}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.666906890699567, 0.007110298008162871], 
            Complex[6.023558855884935, -1.163316510563181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.668857252414806, -1.2626225207983641`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[5.170878634413056, 0.007850743160533592], 
            Complex[6.668857252414806, -1.162622520798364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.668857252414808, -1.1626225207983634`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[8.312471288002852, 0.00785074316053409], 
            Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.603697599379137, -1.2969782988821368`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[7.199056007873823, -0.014641876121436175`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.603697599379137, -1.1969782988821367`}],
          RowBox[{"{", 
            RowBox[{"16.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.599999999999998`, {
            Complex[10.340648661463618`, -0.014641876121436062`], 
            Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4715621017597873`, -2.471130430093209}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5219614272863144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9799721862678735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.471130430093209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[3.5219614272863144`, -0.9799721862678735], 
            Complex[1.4715621017597873`, -2.471130430093209]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4715621017597882`, -2.5711304300932105`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.38036877369652167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9799721862678751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4715621017597882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4711304300932104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.38036877369652167`, -0.9799721862678751], 
            Complex[1.4715621017597882`, -2.4711304300932104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.970954950697273, -2.009827028796297}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.017318225749185, -0.5228778864146391], 
            Complex[1.970954950697273, -2.009827028796297]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9709549506972748`, -2.109827028796298}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[0.8757255721593927, -0.52287788641464], 
            Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.003310291269154, -1.2632987794618458`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[4.5056658326490995`, 0.007196517077880139], 
            Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.0033102912691545`, -1.163298779461846}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.6472584862388935`, 0.007196517077880152], 
            Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.6923267792271615`, -1.2625263894330447`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[5.19501091123548, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.6923267792271615`, -1.1625263894330444`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[8.336603564825275, 0.00802653852897203], 
            Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.579535601926914, -1.2970974543173976`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.7, {
            Complex[7.174373102447971, -0.014862729232274653`], 
            Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.579535601926915, -1.1970974543173976`}],
          RowBox[{"{", 
            RowBox[{"16.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.7, {
            Complex[10.315965756037766`, -0.014862729232274637`], 
            Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4612931389803365`, -2.484271399542434}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5125370745305697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9938506052393002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.484271399542434`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[3.5125370745305697`, -0.9938506052393002], 
            Complex[1.4612931389803365`, -2.484271399542434]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4612931389803379`, -2.5842713995424336`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.37094442094077773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9938506052392997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4612931389803379`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4842713995424335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.37094442094077773`, -0.9938506052392997], 
            Complex[1.4612931389803379`, -2.4842713995424335`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9896739101964112`, -1.997438454007966}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.036161628380458, -0.5119589442981466], 
            Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.9896739101964132`, -2.0974384540079685`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[0.8945689747906652, -0.5119589442981493], 
            Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.984180253839811, -1.1632798309089558`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.628730822140306, 0.0072844163322486775`], 
            Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.984180253839812, -1.2632798309089608`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[4.487138168550514, 0.007284416332243672], 
            Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.7147793676173775`, -1.2624256923931878`}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[5.2181348551047995`, 0.008208588338762854], 
            Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.714779367617378, -1.162425692393188}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[8.359727508694593, 0.008208588338762687], 
            Complex[6.714779367617378, -1.162425692393188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.556435217312076, -1.297217311276035}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[7.1507421714555965`, -0.015086273942248003`], 
            Complex[8.556435217312076, -1.197217311276035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.556435217312078, -1.197217311276035}],
          RowBox[{"{", 
            RowBox[{"16.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.799999999999997`, {
            Complex[10.29233482504539, -0.015086273942248], 
            Complex[8.556435217312078, -1.197217311276035]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4517287827631644`, -2.5966893902296495`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3622285720771921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0069826142874234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.3622285720771921, -1.0069826142874234`], 
            Complex[1.4517287827631644`, -2.4966893902296494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4517287827631657`, -2.4966893902296525`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.503821225666987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.006982614287426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4517287827631657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296525`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[3.503821225666987, -1.006982614287426], 
            Complex[1.4517287827631657`, -2.4966893902296525`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.007664340945304, -2.0857722832958543`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[0.9126523619522108, -0.5017701062164057], 
            Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0076643409453054`, -1.985772283295857}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.054245015542006, -0.5017701062164085], 
            Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.965990045977094, -1.2632597604074918`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[4.469552623884141, 0.007373913179256361], 
            Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.965990045977096, -1.1632597604074917`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.611145277473936, 0.007373913179256576], 
            Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.736398653893472, -1.1623199234705246`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[8.382027043209192, 0.008397467701836855], 
            Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.736398653893472, -1.262319923470525}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[5.240434389619399, 0.00839746770183686], 
            Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.534205636043778, -1.1973389757687454`}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {16.9, {
            Complex[10.269564843263957`, -0.01531366326459591], 
            Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.534205636043778, -1.297338975768746}],
          RowBox[{"{", 
            RowBox[{"16.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {16.9, {
            Complex[7.127972189674163, -0.015313663264596189`], 
            Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.44276726787218, -2.608483683764771}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3541186043574641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.44276726787218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.508483683764771`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.3541186043574641, -1.0194689005855264`], 
            Complex[1.44276726787218, -2.508483683764771]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4427672678721806`, -2.5084836837647715`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4957112579472582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4427672678721806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5084836837647715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[3.4957112579472582`, -1.0194689005855273`], 
            Complex[1.4427672678721806`, -2.5084836837647715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.02502886467753, -2.0747292562304525`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[0.9300797102089358, -0.4922109148816913], 
            Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0250288646775303`, -1.9747292562304544`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[4.071672363798729, -0.49221091488169333`], 
            Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.948603001807254, -1.1632386348615993`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[7.5943652547457265`, 0.0074649522520338], 
            Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.948603001807257, -1.2632386348615994`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[4.452772601155936, 0.007464952252033912], 
            Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.757326609412581, -1.1622085635431991`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[8.40364445944282, 0.008593772293729832], 
            Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.757326609412582, -1.2622085635431994`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[5.262051805853028, 0.008593772293729816], 
            Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.512699415121855, -1.2974634260014826`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17., {
            Complex[7.1059154551031405`, -0.015545933419028879`], 
            Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.512699415121856, -1.1974634260014816`}],
          RowBox[{"{", 
            RowBox[{"17.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17., {
            Complex[10.247508108692935`, -0.01554593341902805], 
            Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4343287018663795`, -2.619732518631919}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3465339039238557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.031388938053689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631919`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.3465339039238557, -1.031388938053689], 
            Complex[1.4343287018663795`, -2.519732518631919]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4343287018663806`, -2.519732518631915}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4881265575136493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0313889380536854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4343287018663806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631915`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[3.4881265575136493`, -1.0313889380536854`], 
            Complex[1.4343287018663806`, -2.519732518631915]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0418482129451156`, -2.064231155946584}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[0.9469329539089921, -0.48320212310888055`], 
            Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0418482129451156`, -1.9642311559465844`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.088525607498785, -0.4832021231088809], 
            Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.931911846413442, -1.1632165013453948`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.5782835412454626`, 0.0075574969911607935`], 
            Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.931911846413443, -1.2632165013453924`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[4.436690887655669, 0.007557496991163237], 
            Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.777676219425206, -1.2620910662296874`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[5.283100441464033, 0.008798133065178963], 
            Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.777676219425206, -1.1620910662296873`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[8.424693095053826, 0.00879813306517896], 
            Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.491799285559544, -1.2975915689762858`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[7.084454398670628, -0.015784060035230123`], 
            Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.491799285559544, -1.1975915689762857`}],
          RowBox[{"{", 
            RowBox[{"17.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.099999999999998`, {
            Complex[10.226047052260421`, -0.01578406003523005], 
            Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4263490191882378`, -2.630498876235687}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33940979143382616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0428068062799807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.530498876235687`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.33940979143382616`, -1.0428068062799807`], 
            Complex[1.4263490191882378`, -2.530498876235687]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4263490191882389`, -2.5304988762356877`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4810024450236203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0428068062799816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4263490191882389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5304988762356877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[3.4810024450236203`, -1.0428068062799816`], 
            Complex[1.4263490191882389`, -2.5304988762356877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.058187273894044, -1.9542150231143423`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.104870714597597, -0.4746798749981737], 
            Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0581872738940445`, -2.0542150231143457`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[0.9632780610078037, -0.47467987499817715`], 
            Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.91583055481642, -1.2631933926704506`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                  RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[4.421221515937318, 0.0076515243225991425`], 
            Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.915830554816423, -1.163193392670451}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.5628141695271145`, 0.007651524322598731], 
            Complex[5.915830554816423, -1.163193392670451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.797539667322055, -1.261966845801127}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[5.303672866164795, 0.009011228909084937], 
            Complex[6.797539667322055, -1.161966845801127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.797539667322055, -1.161966845801127}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[8.445265519754589, 0.009011228909084963], 
            Complex[6.797539667322055, -1.161966845801127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.471409637754663, -1.297724279804307}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.2, {
            Complex[7.063493070122277, -0.01602899750358731], 
            Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.471409637754663, -1.1977242798043068`}],
          RowBox[{"{", 
            RowBox[{"17.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.2, {
            Complex[10.20508572371207, -0.016028997503587203`], 
            Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.418775926679894, -2.6408343661536398`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.33269344666361156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.418775926679894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5408343661536397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.33269344666361156`, -1.0537751001493318`], 
            Complex[1.418775926679894, -2.5408343661536397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4187759266798956`, -2.5408343661536392`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.474286100253405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4187759266798956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5408343661536392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[3.474286100253405, -1.0537751001493318`], 
            Complex[1.4187759266798956`, -2.5408343661536392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0740991475740485`, -2.0446292707044913`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[0.9791691098460469, -0.46659179640833603`], 
            Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.0740991475740485`, -1.9446292707044917`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.12076176343584, -0.46659179640833626`], 
            Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.900288896133161, -1.2631693310632666`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[4.406294309063904, 0.007747021157202576], 
            Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.900288896133163, -1.1631693310632691`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.547886962653699, 0.00774702115719995], 
            Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.816993839756789, -1.2618352658470922`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[5.323846388854408, 0.00923379877093513], 
            Complex[6.816993839756789, -1.161835265847092]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.8169938397567895`, -1.161835265847092}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[8.465439042444201, 0.009233798770935121], 
            Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.451450795228002, -1.2978624312936875`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[7.042951411025012, -0.016281708942805718`], 
            Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.451450795228004, -1.1978624312936872`}],
          RowBox[{"{", 
            RowBox[{"17.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.299999999999997`, {
            Complex[10.184544064614805`, -0.016281708942805753`], 
            Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4115660932135865`, -2.5507819227528166`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4679337359736433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.06433764500318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[3.4679337359736433`, -1.06433764500318], 
            Complex[1.4115660932135865`, -2.5507819227528166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.4115660932135874`, -2.6507819227528135`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32634108238384935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0643376450031767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4115660932135874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.32634108238384935`, -1.0643376450031767`], 
            Complex[1.4115660932135874`, -2.5507819227528135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.089627957098804, -1.9354309873904456`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.13624377018248, -0.4588942798973108], 
            Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.089627957098805, -2.0354309873904426`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[0.9946511165926878, -0.45889427989730874`], 
            Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.885228654304801, -1.2631443306747423`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[4.391851102143664, 0.007843982012263403], 
            Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.885228654304802, -1.1631443306747424`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.533443755733459, 0.007843982012263152], 
            Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.836104162316991, -1.1616956277315167`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[8.485279549606197, 0.009466654168547486], 
            Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.836104162316992, -1.2616956277315166`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[5.343686896016404, 0.009466654168547547], 
            Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.431855025955324, -1.2980069181435885`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.4, {
            Complex[7.022761264330782, -0.01654319107188898], 
            Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.431855025955324, -1.1980069181435884`}],
          RowBox[{"{", 
            RowBox[{"17.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.4, {
            Complex[10.164353917920575`, -0.016543191071888914`], 
            Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.4046831465120544`, -2.6603777298614024`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.32031592905730694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.4046831465120544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5603777298614023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[0.32031592905730694`, -1.0745314357254354`], 
            Complex[1.4046831465120544`, -2.5603777298614023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.404683146512056, -2.560377729861402}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4619085826471014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.404683146512056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.560377729861402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[3.4619085826471014`, -1.0745314357254354`], 
            Complex[1.404683146512056, -2.560377729861402]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1048108525831077`, -1.9265840128958314`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.151354705396683, -0.4515505457349306], 
            Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1048108525831113`, -2.026584012895829}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[1.009762051806893, -0.45155054573492875`], 
            Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.870600935988343, -1.2631183993398405`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[4.377843050837108, 0.007942407351021055], 
            Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.870600935988343, -1.1631183993398404`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.5194357044269005`, 0.007942407351021058], 
            Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.854927356440139, -1.2615471581185316`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[5.363251612071681, 0.009710692858210855], 
            Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.854927356440139, -1.1615471581185317`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[8.504844265661474, 0.009710692858210806], 
            Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.412563676597296, -1.2981586784333552`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.5, {
            Complex[7.002863505905769, -0.016814496662831985`], 
            Complex[8.412563676597296, -1.198158678433355]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.412563676597298, -1.1981586784333549`}],
          RowBox[{"{", 
            RowBox[{"17.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.5, {
            Complex[10.144456159495563`, -0.016814496662831836`], 
            Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.398096210752566, -2.5696526277620455`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4561794165348236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501943`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.398096210752566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5696526277620455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[3.4561794165348236`, -1.0843880551501943`], 
            Complex[1.398096210752566, -2.5696526277620455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3980962107525663`, -2.6696526277620443`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.3145867629450303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3980962107525663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.569652627762044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[0.3145867629450303, -1.0843880551501937`], 
            Complex[1.3980962107525663`, -2.569652627762044]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.119679474265541, -2.018057531021162}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[1.024534313536096, -0.4445292235923795], 
            Complex[2.119679474265541, -1.918057531021162]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.119679474265542, -1.918057531021161}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.166126967125889, -0.44452922359237873`], 
            Complex[2.119679474265542, -1.918057531021161]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.856364206404795, -1.2630915398400686`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[4.3642286676832285`, 0.00804230239670521], 
            Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.856364206404795, -1.1630915398400685`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[7.5058213212730225`, 0.008042302396705316], 
            Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.873513478358425, -1.1613889949346565`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[8.52418379610039, 0.00996691431009624], 
            Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.873513478358427, -1.2613889949346566`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[5.382591142510598, 0.009966914310096187], 
            Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.39352505422987, -1.2983187142405295`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[6.983205922649462, -0.017096756417673678`], 
            Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.393525054229872, -1.1983187142405292`}],
          RowBox[{"{", 
            RowBox[{"17.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.599999999999998`, {
            Complex[10.124798576239256`, -0.017096756417673668`], 
            Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3917788166049048`, -2.6786331633102036`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30912680858594205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939347333651805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[0.30912680858594205`, -1.0939347333651805`], 
            Complex[1.3917788166049048`, -2.5786331633102035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3917788166049063`, -2.5786331633102058`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4507194621757376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939347333651823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3917788166049063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[3.4507194621757376`, -1.0939347333651823`], 
            Complex[1.3917788166049063`, -2.5786331633102058`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1342610431682947`, -1.9098250195461792`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.180588479578346, -0.43780329333443724`], 
            Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.134261043168297, -2.009825019546178}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[1.0389958259885552`, -0.43780329333443724`], 
            Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.842482826256841, -1.2630637508268274`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[4.350972359395372, 0.008143676269233574], 
            Complex[5.842482826256841, -1.1630637508268273`]}, -1}, "Tooltip"]
         & ], 
        TagBox[
         TooltipBox[PointBox[{5.842482826256841, -1.1630637508268273`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[7.492565012985164, 0.008143676269233487], 
            Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.891907468896068, -1.2612201711252071`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[5.401751028707841, 0.010236437677199473`], 
            Complex[6.891907468896068, -1.161220171125207]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.891907468896068, -1.161220171125207}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[8.543343682297635, 0.01023643767719948], 
            Complex[6.891907468896068, -1.161220171125207]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.374692817528384, -1.1984881127881408`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.7, {
            Complex[10.105334252708913`, -0.017391201699304026`], 
            Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.374692817528384, -1.2984881127881411`}],
          RowBox[{"{", 
            RowBox[{"17.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.7, {
            Complex[6.963741599119119, -0.017391201699304113`], 
            Complex[8.374692817528384, -1.198488112788141]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.385708073986173, -2.687342388059074}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.30391290545435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1031951533323334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.385708073986173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[0.30391290545435, -1.1031951533323334`], 
            Complex[1.385708073986173, -2.587342388059074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3857080739861731`, -2.587342388059074}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4455055590441432`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1031951533323339`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3857080739861731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[3.4455055590441432`, -1.1031951533323339`], 
            Complex[1.3857080739861731`, -2.587342388059074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.148579189013271, -1.9018634521265059`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.194763527568909, -0.43134927949335283`], 
            Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.148579189013272, -2.0018634521265044`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[1.0531708739791161`, -0.43134927949335167`], 
            Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.828925941917191, -1.1630350275077863`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[7.479635970943437, 0.008246541346654087], 
            Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.828925941917192, -1.2630350275077864`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[4.338043317353644, 0.008246541346654037], 
            Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.9101503643132345`, -1.2610395954830416`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[5.4207729647332625`, 0.010520523036427932`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.9101503643132345`, -1.1610395954830415`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[8.562365618323055, 0.010520523036427927`], 
            Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.356024721208028, -1.2986680693372454`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[6.944427656372562, -0.01769918937958054], 
            Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.356024721208028, -1.1986680693372456`}],
          RowBox[{"{", 
            RowBox[{"17.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.799999999999997`, {
            Complex[10.086020309962356`, -0.017699189379580486`], 
            Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3798640340783366`, -2.5958004746630317`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.440517518589483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[3.440517518589483, -1.1121900734843542`], 
            Complex[1.3798640340783366`, -2.5958004746630317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3798640340783381`, -2.6958004746630366`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.29892486499969306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843577`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3798640340783381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[0.29892486499969306`, -1.1121900734843577`], 
            Complex[1.3798640340783381`, -2.5958004746630365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1626545888502187`, -1.9941526819126023`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[1.0670807469468007`, -0.42514662876555165`], 
            Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1626545888502187`, -1.8941526819126024`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.208673400536594, -0.42514662876555215`], 
            Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.815666629983416, -1.1630053621640015`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[7.4670073159977095`, 0.008350912786614366], 
            Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.815666629983418, -1.2630053621640045`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[4.325414662407916, 0.008350912786611275], 
            Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.9282802700841595`, -1.2608460296816648`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[5.439695778207934, 0.010820596844492497`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.9282802700841595`, -1.1608460296816647`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[8.581288431797727, 0.010820596844492403`], 
            Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.337481607819116, -1.1988599130234305`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.9, {
            Complex[10.06681689057666, -0.018022230071644385`], 
            Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.33748160781912, -1.2988599130234304`}],
          RowBox[{"{", 
            RowBox[{"17.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.9, {
            Complex[6.925224236986869, -0.01802223007164421], 
            Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3742291902547281`, -2.6040251997705024`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4357376210557065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.120937815790952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6040251997705024`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[3.4357376210557065`, -1.120937815790952], 
            Complex[1.3742291902547281`, -2.6040251997705024`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3742291902547281`, -2.704025199770505}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2941449674659141`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1209378157909546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.604025199770505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[0.2941449674659141, -1.1209378157909546`], 
            Complex[1.3742291902547281`, -2.604025199770505]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1765054667524417`, -1.886674958680205}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.222336896739361, -0.41917722203755803`], 
            Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.176505466752442, -1.9866749586802046`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[1.0807442431495686`, -0.4191772220375579], 
            Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.802681228429218, -1.2629747445437838`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[4.3130627762344576`, 0.00845680816400054], 
            Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.802681228429218, -1.1629747445437837`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[7.454655429824251, 0.008456808164000526], 
            Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.946333169123364, -1.1606380604240905`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[8.600148900521386, 0.011138282794836918`], 
            Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.946333169123367, -1.2606380604240905`}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[5.458556246931596, 0.011138282794836883`], 
            Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.319026572634915, -1.299065136952576}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[6.906093661793765, -0.01836202115462416], 
            Complex[8.319026572634915, -1.199065136952576]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.319026572634915, -1.199065136952576}],
          RowBox[{"{", 
            RowBox[{"17.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {17.999999999999996`, {
            Complex[10.047686315383556`, -0.018362021154624195`], 
            Complex[8.319026572634915, -1.199065136952576]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3687880826648193`, -2.712032327183787}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2895575630554191`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1294546532828313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.612032327183787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[0.2895575630554191, -1.1294546532828313`], 
            Complex[1.3687880826648193`, -2.612032327183787]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3687880826648213`, -2.6120323271837886`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4311502166452144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.129454653282832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3687880826648213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6120323271837886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[3.4311502166452144`, -1.129454653282832], 
            Complex[1.3687880826648213`, -2.6120323271837886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.19014798983231, -1.9794145456947623`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[1.0941780694739518`, -0.41342498695323976`], 
            Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.1901479898323104`, -1.879414545694765}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.2357707230637445`, -0.41342498695324215`], 
            Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.789948806930199, -1.2629431621652236`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[4.300966771833883, 0.008564247194411541], 
            Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.7899488069302, -1.1629431621652235`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[7.442559425423676, 0.008564247194411552], 
            Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.964343616618659, -1.2604140653041307`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[5.47738980371477, 0.011475439606775242`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.964343616618659, -1.1604140653041306`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[8.618982457304563, 0.011475439606775252`], 
            Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.30062424755183, -1.2992854341178675`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[6.886999703988066, -0.01872048627707082], 
            Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.300624247551832, -1.1992854341178674`}],
          RowBox[{"{", 
            RowBox[{"18.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.099999999999998`, {
            Complex[10.02859235757786, -0.018720486277070698`], 
            Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3635269813327329`, -2.6198359153990136`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.426741405743924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377551213057147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327329`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[3.426741405743924, -1.1377551213057147`], 
            Complex[1.3635269813327329`, -2.6198359153990136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3635269813327346`, -2.7198359153990137`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2851487521541328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1377551213057142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3635269813327346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[0.2851487521541328, -1.1377551213057142`], 
            Complex[1.3635269813327346`, -2.6198359153990136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.203596585722576, -1.9723574121967355`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[1.107397162145414, -0.4078755867501416], 
            Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.203596585722578, -1.872357412196735}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.248989815735208, -0.4078755867501412], 
            Complex[2.203596585722578, -1.872357412196735]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.7774507425522845`, -1.162910600549928}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[7.430700722955541, 0.008673251522090992], 
            Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.777450742552286, -1.262910600549928}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[4.289108069365748, 0.008673251522090971], 
            Complex[5.777450742552286, -1.162910600549928]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.982345361327388, -1.160172170534845}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[8.637823823216573, 0.011834207760463409`], 
            Complex[6.982345361327388, -1.160172170534845]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{6.982345361327388, -1.2601721705348452`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[5.496231169626781, 0.011834207760463395`], 
            Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.28224016277643, -1.2995227410964951`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.2, {
            Complex[6.867906939037359, -0.019099823463292427`], 
            Complex[8.28224016277643, -1.199522741096495]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.28224016277643, -1.1995227410964953`}],
          RowBox[{"{", 
            RowBox[{"18.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.2, {
            Complex[10.009499592627153`, -0.019099823463292497`], 
            Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3584336295287167`, -2.6274485670330767`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4224987798606765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6274485670330767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[3.4224987798606765`, -1.1458522701333511`], 
            Complex[1.3584336295287167`, -2.6274485670330767`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3584336295287214`, -2.727448567033079}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2809061262708882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3584336295287214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.627448567033079`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[0.2809061262708882, -1.1458522701333518`], 
            Complex[1.3584336295287214`, -2.627448567033079]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.216864199765703, -1.8654909840009626`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.262007600278324, -0.4025161677361105], 
            Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.216864199765705, -1.9654909840009627`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[1.1204149466885311`, -0.40251616773611126`], 
            Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.765170376285118, -1.2628770434041632`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[4.277470052807503, 0.008783844556995735], 
            Complex[5.765170376285118, -1.162877043404163]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.765170376285118, -1.162877043404163}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[7.419062706397297, 0.008783844556995738], 
            Complex[5.765170376285118, -1.162877043404163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.000371925640259, -1.1599101980783053`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[8.656707602013043, 0.012217067867222313`], 
            Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.00037192564026, -1.2599101980783054`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[5.515114948423251, 0.012217067867222332`], 
            Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.263840153003091, -1.2997792920739641`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[6.8487801366438275`, -0.019502564592186727`], 
            Complex[8.263840153003091, -1.199779292073964]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.263840153003093, -1.1997792920739636`}],
          RowBox[{"{", 
            RowBox[{"18.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.299999999999997`, {
            Complex[9.990372790233621, -0.01950256459218661], 
            Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3534970339779715`, -2.634881633043194}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.41841120976327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1537578719399622`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.634881633043194`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[3.41841120976327, -1.1537578719399622`], 
            Complex[1.3534970339779715`, -2.634881633043194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3534970339779717`, -2.7348816330431904`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2768185561734762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1537578719399602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3534970339779717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6348816330431903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[0.2768185561734762, -1.1537578719399602`], 
            Complex[1.3534970339779717`, -2.6348816330431903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2299625053481056`, -1.8588039393045286`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.274836204246599, -0.39733515240586165`], 
            Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2299625053481065`, -1.9588039393045302`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[1.1332435506568057`, -0.39733515240586337`], 
            Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.753092732368909, -1.1628424727592266`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[7.4076304429802775`, 0.00889605134985899], 
            Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.75309273236891, -1.2628424727592267`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[4.266037789390484, 0.008896051349858974], 
            Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.018457172595781, -1.1596255988326747`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[8.675668864524779, 0.012626914319474911`], 
            Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.018457172595782, -1.2596255988326748`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[5.5340762109349875`, 0.012626914319474934`], 
            Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.24538977916942, -1.2000576866004597`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[9.971176318841339, -0.019931649951741043`], 
            Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.24538977916942, -1.3000576866004603`}],
          RowBox[{"{", 
            RowBox[{"18.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.399999999999995`, {
            Complex[6.829583665251546, -0.019931649951741116`], 
            Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.348707291872495, -2.6421453813855136`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4144686707126652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.348707291872495`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[3.4144686707126652`, -1.1614825918531306`], 
            Complex[1.348707291872495, -2.6421453813855136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3487072918724958`, -2.7421453813855137`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2728760171228721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3487072918724958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[0.2728760171228721, -1.1614825918531306`], 
            Complex[1.3487072918724958`, -2.6421453813855136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2429020774149055`, -1.8522860400567247`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.287486632822467, -0.39232206847656975`], 
            Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.242902077414907, -1.9522860400567257`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[1.1458939792326737`, -0.3923220684765709], 
            Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.74120428693884, -1.2628068690797756`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[4.254797798340199, 0.009009898497034034], 
            Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.741204286938846, -1.1628068690797762`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[7.396390451929997, 0.009009898497033932], 
            Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.036635886648768, -1.1593153672755068`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[8.694743750598732, 0.013067149229433986`], 
            Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.036635886648769, -1.2593153672755069`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[5.553151097008939, 0.013067149229433903`], 
            Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.226853738441676, -1.2003609757255185`}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[9.951873534557844, -0.020390522922278387`], 
            Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.226853738441678, -1.300360975725519}],
          RowBox[{"{", 
            RowBox[{"18.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.499999999999996`, {
            Complex[6.810280880968052, -0.020390522922278664`], 
            Complex[8.226853738441678, -1.200360975725519]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3440554470967183`, -2.6492491374148304`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.410662097155336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1690361304484036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6492491374148304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[3.410662097155336, -1.1690361304484036`], 
            Complex[1.3440554470967183`, -2.6492491374148304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3440554470967194`, -2.7492491374148322`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2690694435655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1690361304484052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3440554470967194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.649249137414832`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[0.2690694435655443, -1.1690361304484052`], 
            Complex[1.3440554470967194`, -2.649249137414832]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2556925367556313`, -1.9459279915891425`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[1.1583762613396105`, -0.38746740648134814`], 
            Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2556925367556317`, -1.8459279915891416`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.299968914929404, -0.38746740648134725`], 
            Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.729492775798816, -1.262770211346653}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[4.243737858735289, 0.009125414068990397], 
            Complex[5.729492775798816, -1.162770211346653]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.729492775798816, -1.1627702113466531`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[7.3853305123250825`, 0.009125414068990404], 
            Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.054944396120723, -1.1589759311366727`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[8.713970117564823, 0.013541803645186434`], 
            Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.054944396120724, -1.2589759311366728`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[5.57237746397503, 0.013541803645186435`], 
            Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.208195234091122, -1.3006927729717155`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[6.790833471518203, -0.020883251810279654`], 
            Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.208195234091123, -1.2006927729717152`}],
          RowBox[{"{", 
            RowBox[{"18.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.599999999999998`, {
            Complex[9.932426125107996, -0.020883251810279745`], 
            Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.339533369860022, -2.756201401617177}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.26539060743652637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1764273433249663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.339533369860022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[0.26539060743652637`, -1.1764273433249663`], 
            Complex[1.339533369860022, -2.656201401617177]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3395333698600238`, -2.656201401617177}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4069832610263204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.176427343324966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3395333698600238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[3.4069832610263204`, -1.176427343324966], 
            Complex[1.3395333698600238`, -2.656201401617177]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.268342670868865, -1.9397213249141578`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[1.1706995721155862`, -0.382762500281366], 
            Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.2683426708688654`, -1.8397213249141586`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.31229222570538, -0.3827625002813669], 
            Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.717947033532342, -1.2627324771191424`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[4.232846848694921, 0.009242627557842213], 
            Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.7179470335323455`, -1.1627324771191436`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[7.374439502284718, 0.00924262755784085], 
            Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.073421269042283, -1.2586030069798182`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[5.591795614755318, 0.014055695951277704`], 
            Complex[7.073421269042283, -1.158603006979818]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.073421269042284, -1.158603006979818}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[8.733388268345113, 0.014055695951277626`], 
            Complex[7.073421269042284, -1.158603006979818]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.18937527323683, -1.2010573992945917`}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.7, {
            Complex[9.912793375391814, -0.02141468876524509], 
            Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.18937527323683, -1.301057399294592}],
          RowBox[{"{", 
            RowBox[{"18.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.7, {
            Complex[6.771200721802021, -0.021414688765245018`], 
            Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3351336552455113`, -2.663009949003302}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4034246691397003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1836643421288453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.663009949003302`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[3.4034246691397003`, -1.1836643421288453`], 
            Complex[1.3351336552455113`, -2.663009949003302]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3351336552455122`, -2.7630099490033024`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2618320155499074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.183664342128846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3351336552455122`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6630099490033023`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[0.2618320155499074, -1.183664342128846], 
            Complex[1.3351336552455122`, -2.6630099490033023`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.280860535897551, -1.933658297363925}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[1.1828723362728408`, -0.378199426130277], 
            Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.280860535897552, -1.8336582973639262`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.324464989862636, -0.3781994261302779], 
            Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.706556857926958, -1.2626936425804283`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[4.222114609872632, 0.009361569840391626], 
            Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.706556857926958, -1.1626936425804284`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[7.363707263462426, 0.009361569840391621], 
            Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.0921081211151265`, -1.258191408520516}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[5.611449146258794, 0.014614641743299664`], 
            Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.092108121115127, -1.1581914085205156`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[8.753041799848587, 0.014614641743299649`], 
            Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.170351853484787, -1.3014600752208563`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.8, {
            Complex[6.751338660172414, -0.021990680088691934`], 
            Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.170351853484789, -1.2014600752208564`}],
          RowBox[{"{", 
            RowBox[{"18.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.8, {
            Complex[9.892931313762208, -0.021990680088691875`], 
            Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.330849537168034, -2.6696819135459715`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.399979476133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[3.399979476133, -1.1907545804380442`], 
            Complex[1.330849537168034, -2.6696819135459715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.330849537168034, -2.769681913545974}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.258386822543207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[0.258386822543207, -1.1907545804380446`], 
            Complex[1.330849537168034, -2.6696819135459737`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.293253543143009, -1.9277318081869506`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[1.1949023158791763`, -0.3737709168766501], 
            Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.293253543143011, -1.82773180818695}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.336494969468971, -0.3737709168766498], 
            Complex[2.293253543143011, -1.82773180818695]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.695312895009785, -1.262653682569165}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[4.211531832555506, 0.009482273153986658], 
            Complex[5.695312895009785, -1.162653682569165]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.695312895009786, -1.1626536825691627`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[7.3531244861453, 0.009482273153988793], 
            Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.111050585905176, -1.157734788294595}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[8.77297862441228, 0.015225736181981687`], 
            Complex[7.111050585905176, -1.157734788294595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.111050585905176, -1.2577347882945953`}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[5.631385970822487, 0.015225736181981623`], 
            Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.151078988162066, -1.201907179567137}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.9, {
            Complex[9.872791686074075, -0.02261834895605743], 
            Complex[8.151078988162066, -1.201907179567137]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.151078988162068, -1.301907179567137}],
          RowBox[{"{", 
            RowBox[{"18.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.9, {
            Complex[6.731199032484283, -0.022618348956057268`], 
            Complex[8.151078988162068, -1.201907179567137]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3266748149775125`, -2.7762238603294422`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2550487565900203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1977049272038123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.676223860329442`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[0.2550487565900203, -1.1977049272038123`], 
            Complex[1.3266748149775125`, -2.676223860329442]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3266748149775132`, -2.67622386032944}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.396641410179813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977049272038105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3266748149775132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.67622386032944`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[3.396641410179813, -1.1977049272038105`], 
            Complex[1.3266748149775132`, -2.67622386032944]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.30552853292255, -1.9219353264340093`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[1.2067966853478913`, -0.369470288610321], 
            Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3055285329225508`, -1.8219353264340112`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.348389338937685, -0.36947028861032294`], 
            Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.684206540989641, -1.2626125705993823`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[4.201089957665183, 0.009604771083122505], 
            Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.684206540989642, -1.1626125705993822`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[7.342682611254977, 0.009604771083122523], 
            Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.130299515097565, -1.2572252835375142`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[5.651659582251507, 0.0158977403597609], 
            Complex[7.130299515097565, -1.157225283537514]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.130299515097567, -1.1572252835375132`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[8.793252235841303, 0.01589774035976148], 
            Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.13150550216652, -1.2024066038908527`}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[9.852320685804424, -0.02330648209651281], 
            Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.13150550216652, -1.302406603890853}],
          RowBox[{"{", 
            RowBox[{"18.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {18.999999999999996`, {
            Complex[6.7107280322146305`, -0.02330648209651286], 
            Complex[8.13150550216652, -1.202406603890853]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3226037905108852`, -2.782641847533846}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.25181205566632714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[0.25181205566632714`, -1.204521729892243], 
            Complex[1.3226037905108852`, -2.682641847533846]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3226037905108854`, -2.682641847533846}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3934047092561204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3226037905108854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[3.3934047092561204`, -1.204521729892243], 
            Complex[1.3226037905108854`, -2.682641847533846]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3176918379683404`, -1.8162628290107474`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.3601547494422475`, -0.3652913776086266], 
            Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.317691837968342, -1.916262829010749}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[1.2185620958524552`, -0.36529137760862845`], 
            Complex[2.317691837968342, -1.816262829010749]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.67322985816244, -1.2625702788705317`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[4.190781092718281, 0.009729098555121772], 
            Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.67322985816244, -1.1625702788705317`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[7.332373746308075, 0.009729098555121761], 
            Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.149912504017514, -1.1566530214405544`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[8.813923320576674, 0.016641620135819556`], 
            Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.149912504017515, -1.2566530214405545`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[5.6723306669868805`, 0.016641620135819466`], 
            Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.11157350310953, -1.3029682475172961`}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[6.689864686007544, -0.024066068896217683`], 
            Complex[8.11157350310953, -1.202968247517296]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.11157350310953, -1.202968247517296}],
          RowBox[{"{", 
            RowBox[{"19.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.099999999999998`, {
            Complex[9.831457339597339, -0.02406606889621767], 
            Complex[8.11157350310953, -1.202968247517296]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3186312138329304`, -2.688941479956369}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.39026406618571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3186312138329304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.688941479956369`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[3.39026406618571, -1.2112108690459429`], 
            Complex[1.3186312138329304`, -2.688941479956369]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.318631213832932, -2.7889414799563705`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.248671412595918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.318631213832932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6889414799563705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[0.248671412595918, -1.2112108690459433`], 
            Complex[1.318631213832932, -2.6889414799563705`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.329749338128145, -1.8107087471951673`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.3717973845316225`, -0.36122848586285683`], 
            Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.329749338128147, -1.9107087471951665`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[1.2302047309418311`, -0.3612284858628565], 
            Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.662375502422984, -1.1625267782689677`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[7.322190592979878, 0.009855291843704485], 
            Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.662375502422985, -1.2625267782689678`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[4.180597939390085, 0.00985529184370446], 
            Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.169955880282914, -1.2560054129682459`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[5.693469206036438, 0.01747131387776226], 
            Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.169955880282916, -1.1560054129682455`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[8.835061859626233, 0.017471313877762306`], 
            Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.09121638979124, -1.2036047239664327`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.2, {
            Complex[9.81013140250469, -0.02491106937082747], 
            Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.09121638979124, -1.3036047239664332`}],
          RowBox[{"{", 
            RowBox[{"19.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.2, {
            Complex[6.668538748914897, -0.024911069370827682`], 
            Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3147522362459447`, -2.7951279554438115`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24562192744249728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2177778056554163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6951279554438115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[0.24562192744249728`, -1.2177778056554163`], 
            Complex[1.3147522362459447`, -2.6951279554438115`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3147522362459452`, -2.69512795544381}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3872145810322905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2177778056554156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3147522362459452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.69512795544381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[3.3872145810322905`, -1.2177778056554156`], 
            Complex[1.3147522362459452`, -2.69512795544381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.341706507788824, -1.8052679202454827`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.38332300838, -0.35727633379543705`], 
            Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3417065077888246`, -1.9052679202454834`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[1.2417303547902065`, -0.3572763337954378], 
            Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.65163666048189, -1.262482038362008}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[4.170533730780807, 0.009983388579384763], 
            Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.651636660481892, -1.162482038362008}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[7.312126384370602, 0.009983388579384756], 
            Complex[5.651636660481892, -1.162482038362008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.190507361138085, -1.2552661200223418`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[5.715157284805061, 0.018404853311322064`], 
            Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.190507361138085, -1.1552661200223417`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[8.856749938394854, 0.01840485331132207], 
            Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.070356192382524, -1.3043323940004823`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[6.646667892120967, -0.025859535214795407`], 
            Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.070356192382524, -1.2043323940004822`}],
          RowBox[{"{", 
            RowBox[{"19.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.299999999999997`, {
            Complex[9.78826054571076, -0.02585953521479562], 
            Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3109623694144812`, -2.8012061053544794`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.24265906608433005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2242276224707753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7012061053544794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[0.24265906608433005`, -1.2242276224707753`], 
            Complex[1.3109623694144812`, -2.7012061053544794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3109623694144825`, -2.701206105354477}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3842517196741237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2242276224707729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3109623694144825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.701206105354477`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[3.3842517196741237`, -1.2242276224707729`], 
            Complex[1.3109623694144825`, -2.701206105354477]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3535684571772366`, -1.899935554980541}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[1.253144354246581, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3535684571772366`, -1.7999355549805411`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.394737007836374, -0.35343001903737564`], 
            Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.6410069952433215`, -1.2624360273853816`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[4.16058217684066, 0.010113427765967319`], 
            Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.641006995243322, -1.162436027385382}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[7.302174830430454, 0.010113427765967268`], 
            Complex[5.641006995243322, -1.162436027385382]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.211659694982882, -1.2544135020746285`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[5.737492944039841, 0.019466046203823834`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.211659694982882, -1.1544135020746285`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[8.879085597629635, 0.019466046203823823`], 
            Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.048899928737553, -1.3051729191751689`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.4, {
            Complex[6.624153849873985, -0.02693529265819097], 
            Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.048899928737553, -1.2051729191751688`}],
          RowBox[{"{", 
            RowBox[{"19.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.4, {
            Complex[9.76574650346378, -0.02693529265819088], 
            Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3072574496615919`, -2.807180429964402}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23977862401903308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2305650601795397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3072574496615919`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.707180429964402`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[0.23977862401903308`, -1.2305650601795397`], 
            Complex[1.3072574496615919`, -2.707180429964402]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.307257449661592, -2.7071804299643993`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.381371277608826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.230565060179537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.307257449661592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7071804299643993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[3.381371277608826, -1.230565060179537], 
            Complex[1.307257449661592, -2.7071804299643993`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3653399684829135`, -1.8947071904178556`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[1.2644517756377363`, -0.34968498034029766`], 
            Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.365339968482914, -1.7947071904178578`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.40604442922753, -0.3496849803402998], 
            Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.630480598081044, -1.2623887122247346`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[4.1507374166916415`, 0.010245449802525813`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.630480598081044, -1.1623887122247345`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[7.292330070281435, 0.010245449802525817`], 
            Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.23352578639705, -1.253418203138091}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[5.76059559895939, 0.020687085496539206`], 
            Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.233525786397051, -1.1534182031380908`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[8.902188252549184, 0.020687085496539234`], 
            Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.026734477486405, -1.306155675029386}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[6.600876998505349, -0.028170551750252844`], 
            Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.026734477486409, -1.2061556750293905`}],
          RowBox[{"{", 
            RowBox[{"19.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.499999999999996`, {
            Complex[9.742469652095146, -0.028170551750257837`], 
            Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.30363360666026, -2.7130551295714294`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.378569348204635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.30363360666026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7130551295714294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[3.378569348204635, -1.2367945492132952`], 
            Complex[1.30363360666026, -2.7130551295714294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.3036336066602605`, -2.81305512957143}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23697669461484225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132955`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3036336066602605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.71305512957143`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[0.23697669461484225`, -1.2367945492132955`], 
            Complex[1.3036336066602605`, -2.71305512957143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3770255275795718`, -1.7895786667158644`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.417250010699276, -0.3460369658605059], 
            Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.3770255275795726`, -1.8895786667158638`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[1.275657357109484, -0.34603696586050564`], 
            Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.620051946974447, -1.262340058391703}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[4.140993976808082, 0.01037949651040012], 
            Complex[5.620051946974447, -1.162340058391703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.620051946974448, -1.1623400583917027`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[7.282586630397876, 0.010379496510400103`], 
            Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.256246121108593, -1.2522392586053033`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[5.78461388785291, 0.022112751073540098`], 
            Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.256246121108593, -1.1522392586053043`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[8.926206541442703, 0.02211275107353916], 
            Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.003719151417389, -1.3073216443878655`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[6.5766885062096785`, -0.02961010826063084], 
            Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{8.003719151417389, -1.2073216443878656`}],
          RowBox[{"{", 
            RowBox[{"19.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.599999999999998`, {
            Complex[9.718281159799472, -0.029610108260631186`], 
            Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.3000872358777424`, -2.7188341319212634`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3758422947494764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.3000872358777424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7188341319212634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[3.3758422947494764`, -1.2429202378151198`], 
            Complex[1.3000872358777424`, -2.7188341319212634`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.300087235877743, -2.818834131921264}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2342496411596838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.300087235877743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.718834131921264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[0.2342496411596838, -1.2429202378151196`], 
            Complex[1.300087235877743, -2.718834131921264]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.388629351988557, -1.8845460977964306`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[1.286765557155954, -0.34248200518323674`], 
            Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.388629351988557, -1.7845460977964323`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.428358210745746, -0.34248200518323846`], 
            Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.609715869645587, -1.262290029994955}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[4.131346734197311, 0.010515611164854463`], 
            Complex[5.609715869645587, -1.162290029994955]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.609715869645588, -1.1622900299949552`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[7.272939387787106, 0.010515611164854442`], 
            Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.279999873987634, -1.1508175252699344`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[8.95133006145241, 0.023807487220115792`], 
            Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.279999873987635, -1.2508175252699347`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[5.809737407862617, 0.023807487220115758`], 
            Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.979674588033218, -1.3087299874638698`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.7, {
            Complex[6.5513985958381715`, -0.03131842125415489], 
            Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.979674588033221, -1.2087299874638697`}],
          RowBox[{"{", 
            RowBox[{"19.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.7, {
            Complex[9.692991249427967, -0.0313184212541546], 
            Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2966149742384296`, -2.7245211164750502`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3731867257580617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2489460168942261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7245211164750502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[3.3731867257580617`, -1.2489460168942261`], 
            Complex[1.2966149742384296`, -2.7245211164750502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2966149742384314`, -2.8245211164750472`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.23159407216826933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.248946016894224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2966149742384314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.724521116475047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[0.23159407216826933`, -1.248946016894224], 
            Complex[1.2966149742384314`, -2.724521116475047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4001554156192917`, -1.8796058471281258`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[1.297780579877745, -0.33901638456087957`], 
            Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.400155415619292, -1.7796058471281262`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.439373233467538, -0.3390163845608803], 
            Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.599467510982897, -1.2622385897064983`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[4.121790883866403, 0.010653838531129443`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.599467510982897, -1.1622385897064982`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[7.263383537456196, 0.010653838531129386`], 
            Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.3050221318566, -1.2490639772295196`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[5.836214897718771, 0.02586798658403449], 
            Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.305022131856608, -1.1490639772295173`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[8.977807551308572, 0.025867986584037196`], 
            Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.954365525461625, -1.2104697460661467`}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[9.6663510144975, -0.033392197154710215`], 
            Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.954365525461625, -1.310469746066147}],
          RowBox[{"{", 
            RowBox[{"19.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.799999999999997`, {
            Complex[6.5247583609077076`, -0.03339219715471046], 
            Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2932136785584984`, -2.8301195359534463`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22900681949582008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2548755421085922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2932136785584984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7301195359534463`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[0.22900681949582008`, -1.2548755421085922`], 
            Complex[1.2932136785584984`, -2.7301195359534463`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.293213678558499, -2.730119535953448}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.370599473085614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.254875542108594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.293213678558499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.730119535953448`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[3.370599473085614, -1.254875542108594], 
            Complex[1.293213678558499, -2.730119535953448]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4116074707342525`, -1.8747545062354531`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[1.3087063974214082`, -0.33563662492447366`], 
            Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.411607470734253, -1.774754506235453}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.450299051011202, -0.3356366249244736], 
            Complex[2.411607470734253, -1.774754506235453]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.58930230415447, -1.1621856987234664`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[7.253914563567924, 0.010794224904694137`], 
            Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.58930230415447, -1.2621856987234668`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[4.11232190997813, 0.010794224904694102`], 
            Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.3316316615292605`, -1.2468374259621589`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[5.864383522178553, 0.028447097632704994`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.3316316615292605`, -1.1468374259621588`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.005976175768346, 0.028447097632704935`], 
            Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.927473033284, -1.3126821236194965`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {19.9, {
            Complex[6.496430480050892, -0.03598429729320658], 
            Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.927473033284, -1.2126821236194971`}],
          RowBox[{"{", 
            RowBox[{"19.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {19.9, {
            Complex[9.638023133640685, -0.035984297293206895`], 
            Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2898804063769855`, -2.835632635522893}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22648491887905142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464206`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.735632635522893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[0.22648491887905142`, -1.2607122535464206`], 
            Complex[1.2898804063769855`, -2.735632635522893]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2898804063769864`, -2.7356326355228924`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.368077572468845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2898804063769864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7356326355228924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[3.368077572468845, -1.2607122535464201`], 
            Complex[1.2898804063769864`, -2.7356326355228924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.422989067514498, -1.7699888755685127`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[4.461139423570387, -0.33233946229789096`], 
            Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4229890675144987`, -1.8699888755685143`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[1.319546769980594, -0.3323394622978922], 
            Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.579215944909336, -1.2621313167255455`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[4.102935560194785, 0.010936818155564383`], 
            Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.579215944909337, -1.1621313167255454`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[7.244528213784578, 0.010936818155564378`], 
            Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.360277468735849, -1.1438984501954066`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.036310546964627, 0.031803157852373865`], 
            Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.360277468735851, -1.2438984501954067`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[5.894717893374835, 0.031803157852374093`], 
            Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.89854795260484, -1.2156065553823723`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20., {
            Complex[9.607532848271008, -0.039353071187373335`], 
            Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.898547952604841, -1.3156065553823721`}],
          RowBox[{"{", 
            RowBox[{"20.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20., {
            Complex[6.465940194681216, -0.03935307118737327], 
            Complex[7.898547952604841, -1.215606555382372]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2866123988665321`, -2.7410634699329792`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365618246173949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7410634699329792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[3.365618246173949, -1.2664593933197807`], 
            Complex[1.2866123988665321`, -2.7410634699329792`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2866123988665328`, -2.841063469932979}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22402559258415555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2866123988665328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.741063469932979`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[0.22402559258415555`, -1.2664593933197807`], 
            Complex[1.2866123988665328`, -2.741063469932979]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.434303571543256, -1.765305947424264}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.471897917269896, -0.3291218303014387], 
            Complex[2.434303571543256, -1.765305947424264]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.434303571543257, -1.8653059474242633`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[1.3303052636801032`, -0.3291218303014382], 
            Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.569204368643545, -1.2620754018281333`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[4.093627822786881, 0.011081667776607964`], 
            Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.569204368643545, -1.1620754018281332`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[7.235220476376673, 0.01108166777660797], 
            Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.391618832430621, -1.1398036000155798`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.069506749440478, 0.03641303093548226], 
            Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.391618832430633, -1.2398036000155712`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[5.927914095850698, 0.036413030935491676`], 
            Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.866930860848724, -1.3196865044147184`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.1, {
            Complex[6.432591283080759, -0.043975393800888975`], 
            Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.866930860848725, -1.2196865044147176`}],
          RowBox[{"{", 
            RowBox[{"20.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.1, {
            Complex[9.574183936670554, -0.04397539380088848], 
            Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2834070655552792`, -2.846414918867112}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.22162623389028935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2721200213365198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.746414918867112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[0.22162623389028935`, -1.2721200213365198`], 
            Complex[1.2834070655552792`, -2.746414918867112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2834070655552816`, -2.7464149188671136`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3632188874800852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2721200213365205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2834070655552816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7464149188671136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[3.3632188874800852`, -1.2721200213365205`], 
            Complex[1.2834070655552816`, -2.7464149188671136`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.445554179476747, -1.760702890657421}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.482577920205066, -0.3259808444790341], 
            Complex[2.445554179476747, -1.760702890657421]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4455541794767472`, -1.8607028906574201`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[1.3409852666152733`, -0.32598084447903347`], 
            Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.559263729872352, -1.2620179105312723`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[4.084394906148223, 0.011228824935798519`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.559263729872352, -1.1620179105312722`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[7.225987559738016, 0.011228824935798491`], 
            Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.426654831776879, -1.133628019546016}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.106617372354673, 0.04326772266645232], 
            Complex[7.426654831776879, -1.133628019546016]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.426654831776879, -1.2336280195460163`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[5.96502471876488, 0.0432677226664523], 
            Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.831622543975548, -1.2258468389686776`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[9.536923681000955, -0.05084228149321134], 
            Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.83162254397556, -1.3258468389686628`}],
          RowBox[{"{", 
            RowBox[{"20.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.199999999999996`, {
            Complex[6.395331027411176, -0.05084228149319564], 
            Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2802619706314171`, -2.7516897007297403`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3608770467672016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2776970294771413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7516897007297403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[3.3608770467672016`, -1.2776970294771413`], 
            Complex[1.2802619706314171`, -2.7516897007297403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2802619706314173`, -2.85168970072974}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21928439317740805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2776970294771406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2802619706314173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.75168970072974`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[0.21928439317740805`, -1.2776970294771406`], 
            Complex[1.2802619706314173`, -2.75168970072974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4567439331314382`, -1.756177036957859}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.4931826568685596`, -0.32291378822242134`], 
            Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.45674393313144, -1.8561770369578598`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[1.351590003278767, -0.32291378822242217`], 
            Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.549390383803342, -1.1619587976643722`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[7.216825874002135, 0.011378342532423407`], 
            Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.549390383803343, -1.2619587976643725`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[4.075233220412342, 0.01137834253242333], 
            Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.466802670715167, -1.123122290976753}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.149127159726488, 0.05476808187732223], 
            Complex[7.466802670715167, -1.123122290976753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.46680267071517, -1.2231222909767527`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.007534506136697, 0.054768081877322586`], 
            Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.791205671196033, -1.3363369885208045`}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[6.352674562767395, -0.062354593032590215`], 
            Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.7912056711960345`, -1.236336988520793}],
          RowBox[{"{", 
            RowBox[{"20.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.299999999999997`, {
            Complex[9.494267216357189, -0.062354593032578], 
            Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2771748206351425`, -2.756890385061134}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.358590419010691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.756890385061134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[3.358590419010691, -1.2831931543706478`], 
            Complex[1.2771748206351425`, -2.756890385061134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2771748206351434`, -2.8568903850611354`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21699776542089913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2771748206351434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7568903850611353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[0.21699776542089913`, -1.2831931543706483`], 
            Complex[1.2771748206351434`, -2.7568903850611353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4678757321837086`, -1.8517258685037106`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[1.362122547573207, -0.319918100098616], 
            Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.467875732183709, -1.7517258685037114`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.503715201163001, -0.3199181000986165], 
            Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.539580869749671, -1.1618980163266774`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[7.207732014499435, 0.011530275257279964`], 
            Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.539580869749673, -1.2618980163266775`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[4.066139360909642, 0.01153027525727997], 
            Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.512359287571745, -1.1022322984450346`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.197298230159177, 0.07734359441247762], 
            Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.512359287571745, -1.202232298445035}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.055705576569384, 0.07734359441247692], 
            Complex[7.512359287571745, -1.102232298445035]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.745383184720138, -1.2572110799472442`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.4, {
            Complex[9.445952310414624, -0.08494182361234351], 
            Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.745383184720156, -1.3572110799472328`}],
          RowBox[{"{", 
            RowBox[{"20.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.4, {
            Complex[6.304359656824848, -0.08494182361233121], 
            Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.274143453370581, -2.7620194037437003`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3563568325133555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2886109889360127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.274143453370581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7620194037437003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[3.3563568325133555`, -1.2886109889360127`], 
            Complex[1.274143453370581, -2.7620194037437003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2741434533705815`, -2.8620194037437012`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21476417892356292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.288610988936014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2741434533705815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.762019403743701`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[0.21476417892356292`, -1.288610988936014], 
            Complex[1.2741434533705815`, -2.762019403743701]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.478952345649963, -1.8473470068263864`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[1.3725858345799593`, -0.31699136241415216`], 
            Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.478952345649964, -1.7473470068263868`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.514178488169753, -0.31699136241415254`], 
            Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.529831896159836, -1.261835517823418}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[4.057110093241812, 0.011684679656931263`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.529831896159836, -1.1618355178234179`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[7.198702746831605, 0.011684679656931228`], 
            Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.552491023448565, -1.1633012820313107`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.097972756057953, 0.11902724764148631`], 
            Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.5524910234485665`, -1.0633012820313072`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.239565409647748, 0.11902724764149018`], 
            Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.704988630788345, -1.3961258835777606`}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.5, {
            Complex[6.261951376465343, -0.12663696940989244`], 
            Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.704988630788347, -1.296125883577755}],
          RowBox[{"{", 
            RowBox[{"20.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.5, {
            Complex[9.403544030055139, -0.12663696940988678`], 
            Complex[7.704988630788347, -1.296125883577755]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2711658278935793`, -2.8670790611410535`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21258158513908437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.293952992832856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[0.21258158513908437`, -1.293952992832856], 
            Complex[1.2711658278935793`, -2.7670790611410534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2711658278935796`, -2.7670790611410547`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.354174238728878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2939529928328564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2711658278935796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[3.354174238728878, -1.2939529928328564`], 
            Complex[1.2711658278935796`, -2.7670790611410547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4899764222920573`, -1.7430382027464797`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.524575324820607, -0.31413129087274355`], 
            Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.4899764222920577`, -1.8430382027464782`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[1.382982671230815, -0.31413129087274266`], 
            Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.520140327071446, -1.2617712515975434`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[4.04814233978115, 0.011841614202115778`], 
            Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.520140327071446, -1.1617712515975436`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[7.189734993370944, 0.011841614202115805`], 
            Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.574268139734727, -1.119141232917107}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.120724694194671, 0.16611165996512534`], 
            Complex[7.574268139734727, -1.019141232917107]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.574268139734727, -1.0191412329171092`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.262317347784464, 0.16611165996512323`], 
            Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.682951641637801, -1.3402694180832728`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[9.380653624650824, -0.17373265713467972`], 
            Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.682951641637805, -1.4402694180832762`}],
          RowBox[{"{", 
            RowBox[{"20.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.599999999999994`, {
            Complex[6.239060971061035, -0.17373265713468317`], 
            Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2682400154509323`, -2.7720715432919705`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.352040703050758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919705`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[3.352040703050758, -1.2992215019455444`], 
            Complex[1.2682400154509323`, -2.7720715432919705`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2682400154509332`, -2.8720715432919715`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.21044804946096587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2682400154509332`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[0.21044804946096587`, -1.2992215019455449`], 
            Complex[1.2682400154509332`, -2.7720715432919714`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.500950500073134, -1.8387973272586897`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[1.3933157460094145`, -0.3113357252023996], 
            Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5009505000731345`, -1.738797327258689}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.534908399599208, -0.3113357252023988], 
            Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.510503169822832, -1.1617051651569135`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[7.180825821018505, 0.012001139360437759`], 
            Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.510503169822832, -1.261705165156914}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[4.039233167428713, 0.012001139360437396`], 
            Complex[5.510503169822832, -1.161705165156914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.58536879774568, -1.080787258766948}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.132202365530885, 0.2069539217818524], 
            Complex[7.58536879774568, -0.980787258766948]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.585368797745682, -0.9807872587669504}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.27379501912068, 0.20695392178184982`], 
            Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.671593955391059, -1.4786065851349246`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[6.22744737065107, -0.21458598503237494`], 
            Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.671593955391099, -1.3786065851349265`}],
          RowBox[{"{", 
            RowBox[{"20.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.699999999999996`, {
            Complex[9.369040024240906, -0.21458598503237647`], 
            Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2653641912632538`, -2.776998926265093}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3499543964575493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3044187370084819`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[3.3499543964575493`, -1.3044187370084819`], 
            Complex[1.2653641912632538`, -2.776998926265093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2653641912632545`, -2.876998926265093}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20836174286775633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.304418737008481`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2653641912632545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[0.20836174286775633`, -1.304418737008481], 
            Complex[1.2653641912632545`, -2.776998926265093]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.511877014772337, -1.8346223632600893`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[1.4035876377924137`, -0.3086026206444544], 
            Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.511877014772339, -1.7346223632600861`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.545180291382208, -0.3086026206444535], 
            Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.500917563878367, -1.1616372039967813`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[7.171972430077165, 0.012163317673485156`], 
            Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.500917563878367, -1.2616372039967816`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[4.030379776487371, 0.012163317673485264`], 
            Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.591990895909478, -0.9479498476029737}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.280570529089989, 0.24191392575349288`], 
            Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.591990895909482, -1.0479498476029747`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.138977875500199, 0.24191392575349213`], 
            Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.664717578441819, -1.5114269055666703`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[6.22053837960052, -0.24955685318475593`], 
            Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.664717578441821, -1.4114269055666684`}],
          RowBox[{"{", 
            RowBox[{"20.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.799999999999997`, {
            Complex[9.362131033190314, -0.2495568531847539], 
            Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2625366270577847`, -2.8818631837665065`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20632093432967819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[0.20632093432967819`, -1.3095468114663624`], 
            Complex[1.2625366270577847`, -2.7818631837665064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2625366270577851`, -2.7818631837665047`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.347913587919471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2625366270577851`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665047`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[3.347913587919471, -1.3095468114663606`], 
            Complex[1.2625366270577851`, -2.7818631837665047`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.522758307852828, -1.8305113980298922`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[1.4138008239261344`, -0.3059300402110024], 
            Complex[2.522758307852828, -1.730511398029892]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5227583078528286`, -1.7305113980298918`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.555393477515928, -0.3059300402110033], 
            Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.491380770642325, -1.2615673115173933`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[4.021579490524692, 0.012328213838552492`], 
            Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.491380770642326, -1.1615673115173935`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[7.163172144114486, 0.012328213838552503`], 
            Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.59644818910947, -0.9191675975214383}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.285085225476458, 0.27256109297706776`], 
            Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.596448189109472, -1.0191675975214392`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.143492571886664, 0.27256109297706693`], 
            Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.660008665723722, -1.440191789692609}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {20.9, {
            Complex[9.357485218342608, -0.2802146897125705], 
            Complex[7.660008665723722, -1.440191789692609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.660008665723728, -1.5401917896926058`}],
          RowBox[{"{", 
            RowBox[{"20.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {20.9, {
            Complex[6.215892564752824, -0.2802146897125671], 
            Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2597556842695194`, -2.786666194080565}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345916637483683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.314607738651282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.786666194080565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[3.345916637483683, -1.314607738651282], 
            Complex[1.2597556842695194`, -2.786666194080565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2597556842695206`, -2.8866661940805636`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20432398389389064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3146077386512802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2597556842695206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7866661940805635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[0.20432398389389064`, -1.3146077386512802`], 
            Complex[1.2597556842695206`, -2.7866661940805635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5335966336654483`, -1.826462616380607}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[1.4239576876222573`, -0.3033161476291157], 
            Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5335966336654483`, -1.726462616380607}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[4.565550341212051, -0.3033161476291155], 
            Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.4818901641520625`, -1.2614954289364904`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[4.012829747116558, 0.012495894795164358`], 
            Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.481890164152063, -1.1614954289364903`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[7.154422400706351, 0.012495894795164308`], 
            Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.599694877117055, -0.9934053728141105}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.146749395916181, 0.30000093008350615`], 
            Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.599694877117055, -0.8934053728141108}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.288342049505975, 0.3000009300835058], 
            Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.656512931924062, -1.565936381216481}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21., {
            Complex[6.212506903993471, -0.30766500790256135`], 
            Complex[7.656512931924062, -1.465936381216481]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.656512931924068, -1.4659363812164734`}],
          RowBox[{"{", 
            RowBox[{"21.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21., {
            Complex[9.35409955758327, -0.30766500790255313`], 
            Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.257019807839279, -2.8914097464142907`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.2023693363760805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3196034383483597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.257019807839279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[0.2023693363760805, -1.3196034383483597`], 
            Complex[1.257019807839279, -2.7914097464142906`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2570198078392791`, -2.7914097464142906`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.343961989965874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.31960343834836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2570198078392791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[3.343961989965874, -1.31960343834836], 
            Complex[1.2570198078392791`, -2.7914097464142906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.544394166060117, -1.8224742944105479`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[1.434060524745711, -0.30075920090048514`], 
            Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.544394166060118, -1.7224742944105473`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.5756531783355054`, -0.30075920090048514`], 
            Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.4724432225550075`, -1.26142149519647}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[4.004128089376173, 0.012666429816627254`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.4724432225550075`, -1.1614214951964699`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[7.145720742965965, 0.012666429816627278`], 
            Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602190099828044, -0.9699776507064143}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.149229270200796, 0.3249638924276399], 
            Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602190099828044, -0.8699776507064156}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.290821923790588, 0.32496389242763857`], 
            Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.653771155925205, -1.4893462105216049`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[9.351493051581292, -0.33263826942312025`], 
            Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.653771155925207, -1.5893462105216072`}],
          RowBox[{"{", 
            RowBox[{"21.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.099999999999998`, {
            Complex[6.209900397991501, -0.3326382694231228], 
            Complex[7.653771155925207, -1.489346210521607]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2543275205461564`, -2.796095546707045}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.342048169184744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.342048169184744, -1.3245357428128088`], 
            Complex[1.2543275205461564`, -2.796095546707045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2543275205461566`, -2.896095546707046}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.20045551559495106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2543275205461566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707046`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[0.20045551559495106`, -1.3245357428128093`], 
            Complex[1.2543275205461566`, -2.796095546707046]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.55515300446826, -1.7185447937963196`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[4.585704203648775, -0.2982575464138705], 
            Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5551530044682607`, -1.81854479379632}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[1.4441115500589816`, -0.29825754641387064`], 
            Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.463037520285709, -1.261345446865949}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[3.995472158184808, 0.012839890606854708`], 
            Complex[5.463037520285709, -1.161345446865949]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.463037520285709, -1.161345446865949}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[7.137064811774602, 0.012839890606854724`], 
            Complex[5.463037520285709, -1.161345446865949]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604182742222913, -0.9484162452714224}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.151192034362995, 0.34794816918875576`], 
            Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604182742222915, -0.8484162452714185}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.292784687952791, 0.34794816918876], 
            Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6515343755500105`, -1.5108894707826885`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.2, {
            Complex[9.349405787878045, -0.35563266944840766`], 
            Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.65153437555002, -1.6108894707826944`}],
          RowBox[{"{", 
            RowBox[{"21.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.2, {
            Complex[6.207813134288261, -0.3556326694484139], 
            Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2516774178194212`, -2.8007252229597475`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.340173772683676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3294064022937957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597475`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.340173772683676, -1.3294064022937957`], 
            Complex[1.2516774178194212`, -2.8007252229597475`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2516774178194228`, -2.9007252229597467`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1985811190938835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.329406402293795`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2516774178194228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[0.1985811190938835, -1.329406402293795], 
            Complex[1.2516774178194228`, -2.8007252229597466`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5658751795119747`, -1.8146725565713104`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[1.454112902979397, -0.29580961355530405`], 
            Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5658751795119756`, -1.7146725565713112`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[4.59570555656919, -0.2958096135553045], 
            Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.453670720869239, -1.1612672180354267`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[7.128452338640535, 0.013016351402742217`], 
            Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.45367072086924, -1.261267218035427}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[3.986859685050743, 0.013016351402742245`], 
            Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605820205415673, -0.8283882117511504}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.294383744285957, 0.36930769700429716`], 
            Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605820205415675, -0.9283882117511523}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.152791090696166, 0.3693076970042951], 
            Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.649655116243796, -1.530899113668034}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.3, {
            Complex[9.347684294964536, -0.37700215031345224`], 
            Complex[7.649655116243796, -1.530899113668034]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.649655116243796, -1.6308991136680344`}],
          RowBox[{"{", 
            RowBox[{"21.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.3, {
            Complex[6.2060916413747425`, -0.3770021503134528], 
            Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2490681629814273`, -2.805300330131515}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.338337466890455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.338337466890455, -1.3342170901139807`], 
            Complex[1.2490681629814273`, -2.805300330131515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2490681629814275`, -2.905300330131515}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19674481330066165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2490681629814275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[0.19674481330066165`, -1.3342170901139803`], 
            Complex[1.2490681629814275`, -2.805300330131515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5765626581891583`, -1.7108561003427043`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[4.605659306489133, -0.2934139097675642], 
            Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5765626581891587`, -1.8108561003427042`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[1.4640666528993398`, -0.29341390976756415`], 
            Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.444340570285955, -1.2611867402067303`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[3.9782884855315257`, 0.013195889082391367`], 
            Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.444340570285955, -1.1611867402067304`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[7.119881139121318, 0.01319588908239133], 
            Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607195850080812, -0.8096479618228554}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.29571595421648, 0.3893033507690842], 
            Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607195850080814, -0.9096479618228547}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.154123300626686, 0.38930335076908473`], 
            Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6480399474006955`, -1.5496207340949588`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.4, {
            Complex[9.346231645579115, -0.3970075923331433], 
            Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.648039947400698, -1.6496207340949585`}],
          RowBox[{"{", 
            RowBox[{"21.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.4, {
            Complex[6.204638991989324, -0.3970075923331428], 
            Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2464984828787806`, -2.909822354646047}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19494532908188417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3389694073479312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2464984828787806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.809822354646047`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[0.19494532908188417`, -1.3389694073479312`], 
            Complex[1.2464984828787806`, -2.809822354646047]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.246498482878781, -2.809822354646045}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.336537982671677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33896940734793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.246498482878781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.809822354646045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.336537982671677, -1.33896940734793], 
            Complex[1.246498482878781, -2.809822354646045]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5872173486781147`, -1.7070940139050714`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[4.615567457703371, -0.2910690160160602], 
            Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.587217348678115, -1.8070940139050702`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[1.4739748041135785`, -0.29106901601605945`], 
            Complex[2.587217348678115, -1.70709401390507]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.435044890840143, -1.261103942175881}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[3.9697564531622382`, 0.01337858327951261], 
            Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.435044890840143, -1.161103942175881}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[7.111349106752032, 0.013378583279512458`], 
            Complex[5.435044890840143, -1.161103942175881]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608371984798493, -0.8920086413709222}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.155253112689077, 0.4081334915298177], 
            Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608371984798496, -0.7920086413709166}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.296845766278874, 0.4081334915298239], 
            Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6466264937920405`, -1.5672411924777172`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[9.344983328511988, -0.41584736171471265`], 
            Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.646626493792042, -1.6672411924777168`}],
          RowBox[{"{", 
            RowBox[{"21.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.499999999999996`, {
            Complex[6.203390674922197, -0.41584736171471254`], 
            Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.243967163863943, -2.914292718545235}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19318145765365854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3436648871377261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.243967163863943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[0.19318145765365854`, -1.3436648871377261`], 
            Complex[1.243967163863943, -2.814292718545235]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2439671638639436`, -2.814292718545235}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.334774111243452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.343664887137726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2439671638639436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.334774111243452, -1.343664887137726], 
            Complex[1.2439671638639436`, -2.814292718545235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5978411048003474`, -1.7033849532134373`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[4.62543195398277, -0.2887735826232172], 
            Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.5978411048003482`, -1.8033849532134367`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[1.483839300392978, -0.2887735826232169], 
            Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.425781575481577, -1.161018749909008}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[7.102854207428718, 0.013564516504362785`], 
            Complex[5.425781575481577, -1.161018749909008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.425781575481578, -1.2610187499090084`}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[3.961261553838926, 0.013564516504362838`], 
            Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6093919681901685`, -0.7753243442615882}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.297817893725249, 0.42595292805234636`], 
            Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60939196819019, -0.8753243442615727}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.156225240135477, 0.4259529280523631], 
            Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.645371333222616, -1.583906400971115}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[9.343894570793292, -0.4336762721416326], 
            Complex[7.645371333222616, -1.583906400971115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6453713332226165`, -1.683906400971116}],
          RowBox[{"{", 
            RowBox[{"21.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.599999999999998`, {
            Complex[6.202301917203499, -0.4336762721416338], 
            Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2414730480936764`, -2.818712783323322}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.333044700404312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323322`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.333044700404312, -1.348304998679792], 
            Complex[1.2414730480936764`, -2.818712783323322]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2414730480936766`, -2.9187127833233233`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.19145204681451947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2414730480936766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323323`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[0.19145204681451947`, -1.348304998679793], 
            Complex[1.2414730480936766`, -2.818712783323323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.608435730175939, -1.6997276376830048`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[4.635254682829313, -0.286526325437767], 
            Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.608435730175939, -1.7997276376830051`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[1.4936620292395204`, -0.28652632543776696`], 
            Complex[2.608435730175939, -1.699727637683005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.416548582534638, -1.2609310864108734`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[3.952801820612012, 0.013753774271608805`], 
            Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.416548582534639, -1.1609310864108735`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[7.094394474201807, 0.013753774271608687`], 
            Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61028701795302, -0.7594786249471307}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.298664434058157, 0.44288515307919907`], 
            Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6102870179530235`, -0.8594786249471303}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.1570717804683675`, 0.44288515307919946`], 
            Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.644243187304668, -1.699732810883159}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.7, {
            Complex[6.201340564384264, -0.4506178210463805], 
            Complex[7.644243187304668, -1.599732810883159]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.644243187304668, -1.5997328108831592`}],
          RowBox[{"{", 
            RowBox[{"21.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.7, {
            Complex[9.342933217974057, -0.45061782104638065`], 
            Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2390150301144984`, -2.9230838534712267`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18975599747025035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.352891150913283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[0.18975599747025035`, -1.352891150913283], 
            Complex[1.2390150301144984`, -2.8230838534712266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2390150301144984`, -2.8230838534712275`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.331348651060044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3528911509132835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.331348651060044, -1.3528911509132835`], 
            Complex[1.2390150301144984`, -2.8230838534712275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.61900298210226, -1.7961208467863343`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[1.503444825853813, -0.28432602230905957`], 
            Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.619002982102262, -1.6961208467863331`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[4.645037479443608, -0.2843260223090588], 
            Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.407343930794649, -1.2608408715855624`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[3.9443753488495013`, 0.01394644523553293], 
            Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.407343930794649, -1.1608408715855625`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[7.085968002439294, 0.013946445235532949`], 
            Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611080255416446, -0.7443768154213608}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.299409090344204, 0.45903052180506093`], 
            Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611080255416446, -0.8443768154213613}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.15781643675441, 0.45903052180506065`], 
            Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6432188767245925`, -1.6148150957352265`}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[9.342075512640728, -0.4667723681000823], 
            Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6432188767245925`, -1.714815095735228}],
          RowBox[{"{", 
            RowBox[{"21.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.799999999999997`, {
            Complex[6.2004828590509335`, -0.46677236810008377`], 
            Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2365920537085775`, -2.8274071797574867`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3296849140134457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3574246959370493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8274071797574867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.3296849140134457`, -1.3574246959370493`], 
            Complex[1.2365920537085775`, -2.8274071797574867`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2365920537085782`, -2.927407179757486}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18809226042365237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3574246959370482`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2365920537085782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.827407179757486`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[0.18809226042365237`, -1.3574246959370482`], 
            Complex[1.2365920537085782`, -2.827407179757486]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6295445751835302`, -1.7925634169220723`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[1.513189476842979, -0.2821715098398555], 
            Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6295445751835325`, -1.6925634169220711`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[4.654782130432774, -0.2821715098398547], 
            Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.398165694955261, -1.1607480220888433`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[7.077572945323753, 0.014142621333044114`], 
            Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.398165694955262, -1.2607480220888434`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[3.9359802917339604`, 0.01414262133304412], 
            Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611789218669329, -0.7299407258319833}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.300069789499112, 0.47447188989313444`], 
            Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611789218669329, -0.8299407258319834}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.15847713590932, 0.4744718898931343], 
            Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.642280807952738, -1.7292314506639923`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[6.199710822382092, -0.4822227732417416], 
            Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.64228080795274, -1.6292314506639929`}],
          RowBox[{"{", 
            RowBox[{"21.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.899999999999995`, {
            Complex[9.341303475971888, -0.4822227732417421], 
            Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.234203108976306, -2.831683962269427}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.328052486994904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.36190693217938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.234203108976306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.831683962269427`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.328052486994904, -1.36190693217938], 
            Complex[1.234203108976306, -2.831683962269427]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2342031089763061`, -2.9316839622694277`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1864598334051111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3619069321793806`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2342031089763061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8316839622694276`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[0.1864598334051111, -1.3619069321793806`], 
            Complex[1.2342031089763061`, -2.8316839622694276`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6400621847358976`, -1.689054238532184}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[4.664490377283739, -0.28006168039394375`], 
            Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.640062184735898, -1.7890542385321857`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[1.5228977236939458`, -0.280061680393945], 
            Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.389012001334582, -1.2606524511716515`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[3.927614856061183, 0.014342397934981635`], 
            Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.389012001334583, -1.1606524511716514`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[7.069207509650976, 0.014342397934981436`], 
            Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612427484506159, -0.8161048892141155}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.1590677155468105`, 0.48927860682774], 
            Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612427484506159, -0.7161048892141156}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.300660369136605, 0.4892786068277399], 
            Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6414153511463985`, -1.6430473477012997`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[9.340603220742913, -0.497038390042908], 
            Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.641415351146402, -1.7430473477013013`}],
          RowBox[{"{", 
            RowBox[{"21.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {21.999999999999996`, {
            Complex[6.199010567153125, -0.49703839004290984`], 
            Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2318472296343572`, -2.9359153532357345`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18485775832244397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[0.18485775832244397`, -1.3663391073422058`], 
            Complex[1.2318472296343572`, -2.8359153532357344`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2318472296343572`, -2.8359153532357357`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.326450411912238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.326450411912238, -1.3663391073422075`], 
            Complex[1.2318472296343572`, -2.8359153532357357`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.650557449990277, -1.785592253447088}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[1.5325712660346489`, -0.2779954793374565], 
            Complex[2.650557449990277, -1.685592253447088]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.650557449990278, -1.6855922534470877`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[4.674163919624442, -0.2779954793374564], 
            Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.379881023870964, -1.260554068514124}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[3.9192772983115907`, 0.014545874006250778`], 
            Complex[5.379881023870964, -1.160554068514124]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.379881023870965, -1.160554068514124}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[7.060869951901384, 0.014545874006250832`], 
            Complex[5.379881023870965, -1.160554068514124]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613005749670383, -0.8028138366825414}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.159599046539053, 0.5035094122855176], 
            Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613005749670385, -0.7028138366825419}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.301191700128847, 0.503509412285517], 
            Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.640611758766885, -1.6563182605942428`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[9.339963828630122, -0.5112779620899647], 
            Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.640611758766885, -1.7563182605942467`}],
          RowBox[{"{", 
            RowBox[{"22.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.099999999999998`, {
            Complex[6.198371175040328, -0.5112779620899686], 
            Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2295234905102042`, -2.9401024596493754`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18328511871069184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391664`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[0.18328511871069184`, -1.3707224211391664`], 
            Complex[1.2295234905102042`, -2.8401024596493754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2295234905102046`, -2.8401024596493727`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.324877772300485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2295234905102046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.324877772300485, -1.3707224211391649`], 
            Complex[1.2295234905102046`, -2.8401024596493727`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6610319771130446`, -1.782176452440394}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[1.5422117647034572`, -0.2759719024950626], 
            Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.6610319771130446`, -1.6821764524403946`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[4.683804418293251, -0.2759719024950625], 
            Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.3707709803622485`, -1.1604527800495483`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[7.052558574558201, 0.014753152275367028`], 
            Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.3707709803622485`, -1.2604527800495486`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[3.910965920968408, 0.014753152275367222`], 
            Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613532572082193, -0.6900200786894212}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.301672454837956, 0.5172145811965813], 
            Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613532572082205, -0.7900200786894305}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.160079801248174, 0.5172145811965714], 
            Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6398614242223575`, -1.7690916835589534`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.2, {
            Complex[6.197783928263984, -0.5249917680556042], 
            Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.639861424222358, -1.6690916835589524`}],
          RowBox[{"{", 
            RowBox[{"22.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.2, {
            Complex[9.339376581853779, -0.5249917680556035], 
            Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2272310052160105`, -2.8442463457079334`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3233336909542834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3750580278450637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.3233336909542834`, -1.3750580278450637`], 
            Complex[1.2272310052160105`, -2.8442463457079334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2272310052160111`, -2.9442463457079335`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18174103736449077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3750580278450635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2272310052160111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[0.18174103736449077`, -1.3750580278450635`], 
            Complex[1.2272310052160111`, -2.8442463457079334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.671487342062718, -1.6788058729768809`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[4.693413498234962, -0.2739899938041945], 
            Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.671487342062719, -1.7788058729768792`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[1.5518208446451707`, -0.27398999380419353`], 
            Complex[2.671487342062719, -1.678805872976879]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.36168012892486, -1.2603484877775457`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[3.9026790690591686`, 0.014964339414034983`], 
            Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.361680128924861, -1.1603484877775456`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[7.044271722648962, 0.014964339414035013`], 
            Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6140148915107115`, -0.7776825815576773}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.160516992248921, 0.5304375419992584], 
            Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614014891510713, -0.6776825815576776}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.302109645838716, 0.5304375419992581], 
            Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.63915736107556, -1.7814086547578187`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.3, {
            Complex[6.197241770749233, -0.538223239963063], 
            Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.639157361075561, -1.6814086547578186`}],
          RowBox[{"{", 
            RowBox[{"22.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.3, {
            Complex[9.338834424339028, -0.5382232399630629], 
            Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.224968923986572, -2.9483480350867417`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.18022467413745052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.224968923986572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8483480350867416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[0.18022467413745052`, -1.3793470386724553`], 
            Complex[1.224968923986572, -2.8483480350867416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2249689239865722`, -2.8483480350867407`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.321817327727244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2249689239865722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8483480350867407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.321817327727244, -1.3793470386724547`], 
            Complex[1.2249689239865722`, -2.8483480350867407`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.68192509329917, -1.775479597139089}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[1.5614000976502447`, -0.27204884315225314`], 
            Complex[2.68192509329917, -1.675479597139089]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.68192509329917, -1.67547959713909}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[4.702992751240038, -0.27204884315225375`], 
            Complex[2.68192509329917, -1.67547959713909]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{5.352606764651277, -1.1602410895657405`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[7.036007780489124, 0.015179546227436098`], 
            Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.352606764651277, -1.2602410895657408`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[3.894415126899331, 0.015179546227436329`], 
            Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614458403240932, -0.6657655987699644}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.302509011886752, 0.5432161176861714], 
            Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614458403240932, -0.7657655987699648}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.160916358296958, 0.5432161176861712], 
            Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.638493829265324, -1.7933049250204687`}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.4, {
            Complex[6.1967389220498434`, -0.5510102042411117], 
            Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.638493829265324, -1.693304925020469}],
          RowBox[{"{", 
            RowBox[{"22.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.4, {
            Complex[9.338331575639637, -0.5510102042411122], 
            Complex[7.638493829265324, -1.693304925020469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2227364316674634`, -2.952408513058603}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17873522389447033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3835905239895683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[0.17873522389447033`, -1.3835905239895683`], 
            Complex[1.2227364316674634`, -2.8524085130586028`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2227364316674654`, -2.8524085130586}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3203278774842637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.383590523989566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2227364316674654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.3203278774842637`, -1.383590523989566], 
            Complex[1.2227364316674654`, -2.8524085130586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.692346754360387, -1.6721967497195434`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[4.712543738542191, -0.2701475843833519], 
            Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.692346754360388, -1.7721967497195439`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[1.5709510849523987`, -0.27014758438335246`], 
            Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.343549216446447, -1.2601304789391283`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[3.8861725150187785`, 0.015398887855965335`], 
            Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.343549216446447, -1.1601304789391282`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[7.027765168608572, 0.01539888785596537], 
            Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6148678313818445`, -0.6542377611605058}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.302875299750397, 0.5555834916479572], 
            Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6148678313818445`, -0.7542377611605093}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.161282646160605, 0.5555834916479535], 
            Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6378660616946545`, -1.8048118676611495`}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[6.1962705954158785`, -0.5633858475760002], 
            Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6378660616946545`, -1.70481186766115}],
          RowBox[{"{", 
            RowBox[{"22.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.499999999999996`, {
            Complex[9.337863249005673, -0.5633858475760003], 
            Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2205327458409323`, -2.9564287284726514`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17727191460430375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3877895153924003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2205327458409323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8564287284726513`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[0.17727191460430375`, -1.3877895153924003`], 
            Complex[1.2205327458409323`, -2.8564287284726513`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.220532745840933, -2.8564287284726504`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3188645681940967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3877895153923996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.220532745840933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8564287284726504`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.3188645681940967`, -1.3877895153923996`], 
            Complex[1.220532745840933, -2.8564287284726504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.702753826320577, -1.7689564964668991`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[1.5804753396984255`, -0.26828539346253044`], 
            Complex[2.702753826320577, -1.668956496466899]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.702753826320577, -1.6689564964669001`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[4.722067993288219, -0.2682853934625311], 
            Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.334505844025381, -1.1600165448562518`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[7.019542340843495, 0.015622483989198223`], 
            Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.334505844025381, -1.2600165448562521`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[3.8779496872537016`, 0.015622483989198204`], 
            Complex[5.334505844025381, -1.160016544856252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615247132185832, -0.743071359259793}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.1616198199314836`, 0.5675689693259762], 
            Complex[7.615247132185832, -0.643071359259793]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615247132185832, -0.6430713592597935}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.303212473521276, 0.5675689693259758], 
            Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.637270060814722, -1.8159571961426482`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[6.195832788389601, -0.5753794785718529], 
            Complex[7.637270060814722, -1.715957196142648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.637270060814722, -1.7159571961426487`}],
          RowBox[{"{", 
            RowBox[{"22.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.599999999999998`, {
            Complex[9.337425441979393, -0.5753794785718535], 
            Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2183571150782422`, -2.860409595603666}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3174266591507107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3919450076426472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2183571150782422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.3174266591507107`, -1.3919450076426472`], 
            Complex[1.2183571150782422`, -2.860409595603666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.218357115078243, -2.9604095956036662`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1758340055609178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.391945007642646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.218357115078243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[0.1758340055609178, -1.391945007642646], 
            Complex[1.218357115078243, -2.860409595603666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7131477901421968`, -1.6657580424757268`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[4.731567022892644, -0.26646148678673676`], 
            Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7131477901421976`, -1.7657580424757249`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[1.5899743693028523`, -0.26646148678673565`], 
            Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.325475035055747, -1.159899171471262}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[7.011337781577717, 0.015850459092959842`], 
            Complex[5.325475035055747, -1.159899171471262]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.325475035055748, -1.259899171471262}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[3.8697451279879247`, 0.015850459092959818`], 
            Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615599647619971, -0.7322417704324716}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.161931218858729, 0.5791985860418423], 
            Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615599647619973, -0.6322417704324753}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.303523872448524, 0.5791985860418385], 
            Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.636702444963451, -1.7267655369464128`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.7, {
            Complex[9.337014778473906, -0.5870171355873209], 
            Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.636702444963452, -1.8267655369464133`}],
          RowBox[{"{", 
            RowBox[{"22.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.7, {
            Complex[6.1954221248841135`, -0.5870171355873215], 
            Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2162088173083034`, -2.864351995882056}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3160134393130587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.396057960481959`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.864351995882056`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.3160134393130587`, -1.396057960481959], 
            Complex[1.2162088173083034`, -2.864351995882056]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2162088173083037`, -2.9643519958820557`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17442078572326566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3960579604819585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2162088173083037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8643519958820556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[0.17442078572326566`, -1.3960579604819585`], 
            Complex[1.2162088173083037`, -2.8643519958820556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7235301089335913`, -1.7626006307106494`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[1.5994496576990789`, -0.26467511963294016`], 
            Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7235301089335926`, -1.6626006307106498`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[4.741042311288872, -0.26467511963294066`], 
            Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.316455202430542, -1.1597782378808235`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[7.003150003118844, 0.016082942650415873`], 
            Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.316455202430543, -1.2597782378808235`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[3.861557349529051, 0.01608294265041592], 
            Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615928222964841, -0.6217269966329017}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.303812331602318, 0.5904955973399487], 
            Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615928222964841, -0.721726996632902}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.162219678012526, 0.5904955973399484], 
            Complex[7.615928222964841, -0.621726996632902]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.636160330682661, -1.7372588918245433`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[9.336628388028364, -0.5983220770848241], 
            Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.636160330682662, -1.8372588918245434`}],
          RowBox[{"{", 
            RowBox[{"22.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.799999999999997`, {
            Complex[6.195035734438572, -0.5983220770848242], 
            Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2140871582933066`, -2.9682567795138803`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17303157216407558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4001293003321469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2140871582933066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[0.17303157216407558`, -1.4001293003321469`], 
            Complex[1.2140871582933066`, -2.8682567795138803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.214087158293307, -2.8682567795138803`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3146242257538696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4001293003321456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.214087158293307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.3146242257538696`, -1.4001293003321456`], 
            Complex[1.214087158293307, -2.8682567795138803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.733902230122971, -1.7594835406566913`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[1.6089026674977167`, -0.2629255847348713], 
            Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7339022301229714`, -1.6594835406566917`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[4.75049532108751, -0.26292558473487176`], 
            Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.307444781657182, -1.1596536178547647`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.994977543195845, 0.016320069418202337`], 
            Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.307444781657183, -1.2596536178547648`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[3.8533848896060525`, 0.0163200694182023], 
            Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6162352979952175`, -0.711507287733823}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.162487621687207, 0.6014808784641323], 
            Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616235297995222, -0.6115072877338223}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.304080275277004, 0.6014808784641332], 
            Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.635641241458829, -1.747457014478097}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.9, {
            Complex[9.336263812328982, -0.609315181113391], 
            Complex[7.635641241458829, -1.747457014478097]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.635641241458829, -1.8474570144780973`}],
          RowBox[{"{", 
            RowBox[{"22.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.9, {
            Complex[6.194671158739189, -0.6093151811133911], 
            Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2119914702029877`, -2.8721247669993084`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.313258362208889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.313258362208889, -1.4041599218900036`], 
            Complex[1.2119914702029877`, -2.8721247669993084`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2119914702029881`, -2.9721247669993085`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17166570861909555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2119914702029881`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[0.17166570861909555`, -1.4041599218900036`], 
            Complex[1.2119914702029881`, -2.8721247669993084`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7442655875587194`, -1.756406087088549}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[1.6183348420620054`, -0.2612122109807513], 
            Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7442655875587207`, -1.656406087088548}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[4.7599274956518, -0.2612122109807508], 
            Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.2984422283503445`, -1.2595251795492592`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[3.8452263089759486`, 0.01656197969868379], 
            Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.298442228350345, -1.159525179549259}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.986818962565743, 0.016561979698683896`], 
            Complex[5.298442228350345, -1.159525179549259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616522978484024, -0.7015648318155974}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.162737136528052, 0.6121732527479822], 
            Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616522978484024, -0.6015648318155976}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.304329790117846, 0.612173252747982], 
            Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.635143036145728, -1.8573777202744643`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[6.194326278421569, -0.6200152737048314], 
            Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.635143036145728, -1.7573777202744643`}],
          RowBox[{"{", 
            RowBox[{"22.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {22.999999999999996`, {
            Complex[9.335918932011362, -0.6200152737048319], 
            Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.209921110279896, -2.875956750557249}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.311915217718847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.408150689624686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.209921110279896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.875956750557249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.311915217718847, -1.408150689624686], 
            Complex[1.209921110279896, -2.875956750557249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2099211102798964`, -2.975956750557247}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.17032256412905356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4081506896246843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2099211102798964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.875956750557247`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[0.17032256412905356`, -1.4081506896246843`], 
            Complex[1.2099211102798964`, -2.875956750557247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7546216035454134`, -1.753367618952437}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[1.6277476075095596`, -0.2595343622253301], 
            Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7546216035454143`, -1.6533676189524371`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[4.769340261099353, -0.2595343622253304], 
            Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.289446015816816, -1.259392785201224}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[3.837080189128189, 0.016808819629533064`], 
            Complex[5.289446015816816, -1.159392785201224]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.289446015816816, -1.159392785201224}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.978672842717983, 0.01680881962953298], 
            Complex[5.289446015816816, -1.159392785201224]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616793092860656, -0.5918834984038932}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.30456268297077, 0.6225897638061416], 
            Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616793092860657, -0.6918834984038951}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.162970029380981, 0.6225897638061394], 
            Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.63466385223734, -1.7670371430158247`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[9.335591908744412, -0.6304394010704698], 
            Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.63466385223734, -1.8670371430158252`}],
          RowBox[{"{", 
            RowBox[{"23.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.099999999999998`, {
            Complex[6.193999255154619, -0.63043940107047], 
            Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2078754595887078`, -2.979753495463146}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16900153176725363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4121024391848713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.879753495463146`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[0.16900153176725363`, -1.4121024391848713`], 
            Complex[1.2078754595887078`, -2.879753495463146]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2078754595887096`, -2.8797534954631456`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.310594185357048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.41210243918487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2078754595887096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8797534954631456`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.310594185357048, -1.41210243918487], 
            Complex[1.2078754595887096`, -2.8797534954631456`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7649716908242405`, -1.7503675183549188`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[1.637142374648998, -0.2578914362102892], 
            Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7649716908242414`, -1.6503675183549193`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[4.778735028238791, -0.25789143621028987`], 
            Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.280454632721416, -1.1592562908025152`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.970537783665925, 0.017060741491919468`], 
            Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.280454632721417, -1.259256290802515}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[3.8289451300761326`, 0.017060741491919426`], 
            Complex[5.280454632721417, -1.159256290802515]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617047237536007, -0.6824486239818053}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.1631878734954, 0.6327459028649584], 
            Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617047237536009, -0.5824486239818062}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.304780527085194, 0.6327459028649576], 
            Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.634202060478484, -1.8764499494328055`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[6.193688485375648, -0.6406030569368893], 
            Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.634202060478484, -1.7764499494328059`}],
          RowBox[{"{", 
            RowBox[{"23.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.199999999999996`, {
            Complex[9.33528113896544, -0.6406030569368892], 
            Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.205853921843281, -2.883515741306371}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3092946810361643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.883515741306371`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.3092946810361643`, -1.4160159787223123`], 
            Complex[1.205853921843281, -2.883515741306371]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.205853921843282, -2.9835157413063706`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1677020274463709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.205853921843282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8835157413063706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[0.1677020274463709, -1.4160159787223117`], 
            Complex[1.205853921843282, -2.8835157413063706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.775317254506115, -1.647405199653864}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[4.788113194449318, -0.256282863587831], 
            Complex[2.775317254506115, -1.647405199653864]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7753172545061173`, -1.7474051996538635`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[1.6465205408595256`, -0.2562828635878306], 
            Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.271466580823748, -1.1591155457523543`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.962412401815591, 0.017317904038714253`], 
            Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.271466580823749, -1.2591155457523544`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[3.820819748225798, 0.01731790403871422], 
            Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617286813480894, -0.6732468315559037}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.163392045750655, 0.6426557999628854], 
            Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617286813480894, -0.5732468315559044}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.304984699340448, 0.6426557999628848], 
            Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.633756228225985, -1.8856295196238635`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[6.193392563005682, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.633756228225985, -1.7856295196238638`}],
          RowBox[{"{", 
            RowBox[{"23.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.299999999999997`, {
            Complex[9.334985216595475, -0.6505203737511226], 
            Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.203855922305636, -2.9872442031730206`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1664234887985512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[0.1664234887985512, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.203855922305636, -2.8872442031730206`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3080161423883445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.3080161423883445`, -1.419892090137794], 
            Complex[1.203855922305636, -2.8872442031730206`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.785659693965298, -1.6444801086473977`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[4.79747614551083, -0.2547081070429694], 
            Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7856596939652984`, -1.744480108647397}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[1.6558834919210377`, -0.25470810704296915`], 
            Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.262480372776143, -1.1589703924863028`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.954295327902444, 0.01758047284423772], 
            Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.262480372776144, -1.2589703924863032`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[3.812702674312651, 0.0175804728442376], 
            Complex[5.262480372776144, -1.158970392486303]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6175130559865005`, -0.5642658778811105}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.305176410484561, 0.6523323858111223], 
            Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617513055986503, -0.664265877881112}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.163583756894771, 0.6523323858111204], 
            Complex[7.617513055986503, -0.564265877881112]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.633325089631601, -1.8945880998355054`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.4, {
            Complex[6.193110249156134, -0.660204284545775], 
            Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.633325089631603, -1.7945880998355062`}],
          RowBox[{"{", 
            RowBox[{"23.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.4, {
            Complex[9.334702902745928, -0.6602042845457757], 
            Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.2018809067516416`, -2.9909395727595074`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1651653741234745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4237315302550273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8909395727595073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[0.1651653741234745, -1.4237315302550273`], 
            Complex[1.2018809067516416`, -2.8909395727595073`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.2018809067516425`, -2.890939572759507}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.306758027713268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4237315302550264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.2018809067516425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.890939572759507`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.306758027713268, -1.4237315302550264`], 
            Complex[1.2018809067516425`, -2.890939572759507]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.796000404700961, -1.7415917218573376`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[1.6652326038019236`, -0.2531666605106765], 
            Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.7960004047009623`, -1.6415917218573366`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[4.806825257391718, -0.2531666605106761], 
            Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.253494529973697, -1.2588206660799293`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[3.8045925513977634`, 0.017848620677213583`], 
            Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.253494529973699, -1.1588206660799294`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.946185204987557, 0.017848620677213628`], 
            Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61772705906054, -0.6554945233226198}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.163764076292796, 0.6617875296457958], 
            Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617727059060542, -0.5554945233226201}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.30535672988259, 0.6617875296457956], 
            Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6329075211926085`, -1.803336932605163}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.5, {
            Complex[9.334433100918964, -0.6696666607954201], 
            Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.632907521192611, -1.9033369326051632`}],
          RowBox[{"{", 
            RowBox[{"23.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.5, {
            Complex[6.192840447329175, -0.6696666607954201], 
            Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1999283404985253`, -2.9946025194218264`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1639271613994279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[0.1639271613994279, -1.4275350319275484`], 
            Complex[1.1999283404985253`, -2.8946025194218263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1999283404985257`, -2.8946025194218263`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3055198149892218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1999283404985257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.3055198149892218`, -1.4275350319275477`], 
            Complex[1.1999283404985257`, -2.8946025194218263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.806340780173878, -1.6387395459042151`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[4.8161618980011855`, -0.2516580484846366], 
            Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8063407801738802`, -1.7387395459042156`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[1.6745692444113933`, -0.251658048484637], 
            Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.24450758044773, -1.1586661938251581`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.938080686504964, 0.018122527898744748`], 
            Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.244507580447731, -1.258666193825158}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[3.796488032915171, 0.018122527898744724`], 
            Complex[5.244507580447731, -1.158666193825158]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617929795566583, -0.5469224203770374}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.305526605913883, 0.6710321572939462], 
            Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617929795566583, -0.6469224203770383}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.16393395232409, 0.671032157293945], 
            Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.632502521562484, -1.9118863682445575`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.6, {
            Complex[6.192582182972333, -0.6789184304865281], 
            Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.632502521562484, -1.8118863682445574`}],
          RowBox[{"{", 
            RowBox[{"23.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.6, {
            Complex[9.334174836562127, -0.6789184304865283], 
            Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1979977074898187`, -2.9982336911650034`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16270834735290776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650033`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[0.16270834735290776`, -1.4313033050832542`], 
            Complex[1.1979977074898187`, -2.8982336911650033`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1979977074898187`, -2.8982336911650046`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.304301000942701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.304301000942701, -1.4313033050832549`], 
            Complex[1.1979977074898187`, -2.8982336911650046`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.816682213625116, -1.7359231169716272`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[1.6838947753228468`, -0.25018182541497563`], 
            Complex[2.816682213625116, -1.635923116971627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8166822136251186`, -1.6359231169716282`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[4.825487428912641, -0.2501818254149765], 
            Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.235518056794404, -1.2585067947770963`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[3.7883877807626547`, 0.018402382887287773`], 
            Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.235518056794405, -1.158506794777096}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.929980434352448, 0.01840238288728782], 
            Complex[5.235518056794405, -1.158506794777096]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618122133957997, -0.5385400176762593}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.305686882893223, 0.6800763528244194], 
            Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618122133957997, -0.6385400176762598}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.164094229303429, 0.680076352824419], 
            Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.632109194769857, -1.9202459608400841`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[6.192334586512061, -0.6879696797720971], 
            Complex[7.632109194769857, -1.820245960840084]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.632109194769857, -1.8202459608400863`}],
          RowBox[{"{", 
            RowBox[{"23.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.699999999999996`, {
            Complex[9.333927240101854, -0.6879696797720991], 
            Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.196088509433674, -2.901833715576858}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3031011001724133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4350370377108632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.196088509433674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.901833715576858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.3031011001724133`, -1.4350370377108632`], 
            Complex[1.196088509433674, -2.901833715576858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1960885094336744`, -3.0018337155768595`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16150844658262048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4350370377108643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1960885094336744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9018337155768594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[0.16150844658262048`, -1.4350370377108643`], 
            Complex[1.1960885094336744`, -2.9018337155768594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8270260998834287`, -1.7331420003581568`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[1.6932105534745874`, -0.2487375751928472], 
            Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.827026099883429, -1.6331420003581558`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[4.834803207064381, -0.24873757519284634`], 
            Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.226524494130514, -1.2583422792689292`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[3.7802904634285417`, 0.018688382492788227`], 
            Complex[5.226524494130514, -1.158342279268929]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.226524494130514, -1.1583422792689293`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.921883117018336, 0.018688382492788213`], 
            Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618304852267418, -0.5303384769181552}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.305838315194185, 0.6889294464957751], 
            Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6183048522674195`, -0.6303384769181541}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.164245661604394, 0.6889294464957759], 
            Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.631726736184739, -1.8284245513261361`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[9.333689532777536, -0.6968297409230606], 
            Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.631726736184741, -1.9284245513261358`}],
          RowBox[{"{", 
            RowBox[{"23.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.799999999999997`, {
            Complex[6.192096879187743, -0.6968297409230599], 
            Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1942002649908234`, -3.0054032007098535`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.16032699073407702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1942002649908234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9054032007098534`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[0.16032699073407702`, -1.438736896792191], 
            Complex[1.1942002649908234`, -2.9054032007098534`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.194200264990824, -2.905403200709853}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3019196443238705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.194200264990824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.905403200709853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.3019196443238705`, -1.438736896792191], 
            Complex[1.194200264990824, -2.905403200709853]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.837373837167927, -1.630395790115732}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[4.844110586443732, -0.24732491072033783`], 
            Complex[2.837373837167927, -1.630395790115732]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8373738371679282`, -1.7303957901157323`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[1.7025179328539397`, -0.2473249107203387], 
            Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.217525428068778, -1.2581724483922545`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[3.772194754147412, 0.018980732522336802`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.217525428068778, -1.1581724483922544`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.913787407737206, 0.018980732522336733`], 
            Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618478649868708, -0.6223096006529586}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.164388925515004, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618478649868708, -0.5223096006529586}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.305981579104797, 0.697600091198504], 
            Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6313544207148105`, -1.936430339702474}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {23.9, {
            Complex[6.191868361155921, -0.7055072687737808], 
            Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6313544207148105`, -1.8364303397024744`}],
          RowBox[{"{", 
            RowBox[{"23.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {23.9, {
            Complex[9.333461014745714, -0.705507268773781], 
            Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.192332509008784, -2.908942735914548}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3007561813111055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4424035291838815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.908942735914548`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[3.3007561813111055`, -1.4424035291838815`], 
            Complex[1.192332509008784, -2.908942735914548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.192332509008784, -3.0089427359145504`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15916352772131243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.442403529183883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9089427359145503`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[0.15916352772131243`, -1.442403529183883], 
            Complex[1.192332509008784, -2.9089427359145503`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8477268288924487`, -1.727684108773821}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[1.711818266170711, -0.24594347356467736`], 
            Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.847726828892449, -1.6276841087738219`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[4.853410919760504, -0.24594347356467788`], 
            Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.2085193927050835`, -1.1579970934399617`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[6.90569198266763, 0.01927964825993098], 
            Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.208519392705085, -1.2579970934399618`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[3.7640993290778377`, 0.019279648259930993`], 
            Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618644157419196, -0.5144457692358492}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.30611728283302, 0.7060963291837463], 
            Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618644157419197, -0.6144457692358496}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.164524629243228, 0.7060963291837459], 
            Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630991592823766, -1.9442709480852434`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24., {
            Complex[6.191648401446948, -0.7140103074539127], 
            Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630991592823766, -1.8442709480852433`}],
          RowBox[{"{", 
            RowBox[{"24.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24., {
            Complex[9.33324105503674, -0.7140103074539126], 
            Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1904847917991184`, -3.0124528926278753`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15801762099250957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4460375624519293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1904847917991184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[0.15801762099250957`, -1.4460375624519293`], 
            Complex[1.1904847917991184`, -2.912452892627875]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.190484791799119, -2.912452892627875}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2996102745823035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.446037562451929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.190484791799119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.2996102745823035`, -1.446037562451929], 
            Complex[1.190484791799119, -2.912452892627875]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.858086485478033, -1.6250066071493976`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[4.862705560115598, -0.24459293369624477`], 
            Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8580864854780335`, -1.7250066071493977`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[1.7211129065258053`, -0.2445929336962447], 
            Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.199504918610364, -1.2578159953084995`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[3.7560028654954856`, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.199504918610364, -1.1578159953084997`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.897595519085279, 0.01958535502317048], 
            Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618801945306149, -0.6067398855588758}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.164653321403731, 0.7144256505494253], 
            Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618801945306149, -0.5067398855588761}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.306245974993525, 0.7144256505494249], 
            Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630637658047721, -1.9519534759784039`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[6.191436429442565, -0.7223463488774431], 
            Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630637658047721, -1.8519534759784038`}],
          RowBox[{"{", 
            RowBox[{"24.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.099999999999994`, {
            Complex[9.333029083032358, -0.7223463488774439], 
            Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1886566784549102`, -2.9159342251191687`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.298481502426376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620289`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1886566784549102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9159342251191687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.298481502426376, -1.4496396056620289`], 
            Complex[1.1886566784549102`, -2.9159342251191687`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.188656678454911, -3.015934225119166}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15688884883658272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.188656678454911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.915934225119166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[0.15688884883658272`, -1.4496396056620269`], 
            Complex[1.188656678454911, -2.915934225119166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8684542261798467`, -1.7223629642431868`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[1.7304032090806973`, -0.24327298931041993`], 
            Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.868454226179847, -1.6223629642431858`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[4.871995862670491, -0.24327298931041968`], 
            Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.190480530819805, -1.2576289238560523`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[3.747904039995082, 0.01989808875998759], 
            Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.190480530819805, -1.1576289238560522`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.889496693584875, 0.019898088759987553`], 
            Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61895253085656, -0.49918532641716257`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.306368151840394, 0.722595044698084], 
            Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61895253085656, -0.5991853264171629}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.164775498250602, 0.7225950446980839], 
            Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630292075750291, -1.8594845489107188`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[9.332824581199281, -0.73052238420331], 
            Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.630292075750293, -1.9594845489107189`}],
          RowBox[{"{", 
            RowBox[{"24.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.199999999999996`, {
            Complex[6.191231927609488, -0.7305223842033104], 
            Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1868477482057302`, -2.919387271196738}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2973694573177923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4532102501286348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.2973694573177923`, -1.4532102501286348`], 
            Complex[1.1868477482057302`, -2.919387271196738]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1868477482057311`, -3.019387271196738}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15577680372799887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4532102501286346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1868477482057311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[0.15577680372799887`, -1.4532102501286346`], 
            Complex[1.1868477482057311`, -2.919387271196738]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8788314809349784`, -1.7197528872232837`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[1.739690532733481, -0.24198336673385532`], 
            Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8788314809349793`, -1.619752887223283}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[4.881283186323276, -0.24198336673385487`], 
            Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.181444746812216, -1.1574356372128107`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.881394180284589, 0.020218096688815555`], 
            Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.181444746812216, -1.257435637212811}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[3.739801526694796, 0.020218096688815523`], 
            Complex[5.181444746812216, -1.157435637212811]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619096384518943, -0.591775899558662}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.164891609869033, 0.7306110457745064], 
            Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6190963845189446`, -0.4917758995586582}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.30648426345883, 0.730611045774511], 
            Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629954352907652, -1.9668703613890224`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[6.1910344252759195`, -0.738544949275635], 
            Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629954352907652, -1.8668703613890223`}],
          RowBox[{"{", 
            RowBox[{"24.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.299999999999997`, {
            Complex[9.332627078865713, -0.7385449492756353], 
            Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1850575938076657`, -2.9228125528774775`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.296273745297108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4567500701253233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9228125528774775`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.296273745297108, -1.4567500701253233`], 
            Complex[1.1850575938076657`, -2.9228125528774775`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1850575938076662`, -3.022812552877478}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1546810917073148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.456750070125323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1850575938076662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.922812552877478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[0.1546810917073148, -1.456750070125323], 
            Complex[1.1850575938076662`, -2.922812552877478]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.889219692237537, -1.7171761114978095`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[1.7489762418071482`, -0.24072382041628856`], 
            Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8892196922375373`, -1.6171761114978092`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[4.8905688953969415`, -0.24072382041628823`], 
            Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1723960744723065`, -1.2572358810391413`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[3.7316939954367316`, 0.020545637985933], 
            Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.172396074472307, -1.1572358810391412`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.873286649026525, 0.020545637985932938`], 
            Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619233935186141, -0.5845058056239236}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.165002065498246, 0.738479772924393], 
            Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619233935186141, -0.4845058056239263}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.30659471908804, 0.7384797729243899], 
            Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629624038754354, -1.8741167149612874`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.4, {
            Complex[9.332436146868352, -0.7464201648848554], 
            Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629624038754354, -1.9741167149612884`}],
          RowBox[{"{", 
            RowBox[{"24.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.4, {
            Complex[6.190843493278558, -0.7464201648848559], 
            Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1832858209661048`, -3.02621057702186}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1536013317951177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.92621057702186`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[0.1536013317951177, -1.4602596235588952`], 
            Complex[1.1832858209661048`, -2.92621057702186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1832858209661052`, -2.926210577021858}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2951939853849117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1832858209661052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.926210577021858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.2951939853849117`, -1.4602596235588936`], 
            Complex[1.1832858209661052`, -2.926210577021858]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8996203170476367`, -1.614632400878879}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[4.899854361345616, -0.23949413300958752`], 
            Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.8996203170476376`, -1.7146324008788798`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[1.758261707755823, -0.23949413300958816`], 
            Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.163333010028643, -1.2570293877270227`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[3.723580109977185, 0.020880984524095002`], 
            Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.163333010028643, -1.1570293877270228`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.865172763566979, 0.020880984524095033`], 
            Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619365574796855, -0.4773696043103919}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.306699891715693, 0.7462069660795199], 
            Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619365574796855, -0.5773696043103921}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.1651072381259, 0.7462069660795196], 
            Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629300720152121, -1.9812290520550746`}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[6.190658739339742, -0.7541537725552644], 
            Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.629300720152121, -1.881229052055075}],
          RowBox[{"{", 
            RowBox[{"24.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.499999999999996`, {
            Complex[9.332251392929535, -0.7541537725552647], 
            Complex[7.629300720152121, -1.881229052055075]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.181532047789208, -3.0295818359364928`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15253715543722762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4637394526094687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.181532047789208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[0.15253715543722762`, -1.4637394526094687`], 
            Complex[1.181532047789208, -2.9295818359364927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1815320477892093`, -2.9295818359364927`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2941298090270217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4637394526094694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1815320477892093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.2941298090270217`, -1.4637394526094694`], 
            Complex[1.1815320477892093`, -2.9295818359364927`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.910034828740951, -1.612121547840817}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[4.90914096448451, -0.23829411553630825`], 
            Complex[2.910034828740951, -1.612121547840817]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.910034828740952, -1.7121215478408176`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[1.7675483108947163`, -0.2382941155363085], 
            Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1542540359599105`, -1.2568158755396661`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[3.7154585261603414`, 0.021224421666976207`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1542540359599105`, -1.156815875539666}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.857051179750135, 0.021224421666976113`], 
            Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619491662328772, -0.5703621842002207}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.165207468468805, 0.7537980178639989], 
            Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619491662328774, -0.4703621842002206}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.306800122058599, 0.7537980178639988], 
            Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628984017568608, -1.8882124861522411`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[9.332072457649627, -0.7617511664534365], 
            Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628984017568608, -1.9882124861522417`}],
          RowBox[{"{", 
            RowBox[{"24.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.599999999999998`, {
            Complex[6.190479804059834, -0.761751166453437], 
            Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.179795904270083, -3.0329268079462413`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.15148820597915524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4671900843386563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.179795904270083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.932926807946241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[0.15148820597915524`, -1.4671900843386563`], 
            Complex[1.179795904270083, -2.932926807946241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1797959042700832`, -2.9329268079462416`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2930808595689487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4671900843386574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1797959042700832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9329268079462416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.2930808595689487`, -1.4671900843386574`], 
            Complex[1.1797959042700832`, -2.9329268079462416`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.920464719105736, -1.6096433738762483`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[4.918430095749453, -0.2371236076506873], 
            Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.920464719105737, -1.7096433738762478`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[1.776837442159661, -0.23712360765068694`], 
            Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.145157618862018, -1.156595047683686}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.848920543658824, 0.02157624912441265], 
            Complex[5.145157618862018, -1.156595047683686]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.145157618862019, -1.256595047683686}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[3.707327890069032, 0.02157624912441267], 
            Complex[5.145157618862019, -1.156595047683686]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619612527276209, -0.5634787357769724}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.165303068434313, 0.761258002124613], 
            Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619612527276209, -0.4634787357769729}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.306895722024107, 0.7612580021246124], 
            Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628673581573148, -1.9950718287746994`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.7, {
            Complex[6.1903063574303445`, -0.7692174219206874], 
            Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62867358157315, -1.8950718287747004`}],
          RowBox[{"{", 
            RowBox[{"24.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.7, {
            Complex[9.33189901102014, -0.7692174219206883], 
            Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1780770317958789`, -3.036245957937765}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1504541381679981`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1780770317958789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.936245957937765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[0.1504541381679981, -1.470612031267735], 
            Complex[1.1780770317958789`, -2.936245957937765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.178077031795879, -2.936245957937766}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2920467917577914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267736`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.178077031795879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.936245957937766`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.2920467917577914`, -1.470612031267736], 
            Complex[1.178077031795879, -2.936245957937766]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.930911500394467, -1.7071977299543906`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[1.7861305049022496`, -0.23598247799562685`], 
            Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.930911500394467, -1.6071977299543907`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[4.927723158492043, -0.23598247799562702`], 
            Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.136042207268361, -1.2563665913076096`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[3.6991868361460636`, 0.021936781873947247`], 
            Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.136042207268362, -1.1563665913076093`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.840779489735858, 0.021936781873947195`], 
            Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619728472689179, -0.5567147272275415}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.165394324140473, 0.7685916995129604], 
            Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619728472689179, -0.4567147272275417}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.306986977730267, 0.7685916995129599], 
            Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62836908977242, -1.9018116136847973`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.8, {
            Complex[9.331730749379409, -0.7765573210571958], 
            Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62836908977242, -2.0018116136847977`}],
          RowBox[{"{", 
            RowBox[{"24.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.8, {
            Complex[6.190138095789615, -0.7765573210571961], 
            Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1763750826821242`, -3.0395397378762263`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1494346176800629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4740057919276426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762262`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[0.1494346176800629, -1.4740057919276426`], 
            Complex[1.1763750826821242`, -2.9395397378762262`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1763750826821242`, -2.9395397378762267`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.291027271269856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.474005791927643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762267`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.291027271269856, -1.474005791927643], 
            Complex[1.1763750826821242`, -2.9395397378762267`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9413767074374184`, -1.7047844970867334`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[1.7954289167267061`, -0.23487062465998598`], 
            Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.94137670743742, -1.6047844970867333`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[4.9370215703165, -0.23487062465998587`], 
            Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.126906229415363, -1.2561301764198545`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[3.6910339852795406`, 0.022306351154756415`], 
            Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.126906229415363, -1.1561301764198548`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.832626638869334, 0.022306351154756456`], 
            Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619839777837855, -0.45006588268489056`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.30707415214959, 0.7758036204842984], 
            Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619839777837857, -0.5500658826848904}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.1654814985597985`, 0.7758036204842987], 
            Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628070244122036, -1.9084361186447758`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.9, {
            Complex[9.331567392745953, -0.7837753757227326], 
            Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.628070244122036, -2.0084361186447763`}],
          RowBox[{"{", 
            RowBox[{"24.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.9, {
            Complex[6.18997473915616, -0.7837753757227331], 
            Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1746897197307482`, -2.9428085872967427`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2900219742624115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4773718513824372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9428085872967427`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.2900219742624115`, -1.4773718513824372`], 
            Complex[1.1746897197307482`, -2.9428085872967427`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1746897197307484`, -3.0428085872967423`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1484293206726183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.477371851382437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1746897197307484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.942808587296742`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[0.1484293206726183, -1.477371851382437], 
            Complex[1.1746897197307484`, -2.942808587296742]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9518618998259747`, -1.602403587006065}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[4.946326764964685, -0.2337879757412101], 
            Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9518618998259756`, -1.7024035870060648`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[1.8047341113748927`, -0.23378797574120985`], 
            Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.117748090945092, -1.1558854547185569`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.824460596435171, 0.022685305540684226`], 
            Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.117748090945093, -1.255885454718557}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[3.6828679428453777`, 0.022685305540684448`], 
            Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619946700555886, -0.4435281626164995}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.307157487430532, 0.7828980260257034], 
            Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619946700555888, -0.543528162616499}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.1655648338407385`, 0.7828980260257037], 
            Complex[7.619946700555888, -0.443528162616499]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627776768560511, -1.9149493850304053`}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[9.331408682475267, -0.7908758482666055], 
            Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627776768560513, -2.014949385030405}],
          RowBox[{"{", 
            RowBox[{"24.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {24.999999999999996`, {
            Complex[6.189816028885474, -0.7908758482666055], 
            Complex[7.627776768560513, -1.914949385030405]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1730206158103629`, -3.046052933772111}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1474379333583333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[0.1474379333583333, -1.4807106817278035`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1730206158103629`, -2.946052933772111}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2890305869481264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.2890305869481264`, -1.4807106817278028`], 
            Complex[1.1730206158103629`, -2.946052933772111]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.962368664173644, -1.7000549429658454`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[1.814047540666005, -0.23273449001922963`], 
            Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9623686641736446`, -1.6000549429658446`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[4.955640194255799, -0.2327344900192291], 
            Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.108566172536498, -1.155632058324808}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.816279950289862, 0.023074012099830184`], 
            Complex[5.108566172536498, -1.155632058324808]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.1085661725364995`, -1.2556320583248082`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[3.6746872967000694`, 0.0230740120998302], 
            Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620049479307305, -0.43709774610477947`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.307237206941968, 0.7898789463823147], 
            Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6200494793073075`, -0.537097746104778}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.165644553352178, 0.7898789463823163], 
            Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627488406920755, -2.0213552355525555`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[6.189661725604909, -0.7978627702556053], 
            Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627488406920755, -1.9213552355525565`}],
          RowBox[{"{", 
            RowBox[{"25.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.099999999999998`, {
            Complex[9.331254379194702, -0.7978627702556061], 
            Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1713674534574503`, -2.9492731933581573`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.288052805190806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4840227425660197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.288052805190806, -1.4840227425660197`], 
            Complex[1.1713674534574503`, -2.9492731933581573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1713674534574505`, -3.0492731933581574`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14646015160101253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.48402274256602`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1713674534574505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[0.14646015160101253`, -1.48402274256602], 
            Complex[1.1713674534574505`, -2.9492731933581573`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9728986164633167`, -1.697738540667867}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[1.8233706764978728`, -0.2317101577484136], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9728986164633167`, -1.5977385406678668`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[4.9649633300876665`, -0.23171015774841372`], 
            Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.099358827456356, -1.255369598409927}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[3.6664906151164782`, 0.023472857648944835`], 
            Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.099358827456356, -1.155369598409927}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.808083268706271, 0.02347285764894464], 
            Complex[5.099358827456356, -1.155369598409927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620148335014862, -0.5307710148004999}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.165720863489107, 0.7967501980135657], 
            Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620148335014864, -0.4307710148004997}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.307313517078901, 0.7967501980135657], 
            Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627204921081202, -1.9276572903056561`}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[9.331104260978192, -0.8047399594318435], 
            Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.627204921081207, -2.027657290305655}],
          RowBox[{"{", 
            RowBox[{"25.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.199999999999996`, {
            Complex[6.189511607388403, -0.804739959431843], 
            Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1697299244972095`, -2.9524697710180425`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2870883341211625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4873084814587765`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1697299244972095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9524697710180425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.2870883341211625`, -1.4873084814587765`], 
            Complex[1.1697299244972095`, -2.9524697710180425`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.16972992449721, -3.0524697710180417`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14549568053136955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.487308481458776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.16972992449721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9524697710180416`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[0.14549568053136955`, -1.487308481458776], 
            Complex[1.16972992449721, -2.9524697710180416`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.983453404489649, -1.6954543893273732`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[1.8327050129169915`, -0.23071500157543248`], 
            Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.98345340448965, -1.5954543893273736`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[4.974297666506786, -0.2307150015754329], 
            Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.090124379020649, -1.2550976637063445`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[3.6582764446551637`, 0.023882250111808095`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.090124379020649, -1.1550976637063444`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.799869098244956, 0.023882250111808064`], 
            Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620243472681646, -0.42454453835966893`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.307386608861503, 0.8035153989801238], 
            Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620243472681651, -0.5245445383596685}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.165793955271714, 0.8035153989801244], 
            Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626926089324718, -1.9338589813326057`}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[9.330958121728596, -0.811511035101225], 
            Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62692608932472, -2.033858981332606}],
          RowBox[{"{", 
            RowBox[{"25.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.299999999999997`, {
            Complex[6.189365468138804, -0.8115110351012247], 
            Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1681077296829168`, -2.9556430610267057`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.28613688777145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4905683343590643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1681077296829168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9556430610267057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.28613688777145, -1.4905683343590643`], 
            Complex[1.1681077296829168`, -2.9556430610267057`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.168107729682917, -3.055643061026704}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1445442341816557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.490568334359063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.168107729682917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.955643061026704`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[0.1445442341816557, -1.490568334359063], 
            Complex[1.168107729682917, -2.955643061026704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.994034710406032, -1.5932025328859931`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[4.983644721854632, -0.22974907759194269`], 
            Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{2.9940347104060323`, -1.6932025328859923`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[1.8420520682648396`, -0.22974907759194238`], 
            Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.080861117956597, -1.1548158188904898`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.7916359615532285`, 0.024302619991773983`], 
            Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.080861117956597, -1.25481581889049}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[3.6500433079634345`, 0.02430261999177399], 
            Complex[5.080861117956597, -1.15481581889049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62033508283309, -0.5184150611992565}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.1658640057650915`, 0.8101779829358522], 
            Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620335082833091, -0.4184150611992563}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.307456659354887, 0.8101779829358526], 
            Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626651704878013, -2.0399635658707655`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[6.189223116150438, -0.8181794321268676], 
            Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6266517048780145`, -1.9399635658707661`}],
          RowBox[{"{", 
            RowBox[{"25.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.399999999999995`, {
            Complex[9.330815769740232, -0.818179432126868], 
            Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1665005783527111`, -2.9587934473565816`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.285198188727837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9587934473565816`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.285198188727837, -1.4938027260233295`], 
            Complex[1.1665005783527111`, -2.9587934473565816`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1665005783527118`, -3.058793447356582}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14360553513804464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1665005783527118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.958793447356582`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[0.14360553513804464`, -1.4938027260233295`], 
            Complex[1.1665005783527118`, -2.958793447356582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0046442533860986`, -1.6909830513843416`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[1.8514133874083418`, -0.22881247653229805`], 
            Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.004644253386099, -1.5909830513843417`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[4.993006040998135, -0.22881247653229808`], 
            Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.071567299655017, -1.2545236028247542`}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[3.64178970149396, 0.024734421969833987`], 
            Complex[5.071567299655017, -1.154523602824754]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.071567299655017, -1.154523602824754}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.783382355083752, 0.024734421969834053`], 
            Complex[5.071567299655017, -1.154523602824754]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620423342802423, -0.5123794904283191}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.165931179342954, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620423342802423, -0.4123794904283191}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.307523832932748, 0.8167412118766469], 
            Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626381574608514, -1.945974138422464}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[9.330677026418373, -0.824748413679325], 
            Complex[7.626381574608514, -1.945974138422464]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626381574608516, -2.045974138422464}],
          RowBox[{"{", 
            RowBox[{"25.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.499999999999996`, {
            Complex[6.18908437282858, -0.8247484136793249], 
            Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1649081881027983`, -2.9619213040456414`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.284271967799523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4970120704049878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.284271967799523, -1.4970120704049878`], 
            Complex[1.1649081881027983`, -2.9619213040456414`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1649081881027992`, -3.0619213040456414`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1426793142097304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4970120704049876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1649081881027992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[0.1426793142097304, -1.4970120704049876`], 
            Complex[1.1649081881027992`, -2.9619213040456414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0152837924104205`, -1.6887960625076501`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[1.860790544062835, -0.2279053251278246], 
            Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.015283792410421, -1.5887960625076492`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[5.0023831976526285`, -0.22790532512782422`], 
            Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.062241141302126, -1.1542205266440744`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.775106746724161, 0.02517813664084302], 
            Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.0622411413021275`, -1.2542205266440742`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[3.633514093134369, 0.025178136640842893`], 
            Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6205084178793125`, -0.5064348848292471}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.165995628815023, 0.823208187778776], 
            Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620508417879314, -0.4064348848292412}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.307588282404819, 0.8232081877787825], 
            Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626115517858926, -1.9518936417752968`}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[9.330541725135806, -0.8312210828762443], 
            Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.626115517858932, -2.051893641775296}],
          RowBox[{"{", 
            RowBox[{"25.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.599999999999998`, {
            Complex[6.188949071546019, -0.8312210828762437], 
            Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1633302844761357`, -2.965026995548729}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.283357963703603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.500196771030314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.283357963703603, -1.500196771030314], 
            Complex[1.1633302844761357`, -2.965026995548729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1633302844761368`, -3.0650269955487293`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14176531011381055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5001967710303135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1633302844761368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[0.14176531011381055`, -1.5001967710303135`], 
            Complex[1.1633302844761368`, -2.965026995548729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.025955129189635, -1.586641723319602}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[5.011777796806058, -0.2270277876307708], 
            Complex[3.025955129189635, -1.586641723319602]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0259551291896356`, -1.686641723319602}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[1.8701851432162653`, -0.22702778763077072`], 
            Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.05288081887921, -1.1539060716710015`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.766807573328626, 0.02563427240203126], 
            Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.052880818879211, -1.2539060716710013`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[3.625214919738834, 0.025634272402031196`], 
            Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620590462338552, -0.5005784447793382}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.166057496435186, 0.8295818632429409], 
            Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620590462338554, -0.40057844477933563`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.30765015002498, 0.8295818632429439], 
            Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625853365402522, -2.057724877082038}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.7, {
            Complex[6.188817056619653, -0.8376003934276774], 
            Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625853365402524, -1.9577248770820381`}],
          RowBox[{"{", 
            RowBox[{"25.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.7, {
            Complex[9.330409710209448, -0.8376003934276777], 
            Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1617666006657197`, -2.968110877073136}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2824559227648207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1617666006657197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.968110877073136`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.2824559227648207`, -1.5033572213576796`], 
            Complex[1.1617666006657197`, -2.968110877073136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.161766600665721, -3.068110877073136}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.14086326917502792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.161766600665721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9681108770731357`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[0.14086326917502792`, -1.5033572213576796`], 
            Complex[1.161766600665721, -2.9681108770731357`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.036660111236013, -1.6845202322015447`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[1.8795988236639012`, -0.22618006752276323`], 
            Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0366601112360136`, -1.5845202322015444`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[5.021191477253695, -0.2261800675227632], 
            Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.0434844640179035`, -1.1535796871411725`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.7584832381419595`, 0.02610336750958422], 
            Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.043484464017904, -1.2535796871411728`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[3.6168905845521655`, 0.0261033675095845], 
            Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620669620363362, -0.49480750301628784`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.1661169148049755`, 0.8358650512460941], 
            Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620669620363364, -0.3948075030162847}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.30770956839477, 0.8358650512460974], 
            Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625594958504517, -2.0634705130965747`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[6.188688182392475, -0.8438891593891127], 
            Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625594958504519, -1.9634705130965746`}],
          RowBox[{"{", 
            RowBox[{"25.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.799999999999997`, {
            Complex[9.33028083598227, -0.8438891593891124], 
            Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.160216877231663, -3.0711732948992334`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13997294503955765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5064938051210208`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.160216877231663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9711732948992333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[0.13997294503955765`, -1.5064938051210208`], 
            Complex[1.160216877231663, -2.9711732948992333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1602168772316634`, -2.9711732948992347`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2815655986293515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5064938051210213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1602168772316634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9711732948992347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.2815655986293515`, -1.5064938051210213`], 
            Complex[1.1602168772316634`, -2.9711732948992347`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0474006350962957`, -1.5824318310164627`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[5.030625914253164, -0.22536240942454472`], 
            Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.047400635096297, -1.682431831016463}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[1.8890332606633722`, -0.22536240942454516`], 
            Complex[3.047400635096297, -1.582431831016463]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.034050160698048, -1.2532407877189193`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[3.6085394545164045`, 0.026585992320965875`], 
            Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.034050160698049, -1.1532407877189195`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.750132108106198, 0.026585992320966013`], 
            Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620746026875822, -0.4891195161626056}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.166174007684912, 0.8420604340909559], 
            Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620746026875822, -0.38911951616260565`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.307766661274705, 0.8420604340909561], 
            Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625340148077104, -2.069133094650825}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {25.9, {
            Complex[6.188562312408357, -0.850090064112114], 
            Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625340148077106, -1.9691330946508248`}],
          RowBox[{"{", 
            RowBox[{"25.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {25.9, {
            Complex[9.330154965998151, -0.8500900641121139], 
            Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.158680861831286, -3.074214586687023}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13909409840205325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.158680861831286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[0.13909409840205325`, -1.5096068966583966`], 
            Complex[1.158680861831286, -2.974214586687023]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1586808618312865`, -2.974214586687023}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.280686751991847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1586808618312865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[3.280686751991847, -1.5096068966583966`], 
            Complex[1.1586808618312865`, -2.974214586687023]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0581786497594123`, -1.680376807519702}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[1.8984901687203608`, -0.2245751012259816], 
            Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.058178649759413, -1.5803768075197013`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[5.040082822310154, -0.22457510122598082`], 
            Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.024575941774229, -1.2528887507802409`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[3.6001598574493725`, 0.027082751742796535`], 
            Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.024575941774229, -1.152888750780241}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[6.7417525110391665`, 0.02708275174279656], 
            Complex[5.024575941774229, -1.152888750780241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620819808285306, -0.48351205693401655`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.166228890724623, 0.8481705716325338], 
            Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620819808285308, -0.38351205693401424`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.307821544314418, 0.8481705716325364], 
            Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625088793917112, -1.9747150504476334`}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26., {
            Complex[9.330031972258514, -0.856205668471937], 
            Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.625088793917112, -2.074715050447634}],
          RowBox[{"{", 
            RowBox[{"26.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26., {
            Complex[6.1884393186687205`, -0.8562056684719376], 
            Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1571583089615174`, -3.077235081769279}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13822649674521148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5126968612263973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[0.13822649674521148`, -1.5126968612263973`], 
            Complex[1.1571583089615174`, -2.9772350817692788`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1571583089615178`, -2.9772350817692788`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.279819150335005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.512696861226397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1571583089615178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.279819150335005, -1.512696861226397], 
            Complex[1.1571583089615178`, -2.9772350817692788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.068996160253663, -1.5783554980412644`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[5.049563958105735, -0.22381847645779873`], 
            Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0689961602536635`, -1.678355498041265}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[1.9079713045159428`, -0.22381847645779898`], 
            Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.0150597853162315`, -1.152522913437557}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.733342732673844, 0.027594287906544456`], 
            Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.015059785316232, -1.2525229134375577`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[3.5917500790840515`, 0.02759428790654434], 
            Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620891083164294, -0.3779828069654451}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.307874325710909, 0.8541979088518956], 
            Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620891083164294, -0.4779828069654454}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.166281672121116, 0.8541979088518953], 
            Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6248407640169, -1.9802187002360254`}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[9.329911734551446, -0.8622384184423436], 
            Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.624840764016902, -2.080218700236026}],
          RowBox[{"{", 
            RowBox[{"26.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.099999999999998`, {
            Complex[6.188319080961654, -0.8622384184423437], 
            Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1556489797129244`, -2.980235101432074}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2789625676809804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5157640553011698`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.980235101432074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.2789625676809804`, -1.5157640553011698`], 
            Complex[1.1556489797129244`, -2.980235101432074]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1556489797129252`, -3.0802351014320726`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13736991409118712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.515764055301169`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1556489797129252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9802351014320725`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[0.13736991409118712`, -1.515764055301169], 
            Complex[1.1556489797129252`, -2.9802351014320725`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0798552314489034`, -1.676368290467833}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[1.9174784699871426`, -0.22309291692935715`], 
            Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.079855231448904, -1.5763682904678322`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[5.059071123576937, -0.22309291692935682`], 
            Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.005499610747705, -1.15214256927739}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.724901013546819, 0.02812128309705345], 
            Complex[5.005499610747705, -1.15214256927739]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{5.005499610747706, -1.2521425692773902`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[3.583308359957026, 0.02812128309705336], 
            Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620959962859786, -0.4725295501957073}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.166332453213396, 0.8601447828394871], 
            Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620959962859786, -0.37252955019570744`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.30792510680319, 0.860144782839487], 
            Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.624595933940285, -2.0856462614276867`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.2, {
            Complex[6.188201486255246, -0.8681906520799051], 
            Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.624595933940287, -1.9856462614276869`}],
          RowBox[{"{", 
            RowBox[{"26.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.2, {
            Complex[9.32979413984504, -0.8681906520799052], 
            Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.15415264153475, -3.08321495918329}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13652413076420825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5188088268667397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.15415264153475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.98321495918329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[0.13652413076420825`, -1.5188088268667397`], 
            Complex[1.15415264153475, -2.98321495918329]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1541526415347505`, -2.9832149591832895`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.278116784354001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.518808826866739`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1541526415347505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9832149591832895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.278116784354001, -1.518808826866739], 
            Complex[1.1541526415347505`, -2.9832149591832895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0907579920802744`, -1.5744156275563803`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[5.068606169162741, -0.22239885565995454`], 
            Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.0907579920802752`, -1.6744156275563802`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[1.927013515572947, -0.22239885565995451`], 
            Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.995893274766249, -1.151746964778438}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.716425545723422, 0.02866446296210377], 
            Complex[4.995893274766249, -1.151746964778438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.99589327476625, -1.251746964778438}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[3.5748328921336294`, 0.02866446296210389], 
            Complex[4.99589327476625, -1.151746964778438]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6210265520474145`, -0.36715016675857504`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.307973982610356, 0.8660134292433511], 
            Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6210265520474145`, -0.46715016675857524`}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.166381329020564, 0.8660134292433507], 
            Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6243541862563, -2.090999855207028}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[6.188086428148008, -0.8740646059731705], 
            Complex[7.6243541862563, -1.990999855207028]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6243541862563, -1.990999855207028}],
          RowBox[{"{", 
            RowBox[{"26.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.299999999999997`, {
            Complex[9.329679081737801, -0.8740646059731706], 
            Complex[7.6243541862563, -1.990999855207028]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.152669068010364, -2.9861749610097594`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.277281586753582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.152669068010364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.277281586753582, -1.5218315156912805`], 
            Complex[1.152669068010364, -2.9861749610097594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1526690680103642`, -3.0861749610097595`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13568893316378858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912807`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1526690680103642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[0.13568893316378858`, -1.5218315156912807`], 
            Complex[1.1526690680103642`, -2.9861749610097594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1017066390111165`, -1.6724980106155332`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[1.9365783436386594`, -0.22173678013483558`], 
            Complex[3.1017066390111165`, -1.572498010615533]}, -1}, "Tooltip"]
         & ], 
        TagBox[
         TooltipBox[PointBox[{3.1017066390111174`, -1.5724980106155328`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[5.078170997228454, -0.22173678013483544`], 
            Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.9862385670271525`, -1.1513352953732714`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.707914469346525, 0.029224600034819193`], 
            Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.986238567027153, -1.2513352953732717`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[3.566321815756732, 0.029224600034819154`], 
            Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621090949234536, -0.36184262733357503`}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.308021042319387, 0.8718059882315835], 
            Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621090949234536, -0.4618426273335753}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.166428388729593, 0.8718059882315833], 
            Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.624115410024538, -2.096281512181469}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[6.187973806370098, -0.8798624212060279], 
            Complex[7.624115410024538, -1.996281512181469]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.624115410024538, -1.996281512181469}],
          RowBox[{"{", 
            RowBox[{"26.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.399999999999995`, {
            Complex[9.329566459959892, -0.8798624212060276], 
            Complex[7.624115410024538, -1.996281512181469]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1511980386425853`, -3.0891154056236187`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13486411354798725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[0.13486411354798725`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1511980386425853`, -2.9891154056236187`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2764567671377804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.2764567671377804`, -1.5248324535919475`], 
            Complex[1.1511980386425853`, -2.9891154056236187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.112703441753819, -1.6706160035957247`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[1.9461749120921603`, -0.22110723592124693`], 
            Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.112703441753819, -1.5706160035957248`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[5.087767565681953, -0.22110723592124715`], 
            Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.976533205571878, -1.1509067011120153`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.699365868995314, 0.02980251760487493], 
            Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.976533205571878, -1.2509067011120163`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[3.557773215405521, 0.029802517604874564`], 
            Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621153247217728, -0.45660498791489157`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.166473716138243, 0.877524510013052], 
            Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621153247217728, -0.35660498791489154`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.308066369728037, 0.8775245100130518], 
            Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623879500326575, -2.0014931776135643`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[9.32945617991971, -0.8855861488792872], 
            Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623879500326577, -2.1014931776135644`}],
          RowBox[{"{", 
            RowBox[{"26.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.499999999999996`, {
            Complex[6.187863526329917, -0.8855861488792874], 
            Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1497393386483457`, -3.0920365846984166`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13404946982617044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5278119646888442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9920365846984165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[0.13404946982617044`, -1.5278119646888442`], 
            Complex[1.1497393386483457`, -2.9920365846984165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1497393386483465`, -2.992036584698415}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2756421234159636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5278119646888435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1497393386483465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.992036584698415`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.2756421234159636`, -1.5278119646888435`], 
            Complex[1.1497393386483465`, -2.992036584698415]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.123750747268463, -1.568770237634814}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[5.097397891796026, -0.2205108306846836], 
            Complex[3.123750747268463, -1.568770237634814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.123750747268464, -1.6687702376348137`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[1.9558052382062334`, -0.22051083068468325`], 
            Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.966774831981249, -1.1504602618808102`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.6907777698397455`, 0.030399093979211252`], 
            Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.966774831981249, -1.2504602618808105`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[3.5491851162499515`, 0.030399093979211273`], 
            Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621213533499525, -0.45143538496113345`}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.166517390057898, 0.8831709599557609], 
            Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621213533499528, -0.3514353849611332}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.308110043647693, 0.8831709599557607], 
            Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623646357838642, -2.006636716272229}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[9.329348152291017, -0.8912377552298729], 
            Complex[7.623646357838642, -2.006636716272229]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623646357838647, -2.106636716272231}],
          RowBox[{"{", 
            RowBox[{"26.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.599999999999998`, {
            Complex[6.187755498701229, -0.8912377552298747], 
            Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1482927587622171`, -3.0949387830955004`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1332448053607902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.530770365648672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830955003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[0.1332448053607902, -1.530770365648672], 
            Complex[1.1482927587622171`, -2.9949387830955003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1482927587622176`, -2.9949387830954994`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274837458950583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5307703656486717`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1482927587622176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830954994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.274837458950583, -1.5307703656486717`], 
            Complex[1.1482927587622176`, -2.9949387830954994`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1348509850602824`, -1.6669614161122601`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[1.965471402661748, -0.21994823865092936`], 
            Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1348509850602837`, -1.5669614161122616`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[5.107064056251541, -0.21994823865093072`], 
            Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.956961006232221, -1.249994992121425}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[3.540555479985998, 0.031015267178413904`], 
            Complex[4.956961006232221, -1.149994992121425]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.956961006232221, -1.149994992121425}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.682148133575791, 0.03101526717841391], 
            Complex[4.956961006232221, -1.149994992121425]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621271890668613, -0.44633203089259044`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.166559484680516, 0.8887472233381511], 
            Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621271890668614, -0.34633203089259035`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.30815213827031, 0.888747223338151], 
            Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623415888441284, -2.1117139169364294`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[6.187649639046593, -0.8968191263829133], 
            Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623415888441285, -2.0117139169364284`}],
          RowBox[{"{", 
            RowBox[{"26.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.699999999999996`, {
            Complex[9.329242292636387, -0.8968191263829126], 
            Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1468580950483382`, -2.997822279081166}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.274042582367506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5337079659185715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.274042582367506, -1.5337079659185715`], 
            Complex[1.1468580950483382`, -2.997822279081166]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1468580950483385`, -3.097822279081167}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13244992877771303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.533707965918572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1468580950483385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[0.13244992877771303`, -1.533707965918572], 
            Complex[1.1468580950483385`, -2.997822279081167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.146006672598035, -1.565190320272424}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[5.116768207416752, -0.21942020556585193`], 
            Complex[3.146006672598035, -1.565190320272424]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1460066725980353`, -1.6651903202724228`}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[1.9751755538269593`, -0.21942020556585135`], 
            Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.947089201235956, -1.249509834990993}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[3.531882200536309, 0.031652040121196476`], 
            Complex[4.947089201235956, -1.149509834990993]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.947089201235956, -1.149509834990993}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.673474854126102, 0.031652040121196295`], 
            Complex[4.947089201235956, -1.149509834990993]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6213283967471925`, -0.3412932099060126}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.308192723503184, 0.8942551097650254], 
            Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621328396747193, -0.4412932099060136}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.166600069913391, 0.8942551097650246], 
            Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623188002862294, -2.116726496581311}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[6.187545867473453, -0.9023320727684235], 
            Complex[7.623188002862294, -2.016726496581311]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623188002862294, -2.016726496581311}],
          RowBox[{"{", 
            RowBox[{"26.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.799999999999997`, {
            Complex[9.329138521063246, -0.9023320727684233], 
            Complex[7.623188002862294, -2.016726496581311]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1454351487203238`, -3.100687344535021}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13166465378465506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.000687344535021`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[0.13166465378465506`, -1.5366250679506237`], 
            Complex[1.1454351487203238`, -3.000687344535021]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1454351487203243`, -3.0006873445350215`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.273257307374448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1454351487203243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0006873445350215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.273257307374448, -1.5366250679506237`], 
            Complex[1.1454351487203243`, -3.0006873445350215`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1572204210764307`, -1.5634578154860739`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[5.126512565878383, -0.21892755421211518`], 
            Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.157220421076432, -1.6634578154860742`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[1.984919912288591, -0.2189275542121152], 
            Complex[3.157220421076432, -1.563457815486074]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.937156797033987, -1.1490036558923018`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.664755753090322, 0.03231048635665902], 
            Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.937156797033987, -1.2490036558923023`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[3.5231630995005294`, 0.03231048635665899], 
            Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621383125508848, -0.43631727407995946`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.166639211685018, 0.8996963572765853], 
            Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621383125508848, -0.33631727407995976`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.30823186527481, 0.8996963572765849], 
            Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622962616349544, -2.0216761042737272`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {26.9, {
            Complex[9.329036761909217, -0.9077783332310709], 
            Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622962616349545, -2.1216761042737278`}],
          RowBox[{"{", 
            RowBox[{"26.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {26.9, {
            Complex[6.187444108319425, -0.9077783332310714], 
            Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1440237259687367`, -3.003534245149988}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.272481452587111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174738`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1440237259687367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.003534245149988`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[3.272481452587111, -1.5395219674174738`], 
            Complex[1.1440237259687367`, -3.003534245149988]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.144023725968737, -3.1035342451499868`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13088879899731687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.144023725968737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0035342451499867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[0.13088879899731687`, -1.5395219674174727`], 
            Complex[1.144023725968737, -3.0035342451499867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1684949415466477`, -1.561764858229167}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[5.1362994292403545`, -0.21847119055042014`], 
            Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.168494941546649, -1.661764858229167}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[1.9947067756505623`, -0.21847119055042036`], 
            Complex[3.168494941546649, -1.561764858229167]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.927161074628285, -1.2484752352951793`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[3.5143959213393177`, 0.03299175641234993], 
            Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.927161074628285, -1.1484752352951793`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[6.655988574929111, 0.03299175641235], 
            Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621436146769792, -0.43140263974642123`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.166676972224923, 0.9050726361762731], 
            Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621436146769792, -0.33140263974642126`}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.308269625814717, 0.9050726361762732], 
            Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6227396483708265`, -2.126564324801445}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27., {
            Complex[6.187344289864064, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6227396483708265`, -2.026564324801445}],
          RowBox[{"{", 
            RowBox[{"27.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27., {
            Complex[9.328936943453858, -0.9131595788587061], 
            Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1426236377957477`, -3.1063632406243786`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.13012218777282775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5423989534195135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[0.13012218777282775`, -1.5423989534195135`], 
            Complex[1.1426236377957477`, -3.0063632406243785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1426236377957488`, -3.0063632406243794`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.271714841362621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.542398953419513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1426236377957488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.271714841362621, -1.542398953419513], 
            Complex[1.1426236377957488`, -3.0063632406243794`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.179833051439644, -1.6601125038693654`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[2.004538523616137, -0.21805211056251306`], 
            Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.179833051439644, -1.5601125038693657`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[5.1461311772059295`, -0.21805211056251345`], 
            Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.917099209420432, -1.1479232607580627`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.647170981866, 0.03369708483581625], 
            Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.917099209420432, -1.2479232607580628`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[3.505578328276208, 0.03369708483581626], 
            Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6214875266561215`, -0.42654778410681526`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.166713410320053, 0.9103855526005633], 
            Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621487526656122, -0.3265477841068158}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.308306063909846, 0.9103855526005625], 
            Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622519022338055, -2.1313926820579585`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.1, {
            Complex[6.1872463440644, -0.9184774165528232], 
            Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622519022338057, -2.0313926820579584`}],
          RowBox[{"{", 
            RowBox[{"27.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.1, {
            Complex[9.328838997654197, -0.9184774165528234], 
            Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1412346998566436`, -3.109174584846388}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12936464805013348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545256308683994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[0.12936464805013348`, -1.545256308683994], 
            Complex[1.1412346998566436`, -3.009174584846388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1412346998566438`, -3.009174584846389}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2709573016399287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5452563086839952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1412346998566438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846389`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.2709573016399287`, -1.5452563086839952`], 
            Complex[1.1412346998566438`, -3.009174584846389]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.1912376815073618`, -1.5585019153641586`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[5.156010276958656, -0.21767140788446362`], 
            Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.191237681507362, -1.6585019153641587`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[2.014417623368864, -0.21767140788446343`], 
            Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.906968264234699, -1.147346318045541}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.6383005484916495`, 0.03442779801852971], 
            Complex[4.906968264234699, -1.147346318045541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.9069682642347, -1.247346318045541}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[3.4967078949018573`, 0.03442779801852968], 
            Complex[4.9069682642347, -1.147346318045541]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621537327849359, -0.321751242072515}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.308341235139771, 0.9156366518516708], 
            Complex[7.621537327849359, -0.321751242072515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621537327849361, -0.42175124207251535`}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.166748581549979, 0.9156366518516704], 
            Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62230066535352, -2.136162642202724}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.2, {
            Complex[6.187150206311988, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62230066535352, -2.036162642202724}],
          RowBox[{"{", 
            RowBox[{"27.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.2, {
            Complex[9.328742859901782, -0.923733392361904], 
            Complex[7.62230066535352, -2.036162642202724]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1398567323078, -3.0119685260713935`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270208665786776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.548094309756492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0119685260713935`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.270208665786776, -1.548094309756492], 
            Complex[1.1398567323078, -3.0119685260713935`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1398567323078006`, -3.1119685260713927`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12861601219698304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5480943097564914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1398567323078006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0119685260713926`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[0.12861601219698304`, -1.5480943097564914`], 
            Complex[1.1398567323078006`, -3.0119685260713926`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2027118832068138`, -1.656934372989885}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[2.0243466352667068`, -0.21733028233169743`], 
            Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2027118832068138`, -1.5569343729898855`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[5.1659392888564994`, -0.2173302823316979], 
            Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.896765181899932, -1.2467428812221832`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[3.4877821024662152`, 0.035185322904060734`], 
            Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.896765181899933, -1.1467428812221825`}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.629374756056008, 0.03518532290406068], 
            Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621585609812358, -0.4170116033119914}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.166782538502952, 0.9208274215121246], 
            Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62158560981236, -0.3170116033119914}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.308375192092747, 0.9208274215121248], 
            Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622084507976147, -2.040875616614767}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[9.328648468799225, -0.9289289945966074], 
            Complex[7.622084507976147, -2.040875616614767]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622084507976148, -2.140875616614767}],
          RowBox[{"{", 
            RowBox[{"27.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.299999999999997`, {
            Complex[6.1870558152094315`, -0.9289289945966069], 
            Complex[7.622084507976148, -2.040875616614767]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1384895596608695`, -3.1147453070923867`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12787611686319877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5509132271850385`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0147453070923866`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[0.12787611686319877`, -1.5509132271850385`], 
            Complex[1.1384895596608695`, -3.0147453070923866`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1384895596608702`, -3.014745307092387}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2694687704529923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5509132271850388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1384895596608702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.014745307092387`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.2694687704529923`, -1.5509132271850388`], 
            Complex[1.1384895596608702`, -3.014745307092387]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.214258836551336, -1.555411285239044}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[5.175920872451979, -0.21703004943242454`], 
            Complex[3.214258836551336, -1.555411285239044]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2142588365513363`, -1.6554112852390448`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[2.034328218862186, -0.2170300494324249], 
            Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.886486777365878, -1.2461113015849472`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[3.478798332845711, 0.03597119669747849], 
            Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.886486777365879, -1.146111301584947}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.620390986435504, 0.03597119669747851], 
            Complex[4.886486777365879, -1.146111301584947]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621632428997374, -0.31232750948827986`}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.30840798456442, 0.9259592943584085], 
            Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621632428997374, -0.41232750948828}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.166815330974628, 0.9259592943584081], 
            Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621870484005858, -2.145532964655917}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.4, {
            Complex[6.186963112364547, -0.9340656567439883], 
            Complex[7.621870484005858, -2.045532964655917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62187048400586, -2.045532964655917}],
          RowBox[{"{", 
            RowBox[{"27.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.4, {
            Complex[9.32855576595434, -0.9340656567439881], 
            Complex[7.62187048400586, -2.045532964655917]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1371330106428, -3.117505165403874}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12714480283990298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973077`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.017505165403874`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[0.12714480283990298`, -1.5537133256973077`], 
            Complex[1.1371330106428, -3.017505165403874]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1371330106428055`, -3.0175051654038723`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268737456429699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973044`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1371330106428055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0175051654038723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.268737456429699, -1.5537133256973044`], 
            Complex[1.1371330106428055`, -3.0175051654038723`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.225881858451649, -1.553934201044293}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[5.185957792848567, -0.21677215110365716`], 
            Complex[3.225881858451649, -1.553934201044293]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.225881858451649, -1.6539342010442935`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[2.0443651392587743`, -0.2167721511036576], 
            Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.8761297293312476`, -1.1454497952754268`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.611346515764966, 0.03678707771053715], 
            Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.876129729331248, -1.2454497952754267`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[3.469753862175173, 0.036787077710537186`], 
            Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621658530284444, -2.050135996258459}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.328464695790345, -0.9391447601963729], 
            Complex[7.621658530284444, -2.050135996258459]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621658530284452, -2.150135996258457}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.186872042200558, -0.9391447601963707], 
            Complex[7.621658530284452, -2.050135996258457]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621677839037961, -0.3076976516720168}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[9.308439659740836, 0.931033651089264], 
            Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621677839037962, -0.40769765167201744`}],
          RowBox[{"{", 
            RowBox[{"27.499999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.499999999999993`, {
            Complex[6.166847006151044, 0.9310336510892632], 
            Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1357869180615123`, -3.120248333359523}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12642191492445268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5564948643711098`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0202483333595227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[0.12642191492445268`, -1.5564948643711098`], 
            Complex[1.1357869180615123`, -3.0202483333595227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1357869180615132`, -3.020248333359523}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.268014568514247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.55649486437111`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1357869180615132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.020248333359523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.268014568514247, -1.55649486437111], 
            Complex[1.1357869180615132`, -3.020248333359523]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2375844115665666`, -1.6525048235121884`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[2.054460273810074, -0.2165581676245985], 
            Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.237584411566567, -1.552504823512188}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[5.196052927399868, -0.21655816762459845`], 
            Complex[3.237584411566567, -1.552504823512188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.8656905713635386`, -1.2447564293886006`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[3.460645854137856, 0.03763475749771081], 
            Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.86569057136354, -1.1447564293886006`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.60223850772765, 0.037634757497710766`], 
            Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621448586511419, -2.1546859743506386`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.186782551780801, -0.9441676368090823], 
            Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621448586511421, -2.0546859743506434`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.328375205370595, -0.9441676368090878], 
            Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621721890926154, -0.40312076791659357`}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[6.166877608777316, 0.9360518228828759], 
            Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621721890926156, -0.3031207679165936}],
          RowBox[{"{", 
            RowBox[{"27.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.599999999999994`, {
            Complex[9.30847026236711, 0.9360518228828761], 
            Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1344511186768103`, -3.0229750383238807`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.267299955380531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0229750383238807`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.267299955380531, -1.559258096798595], 
            Complex[1.1344511186768103`, -3.0229750383238807`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1344511186768111`, -3.12297503832388}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12570730179073827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1344511186768111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.02297503832388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[0.12570730179073827`, -1.559258096798594], 
            Complex[1.1344511186768111`, -3.02297503832388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2493701136786943`, -1.5511250253784865`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[5.206209272752708, -0.2163898310860751], 
            Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2493701136786943`, -1.6511250253784848`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[2.0646166191629156`, -0.21638983108607387`], 
            Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.855165682495277, -1.244029106365958}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[3.4514713529124292`, 0.03851617446207811], 
            Complex[4.855165682495277, -1.144029106365958]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.855165682495278, -1.1440291063659584`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.593064006502223, 0.038516174462077585`], 
            Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621240595073557, -2.0591841171322502`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.32828724423658, -0.9491355712999281], 
            Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621240595073559, -2.1591841171322437`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.186694590646789, -0.9491355712999217], 
            Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62176463317627, -0.29859564098319413`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[9.308499834903161, 0.9410150937958542], 
            Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62176463317627, -0.39859564098319433`}],
          RowBox[{"{", 
            RowBox[{"27.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.699999999999996`, {
            Complex[6.166907181313368, 0.9410150937958539], 
            Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1331254530764636`, -3.0256855028184027`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2665934694544774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5620032712443408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.2665934694544774`, -1.5620032712443408`], 
            Complex[1.1331254530764636`, -3.0256855028184027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1331254530764638`, -3.125685502818402}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12500081586468456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5620032712443406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1331254530764638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[0.12500081586468456`, -1.5620032712443406`], 
            Complex[1.1331254530764638`, -3.0256855028184018`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.261242747603761, -1.6497968664306097`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[2.0748372986380015`, -0.2162690405227275], 
            Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2612427476037635`, -1.5497968664306097`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[5.216429952227797, -0.21626904052272788`], 
            Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.844551277287891, -1.2432655464271398`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[3.442227275783197, 0.03943342913804209], 
            Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.844551277287892, -1.1432655464271397`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.58381992937299, 0.03943342913804175], 
            Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6210345008869025`, -2.1636316002114744`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.186608110668219, -0.9540498035022783], 
            Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621034500886904, -2.063631600211478}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.328200764258014, -0.9540498035022821], 
            Complex[7.621034500886904, -2.063631600211478]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621806111976445, -0.3941210962045668}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[6.166935764077781, 0.9459247030157971], 
            Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621806111976447, -0.29412109620456683`}],
          RowBox[{"{", 
            RowBox[{"27.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.799999999999997`, {
            Complex[9.308528417667576, 0.9459247030157971], 
            Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1318097655570643`, -3.028379944662053}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.265894966794422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976763`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1318097655570643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.265894966794422, -1.5647306307976763`], 
            Complex[1.1318097655570643`, -3.028379944662053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.131809765557065, -3.1283799446620533`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12430231320462909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.131809765557065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[0.12430231320462909`, -1.5647306307976756`], 
            Complex[1.131809765557065, -3.028379944662053]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2732062716325756`, -1.6485226131825368`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[2.0851255699314044`, -0.21619787896744103`], 
            Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.273206271632577, -1.5485226131825387`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[5.226718223521198, -0.2161978789674424], 
            Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.833843395364207, -1.242463267754563}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[3.4329104054302233`, 0.04038880139063529], 
            Complex[4.833843395364207, -1.142463267754563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.833843395364207, -1.1424632677545632`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.574503059020016, 0.040388801390635574`], 
            Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620830251250191, -2.1680295586131555`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.186523065904121, -0.9589115304824511], 
            Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620830251250195, -2.0680295586131603`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.328115719493917, -0.9589115304824558], 
            Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6218463713290605`, -0.28969599947733177`}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {27.9, {
            Complex[9.308556048970686, 0.9507818469782096], 
            Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621846371329061, -0.3896959994773318}],
          RowBox[{"{", 
            RowBox[{"27.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.9, {
            Complex[6.166963395380894, 0.9507818469782096], 
            Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1305039040095175`, -3.0310585771067586`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2652043069761856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067586`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.2652043069761856`, -1.5674404135194786`], 
            Complex[1.1305039040095175`, -3.0310585771067586`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1305039040095248`, -3.1310585771067525`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1236116533863979`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1305039040095248`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[0.1236116533863979, -1.5674404135194724`], 
            Complex[1.1305039040095248`, -3.0310585771067524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2852648304909686`, -1.5473047611339115`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[5.237077486695947, -0.21617863270584659`], 
            Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.2852648304909695`, -1.6473047611339122`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[2.0954848331061537`, -0.21617863270584692`], 
            Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.823037890424123, -1.1416195640990143`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.565110035519868, 0.04138476980950452], 
            Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.823037890424123, -1.241619564099015}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[3.423517381930075, 0.04138476980950441], 
            Complex[4.823037890424123, -1.141619564099015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6206277957087085`, -2.0723790886678484`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.328032066063827, -0.9637219085312987], 
            Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620627795708716, -2.172379088667851}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.186439412474038, -0.9637219085313011], 
            Complex[7.620627795708716, -2.072379088667851]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621885453180955, -0.38531925537351297`}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[6.166990111648028, 0.9555876813576081], 
            Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621885453180955, -0.2853192553735133}],
          RowBox[{"{", 
            RowBox[{"27.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {27.999999999999996`, {
            Complex[9.308582765237823, 0.9555876813576076], 
            Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1292077198089117`, -3.03372160896789}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2645213529825936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.03372160896789`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.2645213529825936`, -1.5701328525836726`], 
            Complex[1.1292077198089117`, -3.03372160896789]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1292077198089157`, -3.1337216089678943`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12292869939280154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1292077198089157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0337216089678942`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[0.12292869939280154`, -1.5701328525836726`], 
            Complex[1.1292077198089157`, -3.0337216089678942`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.297422766784157, -1.5461460599999748`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[5.247511292414014, -0.21621381305374007`], 
            Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.297422766784158, -1.6461460599999758`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[2.1059186388242215`, -0.21621381305374038`], 
            Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.812130418776984, -1.240731479419345}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[3.4140446945168277`, 0.042424033620649226`], 
            Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.812130418776984, -1.1407314794193455`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.555637348106621, 0.04242403362064838], 
            Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620427085927699, -2.1766812497901036`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.1863571084384, -0.9684820550389218], 
            Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620427085927699, -2.0766812497901053`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.327949762028192, -0.9684820550389235], 
            Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621923397544282, -0.38098980536276317`}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[6.167015947533717, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621923397544282, -0.2809898053627634}],
          RowBox[{"{", 
            RowBox[{"28.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.099999999999998`, {
            Complex[9.30860860112351, 0.960343322941825], 
            Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1279210677086149`, -3.1363692447500138`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12225331750747458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5728081764136674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0363692447500137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[0.12225331750747458`, -1.5728081764136674`], 
            Complex[1.1279210677086149`, -3.0363692447500137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1279210677086156`, -3.036369244750015}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2638459710972687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5728081764136679`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1279210677086156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.036369244750015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.2638459710972687`, -1.5728081764136679`], 
            Complex[1.1279210677086156`, -3.036369244750015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3096846328660456`, -1.645049542363364}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[2.116430696743796, -0.21630618103294583`], 
            Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3096846328660456`, -1.5450495423633641`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[5.258023350333589, -0.21630618103294588`], 
            Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.801116427450052, -1.2397957791050334`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[3.4044886731783923`, 0.043509537491681564`], 
            Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.801116427450052, -1.1397957791050335`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.546081326768186, 0.04350953749168187], 
            Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620228075574519, -2.1809370661539056`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.186276113687406, -0.9731930502608692], 
            Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620228075574522, -2.0809370661539037`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.327868767277202, -0.9731930502608676], 
            Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6219602426088535`, -0.276706626137473}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.2, {
            Complex[9.308633589617479, 0.9650498513977598], 
            Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.621960242608855, -0.37670662613747297`}],
          RowBox[{"{", 
            RowBox[{"28.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.2, {
            Complex[6.1670409360276865`, 0.9650498513977598], 
            Complex[7.621960242608855, -0.276706626137473]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.126643805738343, -3.03900168476816}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2631780308024685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.575466608813974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.126643805738343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.03900168476816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.2631780308024685`, -1.575466608813974], 
            Complex[1.126643805738343, -3.03900168476816]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1266438057383434`, -3.139001684768161}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12158537721267502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754666088139742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1266438057383434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.039001684768161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[0.12158537721267502`, -1.5754666088139742`], 
            Complex[1.1266438057383434`, -3.039001684768161]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3220552030387194`, -1.644018556274634}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[2.127024883972908, -0.21645877538292152`], 
            Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.32205520303872, -1.5440185562746336`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[5.268617537562701, -0.21645877538292138`], 
            Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.78999114196779, -1.1388089172545461`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.536438133786874, 0.04464449966811444], 
            Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.78999114196779, -1.2388089172545464`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[3.3948454801970804`, 0.044644499668114825`], 
            Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620030720208938, -2.08514752827235}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.327789043427426, -0.9778559389833152], 
            Complex[7.620030720208938, -2.08514752827235]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.620030720208938, -2.185147528272351}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.186196389837632, -0.977855938983316], 
            Complex[7.620030720208938, -2.085147528272351]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6219960248466, -0.27246872803358446`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.3, {
            Complex[9.30865776214308, 0.9697083109361536], 
            Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6219960248466, -0.37246872803358466`}],
          RowBox[{"{", 
            RowBox[{"28.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.3, {
            Complex[6.167065108553286, 0.9697083109361534], 
            Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1253757951060699`, -3.14161912526473}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12092475109102498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5781083690971813`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.04161912526473`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[0.12092475109102498`, -1.5781083690971813`], 
            Complex[1.1253757951060699`, -3.04161912526473]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1253757951060703`, -3.041619125264729}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2625174046808185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5781083690971809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1253757951060703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.041619125264729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.2625174046808185`, -1.5781083690971809`], 
            Complex[1.1253757951060703`, -3.041619125264729]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.334539485939789, -1.5430568024175473`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[5.279297907015237, -0.2166749444176823], 
            Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3345394859397897`, -1.6430568024175474`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[2.137705253425444, -0.21667494441768215`], 
            Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.778749553944275, -1.1377669993932322`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.526703755378124, 0.045832443950467455`], 
            Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.778749553944276, -1.2377669993932332`}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[3.3851111017883304`, 0.045832443950466685`], 
            Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619834977180716, -2.189313594488205}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.186117900135718, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619834977180716, -2.089313594488205}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.327710553725511, -0.9824717320942182], 
            Complex[7.619834977180716, -2.089313594488205]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622030779108827, -0.3682751535405323}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[6.1670884950589855`, 0.974319711882344], 
            Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622030779108829, -0.2682751535405323}],
          RowBox[{"{", 
            RowBox[{"28.399999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.399999999999995`, {
            Complex[9.30868114864878, 0.974319711882344], 
            Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1241169001035878`, -3.0442217585222795`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2618639683207284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5807336722064977`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1241169001035878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0442217585222795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.2618639683207284`, -1.5807336722064977`], 
            Complex[1.1241169001035878`, -3.0442217585222795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.124116900103588, -3.1442217585222787`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.12027131473093523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.580733672206497`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.124116900103588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0442217585222786`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[0.12027131473093523`, -1.580733672206497], 
            Complex[1.124116900103588, -3.0442217585222786`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.34714273691111, -1.5421683765599403`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[5.29006869545568, -0.21695838232209166`], 
            Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.347142736911111, -1.6421683765599402`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[2.1484760418658873`, -0.21695838232209172`], 
            Complex[3.347142736911111, -1.54216837655994]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.767386408695089, -1.2366657399097989`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[3.3752813400511936`, 0.04707723610641603], 
            Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.767386408695089, -1.136665739909799}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.516873993640987, 0.047077236106415926`], 
            Complex[4.767386408695089, -1.136665739909799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619640805534103, -2.1934361923813577`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.186040609368656, -0.9870414080668142], 
            Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619640805534105, -2.093436192381357}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.32763326295845, -0.9870414080668136], 
            Complex[7.619640805534105, -2.093436192381357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6220645387168675`, -0.36412497589424186`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[6.167111124103515, 0.9788850321593934], 
            Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622064538716871, -0.26412497589424166`}],
          RowBox[{"{", 
            RowBox[{"28.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.499999999999996`, {
            Complex[9.308703777693312, 0.9788850321593942], 
            Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1228669880155542`, -3.1468097729723588`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11962494663556839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[0.11962494663556839`, -1.5833427288340611`], 
            Complex[1.1228669880155542`, -3.0468097729723587`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1228669880155548`, -3.0468097729723587`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2612176002253626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1228669880155548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.2612176002253626`, -1.5833427288340611`], 
            Complex[1.1228669880155548`, -3.0468097729723587`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.359870470056671, -1.6413578181336939`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[2.15934167735015, -0.21731317057992383`], 
            Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3598704700566717`, -1.5413578181336938`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[5.300934330939945, -0.21731317057992383`], 
            Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.755896193160949, -1.235500413367616}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[3.365351805523236, 0.04838312541060397], 
            Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.75589619316095, -1.1355004133676139`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.50694445911303, 0.04838312541060556], 
            Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619448165918566, -2.197516220098791}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.18596448378006, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619448165918566, -2.097516220098791}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.327557137369855, -0.991565914361383], 
            Complex[7.619448165918566, -2.097516220098791]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6220973355465995`, -0.26001729774761967`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[9.308725676524938, 0.9834052186894814], 
            Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6220973355465995`, -0.36001729774762004`}],
          RowBox[{"{", 
            RowBox[{"28.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.599999999999998`, {
            Complex[6.167133022935145, 0.9834052186894809], 
            Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1216259290318777`, -3.1493833533005415`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11898552813518211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0493833533005414`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[0.11898552813518211`, -1.5859357455351755`], 
            Complex[1.1216259290318777`, -3.0493833533005414`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1216259290318786`, -3.049383353300541}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.260578181724976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1216259290318786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.049383353300541`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.260578181724976, -1.5859357455351744`], 
            Complex[1.1216259290318786`, -3.049383353300541]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3727284695824946`, -1.640630165930743}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[2.170306785665302, -0.21774382534019746`], 
            Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3727284695824955`, -1.5406301659307426`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[5.311899439255096, -0.21774382534019754`], 
            Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.744273124550122, -1.2342657987037833`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[3.3553179107369844`, 0.049754792118764775`], 
            Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.744273124550122, -1.1342657987037834`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.496910564326778, 0.04975479211876483], 
            Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619257020505317, -2.10155454761218}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.327482144581792, -0.9960461687506829], 
            Complex[7.619257020505317, -2.10155454761218]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.619257020505318, -2.2015545476121803`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1858894909919995`, -0.9960461687506831], 
            Complex[7.619257020505318, -2.10155454761218]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622129200107364, -0.2559512499133873}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[9.308746871155384, 0.9878811887189863], 
            Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6221292001073655`, -0.35595124991338734`}],
          RowBox[{"{", 
            RowBox[{"28.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.699999999999996`, {
            Complex[6.1671542175655905`, 0.9878811887189864], 
            Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1203935961632907`, -3.151942680547835}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11835294330270157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5885129248386511`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632907`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[0.11835294330270157`, -1.5885129248386511`], 
            Complex[1.1203935961632907`, -3.051942680547835]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1203935961632925`, -3.051942680547835}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.259945596892496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58851292483865`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1203935961632925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.259945596892496, -1.58851292483865], 
            Complex[1.1203935961632925`, -3.051942680547835]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.3857227998582564`, -1.639991022068634}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[2.181376195232895, -0.2182553516597405], 
            Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.385722799858257, -1.5399910220686344`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[5.322968848822688, -0.21825535165974055`], 
            Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.732511140259881, -1.1329561151622733`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.486767518902965, 0.0511974018142995], 
            Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.7325111402598825`, -1.2329561151622777`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[3.345174865313174, 0.0511974018142957], 
            Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6190673329092, -2.105552017907876}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.32740825352173, -1.000483060574067], 
            Complex[7.6190673329092, -2.105552017907876]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{7.619067332909202, -2.205552017907877}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.185815599931938, -1.000483060574068], 
            Complex[7.619067332909202, -2.105552017907877]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622160161615688, -0.25192599017451744`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[9.308767386428746, 0.9923138310722672], 
            Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622160161615688, -0.35192599017451764`}],
          RowBox[{"{", 
            RowBox[{"28.799999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.799999999999994`, {
            Complex[6.167174732838952, 0.992313831072267], 
            Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1191698651599729`, -3.1544879322086086`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11772707887238294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5910744653534168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1191698651599729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0544879322086085`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[0.11772707887238294`, -1.5910744653534168`], 
            Complex[1.1191698651599729`, -3.0544879322086085`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.119169865159973, -3.054487932208608}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2593197324621768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5910744653534166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.119169865159973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.054487932208608`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.2593197324621768`, -1.5910744653534166`], 
            Complex[1.119169865159973, -3.054487932208608]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.398859813435927, -1.5394466255711594`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[5.334147593347899, -0.21885330570991693`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.398859813435927, -1.6394466255711595`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[2.1925549397581063`, -0.21885330570991673`], 
            Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.720603889841738, -1.1315649486154922`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.476510326898408, 0.05271666771536847], 
            Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.720603889841739, -1.2315649486154923`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[3.3349176733086154`, 0.052716667715368405`], 
            Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618879068115525, -2.2095094481136446`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.185742780764412, -1.004877451924907], 
            Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618879068115525, -2.109509448113651}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.327335434354206, -1.0048774519249142`], 
            Complex[7.618879068115525, -2.109509448113651]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622190248064221, -0.3479407021579015}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[6.167194592496085, 0.9967040073387544], 
            Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622190248064221, -0.24794070215790154`}],
          RowBox[{"{", 
            RowBox[{"28.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.899999999999995`, {
            Complex[9.30878724608588, 0.9967040073387546], 
            Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1179546144330925`, -3.157019282325191}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11710782416143134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.593620561871549`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0570192823251907`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[0.11710782416143134`, -1.593620561871549], 
            Complex[1.1179546144330925`, -3.0570192823251907`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1179546144330978`, -3.057019282325188}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258700477751228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5936205618715453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1179546144330978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.057019282325188`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.258700477751228, -1.5936205618715453`], 
            Complex[1.1179546144330978`, -3.057019282325188]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4121461559885464`, -1.5390039371286068`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[5.34544091125561, -0.21954386620430968`], 
            Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4121461559885473`, -1.6390039371286067`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[2.2038482576658165`, -0.2195438662043097], 
            Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.70854473004717, -1.230085166709498}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[3.3245411337774544`, 0.05431892219952697], 
            Complex[4.70854473004717, -1.130085166709498]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.70854473004717, -1.130085166709498}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.466133787367247, 0.05431892219952709], 
            Complex[4.70854473004717, -1.130085166709498]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618692192411457, -2.213427630566214}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.185671004827051, -1.0092301787755908`], 
            Complex[7.618692192411457, -2.113427630566214]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618692192411457, -2.113427630566214}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.327263658416845, -1.009230178775591], 
            Complex[7.618692192411457, -2.113427630566214]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622219486286243, -0.34399459426719103`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[6.167213819234735, 1.0010525529976395`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622219486286243, -0.24399459426719103`}],
          RowBox[{"{", 
            RowBox[{"28.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {28.999999999999996`, {
            Complex[9.308806472824529, 1.0010525529976397`], 
            Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1167477249791702`, -3.1595369015792554`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1164950709944641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.596151405467845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[0.1164950709944641, -1.596151405467845], 
            Complex[1.1167477249791702`, -3.0595369015792553`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1167477249791709`, -3.0595369015792553`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.258087724584257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5961514054678452`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1167477249791709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.258087724584257, -1.5961514054678452`], 
            Complex[1.1167477249791709`, -3.0595369015792553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4255887667699536`, -1.638670736847748}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[2.2152615870464745`, -0.2203339164903331], 
            Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.425588766769954, -1.5386707368477481`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[5.356854240636268, -0.2203339164903332], 
            Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.696326724353138, -1.2285088210227602`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[3.314039845823023, 0.05601119898888117], 
            Complex[4.696326724353138, -1.12850882102276]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.696326724353139, -1.1285088210227605`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.4556324994128165`, 0.05601119898888104], 
            Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618506673321678, -2.1173073338233785`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.327192898160455, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618506673321678, -2.2173073338233786`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.18560024457066, -1.013542052044059], 
            Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622247902016085, -0.24008689867107663`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[9.308825088355581, 1.0053602784840994`], 
            Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622247902016086, -0.34008689867107705`}],
          RowBox[{"{", 
            RowBox[{"29.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.099999999999998`, {
            Complex[6.16723243476579, 1.005360278484099], 
            Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.115549080307041, -3.1620409573801793`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11588871363063293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961561`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0620409573801792`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[0.11588871363063293`, -1.5986671835961561`], 
            Complex[1.115549080307041, -3.0620409573801792`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.115549080307043, -3.062040957380181}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.257481367220427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.115549080307043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.062040957380181`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.257481367220427, -1.5986671835961581`], 
            Complex[1.115549080307043, -3.062040957380181]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4391948727143977`, -1.6384557370705048`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[2.2268005544144556`, -0.22123113894674887`], 
            Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4391948727143986`, -1.538455737070505}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[5.36839320800425, -0.2212311389467491], 
            Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.68394264884831, -1.1268270341592392`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.445000873427293, 0.05780132763801389], 
            Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.683942648848311, -1.2268270341592393`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[3.3034082198375003`, 0.05780132763801396], 
            Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618322479547935, -2.221149303624121}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.185530473503019, -1.017813858605525], 
            Complex[7.618322479547935, -2.121149303624121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618322479547946, -2.12114930362412}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.327123127092824, -1.0178138586055234`], 
            Complex[7.618322479547946, -2.12114930362412]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622275519945756, -0.236216870343528}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.2, {
            Complex[9.308843113455703, 1.0096279702007276`], 
            Complex[7.622275519945756, -0.236216870343528]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622275519945756, -0.33621687034352865`}],
          RowBox[{"{", 
            RowBox[{"29.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.2, {
            Complex[6.16725045986591, 1.0096279702007271`], 
            Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1143585663674842`, -3.064531613950414}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.256881302283198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60116808018249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1143585663674842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.064531613950414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.256881302283198, -1.60116808018249], 
            Complex[1.1143585663674842`, -3.064531613950414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.114358566367485, -3.164531613950414}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11528864869340531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6011680801824892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.114358566367485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0645316139504137`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[0.11528864869340531`, -1.6011680801824892`], 
            Complex[1.114358566367485, -3.0645316139504137`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.452971973654926, -1.5383687126232324`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[5.380063608617472, -0.22224412353114406`], 
            Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.452971973654928, -1.6383687126232318`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[2.23847095502768, -0.2222441235311438], 
            Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.671385007001143, -1.2250298694138173`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[3.292640497180628, 0.059698042168788046`], 
            Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.671385007001144, -1.1250298694138172`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.434233150770422, 0.05969804216878785], 
            Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618139580912272, -2.224954263799971}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.185461666136161, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.618139580912272, -2.124954263799971}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.327054319725956, -1.0220463622527831`], 
            Complex[7.618139580912272, -2.124954263799971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622302363778045, -0.3323837861527894}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[6.167267914426828, 1.013856391477559], 
            Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622302363778045, -0.23238378615278985`}],
          RowBox[{"{", 
            RowBox[{"29.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.299999999999997`, {
            Complex[9.308860568016621, 1.0138563914775585`], 
            Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1131760714852184`, -3.167009032408055}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11469477510277208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.603654275715108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408055`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[0.11469477510277208`, -1.603654275715108], 
            Complex[1.1131760714852184`, -3.067009032408055]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1131760714852224`, -3.067009032408053}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2562874286925667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.603654275715105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1131760714852224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408053`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2562874286925667`, -1.603654275715105], 
            Complex[1.1131760714852224`, -3.067009032408053]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.466927815290494, -1.5384206511375544`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[5.39187137537774, -0.22338249250843517`], 
            Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.466927815290494, -1.638420651137555}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[2.250278721787946, -0.22338249250843553`], 
            Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.658646056679823, -1.1231061803689852`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.423323434867788, 0.061711105883242766`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.658646056679823, -1.2231061803689853`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                   ",", 
                  RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[3.2817307812779952`, 0.061711105883242925`], 
            Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617957948303616, -2.228722917140586}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.185393797936859, -1.0262403046082502`], 
            Complex[7.617957948303616, -2.128722917140586]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6179579483036175`, -2.128722917140585}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.326986451526654, -1.0262403046082496`], 
            Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622328456276393, -0.22858694399613969`}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.4, {
            Complex[9.308877471091341, 1.0180462834838366`], 
            Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622328456276393, -0.3285869439961401}],
          RowBox[{"{", 
            RowBox[{"29.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.4, {
            Complex[6.167284817501548, 1.0180462834838364`], 
            Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1120014862933134`, -3.06947337084671}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.255699647599667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.606125947331712`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1120014862933134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.255699647599667, -1.606125947331712], 
            Complex[1.1120014862933134`, -3.06947337084671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.112001486293314, -3.16947337084671}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11410699400987415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6061259473317113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.112001486293314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[0.11410699400987415`, -1.6061259473317113`], 
            Complex[1.112001486293314, -3.06947337084671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.481070345408924, -1.5386239263253454`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[5.403822532373675, -0.2246570435317341], 
            Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.4810703454089253`, -1.6386239263253453`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[2.2622298787838817`, -0.2246570435317342], 
            Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.645717853916904, -1.1210434375401022`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.412265737666768, 0.06385145452602968], 
            Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.645717853916905, -1.2210434375401022`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[3.270673084076976, 0.06385145452602974], 
            Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617777553627533, -2.2324559462163154`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.185326845280091, -1.030396405990655], 
            Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617777553627534, -2.1324559462163153`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.326919498869884, -1.030396405990655], 
            Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622353819311706, -0.22482566197765572`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.5, {
            Complex[9.308893840937472, 1.0221983660944407`], 
            Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622353819311706, -0.32482566197765594`}],
          RowBox[{"{", 
            RowBox[{"29.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.5, {
            Complex[6.167301187347679, 1.0221983660944405`], 
            Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1108347036697903`, -3.1719247844127585`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11352520873386833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.608583268903826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127584`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[0.11352520873386833`, -1.608583268903826], 
            Complex[1.1108347036697903`, -3.0719247844127584`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1108347036697925`, -3.0719247844127553`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2551178623236616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6085832689038237`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1108347036697925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127553`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2551178623236616`, -1.6085832689038237`], 
            Complex[1.1108347036697925`, -3.0719247844127553`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.49540764739327, -1.638992497237254}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[2.274330474286138, -0.22607991328743204`], 
            Complex[3.49540764739327, -1.538992497237254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.49540764739327, -1.538992497237254}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[5.415923127875931, -0.22607991328743238`], 
            Complex[3.49540764739327, -1.538992497237254]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.6325923193910725`, -1.2188275290397075`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[3.2594613930506555`, 0.06613136000835836], 
            Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.632592319391073, -1.1188275290397078`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.401054046640449, 0.06613136000835822], 
            Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6175983697588965`, -2.236154014160339}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.18526078540529, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6175983697588965`, -2.136154014160339}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.326853438995084, -1.034515366239107], 
            Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62237847390638, -0.22109927762639908`}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[9.3089096950579, 1.0263133387136967`], 
            Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622378473906381, -0.3210992776263989}],
          RowBox[{"{", 
            RowBox[{"29.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.599999999999998`, {
            Complex[6.167317041468107, 1.0263133387136971`], 
            Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1096756186764682`, -3.1743634253800934`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1129493247010233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[0.1129493247010233, -1.611026411118455], 
            Complex[1.1096756186764682`, -3.0743634253800933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1096756186764698`, -3.0743634253800933`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.254541978290817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1096756186764698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.254541978290817, -1.611026411118455], 
            Complex[1.1096756186764698`, -3.0743634253800933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5099478431009334`, -1.6395421364907365`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[2.2865864863773204`, -0.2276647637711871], 
            Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5099478431009343`, -1.5395421364907365`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[5.428179139967114, -0.22766476377118722`], 
            Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.619261335536663, -1.1164425322748182`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.389682419157071, 0.06856461676025156], 
            Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.619261335536663, -1.2164425322748187`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[3.2480897655672782`, 0.06856461676025145], 
            Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617420370497284, -2.2398177654127496`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.185195596375154, -1.0385978654970505`], 
            Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617420370497285, -2.1398177654127517`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.326788249964949, -1.0385978654970531`], 
            Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622402440275706, -0.21740714715263532`}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[9.30892505023899, 1.0303918810590929`], 
            Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622402440275708, -0.3174071471526355}],
          RowBox[{"{", 
            RowBox[{"29.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.699999999999996`, {
            Complex[6.167332396649198, 1.0303918810590926`], 
            Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.108524128499807, -3.1767894432225035`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11237924938587697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571996`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.108524128499807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0767894432225034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[0.11237924938587697`, -1.6134555415571996`], 
            Complex[1.108524128499807, -3.0767894432225034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1085241284998075`, -3.076789443222504}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.253971902975671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1085241284998075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.076789443222504`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.253971902975671, -1.6134555415571998`], 
            Complex[1.1085241284998075`, -3.076789443222504]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.524698954687548, -1.6402906900657317`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[2.2990036923040837`, -0.2294269927942462], 
            Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5246989546875493`, -1.5402906900657307`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[5.440596345893878, -0.22942699279424578`], 
            Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.605716884708898, -1.1138704540789914`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.378145113127533, 0.07116675231062962], 
            Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.605716884708899, -1.2138704540789917`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[3.23655245953774, 0.07116675231062944], 
            Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617243530524916, -2.1434478264288344`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.326723910626667, -1.042644564958483], 
            Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617243530524916, -2.2434478264288353`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.185131257036874, -1.0426445649584837`], 
            Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622425737866838, -0.21374864473986183`}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[9.30893992258648, 1.034434653907242], 
            Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622425737866838, -0.3137486447398621}],
          RowBox[{"{", 
            RowBox[{"29.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.799999999999997`, {
            Complex[6.1673472689966875`, 1.0344346539072418`], 
            Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1073801323937882`, -3.1792029846837004`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1118148922544208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728453`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[0.1118148922544208, -1.6158708247728453`], 
            Complex[1.1073801323937882`, -3.0792029846837004`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1073801323937882`, -3.0792029846837012`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2534075458442144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837012`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2534075458442144`, -1.6158708247728455`], 
            Complex[1.1073801323937882`, -3.0792029846837012`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.539668711719687, -1.6412583702907801`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[2.311587489979285, -0.23138396931833907`], 
            Complex[3.539668711719687, -1.54125837029078]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5396687117196883`, -1.54125837029078}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[5.453180143569079, -0.23138396931833927`], 
            Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.591951242060748, -1.111090937656241}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.3664367655030105`, 0.07395526269357508], 
            Complex[4.591951242060748, -1.111090937656241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.591951242060749, -1.2110909376562413`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[3.2248441119132174`, 0.07395526269357484], 
            Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6170678253669655`, -2.2470448063535953`}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.185067746985585, -1.0466561075785734`], 
            Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.617067825366967, -2.147044806353595}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.32666040057538, -1.0466561075785734`], 
            Complex[7.617067825366967, -2.147044806353595]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622448385395497, -0.3101231618705582}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[6.16736167396946, 1.0384422998042997`], 
            Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622448385395499, -0.2101231618705582}],
          RowBox[{"{", 
            RowBox[{"29.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.899999999999995`, {
            Complex[9.308954327559254, 1.0384422998042997`], 
            Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1062435316246895`, -3.0816041938451617`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2528488182990007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6182724223635778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.2528488182990007`, -1.6182724223635778`], 
            Complex[1.1062435316246895`, -3.0816041938451617`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1062435316246904`, -3.181604193845162}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11125616470920796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6182724223635776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1062435316246904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[0.11125616470920796`, -1.6182724223635776`], 
            Complex[1.1062435316246904`, -3.0816041938451617`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.554864285859265, -1.6424680817046264`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[2.324342656755631, -0.2335552923600304], 
            Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.554864285859266, -1.5424680817046266`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[5.465935310345424, -0.23355529236003053`], 
            Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.577957240848535, -1.2080809366516996`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[3.212959979911501, 0.07694987142173919], 
            Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.577957240848536, -1.108080936651698}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.354552633501294, 0.07694987142174026], 
            Complex[4.577957240848536, -1.108080936651698]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616893231354067, -2.150609297664497}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.326597700119693, -1.0506331187508058`], 
            Complex[7.616893231354067, -2.150609297664497]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6168932313540685`, -2.250609297664496}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.1850050465299, -1.0506331187508056`], 
            Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622470400880571, -0.306530106683735}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[6.167375626411306, 1.0424154437428594`], 
            Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622470400880571, -0.20653010668373517`}],
          RowBox[{"{", 
            RowBox[{"29.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {29.999999999999996`, {
            Complex[9.308968280001098, 1.042415443742859], 
            Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.105114229417701, -3.0839932121918214`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.252295633626107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.620660493044881`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.105114229417701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.252295633626107, -1.620660493044881], 
            Complex[1.105114229417701, -3.0839932121918214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1051142294177012`, -3.1839932121918215`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.110702980036313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6206604930448811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1051142294177012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[0.110702980036313, -1.6206604930448811`], 
            Complex[1.1051142294177012`, -3.0839932121918214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5702919304393554`, -1.643945776013632}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[2.3372730266129884`, -0.2359630690132302], 
            Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.570291930439357, -1.5439457760136326`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[5.478865680202783, -0.23596306901323125`], 
            Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.56372863284657, -1.1048143601285865`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.342488917419652, 0.08017280757570108], 
            Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.563728632846572, -1.2048143601285868`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[3.20089626382986, 0.0801728075757009], 
            Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61671972558691, -2.2541418767841934`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.184943136659399, -1.0545762069524705`], 
            Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616719725586911, -2.1541418767841924`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.326535790249194, -1.0545762069524702`], 
            Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622491801676729, -0.3029689033624723}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[6.167389140580846, 1.04635469380724], 
            Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6224918016767305`, -0.20296890336247192`}],
          RowBox[{"{", 
            RowBox[{"30.099999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.099999999999998`, {
            Complex[9.30898179417064, 1.04635469380724], 
            Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1039921309052896`, -3.186370178675715}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.11015525335407254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1039921309052896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0863701786757147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[0.11015525335407254`, -1.6230351927192315`], 
            Complex[1.1039921309052896`, -3.0863701786757147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.10399213090529, -3.086370178675715}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.251747906943866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.10399213090529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.086370178675715`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.251747906943866, -1.6230351927192315`], 
            Complex[1.10399213090529, -3.086370178675715]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5859564964599824`, -1.6457208265493541`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[2.3503810623577226`, -0.23863220192231419`], 
            Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.5859564964599846`, -1.545720826549354}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[5.491973715947518, -0.2386322019223144], 
            Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.549260572342168, -1.1012616980470773`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.330243188435803, 0.08364909334179328], 
            Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.549260572342168, -1.2012616980470778`}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[3.18865053484601, 0.08364909334179278], 
            Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616547285902736, -2.257643104664951}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.1848819990139186`, -1.0584859643603293`], 
            Complex[7.616547285902736, -2.157643104664951]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616547285902738, -2.157643104664951}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.326474652603713, -1.058485964360329], 
            Complex[7.616547285902738, -2.157643104664951]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622512604505212, -0.299438991549757}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[6.167402230179722, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622512604505212, -0.199438991549757}],
          RowBox[{"{", 
            RowBox[{"30.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.199999999999996`, {
            Complex[9.308994883769515, 1.0502606417889433`], 
            Complex[7.622512604505212, -0.199438991549757]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.102877143077272, -3.188735229777653}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1096129015635269`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6253966745436466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.102877143077272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0887352297776527`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[0.1096129015635269, -1.6253966745436466`], 
            Complex[1.102877143077272, -3.0887352297776527`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1028771430772724`, -3.0887352297776514`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.25120555515332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6253966745436454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1028771430772724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0887352297776514`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.25120555515332, -1.6253966745436454`], 
            Complex[1.1028771430772724`, -3.0887352297776514`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6018607902943125`, -1.647826403307316}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[2.3636672947096224`, -0.24159066834690415`], 
            Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.601860790294313, -1.5478264033073161`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[5.5052599482994165`, -0.2415906683469046], 
            Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.534550258420687, -1.1973896461639486`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[3.176222295931689, 0.08740682313953917], 
            Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.534550258420687, -1.0973896461639485`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.317814949521482, 0.08740682313953926], 
            Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616375890843667, -2.261113527346336}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.184821615854545, -1.062362967438099], 
            Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616375890843669, -2.1611135273463358`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.326414269444339, -1.0623629674380988`], 
            Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622532825482894, -0.2959398257910543}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[6.167414908379169, 1.054133863773935], 
            Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622532825482894, -0.19593982579105432`}],
          RowBox[{"{", 
            RowBox[{"30.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.299999999999997`, {
            Complex[9.309007561968963, 1.0541338637739348`], 
            Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1017691747325018`, -3.191088499566983}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10907584330050497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.091088499566983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[0.10907584330050497`, -1.6277450889951857`], 
            Complex[1.1017691747325018`, -3.091088499566983]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1017691747325018`, -3.0910884995669843`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.250668496890299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0910884995669843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.250668496890299, -1.6277450889951866`], 
            Complex[1.1017691747325018`, -3.0910884995669843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6180047326806646`, -1.6502998152929638`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[2.3771295961517165`, -0.24486976056502352`], 
            Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6180047326806664`, -1.5502998152929646`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[5.518722249741511, -0.24486976056502427`], 
            Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.519597775965093, -1.0931607636269258`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.30520636159325, 0.09147740408549994], 
            Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.519597775965093, -1.1931607636269261`}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[3.1636137080034565`, 0.09147740408549974], 
            Complex[4.519597775965093, -1.093160763626926]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6162055196267024`, -2.264553676487631}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.184761970036191, -1.0662077774973115`], 
            Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616205519626703, -2.164553676487631}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.326354623625987, -1.0662077774973113`], 
            Complex[7.616205519626703, -2.164553676487631]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62255248014975, -0.1924708750021304}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.4, {
            Complex[9.309019841434887, 1.0579749207033116`], 
            Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62255248014975, -0.2924708750021312}],
          RowBox[{"{", 
            RowBox[{"30.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.4, {
            Complex[6.167427187845094, 1.0579749207033107`], 
            Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.1006681364321238`, -3.093430119759536}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2501366524790782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6300805839344696`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.093430119759536`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.2501366524790782`, -1.6300805839344696`], 
            Complex[1.1006681364321238`, -3.093430119759536]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.1006681364321256`, -3.1934301197595354`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10854399888928548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6300805839344692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.1006681364321256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0934301197595353`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[0.10854399888928548`, -1.6300805839344692`], 
            Complex[1.1006681364321256`, -3.0934301197595353`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.634384275397017, -1.653182765701945}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[2.3907622559358295`, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.634384275397017, -1.5531827657019448`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[5.532354909525623, -0.24850423935263424`], 
            Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.504407178973381, -1.1885332177365604`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[3.1508305149179034`, 0.09589570953158899], 
            Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.504407178973381, -1.0885332177365608`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.292423168507697, 0.09589570953158878], 
            Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616036152115314, -2.1679640698763802`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.326295698571451, -1.0700209412330057`], 
            Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.616036152115315, -2.2679640698763754`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.184703044981658, -1.070020941233001], 
            Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622571583494798, -0.18903162196075995`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.5, {
            Complex[9.309031734351517, 1.0617843589087967`], 
            Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6225715834948, -0.28903162196075954`}],
          RowBox[{"{", 
            RowBox[{"30.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.5, {
            Complex[6.167439080761725, 1.061784358908797], 
            Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0995739404543334`, -3.095760219773794}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2496099438875583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6324033046672912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.2496099438875583`, -1.6324033046672912`], 
            Complex[1.0995739404543334`, -3.095760219773794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0995739404543337`, -3.195760219773794}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10801729029776416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6324033046672906`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0995739404543337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[0.10801729029776416`, -1.6324033046672906`], 
            Complex[1.0995739404543337`, -3.095760219773794]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6509900350811173`, -1.656521435684903}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[2.404554826889628, -0.25253232740394693`], 
            Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.650990035081118, -1.556521435684903}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[5.546147480479421, -0.25253232740394727`], 
            Complex[3.650990035081118, -1.556521435684903]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.488987856730723, -1.1834607001253281`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[3.137883196665494, 0.10070007254234226`], 
            Complex[4.488987856730723, -1.083460700125328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.488987856730723, -1.083460700125328}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.279475850255287, 0.10070007254234241`], 
            Complex[4.488987856730723, -1.083460700125328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615867768792521, -2.2713452119143027`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.184644824657079, -1.07380299123558], 
            Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615867768792523, -2.171345211914303}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.326237478246874, -1.0738029912355802`], 
            Complex[7.615867768792523, -2.171345211914303]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6225901499806685`, -0.18562156282100936`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[9.309043252443763, 1.0655627106244419`], 
            Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62259014998067, -0.28562156282100937`}],
          RowBox[{"{", 
            RowBox[{"30.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.599999999999998`, {
            Complex[6.167450598853971, 1.065562710624442], 
            Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0984865007505693`, -3.098078926785381}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2490882946838866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6347133940043952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0984865007505693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.098078926785381`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.2490882946838866`, -1.6347133940043952`], 
            Complex[1.0984865007505693`, -3.098078926785381]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.09848650075057, -3.19807892678538}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10749564109409336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6347133940043936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09848650075057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.09807892678538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[0.10749564109409336`, -1.6347133940043936`], 
            Complex[1.09848650075057, -3.09807892678538]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.66780561916792, -1.660366273382241}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[2.4184907299124174`, -0.2569954375693104], 
            Complex[3.66780561916792, -1.560366273382241]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.667805619167921, -1.560366273382241}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[5.560083383502212, -0.2569954375693105], 
            Complex[3.667805619167921, -1.560366273382241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.473356207864622, -1.17789263766847}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[3.124788364875778, 0.1059320141880026], 
            Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.473356207864623, -1.0778926376684699`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.266381018465571, 0.10593201418800262`], 
            Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615700350735349, -2.1746975940818984`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.326179947138467, -1.077554446480185], 
            Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615700350735352, -2.2746975940818928`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.184587293548676, -1.0775544464801792`], 
            Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622608193566827, -0.18224020664891896`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[9.309054406998325, 1.069310494475782], 
            Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622608193566829, -0.28224020664891875`}],
          RowBox[{"{", 
            RowBox[{"30.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.699999999999996`, {
            Complex[6.167461753408532, 1.069310494475782], 
            Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0974057329031106`, -3.1003863657798956`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2485716299944873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1003863657798956`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.2485716299944873`, -1.6370109923194756`], 
            Complex[1.0974057329031106`, -3.1003863657798956`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0974057329031108`, -3.200386365779895}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10697897640469432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0974057329031108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.100386365779895`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[0.10697897640469432`, -1.6370109923194756`], 
            Complex[1.0974057329031108`, -3.100386365779895]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6848056561525757`, -1.564771318831328}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[5.5741382895514295`, -0.26193749411720274`], 
            Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.6848056561525757`, -1.6647713188313291`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[2.4325456359616355`, -0.26193749411720374`], 
            Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.4575376100748025`, -1.171774867524016}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[3.1115703808320068`, 0.11163556486001101`], 
            Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.457537610074803, -1.0717748675240166`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.2531630344218, 0.11163556486001082`], 
            Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615533879590611, -2.27802169538267}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.1845304366407206`, -1.081275812794643], 
            Complex[7.615533879590611, -2.17802169538267]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615533879590611, -2.17802169538267}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.326123090230514, -1.0812758127946427`], 
            Complex[7.615533879590611, -2.17802169538267]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622625727731571, -0.2788870749784164}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[6.167472555293864, 1.0730282159476652`], 
            Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622625727731571, -0.17888707497841683`}],
          RowBox[{"{", 
            RowBox[{"30.799999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.799999999999997`, {
            Complex[9.309065208883657, 1.0730282159476647`], 
            Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0963315540840044`, -3.2026826596041884`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1064672228736436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6392962376054825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[0.1064672228736436, -1.6392962376054825`], 
            Complex[1.0963315540840044`, -3.1026826596041883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0963315540840044`, -3.1026826596041888`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.248059876463437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6392962376054834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.248059876463437, -1.6392962376054834`], 
            Complex[1.0963315540840044`, -3.1026826596041888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7019536132591457`, -1.5697928508801484`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[5.5882783610426285`, -0.267403671805992], 
            Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7019536132591475`, -1.66979285088015}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[2.4466857074528354`, -0.2674036718059935], 
            Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.44156860245767, -1.1650509901679487`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[3.098263114072366, 0.11785600339463051`], 
            Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.44156860245767, -1.065050990167949}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.23985576766216, 0.11785600339462998`], 
            Complex[4.44156860245767, -1.065050990167949]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61536833755189, -2.181317982768311}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.32606689298445, -1.0849675833073058`], 
            Complex[7.61536833755189, -2.181317982768311]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6153683375518915`, -2.2813179827683103`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.184474239394659, -1.0849675833073054`], 
            Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622642765492878, -0.17556170138642116`}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {30.9, {
            Complex[9.30907566856886, 1.076716367831864], 
            Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622642765492878, -0.2755617013864214}],
          RowBox[{"{", 
            RowBox[{"30.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.9, {
            Complex[6.1674830149790685`, 1.0767163678318639`], 
            Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0952638830152697`, -3.204967929016111}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10596030862333504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0952638830152697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.104967929016111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[0.10596030862333504`, -1.64156926552927], 
            Complex[1.0952638830152697`, -3.104967929016111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.09526388301527, -3.104967929016112}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2475529622131285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.09526388301527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.104967929016112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.2475529622131285`, -1.64156926552927], 
            Complex[1.09526388301527, -3.104967929016112]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.719199600336583, -1.5754871190552313`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[5.602458533258957, -0.2734383645589251], 
            Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.719199600336585, -1.6754871190552318`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[2.4608658796691665`, -0.2734383645589258], 
            Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.425499081603797, -1.1576646374765922`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[3.084911660981808, 0.1246378257982292], 
            Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.425499081603797, -1.0576646374765928`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.226504314571602, 0.12463782579822859`], 
            Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615203707337716, -2.284586911545557}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.184418687729288, -1.0886302388755988`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.615203707337716, -2.1845869115455567`}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.32601134131908, -1.0886302388755993`], 
            Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622659319428154, -0.2722636310861375}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[6.1674931425517565`, 1.08037543065552], 
            Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622659319428154, -0.1722636310861379}],
          RowBox[{"{", 
            RowBox[{"30.999999999999993`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {30.999999999999993`, {
            Complex[9.309085796141549, 1.0803754306555196`], 
            Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0942026399303617`, -3.2072422927328}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10545816321639523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.643830209484655`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1072422927328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[0.10545816321639523`, -1.643830209484655], 
            Complex[1.0942026399303617`, -3.1072422927328]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0942026399303626`, -3.107242292732799}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2470508168061887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6438302094846542`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0942026399303626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.107242292732799`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.2470508168061887`, -1.6438302094846542`], 
            Complex[1.0942026399303626`, -3.107242292732799]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.736478521301464, -1.5819069561624801`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[5.616621151226328, -0.2800822323034732], 
            Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.736478521301466, -1.68190695616248}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[2.4750284976365355`, -0.28008223230347307`], 
            Complex[3.736478521301466, -1.58190695616248]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.409394150148913, -1.1495628600775767`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[3.071573707918281, 0.1320217921353984], 
            Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.409394150148914, -1.0495628600775768`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.213166361508075, 0.13202179213539816`], 
            Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6150399721707815`, -2.287828925765876}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.1843637680019645`, -1.092264248496479], 
            Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6150399721707815`, -2.1878289257658765`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.325956421591757, -1.0922642484964793`], 
            Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622675401692968, -0.16899242053759034`}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[9.309095601324776, 1.0840058730914168`], 
            Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622675401692968, -0.268992420537591}],
          RowBox[{"{", 
            RowBox[{"31.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.099999999999994`, {
            Complex[6.167502947734983, 1.0840058730914166`], 
            Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0931477465368076`, -3.109505867477551}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2465533712085897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6460792006439566`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0931477465368076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.109505867477551`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.2465533712085897`, -1.6460792006439566`], 
            Complex[1.0931477465368076`, -3.109505867477551]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.093147746536808, -3.2095058674775503`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10496071761879634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.646079200643956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.093147746536808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.10950586747755`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[0.10496071761879634`, -1.646079200643956], 
            Complex[1.093147746536808, -3.10950586747755]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7537091204741744`, -1.6890972039111016`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[2.4891027727434665`, -0.2873682998621285], 
            Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.7537091204741753`, -1.5890972039111027`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[5.6306954263332605`, -0.2873682998621296], 
            Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.39333507043169, -1.0407007016791037`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.199912728184141, 0.14004102546706554`], 
            Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.393335070431694, -1.140700701679103}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[3.0583200745943513`, 0.1400410254670661], 
            Complex[4.393335070431694, -1.040700701679103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614877115758213, -2.1910444585987423`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.325902120580537, -1.0958700696995949`], 
            Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614877115758213, -2.2910444585987433`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.1843094669907455`, -1.0958700696995953`], 
            Complex[7.614877115758213, -2.191044458598743]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622691024038829, -0.16574763707454038`}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[9.309105093493066, 1.0876081523510002`], 
            Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622691024038829, -0.2657476370745412}],
          RowBox[{"{", 
            RowBox[{"31.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.199999999999996`, {
            Complex[6.167512439903273, 1.0876081523509995`], 
            Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0920991259799997`, -3.211758768025329}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10446790416412378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6483163680080417`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259799997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1117587680253287`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[0.10446790416412378`, -1.6483163680080417`], 
            Complex[1.0920991259799997`, -3.1117587680253287`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0920991259800008`, -3.111758768025328}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2460605577539177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648316368008041`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0920991259800008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.111758768025328`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.2460605577539177`, -1.648316368008041], 
            Complex[1.0920991259800008`, -3.111758768025328]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.770794613325989, -1.6970891666976442`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[2.5030056270697787`, -0.29531732776612113`], 
            Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.770794613325991, -1.597089166697644}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[5.644598280659573, -0.29531732776612096`], 
            Complex[3.770794613325991, -1.597089166697644]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.377418633740917, -1.1310467452404807`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[3.0452338697500734`, 0.14871638271009868`], 
            Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.377418633740918, -1.0310467452404806`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.1868265233398665`, 0.1487163827100988], 
            Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614715122272777, -2.194233932689377}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.325848425467212, -1.0994481489240884`], 
            Complex[7.614715122272777, -2.194233932689377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614715122272779, -2.294233932689377}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.18425577187742, -1.0994481489240884`], 
            Complex[7.614715122272779, -2.194233932689377]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622706197830052, -0.16252885854692958`}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[9.309114281687616, 1.0911827145610287`], 
            Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622706197830052, -0.2625288585469304}],
          RowBox[{"{", 
            RowBox[{"31.299999999999997`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.299999999999997`, {
            Complex[6.167521628097823, 1.0911827145610276`], 
            Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0910567028080986`, -3.2140011072469723`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10397965651895658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.65054183845496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[0.10397965651895658`, -1.65054183845496], 
            Complex[1.0910567028080986`, -3.114001107246972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0910567028080993`, -3.114001107246972}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2455723101087495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6505418384549597`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0910567028080993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.2455723101087495`, -1.6505418384549597`], 
            Complex[1.0910567028080993`, -3.114001107246972]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.787625571970204, -1.705894733710108}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[2.5166444532991594`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.787625571970204, -1.605894733710108}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[5.6582371068889525`, -0.3039330313949986], 
            Complex[3.787625571970204, -1.605894733710108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.361754274818783, -1.0205889908238657`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.1740003848318254`, 0.15805167382144575`], 
            Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.361754274818786, -1.1205889908238693`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[3.032407731242035, 0.1580516738214428], 
            Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6145539763350305`, -2.1973977605017097`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.3257953238212, -1.1029989218798244`], 
            Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6145539763350305`, -2.2973977605017106`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.184202670231408, -1.1029989218798246`], 
            Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622720934059783, -0.25933567297809756`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.4, {
            Complex[6.167530521040912, 1.0947299951246656`], 
            Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6227209340597835`, -0.15933567297809714`}],
          RowBox[{"{", 
            RowBox[{"31.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.4, {
            Complex[9.309123174630706, 1.0947299951246658`], 
            Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0900204029379934`, -3.116232996152112}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2450885632391073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6527557367871826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152112`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.2450885632391073`, -1.6527557367871826`], 
            Complex[1.0900204029379934`, -3.116232996152112]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0900204029379945`, -3.2162329961521112`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10349590964931504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.652755736787182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0900204029379945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152111`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[0.10349590964931504`, -1.652755736787182], 
            Complex[1.0900204029379945`, -3.116232996152111]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8040854242836235`, -1.715501270452578}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[2.5299220300509884`, -0.31319809514055186`], 
            Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8040854242836257`, -1.6155012704525782`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[5.671514683640783, -0.31319809514055214`], 
            Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.34645857273412, -1.009339964026806}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.161531564303005, 0.16802967600526247`], 
            Complex[4.34645857273412, -1.009339964026806]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.34645857273412, -1.109339964026807}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[3.0199389107132126`, 0.16802967600526134`], 
            Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614393662996269, -2.300536344647323}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.184150149994408, -1.1065228138938465`], 
            Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61439366299628, -2.2005363446473316`}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.325742803584212, -1.1065228138938557`], 
            Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622735243365228, -0.1561676782360194}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[9.309131780739362, 1.098250419067798], 
            Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622735243365228, -0.2561676782360204}],
          RowBox[{"{", 
            RowBox[{"31.499999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.499999999999996`, {
            Complex[6.167539127149569, 1.098250419067797], 
            Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0889901536222948`, -3.218454543930881}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10301659978814422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6549581857775262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0889901536222948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.118454543930881`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[0.10301659978814422`, -1.6549581857775262`], 
            Complex[1.0889901536222948`, -3.118454543930881]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.088990153622295, -3.1184545439308806`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2446092533779374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6549581857775257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.088990153622295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1184545439308806`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.2446092533779374`, -1.6549581857775257`], 
            Complex[1.088990153622295, -3.1184545439308806`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8200582761098634`, -1.625868648866983}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[5.684335924466961, -0.3230721172560274], 
            Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8200582761098674`, -1.7258686488669852`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[2.5427432708771702`, -0.3230721172560292], 
            Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.331647428673965, -1.0973396858188016`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[3.007922524597889, 0.17861007860412123`], 
            Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.331647428673966, -0.9973396858188027}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.1495151781876825`, 0.1786100786041201], 
            Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614234167722324, -2.2036500782010373`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.325690853055608, -1.1100202402427715`], 
            Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614234167722325, -2.3036500782010374`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.184098199465816, -1.1100202402427715`], 
            Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622749136042124, -0.15302448171788963`}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[9.309140108138353, 1.1017444013712938`], 
            Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622749136042124, -0.2530244817178898}],
          RowBox[{"{", 
            RowBox[{"31.599999999999998`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.599999999999998`, {
            Complex[6.167547454548559, 1.1017444013712936`], 
            Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0879658834173156`, -3.2206658579944394`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.1025416644037889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137859`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944393`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[0.1025416644037889, -1.6571493062137859`], 
            Complex[1.0879658834173156`, -3.1206658579944393`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0879658834173163`, -3.1206658579944384`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2441343179935824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137856`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0879658834173163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944384`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[3.2441343179935824`, -1.6571493062137856`], 
            Complex[1.0879658834173163`, -3.1206658579944384`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8354379364471782`, -1.7369295948434276`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.5550227978429705`, -0.33349241406049857`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8354379364471782`, -1.6369295948434275`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[5.696615451432764, -0.33349241406049873`], 
            Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.317427040750872, -1.084655324990569}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[2.996443980542599, 0.1897302873440814], 
            Complex[4.317427040750872, -0.984655324990569]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.317427040750873, -0.9846553249905683}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.138036634132392, 0.18973028734408198`], 
            Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614075476378116, -2.306739345003816}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.1840468072888495`, -1.1134916064718126`], 
            Complex[7.614075476378116, -2.206739345003816]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.614075476378116, -2.2067393450038164`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.325639460878643, -1.1134916064718128`], 
            Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622762622058501, -0.14990570004738207`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.7, {
            Complex[9.309148164672497, 1.1052123472899034`], 
            Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622762622058503, -0.24990570004738208`}],
          RowBox[{"{", 
            RowBox[{"31.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.7, {
            Complex[6.167555511082704, 1.1052123472899034`], 
            Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0869475221520086`, -3.222867044014348}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10207104216942726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.122867044014348`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[0.10207104216942726`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.122867044014348]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0869475221520086`, -3.1228670440143484`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2436636957592206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1228670440143484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[3.2436636957592206`, -1.6593292169421239`], 
            Complex[1.0869475221520086`, -3.1228670440143484`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8501363909766324`, -1.748593781537542}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.5666918389490667`, -0.3443779449095298], 
            Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.850136390976634, -1.6485937815375413`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[5.708284492538861, -0.3443779449095292], 
            Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.303885430470007, -0.971377104797332}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.127164733575719, 0.20130934934495107`], 
            Complex[4.303885430470007, -0.971377104797332]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.303885430470007, -1.071377104797334}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[2.9855720799859258`, 0.20130934934494918`], 
            Complex[4.303885430470007, -0.971377104797334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613917575212898, -2.3098045199535915`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.183995962437312, -1.1169373087010905`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613917575212898, -2.2098045199535914`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.325588616027105, -1.1169373087010908`], 
            Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622775711067786, -0.24681095878399034`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.8, {
            Complex[6.167563304328588, 1.1086546526584367`], 
            Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622775711067788, -0.14681095878399034`}],
          RowBox[{"{", 
            RowBox[{"31.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.8, {
            Complex[9.309155957918382, 1.1086546526584367`], 
            Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0859350008978244`, -3.1250582059608574`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2431973265232212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6614980349092643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608574`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[3.2431973265232212`, -1.6614980349092643`], 
            Complex[1.0859350008978244`, -3.1250582059608574`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0859350008978255`, -3.2250582059608566`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10160467293342826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6614980349092632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0859350008978255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[0.10160467293342826`, -1.6614980349092632`], 
            Complex[1.0859350008978255`, -3.1250582059608565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.864089926301709, -1.760755021789122}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.5777029731444694`, -0.35563571212946193`], 
            Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8640899263017117`, -1.6607550217891227`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[5.719295626734264, -0.3556357121294631], 
            Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.291086318485069, -0.957611110502011}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.1169469267372625`, 0.21325435309295884`], 
            Complex[4.291086318485069, -0.957611110502011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.291086318485069, -1.0576111105020116`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[2.9753542731474694`, 0.21325435309295854`], 
            Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613760450846203, -2.312845969284587}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.183945654203009, -1.1203577339198187`], 
            Complex[7.613760450846203, -2.212845969284587]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613760450846203, -2.212845969284587}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.325538307792803, -1.1203577339198192`], 
            Complex[7.613760450846203, -2.212845969284587]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622788412421259, -0.24373989214385858`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[6.16757084160569, 1.1120717041858348`], 
            Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622788412421261, -0.14373989214385835`}],
          RowBox[{"{", 
            RowBox[{"31.899999999999995`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.899999999999995`, {
            Complex[9.309163495195484, 1.112071704185835], 
            Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.084928251939455, -3.127239446140108}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.242735151280391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.084928251939455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.127239446140108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[3.242735151280391, -1.6636558752035226`], 
            Complex[1.084928251939455, -3.127239446140108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0849282519394552`, -3.2272394461401084`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10114249769059809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0849282519394552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1272394461401083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[0.10114249769059809`, -1.6636558752035224`], 
            Complex[1.0849282519394552`, -3.1272394461401083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8772617652382877`, -1.673300014636814}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[5.729624504719875, -0.3671682712416461], 
            Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.8772617652382886`, -1.7733000146368147`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.588031851130083, -0.3671682712416466], 
            Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.2790664893039665`, -1.043470542823362}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[2.965814938226205, 0.22546793870233256`], 
            Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.279066489303967, -0.9434705428233617}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.107407591815999, 0.22546793870233275`], 
            Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613604090254429, -2.315864050835693}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.1838958721837285`, -1.1237532602689642`], 
            Complex[7.613604090254429, -2.215864050835693]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613604090254429, -2.2158640508356933`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.325488525773522, -1.1237532602689644`], 
            Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622800735179931, -0.14069214273155697`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[9.309170783576755, 1.11546387973771], 
            Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622800735179931, -0.24069214273155717`}],
          RowBox[{"{", 
            RowBox[{"31.999999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {31.999999999999996`, {
            Complex[6.167578129986962, 1.1154638797377099`], 
            Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.083927208746434, -3.1294108652303243`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2422771121440808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6658028510947214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303243`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[3.2422771121440808`, -1.6658028510947214`], 
            Complex[1.083927208746434, -3.1294108652303243`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.083927208746434, -3.2294108652303257`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10068445855428786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6658028510947218`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[0.10068445855428786`, -1.6658028510947218`], 
            Complex[1.083927208746434, -3.1294108652303256`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.889641123048907, -1.7861168153853224`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.5976759196164494`, -0.3788808057418005], 
            Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.889641123048907, -1.6861168153853237`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[5.7392685732062425`, -0.37888080574180155`], 
            Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.267836735050403, -0.9290672478326635}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.098549310734496, 0.2378553727309036], 
            Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.267836735050403, -1.0290672478326643`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[2.9569566571447035`, 0.2378553727309031], 
            Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613448480758017, -2.3188591143084136`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.1838466062718, -1.1271242573129145`], 
            Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613448480758017, -2.218859114308414}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.325439259861593, -1.1271242573129148`], 
            Complex[7.613448480758017, -2.218859114308414]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62281268812585, -0.13766736128229182`}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[9.309177829898688, 1.118831548607897], 
            Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622812688125852, -0.2376673612822912}],
          RowBox[{"{", 
            RowBox[{"32.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.099999999999994`, {
            Complex[6.167585176308896, 1.1188315486078975`], 
            Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.082931805945569, -3.2315725623170004`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.10023049872932865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6679390740730153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[0.10023049872932865`, -1.6679390740730153`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.082931805945569, -3.1315725623170003`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2418231523191214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6679390740730151`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[3.2418231523191214`, -1.6679390740730151`], 
            Complex[1.082931805945569, -3.1315725623170003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.901239519558195, -1.799101588537602}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.606650933262854, -0.3906866010723904], 
            Complex[3.901239519558195, -1.699101588537602]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.901239519558195, -1.6991015885376035`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[5.748243586852646, -0.3906866010723917], 
            Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.257385543344473, -1.0145049639864019`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[2.9487637036120304`, 0.25033002218771455`], 
            Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.257385543344473, -0.9145049639864037}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.0903563572018244`, 0.2503300221877129], 
            Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6132936100092135`, -2.2218315015148575`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.325390500232961, -1.1304710863006695`], 
            Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613293610009215, -2.3218315015148523`}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.183797846643169, -1.1304710863006642`], 
            Complex[7.613293610009215, -2.221831501514852]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622824279772895, -0.2346652064140493}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[6.167591987181104, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622824279772895, -0.1346652064140495}],
          RowBox[{"{", 
            RowBox[{"32.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.199999999999996`, {
            Complex[9.309184640770896, 1.1221750717795362`], 
            Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0819419792941676`, -3.233724634927121}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09978056248576549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927121`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[0.09978056248576549, -1.6700646538866686`], 
            Complex[1.0819419792941676`, -3.133724634927121]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0819419792941676`, -3.133724634927122}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.241373216075559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927122`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[3.241373216075559, -1.6700646538866692`], 
            Complex[1.0819419792941676`, -3.133724634927122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9120856219032407`, -1.7121629626858914`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[5.75657901938974, -0.4025104167837189], 
            Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.912085621903242, -1.8121629626858926`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.6149863657999486`, -0.40251041678372024`], 
            Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.247684254548456, -0.8998749672010666}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.08279928559293, 0.26281672672835754`], 
            Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.247684254548457, -0.9998749672010703}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[2.9412066320031385`, 0.2628167267283543], 
            Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613139465980372, -2.3247815466162494`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.183749583746966, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.613139465980372, -2.2247815466162493`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.32534223733676, -1.1337941004170402`], 
            Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622835518377028, -0.13168534438923124`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.3, {
            Complex[9.309191222585227, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622835518377028, -0.23168534438923144`}],
          RowBox[{"{", 
            RowBox[{"32.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.3, {
            Complex[6.167598568995433, 1.1254948021761624`], 
            Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0809576656540323`, -3.2358671790624696`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09933459513336479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624695`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[0.09933459513336479, -1.6721796985788298`], 
            Complex[1.0809576656540323`, -3.1358671790624695`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0809576656540323`, -3.1358671790624704`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240927248723158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[3.240927248723158, -1.6721796985788306`], 
            Complex[1.0809576656540323`, -3.1358671790624704`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9222198214979045`, -1.7252240340035674`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[5.7643133844056464`, -0.4142898642644478], 
            Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9222198214979063`, -1.825224034003568}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.6227207308158538`, -0.41428986426444875`], 
            Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.238692484798848, -0.8852540673280812}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.075839610164613, 0.27525317641875785`], 
            Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.2386924847988485`, -0.9852540673280815}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[2.93424695657482, 0.27525317641875774`], 
            Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612986036952771, -2.327709576352396}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.183701808295563, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612986036952771, -2.227709576352396}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.325294461885356, -1.1370936450243205`], 
            Complex[7.612986036952771, -2.227709576352396]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6228464119461155`, -0.2287274488853233}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.4, {
            Complex[6.167604927934658, 1.128791084903274], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6228464119461155`, -0.12872744888532328`}],
          RowBox[{"{", 
            RowBox[{"32.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.4, {
            Complex[9.309197581524451, 1.1287910849032743`], 
            Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0799788029662047`, -3.138000289232015}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.240485196586656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6742843145233057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0799788029662047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138000289232015`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[3.240485196586656, -1.6742843145233057`], 
            Complex[1.0799788029662047`, -3.138000289232015]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.079978802966205, -3.238000289232016}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0988925429968627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6742843145233064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079978802966205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.138000289232016`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[0.0988925429968627, -1.6742843145233064`], 
            Complex[1.079978802966205, -3.138000289232016]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.931689378166075, -1.7382225152116566`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[5.771490138844717, -0.42597525546826004`], 
            Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9316893781660758`, -1.8382225152116571`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.629897485254924, -0.42597525546826037`], 
            Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.230362981869568, -0.9707044591549228}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[2.927841247969024, 0.28758976049421764`], 
            Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.230362981869569, -0.8707044591549226}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.069433901558818, 0.2875897604942178], 
            Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612833311505916, -2.3306159102625106`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.183654511255059, -1.1403700578948637`], 
            Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612833311505918, -2.2306159102625105`}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.325247164844853, -1.1403700578948632`], 
            Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622856968249285, -0.2257912007742036}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[6.16761106998075, 1.1320642574808064`], 
            Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622856968249287, -0.1257912007742034}],
          RowBox[{"{", 
            RowBox[{"32.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.49999999999999, {
            Complex[9.309203723570544, 1.1320642574808066`], 
            Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0790053302264244`, -3.2401240584834468`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09845435339193638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6763786064594066`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0790053302264244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1401240584834467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[0.09845435339193638, -1.6763786064594066`], 
            Complex[1.0790053302264244`, -3.1401240584834467`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.079005330226425, -3.140124058483446}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2400470069817295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6763786064594062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.079005330226425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.140124058483446`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[3.2400470069817295`, -1.6763786064594062`], 
            Complex[1.079005330226425, -3.140124058483446]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9405445393067433`, -1.7511096707348452`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[5.778154476287738, -0.43752848511674675`], 
            Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9405445393067433`, -1.8511096707348456`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.636561822697944, -0.4375284851167467], 
            Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.222645506003507, -0.956274787217682}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[2.921944339934747, 0.2997884495937316], 
            Complex[4.222645506003507, -0.856274787217682]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.2226455060035075`, -0.8562747872176826}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.063536993524541, 0.2997884495937313], 
            Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612681278507311, -2.3335008608977987`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.183607683836199, -1.1436236694349755`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612681278507311, -2.2335008608977986`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.325200337425992, -1.1436236694349757`], 
            Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622867194825846, -0.222876287909687}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[6.167617000922771, 1.1353146500669256`], 
            Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622867194825848, -0.12287628790968698`}],
          RowBox[{"{", 
            RowBox[{"32.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.599999999999994`, {
            Complex[9.309209654512566, 1.1353146500669253`], 
            Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0780371874612853`, -3.1422385784338522`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2396126281916615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6784626775258558`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[3.2396126281916615`, -1.6784626775258558`], 
            Complex[1.0780371874612853`, -3.1422385784338522`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0780371874612855`, -3.2422385784338505`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09801997460186761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6784626775258555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0780371874612855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338505`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[0.09801997460186761, -1.6784626775258555`], 
            Complex[1.0780371874612855`, -3.1422385784338505`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.948835712532858, -1.7638486148780146`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[5.784351043372479, -0.448921436448157], 
            Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.948835712532859, -1.8638486148780158`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.6427583897826854`, -0.4489214364481581], 
            Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.215489657270424, -0.8420018475938849}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.058104266499389, 0.311821201539341], 
            Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.2154896572704255`, -0.9420018475938849}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[2.9165116129095963`, 0.31182120153934106`], 
            Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612529927102651, -2.336364734026166}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.183561317485685, -1.1468548029005128`], 
            Complex[7.612529927102651, -2.236364734026166]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612529927102659, -2.2363647340261776`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.325153971075487, -1.1468548029005257`], 
            Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622877098993824, -0.21998240492294285`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[6.167622726364391, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622877098993824, -0.11998240492294286`}],
          RowBox[{"{", 
            RowBox[{"32.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.699999999999996`, {
            Complex[9.309215379954184, 1.1385425856735312`], 
            Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0770743157050577`, -3.2443439392995934`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09758935585487952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6805366292938224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1443439392995933`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[0.09758935585487952, -1.6805366292938224`], 
            Complex[1.0770743157050577`, -3.1443439392995933`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0770743157050588`, -3.144343939299593}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2391820094446726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6805366292938222`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0770743157050588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.144343939299593`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[3.2391820094446726`, -1.6805366292938222`], 
            Complex[1.0770743157050588`, -3.144343939299593]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9566115778779483`, -1.8764123973101796`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.648529805818011, -0.4601342612759221], 
            Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.95661157787795, -1.77641239731018}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[5.790122459407805, -0.4601342612759226], 
            Complex[3.95661157787795, -1.77641239731018]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{4.208846763357215, -0.8279125023887509}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.053093127997606, 0.32366824142440104`], 
            Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.208846763357217, -0.9279125023887512}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[2.911500474407813, 0.323668241424401], 
            Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612379246706456, -2.2392078288294064`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.325108057467666, -1.1500637746045623`], 
            Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612379246706457, -2.3392078288294065`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.183515403877874, -1.1500637746045628`], 
            Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622886687858099, -0.1171092530254295}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.8, {
            Complex[9.309220905320853, 1.1417483803738433`], 
            Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6228866878581005`, -0.21710925302543033`}],
          RowBox[{"{", 
            RowBox[{"32.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.8, {
            Complex[6.1676282517310606`, 1.1417483803738426`], 
            Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.076116656977162, -3.1464402299253895`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2387551008919058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6826005617990878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.076116656977162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1464402299253895`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[3.2387551008919058`, -1.6826005617990878`], 
            Complex[1.076116656977162, -3.1464402299253895`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0761166569771627`, -3.2464402299253887`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09716244730211258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.682600561799087`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0761166569771627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1464402299253886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[0.09716244730211258, -1.682600561799087], 
            Complex[1.0761166569771627`, -3.1464402299253886`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.963917947183657, -1.8887821416602486`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.653915808537619, -0.4711537472500261], 
            Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.963917947183657, -1.7887821416602485`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[5.795508462127413, -0.4711537472500259], 
            Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.202671020177384, -0.8140255411104014}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.048463866858473, 0.3353164289039027], 
            Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.202671020177384, -0.9140255411104018}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[2.90687121326868, 0.33531642890390234`], 
            Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612229226993079, -2.342030438093195}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.183469934906837, -1.1532508941175408`], 
            Complex[7.612229226993079, -2.242030438093195]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612229226993084, -2.242030438093204}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.325062588496635, -1.1532508941175512`], 
            Complex[7.612229226993084, -2.242030438093204]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622895968318211, -0.21425653981902026`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {32.9, {
            Complex[6.167633582276865, 1.1449323435024108`], 
            Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622895968318212, -0.11425653981902067`}],
          RowBox[{"{", 
            RowBox[{"32.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {32.9, {
            Complex[9.30922623586666, 1.1449323435024106`], 
            Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0751641542602708`, -3.2485275378126324`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09673919999623987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.684654573573374`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0751641542602708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1485275378126323`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[0.09673919999623987, -1.684654573573374], 
            Complex[1.0751641542602708`, -3.1485275378126323`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.075164154260271, -3.148527537812633}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.238331853586033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6846545735733742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.075164154260271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.148527537812633`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[3.238331853586033, -1.6846545735733742`], 
            Complex[1.075164154260271, -3.148527537812633]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.970797171183352, -1.8009453770853798`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[5.800545503681592, -0.4819718787730359], 
            Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9707971711833534`, -1.9009453770853804`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.6589528500918, -0.48197187877303665`], 
            Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.196920084784546, -0.8003533490732548}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[6.044180057256696, 0.34675781913864817`], 
            Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.196920084784548, -0.9003533490732543}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[2.9025874036669044`, 0.3467578191386486], 
            Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.612079857888092, -2.2448328483902147`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.325017556268538, -1.1564164644600665`], 
            Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6120798578880935`, -2.3448328483902148`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.183424902678746, -1.1564164644600665`], 
            Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62290494707578, -0.21142397911299568`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33., {
            Complex[6.167638723091055, 1.1480947778478905`], 
            Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622904947075782, -0.11142397911299567`}],
          RowBox[{"{", 
            RowBox[{"33.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33., {
            Complex[9.30923137668085, 1.1480947778478905`], 
            Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0742167514790106`, -3.2506059491469688`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0963195658706748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6866987616748745`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1506059491469687`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[0.0963195658706748, -1.6866987616748745`], 
            Complex[1.0742167514790106`, -3.1506059491469687`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0742167514790106`, -3.15060594914697}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237912219460468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.686698761674875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.15060594914697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[3.237912219460468, -1.686698761674875], 
            Complex[1.0742167514790106`, -3.15060594914697]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9772879223008717`, -1.812894617501449}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[5.805266648945746, -0.4925846278657947], 
            Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.977287922300882, -1.9128946175014523`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.6636739953559614`, -0.49258462786579826`], 
            Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1915552925709445`, -0.7869033281400241}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.04020866039606, 0.3579884536883503], 
            Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1915552925709445`, -0.8869033281400255}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[2.8986160068062667`, 0.3579884536883491], 
            Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611931129560043, -2.2476153402566923`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.324972953094393, -1.159560782288886], 
            Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611931129560044, -2.3476153402566924`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.1833802995046, -1.1595607822888863`], 
            Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622913630641643, -0.20861129074761375`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[6.167643679104286, 1.1512359798388985`], 
            Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622913630641643, -0.10861129074761434`}],
          RowBox[{"{", 
            RowBox[{"33.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.099999999999994`, {
            Complex[9.309236332694079, 1.151235979838898], 
            Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0732743934792583`, -3.2526755488251644`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09590349771937258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.688733221717992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1526755488251643`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[0.09590349771937258, -1.688733221717992], 
            Complex[1.0732743934792583`, -3.1526755488251643`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0732743934792588`, -3.152675548825165}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237496151309166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6887332217179927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0732743934792588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.152675548825165`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[3.237496151309166, -1.6887332217179927`], 
            Complex[1.0732743934792588`, -3.152675548825165]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.983425219490024, -1.8246261926386411`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[5.809701663341314, -0.5029909709021079], 
            Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.9834252194900266`, -1.9246261926386432`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.668109009751523, -0.50299097090211], 
            Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.186541632425325, -0.7736790656393441}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.036519936690694, 0.36900737727295657`], 
            Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1865416324253255`, -0.8736790656393452}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[2.8949272831009005`, 0.36900737727295585`], 
            Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61178303241253, -2.3503781883626598`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.183336117893254, -1.1626841380761952`], 
            Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611783032412532, -2.250378188362658}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.32492877148305, -1.1626841380761932`], 
            Complex[7.611783032412532, -2.250378188362658]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622922025342652, -0.20581820042396892`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[6.167648455094579, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622922025342652, -0.10581820042396912`}],
          RowBox[{"{", 
            RowBox[{"33.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.199999999999996`, {
            Complex[9.309241108684372, 1.154356239723236], 
            Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0723370260079925`, -3.154736420481273}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.237083602766982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0723370260079925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.154736420481273`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[3.237083602766982, -1.6907580479023252`], 
            Complex[1.0723370260079925`, -3.154736420481273]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.072337026007993, -3.2547364204812728`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09549094917718823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023245`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.072337026007993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1547364204812727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[0.09549094917718823, -1.6907580479023245`], 
            Complex[1.072337026007993, -3.1547364204812727`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.989240598169983, -1.9361393091196961`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.6722845561748567`, -0.5131921073476409], 
            Complex[3.989240598169983, -1.836139309119696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.989240598169983, -1.836139309119696}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[5.81387720976465, -0.5131921073476412], 
            Complex[3.989240598169983, -1.836139309119696]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1818475767949295`, -0.8606812732613812}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[2.8914945952485174`, 0.37981585653752775`], 
            Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1818475767949295`, -0.7606812732613814}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.033087248838311, 0.3798158565375278], 
            Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611635557076616, -2.2531216616761798`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.324885004134527, -1.165786816282607], 
            Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611635557076617, -2.3531216616761848`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.183292350544735, -1.1657868162826117`], 
            Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622930137328205, -0.203044439539864}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.3, {
            Complex[6.167653055693024, 1.1574558417407834`], 
            Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622930137328205, -0.10304443953986439`}],
          RowBox[{"{", 
            RowBox[{"33.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.3, {
            Complex[9.309245709282818, 1.1574558417407832`], 
            Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.071404595693708, -3.156788646512134}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2366745282905844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6927733330409118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.071404595693708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[3.2366745282905844`, -1.6927733330409118`], 
            Complex[1.071404595693708, -3.156788646512134]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0714045956937088`, -3.2567886465121343`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09508187470079153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6927733330409114`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0714045956937088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[0.09508187470079153, -1.6927733330409114`], 
            Complex[1.0714045956937088`, -3.156788646512134]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.994762358551031, -1.8474353092142086`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[5.817817100281683, -0.5231908494724428], 
            Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{3.994762358551031, -1.9474353092142092`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.67622444669189, -0.5231908494724435], 
            Complex[3.994762358551031, -1.847435309214209]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.177444833357386, -0.8479085282781004}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[2.8882941565379943`, 0.3904167697900055], 
            Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.177444833357386, -0.7479085282781011}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.029886810127787, 0.39041676979000506`], 
            Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611488694403536, -2.3558460236218126`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.183248990343842, -1.1688690955240477`], 
            Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611488694403542, -2.2558460236218103`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.324841643933642, -1.168869095524045], 
            Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62293797257647, -0.10028974503145545`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[9.309250138979012, 1.1605350642903134`], 
            Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622937972576472, -0.20028974503145566`}],
          RowBox[{"{", 
            RowBox[{"33.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.39999999999999, {
            Complex[6.16765748538922, 1.1605350642903134`], 
            Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0704770500273406`, -3.2588323081022286`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09467622955009732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6947791685877762`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1588323081022285`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[0.09467622955009732, -1.6947791685877762`], 
            Complex[1.0704770500273406`, -3.1588323081022285`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0704770500273408`, -3.158832308102228}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2362688831398905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.694779168587776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0704770500273408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.158832308102228`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[3.2362688831398905`, -1.694779168587776], 
            Complex[1.0704770500273408`, -3.158832308102228]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.000015848490728, -1.958517093091784}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.679949913999627, -0.5329911517598123], 
            Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.000015848490729, -1.858517093091784}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[5.821542567589421, -0.5329911517598128], 
            Complex[4.000015848490729, -1.858517093091784]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.173308062162179, -0.835357851265334}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[2.8853047593900265`, 0.4008141364346624], 
            Complex[4.173308062162179, -0.735357851265334]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.173308062162179, -0.7353578512653347}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.02689741297982, 0.40081413643466185`], 
            Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611342435457713, -2.258551532233558}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.324798683943808, -1.1719312487328415`], 
            Complex[7.611342435457713, -2.258551532233558]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611342435457713, -2.358551532233561}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1832060303540155`, -1.171931248732845], 
            Complex[7.611342435457713, -2.258551532233561]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6229455369003825`, -0.09755385922040935}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[9.309254402126275, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6229455369003825`, -0.19755385922040955`}],
          RowBox[{"{", 
            RowBox[{"33.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.49999999999999, {
            Complex[6.1676617485364815`, 1.1635941800905014`], 
            Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.069554337343726, -3.260867485247888}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0942739697702223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6967756446647657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.069554337343726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1608674852478877`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[0.0942739697702223, -1.6967756446647657`], 
            Complex[1.069554337343726, -3.1608674852478877`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0695543373437264`, -3.1608674852478886`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.235866623360016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6967756446647662`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0695543373437264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1608674852478886`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[3.235866623360016, -1.6967756446647662`], 
            Complex[1.0695543373437264`, -3.1608674852478886`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.00502375333401, -1.869388672925242}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[5.8250725348409, -0.5425977517885678], 
            Complex[4.00502375333401, -1.869388672925242]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.005023753334011, -1.9693886729252434`}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.683479881251108, -0.5425977517885688], 
            Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.169414585788292, -0.8230251519753936}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[2.8825075055343556`, 0.41101275787833075`], 
            Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.169414585788293, -0.7230251519753931}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.024100159124149, 0.4110127578783314], 
            Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611196771510031, -2.361238440302506}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.183163463811437, -1.1749735433132202`], 
            Complex[7.611196771510031, -2.261238440302506]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611196771510045, -2.261238440302506}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.324756117401245, -1.1749735433132202`], 
            Complex[7.611196771510045, -2.261238440302506]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622952835953341, -0.09483652966635159}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[9.309258502946614, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622952835953341, -0.1948365296663518}],
          RowBox[{"{", 
            RowBox[{"33.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.599999999999994`, {
            Complex[6.167665849356821, 1.1666334563353578`], 
            Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.068636406803538, -3.162894256780908}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2354677057637162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6987628500877325`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.068636406803538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.162894256780908`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[3.2354677057637162`, -1.6987628500877325`], 
            Complex[1.068636406803538, -3.162894256780908]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0686364068035386`, -3.2628942567809087`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09387505217392343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6987628500877328`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0686364068035386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1628942567809086`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[0.09387505217392343, -1.6987628500877328`], 
            Complex[1.0686364068035386`, -3.1628942567809086`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.009806376364359, -1.9800548315018012`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.6868312180069145`, -0.5520158986267104], 
            Complex[4.009806376364359, -1.880054831501801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.009806376364359, -1.880054831501802}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[5.8284238715967085`, -0.5520158986267112], 
            Complex[4.009806376364359, -1.880054831501802]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.165744108890899, -0.7109055707023495}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.021478203650236, 0.4210179459473799], 
            Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.165744108890901, -0.8109055707023496}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[2.8798855500604437`, 0.42101794594737985`], 
            Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611051694031386, -2.2639069955194184`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.324713937709186, -1.1779962412914933`], 
            Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.611051694031386, -2.3639069955194216`}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.183121284119393, -1.1779962412914966`], 
            Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622959875234723, -0.09213750902438231}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[9.30926244553551, 1.1696531548443287`], 
            Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6229598752347245`, -0.1921375090243823}],
          RowBox[{"{", 
            RowBox[{"33.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.699999999999996`, {
            Complex[6.167669791945717, 1.1696531548443287`], 
            Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0677232083757218`, -3.2649127003915566`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09347943432451934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.700740872392058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915565`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[0.09347943432451934, -1.700740872392058], 
            Complex[1.0677232083757218`, -3.1649127003915565`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0677232083757224`, -3.1649127003915547`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2350720879143124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7007408723920572`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0677232083757224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[3.2350720879143124`, -1.7007408723920572`], 
            Complex[1.0677232083757224`, -3.1649127003915547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.01438190088909, -1.9905208626824291`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.6900189760399855`, -0.5612511491377956], 
            Complex[4.01438190088909, -1.890520862682429]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.014381900889091, -1.8905208626824301`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[5.831611629629778, -0.5612511491377962], 
            Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.162278456114006, -0.7989937377997083}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[2.8774238656148396`, 0.4308353192168015], 
            Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.162278456114007, -0.6989937377997093}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.019016519204634, 0.4308353192168009], 
            Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610907194686489, -2.366557440612444}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.1830794848428505`, -1.180999599461101], 
            Complex[7.610907194686489, -2.266557440612444]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610907194686491, -2.2665574406124485`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.324672138432646, -1.180999599461105], 
            Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62296666009513, -0.18945655490745467`}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.8, {
            Complex[6.167673580276672, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62296666009513, -0.08945655490745465}],
          RowBox[{"{", 
            RowBox[{"33.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.8, {
            Complex[9.309266233866467, 1.1726535322072742`], 
            Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0668146928203772`, -3.1669228926510127`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.234679728109072`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7027097978575507`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1669228926510127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[3.234679728109072, -1.7027097978575507`], 
            Complex[1.0668146928203772`, -3.1669228926510127`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0668146928203786`, -3.266922892651011}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0930870745192786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7027097978575496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0668146928203786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.166922892651011`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[0.0930870745192786, -1.7027097978575496`], 
            Complex[1.0668146928203786`, -3.166922892651011]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.018766629721939, -2.000792375423005}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.693056602464925, -0.5703092165540393], 
            Complex[4.018766629721939, -1.900792375423005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.018766629721941, -1.9007923754230098`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[5.834649256054719, -0.5703092165540443], 
            Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.159001332605871, -0.6872839696368798}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.016701682863842, 0.4404706516054355], 
            Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.159001332605871, -0.7872839696368801}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[2.8751090292740487`, 0.4404706516054349], 
            Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610763265327906, -2.3691900134801815`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.183038059703257, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610763265327906, -2.2691900134801815`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.32463071329305, -1.183983869522754], 
            Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6229731957414195`, -0.08679342975340713}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {33.9, {
            Complex[9.309269871795374, 1.1756348399245429`], 
            Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6229731957414195`, -0.18679342975340757`}],
          RowBox[{"{", 
            RowBox[{"33.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {33.9, {
            Complex[6.167677218205581, 1.1756348399245424`], 
            Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0659108116721088`, -3.268924909033252}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0926979317732518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0659108116721088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.168924909033252`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[0.0926979317732518, -1.7046697115327327`], 
            Complex[1.0659108116721088`, -3.168924909033252]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.065910811672111, -3.1689249090332523`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2342905853630466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327338`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.065910811672111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1689249090332523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[3.2342905853630466`, -1.7046697115327338`], 
            Complex[1.065910811672111, -3.1689249090332523`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.022975200759233, -1.9108751468578686`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[5.837548783508502, -0.5791958590266288], 
            Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.022975200759234, -2.0108751468578676`}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.695956129918709, -0.5791958590266285], 
            Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.155898108440934, -0.7757704154937819}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[2.8729290323659913`, 0.4499297609478434], 
            Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.155898108440934, -0.675770415493782}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[6.014521685955785, 0.4499297609478434], 
            Complex[4.155898108440934, -0.675770415493782]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610619897990325, -2.371804947320256}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.182997002573542, -1.1869492982198684`], 
            Complex[7.610619897990325, -2.271804947320256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610619897990326, -2.271804947320259}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.324589656163337, -1.186949298219872], 
            Complex[7.610619897990326, -2.271804947320259]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622979487241572, -0.1841479006964723}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34., {
            Complex[6.167680709474919, 1.1785973245423345`], 
            Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622979487241573, -0.0841479006964717}],
          RowBox[{"{", 
            RowBox[{"34.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34., {
            Complex[9.309273363064712, 1.178597324542335], 
            Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0650115172238024`, -3.170918823936388}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2339046193933325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[3.2339046193933325`, -1.7066206972585347`], 
            Complex[1.0650115172238024`, -3.170918823936388]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0650115172238028`, -3.270918823936388}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09231196580353926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0650115172238028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[0.09231196580353926, -1.7066206972585347`], 
            Complex[1.0650115172238028`, -3.170918823936388]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.027020779081279, -1.9207750130848578`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[5.840320998393064, -0.5879167986060267], 
            Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.02702077908128, -2.020775013084858}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.698728344803272, -0.5879167986060275], 
            Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.152955626516613, -0.764447166754532}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[2.8708731122295896`, 0.4592184279956057], 
            Complex[4.152955626516613, -0.664447166754532]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.152955626516614, -0.6644471667545314}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.012465765819384, 0.4592184279956062], 
            Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610477084885045, -2.3744024707536155`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.182956307473314, -1.1898961274694768`], 
            Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610477084885046, -2.2744024707536186`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.324548961063108, -1.18989612746948], 
            Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622985539529303, -0.18151973944306815`}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.1, {
            Complex[6.1676840577177385`, 1.1815412277835526`], 
            Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622985539529303, -0.08151973944306835}],
          RowBox[{"{", 
            RowBox[{"34.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.1, {
            Complex[9.309276711307533, 1.1815412277835524`], 
            Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0641167625108199`, -3.1729047107034827`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2335217906037683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7085628376914088`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0641167625108199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[3.2335217906037683`, -1.7085628376914088`], 
            Complex[1.0641167625108199`, -3.1729047107034827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.06411676251082, -3.2729047107034828`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09192913701397513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7085628376914086`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06411676251082`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[0.09192913701397513, -1.7085628376914086`], 
            Complex[1.06411676251082, -3.1729047107034827`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.030915226970466, -2.030497788821198}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.7013829352654026`, -0.5964776632911527], 
            Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.030915226970469, -1.9304977888211992`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[5.842975588855198, -0.5964776632911535], 
            Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.150162032533434, -0.7533083372307825}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[2.8689316042370305`, 0.4683423384869718], 
            Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.150162032533443, -0.6533083372307831}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.010524257826831, 0.4683423384869708], 
            Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61033481839468, -2.276982807944708}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.324508622154049, -1.1928245944888063`], 
            Complex[7.61033481839468, -2.276982807944708]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610334818394682, -2.3769828079447084`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.182915968564257, -1.1928245944888065`], 
            Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622991357408528, -0.0789087221517155}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.2, {
            Complex[9.309279920051315, 1.18446678667431], 
            Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622991357408529, -0.17890872215171533`}],
          RowBox[{"{", 
            RowBox[{"34.2`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.2, {
            Complex[6.167687266461523, 1.1844667866743102`], 
            Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.063226501295623, -3.2748826416428582`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09154940648022836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7104962143258893`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.063226501295623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.174882641642858`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[0.09154940648022836, -1.7104962143258893`], 
            Complex[1.063226501295623, -3.174882641642858]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0632265012956237`, -3.1748826416428573`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2331420600700214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7104962143258888`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0632265012956237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1748826416428573`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[3.2331420600700214`, -1.7104962143258888`], 
            Complex[1.0632265012956237`, -3.1748826416428573`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.034669253707697, -2.0400492091033886`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.7039286208715065`, -0.6048839465011073], 
            Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.034669253707697, -1.9400492091033892`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[5.8455212744613, -0.6048839465011082], 
            Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.147506625196922, -0.6423481214415794}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.008688465710948, 0.47730704263853474`], 
            Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.147506625196923, -0.742348121441579}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[2.8670958121211547`, 0.477307042638535], 
            Complex[4.147506625196923, -0.642348121441579]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610193091068048, -2.37954617871769}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.1828759801456865`, -1.1957349319176866`], 
            Complex[7.610193091068048, -2.27954617871769]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.61019309106805, -2.2795461787176903`}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.32446863373548, -1.195734931917687], 
            Complex[7.61019309106805, -2.2795461787176903`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622996945557652, -0.0763146293168978}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.3, {
            Complex[9.30928299272165, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.622996945557652, -0.176314629316898}],
          RowBox[{"{", 
            RowBox[{"34.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.3, {
            Complex[6.167690339131856, 1.1873742336662831`], 
            Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.06234068805277, -3.276852688047909}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0911727359352858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7124209075166128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.06234068805277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.176852688047909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[0.0911727359352858, -1.7124209075166128`], 
            Complex[1.06234068805277, -3.176852688047909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0623406880527706`, -3.1768526880479087`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2327653895250794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.712420907516613`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0623406880527706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1768526880479087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[3.2327653895250794`, -1.712420907516613], 
            Complex[1.0623406880527706`, -3.1768526880479087`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.038292547177893, -1.9494348877721936`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[5.84796591957802, -0.6131409796537515], 
            Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.038292547177894, -2.049434887772193}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.7063732659882276`, -0.613140979653751], 
            Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.144979724610491, -0.731560836108617}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[2.8653578945969786`, 0.48611792774323803`], 
            Complex[4.144979724610491, -0.631560836108617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.144979724610491, -0.6315608361086175}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.006950548186772, 0.4861179277432377], 
            Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6100518956152605`, -2.382092798668853}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.182836336650298, -1.1986273679369637`], 
            Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.610051895615262, -2.2820927986688537`}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.324428990240092, -1.1986273679369637`], 
            Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623002308533652, -0.07373724565672798}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[9.309285932645754, 1.1902637967550587`], 
            Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623002308533653, -0.1737372456567276}],
          RowBox[{"{", 
            RowBox[{"34.39999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.39999999999999, {
            Complex[6.167693279055961, 1.1902637967550591`], 
            Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0614592779543155`, -3.2788149202164436`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09079908775532702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.714336996499808`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[0.09079908775532702, -1.714336996499808], 
            Complex[1.0614592779543155`, -3.1788149202164435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0614592779543162`, -3.1788149202164426`}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.23239174134512`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7143369964998079`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0614592779543162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164426`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[3.23239174134512, -1.7143369964998079`], 
            Complex[1.0614592779543162`, -3.1788149202164426`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.041793889306879, -2.058660288701135}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.708723978803601, -0.6212539145605391], 
            Complex[4.041793889306879, -1.958660288701135]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.04179388930688, -1.958660288701135}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[5.850316632393395, -0.6212539145605389], 
            Complex[4.04179388930688, -1.958660288701135]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1425725568370115`, -0.6209409489084491}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.0053034199324715`, 0.4947802005841794], 
            Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1425725568370115`, -0.7209409489084496}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[2.8637107663426793`, 0.49478020058417876`], 
            Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609911224902993, -2.284622879275391}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.32438968622985, -1.201502126383065], 
            Complex[7.609911224902993, -2.284622879275391]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609911224902995, -2.384622879275391}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.182797032640057, -1.201502126383065], 
            Complex[7.609911224902995, -2.284622879275391]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623007450776044, -0.07117636000425508}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[9.309288743055875, 1.193135699594645], 
            Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623007450776046, -0.1711763600042553}],
          RowBox[{"{", 
            RowBox[{"34.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.49999999999999, {
            Complex[6.167696089466082, 1.193135699594645], 
            Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.060582226855574, -3.280769407469539}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.09042842494596093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7162445594142677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.060582226855574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1807694074695387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[0.09042842494596093, -1.7162445594142677`], 
            Complex[1.060582226855574, -3.1807694074695387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0605822268555747`, -3.180769407469538}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2320210785357544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7162445594142668`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0605822268555747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.180769407469538`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[3.2320210785357544`, -1.7162445594142668`], 
            Complex[1.0605822268555747`, -3.180769407469538]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.04518125724443, -1.9677307066670984`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[5.852579851369116, -0.6292277131331433], 
            Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.045181257244431, -2.0677307066670987`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.710987197779323, -0.6292277131331433], 
            Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.140277152714267, -0.7104830975830696}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[2.8621480115494466`, 0.503298877159704], 
            Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.140277152714267, -0.6104830975830703}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.003740665139239, 0.5032988771597035], 
            Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60977107194993, -2.3871366280006607`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.182758062802262, -1.2043594268588764`], 
            Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60977107194993, -2.2871366280006615`}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.324350716392056, -1.2043594268588769`], 
            Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623012376610668, -0.06863176520228108}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[9.309291427092525, 1.195990161608288], 
            Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62301237661067, -0.1686317652022815}],
          RowBox[{"{", 
            RowBox[{"34.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.599999999999994`, {
            Complex[6.167698773502733, 1.1959901616082875`], 
            Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0597094912812492`, -3.1827162181699684`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231653364718622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218398`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0597094912812492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1827162181699684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[3.231653364718622, -1.7181436733218398`], 
            Complex[1.0597094912812492`, -3.1827162181699684`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.05970949128125, -3.2827162181699845`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.090060711128834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218531`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.05970949128125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1827162181699844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[0.090060711128834, -1.7181436733218531`], 
            Complex[1.05970949128125, -3.1827162181699844`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.048461912051172, -1.9766512554854916`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[5.854761420740972, -0.637067142498334], 
            Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.048461912051173, -2.076651255485493}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.7131687671511795`, -0.6370671424983351], 
            Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1380862591666565`, -0.6001821017863873}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.0022564620129675`, 0.5116787778163029], 
            Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1380862591666565`, -0.7001821017863883}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[2.860663808423174, 0.5116787778163023], 
            Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609631429922364, -2.3896342483960784`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.182719421945745, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609631429922364, -2.2896342483960783`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.324312075535536, -1.2071994848410685`], 
            Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623017090253322, -0.06610325800154515}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[9.309293987807608, 1.1988273980957402`], 
            Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623017090253322, -0.16610325800154535`}],
          RowBox[{"{", 
            RowBox[{"34.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.699999999999996`, {
            Complex[6.167701334217814, 1.19882739809574], 
            Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.058841028411909, -3.2846554197401803`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08969591052854747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274246`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.058841028411909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.18465541974018`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[0.08969591052854747, -1.7200344142274246`], 
            Complex[1.058841028411909, -3.18465541974018]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0588410284119094`, -3.184655419740182}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.231288564118341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274249`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0588410284119094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.184655419740182`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[3.231288564118341, -1.7200344142274249`], 
            Complex[1.0588410284119094`, -3.184655419740182]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.051642476470394, -1.9854268615885529`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[5.856866656504023, -0.6447767740762016], 
            Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.051642476470395, -2.085426861588554}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.71527400291423, -0.6447767740762022], 
            Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.135993261431996, -0.6900329694879923}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[2.8592528632013723`, 0.5199245263444046], 
            Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.135993261432002, -0.5900329694879913}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.000845516791171, 0.519924526344405], 
            Complex[4.135993261432002, -0.5900329694879913]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609492292129981, -2.3921159401997616`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.1826811049972195`, -1.210022511784006], 
            Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609492292129981, -2.2921159401997615`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.324273758587013, -1.2100225117840062`], 
            Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623021595813277, -0.06359063896214531}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {34.8, {
            Complex[9.309296428167405, 1.201647620337122], 
            Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623021595813279, -0.16359063896214432`}],
          RowBox[{"{", 
            RowBox[{"34.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.8, {
            Complex[6.167703774577614, 1.201647620337123], 
            Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0579767960708073`, -3.1865870786798474`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230926641549791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7219168570985053`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1865870786798474`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[3.230926641549791, -1.7219168570985053`], 
            Complex[1.0579767960708073`, -3.1865870786798474`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0579767960708075`, -3.286587078679847}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0893339879599975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.721916857098505`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0579767960708075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.186587078679847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[0.0893339879599975, -1.721916857098505], 
            Complex[1.0579767960708075`, -3.186587078679847]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.054729003187752, -2.094062261652423}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.717307750554921, -0.6523609855265123], 
            Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.054729003187752, -1.9940622616524237`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.8589004041447135`, -0.6523609855265128], 
            Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.133992114800525, -0.6800308993285684}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[2.857910352423154, 0.5280405519418746], 
            Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.133992114800525, -0.5800308993285693}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[5.999503006012947, 0.528040551941874], 
            Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609353652021759, -2.3945818994320716`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.182643106997762, -1.2128287152203816`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609353652021759, -2.2945818994320715`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.324235760587555, -1.2128287152203814`], 
            Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623025897296652, -0.061093712358079366`}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {34.9, {
            Complex[9.309298751055461, 1.204451035693495], 
            Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623025897296652, -0.1610937123580798}],
          RowBox[{"{", 
            RowBox[{"34.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {34.9, {
            Complex[6.167706097465667, 1.2044510356934945`], 
            Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0571167527110277`, -3.2885112605830047`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08897490881592815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7237910758842274`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0571167527110277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1885112605830046`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[0.08897490881592815, -1.7237910758842274`], 
            Complex[1.0571167527110277`, -3.1885112605830046`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.057116752711029, -3.188511260583004}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2305675624057217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7237910758842263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.057116752711029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.188511260583004`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[3.2305675624057217`, -1.7237910758842263`], 
            Complex[1.057116752711029, -3.188511260583004]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.057727034812087, -2.0025620032062545`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.860867089220406, -0.6598239647344442], 
            Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.057727034812088, -2.102562003206256}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.7192744356306133`, -0.6598239647344449], 
            Complex[4.057727034812088, -2.002562003206256]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.132077284632824, -0.670171279993703}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[2.8566318723517807`, 0.5360310932164641], 
            Complex[4.132077284632824, -0.570171279993703]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1320772846328255`, -0.5701712799937014}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[5.998224525941575, 0.5360310932164654], 
            Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609215503182056, -2.397032318488139}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.182605423099423, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.609215503182056, -2.2970323184881387`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.324198076689216, -1.215618298858686], 
            Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62302999860963, -0.15861228608478187`}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35., {
            Complex[6.167708305685528, 1.2072378477042838`], 
            Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62302999860963, -0.05861228608478186}],
          RowBox[{"{", 
            RowBox[{"35.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35., {
            Complex[9.30930095927532, 1.2072378477042842`], 
            Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.056260857402957, -3.190428030154787}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.230211292644681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7256571435340284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.056260857402957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.190428030154787`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[3.230211292644681, -1.7256571435340284`], 
            Complex[1.056260857402957, -3.190428030154787]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0562608574029573`, -3.290428030154786}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08861863905488769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.725657143534028`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0562608574029573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.190428030154786`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[0.08861863905488769, -1.725657143534028], 
            Complex[1.0562608574029573`, -3.190428030154786]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0606416566544326`, -2.0109304474081906`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.862770761740871, -0.6671697152100744], 
            Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.060641656654434, -2.1109304474081902`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.7211781081510784`, -0.6671697152100743], 
            Complex[4.060641656654434, -2.01093044740819]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.130243693579622, -0.6604496874212127}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[2.8554133945952374`, 0.543900203601609], 
            Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.130243693579622, -0.5604496874212136}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[5.99700604818503, 0.5439002036016083], 
            Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6090778393267975`, -2.2994673862275166`}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.324160702151756, -1.2183914626776438`], 
            Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6090778393267975`, -2.399467386227517}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.182568048561961, -1.218391462677644], 
            Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230339035616055`, -0.1561461715695423}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.1, {
            Complex[6.1677104019634195`, 1.210008256181661], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230339035616055`, -0.0561461715695423}],
          RowBox[{"{", 
            RowBox[{"35.1`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.1, {
            Complex[9.309303055553212, 1.2100082561816605`], 
            Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.055409069822059, -3.2923374512277785`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08826514518945743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.727515132015846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.055409069822059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1923374512277785`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[0.08826514518945743, -1.727515132015846], 
            Complex[1.055409069822059, -3.1923374512277785`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0554090698220604`, -3.1923374512277776`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2298577987792507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.727515132015845`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0554090698220604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1923374512277776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[3.2298577987792507`, -1.727515132015845], 
            Complex[1.0554090698220604`, -3.1923374512277776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.063477543241718, -2.0191717733661467`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.86461513517684, -0.6744020624307271], 
            Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.063477543241718, -2.1191717733661477`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.7230224815870465`, -0.6744020624307276], 
            Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.128486675066932, -0.6508618804640703}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[2.854251227099731, 0.5516517577146821], 
            Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.128486675066932, -0.5508618804640709}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[5.995843880689525, 0.5516517577146818], 
            Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608940654299824, -2.401887288061049}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.1825309787497025`, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.301887288061049]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608940654299824, -2.3018872880610495`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.324123632339496, -1.2211484030177213`], 
            Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623037615868166, -0.15369518368470475`}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[6.167712388950775, 1.2127624573020033`], 
            Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623037615868166, -0.05369518368470496}],
          RowBox[{"{", 
            RowBox[{"35.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.199999999999996`, {
            Complex[9.309305042540569, 1.212762457302003], 
            Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0545613502369584`, -3.2942395867779743`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08791439427478234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[0.08791439427478234, -1.7293651123339018`], 
            Complex[1.0545613502369584`, -3.1942395867779743`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0545613502369586`, -3.1942395867779743`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2295070478645758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0545613502369586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[3.2295070478645758`, -1.7293651123339018`], 
            Complex[1.0545613502369586`, -3.1942395867779743`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.066238999377148, -2.0272899835297697`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.86640362080727, -0.6815246607732995], 
            Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.066238999377148, -2.1272899835297707`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.724810967217476, -0.6815246607732999], 
            Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.126801932234572, -0.6414037954825226}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[2.8531419798044717`, 0.5592894583048513], 
            Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.126801932234575, -0.5414037954825208}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[5.994734633394268, 0.5592894583048527], 
            Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608803942069354, -2.3042922060350675`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.324086862718293, -1.2238893126698196`], 
            Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608803942069356, -2.4042922060350675`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.1824942091285005`, -1.2238893126698194`], 
            Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623041139153993, -0.1512591406635367}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.3, {
            Complex[6.167714269226694, 1.2155006436945395`], 
            Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623041139153995, -0.051259140663536505`}],
          RowBox[{"{", 
            RowBox[{"35.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.3, {
            Complex[9.30930692281649, 1.2155006436945397`], 
            Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0537176594978057`, -3.296134498940378}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08756635389739194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.73120715454608`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1961344989403777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[0.08756635389739194, -1.73120715454608], 
            Complex[1.0537176594978057`, -3.1961344989403777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0537176594978062`, -3.196134498940377}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.229159007487185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7312071545460794`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0537176594978062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.196134498940377`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[3.229159007487185, -1.7312071545460794`], 
            Complex[1.0537176594978062`, -3.196134498940377]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.06892999644998, -2.0352889097939633`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.868139358018381, -0.6885410007735715], 
            Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.06892999644998, -2.135288909793964}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.7265467044285883`, -0.6885410007735716], 
            Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.125185501625341, -0.5320715402250115}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[5.993675187934443, 0.5668168435275391], 
            Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.125185501625341, -0.6320715402250119}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[2.852082534344649, 0.5668168435275388], 
            Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608667696724579, -2.40668231891301}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.182457735262816, -1.2266143809612575`], 
            Complex[7.608667696724579, -2.30668231891301]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608667696724579, -2.3066823189130106`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.32405038885261, -1.2266143809612582`], 
            Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623044476955635, -0.048837864018669234`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.4, {
            Complex[9.309308698890094, 1.2182230045272866`], 
            Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623044476955637, -0.14883786401866902`}],
          RowBox[{"{", 
            RowBox[{"35.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.4, {
            Complex[6.167716045300302, 1.2182230045272868`], 
            Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0528779590249415`, -3.2980222490242426`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08722099216430315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.733041327780913`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0528779590249415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1980222490242425`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[0.08722099216430315, -1.733041327780913], 
            Complex[1.0528779590249415`, -3.1980222490242425`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.052877959024942, -3.1980222490242434`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228813645754096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7330413277809138`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052877959024942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1980222490242434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[3.228813645754096, -1.7330413277809138`], 
            Complex[1.052877959024942, -3.1980222490242434`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.071554204602269, -2.043172220042138}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.869825241082359, -0.6954544165180526], 
            Complex[4.071554204602269, -2.043172220042138]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.07155420460227, -2.1431722200421386`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.7282325874925664`, -0.6954544165180527], 
            Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.123633721017262, -0.6228613872697347}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[2.8510700172747567`, 0.5742372943510567], 
            Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.123633721017264, -0.5228613872697351}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[5.992662670864552, 0.5742372943510564], 
            Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608531912472353, -2.4090578022545657`}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.1824215528129, -1.229323793839144], 
            Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608531912472354, -2.309057802254565}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.324014206402694, -1.2293237938391435`], 
            Complex[7.608531912472354, -2.309057802254565]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230476327242, -0.1464311784630232}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[6.167717719612997, 1.2209297255903704`], 
            Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623047632724201, -0.0464311784630234}],
          RowBox[{"{", 
            RowBox[{"35.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.49999999999999, {
            Complex[9.309310373202791, 1.2209297255903702`], 
            Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0520422107978245`, -3.299902897527961}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.086878277692393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0520422107978245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.199902897527961`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[0.086878277692393, -1.7348677002541821`], 
            Complex[1.0520422107978245`, -3.199902897527961]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.052042210797825, -3.1999028975279598`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.228470931282186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.052042210797825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1999028975279598`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[3.228470931282186, -1.7348677002541815`], 
            Complex[1.052042210797825, -3.1999028975279598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.074115021277763, -2.1509434249247765`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.729871289280439, -0.7022680930260651], 
            Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.074115021277763, -2.0509434249247764`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.871463942870232, -0.7022680930260652], 
            Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.122143200873719, -0.6137697672312343}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[2.850101776357696, 0.5815540419531228], 
            Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.12214320087372, -0.5137697672312349}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[5.991694429947489, 0.5815540419531224], 
            Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608396583634034, -2.4114188284924203`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.182385657532068, -1.2320177339512255`], 
            Complex[7.608396583634034, -2.31141882849242]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608396583634034, -2.311418828492422}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.323978311121861, -1.232017733951227], 
            Complex[7.608396583634034, -2.311418828492422]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623050609827915, -0.14403891183312117`}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[6.167719294540649, 1.2236209893768326`], 
            Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62305060982792, -0.04403891183311752}],
          RowBox[{"{", 
            RowBox[{"35.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.599999999999994`, {
            Complex[9.309311948130448, 1.2236209893768368`], 
            Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0512103773442263`, -3.301776504153616}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08653817959803752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7366863392851428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153616`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[0.08653817959803752, -1.7366863392851428`], 
            Complex[1.0512103773442263`, -3.201776504153616]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0512103773442272`, -3.201776504153611}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2281308331878296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.736686339285139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0512103773442272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153611`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[3.2281308331878296`, -1.736686339285139], 
            Complex[1.0512103773442272`, -3.201776504153611]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.076615596606935, -2.158605884720824}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.7314652823007664`, -0.7089850735194753], 
            Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.076615596606936, -2.0586058847208237`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.87305793589056, -0.7089850735194753], 
            Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.120710798957501, -0.5047932618845052}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[5.990768013117869, 0.588770175004682], 
            Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.120710798957502, -0.6047932618845051}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[2.8491753595280755`, 0.5887701750046822], 
            Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608261704642392, -2.413765567006709}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.182350045264077, -1.2346963807243223`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608261704642392, -2.3137655670067088`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.323942698853871, -1.2346963807243225`], 
            Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623053411554656, -0.041660895014681676`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[9.30931342598549, 1.2262969751610369`], 
            Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623053411554656, -0.14166089501468188`}],
          RowBox[{"{", 
            RowBox[{"35.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.699999999999996`, {
            Complex[6.167720772395696, 1.2262969751610366`], 
            Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0503824217296986`, -3.3036431278211884`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08620066748699956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123776`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[0.08620066748699956, -1.7384973113123776`], 
            Complex[1.0503824217296986`, -3.2036431278211883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0503824217296989`, -3.2036431278211888`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227793321076793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123774`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0503824217296989`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211888`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[3.227793321076793, -1.7384973113123774`], 
            Complex[1.0503824217296989`, -3.2036431278211888`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.079058856020895, -2.1661628161692956`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.733016857401756, -0.7156082665076033], 
            Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.079058856020895, -2.0661628161692955`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.874609510991549, -0.7156082665076038], 
            Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1193335977160075`, -0.49592859731920275`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[5.98988114978185, 0.5958886467685789], 
            Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1193335977160075`, -0.5959285973192032}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[2.848288496192057, 0.5958886467685786], 
            Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608127270038639, -2.3160981841972186`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.323907365530383, -1.2373599104403945`], 
            Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.608127270038645, -2.4160981841972364`}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.182314711940597, -1.2373599104404132`], 
            Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623056041114284, -0.03929696187048912}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.8, {
            Complex[9.309314809018922, 1.2289578590746733`], 
            Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623056041114285, -0.1392969618704885}],
          RowBox[{"{", 
            RowBox[{"35.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.8, {
            Complex[6.16772215542913, 1.2289578590746735`], 
            Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0495583075472772`, -3.20550282668249}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227458365034377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093283`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.20550282668249`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[3.227458365034377, -1.7403006819093283`], 
            Complex[1.0495583075472772`, -3.20550282668249]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0495583075472783`, -3.3055028266824884`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08586571144458416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093272`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0495583075472783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2055028266824883`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[0.08586571144458416, -1.7403006819093272`], 
            Complex[1.0495583075472783`, -3.2055028266824883`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.081447520434107, -2.0736172991891597`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.876120794018037, -0.7221404526376908], 
            Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.081447520434109, -2.1736172991891602`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.734528140428245, -0.7221404526376912], 
            Complex[4.081447520434109, -2.07361729918916]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.118008884097688, -0.5871726372059103}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[2.847439080572326, 0.6029122819634529], 
            Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.118008884097689, -0.4871726372059098}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[5.989031734162119, 0.6029122819634535], 
            Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6079932744696, -2.4184168435535707`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.182279653578758, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6079932744696, -2.3184168435535706`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.323872307168552, -1.2400084963104758`], 
            Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623058501641021, -0.13694694917032468`}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.9, {
            Complex[6.167723445832482, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623058501641021, -0.03694694917032467}],
          RowBox[{"{", 
            RowBox[{"35.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {35.9, {
            Complex[9.309316099422276, 1.2316038141805976`], 
            Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0487379989074426`, -3.307355658134716}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08553328202600917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.742096515799434`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[0.08553328202600917, -1.742096515799434], 
            Complex[1.0487379989074426`, -3.207355658134716]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0487379989074426`, -3.207355658134717}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.227125935615802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7420965157994346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134717`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[3.227125935615802, -1.7420965157994346`], 
            Complex[1.0487379989074426`, -3.207355658134717]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.083784124290591, -2.0809722834290376`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.877593760675199, -0.7285842912785059], 
            Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0837841242905935`, -2.1809722834290373`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.736001107085408, -0.7285842912785057], 
            Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.116734131505034, -0.5785223762328967}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[2.8466251568463186`, 0.6098437833604624], 
            Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.116734131505035, -0.4785223762328954}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[5.988217810436113, 0.6098437833604634], 
            Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607859712684855, -2.4207217057230572`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.182244866278791, -1.242642308546148], 
            Complex[7.607859712684855, -2.320721705723057]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607859712684855, -2.320721705723063}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.323837519868585, -1.242642308546154], 
            Complex[7.607859712684855, -2.320721705723063]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623060796195637, -0.13461069652302135`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[6.167724645739662, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623060796195637, -0.034610696523021345`}],
          RowBox[{"{", 
            RowBox[{"35.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {35.99999999999999, {
            Complex[9.309317299329457, 1.2342350105444317`], 
            Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0479214604283111`, -3.209201678833752}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2267960038368266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7438848768709785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[3.2267960038368266`, -1.7438848768709785`], 
            Complex[1.0479214604283111`, -3.209201678833752]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0479214604283116`, -3.309201678833752}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08520335024703361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7438848768709778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0479214604283116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[0.08520335024703361, -1.7438848768709778`], 
            Complex[1.0479214604283116`, -3.209201678833752]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.086071031729207, -2.0882305946062263`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.879030249816931, -0.7349423268176076], 
            Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.086071031729208, -2.1882305946062273`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.7374375962271382`, -0.7349423268176083], 
            Complex[4.086071031729208, -2.088230594606227]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.115506983628505, -0.46997493375384003`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[5.987437559449537, 0.616685738093365], 
            Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.115506983628505, -0.5699749337538403}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[2.845844905859744, 0.6166857380933649], 
            Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607726579534131, -2.32301292857686}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.323802999811543, -1.2452615144292978`], 
            Complex[7.607726579534131, -2.32301292857686]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607726579534131, -2.4230129285768607`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.1822103462217495`, -1.245261514429298], 
            Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230629277676165`, -0.13228804631047783`}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[6.167725757228776, 1.2368516153041005`], 
            Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230629277676165`, -0.03228804631048309}],
          RowBox[{"{", 
            RowBox[{"36.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.099999999999994`, {
            Complex[9.30931841081857, 1.2368516153040952`], 
            Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.047108657226064, -3.3110409447071545`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08487588757480041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7456658281915818`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.047108657226064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[0.08487588757480041, -1.7456658281915818`], 
            Complex[1.047108657226064, -3.2110409447071544`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0471086572260642`, -3.2110409447071544`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2264685411645937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7456658281915811`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0471086572260642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[3.2264685411645937`, -1.7456658281915811`], 
            Complex[1.0471086572260642`, -3.2110409447071544`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0883104510902495`, -2.095394940608318}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.880431975347877, -0.7412169946624547], 
            Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.088310451090251, -2.195394940608318}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.7388393217580846`, -0.7412169946624545], 
            Complex[4.088310451090251, -2.095394940608318]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.114325239939221, -0.5615275476732827}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[2.8450966332264747`, 0.6234406236721284], 
            Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.114325239939222, -0.46152754767328286`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[5.986689286816269, 0.6234406236721282], 
            Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607593869964685, -2.32529066727406}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.3237687432571, -1.2478662783795624`], 
            Complex[7.607593869964685, -2.32529066727406]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607593869964685, -2.425290667274061}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.182176089667306, -1.2478662783795629`], 
            Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623064899277237, -0.12997884362362547`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[6.16772678232385, 1.2394537927373115`], 
            Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623064899277239, -0.029978843623626066`}],
          RowBox[{"{", 
            RowBox[{"36.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.199999999999996`, {
            Complex[9.309319435913645, 1.2394537927373108`], 
            Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0462995549055958`, -3.212873510966856}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.226143519508699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747439432022393`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0462995549055958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.212873510966856`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[3.226143519508699, -1.747439432022393], 
            Complex[1.0462995549055958`, -3.212873510966856]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.046299554905596, -3.3128735109668557`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08455086591890591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474394320223927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.046299554905596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2128735109668556`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[0.08455086591890591, -1.7474394320223927`], 
            Complex[1.046299554905596, -3.2128735109668556`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090504447956572, -2.2024679173410124`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.7402078833132797`, -0.7474106269426312], 
            Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090504447956573, -2.1024679173410123`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.881800536903074, -0.7474106269426314], 
            Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.113186842647121, -0.5531775685861368}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[2.8443787586507785`, 0.6301108136973931], 
            Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.113186842647122, -0.4531775685861346}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[5.985971412240573, 0.6301108136973947], 
            Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60746157901877, -2.4275550743239185`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.182142092951617, -1.2504567620199438`], 
            Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607461579018771, -2.327555074323918}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.323734746541412, -1.2504567620199438`], 
            Complex[7.607461579018771, -2.327555074323918]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62306671357756, -0.027682936200179965`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.3, {
            Complex[9.309320376586301, 1.2420417043271583`], 
            Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62306671357756, -0.12768293620018037`}],
          RowBox[{"{", 
            RowBox[{"36.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.3, {
            Complex[6.167727722996508, 1.2420417043271579`], 
            Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0454941195513836`, -3.3146994321215857`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0842282576226818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7492057498319649`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0454941195513836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2146994321215856`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[0.0842282576226818, -1.7492057498319649`], 
            Complex[1.0454941195513836`, -3.2146994321215856`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.045494119551384, -3.2146994321215847`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225820911212475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7492057498319644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.045494119551384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2146994321215847`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[3.225820911212475, -1.7492057498319644`], 
            Complex[1.045494119551384, -3.2146994321215847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.092654956897793, -2.209452014313655}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.7415447758580713`, -0.7535254579157126], 
            Complex[4.092654956897793, -2.109452014313655]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0926549568977935`, -2.109452014313655}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.883137429447864, -0.7535254579157123], 
            Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.112089864956078, -0.4449224541797798}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[5.985282459919064, 0.6366985832782691], 
            Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.112089864956078, -0.5449224541797805}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[2.843689806329271, 0.6366985832782687], 
            Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607329701831238, -2.42980629964634}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.182108352485272, -1.2530331242405153`], 
            Complex[7.607329701831238, -2.32980629964634]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607329701831238, -2.32980629964634}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.323701006075066, -1.253033124240515], 
            Complex[7.607329701831238, -2.32980629964634]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623068373456371, -0.02540017436427072}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.4, {
            Complex[9.309321234757373, 1.2446155088257416`], 
            Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623068373456371, -0.12540017436427114`}],
          RowBox[{"{", 
            RowBox[{"36.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.4, {
            Complex[6.16772858116758, 1.2446155088257413`], 
            Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0446923177185725`, -3.3165187619890237`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08390803545469033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7509648423098307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[0.08390803545469033, -1.7509648423098307`], 
            Complex[1.0446923177185725`, -3.2165187619890236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0446923177185734`, -3.2165187619890245`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.225500689044484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.750964842309831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0446923177185734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890245`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[3.225500689044484, -1.750964842309831], 
            Complex[1.0446923177185734`, -3.2165187619890245`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094763792064631, -2.1163496199598395`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.884444051922338, -0.7595636290829754], 
            Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094763792064631, -2.21634961995984}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.742851398332544, -0.7595636290829759], 
            Complex[4.094763792064631, -2.11634961995984]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.111032500468935, -0.5367597639013432}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[2.8430283963083336`, 0.6432061141597183], 
            Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.111032500468935, -0.4367597639013438}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[5.984621049898127, 0.643206114159718], 
            Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607198233627162, -2.332044490630609}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.323667518341093, -1.255595521260306], 
            Complex[7.607198233627162, -2.332044490630609]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607198233627164, -2.4320444906306093`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.182074864751301, -1.2555955212603063`], 
            Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623069881638044, -0.12313041096773103`}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.5, {
            Complex[6.167729358708656, 1.247175362316046], 
            Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623069881638048, -0.02313041096773061}],
          RowBox[{"{", 
            RowBox[{"36.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.5, {
            Complex[9.30932201229845, 1.247175362316046], 
            Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0438941164242617`, -3.318331553707678}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0835901726004175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.752716769379781`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.218331553707678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[0.0835901726004175, -1.752716769379781], 
            Complex[1.0438941164242617`, -3.218331553707678]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0438941164242628`, -3.2183315537076793`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2251828261902116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7527167693797805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0438941164242628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2183315537076793`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[3.2251828261902116`, -1.7527167693797805`], 
            Complex[1.0438941164242628`, -3.2183315537076793`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.096832656761998, -2.2231630266947917`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.744129061448893, -0.7655271940238008], 
            Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.096832656761998, -2.123163026694792}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.885721715038686, -0.7655271940238007], 
            Complex[4.096832656761998, -2.123163026694792]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.110013053613793, -0.42868715388848116`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[5.983985890278379, 0.6496354995683528], 
            Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.110013053613794, -0.5286871538884808}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[2.842393236688587, 0.6496354995683534], 
            Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607067169719584, -2.4342697921924636`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.182041626303249, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.607067169719584, -2.3342697921924636`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.323634279893042, -1.2581441066874384`], 
            Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307124078535, -0.020873501333080847`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.6, {
            Complex[9.309322711033374, 1.2497214182720298`], 
            Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623071240785351, -0.12087350133307964`}],
          RowBox[{"{", 
            RowBox[{"36.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.6, {
            Complex[6.167730057443585, 1.249721418272031], 
            Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.04309948313899, -3.3201378597485256`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08327464265416494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.04309948313899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2201378597485255`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[0.08327464265416494, -1.7544615902128715`], 
            Complex[1.04309948313899, -3.2201378597485255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0430994831389901`, -3.2201378597485246`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.224867296243958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0430994831389901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2201378597485246`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[3.224867296243958, -1.7544615902128715`], 
            Complex[1.0430994831389901`, -3.2201378597485246`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.098863152113465, -2.229894435714409}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.745378994736478, -0.7714181229593412], 
            Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.098863152113465, -2.1298944357144114`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.886971648326271, -0.7714181229593432], 
            Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.109029930978956, -0.5207023721587466}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[2.8417831165816425`, 0.6559887487872518], 
            Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.109029930978956, -0.4207023721587472}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[5.983375770171436, 0.655988748787251], 
            Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6069365055072815`, -2.4364823468295485`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.182008633763318, -1.260679031577555], 
            Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6069365055072815`, -2.3364823468295493`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.323601287353112, -1.2606790315775551`], 
            Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623072453501178, -0.1186293031981204}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[6.167730679149904, 1.2522538276170248`], 
            Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623072453501181, -0.018629303198118775`}],
          RowBox[{"{", 
            RowBox[{"36.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.699999999999996`, {
            Complex[9.309323332739702, 1.2522538276170265`], 
            Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0423083857784268`, -3.2219377319263685`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2245540732009284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561993632401343`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263685`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[3.2245540732009284`, -1.7561993632401343`], 
            Complex[1.0423083857784268`, -3.2219377319263685`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0423083857784274`, -3.3219377319263677`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08296141961113473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561993632401347`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0423083857784274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263676`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[0.08296141961113473, -1.7561993632401347`], 
            Complex[1.0423083857784274`, -3.2219377319263676`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100856784915977, -2.236545961543077}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.746602352917594, -0.7772383070571701], 
            Complex[4.100856784915977, -2.136545961543077]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100856784915978, -2.136545961543077}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.888195006507387, -0.7772383070571703], 
            Complex[4.100856784915978, -2.136545961543077]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.108081633457668, -0.5128032540504381}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[2.8411968997361448`, 0.6622677914714884], 
            Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.10808163345767, -0.41280325405043844`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[5.982789553325939, 0.6622677914714878], 
            Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606806236472662, -2.3386822946753205`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.323568537410361, -1.2632004444906193`], 
            Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606806236472662, -2.4386822946753215`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.181975883820568, -1.2632004444906197`], 
            Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623073522330233, -0.016397676662069878`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[9.309323879150051, 1.254772738780499], 
            Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623073522330235, -0.11639767666206947`}],
          RowBox[{"{", 
            RowBox[{"36.79999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.79999999999999, {
            Complex[6.167731225560259, 1.2547727387804994`], 
            Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0415207926952421`, -3.323731221410986}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08265047785970185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7579301461650303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.223731221410986`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[0.08265047785970185, -1.7579301461650303`], 
            Complex[1.0415207926952421`, -3.223731221410986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0415207926952428`, -3.2237312214109846`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2242431314494953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7579301461650294`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0415207926952428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2237312214109846`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[3.2242431314494953`, -1.7579301461650294`], 
            Complex[1.0415207926952428`, -3.2237312214109846`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.102814974771636, -2.243119636338954}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.7478002216867257`, -0.7829895624892164], 
            Complex[4.102814974771636, -2.143119636338954]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.102814974771636, -2.143119636338955}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.88939287527652, -0.782989562489217], 
            Complex[4.102814974771636, -2.143119636338955]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1071667491158, -0.4049877179062303}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[5.982226172350083, 0.6684744817167128], 
            Complex[4.1071667491158, -0.4049877179062303]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.107166749115801, -0.5049877179062305}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[2.8406335187602902`, 0.6684744817167128], 
            Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606676358179671, -2.340869773551443}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.323536026818966, -1.2657084915461236`], 
            Complex[7.606676358179671, -2.340869773551443]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606676358179671, -2.4408697735514435`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.1819433732291715`, -1.2657084915461239`], 
            Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623074449760662, -0.1141784841332231}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[6.167731698363721, 1.2572782977532326`], 
            Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623074449760668, -0.014178484133219656`}],
          RowBox[{"{", 
            RowBox[{"36.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.89999999999999, {
            Complex[9.309324351953519, 1.2572782977532362`], 
            Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0407366726711678`, -3.325518378738005}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08234179217386196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.759653995975626`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738005`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[0.08234179217386196, -1.759653995975626], 
            Complex[1.0407366726711678`, -3.225518378738005]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0407366726711693`, -3.225518378738008}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223934445763656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7596539959756308`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0407366726711693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738008`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[3.223934445763656, -1.7596539959756308`], 
            Complex[1.0407366726711693`, -3.225518378738008]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.104739060573037, -2.249617413966406}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.748973622957287, -0.7886736342555815], 
            Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.104739060573037, -2.149617413966407}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.89056627654708, -0.7886736342555825], 
            Complex[4.104739060573037, -2.149617413966407]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1062839467060055`, -0.3972537609898815}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[5.981684623466656, 0.6746106018933713], 
            Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.106283946706008, -0.4972537609898835}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[2.8400919698768647`, 0.6746106018933697], 
            Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606546866271806, -2.443044919018727}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.181911098806735, -1.2682033164767692`], 
            Complex[7.606546866271806, -2.343044919018727]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60654686627181, -2.343044919018725}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.323503752396531, -1.2682033164767677`], 
            Complex[7.60654686627181, -2.343044919018725]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307523822561, -0.1119715902780481}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[6.167732099207092, 1.2597706481409663`], 
            Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623075238225624, -0.01197159027804566}],
          RowBox[{"{", 
            RowBox[{"36.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {36.99999999999999, {
            Complex[9.309324752796902, 1.2597706481409692`], 
            Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0399559949092405`, -3.327299253819592}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08203533770586706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7613709689565493`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[0.08203533770586706, -1.7613709689565493`], 
            Complex[1.0399559949092405`, -3.227299253819592]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0399559949092407`, -3.227299253819592}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2236279912956602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7613709689565495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0399559949092407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[3.2236279912956602`, -1.7613709689565495`], 
            Complex[1.0399559949092407`, -3.227299253819592]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.105431969760929, -0.3895994556256985}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.981163961744247, 0.6806778662591632], 
            Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.10543196976093, -0.4895994556256973}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.8395713081544542`, 0.6806778662591643], 
            Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1066303064095715`, -2.156041173845927}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[5.891716173221934, -0.7942921997868306], 
            Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.106630306409572, -2.256041173845927}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[2.750123519632142, -0.794292199786831], 
            Complex[4.106630306409572, -2.156041173845927]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606417756470162, -2.345207864426671}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.323471711022448, -1.2706850606806674`], 
            Complex[7.606417756470162, -2.345207864426671]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606417756470163, -2.445207864426671}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.1818790574326545`, -1.2706850606806677`], 
            Complex[7.606417756470163, -2.345207864426671]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623075890104745, -0.10977686197169398`}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[6.167732429696165, 1.2622499312165703`], 
            Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623075890104745, -0.009776861971693968}],
          RowBox[{"{", 
            RowBox[{"37.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.099999999999994`, {
            Complex[9.309325083285957, 1.26224993121657], 
            Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.039178729026203, -3.329073895954844}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0817310899790139`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.763081120700618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2290738959548437`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[0.0817310899790139, -1.763081120700618], 
            Complex[1.039178729026203, -3.2290738959548437`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.039178729026203, -3.229073895954844}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.223323743568807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7630811207006185`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.229073895954844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[3.223323743568807, -1.7630811207006185`], 
            Complex[1.039178729026203, -3.229073895954844]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.104609631205909, -0.3820229455501256}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.980663296755008, 0.6866779243621381], 
            Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.10460963120591, -0.4820229455501247}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.839070643165216, 0.6866779243621389], 
            Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.108489906954296, -2.2623927245921425`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[2.751250819947598, -0.7998468723371362], 
            Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.108489906954296, -2.1623927245921415`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[5.892843473537392, -0.7998468723371351], 
            Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606289024571562, -2.4473587409616404`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.181847246046556, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606289024571562, -2.3473587409616403`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.323439899636348, -1.273153863272108], 
            Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623076407725729, -0.10759416824985354`}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[6.167732691396911, 1.2647162859707828`], 
            Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623076407725729, -0.007594168249853738}],
          RowBox[{"{", 
            RowBox[{"37.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.199999999999996`, {
            Complex[9.309325344986703, 1.2647162859707826`], 
            Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0384048450451053`, -3.230842353840041}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2230216784704147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7647845061203178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840041`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[3.2230216784704147`, -1.7647845061203178`], 
            Complex[1.0384048450451053`, -3.230842353840041]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0384048450451058`, -3.330842353840039}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08142902488062087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7647845061203167`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0384048450451058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840039`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[0.08142902488062087, -1.7647845061203167`], 
            Complex[1.0384048450451058`, -3.230842353840039]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.103815808438448, -0.37452244246479277`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.980181788615051, 0.6926123642464803], 
            Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.103815808438448, -0.4745224424647926}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.838589135025258, 0.6926123642464805], 
            Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.11031899238399, -2.268673807450607}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[2.7523563814347085`, -0.8053392041803537], 
            Complex[4.11031899238399, -2.168673807450607]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1103189923839905`, -2.1686738074506064`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[5.893949035024502, -0.8053392041803533], 
            Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606160666446714, -2.449497677693729}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.181815661646743, -1.275609861130944], 
            Complex[7.606160666446714, -2.349497677693729]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60616066644672, -2.349497677693727}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.323408315236543, -1.2756098611309419`], 
            Complex[7.60616066644672, -2.349497677693727]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307679336563, -0.005423380261944406}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.3, {
            Complex[9.30932553942646, 1.2671698491615646`], 
            Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307679336563, -0.10542338026194462`}],
          RowBox[{"{", 
            RowBox[{"37.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.3, {
            Complex[6.167732885836667, 1.2671698491615644`], 
            Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0376343133880408`, -3.2326046755786235`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222721772244943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589748`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[3.222721772244943, -1.7664811794589748`], 
            Complex[1.0376343133880408`, -3.2326046755786235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0376343133880443`, -3.3326046755786214`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08112911865515363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589725`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0376343133880443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786213`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[0.08112911865515363, -1.7664811794589725`], 
            Complex[1.0376343133880443`, -3.2326046755786213`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1030494388277985`, -0.3670962227803727}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.979718644368703, 0.6984827154726538], 
            Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.103049438827799, -0.46709622278037277`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.8381259907789103`, 0.6984827154726537], 
            Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.112118632879191, -2.1748860995439667`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[5.8950336681265165`, -0.8107706896206487], 
            Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.112118632879193, -2.2748860995439673`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[2.7534410145367234`, -0.8107706896206492], 
            Complex[4.112118632879193, -2.174886099543967]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606032678038458, -2.451624801622354}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.1817843012887375`, -1.2780531889506415`], 
            Complex[7.606032678038458, -2.351624801622354]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.606032678038458, -2.351624801622354}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.323376954878531, -1.2780531889506412`], 
            Complex[7.606032678038458, -2.351624801622354]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077049252293, -0.10326437122555437`}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.4, {
            Complex[6.167733014505244, 1.2696107553621172`], 
            Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077049252295, -0.003264371225554161}],
          RowBox[{"{", 
            RowBox[{"37.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.4, {
            Complex[9.309325668095038, 1.2696107553621176`], 
            Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0368671048690645`, -3.3343609086909947`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08083134789749542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2343609086909946`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[0.08083134789749542, -1.7681711943017286`], 
            Complex[1.0368671048690645`, -3.2343609086909946`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0368671048690654`, -3.234360908690994}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.222424001487289`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0368671048690654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.234360908690994`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[3.222424001487289, -1.7681711943017286`], 
            Complex[1.0368671048690654`, -3.234360908690994]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.102309515593154, -0.45974262454091697`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.8376804610924062`, 0.7042904519630285], 
            Complex[4.102309515593154, -0.359742624540917]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.102309515593163, -0.3597426245409141}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.979273114682207, 0.7042904519630309], 
            Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.113889842745602, -2.2810312169378864`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[2.7545054859170786`, -0.8161427678288303], 
            Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1138898427456025`, -2.181031216937888}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[5.896098139506871, -0.8161427678288314], 
            Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605905055360047, -2.4537402377206172`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.181753162083825, -1.2804839792850273`], 
            Complex[7.605905055360047, -2.353740237720617]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605905055360047, -2.3537402377206176`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.323345815673619, -1.2804839792850278`], 
            Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077177565682, -0.0011170163821173382`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.5, {
            Complex[9.309325732445826, 1.2720391370076072`], 
            Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077177565682, -0.10111701638211774`}],
          RowBox[{"{", 
            RowBox[{"37.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.5, {
            Complex[6.167733078856032, 1.272039137007607], 
            Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0361031906872573`, -3.3361111001240946`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08053568954642111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7698546035862615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[0.08053568954642111, -1.7698546035862615`], 
            Complex[1.0361031906872573`, -3.2361111001240945`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0361031906872582`, -3.2361111001240945`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2221283431362147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.769854603586262`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0361031906872582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[3.2221283431362147`, -1.769854603586262], 
            Complex[1.0361031906872582`, -3.2361111001240945`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.101595084023627, -0.35246004451858104`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.978844490816281, 0.7100369946836335], 
            Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.101595084023627, -0.4524600445185817}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.8372518372264883`, 0.710036994683633], 
            Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.115633584193734, -2.187110717536775}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[5.897143175078252, -0.8214568255150104], 
            Complex[4.115633584193734, -2.187110717536775]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.115633584193734, -2.2871107175367755`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[2.7555505214884586`, -0.8214568255150109], 
            Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605777794493471, -2.355844108978483}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.32331489478747, -1.282902362593793], 
            Complex[7.605777794493471, -2.355844108978483]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605777794493473, -2.455844108978483}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.181722241197679, -1.2829023625937932`], 
            Complex[7.605777794493473, -2.355844108978483]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077180439138, 0.0010188070462170521`}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.6, {
            Complex[9.309325733896824, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623077180439138, -0.09898119295378276}],
          RowBox[{"{", 
            RowBox[{"37.6`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.6, {
            Complex[6.1677330803070305`, 1.2744551244406346`], 
            Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0353425424199532`, -3.3378552962607935`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.08024212087815223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133194`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[0.08024212087815223, -1.7715314596133194`], 
            Complex[1.0353425424199532`, -3.2378552962607934`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0353425424199543`, -3.2378552962607934`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.221834774467946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133196`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0353425424199543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[3.221834774467946, -1.7715314596133196`], 
            Complex[1.0353425424199543`, -3.2378552962607934`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100905238007176, -0.44524693546904015`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.836839448260752, 0.7157237141721116], 
            Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100905238007176, -0.34524693546904034`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.9784321018505455`, 0.7157237141721113], 
            Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.117350770809639, -2.293126103819013}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[2.7565768091900997`, -0.8267141994476596], 
            Complex[4.117350770809639, -2.193126103819013]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.11735077080964, -2.193126103819013}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[5.898169462779893, -0.8267141994476594], 
            Complex[4.11735077080964, -2.193126103819013]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605650891587858, -2.357936536444798}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.323284189438796, -1.2853084672867803`], 
            Complex[7.605650891587858, -2.357936536444798]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605650891587861, -2.4579365364447976`}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.181691535849006, -1.2853084672867796`], 
            Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307705996065, -0.09685678010142817}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.7, {
            Complex[6.167733020241881, 1.276858845955496], 
            Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307705996065, 0.003143219898572241}],
          RowBox[{"{", 
            RowBox[{"37.7`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.7, {
            Complex[9.309325673831674, 1.2768588459554961`], 
            Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.034585132016095, -3.339593542929082}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07995061950010503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.773201814057012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.034585132016095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.239593542929082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[0.07995061950010503, -1.773201814057012], 
            Complex[1.034585132016095, -3.239593542929082]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0345851320160955`, -3.2395935429290827`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2215432730898983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7732018140570123`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0345851320160955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2395935429290827`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[3.2215432730898983`, -1.7732018140570123`], 
            Complex[1.0345851320160955`, -3.2395935429290827`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100239116839224, -0.43810180353832096`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.8364426585455744`, 0.7213519329214126], 
            Complex[4.100239116839224, -0.338101803538321]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.100239116839226, -0.3381018035383217}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.978035312135368, 0.7213519329214122], 
            Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.119042270745964, -2.199078825420971}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[5.899177655127286, -0.8319161788285983], 
            Complex[4.119042270745964, -2.199078825420971]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.119042270745964, -2.299078825420972}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[2.7575850015374925`, -0.8319161788285991], 
            Complex[4.119042270745964, -2.199078825420972]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60552434285789, -2.4600176392681967`}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.181661043308228, -1.2877024197670905`], 
            Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60552434285789, -2.360017639268197}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.323253696898021, -1.2877024197670908`], 
            Complex[7.60552434285789, -2.360017639268197]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307681817404, -0.09474365888378924}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.8, {
            Complex[6.1677329000108365`, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307681817404, 0.005256341116210763}],
          RowBox[{"{", 
            RowBox[{"37.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.8, {
            Complex[9.30932555360063, 1.2792504278412689`], 
            Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0338309317897683`, -3.24132588541108}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2212538169345617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749052`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.24132588541108`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[3.2212538169345617`, -1.7748657179749052`], 
            Complex[1.0338309317897683`, -3.24132588541108]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0338309317897687`, -3.3413258854110794`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0796611633447683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749043`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0338309317897687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2413258854110794`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[0.0796611633447683, -1.7748657179749043`], 
            Complex[1.0338309317897687`, -3.2413258854110794`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.099595902284807, -0.33102320581219813`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.977653518949829, 0.7269229276281969], 
            Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.099595902284807, -0.43102320581219855`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.836060865360036, 0.7269229276281965], 
            Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.120708909659479, -2.3049702815786572`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[2.7585757179660733`, -0.8370640075328957], 
            Complex[4.120708909659479, -2.204970281578657]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.120708909659479, -2.204970281578657}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[5.900168371555867, -0.8370640075328958], 
            Complex[4.120708909659479, -2.204970281578657]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605398144582298, -2.3620875347369377`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.32322341448604, -1.2900843444730699`], 
            Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605398144582301, -2.4620875347369378`}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.181630760896252, -1.2900843444730699`], 
            Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307645708013, 0.007358287782327438}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[9.30932537452151, 1.2816299944237615`], 
            Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623076457080134, -0.09264171221767196}],
          RowBox[{"{", 
            RowBox[{"37.89999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.89999999999999, {
            Complex[6.167732720931719, 1.2816299944237621`], 
            Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0330799144138363`, -3.2430523684518433`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.220966384253502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7765232218179048`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2430523684518433`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[3.220966384253502, -1.7765232218179048`], 
            Complex[1.0330799144138363`, -3.2430523684518433`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0330799144138367`, -3.3430523684518443`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07937373066370935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.776523221817905`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0330799144138367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.243052368451844`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[0.07937373066370935, -1.776523221817905], 
            Complex[1.0330799144138367`, -3.243052368451844]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.098974815870868, -0.32400974799972276`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.97728615034638, 0.7324379313144281], 
            Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.098974815870868, -0.42400974799972313`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.8356934967565883`, 0.732437931314428], 
            Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.122351473418491, -2.3108018234353835`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[2.759549546988155, -0.8421588862221198], 
            Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.122351473418492, -2.2108018234353843`}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[5.901142200577949, -0.8421588862221203], 
            Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605272293102371, -2.364146338317678}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.323193339572983, -1.292454363919178], 
            Complex[7.605272293102371, -2.364146338317678]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605272293102373, -2.464146338317678}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.181600685983191, -1.2924543639191768`], 
            Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623075978637889, 0.009449175160798235}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[9.309325137880622, 1.2839976681063674`], 
            Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230759786378925`, -0.09055082483920157}],
          RowBox[{"{", 
            RowBox[{"37.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {37.99999999999999, {
            Complex[6.167732484290831, 1.2839976681063678`], 
            Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0323320529137487`, -3.2447730362680187`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2206809536115193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7781743754399488`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680187`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[3.2206809536115193`, -1.7781743754399488`], 
            Complex[1.0323320529137487`, -3.2447730362680187`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0323320529137487`, -3.3447730362680206`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07908830002172706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7781743754399495`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680205`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[0.07908830002172706, -1.7781743754399495`], 
            Complex[1.0323320529137487`, -3.2447730362680205`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0983751163877695`, -0.4170600822429599}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.8353400095752215`, 0.7378981353300624], 
            Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.098375116387771, -0.31706008224295834`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.976932663165016, 0.7378981353300635], 
            Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.123970710601056, -2.3165747562234498`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[2.760507048180339, -0.8472019743388879], 
            Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.123970710601056, -2.2165747562234497`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[5.9020997017701315`, -0.8472019743388882], 
            Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605146784820535, -2.3661941636932524`}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.323163469577016, -1.2948125987358026`], 
            Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605146784820535, -2.466194163693253}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.181570815987224, -1.2948125987358035`], 
            Complex[7.605146784820535, -2.366194163693253]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623075384765489, -0.08847088326608643}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[6.167732191343831, 1.2863535694098465`], 
            Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230753847654915`, 0.01152911673391317}],
          RowBox[{"{", 
            RowBox[{"38.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.099999999999994`, {
            Complex[9.309324844933629, 1.286353569409846], 
            Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0315873206614592`, -3.3464879325562995`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07880485029112587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325562994`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[0.07880485029112587, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325562994`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0315873206614592`, -3.2464879325563003`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2203975038809194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325563003`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[3.2203975038809194`, -1.7798192281074985`], 
            Complex[1.0315873206614592`, -3.2464879325563003`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.097796097581198, -0.4101729050453705}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.8349998876116986`, 0.7433046912443027], 
            Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.097796097581198, -0.31017290504537054`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.976592541201492, 0.7433046912443029], 
            Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.12556733480281, -2.322290341327314}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[2.7614487540168455`, -0.8521943919901349], 
            Complex[4.12556733480281, -2.222290341327314]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.12556733480281, -2.222290341327314}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[5.903041407606638, -0.852194391990135], 
            Complex[4.12556733480281, -2.222290341327314]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605021616198942, -2.4682311227994598`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.181541148373396, -1.2971591677080394`], 
            Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.605021616198944, -2.3682311227994606`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.323133801963191, -1.2971591677080403`], 
            Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307467734139, 0.013598224239136788`}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[9.309324496906415, 1.2886978170110814`], 
            Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307467734139, -0.08640177576086301}],
          RowBox[{"{", 
            RowBox[{"38.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.199999999999996`, {
            Complex[6.167731843316621, 1.2886978170110817`], 
            Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.030845691369485, -3.248197100501716}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2201160142359173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7814578285088363`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030845691369485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.248197100501716`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[3.2201160142359173`, -1.7814578285088363`], 
            Complex[1.030845691369485, -3.248197100501716]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0308456913694903`, -3.3481971005017126`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07852336064612488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.781457828508837`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0308456913694903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2481971005017125`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[0.07852336064612488, -1.781457828508837], 
            Complex[1.0308456913694903`, -3.2481971005017125`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0972370860175795`, -0.40334695531178244`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.8346726399259916`, 0.7486587126323618], 
            Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.09723708601758, -0.30334695531178235`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.976265293515786, 0.7486587126323617], 
            Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.127142026771301, -2.2279497982353833`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[5.903967825152418, -0.8571372217260815], 
            Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.127142026771301, -2.327949798235384}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[2.762375171562624, -0.8571372217260823], 
            Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604896783758137, -2.370257325860909}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.323104334242323, -1.2994941878134678`], 
            Complex[7.604896783758137, -2.370257325860909]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604896783758138, -2.470257325860909}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.18151168065253, -1.2994941878134685`], 
            Complex[7.604896783758138, -2.370257325860909]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623073858205366, -0.08434339229508822}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.3, {
            Complex[6.167731441406146, 1.2910305277808336`], 
            Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62307385820537, 0.015656607704910973`}],
          RowBox[{"{", 
            RowBox[{"38.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.3, {
            Complex[9.309324094995942, 1.291030527780833], 
            Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0301071390850915`, -3.249900582785768}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.219836464147169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.78309022476319`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0301071390850915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.249900582785768`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[3.219836464147169, -1.78309022476319], 
            Complex[1.0301071390850915`, -3.249900582785768]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.030107139085092, -3.349900582785767}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07824381055737564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7830902247631892`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.030107139085092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.249900582785767`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[0.07824381055737564, -1.7830902247631892`], 
            Complex[1.030107139085092, -3.249900582785767]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.096697439107836, -0.29658101249323643`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.975950452868279, 0.7539612767642825], 
            Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.096697439107836, -0.39658101249323674`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.8343577992784867`, 0.7539612767642822], 
            Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.128695436382012, -2.333554306387066}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[2.7632867840386814`, -0.8620315102214068], 
            Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.128695436382012, -2.2335543063870658`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[5.904879437628475, -0.8620315102214064], 
            Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604772284075737, -2.4722728814259396`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.181482410380124, -1.3018177742589643`], 
            Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604772284075739, -2.372272881425941}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.32307506396992, -1.3018177742589656`], 
            Complex[7.604772284075739, -2.372272881425941]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623072929159484, 0.017704375485551985`}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.4, {
            Complex[9.309323640371, 1.2933518168205271`], 
            Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623072929159485, -0.08229562451444802}],
          RowBox[{"{", 
            RowBox[{"38.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.4, {
            Complex[6.167730986781208, 1.2933518168205271`], 
            Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0293716381845965`, -3.3515984215943755`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07796617978662179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7847164644296631`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381845965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2515984215943754`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[0.07796617978662179, -1.7847164644296631`], 
            Complex[1.0293716381845965`, -3.2515984215943754`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0293716381846, -3.251598421594382}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2195588333764196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7847164644296638`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0293716381846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.251598421594382`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[3.2195588333764196`, -1.7847164644296638`], 
            Complex[1.0293716381846, -3.251598421594382]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{4.096176543275775, -0.3898738948304563}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.8340549206827474`, 0.7592134262018864], 
            Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.096176543275776, -0.28987389483045467`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.975647574272541, 0.7592134262018878], 
            Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.130228184469745, -2.2391050069213736`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[5.905776705860623, -0.8668782698647188], 
            Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.130228184469746, -2.3391050069213732`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[2.764184052270831, -0.8668782698647187], 
            Complex[4.130228184469746, -2.239105006921373]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604648113785144, -2.4742778964006495`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.18145333515529, -1.3041300405165688`], 
            Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604648113785146, -2.374277896400649}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.323045988745086, -1.3041300405165683`], 
            Complex[7.604648113785146, -2.374277896400649]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623071891969078, -0.0802583657047648}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.5, {
            Complex[6.167730480583245, 1.2956617974980968`], 
            Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623071891969081, 0.019741634295234595`}],
          RowBox[{"{", 
            RowBox[{"38.5`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.5, {
            Complex[9.309323134173042, 1.2956617974980962`], 
            Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0286391633678167`, -3.253290658625719}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.21928310197127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7863365945159997`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625719`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[3.21928310197127, -1.7863365945159997`], 
            Complex[1.0286391633678167`, -3.253290658625719]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0286391633678178`, -3.353290658625721}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0776904483814771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7863365945160001`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0286391633678178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625721`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[0.0776904483814771, -1.7863365945160001`], 
            Complex[1.0286391633678178`, -3.253290658625721]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.095673812258774, -0.3832244576900403}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.8337635800647583`, 0.764416170309563], 
            Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.095673812258775, -0.2832244576900404}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.975356233654551, 0.7644161703095629], 
            Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.131740864527742, -2.3446030043329675`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[2.765067416031943, -0.8716784802620265], 
            Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.131740864527742, -2.2446030043329674`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[5.9066600696217355`, -0.8716784802620264], 
            Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60452426957432, -2.4762724760820616`}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.181424452619743, -1.3064310983584468`], 
            Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604524269574324, -2.376272476082065}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.323017106209543, -1.3064310983584502`], 
            Complex[7.604524269574324, -2.376272476082065]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623070748363671, -0.07823151075886116}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[6.167729923927075, 1.2979605814829254`], 
            Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623070748363671, 0.02176848924114553}],
          RowBox[{"{", 
            RowBox[{"38.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.599999999999994`, {
            Complex[9.309322577516868, 1.2979605814829327`], 
            Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0279096896525775`, -3.2549773350978284`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2190092502600542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7879506614871665`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0279096896525775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2549773350978284`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[3.2190092502600542`, -1.7879506614871665`], 
            Complex[1.0279096896525775`, -3.2549773350978284`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.027909689652578, -3.3549773350978263`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.077416596670261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7879506614871654`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.027909689652578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.254977335097826`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[0.077416596670261, -1.7879506614871654`], 
            Complex[1.027909689652578, -3.254977335097826]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.095188685529604, -0.27663159198783}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.975076026609326, 0.7695704866842142], 
            Complex[4.095188685529604, -0.27663159198783]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.095188685529604, -0.37663159198783025`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.8334833730195332`, 0.769570486684214], 
            Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.133234044285656, -2.3500493680411703`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[2.7659372952868275`, -0.8764330896595155], 
            Complex[4.133234044285656, -2.25004936804117]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.133234044285656, -2.25004936804117}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[5.907529948876621, -0.8764330896595154], 
            Complex[4.133234044285656, -2.25004936804117]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6044007481845695`, -2.4782567241904525`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.181395760456799, -1.3087210578909678`], 
            Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604400748184571, -2.3782567241904538`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.322988414046595, -1.3087210578909694`], 
            Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623069500037891, 0.023785043855733365`}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[9.309321971491423, 1.300248278779899], 
            Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623069500037891, -0.07621495614426643}],
          RowBox[{"{", 
            RowBox[{"38.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.699999999999996`, {
            Complex[6.167729317901629, 1.3002482787798992`], 
            Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0271831923693993`, -3.3566584917561224`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07714460525703772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.789558711273773`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923693993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2566584917561223`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[0.07714460525703772, -1.789558711273773], 
            Complex[1.0271831923693993`, -3.2566584917561223`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0271831923694072`, -3.256658491756127}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2187372588468346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895587112737734`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0271831923694072`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.256658491756127`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[3.2187372588468346`, -1.7895587112737734`], 
            Complex[1.0271831923694072`, -3.256658491756127]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094720626829336, -0.27009422269428585`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.974806567246683, 0.7746773225093266], 
            Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094720626829336, -0.37009422269428627`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.8332139136568895`, 0.7746773225093263], 
            Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.134708267176491, -2.355445133877134}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[2.7667940913479225`, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.134708267176491, -2.2554451338771337`}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[5.908386744937716, -0.8811430162906054], 
            Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604277546409371, -2.480230742900865}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.181367256390402, -1.3110000275879252`], 
            Complex[7.604277546409371, -2.380230742900865]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604277546409373, -2.380230742900865}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.322959909980197, -1.3110000275879254`], 
            Complex[7.604277546409373, -2.380230742900865]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623068148652344, 0.02579140012826888}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.8, {
            Complex[9.30932131716045, 1.3025249977626072`], 
            Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623068148652344, -0.07420859987173092}],
          RowBox[{"{", 
            RowBox[{"38.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.8, {
            Complex[6.167728663570656, 1.3025249977626074`], 
            Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0264596471562961`, -3.3583341688807753`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07687445501670612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7911607892803307`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.258334168880775`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[0.07687445501670612, -1.7911607892803307`], 
            Complex[1.0264596471562961`, -3.258334168880775]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0264596471562961`, -3.2583341688807756`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2184671086065006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.791160789280331`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2583341688807756`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[3.2184671086065006`, -1.791160789280331], 
            Complex[1.0264596471562961`, -3.2583341688807756`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094269122802148, -0.26361130741698524`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.974547487118723, 0.779737595837812], 
            Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.094269122802148, -0.36361130741698544`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.83295483352893, 0.7797375958378118], 
            Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.136164053701611, -2.2607913054940165`}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[5.909230841539049, -0.8858091496519155], 
            Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.136164053701611, -2.360791305494017}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[2.7676381879492564`, -0.8858091496519156], 
            Complex[4.136164053701611, -2.260791305494017]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604154661093239, -2.382194632873833}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.322931591773996, -1.3132681143229277`], 
            Complex[7.604154661093239, -2.382194632873833]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604154661093243, -2.482194632873834}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.181338938184205, -1.3132681143229286`], 
            Complex[7.604154661093243, -2.382194632873834]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623066695834459, 0.02778765853546761}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.9, {
            Complex[9.309320615563188, 1.3047908452057129`], 
            Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623066695834459, -0.07221234146453219}],
          RowBox[{"{", 
            RowBox[{"38.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.9, {
            Complex[6.167727961973395, 1.304790845205713], 
            Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.025739029953579, -3.2600044062938625`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2181987806799732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.79275694039334`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025739029953579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[3.2181987806799732`, -1.79275694039334], 
            Complex[1.025739029953579, -3.2600044062938625`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0257390299535794`, -3.3600044062938625`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07660612709017996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7927569403933397`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0257390299535794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[0.07660612709017996, -1.7927569403933397`], 
            Complex[1.0257390299535794`, -3.2600044062938625`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.093833681723804, -0.3571818350557062}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.8327057806325184`, 0.7847521968079433], 
            Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.093833681723805, -0.25718183505570735`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.974298434222312, 0.7847521968079424], 
            Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.137601902702118, -2.3660888557047377`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[2.768469952245414, -0.8904323517124777], 
            Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.137601902702118, -2.2660888557047376`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[5.910062605835208, -0.8904323517124778], 
            Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604032089130615, -2.3841484932853487`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.32290345723042, -1.315525423400987], 
            Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.604032089130619, -2.4841484932853493`}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.18131080364063, -1.3155254234009877`], 
            Complex[7.604032089130619, -2.384148493285349]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623065143179327, -0.0702260819285421}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[6.167727214125249, 1.307045926316517], 
            Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623065143179328, 0.02977391807145791}],
          RowBox[{"{", 
            RowBox[{"38.99999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {38.99999999999999, {
            Complex[9.309319867715043, 1.3070459263165168`], 
            Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.025021316998925, -3.2616692433664776`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2179322564695223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794347208989231`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.025021316998925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2616692433664776`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[3.2179322564695223`, -1.794347208989231], 
            Complex[1.025021316998925, -3.2616692433664776`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0250213169989348`, -3.3616692433664768`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07633960287973203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7943472089892278`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0250213169989348`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2616692433664767`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[0.07633960287973203, -1.7943472089892278`], 
            Complex[1.0250213169989348`, -3.2616692433664767`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.093413832316266, -0.35080482452581296`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.832466418480638, 0.7897219887964373], 
            Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0934138323162665`, -0.2508048245258122}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.974059072070432, 0.7897219887964377], 
            Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.139022292544098, -2.3713387277515543`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[2.7692897357415935`, -0.8950134580602265], 
            Complex[4.139022292544098, -2.271338727751554]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.139022292544099, -2.2713387277515547`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[5.910882389331387, -0.8950134580602268], 
            Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60390982746478, -2.386092421856075}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.322875504189794, -1.3177720585893213`], 
            Complex[7.60390982746478, -2.386092421856075]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603909827464783, -2.4860924218560765`}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.181282850600006, -1.3177720585893227`], 
            Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623063492250484, 0.03175027627696571}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[9.309319074608208, 1.3092903447657454`], 
            Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623063492250484, -0.06824972372303409}],
          RowBox[{"{", 
            RowBox[{"39.099999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.099999999999994`, {
            Complex[6.167726421018415, 1.3092903447657456`], 
            Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.024306484822421, -3.3633287190256436`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07607486404437007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.024306484822421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[0.07607486404437007, -1.7959316389421525`], 
            Complex[1.024306484822421, -3.2633287190256435`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0243064848224217`, -3.2633287190256435`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2176675176341636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0243064848224217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[3.2176675176341636`, -1.7959316389421525`], 
            Complex[1.0243064848224217`, -3.2633287190256435`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0930091226416065`, -0.244479323545952}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.973829078826883, 0.7946478095124517], 
            Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0930091226416065`, -0.34447932354595234`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.83223642523709, 0.7946478095124515], 
            Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1404256822245795`, -2.3765418365114743`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[2.770097875160309, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1404256822245795`, -2.2765418365114747`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[5.911690528750102, -0.8995532789895441], 
            Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603787873086824, -2.488026514879854}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.181255076939699, -1.3200081221474058`], 
            Complex[7.603787873086824, -2.388026514879854]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603787873086826, -2.3880265148798543`}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.322847730529492, -1.3200081221474065`], 
            Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623061744580699, -0.06628317073221635}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[6.167725583622502, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623061744580699, 0.03371682926778386}],
          RowBox[{"{", 
            RowBox[{"39.199999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.199999999999996`, {
            Complex[9.309318237212295, 1.311524202717574], 
            Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0235945102417783`, -3.2649828717610987`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2174045460851777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7975102736315947`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2649828717610987`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[3.2174045460851777`, -1.7975102736315947`], 
            Complex[1.0235945102417783`, -3.2649828717610987`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0235945102417785`, -3.3649828717610992`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07581189249538411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.797510273631595`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0235945102417785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.264982871761099`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[0.07581189249538411, -1.797510273631595], 
            Complex[1.0235945102417785`, -3.264982871761099]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0926191190690275`, -0.3382044074863149}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.832015492909507, 0.7995304720360317], 
            Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.092619119069028, -0.2382044074863148}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.973608146499301, 0.7995304720360318], 
            Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.141812512404396, -2.3816990696412366`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[2.770894693249766, -0.9040526005333875], 
            Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.141812512404397, -2.2816990696412356`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[5.912487346839559, -0.904052600533387], 
            Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603666223034595, -2.389950867251501}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.322820134163065, -1.322233714856279], 
            Complex[7.603666223034595, -2.389950867251501]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603666223034602, -2.4899508672515016`}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.181227480573279, -1.32223371485628], 
            Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623059901672726, -0.06432632823745194}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.3, {
            Complex[6.16772470288514, 1.313747600858923], 
            Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623059901672726, 0.03567367176254808}],
          RowBox[{"{", 
            RowBox[{"39.3`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.3, {
            Complex[9.309317356474933, 1.3137476008589228`], 
            Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0228853703576102`, -3.266631739631969}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.217143323981706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498917`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.266631739631969`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[3.217143323981706, -1.7990831559498917`], 
            Complex[1.0228853703576102`, -3.266631739631969]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0228853703576115`, -3.3666317396319685`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07555067039191275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498914`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0228853703576115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2666317396319684`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[0.07555067039191275, -1.7990831559498914`], 
            Complex[1.0228853703576115`, -3.2666317396319684`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.092243405309306, -0.23197917827395678`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.9733959801858845`, 0.8043707658042932], 
            Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.092243405309307, -0.3319791782739563}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.8318033265960922`, 0.8043707658042935], 
            Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.143183206373633, -2.386811288665357}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[2.771680499538499, -0.9085121854432784], 
            Complex[4.143183206373633, -2.286811288665357]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.143183206373633, -2.286811288665357}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[5.913273153128292, -0.9085121854432785], 
            Complex[4.143183206373633, -2.286811288665357]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603544874391759, -2.4918655724939387`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.181200059449696, -1.32444893604715], 
            Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603544874391759, -2.391865572493939}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.32279271303949, -1.32444893604715], 
            Complex[7.603544874391759, -2.391865572493939]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623057965000035, -0.06237910289016552}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.4, {
            Complex[6.167723779732554, 1.3159606384280345`], 
            Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230579650000365`, 0.037620897109835086`}],
          RowBox[{"{", 
            RowBox[{"39.4`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.4, {
            Complex[9.309316433322348, 1.3159606384280351`], 
            Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0221790425488162`, -3.36827536027329}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07529118013665538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8006503283095583`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0221790425488162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.26827536027329`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[0.07529118013665538, -1.8006503283095583`], 
            Complex[1.0221790425488162`, -3.26827536027329]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.022179042548827, -3.268275360273292}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2168838337264507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8006503283095574`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.022179042548827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.268275360273292`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[3.2168838337264507`, -1.8006503283095574`], 
            Complex[1.022179042548827, -3.268275360273292]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.091881581511521, -0.3258027633518864}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.8315996437819138`, 0.8091694575484238], 
            Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.0918815815115215`, -0.22580276335188598`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.973192297371707, 0.8091694575484238], 
            Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1445381709548, -2.391879330010544}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[2.772455591040422, -0.9129327741202401], 
            Complex[4.1445381709548, -2.291879330010544]}, -1}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1445381709548, -2.291879330010546}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[5.914048244630215, -0.9129327741202411], 
            Complex[4.1445381709548, -2.291879330010546]}, 0}, "Tooltip"]& ], 
        
        TagBox[
         TooltipBox[PointBox[{7.603423824286758, -2.493770722784648}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.1811728115525035`, -1.3266538836292885`], 
            Complex[7.603423824286758, -2.393770722784648]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6034238242867636`, -2.3937707227846508`}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.322765465142302, -1.326653883629291], 
            Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623055936007519, -0.060441402685402}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[6.167722815070127, 1.3181634132423612`], 
            Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623055936007521, 0.0395585973145974}],
          RowBox[{"{", 
            RowBox[{"39.49999999999999`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.49999999999999, {
            Complex[9.309315468659923, 1.3181634132423605`], 
            Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0214755044681099`, -3.3699137709024374`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07503340437166661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.802211832650498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681099`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2699137709024373`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[0.07503340437166661, -1.802211832650498], 
            Complex[1.0214755044681099`, -3.2699137709024373`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0214755044681103`, -3.269913770902438}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2166260579614594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8022118326504983`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0214755044681103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.269913770902438`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[3.2166260579614594`, -1.8022118326504983`], 
            Complex[1.0214755044681103`, -3.269913770902438]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.091533263417342, -0.31967431468886165`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.8314041736809603`, 0.8139272921843714], 
            Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.091533263417343, -0.21967431468886214`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.972996827270754, 0.8139272921843711], 
            Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.1458777973484535`, -2.3969040059895237`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[2.773220252914124, -0.9173150854995425], 
            Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.145877797348456, -2.296904005989524}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[5.914812906503919, -0.9173150854995431], 
            Complex[4.145877797348456, -2.296904005989524]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603303069891951, -2.495666408981522}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.181145734899095, -1.3288486541172821`], 
            Complex[7.603303069891951, -2.395666408981522]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603303069891951, -2.3956664089815227`}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.322738388488887, -1.3288486541172835`], 
            Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62305381611219, -0.05851313693602809}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[6.167721809782957, 1.3203560217257764`], 
            Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623053816112197, 0.04148686306397394}],
          RowBox[{"{", 
            RowBox[{"39.599999999999994`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.599999999999994`, {
            Complex[9.30931446337276, 1.3203560217257788`], 
            Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.020774734037491, -3.2715470083253844`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2163699795640026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470822`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.020774734037491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2715470083253844`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[3.2163699795640026`, -1.8037677104470822`], 
            Complex[1.020774734037491, -3.2715470083253844`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0207747340374922`, -3.3715470083253805`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0747773259742065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470848`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0207747340374922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2715470083253804`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[0.0747773259742065, -1.8037677104470848`], 
            Complex[1.0207747340374922`, -3.2715470083253804`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.091198081568591, -0.21359300783699628`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.972809310210266, 0.8186449936599097], 
            Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.091198081568593, -0.3135930078369963}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.8312166566204735`, 0.8186449936599106], 
            Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.147202461925567, -2.3018861057371853`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[5.9155674126696605`, -0.9216598178919517], 
            Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.147202461925569, -2.4018861057371836`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[2.7739747590798687`, -0.9216598178919512], 
            Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.60318260842262, -2.4975527206480335`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.181118827539914, -1.3310333426575782`], 
            Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.603182608422626, -2.3975527206480365`}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.322711481129714, -1.331033342657582], 
            Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.62305160670384, -0.05659421624754792}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[6.167720764736373, 1.322538558935139], 
            Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623051606703843, 0.04340578375245147}],
          RowBox[{"{", 
            RowBox[{"39.699999999999996`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.699999999999996`, {
            Complex[9.30931341832617, 1.3225385589351384`], 
            Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0200767094440117`, -3.27317510894289}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.216115581642531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.27317510894289`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[3.216115581642531, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.27317510894289]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0200767094440117`, -3.373175108942891}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0745229280527381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.273175108942891`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[0.0745229280527381, -1.805318002715075], 
            Complex[1.0200767094440117`, -3.273175108942891]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090875680564112, -0.307558041034481}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.8310368434643864`, 0.8233232657606014], 
            Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090875680564113, -0.20755804103448117`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.9726294970541804`, 0.8233232657606012], 
            Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.148512526970577, -2.306826396101707}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[5.916312026387238, -0.925967649783973], 
            Complex[4.148512526970577, -2.306826396101707]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.148512526970578, -2.406826396101705}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[2.774719372797445, -0.9259676497839711], 
            Complex[4.148512526970578, -2.306826396101705]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6030624371361615`, -2.4994297460778916`}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.1810920875578015`, -1.3332080430544786`], 
            Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6030624371361615`, -2.399429746077893}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.322684741147594, -1.3332080430544797`], 
            Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230493091457, 0.04531544750647416}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {39.8, {
            Complex[9.309312334366247, 1.3247111185862175`], 
            Complex[7.6230493091457, 0.04531544750647416]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.6230493091457, -0.05468455249352523}],
          RowBox[{"{", 
            RowBox[{"39.8`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.8, {
            Complex[6.167719680776454, 1.3247111185862182`], 
            Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0193814091354683`, -3.2747981087565443`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2158628475327276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8068627500184498`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565443`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[3.2158628475327276`, -1.8068627500184498`], 
            Complex[1.0193814091354683`, -3.2747981087565443`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0193814091354747`, -3.374798108756529}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.07427019394292937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8068627500184438`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0193814091354747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565288`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[0.07427019394292937, -1.8068627500184438`], 
            Complex[1.0193814091354747`, -3.2747981087565288`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090565718362365, -0.2015686343508945}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.972457148662774, 0.8279627928769886], 
            Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090565718362366, -0.30156863435089454`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.8308644950729818`, 0.8279627928769887], 
            Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.149808341378717, -2.311725622493254}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[5.917047000797618, -0.9302392405994727], 
            Complex[4.149808341378717, -2.311725622493254]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.149808341378721, -2.411725622493254}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[2.775454347207829, -0.9302392405994732], 
            Complex[4.149808341378721, -2.311725622493254]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602942553331131, -2.5012975723190065`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.181065513067208, -1.3353728477954119`], 
            Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602942553331133, -2.4012975723190064`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.322658166657003, -1.3353728477954119`], 
            Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623046924775063, 0.047215941208410626`}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {39.9, {
            Complex[9.309311212320324, 1.3268737930790047`], 
            Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623046924775063, -0.05278405879158898}],
          RowBox[{"{", 
            RowBox[{"39.9`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {39.9, {
            Complex[6.167718558730529, 1.326873793079005], 
            Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
          "Tooltip"]& ]}, {
        TagBox[
         TooltipBox[PointBox[{1.0186888118162511`, -3.3764160433747037`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"0.0740191072038374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760677`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2764160433747036`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[0.0740191072038374, -1.8084019924760677`], 
            Complex[1.0186888118162511`, -3.2764160433747036`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{1.0186888118162514`, -3.276416043374702}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"3.2156117607936308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760657`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"1.0186888118162514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.276416043374702`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[3.2156117607936308`, -1.8084019924760657`], 
            Complex[1.0186888118162514`, -3.276416043374702]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090267865626448, -0.19562402887272795`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.97229203538588, 0.8325642407352367], 
            Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.090267865626449, -0.29562402887272815`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.8306993817960873`, 0.8325642407352367], 
            Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.15109024131099, -2.316584509692523}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[5.9177725794310545`, -0.9344752314248252], 
            Complex[4.15109024131099, -2.316584509692523]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{4.151090241310992, -2.4165845096925236`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[2.776179925841262, -0.9344752314248258], 
            Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602822954346447, -2.40315628519697}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                "}"}], ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.322631755803343, -1.3375278480756927`], 
            Complex[7.602822954346447, -2.40315628519697]}, 0}, "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.602822954346457, -2.503156285196985}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                 "}"}], ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1810391022135605`, -1.337527848075709], 
            Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623044454903904, -0.050892649480003736`}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", 
              RowBox[{"-", "1"}]}], "}"}]],
         Annotation[#, {40., {
            Complex[6.1677173994076595`, 1.3290266735224265`], 
            Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
          "Tooltip"]& ], 
        TagBox[
         TooltipBox[PointBox[{7.623044454903904, 0.04910735051999668}],
          RowBox[{"{", 
            RowBox[{"40.`", ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                  ",", 
                  RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
               ",", "0"}], "}"}]],
         Annotation[#, {40., {
            Complex[9.309310052997454, 1.3290266735224268`], 
            Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
          "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]\[Tau])\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]\[Tau])\"", TraditionalForm]},
      ImageSize->800,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Syntax options for GetSaddlePoints", "Subsection"],

Cell["Single energy, single range:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalOmega]Range", "=", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{"Ip", ",", "\[Omega]"}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{
          RowBox[{"1.32", "Ip"}], "+", 
          RowBox[{"3.17", "U"}]}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{"2", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"GetSaddlePoints", "[", 
     RowBox[{
      RowBox[{
      "\[CapitalOmega]Range", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], ",", "S", ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", 
          RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"], 
        ",", 
        FractionBox[
         RowBox[{
          RowBox[{"3", "\[Pi]"}], "+", 
          RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", 
          RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"], 
        ",", 
        FractionBox[
         RowBox[{
          RowBox[{"2", "\[Pi]"}], "+", 
          RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"]}], 
       "}"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Tolerance", "\[Rule]", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
      RowBox[{"Seeds", "\[Rule]", "30"}], "\[IndentingNewLine]", ",", 
      RowBox[{"SelectionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]", ",", "SS", ",", "\[CapitalOmega]"}], 
          "}"}], ",", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"t", "-", "\[Tau]"}], "]"}], ">", "0"}]}], "]"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<tt\>\"", ",", "\"\<\[Tau]\>\""}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"61.32826768328523`", "\[VeryThinSpace]", "-", 
      RowBox[{"17.885419308518028`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"25.311706453897894`", "\[VeryThinSpace]", "-", 
      RowBox[{"44.00848568008373`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"171.55958886187446`", "\[VeryThinSpace]", "-", 
      RowBox[{"17.885419308518056`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"25.3117064538979`", "\[VeryThinSpace]", "-", 
      RowBox[{"44.00848568008375`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"71.43284848769699`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450722`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.52682218732508`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.64437291632372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"181.66416966628626`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450768`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.5268221873251`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.64437291632377`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"126.54850907699164`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450733`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.52682218732511`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"133.2344781534338`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.1309640745970846`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"243.46579933202304`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.13096407459708814`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\

Single energy, multiple ranges:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalOmega]Range", "=", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{"Ip", ",", "\[Omega]"}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{
          RowBox[{"1.32", "Ip"}], "+", 
          RowBox[{"3.17", "U"}]}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{"2", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"GetSaddlePoints", "[", 
     RowBox[{
      RowBox[{
      "\[CapitalOmega]Range", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], ",", "S", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"3", "\[Pi]"}], "+", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"2", "\[Pi]"}], "+", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"3", "\[Pi]"}], "+", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"2", "\[Pi]"}], "-", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"4", "\[Pi]"}], "+", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}]}], "}"}]}], "}"}], "\[IndentingNewLine]", 
      ",", 
      RowBox[{"Tolerance", "\[Rule]", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
      RowBox[{"Seeds", "\[Rule]", "30"}], "\[IndentingNewLine]", ",", 
      RowBox[{"SelectionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]", ",", "SS", ",", "\[CapitalOmega]"}], 
          "}"}], ",", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"t", "-", "\[Tau]"}], "]"}], ">", "0"}]}], "]"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<tt\>\"", ",", "\"\<\[Tau]\>\""}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"116.44392827257983`", "\[VeryThinSpace]", "-", 
      RowBox[{"17.885419308518014`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"25.31170645389788`", "\[VeryThinSpace]", "-", 
      RowBox[{"44.0084856800837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"126.5485090769916`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450736`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.52682218732508`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.64437291632374`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"71.43284848769702`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450758`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.52682218732509`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"181.66416966628623`", "\[VeryThinSpace]", "-", 
      RowBox[{"8.635279208450758`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"35.52682218732509`", "\[VeryThinSpace]", "-", 
      RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"188.35013874272843`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.1309640745970846`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"243.46579933202304`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.13096407459708814`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"104.36145617205712`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"202.54801952688797`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.15076793497771845`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"118.54958963881721`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"147.43235893759336`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.1507679349777149`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"118.54958963881722`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"290.0121651907459`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.27273567401804755`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"149.34560377406763`", "\[VeryThinSpace]", "-", 
      RowBox[{"21.008130280727762`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"194.59260474081614`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.20393306564784908`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"164.14019346872632`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.9434322176268`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"249.7082653301108`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.20393306564785263`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"164.14019346872638`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.9434322176268`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"304.8239259194055`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.20393306564784908`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"164.1401934687264`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.943432217626796`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"242.25681304893914`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.03347959101790465`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"214.036812181266`", "\[VeryThinSpace]", "-", 
      RowBox[{"20.420935619004233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\

List of energies, single range:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalOmega]Range", "=", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{"Ip", ",", "\[Omega]"}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{
          RowBox[{"1.32", "Ip"}], "+", 
          RowBox[{"3.17", "U"}]}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{"2", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"GetSaddlePoints", "[", 
     RowBox[{
      RowBox[{"\[CapitalOmega]Range", "\[LeftDoubleBracket]", 
       RowBox[{"1", ";;", "2"}], "\[RightDoubleBracket]"}], ",", "S", ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", 
          RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"], 
        ",", 
        FractionBox[
         RowBox[{
          RowBox[{"3", "\[Pi]"}], "+", 
          RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", 
          RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"], 
        ",", 
        FractionBox[
         RowBox[{
          RowBox[{"2", "\[Pi]"}], "+", 
          RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"]}], 
       "}"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Tolerance", "\[Rule]", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
      RowBox[{"Seeds", "\[Rule]", "30"}], "\[IndentingNewLine]", ",", 
      RowBox[{"SelectionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]", ",", "SS", ",", "\[CapitalOmega]"}], 
          "}"}], ",", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"t", "-", "\[Tau]"}], "]"}], ">", "0"}]}], "]"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<tt\>\"", ",", "\"\<\[Tau]\>\""}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"0.9690000000000001`", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"61.32826768328523`", "\[VeryThinSpace]", "-", 
         RowBox[{"17.885419308518028`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"25.311706453897894`", "\[VeryThinSpace]", "-", 
         RowBox[{"44.00848568008373`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"171.55958886187446`", "\[VeryThinSpace]", "-", 
         RowBox[{"17.885419308518056`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"25.3117064538979`", "\[VeryThinSpace]", "-", 
         RowBox[{"44.00848568008375`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"71.43284848769699`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450722`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.52682218732508`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.64437291632372`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"181.66416966628626`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450768`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.5268221873251`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.64437291632377`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"126.54850907699164`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450733`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.52682218732511`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"133.2344781534338`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.1309640745970846`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"243.46579933202304`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.13096407459708814`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"1.0830000000000002`", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"59.5902001785932`", "\[VeryThinSpace]", "-", 
         RowBox[{"21.012367143926518`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"23.274996753991438`", "\[VeryThinSpace]", "-", 
         RowBox[{"46.951295795253344`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"169.82152135718246`", "\[VeryThinSpace]", "-", 
         RowBox[{"21.0123671439265`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"23.27499675399147`", "\[VeryThinSpace]", "-", 
         RowBox[{"46.95129579525333`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"131.40319285135928`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.481934887900383`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"40.44786899864125`", "\[VeryThinSpace]", "-", 
         RowBox[{"31.963777656737015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"186.51885344065386`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.481934887900383`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"40.447868998641255`", "\[VeryThinSpace]", "-", 
         RowBox[{"31.96377765673701`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"239.05031435850105`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.1685047558442534`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"99.72292177174806`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.396711764901436`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"128.81899317991184`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.16850475584425695`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"99.72292177174808`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.396711764901433`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
     "}"}]}]}], "\[RightAssociation]"}]], "Output"]
}, Open  ]],

Cell["\<\

List of energies, multiple ranges:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalOmega]Range", "=", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{"Ip", ",", "\[Omega]"}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{
        RowBox[{"Ceiling", "[", 
         RowBox[{
          RowBox[{"1.32", "Ip"}], "+", 
          RowBox[{"3.17", "U"}]}], "]"}], "+", "\[Omega]"}], ",", 
       RowBox[{"2", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"GetSaddlePoints", "[", 
     RowBox[{
      RowBox[{"\[CapitalOmega]Range", "\[LeftDoubleBracket]", 
       RowBox[{"1", ";;", "2"}], "\[RightDoubleBracket]"}], ",", "S", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"3", "\[Pi]"}], "+", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"2", "\[Pi]"}], "+", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"0", "-", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"3", "\[Pi]"}], "+", 
              RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"2", "\[Pi]"}], "-", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"4", "\[Pi]"}], "+", 
              RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
             "\[Omega]"]}], "}"}]}], "}"}]}], "}"}], "\[IndentingNewLine]", 
      ",", 
      RowBox[{"Tolerance", "\[Rule]", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
      RowBox[{"Seeds", "\[Rule]", "30"}], "\[IndentingNewLine]", ",", 
      RowBox[{"SelectionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]", ",", "SS", ",", "\[CapitalOmega]"}], 
          "}"}], ",", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"t", "-", "\[Tau]"}], "]"}], ">", "0"}]}], "]"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<tt\>\"", ",", "\"\<\[Tau]\>\""}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"IndependentVariables", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"0.9690000000000001`", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"116.44392827257983`", "\[VeryThinSpace]", "-", 
         RowBox[{"17.885419308518014`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"25.31170645389788`", "\[VeryThinSpace]", "-", 
         RowBox[{"44.0084856800837`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"126.5485090769916`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450736`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.52682218732508`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.64437291632374`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"71.43284848769702`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450758`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.52682218732509`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"181.66416966628623`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.635279208450758`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"35.52682218732509`", "\[VeryThinSpace]", "-", 
         RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"188.35013874272843`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.1309640745970846`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"104.3614561720571`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"243.46579933202304`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.13096407459708814`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"104.36145617205712`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"133.23447815343383`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.1309640745970846`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"104.36145617205713`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.407695348449106`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"202.54801952688797`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.15076793497771845`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"118.54958963881721`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"147.43235893759336`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.1507679349777149`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"118.54958963881722`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"290.0121651907459`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.27273567401804755`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"149.34560377406763`", "\[VeryThinSpace]", "-", 
         RowBox[{"21.008130280727762`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"194.59260474081614`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.20393306564784908`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"164.14019346872632`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.9434322176268`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"249.7082653301108`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.20393306564785263`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"164.14019346872638`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.9434322176268`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"304.8239259194055`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.20393306564784908`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"164.1401934687264`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.943432217626796`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"242.25681304893914`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.03347959101790465`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"214.036812181266`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.420935619004233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"1.0830000000000002`", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"114.70586076788786`", "\[VeryThinSpace]", "-", 
         RowBox[{"21.012367143926515`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"23.27499675399147`", "\[VeryThinSpace]", "-", 
         RowBox[{"46.95129579525335`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"186.51885344065386`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.481934887900387`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"40.44786899864121`", "\[VeryThinSpace]", "-", 
         RowBox[{"31.963777656737026`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"131.40319285135928`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.4819348879003655`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"40.44786899864125`", "\[VeryThinSpace]", "-", 
         RowBox[{"31.963777656736994`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"76.28753226206467`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.48193488790038`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"40.44786899864126`", "\[VeryThinSpace]", "-", 
         RowBox[{"31.963777656737005`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"183.93465376920648`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.16850475584425695`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"99.72292177174806`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.396711764901433`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"128.81899317991184`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.16850475584424984`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"99.72292177174808`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"239.0503143585011`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.16850475584425695`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"99.72292177174809`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.396711764901436`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"154.26758308493513`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.27890772560983734`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"125.09297394908012`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.30219795679849`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"209.38324367422973`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.27890772560983734`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"125.09297394908012`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.30219795679849`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"283.0790525084914`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.40888565081601413`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"142.65799126607928`", "\[VeryThinSpace]", "-", 
         RowBox[{"21.094852699839524`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"309.7215899482923`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.2064505878368017`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"169.18762224737455`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.919646652737136`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"254.60592935899774`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.20645058783680525`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"169.18762224737458`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.919646652737136`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"199.49026876970314`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.20645058783680525`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"169.18762224737458`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.91964665273714`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"237.4638648747471`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.044974320804850976`", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"209.12655606285406`", "\[VeryThinSpace]", "-", 
         RowBox[{"20.416471870701486`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
     "}"}]}]}], "\[RightAssociation]"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reperioding of saddle points", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "Getting saddle points over a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", ",", "\[Tau]"}], TraditionalForm]]],
 " box including multiple ionization bursts"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
        "}"}], "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Omega]", ",", "Ip", ",", 
          SqrtBox[
           RowBox[{"2", "Ip"}]], ",", 
          FractionBox[
           SuperscriptBox["F", "2"], 
           RowBox[{"4", 
            SuperscriptBox["\[Omega]", "2"]}]], ",", 
          FractionBox[
           RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
        "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"\[CapitalOmega]Range", "=", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"Ceiling", "[", 
          RowBox[{"Ip", ",", "\[Omega]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Ceiling", "[", 
           RowBox[{
            RowBox[{"1.32", "Ip"}], "+", 
            RowBox[{"3.17", "U"}]}], "]"}], "+", 
          RowBox[{"5", "\[Omega]"}]}], ",", 
         RowBox[{"0.1", "\[Omega]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"saddlePoints", "=", 
       RowBox[{"GetSaddlePoints", "[", 
        RowBox[{"\[CapitalOmega]Range", ",", "S", ",", 
         RowBox[{"{", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"0", "\[Degree]"}], "-", 
             RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"],
            ",", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "\[Pi]"}], "+", 
             RowBox[{"1.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
            "\[Omega]"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           FractionBox[
            RowBox[{"0", "-", 
             RowBox[{"2.5", "\[ImaginaryI]", " ", "\[Gamma]"}]}], "\[Omega]"],
            ",", 
           FractionBox[
            RowBox[{
             RowBox[{"3", "\[Pi]"}], "+", 
             RowBox[{"0.1", "\[ImaginaryI]", " ", "\[Gamma]"}]}], 
            "\[Omega]"]}], "}"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Tolerance", "\[Rule]", 
          RowBox[{
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]], "/", "\[Omega]"}]}], ",", 
         RowBox[{"Seeds", "\[Rule]", "300"}], "\[IndentingNewLine]", ",", 
         RowBox[{"SelectionFunction", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", "\[Tau]", ",", "SS", ",", "\[CapitalOmega]"}], 
             "}"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              RowBox[{"t", "-", "\[Tau]"}], "]"}], ">", "0"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"1", ";;", "3"}], "\[RightDoubleBracket]"}], "//", 
  "AbsoluteTiming"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}]}], "Input"],

Cell[BoxData["\<\"Wed 11 May 2016 13:43:26\"\>"], "Output"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "cvmit"}], "MessageName"], ":", 
  " ", "\<\"Failed to converge to the requested accuracy or precision within \
\\!\\(\\*RowBox[{\\\"100\\\"}]\\) iterations.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"GetSaddlePoints", "::", "error"}], "MessageName"], ":", 
  " ", "\<\"Errors encountered for frequency \
\[CapitalOmega]=\\!\\(\\*RowBox[{\\\"1.0716`\\\"}]\\)\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"26.146112`", ",", 
   RowBox[{"\[LeftAssociation]", 
    RowBox[{
     RowBox[{"0.912`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"8.606967005168235`", "\[VeryThinSpace]", "-", 
           RowBox[{"14.707989760797723`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.850149832952376`", "\[VeryThinSpace]", "-", 
           RowBox[{"40.974114403929825`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"63.72262759446288`", "\[VeryThinSpace]", "-", 
           RowBox[{"14.707989760797755`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.850149832952408`", "\[VeryThinSpace]", "-", 
           RowBox[{"40.97411440392985`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"67.36127628819972`", "\[VeryThinSpace]", "-", 
           RowBox[{"11.285995288896316`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"31.494082066597223`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.54646297451055`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"12.24561569890513`", "\[VeryThinSpace]", "-", 
           RowBox[{"11.285995288896254`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"31.494082066597258`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.546462974510476`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"27.242696505008073`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11658019540031486`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"108.7058292318411`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"82.3583570943027`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11658019540031471`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"108.70582923184111`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410164695938448`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"32.19956620870829`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12083732434029185`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"113.66233957629898`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.405968816918104`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"87.31522679800294`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12083732434029808`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"113.662339576299`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"19.56344266876226`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23233632108244326`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"154.3862465344917`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.98506363389133`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"74.67910325805687`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23233632108244312`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"154.3862465344917`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.98506363389133`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"79.84124001923493`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.2115042067050312`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"159.54768443393`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.96439984430161`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"24.725579429940325`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.21150420670503203`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"159.54768443393`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.964399844301617`", " ", "\[ImaginaryI]"}]}]}], "}"}]}],
        "}"}]}], ",", 
     RowBox[{"0.9177000000000001`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"63.27407519703167`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.231847559133001`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.388201480646195`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.48085448472254`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"8.15841460773708`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.231847559132992`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.388201480646213`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.48085448472252`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"12.866460671342141`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.816178584119376`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.107663681420426`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.05300319249049`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"67.9821212606368`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.816178584119271`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.10766368142047`", "\[VeryThinSpace]", "-", 
           RowBox[{"37.053003192490394`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"26.538885474415657`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11776334712026189`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.9916707304329`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"81.65454606371027`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11776334712026212`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.9916707304329`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.41014295719712`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"32.97184965881184`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12356070149769749`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"114.42383835786649`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40448191262519`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"88.08751024810645`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.1235607014976989`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"114.42383835786649`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40448191262519`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"18.767172043852984`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23701538097059377`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"153.59811008119402`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"73.8828326331476`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.23701538097059358`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"153.59811008119402`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.988167845040152`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"25.46767563530732`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20963659080933705`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.29707986973403`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.961158174071347`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"80.58333622460194`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20963659080933753`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.29707986973403`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.961158174071347`", " ", "\[ImaginaryI]"}]}]}], "}"}]}],
        "}"}]}], ",", 
     RowBox[{"0.9234`", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"7.810509871075463`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.658144656848105`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.02649667251937`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.8908842726462`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"62.926170460370074`", "\[VeryThinSpace]", "-", 
           RowBox[{"15.658144656848123`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"27.026496672519375`", "\[VeryThinSpace]", "-", 
           RowBox[{"41.89088427264622`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"68.50122981057173`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.443606571400101`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.620466904032114`", "\[VeryThinSpace]", "-", 
           RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"13.385569221277159`", "\[VeryThinSpace]", "-", 
           RowBox[{"10.443606571400213`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"32.62046690403217`", "\[VeryThinSpace]", "-", 
           RowBox[{"36.656241212144366`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"81.08582224927886`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.41258000537293`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"25.97016165998426`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.11905307061487362`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"107.41258000537294`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.410019527358276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"88.72623375924718`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12627795169569794`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"115.05163809511701`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.40302717127308`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"33.610573169952566`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.12627795169569858`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"115.05163809511701`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"73.2255640326224`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.24124640092127708`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"152.94915336254536`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"18.109903443327802`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.2412464009212797`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"152.9491533625454`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.99078635006785`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"81.1851002487146`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20830597502517537`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.906109196267`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.958466389341233`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"26.069439659420002`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.20830597502517445`", " ", "\[ImaginaryI]"}]}], ",", 
          RowBox[{"160.90610919626704`", "\[VeryThinSpace]", "-", 
           RowBox[{"20.958466389341233`", " ", "\[ImaginaryI]"}]}]}], "}"}]}],
        "}"}]}]}], "\[RightAssociation]"}]}], "}"}]], "Output"],

Cell[BoxData["\<\"Wed 11 May 2016 13:43:52\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Length", "/@", "saddlePoints"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxF13lUTlsYBvCvT3ETSZIylltEGrghSRMaKEVJkiIiFUVKaHUzVKQyRBGi
WxEypUgq6oaSlESXVgMiaVBp1HT3Pns5z7dWq/X756xz9n7fdz9b0dlzlYtQ
IBC0kj/6v8A3+9J4jSZ9AfdTMVA0bN30cj3sJ6GkEhAGl7y1bdR4BKtcPnrn
Yz38t1vm7ki5Zt7lWj+0l5rAGoOK/Z0+cHCBTU5SAlwVGRJk/wae55hhNkL4
g3e4StPIbE34S9uUUk8nWDdrVZRiBHyaPi4TblyZPjmo4beVDKZG+OycMLKF
94qfEda7leC9dklzixbCiVk546ZZw6+nVvQEuMH9Ie0V5QfgGfR1z8E2q6aT
FYMDHxgc/PQcTp5ov3lhNfzfAW/j052waF0YWYFW3prmV4YbK8MOdx83xurC
IbLvX3VZw/f2t92xcoerayQirx2EJYyVfYQx8PwbemvW3YWdpewWpObD3PLV
wBkfQvtduuCv+gnV2ZJtvKW5BYT1hpfHey2C3Txbggps4DNl4q5TPeCcBX8u
238IborVnVUWA8uL2kqqpcBLttEHwl6vjpRW1cAX/vondX43nH/2UdSJUT95
t/eX+dVPgxU2Ndsb6cHm+cMWnV8N+6kpTmn3gONP6YhYHIaLu6w/J56Hex22
Px1IgafnBl9d8wLmyuUjHBD20F28B77eWmrhLNXO+x1tz+mwMFNMWkYfVqev
ZwvbB2u/e7odDmqgDQLftXKP2XMBrkw77F9yDxafEOs4oxCeyxU0vOFLCekQ
OGzZd1Gt0R28028PIRUN18pMKviiD0vtm0cqENattgyP3gG7chsMk2JeaXYR
fixJdxhu8E4b21sIj6Pt8Rk20vv2PvkXvCNehKxgJ++YP+gHw8+2a5Evhtvo
dtjBk7W3kjeEl10MnJYbDPsK6RPhuK33vnunwUUv6Q/umf31lnItrBQ9eCKg
F7bqk/Mul+7i7b9xzmrNmXDSs+XzjxrCZaou8p/sYMHJgF4dL3hWZ3RlZAhs
t44OGPjwkxdxS+/Dt5VrD8UWwRV0HNTCw1pkTa36YPp218Z08+bGvSocOoU2
HHyflt9a+FP9mZQRO2FJy9unXY7AOqn55ISDt5CvHfcAPkU/9xWc9ZkWIFxv
qk5OLFjmlsnHfTI9vA3GbPz3jSrs4bcvcdZi+GwlPdDgPKOb26p2wi1X6YbA
E0fWqJ24DJvu6hlV/wDeXS7dZlgMX6Lj7ytcSHbjZz/cNdTprPnYXzjvuBeE
V7w+6TCwGObabR185Xyewp1dcKmgSigeCg+Q3d0YB88slHqekQ7b0u0tgQ+e
WXzMow6++YsOQPi9k6/lZNle3mJPj8/eowZzj1sCOxzP7VBxgI/Q49cbTl3b
8fBDKFyTTQcCPILGm4ew9lFDMrLgzXTcf4OPk3QQPQg/Sg8f2iLbx7tu0tVv
puqw9CHaIDA3XhxgNwsaOOAoUs3Jx+BckjbE4uFmf/25jhnweFrOr2FjE1ow
8K7kYxWugn7eF0fTAxhm+Q/uoMtnDCtweRDm4oYPzPIhnOC1iJzoMMuLcJ8O
PYFhlh9hGzF6Yg7wDuTyJHyjmD4QZvkSHsINaFidy5swTVeW4TDLn3CKOp34
MMuj8PCey2RCwyyfDvJ2JtPARR6O4PIqnEHLxRSu5fIrzMUrX5jlWdiVa2CY
5Vv4SSMNRDDLu3AYqQZPEYHBb7P8C6fTOCoHszwMk/CSp6AJs3wMj5JIu7LX
BGZ5GV5It98RZvkZ3vq2zk3VF2Z5Go6kcSocZvkafkyquTIBXs0FKJimj3mZ
MMvfsCxtyDcwy+OwUfGWt3XfYZbP4R00DghFeLO8DsecIz95mOV3+NlAyv42
TZjleZh243JTmOV7mKanBCeY5X3YjDaEL8zyP+wTKSdqGwGz+wAc100CSCLM
7gdw0frl+cOyYHZfgLtzN1/fUAaz+wPMjeMGmN0nYCuS/qSHCHmz+wXsTz93
PMzuG3DSmhdz8mbD7P4B/w9seyZl
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.8906250000000001, 9.9},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.912, 2.2800000000000002`}, {10., 12.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"data", "=", 
     RowBox[{"Compress", "[", "saddlePoints", "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Button", "[", 
    RowBox[{"\"\<Restore saddlePoints\>\"", ",", 
     RowBox[{"Set", "[", 
      RowBox[{"saddlePoints", ",", 
       RowBox[{"Uncompress", "[", "data", "]"}]}], "]"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"saddlePoints", ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Global saddle-points map", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "saddles"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"saddles", "=", "saddlePoints"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], 
                  "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]tt)\>\"", ",", "\"\<Im(\[Omega]tt)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", "t"}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], 
                  "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "\[Tau]"}], "+", " ", 
                    RowBox[{"0.1", " ", "\[ImaginaryI]", " ", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}]}], "]"}]}], "\[IndentingNewLine]", 
                    "]"}], "]"}], "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Re(\[Omega]\[Tau])\>\"", ",", "\"\<Im(\[Omega]\[Tau])\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[PointBox[CompressedData["
1:eJw82Hk4Vd3bwPFNmRqoo4mkKEWUBjK3tiJDk6FChkZTKTRIkyZFKCSVlDEp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       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]tt)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]tt)\"", TraditionalForm]},
      ImageSize->800]},
    {
     GraphicsBox[PointBox[CompressedData["
1:eJw813c41t//wHGybre970QyykhaVKTOEfIpNERR0pAiikJG2WUmZGWPtBVF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       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->800]},
    {
     GraphicsBox[PointBox[CompressedData["
1:eJxE2Gk4lN/DwPEZy8ygkl2WsQtJtpSSOe2LFBXSilSKihalUEgqaZcKkWSr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       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]\[Tau])\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]\[Tau])\"", TraditionalForm]},
      ImageSize->800]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reperioding a saddle-point set", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ReperiodSaddles"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"ReperiodSaddles[{{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]},f] readjusts \
the assigned cycle of the saddle points {\!\(\*SubscriptBox[\(t\), \
\(i\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(i\)]\)}, returning the list \
{{\!\(\*SubscriptBox[\(t\), \(1\)]\)+f[\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)],\!\(\*SubscriptBox[\(\[Tau]\
\), \(1\)]\)},\[Ellipsis]}.\\n\\nReperiodSaddles[\[LeftAssociation]\!\(\*\
SubscriptBox[\(\[CapitalOmega]\), \
\(1\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},\[Ellipsis]},\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\)]\)\
\[Rule]\[Ellipsis]\[RightAssociation],f] reperiods saddle-point pairs in a \
harmonic-energy-indexed \
association.\\n\\nReperiodSaddles[\[LeftAssociation]\!\(\*SubscriptBox[\(\
label\), \(l\)]\)\[Rule]\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\
\), \(1\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(11\)]\)},\[Ellipsis]},\[Ellipsis]\
\[RightAssociation],\[Ellipsis]\[RightAssociation],f] reperiods saddle-point \
pairs of a classified set of saddle points.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info83674213688-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "saddles"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"saddles", "=", 
     RowBox[{"ReperiodSaddles", "[", 
      RowBox[{"saddlePoints", ",", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"t", "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"t", "-", "\[Tau]"}], "]"}], ",", 
              FractionBox[
               RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "]"}]}], ",", 
           "\[Tau]"}], "}"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], 
                  "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]tt)\>\"", ",", "\"\<Im(\[Omega]tt)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", "t"}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], 
                  "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Point", "[", "\[IndentingNewLine]", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Map", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "\[Tau]"}], "+", " ", 
                    RowBox[{"0.1", " ", "\[ImaginaryI]", " ", 
                    FractionBox[
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}], "\[Pi]"]}]}], "]"}]}], "\[IndentingNewLine]", 
                    "]"}], "]"}], "\[IndentingNewLine]", ",", 
                  RowBox[{
                   RowBox[{"saddles", "[", "\[CapitalOmega]", "]"}], 
                   "\[LeftDoubleBracket]", "All", "\[RightDoubleBracket]"}]}],
                  "]"}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", "saddles", "]"}]}], "}"}]}], "]"}], 
              ",", "1"}], "]"}], "\[IndentingNewLine]", "]"}], 
           "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Re(\[Omega]\[Tau])\>\"", ",", "\"\<Im(\[Omega]\[Tau])\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[PointBox[CompressedData["
1:eJw83Hk4lN0bwPHRIlok80iSIkukRNmKOgehtKANiVakSCJFpEXZIkuKIiQp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       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]tt)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]tt)\"", TraditionalForm]},
      ImageSize->800]},
    {
     GraphicsBox[PointBox[CompressedData["
1:eJw82Hc81d8fwHGr5KLMcq91udcWDSpSn3fRMpoKJZUikqhUZlaZISkiIyPJ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       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->800]},
    {
     GraphicsBox[PointBox[CompressedData["
1:eJxE2Xc8le//wHHzHDRUVhnHiAgZJZJyrpaGSihUslJ2oUJJITMjojSUQkka
KlnhumVkZBOVUXalHOfgHPt3fR6/65zvXz2ef5TXPa77ut6SdzhrdoqHi4sr
QpCL678/xcu0/24+PUWVSF316lgvN0HBHjozeEn5NQ8xs5oncDZ/lkqP8KCQ
ZLkJfsX/t3TRI1N9My4iE/hKj1WtBN2kMzkbHtDhc+xdHq2S93jHoG5fh6nh
71VgrZ7gyKZkOtyEHfvgrFkKzxjMMTDIuX9XHvyyj1dsifyfr82olrivZsCZ
ikHLrVoK4OjfTW/uUv7nUvMUCa7QMbiZptRoN82iFnhGSJv85iEMsX+lfTAJ
luEhxhkXYrfumaNuOfPhxsOVXMQC9uzmCGu3AS4i3Pgh9/aUlWBIucFpPepn
+2Dsxvo7qL/47kxNtrgkoLPWLflxn86xlW3iOSPUXzZtf/5+sDxoFYh+GX39
fz6bqrR7jSIDeixPVJY2UgDTS5wtDUPGOE7M4B5rl2HA2shHq/89YVELV/1t
sD3AQ3zGjhwsSFaX5CXCVCp1mHCOau90zVoyj4tIxN650UP2fusCzOgukr4Q
sBKsSHnsEY96n2FnbTIgq6HreSXZFnTEQBLIvG0PHOUe4zjf2EsyEl3PnwPC
Alln5cGYr3vVR9Q7gm3V3ayxNmoMDt59btRrqQAW+wcs1UO9Q9jeP/vOP7g2
BiVKYImcLYu6Tqbw+R0fHmIVNvNXmO+pHbyEgdLfzJG189R/n0nZ20IXIMDe
t6Ex3eMGF0HXsHIztFsJNH79I8mhXgZ2oskRjzB0Pf38MlYXj0uCkumB8iTU
/wvbLPGqjTbqn/JXr1hhKw9im8JTc1HvNPZaN/kth5QY8NrvL0wjJwXAyqMf
zJRmwBBsG8rR98Ko/+6Cblq4PIv6PO8Z0/g+D5GC7RFyoXylMy9hHZ3FuHEd
9Rp5yRm5cxEu2PP0PRl0wwVIkX90kmK0EjS5p11cgfplsfVaBH/4oX4SU7Mi
2U8SXFtDv9p+jw4FsH9HWw1uRdfzqOF0qtAhedBYZxpsEP0/uzr9kWpD/YmD
Ul+WX1AAfemr+mODx+AtbH/DdwEq6HpyAvUCs34zqUOlV8GzIh4iF/tt7P4l
FyJ5CVsLxsmj/fPUXgedPRf2c3G8Sb1h8tDCPGStNj8CNFaCvrFHYzyofwp7
rxXZygX1y9V4+txKkAQimlykn1xjUB77ZdXdlEvoeriXePit3i4PVsxWh35A
/Wy/uHVS9sgaBtx6buLmmyAF8LcqP1EC9VOxLzmYabyRYsAy4ek6ngImtXuz
aYnrdx6iCjuLTInSe8ZLlJu8DGjZtEBtvJyn3Vs+DyuxdaOeDWzV5CIsNi9t
lF25EhwCsxVj6PtiiZ331EHdCvXHbDv5e/iFJCggwlZIot5YbIryX79AdD2p
vIu/SWyUB+F/f8rox/zP8uH+ec2oP9smUsYtRgG8SLV9lhE0xrHRlqlt21D/
1IWmdyFRTCrDiWIgwuIhprELdP6Qf5TzEhpK9KUCkQvUNXaXtOVEuQht7Fdr
jlc/jZ2HQszeipO8K8E3w8MaPaifbfCkMHEX6u99l2UyVo76yZ1ZUqi3D/vw
4wu73t+lw+S99L58FXnQLu4hnIv62fbKJmWaKDNgZIVUs/sdBeB6dlXOVtTP
Np/guwPtkgyYnyr9+7w9k3rglkbv7ApeogxbyWHmVXUPLzHEtDXJaVug/qgx
IAVPLMB/2Oraqe7Dx+fhY696+udRCfCIe2euNupNxTa432VSi66nSNxWdvS7
JDinqCP2doHG8ZKSulfGqN/xVKbIgLQ8GI7fU7whdozja2q9FnWoPzF0Y2p7
qgL4Mvw4ryNwjGOvYANTb9SvJ1IzsXszk1p+7tLeTVO8xFbs2acvL7up8xLN
6R5mb4W5gNuYnUpBxQJswe6w/BQrqz4PiX8Pr6h3SQA7qsHOXNTL9qcnj59L
o+vpWSsTsIIuCb7kv6jsvEPneIusyLod6Hr0jLNPX1suD4y86b/2qzA4ftlh
degdup5OqZjxshcKYGPltUlf1N+F3WArE7cc9Stzn5dPEGNS/8V87Lddzkes
x1YonZBI2MlLNDGPHtm+gQsQLRWS/fNzsAXbxsM2J+DOAtS4++WWTa0EUNSq
vkZCvZrYxdUOMo/Q9ejvOvsokCwFvmjKOtfP0+BmbM/qfG5ndD3dIDMykCQP
OkzrnBtQP9vU/A0NG2+MQdczH87vzFUAIab5PyVRvzu26B9T/5xVDLj09eoM
HsYkdeEDX0HycV5iOXZVRFOoiwof4TwpHJJzhAvM3zm7uL9lDrpg31kv+DTA
YwHKOVmv2l0oAZoUmEMRqFceWy/yxMFRtL8mGjxRtpSWAo17Xm4wR/1su/Ua
1Y0k0eGBo69l6mbkQM+VP5VH1jLgQWyjAdN1Rah/fFHaZyeoACz4bqQdQ71s
l7hOCJZeHYMlofZHzZsnqf+merR9DPmIKmzKOpFTmV68RL7Vuz5VXy7w1BvY
dj2fg4XYBou/sXx2LsC682suN2RKgAWxTy88UT/bpy+vE2lH/Q3py7e+0pIC
zwWko11RL9vLzwbTG+do8OvR1HvWY3IgXFl39AfqZ/tfTPKR3XHo75fnEPpV
CiBu7mI2L+pvxGae/CHuivrtRdodDr6bpIZnLlZrDeMlTmMf8fnKfGTOR2SM
GhiXJnGB02YCtzbILMBn2J/yz8zcvTYH5e0kjgzclQBj5BovS9SvgG15Rquj
GPXXKfsL3NspBZjtVVNGqLceO97LIeHHbTpsucZzQ3FIDpD0WLVeqgzYiu32
wGZ9B+p/kOD5r6xRATw3VysVQ72PsDf/LT/2eiUDdv0eMq+8NUk1SzY+xuXM
R/RiRzZcidlwn5e4blveGZvHBb4FL+0dOTEHY7EvSz/zD2POw5BeG/uL1yVA
jcvnzVtRfyi2VuP6x2mo/1NdSLaalRTw2xinfBD1st1zfzImZ5YGKzUkJaW7
5MD3I2XvzsaPcXxh1PqAoBoDBlUfP7T0qwI44yTjfAL1BmO31V2rL7syBqEm
S+DWxUnq94CRkG+veIlS7Kf7Ckwz/PmIiZ+BKzK+cIGTUe4q2fpzcBJ7VpH0
cW/LPHSBDQ1X/CVA45NhQQXUz7beYhPPCNT/x+eNiLebFBiQWHrx7S06x/uv
nO9ZifqvcLdFGbTIgduC99uW3hzjWCtN5+wz1L82sEv+ns0k9SR8suVrKS+h
ha0a7S34NJaPeFYle01yggv4mU5JnMieh1nY3Xm2V8rE5yCjX7j4t7sEUN+9
08gd9YxjV/7o6uFHvXeebTK9dEUK1Hz3frT41v+svf0r6dwMer+VXshcrpYD
qsy+9FzUx3Z5XIDhIXUGTLXY21Wwc5JKOhnmLvQY9WBvvF2QsrWVl+DfrX6e
uYIbqI+eFl00MQtJ2LURXK/S0f5J++7c9M5GAnR4mBQNo/PgGDa19b2CyX+9
XWTtQ/FS4JFLDNfHaRrHBrzK944nonkk83lRO5QDTiG+u5wTxjjmpizv4V7H
gKs0CjZ3qk1SPZR643685SPksO9biZWLDPISTPd1e/dpcYNV390qzrTOwins
/PP8tgJn5mGw9YHJpkMS4MIU40EN6gvB7rc9xqeN+r5n8V2YT5MCKrbUbQ8T
6LATO7HiSQYf6u0x2d+zJ1cOKDtrshQTx+AP7I/c1fElqM8vW8dkRGSSWshY
LLShnI+4hD2yBmw9zeQlQqknvsoc4Aa8ckNC5w7OwzBst7ADXl9zZmFoN03a
cIcECFtREJyF+sKwR/xkfy1HfaYKpyVv5EqBoGqzvS036dAMe1Cz4LX+FA2a
qWWerHkhBxKKznwI12BAc2yWQpv8P9R7MP0IbJ+doJrPq54wFOAjrLBla5lr
F7XxEXkKhW/9XbiBR9M2/023Z2EB9iK376LNmvPwc5fjcvpGCeBi0O0UhfrY
bni8s34MnZ/5+Ok3FlVLgeLNXHpT8XSOVz8+/cCWhfa7RZ7nLNPkwI61uuYV
t8Y47v7YMGKjyYCz61cfiR2coFLnHzilr+Qj5rEFal11vAb4iK9f1pm4h3ID
vZuzDv5+s5DtFrXbs6Ir5qE8ZYnlsIoEEM4R3OeK+ti+IOmZ3Yj6JEcf9F/+
LgVsasstlqI+tsu11YrPM2nQeGuP25+7ckBBvMrsxe0xuB/7w2v7kV1aDHj6
HlcWd9ME1e701Q8paD91w167YX+E+wQf8WGRKpX5iBvcPbzaO+H4LITYRv+K
Fq2bmIP7lqxZLC0tAXoirZT2oL792LtoJVGvUB9FZtvYn79SYKQ59c2yODS/
YJvpC670naRB5ctHq4Li5ECt/0mVJ0ljHJ8Smys11GbAq5+rBxWLJqiGbQfG
dTfxEWHY5FTJUl5+fqLxyLr9q4u4wVzWsYvnqLOwFfvBrvEVS77OwcHF+c0R
whLAR8htQhH1/cLu92w6HoX6IjqCrtpzSQNrCctTjhM0eB17Mps2PxdLh9pC
F5eKh8uB/S7lam/vjMH12EM8NhXG6xnw/ZvgoJEM9Hx5LZq3iPITudjndSP5
PXfzEaMb5xMnv3ADAX2fu8KKs5CGnd4svCGzeA5+DyktVuVFz9flzHsu1NeJ
faGhVcoJ9eW96z07uEIaFJ5zudkSQ4f52LLfGlj64zRonvysMC1ADqy9Wyj+
5e4YPIxdtv5w9tkN6PkGDa08mDhBdWs5YnrIgo9wxdZ/pECRWc1PiPBPpPuM
cYOhKzriJwRnoSj29ZX1rydT52DO5uxt85PiwFhL0e47mm/eY8Pb1yu3ob7m
ZUU/rilJA811O3bFRtM5vpWQmTVOp0EVVUv1NeflgPfNPdKi98c4Xqze+/6l
DjrPPmvdA4ImqNbuhz90OvIRm7G19OUjMrX5ia6bR8OfLeIBH4vjtMxGZ2A3
toWlas2fCLRfD1xS5vojDrYwhkZz/pu/sFOPHrSQQn3nIbfVjk3S4MHheCvV
KDq8gM37gVkSN0aDfhtb4u64ovt3iPxIUJcBL2LfyPUgeSaj+Vqbeb3wDFoP
/mfzV53jIwSxx3dvCR2k8hO7ScntcUo84Pja8kdXz87BPdg1N1TJg20z0EGu
LWhdjzhISXxnE4P62OafWVXBQPMW1W9iTMNYGlQ6Bx5Mi6RzrN4wmCNIo8ED
3oW1E3ZyYF+L8Il/D9D3DnvAPXMyXI8BdVbGS723nqCeVVhQ6TjAT2zETj+y
3npREB+x2IK3YQOVB6T33PVfVjwD2d5+cYPYc4s5uMNQPP1aizh4cFrhqSPq
24W9qC5icS3qK7xum2RqIw3kM3/mMsLRvIUdLrxH5tg/Gjwr/Pr4Jks5YGWr
skFDn8ExrIi9m5gyBpkRdr0qxhPUFjeK43t0HpjDTt30Ryv4OD+x8HPvoVtW
PGApUSlVkz4DeXr/38+P2r0/aYjO83rBklxV4mCVxTm4GfWxfbXoq9Jj1Gfy
7Llhnpc0uLxc/5D/CA0ewhbLav4lGkaHTyNT9Y8dkAPVV/TcXR6Pcey4somf
14ABY8RGbIQ3T1BvmB7bJpXMR9zCtqYoLx125icC1oWP5XvxgH2fYpYujpmB
bA/bKT97smYOkoXepz0qEgfCe6+nCaM+Ieyg1zRBH9TnKOO5xSNUGjiViwqf
+k2Dp7C5bV49m7+GzgerzmQf3iEH8rJdpC6kof0De/8+3vdLt6L9biI5yWEt
ul8mjX8X+/ATbHcF88qDTD7i49a3fKnXeYDr8/xkF+E5WIZduUyWt/HCDLSe
n1M9+UYcOGy0fLMX9ZzAnq2n7etD8/HK5R2ZwXelQchw+sLiYRqUxJYNNrz7
NIgOd/wKXSunj55nw0WBj0/GOD7qIpJ6nMqAAsc1FsmsmqB2r1UlGMH8hCC2
2IkTjDW5fES25NRD8zQe8Dl6S1Emaxa+xV7LSFVYZjsDVQ8Fl+16Kg4MDL68
/O/3DWrYjx5vEZVGvV0mS38LvJIGtmvVIhau0GEfduGN+H+nBtD7R1rz+52G
HDjH+ENibmNw/O2omceJZ2geOLgsXV9wgqoXsdi7+SMf8RKb+8hXw5Qb/ITV
TkpK4wce8HW8gvfTnhl4DPtCrO0Du95Z2JFASje6Lw5ObhEuD0N9X7EbUi+o
/kXz+RzttrVomTTILCs0Z/nT4Ty2sKp8oU0vDe54v6KQX1EO1Jh/9LLKGuPY
8e/xRfSd6HwAz7x8NzVOtdEPVdrVgNYHtgrJjL48mZ8Iq+Z9J9XKAzqq/PQj
P8/CSOwtmj0po+tn4BqTnasd48RB7yn/P0WoRxk7YEE01AL11h1+bVrcIQ1e
XW/fd8mPDuuxRca2vvnRTYN5zkdcBFfJgf5rIZ+rX41xHChDOX1yDwMGztyv
Dvs9TpWEtS5B3/mIa9h/ou7oHnzGTxh6h1jrjaD7Bbz3hsrMQLbFvi3qo+TN
Qkmx3JzkUHHw7DfvsCLqYXupqevBKNRr7bjVQX5UGhz0MH1y+jwdnsDOaclb
VPeNBtMmdBSzl8iBsAQB48a3YzAdm7Iutd9lPwMeUMn89er7OLVX4AzVIoef
OIQtsuWxd+QQmo+y308o8fGCRv6vadcEZiAL+2yK91aZ1Fmod7Bq4N8lcaDN
uts3dofOcZIN1z4r1HcrRsLhFEkGfD+j08Zqo8Ek7AsC9WdunqXDjy68l4a4
5UCS/ZpALVMGx7Ofogdv543B6iwuI5W6cWoF13oTWwYfUY99q25eSp3gJ0rP
Pcv5JcULGrb+vj/ImIZl2Kfar20MjJmFIX9sjx/1FAdSBTpnilFfKHaQ7P3W
1ajvZ7rP3nyKDAiMjxdc00iDvdir1NTSoAsdlux/06j5RxbwPz6xbcKCAQls
V3J5xvHiMShT2GU5WjJOjVJXLGyq5SdWY0Nby798C3zEHb0Pr0I28IK/Nhft
n/dMw3vYIawVMzsuzsLwkucN306Jg1N8DQHhqC8Su8l1Y//feRr0CC3Lt9wk
Aw6cfjcc50Dn+N3nVSbMKhr0WrNt/a4mWSDU8mzEv3yM4yfu28PEbBgwyy64
hevNOPVnwZ5fe9r5iVfYy//6S18WQu9fSfR31j5eoPAx3r62dhqyXXpcbcbx
1CyU0dFc5n1cHLRYzJMPoT629Ysdz+SiPnurFSDJHD1P+1MbvI/S4Unsb59q
73ZAGiwJygj48F4WLE/dUhFVN8ZxlsEXGyUnBuw0XJF2NG2ceip8xjqhl59g
+16hRlylGD8RY5YssceBF1jyHN5mlD8N2R6///dbj+ksPNS6YlbGVBz8Gxjl
lkB95tgn9ls4B6A+iZanCSOeMkCGcaWz/t3/nB+90sf5AB1aHTg6Ln1HFlTK
uWwP+zoGj2HbF/J0yp5jQCeV2Z+Tt8ap/9Z59g7I8RPO2AXTW16//ctPPLuW
uub8RV4gbmX3VeLJNMzCzh6b8n5jOAsHtsUFdxmJAy7nU3adSXQ4iH2qvrZy
O+pTW8MM44uXAYt/Ut6lbqFzfG536CrBNBqUHt9SUOQrCyKKT57a8hvNA9ir
Lefm264xoI/hj462CPS98y699V2Nn7iEPWEY6/CMxU/wJWW9vxLHCxyvH6n9
ojYL2a6gfdDeenMaSsXdfvx6izjIjn8j8Qj1SWOLsySukFDfxBNR7oEcGWDv
Z61guZoOmdifuj9GFEfSoBJzQ2eiObpf9femfHnpHM846SQsf8CA4TW9Uwz/
ceo77XnxTF1+Igo7cL6m7wIvidgfP2PtksELekI/SBxYNQvZNhqRv/Lu6jS0
y452TFgvDm7uzZFyQH322DOvJYOr5tD8/WgshLtbBqh25l96b/M/V1wwEzVh
jUGP6qombVVZMBG8x1iwCu1v2Fa/Xr05q0GH4l42XQfPou+LMhmabOMn2L45
3hIlvZRE3Ir/+HhjCS/o7nsr6ecxDe9g+wTsz1lOnoU8ATp94SpoP4v7YquA
+tjeyNxSGYH6nmTDXxmLKeBg5tMjJaljHL8XXlKkKEiDS70rCnfNUMB+kdGy
UXSeWYY9+CLiRKTMOBzT/23Y7zBO3aW+o7XRmJ9gYC+fEn78YCWJqNmVwexv
5QU65vEKChMzkO0HBcyIiOPT0D4yE0RTxAFTltT+3+8D2bYNc9+6G/VRNcZ1
iI0U4PGwceOJln8QYDcPB+ns4R2DL9coXR9uooAJ76Qr/4rGObb5Otd/eDUD
/g7PnH5jMU7tT5iJWmfBT/zDfmlXZTWtQCKSvdQ/+v3hBQl3PpEu983AB9jj
8+s8evdOw+Uufs9TRMUBb272uQeoj203aYlvvKjvikYAffF+CtitdFvQ6SAN
BmKbSkz13HP5CwePfHlh+YECFOlOViVeExzHW9WXKHYwYItXl1DuPnS/JO4s
crLjJ1qxf/Q5dmxYRyIGWyeO0Ln5gJL6WSWZ5hk4hH3jZlvUtU3TsP1mrWWp
kDjwlIDKVqivA/tbgFJsySwNRjwX/ONqSQEzdyUm7zuMclx3uv+js+YI1HJw
Nc99TQGklwXr1C+Mc5xhZP6pYukkXCuWHfrPcJz6prfY5YorP6GOffX1dV1j
PRLxUI02ZbaSD5xZ7/fJRXkaPsbm+7zcnrcU7censiJoXOLgTuGN/mWobwqb
R35yny/q4+4I7VxvQwF2xrz5Tgp/IC92whXdP/eO/IMxo/EFWc8oQCeD217n
1iS8gQ2XOH+6NzMOZ7023D+6AT3favnL27aRiAVs8bnDr8+fR+erUNvh+xp8
YNd+w3z17BnI9tu36ZQE8WkoomYSqs4UA5KUsXufbtE5Dgyx5NZAfbqjTofK
HCigPWQt86Hub46X51urNqPnm+JZbfI1jQLKVWqjSIuYHG+4oU13R8+btSE2
YUJ5nDofu+OJhDGJmMfW+OjTse8KP3Gk5otJ/U4+sNly5fM5/mnIdjvtzY6k
lBl4SCvgwfm/qKdCyuAy6jPF/q0W/Lh3hgbvazJcxE9TgHnb3q7K2yMcr0sV
f55w8hc8ILzs785HFKDtM5Fz8TwTHsRO7Dwu9ePbBHwUaFpHSI9T174STa0/
TCLSsS1/7m7jjuAnFPolD/85xgciJLN0tt2YgUrY/wKX38+YmIKfrFnKVX1i
QKojK0cD9VVhXzVcIXUL9a2iB4emO1OAJ6XU5vuXP1AKW/tPjNqztGG4e3mS
ps8DCnDTipMo2zzJsWDN2jfWrUw4f4XxoWD5ODW3KtrSyQY9X+yRGXj9Xjw/
sbyYsXTckw9UXvikf2NgCrJ9Uti+ReXqDGyomQpa800MJJdxndiFehqxdU/c
m+xOpMPih5d+vnKlAPlo5UckxhDHNvBYi/6aP1Co9XOL2n0KeB1y/gtXwiTH
+ylLPe+ps+ClJtfBbhI6H5TatYjd5yeuYq+LXfeo14lEzE6NxP0K4wMHb/D2
v22bgmwPqzwI2H92Bs4rvl96o1EMPF6mOxqNehawhXyTjzCmaTB/WaW8tTsF
+LlF1I4fHOK44OGHeeXg37C/ql2LepcC+IyW+032T3Kc0vN8edwVFtzwamhA
Y5ZBTZl5vn+bF4nYiN2s0X31fDo/cXS1QO/nZD6wL6pj0fLKKXgMe1DR+8lz
NL9JPRvU5f4kBkqqpaI3oT62lbSC6Q9RH3G+AJZ7oPXq55N+9v0gx1VZme2p
w79gxtG3VUlJFMC9w0GaWsvi2CuzKviJNhPWPclwfDbGoCqsD1MMuUQiGrEP
nyqwzHvJTyz+YM+T8hatX5kLus9yp6Awdm/u0sZth2agTJ2L8+ViMTB2RqPw
ZwIdymIfbUuU24P6vBbXLJs6g+7H53tBCla/OPa463RwVHEQXtl2ZpvSbQoo
uRk32HSRCYOw7dRVA91EpiDv1Z/S+4YY1EL7hlU9ufyEEHaYRvJg1jUS4ZtQ
89uuig/cq3uWuGzbDLyIza0jPOOTMQWlP7SLceWIgbgzsaciUB8Fm9k6Xvtv
igaf783z5vOkgLYXnxfONwxznHHx7udtyQNwRzdZvzORAh6OOqWJljDhTmz9
SO6tryynoHJHZfuKLgaVVdB5eQTyEyrYZWGZewuiSUTSbYsYkW4+EPZmgPvy
nSl4H1vO+Op9MTRfVheo50Y9FwMiuXEX1VFfDba/NLPnJuo7JhcgOop6JPqa
fntLDnBsLs5PeXpgGDYkeF7OSaAA8QPxZ4LQv9+EHfCO2To0z4QTQXfduVsY
1PBTTM0fVfwE2xbry2df3CIRjxf1tuUx+ED8OlqyyeoZmIo9kWDBmxs5Bevo
58opj8WAoez7H3U36Rw/DZXarYP62qcJfuhFAY/k4+WKHvZzzHuk3Hy0aQi2
1lNYGTcpgJ43TbzawuL4pmnisT1fpiABm6FoNYP6xW/hW2ETmtewH+/6nBH+
kER83B/7/KAgPwi3f2xXLDoDy7F/fyJ/Wu0/Bff2+cH8JDHQsi85xB31sb35
Dc+fZhYNvvzj1+PnTQF3aRoZL44PwdfYDsUz5y6q9MO7/I7Cb+PRevY5uXB4
+TTHcl3Vpz74suCn2mMfjSGD+iiNLBvwjZ+ownbzbP2zN4NEpFbqjnRQ+MGt
jMKiE6QZmI49u0R+dbn7FFwzGrD2aKwYWNMze0AA9Sljx+46mXMG9QUFlmvJ
naOALRUTnw//HoTXsEVufrwrn9cHmQfiNRviKCAoiIdvBJ2H2B4ecnY1y2ZB
QdUGzyfvGdQ76rm3lfv4iWXYJ6eCT46/JhFDfD0+ljr8YC7y1swtmyn4Cztu
teYtTdY0NLnNDF8IEQMOcncUH8fT4SHsqrD562TUF2p3+VMe6lHa5+t1LmAQ
hmMzxHcagn19cMDqVPjsDQroypucejnI4jjANC5hd+A0BP5fmuVeMKgZXW5p
4fkkYgf2l2UpXwr/8BMulyUVavfyg6AC/213Dk1Bd+zV5mLftX9Pw88dxiez
/MVA09bEIw+YNI7d29eN6qLe0iu0n9vOo/2/eGw2XXQQlmHHXy+p9vrZC9eR
97fpoR6emcSfC5JTHD9I1PC/mzMNc9MCp4tSGVTrriQPvXF+4gO2ynPHzXyl
JOLn2zOlOrb84LLx4uiTndOQ7d433vTq7VPwsf0tI2tvMWDlfzahOo7OMfzZ
NqWJem9rfDUlUE9swH37hNcDHFvvc9awu9wL63e67bwaSwGaxdZrzx2Y4rjW
YvLj4iF0vtR7y3vxLoN6o5p/4MEsP/Ed+9jt5jeu1STi+JFsxVvn+YFbushK
1Y1TkG2y4cs3ZfXTcJOkKzozi4GzcfQJK9THdtuklTWcpEHTbNdbOhcoYLvT
3HlCspfji/e0njEODMDa+BjzphgKYA68GaqUmOHYdv/Kg+uuTEFbg3sih+MY
VL+jjJgPTSTCDjsrek3pPz4SUVZ6fOXfSH5gWX7mU57yFGSbcULA3rR0GtY3
pp+otRUDtzQUpvtv0GED9mxihJ0x6uNOevErBfV8KLtKDhnt5zgybn/roaKf
sKWl6qM66nl6KmCjycsp2Ia9bUG8YdhoBiZaalsdCEff5+OHg1SXkAi2K1Xk
DzK/kgiHy79ObU3hBy7H1AsXoffBCbuGuCnnjd6XwjTtdxEWYmAT6fZwywSN
45YUzWAP1JteRbHi9aGAa/5yJ4US+zk23fNXs93uJ9R/2R4aF00BJm+b/018
m4IG2L+M3SNunJ+BDh9LyY5XGFTXC7semYqRCEdsve0rPCi9JKKNS7Y1LIcf
3JShHLRaMgW/YKvn5Q2NPZ2GDr87zfceEAOuJJ6z9Fg6x43uzm1WqLe7hVxq
i3qGzN72ywr85FgmbEDC3KAf9t+rLpiJQu9f3qHB1kczcBD7tkzefgPyNGxU
8LVLusCg/o7bnegoQyJasPNPiNpr/yYRKoetlWuq+YGc/TkK771puBY77NPX
EBcu9D4eU2xbvFMMnGYpPjqH+qyxP9tEkb6No+e762jfe9Tz5NDVxtk3Pzjm
C3nLqzXQB5+uk3nggXrMlZqmG2pnOC6I0rPXXT8NNRsnMgbdGVSh674NJ5VI
BNtfLXYma9FJREzeoLxADz+QOGLN+4TBgjewX/+bSDaMmYaB6kL1zZvFQMhJ
6WOWqIdtmbn3DFoMHfLL1juQfCkApG3/4Bvfx/EyT+GInTY/YJPeo8iB6xTw
ZfZP7wyap9n2uh16+Raat7d2sFRNHRlUx6Mfo6WnSYQh9r3oCWiC5svqZq2Q
beP8AJx7v1xoiAU/Y3cvNslCnyJoKfT7yz1tMXCm/ZCRK+phu21r3otGBg1K
7837bIp6nFa+zm5a/IPjh8a9fXygDxZIp446oJ7F5TmrNlFmOT6nKhX4MGQa
7jGa3PLlOINaTxZvVNlIIsyx77T2Jk9wkwn9TLklvoIkUL5UnvvONxZk2+FZ
4T3t89NQMs4k0lFFDLD+2H3dhXrYTgid9u6JpsPvtKr7d1CP2vStzPe0XtiJ
TYupGOHz74HbgZLZQCQF5MpuK67aNcuxdFjGas0X01BQu1rvgjmD+vLJjdOj
W0iEELa/t/WGIkEyUfbE/FImhQQ6PY9XDDlNQ7Z3tpeqHaxnQfsN9Vc1ZcVA
5w6vglw6DTpg+3YJmR9CfUl6SgbfUQ95J8PYLa0X3sV+IR+o7fmjG54wbNnh
jnoO5m2psnCf5ThXJk2juHkaZsra+68zZlAHjc+981xOJl5gr7z6dDBtJ4nI
I9lHfN1AAuc+OYyrfWRBtpfaz8ZUoPdlk/23IzNiYmD9c9GSoig6x/eW+Suu
Rr3KyY0Ckn4UoMiUEX25txuuxR7V2F4saNULC3zDHZkRaN4cttpOi5+FJdi3
D8JnFmh//2jn4zG/nUF9Fy0fILKKTJRjD8LD2Ub7SYT+P0kGeS8J+PF8ta0x
mYYG2F+dqZVauSx4OjMt49NiMdCj/jlSEfWxvSthPe36GA0mbX9jeQT1RF+K
3ByR28WxP833kO/SXtjfeNA2DPXcgyYuAjIzHG88+osnNXcW7pzcfnFoM4Mq
/ttTrsOcRBhh9+Ru/ZsuRyY6reovbLQhgd5bzaLWz1mwG/uipvuriR3TsLJ+
dHkirxhINDKj/aXRONb88Scy/DodEiLrvWJQj7OdcWDzmi6O3fqsziVX/oTp
z8qGV6Ke4MMtLb7fZjkeLtTf3A1moFMpVXh4PYPKl/3whJIKmWBbv68pzuo4
idDTD651OEcCZXK7Jow2TUN9bNXwrOMvH7Lgo9uT2nbToiDquETcQCSd47HS
gElj1NtUmHz7I+o5MP/Q+2TgT451brdfsbvXCW3m3xa/CqeAwW0/J3pPznAc
9P3Sjctzs7D80UD6giqDmkZsVbqlSSYqsFsZnlZVDuh+Tmx8HRdBArp8eymK
CSy4B7vuQW9esfo0TFlv+ERtTBQUaxS5GaI+thVvKTSnj9KgvII+zwTqmRW4
tEZoeSfH7/Q8jfINfsLDa2Yf70Y940r/HsmFzXB8A4ZvLpSdg6f0vXPWrWZQ
IzMt7ozrkgkX7MLOyFplVxIRFijbCR+QgOP6xKCj8tMwHLvizvQQDGfBgwp+
gpNDouBHFO1XfASdYyO6xSHWPxo8Xb11WPEiBVTHVZyKYP3gWOOD4qnn179D
t+wU274wCth6cr3k5m1z0AP7cfWdwEcZM9BvbXaRlxSDWkALFdhpSCYuYo+s
LjDwRfO6xf5fS8bekgCj8JNx4GUWZDvhsP3AKvFpuM/VZrakWxQcjjdp6wmn
c/yB+d7ACPU5tN/1NUM97u0DHRTyd45plKcpH3N/wM6H4xVBqIfb7+knPoc5
jp26F2u4Vc3AVqePoFaEQU0JGSi/totMfMFuyVvJyvVD55fdNC6lKhL49cW6
39GLBU9hh3pOBswLTUNZrnipsDZRUMPVMqGM+tjWctK3jv1LgzbDKd8CUM9D
q43Ru8O+QTvssJ4DUxY+P2Do79lnCqjnkr5FRsTwDMdiLaNAIXgO0u7SP+kv
ZlCjmpQlc/aTiTHsj3zHDwxdJREHFYO9rbtIoIU6b+5xmgXNsM9+TfpL4pqG
p/ed4zP+LArq1Z4vcw2jc6xzc5lv4wgNiqom6WWgnvQPQXG6ej847l32oJAk
8A3eLGv5URFKAaynjcy7j+dgIrbdEj0bLoFZeFQ9uKuIj0F1SeoPFQgnEdbY
6x3fmLWZk4m7stLyd+gkcPSZZPf6CTSfY5ctDdp59zhaL7cEDy8pEwWlHUuG
n4TSOVamnj+4GPW93qT3ph71JB8MTAbRX+EbbJ73gzwZ9B64XFJ7rxvqKdik
u+vrmlmOLZobur2JOei6ELDs8Byd+vpk/y/JWBLhhn1F603u0DEy0Xf5+ecO
MhlY8exzGj7Egv3YzPt9XMG/p+CD41+efi4QBeOdywy+h9A5Pr7D9/G2PzT4
2GyF0zjqWVw9t+n7iq8wDbtO0zFl28UeuLtjnliBeprvEuffdc9xvIlL+fsq
tB87XU5kzE/QqZEJetF/7NH6xf5Q6Qopt0jE9fEqXVkZMlgVYHbhmBELRmG/
FR9ZOt4zBSd25t2JyBYFWxU8KgRRH9tpES1qnr9pMLmGdmHlJQroo/ilKfL0
cBycv3xryf0O+Hlwdm1RCJrHP9htrHKY5bjo8HS9/ewcNPjzV7r4H526RWm/
xE9nMrEF+4zV1X2iyej7Z8y32n09GeRVb9AcNUDPE/vgybqqiLYpeDu/tBxk
iILQyv1U7WvoPID9R/3dk6RfNLhZTI61GfVsl9vW3rymAxpgZ4VlbNWP6Ya7
kr2cnVCPfrVH6rVV8xw/1mwV+H11Ft7oI62JHaJTjd157lWdJROJ2P4pG+tm
UklE+EEZS2I3GUSda56k1k7BCGz6100nnmqz4PoBSsX4A7ReHS6U5Q3TOK6d
WXrCNJgOl53M47dGPZ1rdZJ4c9qhCHZq3L05F8luWJfR7yCKeq6WlRhTdOc5
Hlir9DYkeRaa5kVnef2gU4cLiPC2TBLBdm5YzOFUHzLx0PvAfekTZOBstcxl
VekUTMVuLfFpuKrMgjulh9anJ4qCu7sEGlyC6BwvZJ3Z2DhEgxdtW3L8UU8Y
qfjQlh3tHI+5r85LzeyCQl293GXXKCDx3/CWB/mzHGtFBH/RNZuHQbkGB5y+
0qkkobD8x9kkgu3WL2ahZwLIBONQTGGQNxlIK4+c8JdhwXHs90QoUzRvCgbb
zj45GCUKSEvSM34M0jh+/HTrtkuBdHj+dM2qe6jHuX67c+PmLo4XO3dyu7Z+
gRo3qjXPoR7bnUqum1pnoRY2s6uEt9ljHmppwpdnmulUJ6ZGsl0eiWBbt3zG
eV0ImXDb3RVMCycDaPhs+I4IC7Jt3bEteD2aV+/P9eUwgkRBwi7J48FX6RxP
ZwWWDg/Q4E7jY7vzUE+8ea38z7pOjnX+On645PQFrrG/06GIehYfKzUZj5jn
+DyhnHtsdBauX5rgHV5Lp/Y0FXisKCEROtgvHoZt7rlOJoYux1W4PCADQL85
5pU2Bf9gp1lNWXYIsuAmyZTxm35ovbqEKg33o/WAvZVXFgZdocPt9xoPtqAe
R8uRqBOzbRzXF5vRyxw64fuUql/twRTQr3uS+ThtnuP9D6pPCAjNwSPkoR1v
yulUo2yLDSHxZMIK27cv8nReOYlwj79n+e8tGST4bNVtuTsFz2BPd6Yl63Ox
oPBsEEvtrCjw8IgS8gtA6wG7pWXMs7uPBq2kNMA/1GPXXO7Ok9DGcdUmtRbn
qe9Q0G6tWTTqeR2lfXKX4hzHxkq1s93F83DHumuf/xTTqfPFPiUmtSRiD/bn
6zuipO+QidqdP5ZfrSKDzYIK2UWTTFiH3Zb6Ya9F3BRsnBI0Kzn13/1baHW8
TOdYsPGUQW0vDa4wMFIV8EfzZJBKEhH/nePnkh+1jqm1Qe8iyL0d9ZhfV7gp
ZjgHz2P/WV2k9rp9Hib2vSzQzaNTu+5n+D17iPYz7KUN37K+N5GIVQ5RTdLd
ZJAl/zfR/i8TSmFv+xCmMRM2BTW63sTttRYFL4z8xV/9pHG8+4do9m5/Oowa
/CYpj3oWGma/Fal9h9HYqS63z1tUtMLM1Oe/WEEUcLqm/9plyzmOeRyvyIiP
zUOquMiH+Gw69e2uxyePd5CI7dhBK85oqTwhE4t2OPhVMcjgTm2jhUo/Ey7G
1jjlSisNmILTceXb6sxEgUwybY3cJTqcwQ7isYwJ+4G+L6bvKfqoR2I/F9Pk
0zfoj50/cDful10rpBQJzmajnqSxltQAzzmON0R5bJEQWoClaS+CZzPpVC1z
81UN3SSiAnteVm7wfhaZaN6++m+woADgnu5Nf35+CrZgO9rtXbT8OxP2jqyj
7dkrCkZ+aCoe7qHBPuzwS9XFf/3oMGtR0bZDqOeMWlsUab4FvsRujjeguzt+
g/VCQ2quqIeiofvpvcICx6GJyeukI+fg1FBWuU8a2j8aFRd0B0jEDLbEg7Fa
3rdkQutKv9QBWQEQp/ivSaqZCbWxlUrC3d67TUHGmb2KRVRRYPPPcey1L53j
isO1luLdNFhRRLpxGvWE9930IfN+41guQH3Z4+QWGNOn4KGIeqTCtDcfR+cr
tvNka1vGNy/ABEtHPa4HdGqxCZdRwh8SkYQdIl23wi6fTJzf4TepvFEAbCMH
n+l1mII+2Fkew617qplQIPvVyTW6oqBH9l/y504aFMS+VBCue9qHDgMaR5dd
Rj3WHjG2L7e0cFzTwqgQSfsKd87Y5/QEUoBweGD+1oI5jl/KSZq1my1ACWm9
hDu30ffvyU2Z/jESIYX90tv2d3YJmfBN/nJe1FgAaA/47b1DMKEfdt2VFX3a
x6ag2okZrXB1UZD38OiU8AU6VMeW4Sdsfb7T4GFzxaY41CMaxLdPrruZ48Ah
1+ywnV+h4O65yfuop/dG2FI71wW4CHvv5Mj5ysY5WJl69SY1jk6V/nskZy2L
RNRhDxcoBE2Wk4mPDtG3ROwFgE+7klC66RRk++fWaE+hfCa8dfneom4FUXB5
qTyvyDcax+LPCpNfnKPDPt23Hemop+SLYNSRoQ6OrT3TFEcDm2GlL0P1KOo5
bHVbkjU0xzFtTDMnPmgBblsWNDYeSadqLE3Wc5wnEWxPf3Pm064lE4YWWjZr
fAVAo8+0lv7eKQiw9bvsklJeM+HW0oizqqtEAfzyr+dxBw0aYh/zjLho4E2H
3uvEtPJRT0hDpLJPVAfHii6rS4WVmuGJn9+NJFBPYNfZjW3zc9AGe6WvYMOZ
OwuwMfrwmfxrdOqDlFOP7JrIRCt2S/OdlgQ+MnEyt/v7gRgBUFvV8WYMTEG2
12tSV1plMCH5hVibm7Ao2CG6aadCOw0KYHe+bOr64EmHJkbbe2pQj42o9mm/
miaOKy8lfe7W6oDi6d+2fbmK9mOfdTp2YvNwJXa98Ke6qVcLcP+JjqrIADqV
32JTYGg7mTiAvTnS7V2+EJkIHvywOipNAITeNDquk8KE17Bl1H+M122agnYb
H2c/5hcFxryTi9adpUN77Dcu1t4JbTRYcubt307UE6dpViXr1QQJbN7b+Rph
7e2wiXFL5DbqmZBM591YscDx8SAh1/tq8/BKccpHZ186tXOrCnfLMjLBdqbQ
RF1KF5n48+qKeU8BWg8Zvz3rtabgCLbOUtN2nSQmTH9/xLt2RgTkf32tH+tB
55gCxB+Nt6D5jenm8A/1tBQVuZy82s6xp4UF79zKJvjmhHqOBeo5sZv8XOH7
AsdlLz2WRW6bh8NefZQjXnTqBpuXb1/3oR5sx/gfA73iZOLXe56bxo0CYGg/
bcWxG0w4gn1tMPIFQwXtH8VdocNjImBrMf+Nbje0f2CnrXaf2NlMg/p6i3Yu
oB6Vmy+mPVTaOa5RM0okf2yEmTQ16ZWoJ7iT1FtOW+B4eLvHHjXLeahKPpd6
0I1OjdZ8ETksTSbUsa1n/Sze/yITSW19wk2DAiD8ddiT9HAmvIO9eq8c1VB+
Ct6LFTNjDYmADFs5JRlXOsdLKsOirjXS4FfXmjvClykg+myFuZ57I8cTbWqF
D5q/wHta13d+u4LOzy91pUPc5zm+s3r421JeLuLa+6ciR06h/exPtki/ApkI
x67ND/iRPUom1s4pCHjNCYCCF1c3iQUyIduHjVY1v1o1Bfc1522a7hIBqi7O
bq/raRxX8PDw73WmQ41vEadlUc/5yi7PEIlGjofVd7b/DvgCJ0qS1zxAPeFF
09FJS7gIts/3HA+8FTQPH/4w3exsS6c+jVR93qZCJh5hn7Ng+qROkIlUizZC
XVQQdChkRbzwY8I0bPeinQpGK6ag9nb+239bREDzPak19qfpHG/iDo7+9JkG
xRya3mqgnh1CZh314Q0cx7rdaD6g+gXOPVlRZId6wAZT3zkJLmIeu/+zwBH7
2/NwQDW3J/wonRoxZ0i9PoPOy9gftLy9izXIhP257ih+NUEwWgGd3LyY0AE7
0vYoN/+iKbi88TTRVC0CLvt+cHd0pEMR7L4u+ZaaGhr84vYjeCvqoYY/WfO2
t55jQdWCi7C9DTro/ptXRD2SK1c7/Xo+z/F3K5vAbQpcxDYx3/p35nRqVBJ/
/H0dMrED28qx+YQztwAxty/30+w2QfDURbDEzJUJF7C38qZZjvBOwQKaoMBT
KAKuZR16ZupAh4XYv5fnLc2vokGJk5nfjVGPckrLVDq1nuO5jYf6NoW1QQvn
q79+BaDz9CvfUEd1LoLt6bIjXppwHi6sjm3+cwC9bz9j1npuJhNciv/v26+O
TW4hCxDNPQY/RI4Kgt7EPdEnTzIh2/4avUpzsyx4Itkn1+W9CNhSHBCvbEfn
OHV1PzOmkgY/534vPYp6Luj+dH23sY3j1Y8mBO49rIPe72x8XqOe3LtCMhtb
5jnOXGV23EmXi9AMphZo7kHPk/ROTWCJALER+6/+oI0BQO+jwy2T/Z6CIEb7
ZPimSRZ8jD2RVP33oTUTViZRlkpniYBAu/FP/SfoHA9VHtMwLqfBZM8hfSfU
s1u1MyZk4TPH0f6HX6oMtkJo6vzoAuo5peFTvw9wEaXY68vMeGcH5+EhGWHT
q9vp1Mnxf7I1KwQIU2x1FQXzuV1kQvEtJSUjHL1/P8xzUkZZUAnbanehJMmC
CS8mDewteiQCvi4TaQw/ToeXsKm+F3X/ldLgJ3fuPedRj29YZOjNpFZYjb0O
GBlaOXyGsC/PYQvqsZ6EL0On5zme/fQiTXgfFzG8Ptfl2xY6dTAzQTnXGH2P
sd/42I0HrxQgVq1wclZOEQRUFTs+nV8sKIWdGlvpes+ECSPrHyfvvS0C9pht
WSZ8lM7xq/xUnwuQBt8aKNMCUU+StZrgn72tMAfbfyRyl+CnWmjpnp7Pi3ru
XXO8k2vORXDsoZnUsmQBAuNVrUAP7WdfH1SvpwgQbHctbpo9ZUom7o8aWtTl
CgKfgYdjk70s+AD7uzG/1Ym9TNgWkKhVFiUCVBS66/ws6BzfiNip01NEg9zv
FXRjUM+t608Mo9fVQl7st2oFoepzLTA0uehBLfLxt8tOghNcBNvSteHqQ3IL
UPy+ocNbbXR+OREOv64WIFZi18cV0hdbov3u4hel+/WC4LoFCD60gwn/YSvS
vkr97mTBatlva1SCRMCIWGjc2kIarMEOe01RLTNH85tT2ZJE9PMubg9+9/I0
F8G29R/XutINC/DmjhiZu8iqWjDA9E0Lx/EJbzS+3KqB3FU7hzTU6dQtzVdV
sqzJBNtCKfsnfNcKECtK/mbcHBQET3q27hduZ0FRbEGj9LcXtjLhoq9Nt319
REBKqTxl5BCdY5JKRIhZHg0Kf33BdwL9vP3iBhsWznIRbM/f7PzsaLQAy2jN
menIvWpbnh4+3QKrsS9GZV3tXKiG+4SO6eWuoVMz6rwil2gKEAewu7ieFAEH
dP77LP7x/bwg2BA22FOvx4SO2HWygRedm1hw82//mGw3EfB3U4fP2AE6x+Yp
hl2WOTR4Rvn+lTXo54XqFIVuvMhFsO3d0O3VZIXmR52N3a+RuZZp9WtJt3Cs
b54wk+hWDU2fvVPeI0+ndmS33r2nI0CYYwv1k+vqnMhE3wYhT5KEENDTif7M
rGXBAezke/T1NuuZ0HO2fnGznQiIUXutq/eGxvHaij2Njfvo8Pvsd1/af/OH
TsMe02Augu3Yej6WgNsCXBNfV1yIet5VtH6a6KiCKtiG1Yf2/WxuhkWVobH9
UnRqyet+HzMPMlGCHXX5zQ7ZzQLEx5olFWGaQqBBdf3iNeuYkG3X8tonsJIF
M/fzLfp+RAQUahvGhe+mcyx3J33y70saLKYPjBSiHqmttaLmUVwE28k/Zm8s
DliAPtM3jCtQzyL7XnH7680cm04w7SZ2V0H+6zPbo8Tp1AC/jLT7VAFCAPtl
1rcv9d5kYnK7x99Ne4SAh6Fc2sdSFmS7NT1McK0KE+pOfvOq2ScCmD47f6zY
Sef4RNdzo4vPafDHZotvoahn6VjbZYNELoLtkD0r7LpiF2Cr6IHrDajnQP/r
N1nbmzn+OnPz9vX8T1A1VFNmy3I6VeRycZvwLgGC7d2vaQI7/ND6PcmrJWsv
BApJwktcV6PzKbbVo2dPeYtZMGq0WSaFKgL4Zr4+PQvoMBrbxR4s+fIU3T/v
f1tMUY+hZ0bI5UcLHP8NkRNe9ICLSNidc/kr6hnMU3heNNME2San+YW/UP0E
D3orTk4uolMTwOkJ/30CBNufzt1VeR1AJpZ2N40aXBICFGfv7tB8FhTGvlbf
sXOEwoSfS+y6LHVEgMFp6UGuNBqsw25beH/13hY63PXg5nIZ1GNpJn/k4xMu
wghbfFHmsj9vFqBR1hGlPtTz677sQ7OHlRzb6Pi8v/G+CX7WLsn4QELngagQ
mR8mAkQjdllJ3iGRa2Qiyyf9ZXyCEGB06dftz2HBV9gWOx9teCfJhEFhUp4M
FbR++bne3dhE59jc/fSqyYc0qAt2H/l1iQI+pk0vUS1bgJuwX1JqWuxfcRFK
bWlhI6inMo7/pZxnE2T702HDmPMilTB28YfF17np1CsbzjpvOSJA3MB+ezr1
/tkIMsH7rFBw9UshoCTseNg6mwXJ2Ncv1BR+FGdCt86hUE8ZEZBTc0DNWIcO
3bGltHPi39yjwe7Hmvy5qIfP7MOi37lcBNtnhLoCNrcuwJ/BE6kTqGfzgbfR
bmpNsA87sy5pv9D1Chik+5LLYXaMWrteZXV5DJm4hn17YXw07pgAwf3Qs4Je
KQS+O9UoyYowIQ/2RW5HmP+CBZdNKpTULRcBx4qTGzVu0+By7HELXdcqTToc
VYymXEM9oktMjsoMLHBsZX7+4nHIRWxdG355HvXEeNl7uQ81QrbNxSfFFvNU
wKzYcdsdzDGqySm7ui5bAeI1dvCdBK7lCWRiQ0hXOe9PIeAToKZXJ4zWK/YK
iYrG05ksaKLV8lSQJAJsFIA/jxodHsKujHj60zmeBkdg/sNDqEfEIOhW7icu
gu3oTuf4lgk07zpdFiP/d947beLg7V/O8cdVsUmy6Y2w+G4+WYM+RjWzfLXf
4g6ZILDlFf1XrT4lQLSrHF12dEYIyF6gNLk9ZUG2w76H6DUvZkIFWv8HhekV
YJnvYD9Dic6xb9d+42PRNLgiVu0aBfXMCTxtnWngItjW2vKVrInmM1nHn2eF
Uc/V/tGjQfaNkO0NsyuGNk6WwcGc3jb5v+h5lsaP2LkKEMPYn8fLZRMfkImi
d21tE2KLgOrKJyQdISYswS57Y/ioLo0Fay4HnJb4twIk1Z1Oui1H53h+Q93c
bBgNVvqeqx65iPazcPIztQ4ugu0nhZu/2yziIj4teREjgXpa5O8nmHiXwWps
Y+YGrVjZRqhzZWUmZXiM2rfqeXxNKpnYhP1y0Mcm6awAMaLKcOnSWgQAGKm6
+ZgFadhPnpppTpGZ0GPSc3bg5wpQmTHV0SdJh2ew1ZbaUfcFoT6a7tkPqMeI
xyzA6AcXUYV9cWNo9kUR5APFnrKox+1T7PHQogbI9vPp0tj80Y/wtGeunWLf
GFW6paBgKoNMuGIPpYSFVZ4XIHIUM/eI7F8EYkMXz6uQmJBtVdmnSR9TWFBc
/y+MblsBymq8bm32R/MQ9gnHRZqtonR4pWa993XUIzzRVbJ/mIsIxN6hspx+
VYqLUFDolVRGPcTjk9x6Bg2Q7enW2zquZz7Cn69rOtd3j1Edcjpfyb8kE73Y
64Iy/f9dFCD2JFiI3XdaBAzVf+qcesiCB7Cf3tx9v5aPCevee/UIVq8A4+ms
HbZL6bAe+/gi2+cV52lwbKV+49H//v+8qbnFkMZFMLA7+Ehk79VcxOOM1hgN
1HO2bP6H6od6yHbWpLaozb9S+JS0bH7v1zEqpfd6+Pa3ZILtX68sDwtfFSDS
BZh3/a4tAt32eWt/8zLhE+yLM4fKrj1gwes3dXyOF60A7adhlT8ZnUexDeuU
NHs9aJClohW+FvVka/mbH1LjIti+MrdbTobFRXSu2Fq7EfWEzaT/jTlbCtm2
rPIqPLalHvou+fXEpXWMurzu/pq1IQLEZeztXA1HrfPIxP/1bOfxUH3/A8dn
xjYjy6CkTZQtqahEUfcilURpl2wVRSpC+ihSki2KLGVJdoks2aNzRNZkzVaE
kiUxE2Xnd/y+9/rz+ZfX494557zPTHXXy3xIi1qC8/TtHfBHfb2Eo90678mh
vgEzCb87acL44G3a0bWUP2CQ8JHvl/I8LFnA7YFQ8ORNcZy57gJX/zwF3iOs
dSJUddU2Cvz0LLNp4T7kRuFOH2VDUEd4b03DbfiuBki7GeUE1LIxy8/L6Ore
dChL+CldR+1aIQ/0W3svYW/hErztyiXTD6jPn/B1HtqkCepbaRC32iFGGOc4
xgyJM2Et+vnQyy17JtggS2hgvBL1lKx5vbRxFwXmEH406NwdxUOFkocLX2mh
np/jT5y8HSFYT7iy1GzvSc0awHy7RPh9FRvjap7lP+CP5nnCqgwljVvFPDC6
vfSSWtsSXCdg39rt6PMXQzhtPMUjDH3+PjHjBFWChXGJZWf2VI+wQS1hz1sw
TukkC7Akm1LDUI+L81mtm5oUyCasu38DU1uQClew6g0Ooh7W3t7lT8YAIK1z
DZwWLf8IMs1UI6Y+sLGvT2X09J6g9UpY4KOhm1sZD7RhdRx4+m8JLl1W9jQH
rdcrhH0VNs2vRut5Ofv3/jJPYbzclp2R+5MNxAhvajklJq7HAjHZlOzLqCfQ
LXbNEnSfjSNsqmc72CJKhYoJZyuOoJ6ihzobpw99BEqE2+9MFp6lAPBNKkdV
rZiNnVCmtOs+pcMuwvcvbeO/U80Dpff99DJdyodLCLWcMKaPAxnC75JtR/6h
/fDFLhC31lkYH1ifsMdQiwWiCXsUYa1/vrKB+OuUJbtRD9c0dcrXgAIlCDeU
fyo7LU6FW4pymadQj/i404n5xmpAOvn4SSELgXcgr/BXtXshG+sHNdM36nhg
AeHMh2EVWpF0OMkdbBy8lQ/fnfC+jSd+AkwTTuDbgF9dMg6Kmxl8GjbCOJjX
arRqYC9a2jJ5Z50qC0SJSqcLoJ4nfoaT5dJUGE24DD5UmD5NgUH6SgrGqOfC
7rXB0eJFIISwy+WzoWvOVgMvds2uplw29rC33fTSZx7oQ/hMZqKCcgwd3l92
tmm3AR/ecNbOey5pAngQ3l7SMnIBzQtj/RZOcibC+K62uwd5ytngL+HnWH/6
lU0skO344UWX08L3Uw2N0puoMJfwdDcXj6EZBc708K4+j3osOzc3H+mtApTv
//Pj9aXCdKVCcObzF2uFN+j94q4rJBLp8CxhL/uMQ8faeeCqb9VpZ2358MS1
+60Ml46DNYSx/C7aaOoE2Jb/javpsDBu2+Iu8qaAvejm3YP/rZBkgWty418y
nRZ+3wXx17dTIekHRX9a4y9S0H3WufvSwvl7cGhl0LUqoE+Yc2ZPhL/2WxC2
fJXmw9dszOOj/meVb2i9Ej7ybFUMZwodSu3fpvL3ER9+ra6hxxLNy7KE+axt
blPQPH0wSHappgba/9rHVPNEWIv2cPBvMEhlA88yRTMP1JMmkDHSfZUCvQi7
fHEpfK1GhZt/JblcRT1e5te9Np4tAKSjZrkCeqYqwdr/liaOvkTrQdeQT/QH
D1xHWF9Mpq0nnQ6XW7z8y0jnw9fWHt2QIjkOxAhnXRp6r/12Atwo5TO22yqM
v1JaHlL6nL1okacuM/JcLLDp0d+Np1FP8KdT59s1qZB0BdU3hP8GBVpV5bDt
UQ9mK+Gh4lkJSPfvS7T97JAPzIzr3M7FszHbc+s4h/t54HnCaltG6gqy6fDc
zdbzEXV8+ERLOech+XFgSTjQzvx5b8kEaGWFSpmvF8a/BI2lRw6OgDbC9B8i
1/v92SCio2n3xoV/j21cJbrBhQJJ28iHfv+rQ4XvffL2/Id67D93nfdfWglK
CR8Vktvs/igPtN9szGl9wcZ8HBzDHxbQ4RfCRYlJn8BvHjiwfI1TCpsPD2hr
38TzaQIMEp7GNIKubB8HKWa3bIWWCuM6J4eXTpaPgFTC70qZUiEubIDFWwXN
3UCft/DQ+1QDKiSd/6kqd/t9CoTS+RauqKfsxnjLxpRcQFrdqyKvJ6YChISt
UjoZgfaXF5YHTwM6DCW8pumZi+8fHrjZei1TVYQff1Z7NlAdHwdbCCtb/dvY
3DYB0tTKjrhzCuMmESmfoq3ZIJ2wJ5eMNTNmBGSOGW5uQD12ZkuAoi8FksY2
tfrOnqLCj2sKLrqjnhcR0bCsKgeQlglfs0lxawVQe7y6tT2UjQWmH19nMM4D
9xA2d5EcWVNKh38fOWrtUubHD8ec5XLvQ/sf4Wx6yeUBvXFQvvWJWv6YED4d
Lfa9/QQbVBD+wJwLvHdzBJy5c5I3AfXIzizZPWhChWcJG27BbNcEUuD2wTfa
XqjHu/Hbg+vvywFpL34ZB91f2cBjfVGQ5RM29u7vYA1zhgc+IOz9Pjeso4IO
1Q+O3kw+xY+3F3hwvzQeB3sIOx5f+0JzfALYPDRzyf0hhNdL7HTrPTgCrhHm
ks8x5MPQ+bFppawz6tFSkG8vt6BCCcJOpsb8008p0Mg4hOKHeoa3TGZn8GcD
0p0XKhPjj5UDVcXjRyb92djZgRHj0BrUQ9hv9fqAKgry8YPnbznz40MhdxP0
GJMAJ3xsto8v69o4ON2KFd1vEsKrl+henJVmA0PCVj/OhZeLjYCPaVbu+qhH
epNLbIgNep+ET5ulN1dGUeAVLp1nAajnXs2Zhx96y8CiqavvsJWygHt9/Fig
DxuTH96no9tAh56EjSWdb7ty0aGjwLovzyL5cbmPMve0748DJ8JlFmjrXjMJ
uGZ0HsmXCuFtH1UiM7uHATdhupty/3VeNhhfIyK+HvVsPJHRctKeCkmbeP3g
9UmgwBVer5ghqIdPg33w080yQDqs/8AM7fQbsDqh6/K2B2zMbqf0CwVeOlxD
WJ37j81kMx1aj5zI+wX5ceqWF+ZPw8cB6fCKndNKypPAp2OeJ+eNEM75WKNY
aYi16C9Dhw8rxg+D74G//447iuMfv/a8oTtTIWkaU7RPLZUCzSaDL4YtnB+C
fcKFfGXgHGHuB9sfdt7JBEz58Bftd9lY6S0Rvs8CdChC+PGBrtboL2ieCWhr
0//Bjz8eeiD0I3sc9BCWeyDxyuXwJKjHT6uqxgrhosJ/bGjVrEXPs9IT6s8N
A+XGVkYN6uHTfGWf4kaFpDHHzoRvbyhwyea2588Xfu9w7S66/TIDkB7yLdro
G/0BREnXu3i5sLG1Bwsj9nbRYTLhky4jtU4idGgjlB//lEcAr6j9G3KqEd0n
CVtYPVJk20yCf67gSlmgED4iE22kunIYjBMW2mRdnp2A7nP/Ck/HoJ7+VZsN
ND2pkPTqw+b3HQvQ/sfAcmNQD68G9+HmpnRA+tjvw2MqKh/APsXuYfX/0LzS
LTG9VAzd1wjLv/5d3v2DDvecLjYOkRfANbcWmqT6TQINwi+frvsgMjYOurVL
eJzvCeHrDqh8k7/DAj2ERYzVfNdV/wZJwj7dTqiH30Lao8qPCpMJ409P581C
CjxY6ZORgHoOFAv0vKspBYcI0wfc5X9Q08HG/T7fxh3Y2IHOmoiU1XS4hfDS
V2FW/w3QYXpLRYyAngC+Kkky9V3GJHhD2EPAS0RabALkrr+ac+26EH4idekS
J8ffi9ZmrV974jgLmLJVYvVQT6WThPPNcgo0Jxy09/c+7SAq5Nf5zz95oc9J
y221RSkgLZXcXrPH/DX478aAWr4tG5PI/VqyR5IOnQkPur98vGSYDg37S06W
XhXAH+0J03TFJgDpja3bvi5vmwQm2G5G2TkhHFv9ae2RFb8XXZDo9lJDhgVk
ij9ErEc9kf7v53trKJC0tdGjj5lhVDi6v1j/Neq5FGd0TW+2BJD2MlHzob1P
AX5BTiw3GzbmKP/XtVqaDgMJa4wX6z79Q4d98fE5zo8E8ASq/56/Vug+SXh3
uGyrP8cUkGnaci78mBB+pulOLjV3CMgSfsTzZnA7mhd463bWTDqI4xoRNQdF
oqmQtEMtxXVfEwWKJYqMZqCeiHC1C/ohJYD0abW3xtwyr8AnAZ5B/UtsLDZW
/+XacTpsJNzUfPfrUXk67OTOXTb1WgAXPqIm2qE4BboI38qJvq0VOgFsH696
ukRbCC9ety5N7PAQsCM8ceJEj+69EaC3P3pbHeoZeqPw1zKRCkmv7TOVC2un
QNOEVbezUU/BfKjsasUSYE64rlrh8m6/l2B1efGy9RfYGNvcNTd6mg7FCa8L
zhhs2kyHScLf9ZfWCOBFt+5+izWbAqRlevq0ecsnwKgF97tNKkJ4DlXG1mPZ
CBgj7PPpj/rRnl/g7qBgbQLquc0zN5uaSoXuhNN3KSl1d6H5fs2dwTzUcyhN
al34eCKYJXx+4kTwm6r3IIQqaz5rysZkQ7Tvi1MY8CnhM5U3cw220WGmTOZU
4oAAbkYP+mIfOAVIf7w6pdE+MQFMGuW8hOWFcAUjxpeHdr8WbemvLgDjhkFJ
W9RzF9SD61mF9L+hQtIObhGVq/oo0CC7c08h6jHNY4cLWb4HpA+8fqIuYpEA
fpszCjqM2Fjjy8AjlSp0yCIcdcN0TQgnA5o1z9ZFcwriLZsd1Js/TAHSe4Pb
Y9QVJoFht0h4yRoh3F7vw7oBxWFwhvD+lYEj2bODIPakXfRx1HPhg+OwaAEV
kg6dSJI8+Bt9/pY3/wdQTxr9l9o22nuwkvDtkZuFzz7HgZrxhwKlp9iY6cHD
j+kMBmwi7O9yr0RNnQ7LTbXlZ9YI4sr24dyFZpOggnAjn/KLE1NToP8zd7WW
sBB+hO7AyPMcXLS3WqL6r4LfoM03uXkj6ukQFVHeCamQNPPgvks2oxS4bf1M
+PuF70sfqXguiyoGyoRTGK8G1unEghZDab30Y2ysuj5ozUscrQfCoc/NBx35
GXD4VyazSFkQT6CtfvgreBKQ1ojIlvbYMg1K7tmIPOYRwvV4W3NsmIOLvrd7
yWCU1m9gecppNwfqed8k+fRwGRWS/stzovreJDrfxL/Hf0A9qtTcw7EgGpCW
8it4ka1eDFI/PbkQcxidv/apqp1CDJhGeBzNCULadHiqdsB3VFcQFxmhX7hc
PQlOE07zipnltJgG6kvHWC9mmfifkmMhZdVDYDfhkscS5588HQDSyxmf2+3R
vPT9tZPfPAWSPpJ+a++Zj1RY1CH2tAL1lDYUv2V+gYD01+VNbwV3vgAn3Hu1
wnTZWHrwgbcOOuj+S/j2uWVeGqIMGGMvV5llJojT77waHKRMAdIxYtr374dN
AwM+t5rLY0x8fNv+9TUSA+AY4Q0XnU9Sjg+BMKeQiEzUgxlNWxg2UCHp6/6b
nz3kokLNvzL21ahHM9VzlZQzBKTTOVocC6wjgWStXXvofjYW8+uWWKMeHcoT
vpJ3oDdqJQMO8fg8WuEgiAc5/6yV2zEFhglvWupm9b52Gkyc4dr34xcT/+LQ
aRHxsh9MEhZOEnpW+/UX6N9r9MQH9aiK35fVa6VC0pcNcs+4LaHC0I5AlU+o
h7nRcgvNKgyQ3hWYL/x7BQTF7q3Lw7XY2BAcf6RwlA7LCOf5lZ6dFGfATh4Z
FfUHgvhVbCLQl3MG9BBuizeZZFtPgRzf6c2z35n4LsfCzRe39S/6StKIeZjl
L1C7+2neOdTz3VD95yUhKqwnnC7DeKPcic631Z29dajHVjkro9smFPwlPJPA
zd3gAECvDmUoFmNjlQ1NU3rrGfAn4Rku+ua7J+mQpzVok0qoID5wIiF/bdQU
YBC+O4Idy1edAYpWK4++/MrED1c3fEllDwIlwkufRiU5v+sDT/sDl6ihnshH
QUoiP9D7JVz3vvzCvuVUaGLzwLUR9UjU+7vuvREESPfp7c6Xz30HLjOW7c9U
Q/uLT8Vc3Rk6vEpY/lRwdaQsA0amPZpYnyiI594ZvLjFZgZEEV7188in4IYp
EDDF+P3lMxNvzthxVtN1EAQSTnTl2CCo2wcarYJ9RVBPp6x+de8AFZIWMro7
J7aGCq9/4aI1L8ynUTVq36aKAOkU0TovUY8AoG78YEWZChvDK/+0929kQNKO
M9ICq03pUNW+LWJljiBuMrffBueaBrsIz4R2c7U/nwF0xvCsVy0TV8mIP3iH
b3DR3K7Xlx9q+wlqzw6rDF0Xx+9O3k1MHaFC0lkK2e1d66gw6U+DbevC9xmD
O855bfUDpLmduuIHsSLQKcR9/Ns2tD56Oi+eO4/2P8K2aa+2b1FkQDmNZH2l
UkH8aOPvO8Iq02Aj4REbzxUpdTNg6pDi5fhKJk7fvfuKrtVPME0Ys7V94Rox
AIpTWYIfUI9zUMKQ9V8qJJ1a3rb2uRwVCjaZVbejnmW1++UPPCgEpOVS7Dwc
LDwB6/WDvtktbKzL7/7yuIvofCOcesbgh+12BmTd8Dp+u14QN4go2MJ5aRqw
CQ8qH6+MpM4C6W8iwrKlTDxzXi199XQvkCX8a+u174c3DwBnx1Hh56jHf+15
uGaaCm8RhkdDRo9spsLwM2uFO1DPyPvCZaM1bwHpvIMruqtj7oLPvLs+SCqw
MU7u23Ldl+mwjXBdw4G/qaoMGLTxOa9AJ1q/v/nUXynNghDCTcfsY4SeToPW
a7wfOAETD0t+/GyquH/R152MLcv9e8HDZgPcCfUIW1Q4T26jQn/CnUrB+8so
NLhc9Zb2N9RjJvv6QGOTEyCtelvq00/Rt8Ck/1HnQTl0fhRWX/+pzoCmhMdH
5uJX2NLhl7Vek/8GBHHvu2s5dpVPA9LSq/IjGs1mQVLJIXxHARMvDM3l15Pq
XTSrahB3O9UP/n2xDj2CenycTiZc4KZB0u+SvdtCd6LzWKjTottl4f/7fKkX
Ny8ApM289tITWZcA/fl26f+k2Fj9roGLKzUYkDTX1dXheg502CudPK79VxD/
qyxY4Pp3GpB+VJt0TOzRLOhxUFyRlY3Wh8TN5OS3PxZ95dirjo7hPsBhGL1c
HvWkn1TepoBRIWnX9TTK5BIalI14bf8d9cSV0XNDUvIBaYrQpmtrZreCkDJB
3xQJNraj/ME3HW0GDCNsMZUv7HKTDo3mA2U5KUxcO6i0vmfdDCDdscnk8u3C
WfDYWeGVUwYTdzumocjv1bdoAwmB2bbjP8DzKiPIgXqqFHc5uQvRIOnZ81eS
c/ZSoWfWkWu9qAcvr2r6zbiAeRO21BqVPziZB35MadJ6V7MxPfWg5Um30fMi
vJJh/sNBhwEPLjf/I8XFxLfyaN6xPjwDdAl/fPFFjHNgFhzPsuC8lcrEH1wt
iuNa3wdOEDZT87FrGPkO8nZyBnTYiePmjkObOJfTIOmgpLXmKgepcMRZ2rBv
4bw1uel+UMYRYxHOEznH3r4/DwgGybmsW8HG7rVgWZ/c6JBJ+HAc391wPQZs
XVX+mpeXiXdWzZtmLZ0DpPcpWZatvDUDXpV8bch7ycSzfL83ez/8DlIIs9+J
8haBn+CXON07F/WoeZ3SvrWaBklfe+tz8/VhKvxi5au08O9NVT+1pCivdMNI
90fNfT8akgtsbxwdvrCMjcVxjIMiAwa0I/xlh/wo6z4dHv7BI1kgwMQ9r+Db
J+NnAGlJnvaaQGwO+F1uOaqQwMSvpriukTP5uejd/+kOjsl/B9j+1sQA1ANu
C3b2S9Ig6T9pmkKrT1Chy5XOiUHU8zSwa09NqAd2h/AGzyJ21M8c8OSH14EU
IXTfEL/46ssJBnxG2McgrFPAmw5hPJpsRZh4f6vA3nirOVBMWB9zTF6C9mcp
/NOe+hgmrlFmDnmqexbtNhk0umuuF3Tm9w9dRj06Scq6bmeosIfwSkeamJ4s
DX6ddEobQj1aVw+Ji6nmgE7C8IxV+xI+X2zbmUrXCX42dl/VVe+vIQOqEM67
nOEm54fet0dU7YPlTLz40CeV05MzgLTxz4v17MA5cJbvL4yNYuItNXv3D0T1
AmPCL8KElubY9ADuqPRT+1DPLTxd+4spFZI+zO8inKRAg3ISaSeGUc/f7Pt3
c32ywQbCt/2PmXmpPca6rmrf1+FlY53PVdN5TRiwmzCz4fL33QF0+Laj8sSr
VUy8UmFg6ofkLCgkfKnsXpDr2zkg7n7S8kUEE3ecUrw7KtgD1hKO3XQhS0ar
F4TLJvdJoJ7MRvO1myyoMJLwvRebhyaVaFA0tvXXyMJ+kt1+0GUoEBMjfHmo
Z59zZxaYBOaHorjZWI3x1Y5V5xhwhvDc42jm4WA6vC5dsjtpLRN/vjWBL09n
FtgT3vkRSzD4PgdGj10WKX3GxMuOv0h7k9UNxgiPezb2/Oz7AThvHI2YtkXn
vfWmEk0VGiS9M9Lsn6M12l94919no56YYlrq2W1ZgLSDqVHm6NNgbHlPVtUk
jY3tkeURPvuMDlcSXjLW2ClnyYB5F9VOuq1n4idF7tm22M6CfMLslFW8drzz
YEkS39SSULTfxJTHr/H/AfgIh18Luj54phs89dzg2Ix6gt2nsu6p0yDpipxN
/dnXqPBAzsGBPwvzFNeAwRT+FCO97fRaLiPvN0DZkHv09DwLG6VMFylZM6Aa
Yentm9kXIumQe/epDTtkmTgfzY6hEzoLSCeE88b2KM6D2fVRjx2D0PO82dHp
S+sGc4RtXjGFgfIPILw20y4D9Vz6myf024EKlxLe+d6jM1+DBhVYSgZjqGfi
Ek9E1I8wjLQzCM2068oE5aF6+YXTLMx3+Oj9HVcZsJIwkHyQaxVNh8HTVzk/
yqP1uxZsTDk5D0IIH3ogHShcNAsU04/5zAUwcbH0k2cevuoCWwkbfPf2A53f
QXmaXcBD1MNhr3S2fx8Nkt6RcOHRKmcqPD97IPnvwv4c5lXIdo/ESLOvO8lH
qmaCfZwZQtITLOx26AY1lesMeIBwStXZq9bxdLiBp21OazMTBx6eSo235gHp
DUO/Q3f2zILQdcZ1cY/QvLLhbJuI9/dFa/2TS+g60QUe6LAaL6Ke9QoMF407
VOhFeHTis47AIXT+bmkf+4d6bN7QRtsCMsAGwrYfN+ndEXyByXJ5sALGWNiK
gVe/tt1gwM2EdVZ/E7/4kg5Fr3fMRymh9+chLmT8Yh6Qjv5136mEew4YhM7c
svRD948/Mr0u1K5Fe0mfEcvY/h1YeOSpaqGe7Xof3m80oMGLhC+5Tfw1uU+F
VX82KU0sfD/ElzA0cCYaI+38ZF+s1FA6EBLRPcjBZmFvslY0mKbSIWm3uz+f
Kzgz4IUVwyXd25l4/T/2mH7pPCC90/i0Ubb8HIjX16nX8GXiIVbOe96c/bZo
jku2DQ+7ewCX/Skgjnr4Q6jLHLypkEG4/dynbvwkDfJ2+5hOLvy+T2+/gsXF
YKQfBqf0/Lc/HdTUpYv895uFbXGZfHw8gw5rCc/olBlLujKg2Em1bl5VtH/I
/dy1VH8OrCB8/v2dptS+efDjb/guZW90v5Qa+BvxqGfRYj2XPRrzOsGHB2cv
Tl1DzyvGfszNnwpJ77qGF+sZ0eD0R2W3qYXfA8sFzz34FYuR3mKzvj5lfxrQ
3fBIY3SAhVE1Dl3QzqZDPcI1/CuUhO8xYJp9QfVqNfT3JX+2/7CdA+mEL3dg
uzAuCry90Wsv5snEk9s+7NdZ3glI80qItrTs6QG6XoaKzaiHriv52uMJFR4m
XLF82PmoGQ2qNNg9mUY9xm7F41dorwHppkw7tQ+K8ZiC/UCF3U8WdprfX3Le
A33+CHvhxce35tPhM5v0VrE9THymnP5p45M5EEb4k2L9m3OiFChbZBBm4sHE
/bvrNm8f6QZyhDPPqo1Tb3aAibs9KzJRz0D+eaN7T6lwhvDbB4pyhy1o8MU5
t2czqKctxrRXEaQA0sceN+rRHBKwN8+Gno/1sDC2X45KvzcDZhFeVzxgvaqI
DjM46jUoGkz86MBXTy1ZyqL5dkrc+J01B25619AC3dF8//Fn5a/2r+A/wn7P
ZMRevugG+el+6/1Rj0HYmmVOkVRYQHj5xcFuLWsa9D0WHTi7sP/VFJ8fcXkF
/AiHWNjVamUnYit1h/NufWNh7s92plGK6XAV4cOW3Ldr/ND73USRa9Ji4nJv
Ark2N6P3S9hcJqT2uwoF3hV6Ydx6l4nfM72V9Rf7CkjP9djybz7WDVwdRg9Z
o54TlT5Q8RoNkvaeKRo9H4Puc4PCd+ZQj2GBj2HsnmTgQrj3ZlLbo7EkbHKj
DR/PVxaW79n073UAOn8J/yrgke8ppUO8ozg4eB9aj3W6ftoHKIu+yj3nxv43
B9Yn1bxQdEPP7z1fbwF3N5AiLLH2zXnBxC9AXeN18D7Uc1tKS1AnkQr3ED7E
Fvy6zIEGjQaETOcXfh98mWw1pJSMkVbz8arcR30JygWXPAppZWEHcv2/gwo6
rCIsct8o/WEwA36OPndXWwc9v12TUG35PCDdbaWTan2aAss+BTQ/c2Xiatqf
a/a/7QKkRaX2Km9gfgG3Hp+ZXYd6jgnwHhq9SYOkH2jsviOTQoX7wtq2UlzR
ejmmYG565RVGOvkbd0Pjh0TAsyNkh/xnFvaVWZBu+YwBeQkL7P39/dlHNP+t
7fn0Q5eJ15n8tGeqzAPSyjOA+8QlCizMd1gl4sLED+4KVtx+qx2QNqlz0a2x
7QJ4Y4j7/FVx/JFQ/ZmZdCrUJGzaGSlb6UKDfe2xUws9Fyf4PIcTUjDSP3bJ
pOx9mADMH85NFNejz1uBzDbbOjq8QHi15+i8eiQD7tuQaOCgz8Q3fs44y32T
Ag8QLmBWrbVH53HkltCI8FvoftJqNC/Z37boxLXdW/fKdoHYCxxyX1EPv21B
XlU2FcYTblf39Ai9R4MXZF/mUFHPUM2UZ1RnKkbawEL11ZPj8WD5X8OPxp9Y
WIAZK14wmgFXES59sr5Ns4kOA/dxfho7gp7H3g4TN0/KoqVGJKQuOs4DM87N
IVudmfjbsqRDukXfgDnh42aaP3+cbAPJtzUH81DPcOSq2yaeNEhasl4/LaCA
CsfiJC7SUI+xg9C409I0jHTPO0n1t+JxQDSwJ2G2ioV1Zrgmd8ahPsLCvRkd
Qq10qH85cMryGLo/WqS+HXkyDw4TDrwTm1waQoFrDGWPttxk4qoyqUXXylsB
6biHIlLNm76B3PUTlcGoR9DpkKT4QxrMJ6yZfOe4AaDCqY04H8fC521qZ+Ie
qXSMdN9u8CN7MAbsW/rPNbqchR3/7HGg4wsdkpaMObosOYkB19Mu3q0+wcS3
l+ycE8ycB6QvvR6oboqnwP8ej8l4O6H1avJ6MHtnKyDtW7rUYPWLTnBIpqrs
OupRD37p0/yYBvUJX6v4WsQopcJeA/WEhR71qSNarnnRoI9w2Gq205midGxM
YJmuTikLmxLeJRn/jQ6nCJd+4x62S2HA0tgN1PWn0fnfqttTVTsPSK/I/7M7
M4sCXZ443Nh/Az1Py7B3Qks7gSvhHZTtp1+ltgCcYdZ1GPUsCw6hvK2gQg3C
P8zP13gG02DE9QPKnKinhT9eOPBEBkb62fIBfkGvF8DjcA/1L2Rhc9pHrll9
p0NfwlXCa9R3pDPgncP8AlfPMPE/WhV71v+eB6TLhhVtTEoosCF4KkXIEc1/
PE62e9e3ANJtVzqak707wJm5c6KbUA9bx03JooYKSb8X1ZtTCqPB5/kh+Qs9
afVF68synwPSAtLJzP6hDKxLdV1YXBELczk0xz3+hgF7CKfdUdol30eHH2+k
b009y8RvjAq8aa+nLDpZRvMnP5oP+Hiu4n326P17poveCGsGpCN+i7p8pXSA
XW0ul3hRj113p9Ln5zRIOm6psAW9gQob5U9v41pYHx7/5k3cMzHSew0eWg6e
jgBN6wp4TxewsL7Ezd59g3TYTjjDYfpEVi4DNsGfrC4TJi7d2fPESISy6NHk
NDO5Lgrc9tEtrfw6E58aEo1WFmkGpC8dc+GJ+O8reMNp3Nx3Bc1X4yq37WJp
MJtwhPzltLhmNA++KoxZ6Jn1vXB+UuwNRvqeSlOrGy0M7C9KOyiYy8Im+tzO
Rw+j+YowzNJTvPqWAZv5rr1nmDNxN/XW/luSlEXrM+KzDwxToP+uSbdMOybu
7e+z89voF0BaUU6q8abfZ3Dj5mvTD6jHPUyCzZ1Eg6Rzao5J7fpChUr0UR5u
1CPI8yzsTlooIJ10ajQzP/UN9u2GnEHVGxa2QeRg3ak/dPiD8Og30UgpwID0
gdAVcueZ+P4l9WK2WyiQQXhZa2Sv+gwF8j7n10q0ZeLW8T57Iq59AaS5MalW
ZcZnMP9akjMW9ezRxFoqvlEhaT5BvrjgFBrcQ91wfqHn7K0j/76aBgOccKMz
19kYjSxMu+/SMu90FlbXZh7b8h7djwhT+YObef/RocmVJnN1CyZ+5tNu3Z27
KYuWDecV4+alwn6jWp/4a+j8mODdc/5BExggvNfULq5yqB2MhV8scUM9Ae4r
k9Zk0CDp0hy9L0d+UOEXPd+shZ60qmHTRyJPQAfh2Z+RxdlNWRh1d5O/bioL
s9p00qVgkg5phJWn1h30LGPAbgUtyv6LTJzF/Tu89SBl0e8a8y/FL6fCX3Ox
oylX0f4t8PekyeV2QFouyZ81ztkECmO2RpqgnpnBlcyobBokvUVcX6uhH837
8dozCz05UuHq/yyzMdLRjZP2flWPwdHXv7KEklkYfk316bYqBjxO2C7mcrXl
LB3GvZU7fsCKiXMNX+5fJU1d9E7JqFWH0fyyMq1KvOgKE3dfPhRm8KsNrCLM
l+Gx/df9RnDOb0eAOupxqnw4vKKABs8TfjkDJPV+U+Hv8nu7eFCPZg9rleVE
NkZaoFD7dzjDD7z6rXfnSwIL06yLLBekMmAqYcFI66CvNQzot8I0F7+M7ufm
gXWRFpRF52w2jbTeSoVZpUOZn22Y+C/PQUa4TRvIIXxf8n7sdu5GUO4uF7US
9XiNRZ/wf0eDFYTfyn72KmZToe1dm2sLPVcHv8XxeOdgpIf/q4l/dN8LLI3O
6U2KZWEfX0fdzOZkwBWEn92y0b5Xj96vXp7RP9TTMbDaf+tIKyDt6p4j+9Gr
AQTIv3VVRM/rzmae3A/X0fxAWH+60T0Qo0JxDlA2YYM+b/vwUzPvaYse/8/e
Z8s/tH6zNoYv9Hx9pCDSIZaLbSPsfvjSth9c90H+19lv/71APdKCvafoDEj6
0p8vGVKfGZDrrnulOOoRp4yPv+RrANyEbS2NTZj2reCUptXUcrQebvMXFZff
oUDSuu3e/kGHqPDZ5wyeFtTT4rxDNXSKCsMJx+3n4LpQjuZn4/6ihZ4ETjNO
5qo7gPT+Z8ee9SfmYrYvllvqR7KwRAtHkfElDOhA2H6rZldJKwPKbZ9I17dG
94uuFUFlAfVgA+G+fW5TChMtYDBZ48Y42k+yCi+1xz2kQNJe3sqJdoZUeJ23
wDwb9eSU77b9UE1b9MCUbezEHBUGhle2LPRkFhWZKezIw4IIT78r8mvccQPs
PS1iKxPGwg5q7Od9IsiA2oSXCyxtMf3KgI2+ZVUeaD1UDzbJ3nVtAU2EL9y/
WrxSrB4sG1u2qxadF189Wa/lLalQlLDA2/U9xs8oUGA4oOkJ6vkat7njGAcN
Mgm/tJt+KVFHg/Tsv/0LPWX5bO/kkjyMtPD09Fh3kTXwN131jxrKwi7c663d
KMKAAYQVD2dGTHxjwB0bTRpLLjFxFcPW31zcLYD01z92nlFRdcC5eNw7ygHN
ry8+Z4yieesW4Y1XYlzhdSr0ov01vY56PI7QShybaIvOc1f+l8RDg9prAtkL
PRFLPihYHMnH9hHWub1eeZXeUbDX04HV9YSFhe2JtC4WRfsz4YtLrFX8vzPg
Va1UHzrqSdJIV9CXqwOkJZNEn2T5N4Os/P8SLqF5qjgidOXFTAokHWB1oW/b
HSrUmYjiMEA9Sa488+NLaPAw4Tu6TdWlrTTY6Vzy/z11EXaFWzKOYKS1zXxP
m3zNx5yeu5wqeczCpjckdR1byYCkK/85pEr0MeAT9o83x9B+bPxINeyBWDMI
ItxtEHcRv1AL3sj8+iiP5uVme+Gfee8okHQs/i3Tw5cKqYlHwBbUYx6a3sTf
QVt0UNV3Hg0m6ktJHVjoKb544UQtsMK6CKcW7l369GIB1jz7ev1LP7R+syY5
0wcZsJ3wxz4F1e9rGLDXWnNZvCUTHwvbBRxjPwPSylZJGeLOn8DmCn+Vn/8x
8UntluaBKgrcQrhcOC42J5QK07jLAgVQz7RBhcT9pbRFV4oH/z7SjfabOvu2
hR63g/zHUjwdMdKaV6tMlv4pwPyXhekF+rAwfxm+verDDEj6vSHmdE2SAf+4
f3WaQedtx6Gq1RsDawDptofVY7e2fAa8ujVrFu5rPJpujuWxVEhazfFN0lQz
BXJsgC6/L6PPexcm499LW7S2iL1hsRgNHturWrzQ48IvcjJ/vStG+knV1ObP
t95iAbP9Na6eLCzkd1fshBR6n4QtClJtP7DR/KLgmGiIer5G1po/KWwCpMev
NvwzTPkIoj+ez9JB992fI/PMoR4KjCGcVfixIy+NCmu2Utw+op48TUX/DwM0
WEv4l+P54onVNCicsTp6oafXw6BB9Iw7tpSwStV3+6+chdhjuknk1fssrCa7
5rHuX9RHeK6fUuoqx4BpbvrXCy8w8Z5r3KY5B5sA6SUiODuqohoIlvlv+uPK
xNNkht69Q/Mg6dujeb6+b6mw+MSBZ69Qz73zSdvHf9MWnR3y5aK8JA3G8Gr+
t9Bz9sHQUgW/Qoy0gWVo+5MIT4zTsDHL/C4L++Omk/xpggFJS2Xd7qAqoF4Z
jpdSqEfLpnn1n59VgLRXRL3Dt7ZGIJGplB/kxsSjWKVG9lMUSNqmKEAOL0f3
oSqjSh/UI3X6tdz6P7RFn/LtNjopTYPeIRU6Cz18uhIl59p8MT/CrTGz7A9L
i7CnN3fxn3ZF+8s6iX93tzBgBGGrkaH3+jMM6BVpLh6I5tHLIhd7tXmqgDfh
DawVhgzrRrAjb/q+0j0mrhCu4svLTYUqhKcucp5uQfeLe5Vzgtaox9ua/z+d
f7RFF0biKbc30KAqq1Z4oedxatL3V+FF2C7C1YfV5XTojzHuP+FRBrdYWKTn
9a7qeQZkEP5UEC8yv5UBBw4dTOREPXbSzfwBGyoBaan/DH5vnm4Ag8+9Cyvc
mXjvJpM8g04qJL3CPODXfSEqzPD8Z6ODehTu+FyM3ERb9JTuqe3WUzS4k9+p
aWHe43bWf/tN8h1GWvZe4wMxyUCsdEjUQv8mC/tZ4U7fx8ELPxBePpOj9t8O
BhTie7zy9jn0/N48Vtf1awCkZcOOp1TqVYAATQ/vMx5MfPmhip60AXSeEj54
Z3rZ99VUaLKZ0SWHemLtxSLylGjQjLAt3nvJY44G/TS++i/0SCa8SpBRCcIC
CSu579U6n/gOE6zuOqnvyMLMYofsWTsZUIzwBtt8vIibF+ay2o9MoPsQv2LN
f4YSDSCPsNqTGpmf9uVAoOy9SN8DJm7Q73b5zxgVrY//2XNV1nNpOSqkt8xe
oqOe05ptUuE0jkU/dOQ7/UmZBmu01mgu9GgbTu5RVQAYacF512DngyEYX9Xe
qwbXWdjWt+H+Sry8kEnYYvhT8YXdDCiw1U/qP9SzJcx9S0d4GSD9cJvc3PGs
evDptdHdq15MPHHT3mV626iQtOMUs2cFhQarPSJ4+q3R/iG+9sYrbo5Fix09
+rJzJw2yFE8NL9wnNeSntFcZPcX+EV4vJXbZLB1g72Jj405dY2HZHZ/lm3EG
hITdkmPGY/h54emxl3ZzZkx827dj+3fq1ANDwpHs9uL4Dx/ANbGKfyxvJt76
NJPzzB4qJB1ncadeBp23u6Revy1HPRq+V6xzeDkWfePdi8iB3TR483HCk4We
0ef7HgtahWGk0198fje8AmJy2+xHzWzQfOVolbV3LwPKExbT3HFXSIgXNjQV
LfNCPYZ+/P+o3+oA6RE9/bUq7FIgI/cv5KovE4+Oyho9pEOFsoSv2dyFK0Rp
0PD2zP1E1CNk6aw5ooHmUcLftu4XLBTggC2nZLcu9FBoa5+cNoJYG2HO5ICt
Jg4RmOzKPcevWLGwqenu8+n70TxKuLzitaLLUl54WahyZBnqUZRM+ZjsWAdI
v3T0/eglXgqO/jB173vIxGFiktKoBA2SHmv/ckHmOLqfbTt63hP1TLybtisU
5lj0xj+b40e0afD08FjlwvctJ0Qe1/O7PMfOEN5cO/fgagTEzK1i4W1LFnac
+8SSn8t54TnCHju99qzQZcBLGzd2JZqi+ckm2z9QrwRYES5ZXZy6hb8O4AFr
vxr5o/2nrbj5pwkVkt6T4B/7ZiMN9pc5n7yIeiJakqJyRTkWXcv7tWFQhwbv
K8obLfRYYnduB2q8wEhnRQxdVuqAWKXOya2PzrOwuDfBOnf0GfAj4Wtu50QP
reKFJT8fVexGPY1VIcordGtBKWH+ucpLh1zfA2V0565+hOYvH6VSfysqJL3x
1Nxjox00aHVf02Q/6jEVV4tPXcmx6ECDq61demi/tu/uXfi+z+aEoMAJrWjs
PmGxmCPMmDXFmHrSmtg4M3TfyKGeShPnhXsIxw1s9+kxYEBB3w7fFhMmbvlQ
7tnr9GLAJMxt+NfilssnwFcSfkglAL3PIP04cQcqJF1svsruF06DiV43nGVR
z8911x49F+eALwmvPBnzvt6ABj29tlv///eRH8Sq67ViMG/CO+cCsWLjYuxy
TyNfkTELk350l0vrBLofEWYZ6TcIruOFfw5JCTiiniAhrguuGWi+Ily9VzU0
4wcEe1qPPn8eiOartwWDIa5USLrJ0zP3vC4Nmuf/SOZBPc4GDdY+6zgWnXqf
63nRCRr8B9T7F75vvqXh9HmJVixGWi1S/v2jyGJs0tHSqvUMC8MDT/hdkeaF
M4TtP3jBF6cZ0LHSf7so6plJmehY2fcROBHe0rVRSH8lBGtWONZRg5h4xvl8
ngkvKiTtqvigqRT9/SvFRiN9Vmj9Co7fiDOkwWuEO7+UaNnJcMB7Q8JmCz0y
xa+MBTqKMdLP6m9pcWvEYcnpnzP/nWJhVRKifhVyvDCD8MwxHThtxIDhrsd6
C4yZuKrn+8bJmHeAtCPzdY6O+EcwoKs1axbMxDWsDC5pPqFC0gI7xJUFzWgw
iu/V/grU4xjhKHNMngNGE06qTTJ8YEyDuGVt/cLvCbJPpCVKd8djpMOVmpt2
r36P1Z7b/n35CRYW+O0N47gpA9YTNktxa5ZQ4IVrNyfynEc9tTuSODhPVQPS
q5tyrlxdWgRe2c3vLgxh4sFaV27ciKRC0ueZu7QWfv97VxLzJgn1UMaGxBU3
cyxaTVbi6HlzGgzg99m90GMiEtsnbvQeI2260vDygZ0JWEFg4pjaURb2SuJV
9MtzDPiW8M3fTldvbOGFSivS3QVQz3HV5NtDXm8BacqA5BKtgCqwxWcyWeQp
Ot8SJp8GJVKhImEH+zILcwcaDKwQ2eaNegRiOHbSt3IsWvPzDhs1Cxqc1zsT
u/B7Ud7lo8cyn73HqPr/c+gt0ZUh2xIx0a2W3ecOo/uRGKffjAUDriBs2Vtn
WLmVF6pxOWsWnWXic+uaBy0pBYD0oU4VTUpNJfjnH2508RkT93tF2x6ZQYWk
jW7WUqxdaXB1Zu0HK9RzpTr8jYAVug8R3vn0ktsXZQ64RPIUx0KPqcHNhomW
9xhpJ+HXoukKSVhAU17sw0MsrEL7Qd0hKwYMJPxE+Fjkih28cPv04KZrqEfu
TN5MnXMeIN0/KaerzFsJkt84WOaGMXFfiwhHYy8afEW46Glt0mM037dUJF0+
iHpcK15QkndywDbC6dON2zps0H2EGWq88HtlQw1jzeiyEoz0Ks4x/JnUS+z/
AMEbkCA=
       "]],
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]\[Tau])\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]\[Tau])\"", TraditionalForm]},
      ImageSize->800]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saddle-point classification", "Subsection"],

Cell[CellGroupData[{

Cell["Classified saddles using points-based map", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ClassifyQuantumOrbits"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"ClassifyQuantumOrbits[saddlePoints,f] sorts an indexed set of \
saddle points of the form \[LeftAssociation]\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(1\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(12\)]\)},\[Ellipsis]}\[Ellipsis]\
\[RightAssociation] using a function f, which should turn f[t,\[Tau],\
\[CapitalOmega]] into an appropriate label, and returns an association of the \
form \[LeftAssociation]\!\(\*SubscriptBox[\(label\), \(1\)]\)\[RightArrow]\
\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(1\)]\)\
\[RightArrow]\[LeftAssociation]1\[RightArrow]{t,\[Tau]},2\[RightArrow]{t,\
\[Tau]},\[Ellipsis]\[RightAssociation],\[Ellipsis]\[RightAssociation],\
\[Ellipsis]\[RightAssociation].\\n\\nClassifyQuantumOrbits[saddlePoints,f,\
sortFunction] uses the function sortFunction to sort the sets of saddle \
points {{\!\(\*SubscriptBox[\(t\), \(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(12\)]\)},\[Ellipsis]} for each \
label and harmonic \
energy.\\n\\nClassifyQuantumOrbits[saddlePoints,f,sortFunction,\
DiscardedLabels\[RightArrow]{\!\(\*SubscriptBox[\(label\), \
\(1\)]\),\!\(\*SubscriptBox[\(label\), \(2\)]\),\[Ellipsis]}] specifies a \
list of labels to discard from the final output.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info103674213707-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       
       RowBox[{"\"\<B\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"keyColour", "[", 
      RowBox[{"\"\<D\>\"", ",", "_"}], "]"}], "=", "Cyan"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Tally", "/@", 
         RowBox[{"Map", "[", 
          RowBox[{"Length", ",", "selection", ",", 
           RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Show", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"n", ",", "t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", "n"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "time"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<tt\>\"", "\[Rule]", 
                    RowBox[{"t", "-", "\[Tau]"}]}], ",", 
                    RowBox[{"\"\<t\>\"", "\[Rule]", "t"}], ",", 
                    RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
                    RowBox[{"\[Tau]", "+", " ", 
                    RowBox[{"0.1", " ", "\[ImaginaryI]", " ", 
                    FractionBox["1", 
                    RowBox[{"\[Pi]", " ", "\[Omega]"}]], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"\[Tau]", "-", "t"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}]}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", "n", ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "}"}]}], "]"}]}], "}"}]}], 
                    "\[IndentingNewLine]", "]"}], "@*", 
                    RowBox[{"Apply", "[", "Sequence", "]"}], "@*", "Flatten", 
                    "@*", "List"}], "\[IndentingNewLine]", ",", 
                   RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "]"}],
                  "\[IndentingNewLine]", "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"\[CapitalOmega]", ",", 
                  RowBox[{"Keys", "[", 
                   RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}],
                "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"index", ",", 
                RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
            "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
           RowBox[{"ImageSize", "\[Rule]", "900"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\"\<Re(\[Omega]\>\"", "<>", "time", "<>", "\"\<)\>\""}], ",", 
              RowBox[{
              "\"\<Im(\[Omega]\>\"", "<>", "time", "<>", "\"\<)\>\""}]}], 
             "}"}]}], "\[IndentingNewLine]", ",", 
           RowBox[{"Method", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<AxesInFront\>\"", "\[Rule]", "False"}], "}"}]}]}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"time", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<tt\>\"", ",", "\"\<t\>\"", ",", "\"\<\[Tau]\>\""}], 
            "}"}]}], "}"}]}], "]"}]}], "]"}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\<\"A\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"2", ",", "241"}], "}"}], "}"}]}], ",", 
       RowBox[{"\<\"B\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"2", ",", "241"}], "}"}], "}"}]}], ",", 
       RowBox[{"\<\"D\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"2", ",", "241"}], "}"}], "}"}]}], ",", 
       RowBox[{"\<\"C\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"2", ",", "241"}], "}"}], "}"}]}]}], 
      "\[RightAssociation]"}]},
    {
     GraphicsBox[{{{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0971625829584515`, 1.4968466580800113`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375925, -0.6433017314670852], 
              Complex[1.795162677796044, -2.1401483895470963`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.5018059118396891`, 1.1700244588063093`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0066450711378179496`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.0066450711378179496`], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0967485715744612`, 1.4954990026771537`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792947959`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.11202118197195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665043, -0.6165221792947959], 
              Complex[1.8301368298409655`, -2.11202118197195]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.5012161060031892`, 1.1700906593460907`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00671251078585357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163378148560237`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.00671251078585357], 
              Complex[6.155525231634676, -1.163378148560237]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0963891679170352`, 1.4941201745224162`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.595285574569809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922253`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127985, -0.595285574569809], 
              Complex[1.8593666135298337`, -2.0894057490922253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.500625192097362, 1.1701571380844698`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047818], 
              Complex[6.122517060306257, -1.1633711130594218`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0960773280652167`, 1.49271766147783}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234363, -0.5773156862277907], 
              Complex[1.8852354657886532`, -2.0700333477056208`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.500032791936924, 1.170223958104622}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850741, 0.006863336573144883], 
              Complex[6.093988110787665, -1.1633606215314773`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.09580844851675, 1.491296260033016}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8130202409023957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.8130202409023957, -0.5615718710865845], 
              Complex[1.908828689419146, -2.0528681311196006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4994386686134773`, 1.1702911588985738`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5690366318402065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006943461497604819`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0684753004536836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.5690366318402065`, 0.006943461497604819], 
              Complex[6.0684753004536836`, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0955791659665364`, 1.4898593936430986`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.83517014589239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756488`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.83517014589239, -0.5474736791133894], 
              Complex[1.9307493118589263`, -2.037333072756488]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4988426539199966`, 1.1703587685295225`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871677], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0953868558011928`, 1.4884096660678885`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104826`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628716, -0.5346576120369374], 
              Complex[1.9513735684640645`, -2.023067278104826]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4982446187751601`, 1.1704268085713438`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.525314237109773`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162857`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.525314237109773, 0.007110298008162857], 
              Complex[6.023558855884934, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0952293785378815`, 1.4869491423816579`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5228778864146406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0098270287962983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593915, -0.5228778864146406], 
              Complex[1.970954950697273, -2.0098270287962983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4976444586200548`, 1.1704952965397262`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880171`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880171], 
              Complex[6.0033102912691545`, -1.163298779461846]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0951049354057474`, 1.485479509709819}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906647, -0.5119589442981474], 
              Complex[1.9896739101964118`, -1.9974384540079664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.497042085289297, 1.1705642472412043`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243443], 
              Complex[5.984180253839811, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.095011978993093, 1.4840021770794485`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.501770106216405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522133, -0.501770106216405], 
              Complex[2.0076643409453063`, -1.9857722832958535`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4964374220929535`, 1.1706336735867482`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884142`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256355`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884142, 0.007373913179256355], 
              Complex[5.965990045977095, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0949491544685936`, 1.4825183413487606`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.930079710208937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304528`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.930079710208937, -0.4922109148816922], 
              Complex[2.0250288646775303`, -1.9747292562304528`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.495830400651321, 1.170703587113633}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252032765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348616004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155933, 0.007464952252032765], 
              Complex[5.948603001807254, -1.1632386348616004`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.094915259036124, 1.4810290328377034`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4832021231088814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089915, -0.4832021231088814], 
              Complex[2.0418482129451156`, -1.9642311559465848`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4952209587577727`, 1.1707739983365557`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4366908876556685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007557496991161311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413441`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.4366908876556685`, 0.007557496991161311], 
              Complex[5.931911846413441, -1.1632165013453943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0949092128862417`, 1.4795351481161685`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.474679874998177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078034, -0.474679874998177], 
              Complex[2.058187273894045, -1.9542150231143454`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4946090388791018`, 1.17084491699305}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937319, 0.007651524322599274], 
              Complex[5.915830554816421, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0949300377280013`, 1.4780374742961557`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460459`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460459, -0.46659179640833626`], 
              Complex[2.074099147574047, -1.944629270704492]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.493994587069257, 1.170916352220469}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157199403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632698`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063905, 0.007747021157199403], 
              Complex[5.900288896133163, -1.1631693310632698`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0949768405061175`, 1.4765367074931344`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926869`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926869, -0.45889427989730996`], 
              Complex[2.0896279570988043`, -1.9354309873904443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4933775521611368`, 1.1709883126870055`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143665`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143665, 0.007843982012263393], 
              Complex[5.885228654304802, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0950488007762176`, 1.4750334671609007`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.451550545734929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806892, -0.451550545734929], 
              Complex[2.1048108525831095`, -1.9265840128958296`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4927578851512358`, 1.1710608066908612`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351017726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837107, 0.007942407351017726], 
              Complex[5.870600935988342, -1.1631183993398435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0951451607294456`, 1.4735283074287815`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0245343135360971`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4445292235923789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9180575310211605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.0245343135360971`, -0.4445292235923789], 
              Complex[2.119679474265543, -1.9180575310211605`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4921355387215662`, 1.1711338422367736`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.008042302396705217], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0952652171797417`, 1.4720217262117412`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885548`, -0.43780329333443585`], 
              Complex[2.1342610431682965`, -1.9098250195461772`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4915104668614703`, 1.171207427096061}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233518`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233518], 
              Complex[5.842482826256842, -1.1630637508268276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.095408315034155, 1.4705141726331523`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949334917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1485791890132715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9018634521265014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791166`, -0.43134927949334917`], 
              Complex[2.1485791890132715`, -1.9018634521265014`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4908826245635478`, 1.1712815688544402`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654023`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353645, 0.008246541346654023], 
              Complex[5.828925941917193, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0955738419034182`, 1.4690060531470506`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4251466287655521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468016`, -0.4251466287655521], 
              Complex[2.1626545888502196`, -1.8941526819126024`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4902519675754997`, 1.171356274950616}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3254146624079155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00835091278661437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.3254146624079155`, 0.00835091278661437], 
              Complex[5.815666629983416, -1.1630053621640015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0957612236028738`, 1.4674977366426467`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41917722203755886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495677`, -0.41917722203755886`], 
              Complex[2.1765054667524413`, -1.8866749586802056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4896184521947609`, 1.1714315527077839`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008456808164000539`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.008456808164000539], 
              Complex[5.802681228429218, -1.1629747445437835`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0959699203583588`, 1.4659895587415224`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4134249869532397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739511`, -0.4134249869532397], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.488982035096316, 1.1715074093596352`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411546`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411546], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0961994235771633`, 1.4644818254465937`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.407875586750141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145416, -0.407875586750141], 
              Complex[2.203596585722579, -1.8723574121967346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.488342673186538, 1.171583852072019}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2891080693657475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008673251522090974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.2891080693657475`, 0.008673251522090974], 
              Complex[5.777450742552285, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0964492530771741`, 1.4629748162648515`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.120414946688531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.402516167736111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.120414946688531, -0.402516167736111], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4877003234776143`, 1.171660887961159}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995704], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0967189546913012`, 1.4614687868986669`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568053`, -0.39733515240586287`], 
              Complex[2.2299625053481065`, -1.8588039393045297`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.487054942978425, 1.1717385241090856`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349859014`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349859014], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.097008098182232, 1.4599639715801556`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326723`, -0.3923220684765708], 
              Complex[2.2429020774149047`, -1.8522860400567263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4864064885986414`, 1.1718167675768099`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2547977983402`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033198`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.2547977983402, 0.009009898497033198], 
              Complex[5.741204286938841, -1.1628068690797766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0973162754160204`, 1.4584605851077945`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396098`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396098`, -0.38746740648134814`], 
              Complex[2.2556925367556304`, -1.8459279915891427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4857549170635265`, 1.1718956254156432`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990407], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0976430987532788`, 1.4569588246327925`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3827625002813666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155868`, -0.3827625002813666], 
              Complex[2.2683426708688654`, -1.839721324914159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4851001848374201`, 1.1719751046769844`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842194`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694922, 0.009242627557842194], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0979881996247092`, 1.4554588712336476`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3781994261302764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728415`, -0.3781994261302764], 
              Complex[2.280860535897551, -1.8336582973639242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4844422480543258`, 1.1720552124208197`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391628], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0983512272638338`, 1.4539608913103}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37377091687665037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.29325354314301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791765`, -0.37377091687665037`], 
              Complex[2.29325354314301, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4837810624542787`, 1.1721359557231514`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988769`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555507, 0.009482273153988769], 
              Complex[5.695312895009786, -1.162653682569163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0987318475746586`, 1.452465037823688}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3694702886103212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.3694702886103212], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.483116583324458, 1.1722173416825046`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122507`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122507], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0991297421158872`, 1.4509714514021206`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862784`], 
              Complex[2.317691837968342, -1.8162628290107483`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4824487654441583`, 1.1722993774256536`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121803`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121803], 
              Complex[5.67322985816244, -1.1625702788705319`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.0995446071863157`, 1.44948026133231}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418302`, -0.3612284858628572], 
              Complex[2.329749338128146, -1.8107087471951673`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4817775630328995`, 1.1723820701126721`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1805979393900845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009855291843704473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.1805979393900845`, 0.009855291843704473], 
              Complex[5.662375502422984, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.099976152998618, 1.4479915864500452`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35727633379543633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.35727633379543633`], 
              Complex[2.3417065077888246`, -1.8052679202454813`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4811029297010843`, 1.1724654269413926`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384774], 
              Complex[5.651636660481891, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1004241029306552`, 1.4465055359431653`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2531443542465808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.353430019037376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7999355549805414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.2531443542465808`, -0.353430019037376], 
              Complex[2.353568457177236, -1.7999355549805414`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4804248184026618`, 1.1725494551513491`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967315`], 
              Complex[5.6410069952433215`, -1.1624360273853818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.100888192845178, 1.445022210077558}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034030016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377347`, -0.34968498034030016`], 
              Complex[2.3653399684829126`, -1.7947071904178582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.479743181389402, 1.1726341620272602`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.150737416691642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.150737416691642, 0.010245449802525817`], 
              Complex[5.630480598081045, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1013681704700884`, 1.4435417008553584`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2756573571094836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34603696586050614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.2756573571094836`, -0.34603696586050614`], 
              Complex[2.3770255275795718`, -1.7895786667158646`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4790579701663649`, 1.1727195549021028`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040011], 
              Complex[5.620051946974447, -1.1623400583917027`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.101863794832604, 1.4420640926131942`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2867655571559535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3424820051832389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.784546097796433`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.2867655571559535`, -0.3424820051832389], 
              Complex[2.3886293519885573`, -1.784546097796433]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.478369135448276, 1.1728056411598098`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854404`], 
              Complex[5.609715869645587, -1.1622900299949552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1023748357415462`, 1.4405894625672464`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2977805798777453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33901638456088035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.2977805798777453`, -0.33901638456088035`], 
              Complex[2.4001554156192917`, -1.7796058471281269`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4776766271164938`, 1.1728924282376276`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0106538385311294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.0106538385311294], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.102901073312845, 1.4391178813109793`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214084`, -0.33563662492447366`], 
              Complex[2.4116074707342534`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4769803941763398`, 1.1729799236281604`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694064`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1034422975339044`, 1.437649413270622}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3195467699805936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.3195467699805936`, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685131`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4762803847145511`, 1.17306813488111}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194784`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564418`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194784, 0.010936818155564418`], 
              Complex[5.579215944909335, -1.1621313167255456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.103998307863154, 1.4361841171228251`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014387], 
              Complex[2.434303571543257, -1.765305947424264]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.475576545856664, 1.1731570696047409`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.01108166777660794], 
              Complex[5.569204368643545, -1.162075401828133]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1045689128614735`, 1.4347220461783865`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.340985266615273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7607028906574198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.340985266615273, -0.32598084447903347`], 
              Complex[2.4455541794767464`, -1.7607028906574198`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4748688237241292`, 1.1732467354670706`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162017910531272`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798505`], 
              Complex[5.559263729872352, -1.162017910531272]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.105153929852672, 1.4332632487354375`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3515900032787673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.456743933131439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.3515900032787673`, -0.32291378822242106`], 
              Complex[2.456743933131439, -1.7561770369578587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.474157163391, 1.1733371401967958`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423352`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.011378342532423352`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.105753184610502, 1.4318077684050952`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.46787573218371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573208, -0.3199181000986168], 
              Complex[2.46787573218371, -1.7517258685037118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4734415088400306`, 1.1734282915839576`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525728], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1063665110700038`, 1.4303556444122343`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799589`, -0.31699136241415293`], 
              Complex[2.478952345649963, -1.7473470068263872`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4727218029180233`, 1.173520197480349}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931245`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.106993751061243, 1.4289069118737354`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3829826712308153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3141312908727419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.3829826712308153`, -0.3141312908727419], 
              Complex[2.4899764222920586`, -1.7430382027464775`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4719979872902957`, 1.1736128657996592`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115795`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1076347540637201`, 1.4274616020562898`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.393315746009415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586887`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.393315746009415, -0.3113357252023987], 
              Complex[2.500950500073135, -1.7387973272586887`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.47127000239412, 1.1737063045173513`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428712, 0.012001139360437757`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1082893769799227`, 1.4260197426156345`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30860262064445376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7346223632600883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924144`, -0.30860262064445376`], 
              Complex[2.5118770147723373`, -1.7346223632600883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4705377873909955`, 1.1738005216702667`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485314`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485314`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1089574839266936`, 1.4245813578188897`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261337`, -0.30593004021100256`], 
              Complex[2.5227583078528273`, -1.7305113980298923`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.469801280117633, 1.173895525355946}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552494`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552494`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.109638946043191, 1.423146468751491}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291149`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7264626163806056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222577`, -0.3033161476291149], 
              Complex[2.5335966336654487`, -1.7264626163806056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4690604170355042`, 1.1739913237316546`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164319`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1103336413144067`, 1.4217150935100629`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4340605247457119`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3007592009004861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.722474294410549`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.4340605247457119`, -0.3007592009004861], 
              Complex[2.5443941660601186`, -1.722474294410549]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4683151331788349`, 1.1740879250130973`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.472443222555007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376172, 0.012666429816627385`], 
              Complex[5.472443222555007, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1110414544092775`, 1.4202872473824497`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2982575464138699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589807`, -0.2982575464138699], 
              Complex[2.5551530044682584`, -1.7185447937963196`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4675653621009008`, 1.1741853374728037`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854726`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1117622765325783`, 1.4188629430160065`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4541129029793964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2958096135553037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713101`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.4541129029793964`, -0.2958096135553037], 
              Complex[2.5658751795119747`, -1.7146725565713101`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4668110358184958`, 1.1742835694381695`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742186`], 
              Complex[5.453670720869239, -1.161267218035427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1124960052898185`, 1.4174421905751402`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993391`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2934139097675647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.576562658189158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.710856100342705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993391`, -0.2934139097675647], 
              Complex[2.576562658189158, -1.710856100342705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.466052084754429, 1.1743826292891217`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391402`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391402`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1132425445645364`, 1.416024997889011}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135787`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.7070940139050703`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4652884376779056`, 1.1744825254553937`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.969756453162239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.969756453162239, 0.013378583279512466`], 
              Complex[5.435044890840144, -1.161103942175881]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.11400180440737, 1.41461137059022}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134369`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134369`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4645200216426517`, 1.1745832664133713`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9612615538389253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362826`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.9612615538389253`, 0.013564516504362826`], 
              Complex[5.425781575481577, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1147737009364185`, 1.4132013122452385`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395195`, -0.28652632543776696`], 
              Complex[2.608435730175938, -1.6997276376830055`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4637467619226254`, 1.174684860682482}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612014, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1155581562484462`, 1.4117948244772742`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5034448258538131`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2843260223090579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.696120846786332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.5034448258538131`, -0.2843260223090579], 
              Complex[2.619002982102259, -1.696120846786332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4629685819451483`, 1.1747873168210956`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013946445235532942`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.013946445235532942`], 
              Complex[5.407343930794649, -1.1608408715855627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1163550983405524`, 1.4103919070822164`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5131894768429806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2821715098398554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.5131894768429806`, -0.2821715098398554], 
              Complex[2.629544575183533, -1.6925634169220718`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4621854032213013`, 1.1748906434218875`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044086`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.014142621333044086`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1171644610419518`, 1.40899255813824}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939463`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28006168039394325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939463`, -0.28006168039394325`], 
              Complex[2.640062184735898, -1.6890542385321832`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4613971452733998`, 1.174994849106633}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1179861839556287`, 1.4075967741096318`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.532571266034649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.532571266034649, -0.2779954793374566], 
              Complex[2.6505574499902775`, -1.6855922534470884`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4606037255593742`, 1.1750999425203745`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1605540685141238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250856`], 
              Complex[5.379881023870965, -1.1605540685141238`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1188202124095872`, 1.406204549945332}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034568`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034568`, -0.2759719024950623], 
              Complex[2.661031977113044, -1.6821764524403942`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.459805059393841, 1.1752059323249158`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367238`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1196664974175483`, 1.4048158791726852`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451711`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2739899938041933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768787`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451711`, -0.2739899938041933], 
              Complex[2.6714873420627194`, -1.6788058729768787`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.459001059865691, 1.17531282719158}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01496433941403484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.01496433941403484], 
              Complex[5.36168012892486, -1.1603484877775454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1205249956489254`, 1.403430753986836}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6754795971390901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502445`, -0.27204884315225397`], 
              Complex[2.68192509329917, -1.6754795971390901`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.458191637751946, 1.175420635793177}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436348`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1213956694079894`, 1.402049165336192}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.672196749719544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335235`], 
              Complex[2.692346754360388, -1.672196749719544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4573767014276684`, 1.1755293667950935`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965262`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965262`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1222784866221516`, 1.400671103004369}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2682853934625309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.2682853934625309], 
              Complex[2.702753826320577, -1.6689564964669]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4565561567716798`, 1.1756390288454504`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198311`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.123173420839346, 1.39929655568899}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028514`, -0.26646148678673626`], 
              Complex[2.713147790142197, -1.6657580424757261`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.455729907067823, 1.1757496305642214`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.869745127987924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.869745127987924, 0.015850459092959724`], 
              Complex[5.325475035055747, -1.1598991714712616`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.124080451234513, 1.3979255110777087`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.599449657699079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.723530108933592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.662600630710649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.599449657699079, -0.26467511963294027`], 
              Complex[2.723530108933592, -1.662600630710649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4548978529014909`, 1.1758611805312393`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.86155734952905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.86155734952905, 0.016082942650415957`], 
              Complex[5.316455202430541, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1249995626252534`, 1.3965579559218202`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.73390223012297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348711], 
              Complex[2.73390223012297, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4540598920511307`, 1.1759736872729671`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.016320069418202337`], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1259307454967145`, 1.3951938761077975`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.74426558755872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620056`, -0.2612122109807515], 
              Complex[2.74426558755872, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4532159193743954`, 1.176087159247943}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016561979698683872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759495`, 0.016561979698683872`], 
              Complex[5.298442228350345, -1.159525179549259]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1268739960358543`, 1.3938332567271066`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.62774760750956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.62774760750956, -0.2595343622253305], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4523658266886268`, 1.176201604830757}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533102`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1278293161752437`, 1.3924760821446291`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6371423746489984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.6371423746489984`, -0.2578914362102898], 
              Complex[2.7649716908242423`, -1.6503675183549191`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.451509502645284, 1.1763170322944347`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761317`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761317`, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1287967136465908`, 1.3911223360660327`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25628286358783076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595245`, -0.25628286358783076`], 
              Complex[2.775317254506115, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4506468325979505`, 1.1764334497910687`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.017317904038714273`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.129776202044261, 1.3897720016044286`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2547081070429701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6444801086473986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210366`, -0.2547081070429701], 
              Complex[2.7856596939652976`, -1.6444801086473986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4497776984634931`, 1.1765508653305403`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237652`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.017580472844237652`], 
              Complex[5.262480372776144, -1.1589703924863026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1307678008990376`, 1.3884250613466609`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106764], 
              Complex[2.796000404700961, -1.6415917218573373`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4489019785759336`, 1.1766692867571427`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213597`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1317715357624867`, 1.3870814974195784`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.2516580484846374], 
              Complex[2.8063407801738802`, -1.6387395459042158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4480195475325601`, 1.1767887217239024`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7964880329151702`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01812252789874474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.7964880329151702`, 0.01812252789874474], 
              Complex[5.24450758044773, -1.1586661938251577`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1327874383022702`, 1.3857412915566518`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.683894775322847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.683894775322847, -0.2501818254149767], 
              Complex[2.8166822136251173`, -1.6359231169716286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.447130276031749, 1.176909177664384}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287794`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770964`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287794`], 
              Complex[5.235518056794404, -1.1585067947770964`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1338155464088415`, 1.3844044251653098`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745872`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24873757519284695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745872`, -0.24873757519284695`], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4462340307019717`, 1.1770306617617174`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788258`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788258`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1348559043139876`, 1.3830708793953934`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.702517932853939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.702517932853939, -0.24732491072033722`], 
              Complex[2.8373738371679265`, -1.6303957901157309`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4453306739213656`, 1.177153180914591}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336754`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.135908562721738, 1.381740635209144}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7118182661707113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.7118182661707113`, -0.24594347356467763`], 
              Complex[2.847726828892449, -1.6276841087738216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4444200636272473`, 1.1772767416998926`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.764099329077837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259931007`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.764099329077837, 0.019279648259931007`], 
              Complex[5.208519392705084, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1369735789522284`, 1.3804136734531534`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24459293369624518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258048`, -0.24459293369624518`], 
              Complex[2.8580864854780335`, -1.6250066071493985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4435020531148777`, 1.17740135033167}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954847`, 0.01958535502317052], 
              Complex[5.199504918610362, -1.1578159953084997`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1380510170991491`, 1.3790899749327663`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041919`], 
              Complex[2.8684542261798467`, -1.6223629642431856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4425764908247227`, 1.1775270126160398`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995081`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995081, 0.01989808875998757], 
              Complex[5.190480530819804, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1391409482014963`, 1.3777695204894287`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7396905327334806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.7396905327334806`, -0.24198336673385487`], 
              Complex[2.8788314809349766`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4416432201174194`, 1.1776537339016266`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02021809668881551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.02021809668881551], 
              Complex[5.181444746812216, -1.1574356372128114`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.140243450430389, 1.376452291081521}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978096`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071484`, -0.24072382041628868`], 
              Complex[2.8892196922375377`, -1.6171761114978096`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.440702079035575, 1.1777815190250742`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985932966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985932966`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.141358609291814, 1.3751382678692918`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7582617077558227`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23949413300958758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.7582617077558227`, -0.23949413300958758`], 
              Complex[2.8996203170476367`, -1.6146324008788793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4397529000514586`, 1.1779103722511177`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7235801099771857`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020880984524094977`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.7235801099771857`, 0.020880984524094977`], 
              Complex[5.163333010028644, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1424865178462353`, 1.373827432304509}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947159`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947159`, -0.2382941155363086], 
              Complex[2.910034828740951, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4387955097995693`, 1.1780402972066422`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603423`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976127`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.154254035959911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603423`, 0.021224421666976127`], 
              Complex[5.154254035959911, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1436272769460765`, 1.3725197662255608`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7768374421596609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.7768374421596609`, -0.2371236076506873], 
              Complex[2.920464719105737, -1.6096433738762481`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4378297287929864`, 1.1781712968080984`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1447809954922168`, 1.3712152519587635`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022491`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60719772995439`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022491`, -0.23598247799562655`], 
              Complex[2.930911500394466, -1.60719772995439]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.436855371122298, 1.1783033731815566`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02193678187394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.02193678187394727], 
              Complex[5.136042207268361, -1.1563665913076093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1459477907107123`, 1.3699138724267477`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2348706246599857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267063`, -0.2348706246599857], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.435872244135823, 1.1784365275746111`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795415`, 0.022306351154756366`], 
              Complex[5.126906229415364, -1.1561301764198548`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1471277884510829`, 1.3686156112648549`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.804734111374893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.804734111374893, -0.2337879757412097], 
              Complex[2.9518618998259756`, -1.6024035870060644`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4348801480997158`, 1.1785707602592412`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684483`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1483211235076403`, 1.3673204529466156`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8140475406660062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23273449001922947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.600054942965845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.8140475406660062`, -0.23273449001922947`], 
              Complex[2.9623686641736464`, -1.600054942965845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4338788758364294`, 1.178706070424638}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.674687296700069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0230740120998301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1556320583248079`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.674687296700069, 0.0230740120998301], 
              Complex[5.108566172536498, -1.1556320583248079`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1495279399654434`, 1.3660283829194537`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.823370676497873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23171015774841427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.597738540667868`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.823370676497873, -0.23171015774841427`], 
              Complex[2.9728986164633167`, -1.597738540667868]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4328682123398786`, 1.1788424560588717`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944804`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944804`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.150748391572657, 1.3647393877519405`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169928`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2307150015754318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.595454389327372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169928`, -0.2307150015754318], 
              Complex[2.9834534044896497`, -1.595454389327372]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4318479343654857`, 1.178979913818152}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02388225011180803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.02388225011180803], 
              Complex[5.090124379020649, -1.1550976637063441`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.151982642141193, 1.3634534552940503`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.842052068264839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.842052068264839, -0.2297490775919429], 
              Complex[2.994034710406032, -1.5932025328859931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4308178099931625`, 1.179118438882264}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.650043307963434`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774112`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.650043307963434, 0.024302619991774112`], 
              Complex[5.080861117956596, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1532308659777568`, 1.3621705748520436`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2288124765322978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.2288124765322978], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4297775981610572`, 1.1792580247945885`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6417897014939595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024734421969833963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.6417897014939595`, 0.024734421969833963`], 
              Complex[5.071567299655017, -1.1545236028247543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1544932483475856`, 1.360890737379825}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8607905440628354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.588796062507649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.8607905440628354`, -0.22790532512782383`], 
              Complex[3.015283792410421, -1.588796062507649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4287270481677588`, 1.1793986632849174`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6335140931343686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025178136640842938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.6335140931343686`, 0.025178136640842938`], 
              Complex[5.0622411413021275`, -1.1542205266440744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1557699859733699`, 1.3596139356888315`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5866417233196022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162648`, -0.22702778763077067`], 
              Complex[3.0259551291896347`, -1.5866417233196022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4276658991403761`, 1.1795403440730323`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6252149197388337`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025634272402031193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.6252149197388337`, 0.025634272402031193`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1570612875721122`, 1.3583401646787816`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2261800675227635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.2261800675227635], 
              Complex[3.036660111236013, -1.5845202322015453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.426593879465738, 1.1796830546507573`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.616890584552165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026103367509584273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.616890584552165, 0.026103367509584273`], 
              Complex[5.0434844640179035`, -1.153579687141173]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1583673744329244`, 1.357069421591918}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454497`], 
              Complex[3.0474006350962966`, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4255107061816445`, 1.1798267800398854`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.608539454516405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.608539454516405, 0.026585992320965892`], 
              Complex[5.034050160698049, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1596884810390518`, 1.3558017062937202`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.898490168720361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.898490168720361, -0.22457510122598107`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4244160843248561`, 1.1799715025230375`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796514`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796514`], 
              Complex[5.024575941774229, -1.152888750780241]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1610248557377203`, 1.3545370215834658`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2238184764577979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.2238184764577979], 
              Complex[3.068996160253663, -1.5783554980412635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4233097062321813`, 1.1801172013441017`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027594287906544515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840506`, 0.027594287906544515`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.162376761461761, 1.3532753735384755`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.917478469987143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.917478469987143, -0.22309291692935712`], 
              Complex[3.0798552314489043`, -1.5763682904678327`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4221912507906798`, 1.1802638523744433`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5833083599570257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.028121283097053456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.5833083599570257`, 0.028121283097053456`], 
              Complex[5.005499610747705, -1.15214256927739]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.163744476507328, 1.352016771896426}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9270135155729469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.090757992080275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.574415627556381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.9270135155729469`, -0.22239885565995504`], 
              Complex[3.090757992080275, -1.574415627556381]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.42106038263262, 1.1804114277405415`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.57483289213363`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028664462962103714`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.57483289213363, 0.028664462962103714`], 
              Complex[4.9958932747662494`, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1651282953724575`, 1.350761230480697}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386605`, -0.22173678013483517`], 
              Complex[3.1017066390111183`, -1.5724980106155322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4199167512704207`, 1.1805598954080907`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5663218157567322`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.029224600034819134`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.5663218157567322`, 0.029224600034819134`], 
              Complex[4.986238567027153, -1.1513352953732714`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1665285296616597`, 1.3495087676744777`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2211072359212472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.11270344175382`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.2211072359212472], 
              Complex[3.11270344175382, -1.5706160035957248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4187599901663561`, 1.1807092187168904`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.02980251760487485], 
              Complex[4.976533205571878, -1.1509067011120155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1679455090622306`, 1.3482594069501301`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.955805238206233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22051083068468322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1237507472684634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.955805238206233, -0.22051083068468322`], 
              Complex[3.1237507472684634`, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4175897157312973`, 1.1808593558600218`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211297`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211297`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.169379582398535, 1.347013177461331}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092963`], 
              Complex[3.134850985060283, -1.5669614161122607`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.416405526246223, 1.181010259299839}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413918`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.170831118771077, 1.345770114706572}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5651903202724238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269589`, -0.21942020556585187`], 
              Complex[3.146006672598036, -1.5651903202724238`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.415207000699647, 1.1811618751121893`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5318822005363093`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03165204012119633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.5318822005363093`, 0.03165204012119633], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1723005087878404`, 1.3445302612739587`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9849199122885905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21892755421211502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.9849199122885905`, -0.21892755421211502`], 
              Complex[3.157220421076431, -1.5634578154860739`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4139936975334582`, 1.1813141422489608`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.523163099500529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665909`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923016`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.523163099500529, 0.03231048635665909], 
              Complex[4.937156797033987, -1.1490036558923016`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.173788165896086, 1.3432936676787464`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505612`, -0.21847119055042033`], 
              Complex[3.1684949415466472`, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4127651532889667`, 1.1814669917075291`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234989], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1752945278235079`, 1.342060393306852}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0045385236161377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1798330514396453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5601125038693655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.0045385236161377`, -0.21805211056251347`], 
              Complex[3.1798330514396453`, -1.5601125038693655`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.411520881144226, 1.1816203455938787`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.033697084835816196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.033697084835816196`], 
              Complex[4.917099209420433, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1768200581384987`, 1.340830507479695}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0144176233688644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2176714078844632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.0144176233688644`, -0.2176714078844632], 
              Complex[3.191237681507363, -1.5585019153641582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4102603693328424`, 1.181774116064071}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.496707894901857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.496707894901857, 0.03442779801852973], 
              Complex[4.906968264234699, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1783652479401079`, 1.3396040906581879`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.202711883206814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5569343729898864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667063`, -0.21733028233169854`], 
              Complex[3.202711883206814, -1.5569343729898864`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4089830794337166`, 1.1819282041262438`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03518532290406062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.03518532290406062], 
              Complex[4.896765181899932, -1.1467428812221834`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1799306176891504`, 1.3383812358066196`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.21703004943242474`], 
              Complex[3.2142588365513363`, -1.5554112852390443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4076884445201672`, 1.1820824982824254`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4787983328457113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0359711966974785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.4787983328457113`, 0.0359711966974785], 
              Complex[4.886486777365879, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1815167191928746`, 1.3371620499406358`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.044365139258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2258818584516473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.044365139258773, -0.21677215110365747`], 
              Complex[3.2258818584516473`, -1.5539342010442931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4063758671560749`, 1.1822368729859642`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4697538621751725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.036787077710537165`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.145449795275427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.4697538621751725`, 0.036787077710537165`], 
              Complex[4.8761297293312476`, -1.145449795275427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.183124137756493, 1.3359466558875899`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.21655816762459842`], 
              Complex[3.237584411566567, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.4050447172256828`, 1.182391186886311}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4606458541378564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.037634757497710815`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.865690571363539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.4606458541378564`, 0.037634757497710815`], 
              Complex[4.865690571363539, -1.1447564293886003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1847534945157798`, 1.3347351942924113`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2163898310860748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.551125025378486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.2163898310860748], 
              Complex[3.249370113678695, -1.551125025378486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.403694329582847, 1.1825452808280363`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.45147135291243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03851617446207765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.45147135291243, 0.03851617446207765], 
              Complex[4.855165682495278, -1.1440291063659587`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1864054489657605`, 1.333527825907882}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21626904052272816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54979686643061`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380024`, -0.21626904052272816`], 
              Complex[3.2612427476037626`, -1.54979686643061]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.402324001504694, 1.1826989755651813`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804186], 
              Complex[4.844551277287891, -1.1432655464271395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.188080701701171, 1.3323247342150961`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2161978789674407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.2161978789674407], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.400932989933984, 1.1828520691451985`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302237`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.040388801390635616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302237`, 0.040388801390635616`], 
              Complex[4.833843395364208, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1897799973848147`, 1.331126128428065}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.285264830490968`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584645`], 
              Complex[3.285264830490968, -1.5473047611339115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3995205084940483`, 1.1830043339085194`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.041384769809504604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.041384769809504604`], 
              Complex[4.823037890424123, -1.1416195640990148`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.191504127959936, 1.3299322469462351`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.105918638824221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.105918638824221, -0.21621381305374007`], 
              Complex[3.2974227667841576`, -1.546146059999975]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3980857242601568`, 1.1831555130399938`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04242403362064922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.04242403362064922], 
              Complex[4.812130418776984, -1.1407314794193446`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1932539361222496`, 1.3287433613304183`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1164306967437954`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21630618103294616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.1164306967437954`, -0.21630618103294616`], 
              Complex[3.3096846328660448`, -1.5450495423633643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3966277542716596`, 1.1833053165967158`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.404488673178392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0435095374916808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.404488673178392, 0.0435095374916808], 
              Complex[4.801116427450052, -1.1397957791050348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1950303190658123`, 1.3275597808917121`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1270248839729087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2164587753829217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.322055203038721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.544018556274634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.1270248839729087`, -0.2164587753829217], 
              Complex[3.322055203038721, -1.544018556274634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3951456617707092`, 1.1834534169226611`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114845`], 
              Complex[4.78999114196779, -1.1388089172545461`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1968342325143446`, 1.3263818579998654`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1377052534254433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175475`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.1377052534254433`, -0.21667494441768215`], 
              Complex[3.334539485939788, -1.5430568024175475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.393638452155945, 1.1835994433437}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04583244395046668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.04583244395046668], 
              Complex[4.778749553944276, -1.1377669993932333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.1986666950452238`, 1.3252099942378486`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209197`], 
              Complex[3.347142736911111, -1.5421683765599408`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3921050686438954`, 1.1837429760162146`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.375281340051193`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04707723610641667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.375281340051193, 0.04707723610641667], 
              Complex[4.767386408695089, -1.136665739909798]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.200528792706521, 1.3240446475537702`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.541357818133694`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992386`], 
              Complex[3.359870470056671, -1.541357818133694]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3905443876377135`, 1.1838835387782198`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410603633`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.135500413367616`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.048383125410603633`], 
              Complex[4.755896193160949, -1.135500413367616]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2024216839171926`, 1.3228863405905458`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1703067856653018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21774382534019787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.372728469582494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5406301659307435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.1703067856653018`, -0.21774382534019787`], 
              Complex[3.372728469582494, -1.5406301659307435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3889552138131367`, 1.1840205908225483`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.355317910736984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.355317910736984, 0.04975479211876499], 
              Complex[4.744273124550121, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.204346604625361, 1.321735670408893}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165973986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.21825535165973986`], 
              Complex[3.385722799858256, -1.5399910220686328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.387336274946709, 1.1841535169765731`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3451748653131745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05119740181429549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622778`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.3451748653131745`, 0.05119740181429549], 
              Complex[4.732511140259883, -1.1329561151622778`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2063048736778208`, 1.3205933198612423`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.192554939758106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2188533057099164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.192554939758106, -0.2188533057099164], 
              Complex[3.398859813435927, -1.5394466255711587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.385686216533123, 1.1842816163308605`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05271666771536838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.05271666771536838], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2082978983227308`, 1.3194600709242967`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21954386620430988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.21954386620430988`], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3840035962697161`, 1.1844040889090253`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952717], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2103271797234785`, 1.3183368203574153`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.215261587046473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.215261587046473, -0.2203339164903332], 
              Complex[3.4255887667699514`, -1.5386707368477486`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.382286878530116, 1.1845200200116413`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3140398458230234`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.3140398458230234`, 0.05601119898888099], 
              Complex[4.696326724353139, -1.1285088210227603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2123943182999426`, 1.3172245981237558`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.226800554414456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22123113894674903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.226800554414456, -0.22123113894674903`], 
              Complex[3.4391948727143986`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3805344290108108`, 1.184628361797253}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375008`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.057801327638013905`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375008`, 0.057801327638013905`], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2145010186272476`, 1.3161245890920878`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2384709550276787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22224412353114367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.2384709550276787`, -0.22224412353114367`], 
              Complex[3.4529719736549263`, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3787445098205142`, 1.1847279115826053`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180629, 0.05969804216878783], 
              Complex[4.671385007001144, -1.1250298694138174`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2166490935025482`, 1.3150381586291193`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2502787217879465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.2502787217879465`, -0.22338249250843537`], 
              Complex[3.4669278152904948`, -1.5384206511375547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3769152754018275`, 1.184817286252228}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.281730781277995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.281730781277995, 0.06171110588324314], 
              Complex[4.658646056679823, -1.1231061803689848`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.218840466625043, 1.3139668827936108`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22465704353173377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838813`, -0.22465704353173377`], 
              Complex[3.481070345408924, -1.5386239263253445`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3750447698399282`, 1.184894892066132}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0638514545260297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.0638514545260297], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.221077173107132, 1.3129125839498217`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.373130926340418, 1.1849588890480665`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.259461393050655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.259461393050655, 0.06613136000835815], 
              Complex[4.6325923193910725`, -1.1188275290397083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2233613567236128`, 1.3118773727195492`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.286586486377321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2276647637711864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.286586486377321, -0.2276647637711864], 
              Complex[3.509947843100934, -1.5395421364907356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.371171569969385, 1.1850071490350698`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672787`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672787`, 0.06856461676025169], 
              Complex[4.619261335536664, -1.1164425322748182`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2256952623834643`, 1.3108636972714853`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.299003692304085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.299003692304085, -0.22942699279424644`], 
              Complex[3.5246989546875493`, -1.5402906900657318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3691644251711594`, 1.1850372063896215`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.236552459537739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.236552459537739, 0.07116675231062836], 
              Complex[4.605716884708898, -1.1138704540789932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.228081221740402, 1.309874400972441}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3115874899792836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23138396931833938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5412583702907805`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.3115874899792836`, -0.23138396931833938`], 
              Complex[3.5396687117196857`, -1.5412583702907805`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3671071301475317`, 1.1850462003498161`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.224844111913217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.224844111913217, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2305216291036345`, 1.3089127893445962`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3243426567556305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.3243426567556305`, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046266`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3649972609370353`, 1.1850308080734386`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2129599799115014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07694987142173917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.2129599799115014`, 0.07694987142173917], 
              Complex[4.577957240848536, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.233018903826367, 1.3079827070004018`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23596306901323055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136321`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.23596306901323055`], 
              Complex[3.5702919304393554`, -1.5439457760136321`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3628323690167117`, 1.1849871677042876`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.200896263829859`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.200896263829859, 0.08017280757570089], 
              Complex[4.563728632846571, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2355754341022602`, 1.3070886246270397`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5457208265493538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577235`, -0.23863220192231416`], 
              Complex[3.5859564964599837`, -1.5457208265493538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3606100374961574`, 1.1849107913888706`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1886505348460092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08364909334179298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.1886505348460092`, 0.08364909334179298], 
              Complex[4.549260572342167, -1.1012616980470775`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.23819349558469, 1.3062357349604115`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.363667294709622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24159066834690393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.363667294709622, -0.24159066834690393`], 
              Complex[3.601860790294312, -1.5478264033073155`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3583279624889981`, 1.1847964693034878`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1762222959316895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08740682313953875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.1762222959316895`, 0.08740682313953875], 
              Complex[4.534550258420688, -1.097389646163949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2408751365289477`, 1.3054300547279405`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.618004732680665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5502998152929643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517174`, -0.24486976056502383`], 
              Complex[3.618004732680665, -1.5502998152929643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3559840679616366`, 1.1846381677124258`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034556`, 0.09147740408549995], 
              Complex[4.519597775965092, -1.0931607636269258`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.243622019461187, 1.3046785263493108`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358286`, -0.24850423935263444`], 
              Complex[3.6343842753970157`, -1.5531827657019452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3535766640554765`, 1.1844289272681492`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.150830514917903`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.150830514917903, 0.09589570953158887], 
              Complex[4.50440717897338, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.24643520819149, 1.3039891082809558`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889629, -0.25253232740394754`], 
              Complex[3.650990035081119, -1.5565214356849035`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.351104660065228, 1.1841607726676704`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1378831966654945`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10070007254234242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.1378831966654945`, 0.10070007254234242`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.249314889255502, 1.3033708358129308`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5603662733822412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.667805619167919, -1.5603662733822412`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3485678429888446`, 1.1838246518564723`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1247883648757773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10593201418800258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.1247883648757773`, 0.10593201418800258`], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2522600201909393`, 1.3028338247141253`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2619374941172033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.684805656152575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647713188313286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.2619374941172033], 
              Complex[3.684805656152575, -1.5647713188313286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3459672292427958`, 1.1834104323840273`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320063`, 0.11163556486001087`], 
              Complex[4.457537610074802, -1.0717748675240164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.255267905806311, 1.3023891790741562`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059931], 
              Complex[3.7019536132591466`, -1.5697928508801493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.343305488385303, 1.1829069935625791`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0982631140723664`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.0982631140723664`, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2583337206674186`, 1.302048754496306}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.460865879669165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7191996003365837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5754871190552315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.460865879669165, -0.27343836455892556`], 
              Complex[3.7191996003365837`, -1.5754871190552315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3405874206219888`, 1.1823024632748216`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981809, 0.12463782579822877`], 
              Complex[4.425499081603798, -1.0576646374765928`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.261450023664929, 1.301824723859007}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.475028497636533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.475028497636533, -0.2800822323034718], 
              Complex[3.736478521301462, -1.5819069561624788`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.337820442230631, 1.1815846522129752`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918283`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4093941501489144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918283, 0.1320217921353984], 
              Complex[4.4093941501489144`, -1.0495628600775768`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2646063477307081`, 1.3017289040489732`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.489102772743466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2873682998621297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.489102772743466, -0.2873682998621297], 
              Complex[3.7537091204741744`, -1.5890972039111029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3350149958373432`, 1.1807417271461693`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.058320074594352`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1400410254670659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.058320074594352, 0.1400410254670659], 
              Complex[4.393335070431696, -1.0407007016791032`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.267788986256211, 1.3017718389315232`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697796`, -0.29531732776612196`], 
              Complex[3.770794613325991, -1.5970891666976452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.332184763990844, 1.1797631279505794`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009882`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2709811186710447`, 1.3019617023151093`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.516644453299159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101082`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.516644453299159, -0.3039330313949988], 
              Complex[3.787625571970204, -1.6058947337101082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3293465435767522`, 1.1786406646453123`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.15805167382144264`], 
              Complex[4.361754274818787, -1.0205889908238697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2741633942326356`, 1.3023031753120264`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3131980951405524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509906`, -0.3131980951405524], 
              Complex[3.8040854242836257`, -1.6155012704525789`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.326519662020908, 1.1773696400320683`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132117`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132117`, 0.16802967600526228`], 
              Complex[4.34645857273412, -1.0093399640268061`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.277315005232697, 1.3027965316109558`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771693`, -0.3230721172560292], 
              Complex[3.8200582761098665`, -1.625868648866985]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.323724904076076, 1.1759497644229226`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1786100786041207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.1786100786041207], 
              Complex[4.331647428673965, -0.9973396858188018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.280415138604208, 1.3034371807829288`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.555022797842972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434281`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.555022797842972, -0.3334924140604994], 
              Complex[3.8354379364471796`, -1.6369295948434281`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.320983060208273, 1.1743856123346503`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.18973028734408162`], 
              Complex[4.317427040750872, -0.9846553249905687]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2834445520275664`, 1.3042158366280123`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.566691838949067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490952983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.566691838949067, -0.34437794490952983`], 
              Complex[3.8501363909766333`, -1.6485937815375424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.318313350484081, 1.1726864541422828`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934495046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859253`, 0.20130934934495046`], 
              Complex[4.3038854304700065`, -0.9713771047973323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.28638695315724, 1.30511930965966}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946227`], 
              Complex[3.864089926301709, -1.6607550217891223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3157320453376002`, 1.1708654635949702`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474703`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2132543530929577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.29108631848507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474703`, 0.2132543530929577], 
              Complex[4.29108631848507, -0.9576111105020126]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.289229914108205, 1.306131743395168}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5880318511300824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36716827124164675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.5880318511300824`, -0.36716827124164675`], 
              Complex[3.8772617652382877`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3132515510777614`, 1.1689384815256942`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9658149382262047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22546793870233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.9658149382262047`, 0.22546793870233295`], 
              Complex[4.2790664893039665`, -0.9434705428233613]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2919652034324578`, 1.3072360096435218`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.37888080574180316`], 
              Complex[3.889641123048907, -1.6861168153853252`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3108800779056993`, 1.1669226205635672`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23785537273090346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.23785537273090346`], 
              Complex[4.267836735050403, -0.9290672478326637]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2945885862953408`, 1.3084149874652113`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6066509332628542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3906866010723906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.6066509332628542`, -0.3906866010723906], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3086218397324414`, 1.1648349861741165`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771305`], 
              Complex[4.257385543344472, -0.9145049639864035]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2970992561032932`, 1.3096525459021722`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.614986365799948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678371946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.614986365799948, -0.40251041678371946`], 
              Complex[3.912085621903241, -1.7121629626858914`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.306477622545319, 1.162691693929425}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.941206632003138`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2628167267283538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.941206632003138, 0.2628167267283538], 
              Complex[4.247684254548457, -0.8998749672010711]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.2994990906820523`, 1.3109341697391197`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.622720730815854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4142898642644486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.725224034003568`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.622720730815854, -0.4142898642644486], 
              Complex[3.9222198214979063`, -1.725224034003568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3044455282240275`, 1.1605072437468391`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2752531764187573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.2752531764187573], 
              Complex[4.238692484798848, -0.8852540673280818]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3017918929111514`, 1.3122472597433967`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6298974852549244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42597525546826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.6298974852549244`, -0.42597525546826], 
              Complex[3.9316893781660758`, -1.7382225152116566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3025217339005444`, 1.1582942196491406`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.2875897604942168], 
              Complex[4.230362981869568, -0.8707044591549238]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3039827166087987`, 1.313581185618099}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6365618226979435`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43752848511674586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.6365618226979435`, -0.43752848511674586`], 
              Complex[3.9405445393067424`, -1.7511096707348448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.3007011660687604`, 1.1560632368114143`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9219443399347473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.29978844959373085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.9219443399347473`, 0.29978844959373085`], 
              Complex[4.2226455060035075`, -0.8562747872176834]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3060773227501732`, 1.3149271784298573`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826845`, -0.44892143644815663`], 
              Complex[3.948835712532858, -1.763848614878014]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.298978044360829, 1.1538230491332264`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934006`], 
              Complex[4.2154896572704255`, -0.8420018475938864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3080817720599374`, 1.316278136034257}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6485298058180127`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4601342612759222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764123973101793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.6485298058180127`, -0.4601342612759222], 
              Complex[3.95661157787795, -1.7764123973101793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.297346288949403, 1.151580743813152}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3236682414244005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.3236682414244005], 
              Complex[4.208846763357216, -0.8279125023887515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3100021386460388`, 1.3176283944102225`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6539158085376195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4711537472500264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.788782141660249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.6539158085376195`, -0.4711537472500264], 
              Complex[3.963917947183658, -1.788782141660249]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2957998069087038`, 1.1493419700143042`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.906871213268679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.906871213268679, 0.3353164289039029], 
              Complex[4.202671020177383, -0.8140255411104013]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3118443210915525`, 1.3189734983123436`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500917994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48197187877303554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.800945377085379`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500917994`, -0.48197187877303554`], 
              Complex[3.970797171183352, -1.800945377085379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2943326811176437`, 1.147111168211903}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669035`, 0.3467578191386486], 
              Complex[4.196920084784547, -0.8003533490732545]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3136139269449212`, 1.320309989635654}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.66367399535596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.66367399535596, -0.49258462786579754`], 
              Complex[3.9772879223008815`, -1.8128946175014515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2929392857646773`, 1.1448917818283746`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.35798845368834886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400257`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.35798845368834886`], 
              Complex[4.1915552925709445`, -0.7869033281400257]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3153162097385034`, 1.3216352217365335`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751522, -0.5029909709021093], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2916143493244245`, 1.1426864429123014`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.894927283100901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.894927283100901, 0.36900737727295463`], 
              Complex[4.1865416324253255`, -0.7736790656393466]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3169560419951263`, 1.322947201772055}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.672284556174856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.672284556174856, -0.5131921073476411], 
              Complex[3.989240598169982, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2903529815464103`, 1.1404971297989093`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485147`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.181847576794925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7606812732613816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485147`, 0.3798158565375278], 
              Complex[4.181847576794925, -0.7606812732613816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3185379118591412`, 1.324244459741766}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.289150676819393, 1.138325298068106}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379956`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.747908528278101`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379956`, 0.3904167697900051], 
              Complex[4.177444833357389, -0.747908528278101]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3200659344911012`, 1.3255259413319709`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598119], 
              Complex[4.000015848490729, -1.858517093091783]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2880033027721522`, 1.1361719876999965`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346618], 
              Complex[4.173308062162179, -0.7353578512653347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3215438720829031`, 1.3267909211366744`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885692], 
              Complex[4.005023753334011, -1.8693886729252436`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2869070802539369`, 1.1340379098537248`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.882507505534356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.723025151975394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.882507505534356, 0.4110127578783307], 
              Complex[4.169414585788293, -0.723025151975394]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.322975158357445, 1.3280389328750903`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.686831218006914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.686831218006914, -0.5520158986267103], 
              Complex[4.009806376364359, -1.8800548315018006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.285858558830457, 1.1319235166497295`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4210179459473809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.4210179459473809], 
              Complex[4.165744108890901, -0.7109055707023485]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3243629248491053`, 1.3292697135446336`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0143819008890915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8905208626824292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399864`, -0.5612511491377957], 
              Complex[4.0143819008890915`, -1.8905208626824292`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.284854590499166, 1.1298290570165097`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148405`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148405`, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3257100272570137`, 1.3304831588689654`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6930566024649254`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.6930566024649254`, -0.5703092165540393], 
              Complex[4.018766629721939, -1.9007923754230047`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2838923033318224`, 1.127754621242315}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44047065160543564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.44047065160543564`], 
              Complex[4.159001332605871, -0.6872839696368794]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3270190708405247`, 1.3316792878312393`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6959561299187063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5791958590266274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.6959561299187063`, -0.5791958590266274], 
              Complex[4.022975200759231, -1.9108751468578666`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2829690760749433`, 1.1257001764416252`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.872929032365991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44992976094784376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.872929032365991, 0.44992976094784376`], 
              Complex[4.155898108440934, -0.6757704154937816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.328292434278008, 1.3328582144788306`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6987283448032713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5879167986060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.6987283448032713`, -0.5879167986060274], 
              Complex[4.027020779081279, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.282082514287024, 1.123665594750138}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.87087311222959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45921842799560564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.87087311222959, 0.45921842799560564`], 
              Complex[4.152955626516614, -0.6644471667545323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3295322917050634`, 1.3340201255300457`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911523], 
              Complex[4.030915226970466, -1.9304977888211978`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2812304282964038`, 1.1216506757177542`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370314`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370314`, 0.4683423384869718], 
              Complex[4.150162032533435, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3307406328361906`, 1.3351652626022807`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011079], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2804108130757665`, 1.119655164080114}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4773070426385345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.4773070426385345], 
              Complex[4.147506625196922, -0.6423481214415796]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3319192811896667`, 1.3362939081184417`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2796218300135123`, 1.1176787638518553`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3330699105032777`, 1.3374063741405955`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7087239788036013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6212539145605382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.7087239788036013`, -0.6212539145605382], 
              Complex[4.041793889306879, -1.9586602887011337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2788617904943318`, 1.1157211494926285`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426784`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.494780200584179`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426784`, 0.494780200584179], 
              Complex[4.142572556837011, -0.6209409489084494]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3341940594651076`, 1.338502993533955}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 1, {
              Complex[2.710987197779322, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2781291411648215`, 1.1137819747427737`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5032988771597041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 2, {
              Complex[2.8621480115494466`, 0.5032988771597041], 
              Complex[4.140277152714268, -0.6104830975830695]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3352931448999934`, 1.339584112987158}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.713168767151179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6370671424983345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 1, {
              Complex[2.713168767151179, -0.6370671424983345], 
              Complex[4.048461912051172, -1.9766512554854925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.277422450743483, 1.1118608796026908`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8606638084231757`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.138086259166659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6001821017863895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 2, {
              Complex[2.8606638084231757`, 0.5116787778163012], 
              Complex[4.138086259166659, -0.6001821017863895]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3363684735561647`, 1.3406500875123515`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7152740029142293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6447767740762025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.985426861588554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 1, {
              Complex[2.7152740029142293`, -0.6447767740762025], 
              Complex[4.051642476470394, -1.985426861588554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.276740398230624, 1.1099574958323968`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.859252863201372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5199245263444041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 2, {
              Complex[2.859252863201372, 0.5199245263444041], 
              Complex[4.135993261431996, -0.5900329694879928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.337421252632832, 1.3417012761259108`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 1, {
              Complex[2.717307750554921, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2760817623773708`, 1.108071451270443}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8579103524231546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5280405519418736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285694`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 2, {
              Complex[2.8579103524231546`, 0.5280405519418736], 
              Complex[4.133992114800526, -0.5800308993285694]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3384525991814753`, 1.3427380384718106`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 1, {
              Complex[2.7192744356306138`, -0.6598239647344452], 
              Complex[4.057727034812089, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.275445412281044, 1.1062023732101671`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 2, {
              Complex[2.8566318723517807`, 0.5360310932164645], 
              Complex[4.132077284632825, -0.5701712799937028]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3394635485033564`, 1.343760732198116}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.721178108151079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0109304474081915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 1, {
              Complex[2.721178108151079, -0.6671697152100752], 
              Complex[4.060641656654435, -2.0109304474081915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2748302989843854`, 1.1043498910228218`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5439002036016087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212129`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 2, {
              Complex[2.8554133945952374`, 0.5439002036016087], 
              Complex[4.130243693579622, -0.5604496874212129]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3404550616546718`, 1.3447697109354197`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.723022481587047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 1, {
              Complex[2.723022481587047, -0.6744020624307275], 
              Complex[4.063477543241719, -2.019171773366147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2742354479671993`, 1.1025136381787524`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8542512270997307`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5516517577146832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12848667506693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 2, {
              Complex[2.8542512270997307`, 0.5516517577146832], 
              Complex[4.12848667506693, -0.5508618804640691]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3414280321596725`, 1.34576532275647}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 1, {
              Complex[2.724810967217476, -0.6815246607732997], 
              Complex[4.066238999377148, -2.0272899835297697`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2736599524301004`, 1.1006932537873735`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 2, {
              Complex[2.8531419798044717`, 0.5592894583048518], 
              Complex[4.126801932234573, -0.5414037954825217]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3423832920213923`, 1.346747909020392}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.726546704428588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 1, {
              Complex[2.726546704428588, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2731029672806922`, 1.0988883837525507`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8520825343446496`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5668168435275389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 2, {
              Complex[2.8520825343446496`, 0.5668168435275389], 
              Complex[4.125185501625342, -0.5320715402250118]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3433216171097035`, 1.347717803524085}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.728232587492566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.695454416518052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 1, {
              Complex[2.728232587492566, -0.695454416518052], 
              Complex[4.071554204602269, -2.043172220042137]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.272563703742505, 1.0970986816207917`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 2, {
              Complex[2.8510700172747567`, 0.5742372943510565], 
              Complex[4.123633721017262, -0.5228613872697352]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3442437319973228`, 1.3486753318987115`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7298712892804384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7022680930260654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050943424924777`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 1, {
              Complex[2.7298712892804384`, -0.7022680930260654], 
              Complex[4.074115021277762, -2.050943424924777]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2720414245160236`, 1.0953238091843571`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8501017763576963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 2, {
              Complex[2.8501017763576963`, 0.5815540419531228], 
              Complex[4.12214320087372, -0.5137697672312345]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3451503143061692`, 1.3496208112013488`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 1, {
              Complex[2.7314652823007664`, -0.7089850735194758], 
              Complex[4.076615596606936, -2.0586058847208246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2715354394294256`, 1.0935634368891871`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.849175359528075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5887701750046824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 2, {
              Complex[2.849175359528075, 0.5887701750046824], 
              Complex[4.120710798957501, -0.5047932618845047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3460419986191394`, 1.3505545496616918`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 1, {
              Complex[2.733016857401756, -0.7156082665076036], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2710451015239508`, 1.0918172440877818`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.495928597319203`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 2, {
              Complex[2.848288496192057, 0.5958886467685788], 
              Complex[4.1193335977160075`, -0.495928597319203]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3469193800058634`, 1.3514768465514693`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7345281404282455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 1, {
              Complex[2.7345281404282455`, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.270569803525362, 1.0900849191693636`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 2, {
              Complex[2.847439080572326, 0.6029122819634526], 
              Complex[4.118008884097688, -0.4871726372059109]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3477830172051848`, 1.3523879921505317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 1, {
              Complex[2.736001107085406, -0.7285842912785055], 
              Complex[4.083784124290591, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2701089746587155`, 1.0883661595933587`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.846625156846318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 2, {
              Complex[2.846625156846318, 0.6098437833604627], 
              Complex[4.116734131505034, -0.478522376232896]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.34863343550207, 1.3532882677886193`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.737437596227138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.734942326817608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 1, {
              Complex[2.737437596227138, -0.734942326817608], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2696620777687606`, 1.0866606718472054`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384025`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 2, {
              Complex[2.845844905859744, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384025`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3494711293321664`, 1.3541779459458636`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 1, {
              Complex[2.7388393217580846`, -0.7412169946624543], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2692286067127463`, 1.084968171345411}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1143252399392205`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.46152754767328247`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.1143252399392205`, -0.46152754767328247`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3502965646432923`, 1.3550572903983809`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.74020788331328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 1, {
              Complex[2.74020788331328, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2688080839963416`, 1.0832883822835293`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613556`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 2, {
              Complex[2.8443787586507785`, 0.6301108136973939], 
              Complex[4.113186842647121, -0.45317756858613556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3511101810397217`, 1.3559265563979426`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1094520143136553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 1, {
              Complex[2.7415447758580713`, -0.7535254579157125], 
              Complex[4.092654956897793, -2.1094520143136553`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2684000586268078`, 1.0816210374580488`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.636698583278269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417977994`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 2, {
              Complex[2.843689806329271, 0.636698583278269], 
              Complex[4.112089864956078, -0.44492245417977994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3519123937320874`, 1.3567859908768638`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7428513983325447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7595636290829763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 1, {
              Complex[2.7428513983325447`, -0.7595636290829763], 
              Complex[4.094763792064632, -2.1163496199598404`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2680041041606018`, 1.0799658780610617`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843028396308333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013437`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 2, {
              Complex[2.843028396308333, 0.643206114159718], 
              Complex[4.1110325004689345`, -0.4367597639013437]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3527035953131048`, 1.3576358326709914`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 1, {
              Complex[2.744129061448893, -0.7655271940238003], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2676198169252069`, 1.0783226534568342`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688586`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848105`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 2, {
              Complex[2.842393236688586, 0.6496354995683531], 
              Complex[4.110013053613793, -0.42868715388848105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3534841573769858`, 1.3584763127550676`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7453789947364777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714181229593399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 1, {
              Complex[2.7453789947364777`, -0.7714181229593399], 
              Complex[4.098863152113464, -2.1298944357144074`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2672468143973123`, 1.0766911209459986`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 2, {
              Complex[2.8417831165816425`, 0.6559887487872507], 
              Complex[4.109029930978955, -0.4207023721587479]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3542544319983827`, 1.3593076544859064`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 1, {
              Complex[2.746602352917594, -0.7772383070571708], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2668847337215239`, 1.0750710455219263`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.841196899736145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 2, {
              Complex[2.841196899736145, 0.6622677914714881], 
              Complex[4.108081633457669, -0.4128032540504382]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3550147530849104`, 1.3601300738497373`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 1, {
              Complex[2.7478002216867257`, -0.7829895624892169], 
              Complex[4.102814974771636, -2.1431196363389544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2665332303555101`, 1.0734621996229434`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.84063351876029`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40498771790623117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 2, {
              Complex[2.84063351876029, 0.6684744817167123], 
              Complex[4.1071667491158, -0.40498771790623117`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3557654376157497`, 1.3609437797108246`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 1, {
              Complex[2.748973622957286, -0.7886736342555828], 
              Complex[4.104739060573036, -2.1496174139664075`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.266191976829143, 1.071864362883253}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.39725376098988185`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 2, {
              Complex[2.8400919698768625`, 0.6746106018933712], 
              Complex[4.1062839467060055`, -0.39725376098988185`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3565067867774316`, 1.3617489740590967`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1560411738459275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409573, -2.1560411738459275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2658606616064754`, 1.0702773218848616`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 2, {
              Complex[2.8395713081544542`, 0.6806778662591636], 
              Complex[4.10543196976093, -0.38959945562569803`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3572390870066984`, 1.362545852255007}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7512508199475976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 1, {
              Complex[2.7512508199475976`, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921433`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2655389880406933`, 1.0687008699122638`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8390706431652144`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.686677924362138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38202294555012584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 2, {
              Complex[2.8390706431652144`, 0.686677924362138], 
              Complex[4.104609631205908, -0.38202294555012584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3579626109492815`, 1.363334603270253}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 1, {
              Complex[2.7523563814347085`, -0.8053392041803542], 
              Complex[4.11031899238399, -2.1686738074506073`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2652266734131907`, 1.0671348067112731`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8385891350252574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.374522442464793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 2, {
              Complex[2.8385891350252574`, 0.6926123642464802], 
              Complex[4.103815808438448, -0.374522442464793]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3586776183424694`, 1.3641154099233181`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 1, {
              Complex[2.7534410145367234`, -0.8107706896206488], 
              Complex[4.112118632879193, -2.1748860995439667`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2649234480488891`, 1.0655789382530263`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83812599077891`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36709622278037246`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 2, {
              Complex[2.83812599077891, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.36709622278037246`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.359384356828524, 1.364888449109056}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 1, {
              Complex[2.7545054859170786`, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.264629054500748, 1.0640330765039459`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409171`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 2, {
              Complex[2.8376804610924067`, 0.7042904519630286], 
              Complex[4.102309515593155, -0.3597426245409171]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3600830627052753`, 1.3656538920217647`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2643432467971374`, 1.0624970392022146`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3524600445185817`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 2, {
              Complex[2.8372518372264883`, 0.7100369946836329], 
              Complex[4.101595084023626, -0.3524600445185817]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3607739616195396`, 1.366411904371353}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1931261038190124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 1, {
              Complex[2.7565768091901, -0.8267141994476594], 
              Complex[4.11735077080964, -2.1931261038190124`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2640657897464236`, 1.0609706496411517`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.34524693546903984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 2, {
              Complex[2.836839448260752, 0.7157237141721119], 
              Complex[4.100905238007176, -0.34524693546903984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.361457269208471, 1.367162646592373}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.757585001537493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 1, {
              Complex[2.757585001537493, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2637964582936505`, 1.059453736459734}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836442658545575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 2, {
              Complex[2.836442658545575, 0.7213519329214123], 
              Complex[4.100239116839225, -0.3381018035383218]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3621331916934059`, 1.3679062740457615`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 1, {
              Complex[2.7585757179660733`, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2635350369247706`, 1.0579461334403948`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 2, {
              Complex[2.836060865360036, 0.7269229276281968], 
              Complex[4.099595902284807, -0.3310232058121981]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3628019264303366`, 1.3686429372132638`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.84215888622212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.210801823435384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 1, {
              Complex[2.759549546988155, -0.84215888622212], 
              Complex[4.122351473418491, -2.210801823435384]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2632813191142795`, 1.056447679314151}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.835693496756588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972326`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 2, {
              Complex[2.835693496756588, 0.7324379313144278], 
              Complex[4.098974815870868, -0.32400974799972326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3634636624207175`, 1.3693727818845618`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7605070481803384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 1, {
              Complex[2.7605070481803384`, -0.8472019743388878], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2630351068125485`, 1.054958217573022}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.737898135330063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 2, {
              Complex[2.8353400095752215`, 0.737898135330063], 
              Complex[4.0983751163877695`, -0.31706008224295906`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3641185807859635`, 1.3700959493371787`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.761448754016845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8521943919901347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125567334802809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2222903413273136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 1, {
              Complex[2.761448754016845, -0.8521943919901347], 
              Complex[4.125567334802809, -2.2222903413273136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2627962099694996`, 1.0534775962896736`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834999887611698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 2, {
              Complex[2.834999887611698, 0.7433046912443019], 
              Complex[4.097796097581198, -0.31017290504537165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3647668552086767`, 1.3708125765093016`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7623751715626246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 1, {
              Complex[2.7623751715626246`, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2625644460915875`, 1.0520056679441445`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834672639925991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.748658712632362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 2, {
              Complex[2.834672639925991, 0.748658712632362], 
              Complex[4.097237086017579, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3654086523433295`, 1.3715227961656586`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.763286784038682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.862031510221407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 1, {
              Complex[2.763286784038682, -0.862031510221407], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2623396398293503`, 1.0505422892575185`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 2, {
              Complex[2.8343577992784867`, 0.7539612767642828], 
              Complex[4.096697439107837, -0.2965810124932357]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.366044132198916, 1.3722267370566545`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.76418405227083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 1, {
              Complex[2.76418405227083, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2621216225930283`, 1.0490873210323428`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834054920682748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045606`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 2, {
              Complex[2.834054920682748, 0.7592134262018868], 
              Complex[4.096176543275776, -0.28987389483045606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3666734484957987`, 1.372924524070941}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7650674160319424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 1, {
              Complex[2.7650674160319424`, -0.8716784802620262], 
              Complex[4.131740864527741, -2.244603004332967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.261910232194015, 1.0476406279996031`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833763580064758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 2, {
              Complex[2.833763580064758, 0.7644161703095633], 
              Complex[4.095673812258773, -0.2832244576900397]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3672967489988284`, 1.3736162783816548`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765937295286828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 1, {
              Complex[2.765937295286828, -0.8764330896595156], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.261705312510071, 1.046202078672044}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.27663159198783]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.367914175828569, 1.3743021175865284`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.766794091347923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 1, {
              Complex[2.766794091347923, -0.8811430162906048], 
              Complex[4.134708267176491, -2.2554451338771333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2615067131724471`, 1.0447715452036124`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833213913656889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 2, {
              Complex[2.833213913656889, 0.7746773225093271], 
              Complex[4.094720626829336, -0.27009422269428524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3685258657523545`, 1.3749821558421014`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 1, {
              Complex[2.7676381879492564`, -0.8858091496519154], 
              Complex[4.136164053701611, -2.2607913054940165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.261314289273218, 1.0433489032547973`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8329548335289294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7797375958378117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2636113074169858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 2, {
              Complex[2.8329548335289294`, 0.7797375958378117], 
              Complex[4.094269122802148, -0.2636113074169858]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3691319504567037`, 1.37565650399226}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 1, {
              Complex[2.768469952245414, -0.8904323517124779], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2611279010912861`, 1.0419340318636496`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325198`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0938336817238055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.25718183505570524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 2, {
              Complex[2.8327057806325198`, 0.7847521968079443], 
              Complex[4.0938336817238055`, -0.25718183505570524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3697325568025043`, 1.3763252696913277`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544097`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 1, {
              Complex[2.7692897357415927`, -0.8950134580602261], 
              Complex[4.139022292544097, -2.2713387277515538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2609474138356278`, 1.0405268133222503`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.2508048245258131]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3703278070642717`, 1.3769885575219305`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 1, {
              Complex[2.770097875160308, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2607726974045164`, 1.0391271330584035`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 2, {
              Complex[2.83223642523709, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.2444793235459518]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.37091781915463, 1.3776464691078487`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7708946932497662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9040526005333868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 1, {
              Complex[2.7708946932497662`, -0.9040526005333868], 
              Complex[4.141812512404397, -2.2816990696412356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2606036261595204`, 1.0377348795223467`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 2, {
              Complex[2.832015492909507, 0.7995304720360316], 
              Complex[4.0926191190690275`, -0.2382044074863151]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.371502706835134, 1.3782991032220788`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 1, {
              Complex[2.771680499538499, -0.9085121854432783], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2604400787132142`, 1.0363499440782498`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831803326596092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.804370765804293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 2, {
              Complex[2.831803326596092, 0.804370765804293], 
              Complex[4.092243405309306, -0.23197917827395678`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.372082579914379, 1.378946555890304}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7724555910404214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 1, {
              Complex[2.7724555910404214`, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2602819377296068`, 1.0349722209003105`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831599643781914`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.225802763351888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 2, {
              Complex[2.831599643781914, 0.8091694575484224], 
              Complex[4.0918815815115215`, -0.225802763351888]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.37265754443433, 1.3795889204899812`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.917315085499543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 1, {
              Complex[2.773220252914126, -0.917315085499543], 
              Complex[4.145877797348456, -2.296904005989524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2601290897363813`, 1.0336016068732337`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809608`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886287`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 2, {
              Complex[2.8314041736809608`, 0.8139272921843708], 
              Complex[4.091533263417342, -0.21967431468886287`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3732277028457007`, 1.3802262878452332`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 1, {
              Complex[2.7739747590798687`, -0.9216598178919513], 
              Complex[4.147202461925569, -2.3018861057371844`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2599814249481192`, 1.0322380014969068`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.213593007836997`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 2, {
              Complex[2.8312166566204735`, 0.8186449936599098], 
              Complex[4.091198081568593, -0.213593007836997]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3737931541731325`, 1.3808587463177344`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7747193727974437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9259676497839735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 1, {
              Complex[2.7747193727974437`, -0.9259676497839735], 
              Complex[4.148512526970577, -2.306826396101708]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2598388370997253`, 1.0308813067950824`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448106`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 2, {
              Complex[2.8310368434643864`, 0.8233232657606013], 
              Complex[4.090875680564112, -0.20755804103448106`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3743539941708924`, 1.3814863818937801`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7754543472078295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 1, {
              Complex[2.7754543472078295`, -0.9302392405994727], 
              Complex[4.149808341378722, -2.311725622493253]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.2597012232893838`, 1.0295314272278835`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20156863435089428`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 2, {
              Complex[2.8308644950729813`, 0.8279627928769892], 
              Complex[4.090565718362365, -0.20156863435089428`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{-1.3749103154697289`, 1.382109278267698}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7761799258412623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.934475231424826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 1, {
              Complex[2.7761799258412623`, -0.934475231424826], 
              Complex[4.151090241310992, -2.316584509692524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-1.259568483830361, 1.028188269607965}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 2, {
              Complex[2.8306993817960873`, 0.8325642407352365], 
              Complex[4.090267865626448, -0.19562402887272834`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0444300706313414`, 1.4968466580800108`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 1, {
              Complex[3.8395927484273855`, -0.6433017314670886], 
              Complex[1.795162677796044, -2.1401483895470994`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6397867417501044`, 1.1700244588063093`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.836019007965047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00664507113781796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.196232266214943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 2, {
              Complex[7.836019007965047, 0.00664507113781796], 
              Complex[6.196232266214943, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.044844082015331, 1.495499002677154}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.874980911856298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.616522179294801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1120211819719548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 1, {
              Complex[3.874980911856298, -0.616522179294801], 
              Complex[1.8301368298409673`, -2.1120211819719548`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6403765475866035`, 1.1700906593460907`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0067125107858549355`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 2, {
              Complex[7.795901779221279, 0.0067125107858549355`], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0452034856727566`, 1.4941201745224157`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025942`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 1, {
              Complex[3.9045700992025942`, -0.5952855745698099], 
              Complex[1.859366613529838, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6409674614924308`, 1.17015713808447}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047784`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 2, {
              Complex[7.763484521798688, 0.006786025025047784], 
              Complex[6.122517060306257, -1.163371113059422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0455153255245757`, 1.4927176614778306`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9307507913132285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.577315686227792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 1, {
              Complex[3.9307507913132285`, -0.577315686227792], 
              Complex[1.8852354657886525`, -2.0700333477056225`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6415598616528695`, 1.1702239581046223`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 2, {
              Complex[7.735547972440535, 0.006863336573144921], 
              Complex[6.093988110787665, -1.1633606215314776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0457842050730433`, 1.491296260033016}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 1, {
              Complex[3.9546128944921866`, -0.5615718710865848], 
              Complex[1.908828689419143, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6421539849763163`, 1.1702911588985738`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604799`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 2, {
              Complex[7.710629285429999, 0.006943461497604799], 
              Complex[6.068475300453683, -1.163347697400969]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0460134876232576`, 1.4898593936430986`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 1, {
              Complex[3.976762799482184, -0.5474736791133856], 
              Complex[1.9307493118589263`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.642749999669796, 1.1703587685295225`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 2, {
              Complex[7.687917286732913, 0.007025882918871683], 
              Complex[6.045167287063117, -1.1633328856106508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0462057977885997`, 1.4884096660678887`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9975793662526633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0230672781048264`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 1, {
              Complex[3.9975793662526633`, -0.5346576120369375], 
              Complex[1.9513735684640636`, -2.0230672781048264`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6433480348146325`, 1.1704268085713438`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162861`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 2, {
              Complex[7.666906890699566, 0.007110298008162861], 
              Complex[6.023558855884933, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0463632750519123`, 1.486949142381658}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 1, {
              Complex[4.017318225749185, -0.5228778864146381], 
              Complex[1.9709549506972726`, -2.009827028796296]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6439481949697388`, 1.1704952965397262`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.647258486238892`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007196517077880158`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 2, {
              Complex[7.647258486238892, 0.007196517077880158], 
              Complex[6.003310291269153, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0464877181840464`, 1.4854795097098197`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 1, {
              Complex[4.036161628380458, -0.5119589442981471], 
              Complex[1.9896739101964112`, -1.9974384540079668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6445505683004957`, 1.1705642472412048`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243424`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089611`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 2, {
              Complex[7.628730822140306, 0.007284416332243424], 
              Complex[5.984180253839811, -1.1632798309089611`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0465806745966995`, 1.4840021770794487`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.501770106216406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 1, {
              Complex[4.054245015542007, -0.501770106216406], 
              Complex[2.0076643409453068`, -1.9857722832958546`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.64515523149684, 1.1706336735867482`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.61114527747392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179249466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.96599004597708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 2, {
              Complex[7.61114527747392, 0.007373913179249466], 
              Complex[5.96599004597708, -1.1632597604074986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0466434991212, 1.4825183413487613`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775294`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.974729256230454`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 1, {
              Complex[4.071672363798729, -0.4922109148816928], 
              Complex[2.0250288646775294`, -1.974729256230454]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6457622529384726`, 1.170703587113633}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.594365254745728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033915`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 2, {
              Complex[7.594365254745728, 0.007464952252033915], 
              Complex[5.948603001807256, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.046677394553669, 1.4810290328377038`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.041848212945115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9642311559465873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 1, {
              Complex[4.088525607498784, -0.4832021231088834], 
              Complex[2.041848212945115, -1.9642311559465873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6463716948320208`, 1.1707739983365557`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.578283541245461`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0075574969911632525`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.93191184641344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 2, {
              Complex[7.578283541245461, 0.0075574969911632525`], 
              Complex[5.93191184641344, -1.1632165013453923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0466834407035526`, 1.4795351481161692`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143463`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 1, {
              Complex[4.104870714597596, -0.4746798749981771], 
              Complex[2.058187273894043, -1.9542150231143463`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6469836147106918`, 1.17084491699305}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.562814169527114`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 2, {
              Complex[7.562814169527114, 0.007651524322599015], 
              Complex[5.915830554816422, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0466626158617913`, 1.4780374742961553`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 1, {
              Complex[4.12076176343584, -0.46659179640833665`], 
              Complex[2.074099147574049, -1.944629270704492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6475980665205356`, 1.170916352220469}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115720029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163169331063269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 2, {
              Complex[7.547886962653699, 0.00774702115720029], 
              Complex[5.900288896133163, -1.163169331063269]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.046615813083676, 1.4765367074931341`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.136243770182482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45889427989730935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 1, {
              Complex[4.136243770182482, -0.45889427989730935`], 
              Complex[2.0896279570988052`, -1.9354309873904436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6482151014286568`, 1.1709883126870055`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00784398201226336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.8852286543048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 2, {
              Complex[7.533443755733457, 0.00784398201226336], 
              Complex[5.8852286543048, -1.1631443306747422`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.046543852813575, 1.4750334671609004`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573493103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 1, {
              Complex[4.151354705396686, -0.45155054573493103`], 
              Complex[2.1048108525831113`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.648834768438557, 1.1710608066908612`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021122`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.16311839933984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 2, {
              Complex[7.5194357044269005`, 0.007942407351021122], 
              Complex[5.870600935988343, -1.16311839933984]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0464474928603473`, 1.473528307428782}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1196794742655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9180575310211614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 1, {
              Complex[4.166126967125892, -0.44452922359237934`], 
              Complex[2.1196794742655443`, -1.9180575310211614`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6494571148682273`, 1.1711338422367739`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705283`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 2, {
              Complex[7.5058213212730225`, 0.008042302396705283], 
              Complex[5.856364206404795, -1.1630915398400687`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0463274364100523`, 1.4720217262117419`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4378032933344357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 1, {
              Complex[4.180588479578347, -0.4378032933344357], 
              Complex[2.134261043168295, -1.9098250195461774`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6500821867283233`, 1.1712074270960608`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00814367626923343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 2, {
              Complex[7.492565012985164, 0.00814367626923343], 
              Complex[5.842482826256841, -1.1630637508268276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0461843385556375`, 1.4705141726331525`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.19476352756891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4313492794933509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 1, {
              Complex[4.19476352756891, -0.4313492794933509], 
              Complex[2.148579189013273, -1.9018634521265034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6507100290262455`, 1.1712815688544405`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654009`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 2, {
              Complex[7.479635970943439, 0.008246541346654009], 
              Complex[5.828925941917193, -1.1630350275077865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0460188116863756`, 1.4690060531470497`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4251466287655523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.162654588850219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 1, {
              Complex[4.208673400536594, -0.4251466287655523], 
              Complex[2.162654588850219, -1.8941526819126022`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.651340686014293, 1.1713562749506157`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614356`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 2, {
              Complex[7.4670073159977095`, 0.008350912786614356], 
              Complex[5.815666629983417, -1.1630053621640013`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0458314299869196`, 1.4674977366426467`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.22233689673936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4191772220375585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 1, {
              Complex[4.22233689673936, -0.4191772220375585], 
              Complex[2.1765054667524413`, -1.8866749586802054`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6519742013950327`, 1.1714315527077839`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 2, {
              Complex[7.454655429824251, 0.008456808164000547], 
              Complex[5.802681228429218, -1.1629747445437835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0456227332314345`, 1.4659895587415224`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.235770723063745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4134249869532411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.190147989832311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 1, {
              Complex[4.235770723063745, -0.4134249869532411], 
              Complex[2.190147989832311, -1.8794145456947635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6526106184934766`, 1.1715074093596352`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00856424719441154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 2, {
              Complex[7.442559425423676, 0.00856424719441154], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.04539323001263, 1.4644818254465943`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2035965857225785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 1, {
              Complex[4.248989815735209, -0.4078755867501412], 
              Complex[2.2035965857225785`, -1.8723574121967355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6532499804032557`, 1.171583852072019}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 2, {
              Complex[7.430700722955541, 0.008673251522090995], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0451434005126203`, 1.462974816264852}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2168641997657033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8654909840009635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 1, {
              Complex[4.262007600278324, -0.4025161677361114], 
              Complex[2.2168641997657033`, -1.8654909840009635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.653892330112179, 1.171660887961159}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995744`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 2, {
              Complex[7.419062706397297, 0.008783844556995744], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.044873698898493, 1.461468786898667}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3973351524058626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 1, {
              Complex[4.274836204246599, -0.3973351524058626], 
              Complex[2.2299625053481056`, -1.8588039393045297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6545377106113686`, 1.1717385241090856`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008896051349859017`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 2, {
              Complex[7.4076304429802775`, 0.008896051349859017], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.04458455540756, 1.4599639715801551`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847657186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567271`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 1, {
              Complex[4.287486632822466, -0.39232206847657186`], 
              Complex[2.2429020774149055`, -1.8522860400567271`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6551861649911512`, 1.1718167675768099`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 2, {
              Complex[7.396390451929993, 0.009009898497034048], 
              Complex[5.741204286938842, -1.1628068690797757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0442763781737727`, 1.4584605851077943`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.255692536755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8459279915891411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 1, {
              Complex[4.299968914929404, -0.38746740648134687`], 
              Complex[2.255692536755631, -1.8459279915891411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.655837736526267, 1.1718956254156434`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990438`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 2, {
              Complex[7.3853305123250825`, 0.009125414068990438], 
              Complex[5.729492775798816, -1.162770211346653]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.043949554836515, 1.4569588246327922`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.312292225705379`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 1, {
              Complex[4.312292225705379, -0.3827625002813669], 
              Complex[2.268342670868864, -1.839721324914159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6564924687523725`, 1.1719751046769844`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842201`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 2, {
              Complex[7.374439502284715, 0.009242627557842201], 
              Complex[5.717947033532342, -1.1627324771191423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.043604453965084, 1.4554588712336476`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37819942613027685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639244`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 1, {
              Complex[4.324464989862635, -0.37819942613027685`], 
              Complex[2.280860535897551, -1.8336582973639244`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6571504055354678`, 1.17205521242082}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391612`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 2, {
              Complex[7.363707263462426, 0.009361569840391612], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0432414263259613`, 1.4539608913103}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.33649496946897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37377091687664876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2932535431430088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.827731808186949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 1, {
              Complex[4.33649496946897, -0.37377091687664876`], 
              Complex[2.2932535431430088`, -1.827731808186949]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6578115911355147`, 1.1721359557231514`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00948227315398883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 2, {
              Complex[7.3531244861453, 0.00948227315398883], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0428608060151343`, 1.452465037823688}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 1, {
              Complex[4.348389338937684, -0.36947028861032244`], 
              Complex[2.3055285329225494`, -1.8219353264340106`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6584760702653347`, 1.1722173416825044`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162612570599382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.162612570599382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.042462911473907, 1.4509714514021212`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 1, {
              Complex[4.3601547494422475`, -0.3652913776086273], 
              Complex[2.317691837968341, -1.8162628290107483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6591438881456353`, 1.1722993774256536`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121796`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 2, {
              Complex[7.332373746308075, 0.009729098555121796], 
              Complex[5.67322985816244, -1.1625702788705319`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0420480464034774`, 1.4494802613323097`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.371797384531623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3612284858628568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 1, {
              Complex[4.371797384531623, -0.3612284858628568], 
              Complex[2.329749338128146, -1.8107087471951664`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6598150905568931`, 1.1723820701126724`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 2, {
              Complex[7.322190592979878, 0.009855291843704476], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0416165005911755`, 1.4479915864500459`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 1, {
              Complex[4.38332300838, -0.35727633379543666`], 
              Complex[2.3417065077888237`, -1.8052679202454824`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6604897238887093`, 1.1724654269413928`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3121263843706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384737`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 2, {
              Complex[7.3121263843706, 0.009983388579384737], 
              Complex[5.65163666048189, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0411685506591373`, 1.446505535943165}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3534300190373758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 1, {
              Complex[4.394737007836374, -0.3534300190373758], 
              Complex[2.353568457177237, -1.799935554980541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6611678351871315`, 1.172549455151349}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0101134277659673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.641006995243321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 2, {
              Complex[7.302174830430452, 0.0101134277659673], 
              Complex[5.641006995243321, -1.1624360273853818`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.040704460744615, 1.445022210077558}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34968498034030004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794707190417858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 1, {
              Complex[4.40604442922753, -0.34968498034030004`], 
              Complex[2.3653399684829144`, -1.794707190417858]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6618494722003916`, 1.1726341620272602`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102454498025258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 2, {
              Complex[7.292330070281435, 0.0102454498025258], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0402244831197045`, 1.4435417008553586`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 1, {
              Complex[4.417250010699276, -0.3460369658605057], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6625346834234278`, 1.172719554902103}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 2, {
              Complex[7.282586630397876, 0.010379496510400108`], 
              Complex[5.620051946974448, -1.162340058391703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0397288587571896`, 1.442064092613194}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3424820051832386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7845460977964327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 1, {
              Complex[4.428358210745747, -0.3424820051832386], 
              Complex[2.3886293519885573`, -1.7845460977964327`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6632235181415176`, 1.1728056411598096`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 2, {
              Complex[7.272939387787106, 0.010515611164854503`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0392178178482463`, 1.440589462567246}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456088024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 1, {
              Complex[4.439373233467539, -0.33901638456088024`], 
              Complex[2.400155415619293, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6639160264732995`, 1.1728924282376278`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 2, {
              Complex[7.263383537456196, 0.010653838531129405`], 
              Complex[5.599467510982896, -1.1622385897064984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0386915802769487`, 1.4391178813109793`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7747545062354526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 1, {
              Complex[4.450299051011203, -0.3356366249244734], 
              Complex[2.411607470734254, -1.7747545062354526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6646122594134538`, 1.1729799236281602`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.589302304154469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234662`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 2, {
              Complex[7.253914563567923, 0.010794224904694154`], 
              Complex[5.589302304154469, -1.1621856987234662`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0381503560558887`, 1.4376494132706221`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 1, {
              Complex[4.461139423570387, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6653122688752422`, 1.17306813488111}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 2, {
              Complex[7.244528213784578, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0375943457266392`, 1.4361841171228251`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 1, {
              Complex[4.471897917269896, -0.3291218303014389], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6660161077331295`, 1.1731570696047409`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607955`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 2, {
              Complex[7.235220476376673, 0.011081667776607955`], 
              Complex[5.569204368643544, -1.162075401828133]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.037023740728319, 1.4347220461783863`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7607028906574185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 1, {
              Complex[4.482577920205065, -0.3259808444790322], 
              Complex[2.445554179476746, -1.7607028906574185`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6667238298656641`, 1.1732467354670708`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 2, {
              Complex[7.225987559738016, 0.011228824935798515`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.036438723737121, 1.4332632487354375`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.49318265686856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 1, {
              Complex[4.49318265686856, -0.32291378822242117`], 
              Complex[2.4567439331314396`, -1.7561770369578587`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6674354901987927`, 1.1733371401967958`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423336`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 2, {
              Complex[7.216825874002135, 0.011378342532423336`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0358394689792916`, 1.4318077684050947`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31991810009861654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037111`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 1, {
              Complex[4.503715201163001, -0.31991810009861654`], 
              Complex[2.467875732183709, -1.7517258685037111`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.668151144749763, 1.1734282915839573`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.2077320144994355`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 2, {
              Complex[7.2077320144994355`, 0.011530275257279964`], 
              Complex[5.539580869749672, -1.1618980163266772`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0352261425197904`, 1.430355644412234}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4789523456499616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.747347006826386`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 1, {
              Complex[4.514178488169752, -0.31699136241415204`], 
              Complex[2.4789523456499616`, -1.747347006826386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6688708506717702`, 1.173520197480349}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931235`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 2, {
              Complex[7.198702746831605, 0.011684679656931235`], 
              Complex[5.529831896159835, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0345989025285505`, 1.4289069118737352`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820609`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3141312908727424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 1, {
              Complex[4.524575324820609, -0.3141312908727424], 
              Complex[2.4899764222920586`, -1.7430382027464777`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6695946662994976`, 1.173612865799659}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370943`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 2, {
              Complex[7.189734993370943, 0.011841614202115798`], 
              Complex[5.520140327071445, -1.1617712515975434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.033957899526074, 1.4274616020562898`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5349083995992086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31133572520239783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7387973272586876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 1, {
              Complex[4.5349083995992086`, -0.31133572520239783`], 
              Complex[2.5009505000731345`, -1.7387973272586876`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6703226511956744`, 1.1737063045173515`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 2, {
              Complex[7.180825821018505, 0.012001139360437552`], 
              Complex[5.510503169822831, -1.161705165156914]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0333032766098706`, 1.4260197426156342`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30860262064445365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.734622363260088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 1, {
              Complex[4.545180291382208, -0.30860262064445365`], 
              Complex[2.5118770147723373`, -1.734622363260088]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6710548661987972`, 1.1738005216702665`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01216331767348526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 2, {
              Complex[7.171972430077164, 0.01216331767348526], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0326351696631, 1.42458135781889}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7305113980298925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 1, {
              Complex[4.555393477515928, -0.30593004021100256`], 
              Complex[2.522758307852828, -1.7305113980298925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6717913734721603`, 1.173895525355946}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 2, {
              Complex[7.163172144114485, 0.012328213838552468`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.031953707546602, 1.423146468751491}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5655503412120515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380606`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 1, {
              Complex[4.5655503412120515`, -0.3033161476291151], 
              Complex[2.5335966336654496`, -1.726462616380606]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6725322365542885`, 1.1739913237316546`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 2, {
              Complex[7.154422400706351, 0.012495894795164315`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.031259012275387, 1.4217150935100624`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.575653178335505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3007592009004852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 1, {
              Complex[4.575653178335505, -0.3007592009004852], 
              Complex[2.5443941660601173`, -1.7224742944105478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6732775204109578`, 1.1740879250130971`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627267`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 2, {
              Complex[7.145720742965965, 0.012666429816627267`], 
              Complex[5.4724432225550075`, -1.1614214951964696`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0305511991805147`, 1.4202872473824493`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 1, {
              Complex[4.585704203648775, -0.29825754641387064`], 
              Complex[2.55515300446826, -1.7185447937963199`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6740272914888925`, 1.1741853374728037`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 2, {
              Complex[7.137064811774601, 0.012839890606854677`], 
              Complex[5.463037520285708, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.029830377057215, 1.4188629430160065`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 1, {
              Complex[4.59570555656919, -0.2958096135553047], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6747816177712969`, 1.1742835694381695`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 2, {
              Complex[7.128452338640535, 0.013016351402742274`], 
              Complex[5.453670720869239, -1.161267218035427]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0290966482999746`, 1.41744219057514}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 1, {
              Complex[4.605659306489134, -0.2934139097675643], 
              Complex[2.5765626581891587`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6755405688353644`, 1.1743826292891215`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013195889082391348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 2, {
              Complex[7.119881139121319, 0.013195889082391348`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0283501090252565`, 1.416024997889011}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 1, {
              Complex[4.615567457703372, -0.29106901601605945`], 
              Complex[2.5872173486781156`, -1.7070940139050703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.676304215911888, 1.1744825254553937`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01337858327951254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 2, {
              Complex[7.111349106752032, 0.01337858327951254], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.027590849182422, 1.4146113705902192`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.625431953982773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 1, {
              Complex[4.625431953982773, -0.2887735826232166], 
              Complex[2.5978411048003505`, -1.7033849532134357`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6770726319471416`, 1.1745832664133713`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1028542074287175`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362847`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 2, {
              Complex[7.1028542074287175`, 0.013564516504362847`], 
              Complex[5.425781575481576, -1.1610187499090083`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0268189526533744`, 1.4132013122452383`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6084357301759398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6997276376830053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 1, {
              Complex[4.635254682829314, -0.28652632543776696`], 
              Complex[2.6084357301759398`, -1.6997276376830053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6778458916671681`, 1.174684860682482}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608692`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 2, {
              Complex[7.094394474201806, 0.013753774271608692`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0260344973413464`, 1.411794824477274}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6190029821022605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6961208467863325`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 1, {
              Complex[4.645037479443607, -0.2843260223090585], 
              Complex[2.6190029821022605`, -1.6961208467863325`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6786240716446452`, 1.1747873168210956`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01394644523553291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 2, {
              Complex[7.085968002439294, 0.01394644523553291], 
              Complex[5.407343930794649, -1.1608408715855627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.025237555249241, 1.4103919070822168`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 1, {
              Complex[4.654782130432772, -0.2821715098398556], 
              Complex[2.629544575183531, -1.6925634169220725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6794072503684923`, 1.1748906434218873`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0775729453237535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044105`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 2, {
              Complex[7.0775729453237535`, 0.014142621333044105`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.024428192547841, 1.4089925581382399`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.66449037728374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800616803939439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 1, {
              Complex[4.66449037728374, -0.2800616803939439], 
              Complex[2.640062184735899, -1.6890542385321838`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6801955083163929`, 1.1749948491066329`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981625`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 2, {
              Complex[7.069207509650975, 0.014342397934981625`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0236064696341645`, 1.4075967741096318`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6741639196244416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470893`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 1, {
              Complex[4.6741639196244416`, -0.2779954793374575], 
              Complex[2.6505574499902775`, -1.6855922534470893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6809889280304193`, 1.1750999425203748`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901383`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250833`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 2, {
              Complex[7.060869951901383, 0.014545874006250833`], 
              Complex[5.379881023870964, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.022772441180206, 1.4062045499453317`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 1, {
              Complex[4.683804418293251, -0.2759719024950629], 
              Complex[2.661031977113045, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6817875941959524`, 1.1752059323249155`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367323`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 2, {
              Complex[7.052558574558201, 0.014753152275367323`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0219261561722446`, 1.4048158791726855`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27398999380419337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 1, {
              Complex[4.693413498234964, -0.27398999380419337`], 
              Complex[2.6714873420627194`, -1.6788058729768789`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6825915937241023`, 1.1753128271915803`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 2, {
              Complex[7.044271722648962, 0.014964339414035003`], 
              Complex[5.36168012892486, -1.1603484877775454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0210676579408675`, 1.4034307539868354`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6819250932991716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6754795971390894`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 1, {
              Complex[4.702992751240039, -0.27204884315225386`], 
              Complex[2.6819250932991716`, -1.6754795971390894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6834010158378476`, 1.1754206357931767`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 2, {
              Complex[7.036007780489124, 0.015179546227436348`], 
              Complex[5.352606764651276, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.020196984181804, 1.402049165336192}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27014758438335257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 1, {
              Complex[4.712543738542191, -0.27014758438335257`], 
              Complex[2.692346754360387, -1.6721967497195445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6842159521621252`, 1.1755293667950935`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015398887855965332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 2, {
              Complex[7.027765168608571, 0.015398887855965332`], 
              Complex[5.343549216446446, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0193141669676415`, 1.400671103004369}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26828539346253194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669008`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 1, {
              Complex[4.722067993288218, -0.26828539346253194`], 
              Complex[2.702753826320576, -1.6689564964669008`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6850364968181137`, 1.1756390288454501`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198301`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.33450584402538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 2, {
              Complex[7.019542340843494, 0.015622483989198301`], 
              Complex[5.33450584402538, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.018419232750448, 1.39929655568899}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2664614867867361`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 1, {
              Complex[4.731567022892644, -0.2664614867867361], 
              Complex[2.713147790142196, -1.6657580424757261`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6858627465219698`, 1.1757496305642217`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959828`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 2, {
              Complex[7.011337781577717, 0.015850459092959828`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.01751220235528, 1.3979255110777091`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 1, {
              Complex[4.741042311288871, -0.26467511963294066`], 
              Complex[2.7235301089335913`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6866948006883018`, 1.1758611805312391`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0031500031188445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01608294265041594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 2, {
              Complex[7.0031500031188445`, 0.01608294265041594], 
              Complex[5.316455202430543, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0165930909645393`, 1.3965579559218206`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.750495321087509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 1, {
              Complex[4.750495321087509, -0.26292558473487154`], 
              Complex[2.7339022301229705`, -1.6594835406566921`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6875327615386626`, 1.1759736872729674`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159653617854765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 2, {
              Complex[6.994977543195845, 0.016320069418202385`], 
              Complex[5.307444781657182, -1.159653617854765]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0156619080930795`, 1.3951938761077975`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.759927495651799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 1, {
              Complex[4.759927495651799, -0.2612122109807511], 
              Complex[2.7442655875587194`, -1.6564060870885486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.688376734215398, 1.176087159247943}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565742`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 2, {
              Complex[6.986818962565742, 0.016561979698683844`], 
              Complex[5.2984422283503445`, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0147186575539395`, 1.393833256727107}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25953436222533105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.754621603545414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.653367618952438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 1, {
              Complex[4.769340261099353, -0.25953436222533105`], 
              Complex[2.754621603545414, -1.653367618952438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6892268269011668`, 1.176201604830757}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 2, {
              Complex[6.978672842717983, 0.01680881962953307], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.01376333741455, 1.3924760821446296`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.764971690824241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 1, {
              Complex[4.778735028238791, -0.2578914362102898], 
              Complex[2.764971690824241, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6900831509445093`, 1.1763170322944347`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919475`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2804546327214155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 2, {
              Complex[6.970537783665924, 0.017060741491919475`], 
              Complex[5.2804546327214155`, -1.159256290802515]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0127959399432025`, 1.3911223360660327`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2562828635878305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 1, {
              Complex[4.788113194449318, -0.2562828635878305], 
              Complex[2.775317254506115, -1.6474051996538635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6909458209918422`, 1.1764334497910687`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714277`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 2, {
              Complex[6.962412401815591, 0.017317904038714277`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0118164515455326`, 1.3897720016044286`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.797476145510829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652962`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647398`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 1, {
              Complex[4.797476145510829, -0.2547081070429693], 
              Complex[2.7856596939652962`, -1.644480108647398]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6918149551263002`, 1.1765508653305403`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237614`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 2, {
              Complex[6.954295327902444, 0.017580472844237614`], 
              Complex[5.262480372776144, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0108248526907553`, 1.3884250613466604`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.641591721857337`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 1, {
              Complex[4.806825257391718, -0.2531666605106765], 
              Complex[2.796000404700962, -1.641591721857337]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.692690675013859, 1.1766692867571427`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.9461852049875565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0178486206772136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.253494529973698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 2, {
              Complex[6.9461852049875565`, 0.0178486206772136], 
              Complex[5.253494529973698, -1.1588206660799292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0098211178273067`, 1.3870814974195784`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25165804848463746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 1, {
              Complex[4.8161618980011855`, -0.25165804848463746`], 
              Complex[2.8063407801738793`, -1.6387395459042158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6935731060572334`, 1.1767887217239028`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 2, {
              Complex[6.938080686504964, 0.018122527898744745`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.008805215287523, 1.3857412915566516`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25018182541497647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 1, {
              Complex[4.825487428912641, -0.25018182541497647`], 
              Complex[2.816682213625118, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6944623775580436`, 1.1769091776643836`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018402382887287818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 2, {
              Complex[6.929980434352448, 0.018402382887287818`], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0077771071809516`, 1.3844044251653096`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.8270260998834296`, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6953586228878208`, 1.1770306617617177`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018335`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 2, {
              Complex[6.921883117018335, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0067367492758064`, 1.3830708793953939`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8441105864437315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24732491072033733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 1, {
              Complex[4.8441105864437315`, -0.24732491072033733`], 
              Complex[2.8373738371679256`, -1.6303957901157313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6962619796684277`, 1.177153180914591}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 2, {
              Complex[6.913787407737206, 0.018980732522336757`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0056840908680553`, 1.381740635209144}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8534109197605035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 1, {
              Complex[4.8534109197605035`, -0.24594347356467763`], 
              Complex[2.847726828892448, -1.6276841087738216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6971725899625454`, 1.177276741699893}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259930976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 2, {
              Complex[6.90569198266763, 0.019279648259930976`], 
              Complex[5.208519392705085, -1.1579970934399622`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0046190746375654`, 1.3804136734531534`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 1, {
              Complex[4.862705560115598, -0.24459293369624502`], 
              Complex[2.858086485478033, -1.6250066071493985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.698090600474915, 1.17740135033167}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 2, {
              Complex[6.897595519085279, 0.01958535502317052], 
              Complex[5.199504918610364, -1.1578159953084994`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0035416364906435`, 1.3790899749327667`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931042018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.622362964243187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 1, {
              Complex[4.871995862670491, -0.24327298931042018`], 
              Complex[2.868454226179847, -1.622362964243187]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6990161627650706`, 1.1775270126160395`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157628923856052`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 2, {
              Complex[6.889496693584875, 0.019898088759987564`], 
              Complex[5.190480530819805, -1.157628923856052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.002451705388296, 1.377769520489428}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 1, {
              Complex[4.881283186323275, -0.24198336673385498`], 
              Complex[2.8788314809349784`, -1.6197528872232831`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.6999494334723733`, 1.1776537339016264`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815565`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 2, {
              Complex[6.881394180284588, 0.020218096688815565`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0013492031594042`, 1.3764522910815207`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 1, {
              Complex[4.8905688953969415`, -0.24072382041628837`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7008905745542187`, 1.1777815190250742`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 2, {
              Complex[6.873286649026525, 0.020545637985932896`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.000234044297979, 1.3751382678692912`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.899620317047638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6146324008788784`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 1, {
              Complex[4.899854361345617, -0.23949413300958722`], 
              Complex[2.899620317047638, -1.6146324008788784`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.701839753538335, 1.1779103722511175`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02088098452409496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270224`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 2, {
              Complex[6.865172763566979, 0.02088098452409496], 
              Complex[5.163333010028644, -1.1570293877270224`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9991061357435584`, 1.3738274323045092`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.909140964484508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9100348287409497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.612121547840818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 1, {
              Complex[4.909140964484508, -0.23829411553630872`], 
              Complex[2.9100348287409497`, -1.612121547840818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7027971437902243`, 1.1780402972066424`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02122442166697627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 2, {
              Complex[6.857051179750135, 0.02122442166697627], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9979653766437164`, 1.3725197662255608`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 1, {
              Complex[4.918430095749454, -0.23712360765068738`], 
              Complex[2.920464719105737, -1.6096433738762481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.703762924796807, 1.1781712968080984`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021576249124412635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1565950476836857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 2, {
              Complex[6.848920543658824, 0.021576249124412635`], 
              Complex[5.145157618862018, -1.1565950476836857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9968116580975759`, 1.371215251958764}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9309115003944672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6071977299543911`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 1, {
              Complex[4.927723158492043, -0.23598247799562727`], 
              Complex[2.9309115003944672`, -1.6071977299543911`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7047372824674956`, 1.178303373181557}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 2, {
              Complex[6.840779489735858, 0.021936781873947226`], 
              Complex[5.136042207268362, -1.1563665913076098`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9956448628790808`, 1.3699138724267474`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703164995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.234870624659986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.941376707437419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 1, {
              Complex[4.9370215703164995`, -0.234870624659986], 
              Complex[2.941376707437419, -1.6047844970867335`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7057204094539706`, 1.1784365275746111`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02230635115475651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 2, {
              Complex[6.832626638869334, 0.02230635115475651], 
              Complex[5.126906229415363, -1.1561301764198546`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.99446486513871, 1.3686156112648549`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23378797574121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060649`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 1, {
              Complex[4.946326764964685, -0.23378797574121], 
              Complex[2.9518618998259756`, -1.6024035870060649`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7067125054900778`, 1.1785707602592412`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684493`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 2, {
              Complex[6.824460596435172, 0.022685305540684493`], 
              Complex[5.117748090945094, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9932715300821544`, 1.3673204529466156`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 1, {
              Complex[4.955640194255799, -0.23273449001922958`], 
              Complex[2.9623686641736446`, -1.6000549429658453`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7077137777533633`, 1.1787060704246382`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8162799502898626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02307401209983014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 2, {
              Complex[6.8162799502898626`, 0.02307401209983014], 
              Complex[5.108566172536499, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9920647136243497`, 1.366028382919453}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.972898616463317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5977385406678666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 1, {
              Complex[4.9649633300876665`, -0.23171015774841358`], 
              Complex[2.972898616463317, -1.5977385406678666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7087244412499147`, 1.1788424560588717`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8080832687062705`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02347285764894477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0993588274563555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 2, {
              Complex[6.8080832687062705`, 0.02347285764894477], 
              Complex[5.0993588274563555`, -1.1553695984099268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9908442620171356`, 1.3647393877519403`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23071500157543234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5954543893273725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 1, {
              Complex[4.974297666506787, -0.23071500157543234`], 
              Complex[2.9834534044896506`, -1.5954543893273725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.709744719224307, 1.1789799138181525`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808084`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 2, {
              Complex[6.799869098244956, 0.023882250111808084`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9896100114486006`, 1.3634534552940505`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 1, {
              Complex[4.983644721854632, -0.2297490775919431], 
              Complex[2.9940347104060314`, -1.5932025328859936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.710774843596631, 1.179118438882264}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.791635961553228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 2, {
              Complex[6.791635961553228, 0.024302619991774015`], 
              Complex[5.080861117956596, -1.15481581889049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.988361787612036, 1.3621705748520432`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 1, {
              Complex[4.993006040998136, -0.22881247653229753`], 
              Complex[3.0046442533861, -1.5909830513843408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.711815055428736, 1.1792580247945887`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02473442196983401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 2, {
              Complex[6.783382355083753, 0.02473442196983401], 
              Complex[5.071567299655017, -1.1545236028247545`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.987099405242207, 1.360890737379825}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.002383197652629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22790532512782447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5887960625076496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 1, {
              Complex[5.002383197652629, -0.22790532512782447`], 
              Complex[3.0152837924104223`, -1.5887960625076496`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7128656054220353`, 1.1793986632849172`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 2, {
              Complex[6.775106746724163, 0.025178136640842865`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9858226676164232`, 1.3596139356888313`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.0259551291896347`, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.713926754449417, 1.1795403440730323`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 2, {
              Complex[6.766807573328626, 0.025634272402031203`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.984531366017681, 1.3583401646787814`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22618006752276337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 1, {
              Complex[5.021191477253694, -0.22618006752276337`], 
              Complex[3.036660111236013, -1.5845202322015448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7149987741240549`, 1.1796830546507573`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026103367509584394`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 2, {
              Complex[6.7584832381419595`, 0.026103367509584394`], 
              Complex[5.043484464017904, -1.153579687141173]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.983225279156869, 1.3570694215919181`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 1, {
              Complex[5.030625914253164, -0.22536240942454527`], 
              Complex[3.0474006350962957`, -1.5824318310164633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7160819474081488`, 1.1798267800398852`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 2, {
              Complex[6.750132108106198, 0.026585992320965892`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9819041725507414`, 1.3558017062937207`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 1, {
              Complex[5.040082822310154, -0.22457510122598123`], 
              Complex[3.058178649759413, -1.5803768075197018`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.717176569264937, 1.1799715025230375`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.741752511039166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027082751742796587`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 2, {
              Complex[6.741752511039166, 0.027082751742796587`], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9805677978520728`, 1.3545370215834653`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.578355498041264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 1, {
              Complex[5.049563958105736, -0.22381847645779854`], 
              Complex[3.0689961602536635`, -1.578355498041264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7182829473576118`, 1.1801172013441015`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 2, {
              Complex[6.733342732673844, 0.027594287906544415`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9792158921280323`, 1.3532753735384762`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2230929169293575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 1, {
              Complex[5.059071123576936, -0.2230929169293575], 
              Complex[3.0798552314489034`, -1.5763682904678338`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7194014027991138`, 1.1802638523744435`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028121283097053466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 2, {
              Complex[6.724901013546819, 0.028121283097053466`], 
              Complex[5.005499610747705, -1.1521425692773901`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9778481770824652`, 1.3520167718964253`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0686061691627415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563799`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 1, {
              Complex[5.0686061691627415`, -0.22239885565995443`], 
              Complex[3.0907579920802766`, -1.5744156275563799`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.720532270957173, 1.1804114277405415`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 2, {
              Complex[6.716425545723423, 0.02866446296210374], 
              Complex[4.9958932747662494`, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9764643582173367`, 1.3507612304806977`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2217367801348355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 1, {
              Complex[5.078170997228453, -0.2217367801348355], 
              Complex[3.1017066390111157`, -1.5724980106155333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7216759023193726`, 1.1805598954080911`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819224`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 2, {
              Complex[6.707914469346526, 0.029224600034819224`], 
              Complex[4.986238567027153, -1.1513352953732718`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9750641239281346`, 1.3495087676744777`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1127034417538186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 1, {
              Complex[5.087767565681953, -0.22110723592124717`], 
              Complex[3.1127034417538186`, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.722832663423437, 1.1807092187168904`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 2, {
              Complex[6.699365868995314, 0.02980251760487482], 
              Complex[4.976533205571878, -1.1509067011120155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.973647144527563, 1.3482594069501301`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 1, {
              Complex[5.097397891796026, -0.2205108306846833], 
              Complex[3.123750747268463, -1.5687702376348136`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7240029378584962`, 1.1808593558600218`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 2, {
              Complex[6.6907777698397455`, 0.030399093979211242`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9722130711912582`, 1.3470131774613308`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 1, {
              Complex[5.107064056251541, -0.21994823865092936`], 
              Complex[3.134850985060283, -1.5669614161122603`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7251871273435702`, 1.181010259299839}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 2, {
              Complex[6.682148133575791, 0.031015267178413856`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.970761534818717, 1.3457701147065713`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272423`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 1, {
              Complex[5.116768207416753, -0.21942020556585173`], 
              Complex[3.146006672598036, -1.565190320272423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.726385652890146, 1.1811618751121895`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126103`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196406`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1495098349909931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 2, {
              Complex[6.673474854126103, 0.031652040121196406`], 
              Complex[4.947089201235957, -1.1495098349909931`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9692921448019527`, 1.3445302612739587`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 1, {
              Complex[5.126512565878384, -0.21892755421211527`], 
              Complex[3.1572204210764316`, -1.563457815486074]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7275989560563358`, 1.181314142248961}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090323`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 2, {
              Complex[6.664755753090323, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9678044876937066`, 1.3432936676787464`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5617648582291666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 1, {
              Complex[5.1362994292403545`, -0.21847119055042008`], 
              Complex[3.168494941546648, -1.5617648582291666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7288275003008264`, 1.1814669917075291`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641234991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 2, {
              Complex[6.655988574929111, 0.03299175641234991], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9662981257662857`, 1.3420603933068522`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.14613117720593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 1, {
              Complex[5.14613117720593, -0.21805211056251347`], 
              Complex[3.179833051439645, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7300717724455676`, 1.181620345593879}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 2, {
              Complex[6.647170981866001, 0.03369708483581623], 
              Complex[4.917099209420433, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9647725954512942`, 1.3408305074796953`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2176714078844637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 1, {
              Complex[5.156010276958657, -0.2176714078844637], 
              Complex[3.191237681507363, -1.5585019153641588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7313322842569507`, 1.1817741160640707`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.638300548491651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 2, {
              Complex[6.638300548491651, 0.03442779801852966], 
              Complex[4.906968264234701, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9632274056496855`, 1.3396040906581876`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21733028233169835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989886`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 1, {
              Complex[5.1659392888565, -0.21733028233169835`], 
              Complex[3.2027118832068147`, -1.556934372989886]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7326095741560767`, 1.1819282041262436`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.035185322904060665`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146742881222183`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 2, {
              Complex[6.629374756056008, 0.035185322904060665`], 
              Complex[4.896765181899932, -1.146742881222183]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9616620359006434`, 1.3383812358066198`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5554112852390445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 1, {
              Complex[5.175920872451979, -0.21703004943242468`], 
              Complex[3.214258836551336, -1.5554112852390445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.733904209069626, 1.1820824982824254`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 2, {
              Complex[6.620390986435504, 0.03597119669747853], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9600759343969185`, 1.337162049940636}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1859577928485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21677215110365722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 1, {
              Complex[5.1859577928485665`, -0.21677215110365722`], 
              Complex[3.225881858451648, -1.5539342010442931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7352167864337187`, 1.1822368729859642`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 2, {
              Complex[6.611346515764966, 0.03678707771053728], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9584685158333004`, 1.3359466558875903`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512189`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 1, {
              Complex[5.196052927399867, -0.21655816762459867`], 
              Complex[3.237584411566566, -1.552504823512189]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7365479363641099`, 1.182391186886311}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 2, {
              Complex[6.60223850772765, 0.037634757497710856`], 
              Complex[4.86569057136354, -1.1447564293886001`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9568391590740133`, 1.3347351942924115`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21638983108607518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 1, {
              Complex[5.206209272752709, -0.21638983108607518`], 
              Complex[3.249370113678695, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7378983240069454`, 1.1825452808280361`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502224`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077786`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8551656824952785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 2, {
              Complex[6.593064006502224, 0.038516174462077786`], 
              Complex[4.8551656824952785`, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9551872046240333`, 1.3335278259078815`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549796866430609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 1, {
              Complex[5.216429952227796, -0.21626904052272736`], 
              Complex[3.261242747603762, -1.549796866430609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7392686520850986`, 1.1826989755651816`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.583819929372991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271393`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 2, {
              Complex[6.583819929372991, 0.03943342913804211], 
              Complex[4.844551277287892, -1.1432655464271393`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.953511951888622, 1.3323247342150961`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21619787896744078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 1, {
              Complex[5.226718223521198, -0.21619787896744078`], 
              Complex[3.273206271632576, -1.5485226131825367`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.74065966365581, 1.1828520691451985`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04038880139063545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 2, {
              Complex[6.574503059020016, 0.04038880139063545], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.951812656204979, 1.3311261284280658`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 1, {
              Complex[5.237077486695946, -0.21617863270584675`], 
              Complex[3.2852648304909673`, -1.5473047611339124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7420721450957446`, 1.1830043339085197`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 2, {
              Complex[6.565110035519868, 0.04138476980950465], 
              Complex[4.823037890424123, -1.141619564099015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9500885256298572`, 1.3299322469462351`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 1, {
              Complex[5.247511292414013, -0.21621381305374002`], 
              Complex[3.2974227667841562`, -1.546146059999975]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7435069293296361`, 1.1831555130399942`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.55563734810662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8121304187769836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.140731479419345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 2, {
              Complex[6.55563734810662, 0.04242403362064897], 
              Complex[4.8121304187769836`, -1.140731479419345]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9483387174675437`, 1.3287433613304185`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.309684632866044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5450495423633648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 1, {
              Complex[5.258023350333588, -0.21630618103294622`], 
              Complex[3.309684632866044, -1.5450495423633648`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7449648993181337`, 1.1833053165967153`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.043509537491681925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 2, {
              Complex[6.546081326768185, 0.043509537491681925`], 
              Complex[4.801116427450051, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9465623345239813`, 1.3275597808917121`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2164587753829211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 1, {
              Complex[5.268617537562702, -0.2164587753829211], 
              Complex[3.3220552030387207`, -1.5440185562746334`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7464469918190846`, 1.1834534169226614`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.789991141967791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 2, {
              Complex[6.536438133786875, 0.04464449966811471], 
              Complex[4.789991141967791, -1.1388089172545466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.944758421075448, 1.3263818579998654`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 1, {
              Complex[5.279297907015237, -0.21667494441768237`], 
              Complex[3.3345394859397888`, -1.5430568024175477`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.747954201433849, 1.1835994433436996`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378125`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04583244395046667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 2, {
              Complex[6.526703755378125, 0.04583244395046667], 
              Complex[4.778749553944276, -1.1377669993932331`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.94292595854457, 1.3252099942378486`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.290068695455681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2169583823220915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 1, {
              Complex[5.290068695455681, -0.2169583823220915], 
              Complex[3.347142736911111, -1.54216837655994]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7494875849458988`, 1.1837429760162155`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106414795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399098006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 2, {
              Complex[6.516873993640986, 0.047077236106414795`], 
              Complex[4.767386408695087, -1.1366657399098006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9410638608832722`, 1.3240446475537695`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 1, {
              Complex[5.300934330939945, -0.21731317057992391`], 
              Complex[3.359870470056673, -1.5413578181336933`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.75104826595208, 1.1838835387782198`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410604036`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 2, {
              Complex[6.50694445911303, 0.048383125410604036`], 
              Complex[4.75589619316095, -1.1355004133676156`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9391709696726003`, 1.3228863405905456`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 1, {
              Complex[5.311899439255095, -0.21774382534019782`], 
              Complex[3.3727284695824946`, -1.5406301659307433`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.752637439776657, 1.1840205908225483`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037839`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 2, {
              Complex[6.496910564326775, 0.04975479211876465], 
              Complex[4.744273124550118, -1.1342657987037839`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9372460489644316`, 1.3217356704088936`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.218255351659741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 1, {
              Complex[5.322968848822687, -0.218255351659741], 
              Complex[3.385722799858256, -1.5399910220686348`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.754256378643084, 1.1841535169765731`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902967`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05119740181429564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 2, {
              Complex[6.486767518902967, 0.05119740181429564], 
              Complex[4.732511140259883, -1.1329561151622776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9352877799119728`, 1.3205933198612425`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3988598134359265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 1, {
              Complex[5.334147593347899, -0.21885330570991685`], 
              Complex[3.3988598134359265`, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7559064370566704`, 1.1842816163308607`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 2, {
              Complex[6.476510326898408, 0.05271666771536851], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.933294755267062, 1.319460070924297}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2195438662043099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.412146155988547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 1, {
              Complex[5.34544091125561, -0.2195438662043099], 
              Complex[3.412146155988547, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.757589057320077, 1.1844040889090253`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054318922199527095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1300851667094982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 2, {
              Complex[6.466133787367247, 0.054318922199527095`], 
              Complex[4.70854473004717, -1.1300851667094982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9312654738663142`, 1.3183368203574153`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22033391649033324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 1, {
              Complex[5.356854240636268, -0.22033391649033324`], 
              Complex[3.4255887667699536`, -1.5386707368477486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7593057750596772`, 1.184520020011641}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.455632499412816`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 2, {
              Complex[6.455632499412816, 0.05601119898888057], 
              Complex[4.696326724353138, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9291983352898512`, 1.317224598123756}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.368393208004248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.221231138946749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 1, {
              Complex[5.368393208004248, -0.221231138946749], 
              Complex[3.4391948727143964`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7610582245789832`, 1.184628361797253}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.057801327638013704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 2, {
              Complex[6.445000873427293, 0.057801327638013704`], 
              Complex[4.683942648848311, -1.1268270341592395`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9270916349625453`, 1.3161245890920883`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 1, {
              Complex[5.380063608617472, -0.22224412353114423`], 
              Complex[3.4529719736549263`, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7628481437692793`, 1.1847279115826053`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168787976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 2, {
              Complex[6.434233150770422, 0.059698042168787976`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9249435600872449`, 1.3150381586291189`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.3918713753777405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 1, {
              Complex[5.3918713753777405`, -0.22338249250843528`], 
              Complex[3.4669278152904957`, -1.5384206511375542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7646773781879659`, 1.1848172862522282`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 2, {
              Complex[6.423323434867787, 0.06171110588324154], 
              Complex[4.658646056679822, -1.1231061803689866`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.92275218696475, 1.313966882793611}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22465704353173413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 1, {
              Complex[5.403822532373675, -0.22465704353173413`], 
              Complex[3.4810703454089245`, -1.5386239263253452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.766547883749865, 1.1848948920661322`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.41226573766677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6457178539169055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.121043437540103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 2, {
              Complex[6.41226573766677, 0.06385145452602912], 
              Complex[4.6457178539169055`, -1.121043437540103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9205154804826614`, 1.3129125839498217`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4159231278759306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2260799132874317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.495407647393269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5389924972372535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 1, {
              Complex[5.4159231278759306`, -0.2260799132874317], 
              Complex[3.495407647393269, -1.5389924972372535`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7684617272493757`, 1.184958889048066}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0661313600083585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397076`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 2, {
              Complex[6.401054046640448, 0.0661313600083585], 
              Complex[4.6325923193910725`, -1.1188275290397076`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9182312968661799`, 1.3118773727195492`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4281791399671135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.227664763771187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 1, {
              Complex[5.4281791399671135`, -0.227664763771187], 
              Complex[3.509947843100934, -1.5395421364907362`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7704210836204077`, 1.1850071490350698`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157072`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 2, {
              Complex[6.389682419157072, 0.06856461676025134], 
              Complex[4.619261335536664, -1.1164425322748186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.915897391206329, 1.3108636972714853`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 1, {
              Complex[5.440596345893877, -0.22942699279424592`], 
              Complex[3.524698954687548, -1.5402906900657312`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7724282284186332`, 1.1850372063896215`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127534`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113870454078992`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 2, {
              Complex[6.378145113127534, 0.07116675231062954], 
              Complex[4.605716884708901, -1.113870454078992]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9135114318493907`, 1.3098744009724408`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5412583702907798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 1, {
              Complex[5.453180143569078, -0.23138396931833902`], 
              Complex[3.539668711719688, -1.5412583702907798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7744855234422623`, 1.1850462003498168`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.366436765503008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 2, {
              Complex[6.366436765503008, 0.07395526269357332], 
              Complex[4.591951242060746, -1.1110909376562434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9110710244861582`, 1.308912789344596}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5548642858592667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 1, {
              Complex[5.465935310345425, -0.23355529236003078`], 
              Complex[3.5548642858592667`, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7765953926527582`, 1.1850308080734386`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 2, {
              Complex[6.354552633501295, 0.07694987142173926], 
              Complex[4.577957240848536, -1.1080809366516993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9085737497634265`, 1.3079827070004018`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901322983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 1, {
              Complex[5.478865680202782, -0.23596306901322983`], 
              Complex[3.5702919304393554`, -1.5439457760136317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7787602845730826`, 1.1849871677042878`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.34248891741965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 2, {
              Complex[6.34248891741965, 0.08017280757570203], 
              Complex[4.563728632846567, -1.1048143601285858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.906017219487533, 1.30708862462704}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.585956496459983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 1, {
              Complex[5.491973715947516, -0.23863220192231419`], 
              Complex[3.585956496459983, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7809826160936353`, 1.1849107913888706`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 2, {
              Complex[6.330243188435803, 0.08364909334179291], 
              Complex[4.549260572342168, -1.1012616980470775`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.903399158005103, 1.3062357349604112`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.547826403307315`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 1, {
              Complex[5.5052599482994165`, -0.2415906683469038], 
              Complex[3.601860790294313, -1.547826403307315]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7832646911007954`, 1.1847964693034876`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 2, {
              Complex[6.317814949521484, 0.08740682313953863], 
              Complex[4.534550258420689, -1.097389646163949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9007175170608452`, 1.3054300547279403`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.51872224974151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 1, {
              Complex[5.51872224974151, -0.24486976056502419`], 
              Complex[3.6180047326806646`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7856085856281567`, 1.1846381677124258`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.305206361593249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408550006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 2, {
              Complex[6.305206361593249, 0.09147740408550006], 
              Complex[4.519597775965091, -1.0931607636269256`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8979706341286053`, 1.3046785263493108`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5323549095256235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.248504239352635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 1, {
              Complex[5.5323549095256235`, -0.248504239352635], 
              Complex[3.6343842753970184`, -1.5531827657019457`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7880159895343162`, 1.1844289272681492`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.095895709531589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 2, {
              Complex[6.292423168507695, 0.095895709531589], 
              Complex[4.50440717897338, -1.0885332177365603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.895157445398303, 1.303989108280956}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2525323274039474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 1, {
              Complex[5.546147480479421, -0.2525323274039474], 
              Complex[3.650990035081118, -1.5565214356849035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7904879935245648`, 1.1841607726676704`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255288`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4889878567307235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0834607001253282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 2, {
              Complex[6.279475850255288, 0.10070007254234209`], 
              Complex[4.4889878567307235`, -1.0834607001253282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8922777643342912`, 1.3033708358129306`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.56008338350221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 1, {
              Complex[5.56008338350221, -0.2569954375693104], 
              Complex[3.667805619167919, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.793024810600948, 1.1838246518564723`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 2, {
              Complex[6.266381018465573, 0.10593201418800287`], 
              Complex[4.473356207864625, -1.0778926376684697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.889332633398853, 1.3028338247141253`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5647713188313284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 1, {
              Complex[5.5741382895514295`, -0.26193749411720313`], 
              Complex[3.6848056561525766`, -1.5647713188313284`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7956254243469978`, 1.1834104323840273`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344217985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1116355648600116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 2, {
              Complex[6.2531630344217985`, 0.1116355648600116], 
              Complex[4.457537610074802, -1.0717748675240155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8863247477834821`, 1.3023891790741564`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.588278361042629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26740367180599306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 1, {
              Complex[5.588278361042629, -0.26740367180599306`], 
              Complex[3.7019536132591475`, -1.5697928508801495`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.7982871652044896`, 1.1829069935625791`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239855767662159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 2, {
              Complex[6.239855767662159, 0.11785600339463097`], 
              Complex[4.44156860245767, -1.0650509901679481`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8832589329223757`, 1.302048754496306}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 1, {
              Complex[5.602458533258957, -0.27343836455892495`], 
              Complex[3.719199600336582, -1.5754871190552309`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.801005232967805, 1.1823024632748211`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.057664637476592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 2, {
              Complex[6.226504314571602, 0.12463782579822917`], 
              Complex[4.425499081603797, -1.057664637476592]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8801426299248631`, 1.3018247238590068`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 1, {
              Complex[5.616621151226329, -0.2800822323034728], 
              Complex[3.736478521301465, -1.5819069561624797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.803772211359162, 1.1815846522129752`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 2, {
              Complex[6.213166361508075, 0.13202179213539886`], 
              Complex[4.409394150148914, -1.0495628600775764`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.876986305859085, 1.301728904048973}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28736829986212964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 1, {
              Complex[5.6306954263332605`, -0.28736829986212964`], 
              Complex[3.7537091204741757`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8065776577524506`, 1.1807417271461689`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.140041025467066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 2, {
              Complex[6.199912728184148, 0.140041025467066], 
              Complex[4.393335070431697, -1.040700701679103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8738036673335818`, 1.301771838931523}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 1, {
              Complex[5.644598280659571, -0.29531732776612085`], 
              Complex[3.770794613325989, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8094078895989492`, 1.1797631279505794`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740917, -1.0310467452404808`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8706115349187489`, 1.3019617023151093`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.658237106888954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 1, {
              Complex[5.658237106888954, -0.3039330313949995], 
              Complex[3.787625571970205, -1.6058947337101088`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8122461100130416`, 1.1786406646453118`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.174000384831828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 2, {
              Complex[6.174000384831828, 0.15805167382144333`], 
              Complex[4.361754274818786, -1.0205889908238686`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.867429259357157, 1.3023031753120258`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3131980951405518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 1, {
              Complex[5.671514683640783, -0.3131980951405518], 
              Complex[3.8040854242836257`, -1.6155012704525775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8150729915688857`, 1.1773696400320683`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 2, {
              Complex[6.161531564303005, 0.16802967600526267`], 
              Complex[4.34645857273412, -1.0093399640268057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8642776483570964`, 1.302796531610956}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669845`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 1, {
              Complex[5.684335924466963, -0.3230721172560285], 
              Complex[3.8200582761098665`, -1.6258686488669845`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.817867749513718, 1.175949764422923}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17861007860412006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 2, {
              Complex[6.1495151781876825`, 0.17861007860412006`], 
              Complex[4.331647428673965, -0.9973396858188028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8611775149855865`, 1.3034371807829284`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 1, {
              Complex[5.696615451432763, -0.3334924140604973], 
              Complex[3.8354379364471765`, -1.6369295948434255`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8206095933815205`, 1.1743856123346508`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 2, {
              Complex[6.138036634132393, 0.18973028734408134`], 
              Complex[4.317427040750873, -0.9846553249905693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8581481015622268`, 1.304215836628012}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490953016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 1, {
              Complex[5.708284492538861, -0.34437794490953016`], 
              Complex[3.850136390976634, -1.6485937815375424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8232793031057126`, 1.172686454142283}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934494968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 2, {
              Complex[6.127164733575719, 0.20130934934494968`], 
              Complex[4.3038854304700065`, -0.9713771047973333]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.855205700432553, 1.3051193096596598`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563571212946327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 1, {
              Complex[5.719295626734264, -0.35563571212946327`], 
              Complex[3.8640899263017108`, -1.6607550217891232`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8258606082521933`, 1.17086546359497}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 2, {
              Complex[6.1169469267372625`, 0.21325435309295837`], 
              Complex[4.291086318485069, -0.9576111105020118]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8523627394815882`, 1.306131743395168}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.877261765238287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6733000146368138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 1, {
              Complex[5.729624504719875, -0.3671682712416456], 
              Complex[3.877261765238287, -1.6733000146368138`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8283411025120313`, 1.168938481525694}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591816001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.225467938702334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303969`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233601`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 2, {
              Complex[6.107407591816001, 0.225467938702334], 
              Complex[4.279066489303969, -0.9434705428233601]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.849627450157335, 1.3072360096435216`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378880805741801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 1, {
              Complex[5.7392685732062425`, -0.378880805741801], 
              Complex[3.889641123048907, -1.6861168153853228`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8307125756840936`, 1.1669226205635672`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23785537273090274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 2, {
              Complex[6.098549310734496, 0.23785537273090274`], 
              Complex[4.267836735050403, -0.9290672478326645]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.847004067294452, 1.3084149874652113`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 1, {
              Complex[5.748243586852647, -0.3906866010723898], 
              Complex[3.901239519558195, -1.6991015885376013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8329708138573517`, 1.1648349861741167`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 2, {
              Complex[6.0903563572018244`, 0.25033002218771333`], 
              Complex[4.257385543344473, -0.9145049639864032]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8444933974864997`, 1.3096525459021722`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.756579019389742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.712162962685892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 1, {
              Complex[5.756579019389742, -0.40251041678372], 
              Complex[3.912085621903242, -1.712162962685892]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.835115031044475, 1.1626916939294247`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.082799285592932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 2, {
              Complex[6.082799285592932, 0.26281672672835515`], 
              Complex[4.247684254548457, -0.8998749672010695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8420935629077408`, 1.3109341697391192`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 1, {
              Complex[5.7643133844056464`, -0.4142898642644484], 
              Complex[3.9222198214979054`, -1.7252240340035676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8371471253657647`, 1.1605072437468391`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 2, {
              Complex[6.075839610164614, 0.27525317641875735`], 
              Complex[4.238692484798849, -0.8852540673280818]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8398007606786424`, 1.312247259743397}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4259752554682592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 1, {
              Complex[5.771490138844716, -0.4259752554682592], 
              Complex[3.931689378166073, -1.7382225152116562`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8390709196892485`, 1.1582942196491404`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 2, {
              Complex[6.069433901558818, 0.2875897604942177], 
              Complex[4.230362981869569, -0.8707044591549227]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8376099369809935`, 1.3135811856180988`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 1, {
              Complex[5.778154476287737, -0.43752848511674636`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8408914875210336`, 1.1560632368114137`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524539`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562747872176812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 2, {
              Complex[6.063536993524539, 0.2997884495937324], 
              Complex[4.222645506003506, -0.8562747872176812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8355153308396206`, 1.3149271784298573`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 1, {
              Complex[5.784351043372478, -0.44892143644815663`], 
              Complex[3.948835712532857, -1.763848614878014]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8426146092289641`, 1.1538230491332264`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.05810426649939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3118212015393396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 2, {
              Complex[6.05810426649939, 0.3118212015393396], 
              Complex[4.2154896572704255`, -0.8420018475938867]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8335108815298558`, 1.316278136034257}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.956611577877951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 1, {
              Complex[5.790122459407806, -0.4601342612759227], 
              Complex[3.956611577877951, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8442463646403897`, 1.1515807438131522`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 2, {
              Complex[6.053093127997608, 0.32366824142440037`], 
              Complex[4.208846763357218, -0.8279125023887518]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8315905149437544`, 1.3176283944102225`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 1, {
              Complex[5.795508462127412, -0.4711537472500254], 
              Complex[3.963917947183657, -1.7887821416602478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8457928466810891`, 1.1493419700143042`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 2, {
              Complex[6.048463866858472, 0.3353164289039024], 
              Complex[4.202671020177383, -0.8140255411104017]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8297483324982398`, 1.318973498312344}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.800945377085382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 1, {
              Complex[5.800545503681593, -0.4819718787730382], 
              Complex[3.9707971711833534`, -1.800945377085382]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8472599724721497`, 1.1471111682119022`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.346757819138651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 2, {
              Complex[6.044180057256696, 0.346757819138651], 
              Complex[4.196920084784546, -0.8003533490732513]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8279787266448715`, 1.320309989635653}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014506`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 1, {
              Complex[5.805266648945753, -0.49258462786579765`], 
              Complex[3.9772879223008815`, -1.8128946175014506`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.848653367825116, 1.1448917818283741`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 2, {
              Complex[6.04020866039606, 0.3579884536883505], 
              Complex[4.1915552925709445`, -0.7869033281400235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.82627644385129, 1.3216352217365332`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341316`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 1, {
              Complex[5.809701663341316, -0.5029909709021095], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8499783042653686`, 1.142686442912301}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 2, {
              Complex[6.036519936690694, 0.36900737727295563`], 
              Complex[4.1865416324253255`, -0.7736790656393453]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.824636611594667, 1.3229472017720547`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8361393091196956`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 1, {
              Complex[5.81387720976465, -0.5131921073476409], 
              Complex[3.989240598169983, -1.8361393091196956`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.851239672043382, 1.1404971297989088`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.37981585653752803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 2, {
              Complex[6.033087248838311, 0.37981585653752803`], 
              Complex[4.1818475767949295`, -0.7606812732613808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.823054741730652, 1.324244459741766}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 1, {
              Complex[5.817817100281683, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8524419767704008`, 1.1383252980681058`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781002`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 2, {
              Complex[6.029886810127787, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781002]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8215267190986917`, 1.325525941331971}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.82154256758942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 1, {
              Complex[5.82154256758942, -0.5329911517598145], 
              Complex[4.000015848490729, -1.8585170930917858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.853589350817641, 1.1361719876999965`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8200487815068902`, 1.3267909211366746`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.825072534840901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 1, {
              Complex[5.825072534840901, -0.5425977517885691], 
              Complex[4.005023753334011, -1.8693886729252436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8546855733358563`, 1.1340379098537243`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.411012757878331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 2, {
              Complex[6.024100159124148, 0.411012757878331], 
              Complex[4.169414585788292, -0.7230251519753932]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8186174952323482`, 1.3280389328750908`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.828423871596708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 1, {
              Complex[5.828423871596708, -0.5520158986267109], 
              Complex[4.009806376364359, -1.8800548315018015`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8557340947593362`, 1.1319235166497295`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023488`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 2, {
              Complex[6.021478203650237, 0.4210179459473805], 
              Complex[4.165744108890901, -0.7109055707023488]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8172297287406878`, 1.3292697135446339`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 1, {
              Complex[5.831611629629778, -0.5612511491377987], 
              Complex[4.01438190088909, -1.8905208626824326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8567380630906272`, 1.1298290570165097`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 2, {
              Complex[6.019016519204634, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8158826263327796`, 1.3304831588689656`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8346492560547185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 1, {
              Complex[5.8346492560547185`, -0.5703092165540392], 
              Complex[4.018766629721938, -1.9007923754230047`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8577003502579712`, 1.1277546212423148`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44047065160543597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.687283969636879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 2, {
              Complex[6.016701682863842, 0.44047065160543597`], 
              Complex[4.159001332605871, -0.687283969636879]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8145735827492684`, 1.3316792878312391`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 1, {
              Complex[5.837548783508502, -0.5791958590266284], 
              Complex[4.022975200759233, -1.9108751468578675`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.85862357751485, 1.1257001764416252`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937821`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 2, {
              Complex[6.014521685955785, 0.4499297609478431], 
              Complex[4.155898108440934, -0.6757704154937821]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.813300219311786, 1.3328582144788308`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 1, {
              Complex[5.840320998393065, -0.5879167986060265], 
              Complex[4.027020779081279, -1.9207750130848573`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.859510139302769, 1.123665594750138}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 2, {
              Complex[6.012465765819384, 0.4592184279956057], 
              Complex[4.152955626516614, -0.6644471667545322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8120603618847302`, 1.3340201255300457`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 1, {
              Complex[5.842975588855197, -0.5964776632911527], 
              Complex[4.030915226970467, -1.9304977888211983`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8603622252933896`, 1.121650675717754}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.46834233848697243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 2, {
              Complex[6.010524257826823, 0.46834233848697243`], 
              Complex[4.150162032533434, -0.6533083372307816]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8108520207536023`, 1.335165262602281}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.940049209103389`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 1, {
              Complex[5.8455212744613, -0.6048839465011079], 
              Complex[4.034669253707697, -1.940049209103389]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8611818405140266`, 1.119655164080114}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 2, {
              Complex[6.008688465710948, 0.47730704263853463`], 
              Complex[4.147506625196923, -0.6423481214415793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8096733724001268`, 1.3362939081184422`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.847965919578021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 1, {
              Complex[5.847965919578021, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721932`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.861970823576281, 1.117678763851855}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086172]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8085227430865154`, 1.337406374140596}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 1, {
              Complex[5.850316632393394, -0.6212539145605388], 
              Complex[4.041793889306879, -1.9586602887011346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.86273086309546, 1.115721149492628}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.00530341993248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49478020058417976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084482`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 2, {
              Complex[6.00530341993248, 0.49478020058417976`], 
              Complex[4.142572556837021, -0.6209409489084482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.807398594124686, 1.338502993533955}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 1, {
              Complex[5.852579851369117, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8634635124249723`, 1.1137819747427735`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597039`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 2, {
              Complex[6.003740665139239, 0.5032988771597039], 
              Complex[4.140277152714267, -0.6104830975830695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8062995086897997`, 1.3395841129871582`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.976651255485492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.976651255485492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8641702028463107`, 1.1118608796026903`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.600182101786388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 2, {
              Complex[6.0022564620129675`, 0.5116787778163024], 
              Complex[4.1380862591666565`, -0.600182101786388]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8052241800336288`, 1.340650087512352}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 1, {
              Complex[5.856866656504023, -0.6447767740762026], 
              Complex[4.051642476470394, -1.9854268615885544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.86485225535917, 1.109957495832397}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0008455167911645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431994`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 2, {
              Complex[6.0008455167911645`, 0.5199245263444042], 
              Complex[4.135993261431994, -0.5900329694879929]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8041714009569616`, 1.3417012761259104`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.858900404144714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 1, {
              Complex[5.858900404144714, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8655108912124228`, 1.108071451270443}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 2, {
              Complex[5.999503006012947, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8031400544083183`, 1.3427380384718102`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 1, {
              Complex[5.860867089220407, -0.6598239647344448], 
              Complex[4.057727034812089, -2.002562003206255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8661472413087499`, 1.106202373210167}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 2, {
              Complex[5.998224525941573, 0.5360310932164655], 
              Complex[4.132077284632823, -0.5701712799937015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8021291050864379`, 1.343760732198116}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.010930447408191`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 1, {
              Complex[5.862770761740872, -0.6671697152100748], 
              Complex[4.060641656654434, -2.010930447408191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8667623546054082`, 1.1043498910228218`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 2, {
              Complex[5.99700604818503, 0.5439002036016085], 
              Complex[4.130243693579621, -0.5604496874212131]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.801137591935122, 1.34476971093542}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864615135176838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 1, {
              Complex[5.864615135176838, -0.6744020624307273], 
              Complex[4.063477543241716, -2.019171773366147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8673572056225929`, 1.1025136381787526`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.550861880464071`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 2, {
              Complex[5.995843880689526, 0.5516517577146817], 
              Complex[4.128486675066933, -0.550861880464071]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.800164621430121, 1.3457653227564705`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.866403620807269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0662389993771475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 1, {
              Complex[5.866403620807269, -0.6815246607732992], 
              Complex[4.0662389993771475`, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8679327011596933`, 1.100693253787374}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.559289458304851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825229`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 2, {
              Complex[5.994734633394265, 0.559289458304851], 
              Complex[4.126801932234572, -0.5414037954825229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7992093615684013`, 1.346747909020392}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.035288909793964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 1, {
              Complex[5.868139358018381, -0.6885410007735722], 
              Complex[4.06892999644998, -2.035288909793964]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8684896863091012`, 1.0988883837525503`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 2, {
              Complex[5.993675187934444, 0.5668168435275395], 
              Complex[4.125185501625342, -0.5320715402250109]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.79827103648009, 1.3477178035240853`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 1, {
              Complex[5.869825241082359, -0.6954544165180522], 
              Complex[4.071554204602269, -2.0431722200421376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8690289498472885`, 1.097098681620791}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697339`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 2, {
              Complex[5.992662670864551, 0.5742372943510572], 
              Complex[4.123633721017262, -0.5228613872697339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7973489215924694`, 1.3486753318987117`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0741150212777635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.050943424924778`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 1, {
              Complex[5.871463942870232, -0.7022680930260665], 
              Complex[4.0741150212777635`, -2.050943424924778]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8695512290737692`, 1.095323809184357}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 2, {
              Complex[5.991694429947489, 0.5815540419531245], 
              Complex[4.12214320087372, -0.5137697672312324]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7964423392836244`, 1.3496208112013484`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 1, {
              Complex[5.87305793589056, -0.7089850735194754], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.870057214160367, 1.093563436889187}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9907680131178696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845041`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 2, {
              Complex[5.9907680131178696`, 0.5887701750046829], 
              Complex[4.120710798957503, -0.5047932618845041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7955506549706537`, 1.3505545496616918`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.066162816169295`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 1, {
              Complex[5.874609510991549, -0.7156082665076033], 
              Complex[4.079058856020895, -2.066162816169295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.870547552065842, 1.0918172440877816`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989881149781852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11933359771601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4959285973192018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 2, {
              Complex[5.989881149781852, 0.5958886467685798], 
              Complex[4.11933359771601, -0.4959285973192018]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7946732735839293`, 1.3514768465514693`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 1, {
              Complex[5.876120794018038, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8710228500644306`, 1.090084919169364}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98903173416212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.60291228196345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11800888409769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 2, {
              Complex[5.98903173416212, 0.60291228196345], 
              Complex[4.11800888409769, -0.4871726372059141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7938096363846086`, 1.352387992150532}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8714836789310776`, 1.088366159593359}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9882178104361135`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.609843783360462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232897`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 2, {
              Complex[5.9882178104361135`, 0.609843783360462], 
              Complex[4.116734131505035, -0.478522376232897]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7929592180877234`, 1.353288267788619}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 1, {
              Complex[5.879030249816932, -0.7349423268176082], 
              Complex[4.086071031729209, -2.088230594606227]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8719305758210323`, 1.0866606718472054`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.46997493375384125`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 2, {
              Complex[5.987437559449537, 0.616685738093364], 
              Complex[4.115506983628505, -0.46997493375384125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7921215242576265`, 1.3541779459458636`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 1, {
              Complex[5.880431975347878, -0.7412169946624548], 
              Complex[4.088310451090251, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8723640468770468`, 1.0849681713454111`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 2, {
              Complex[5.986689286816269, 0.6234406236721283], 
              Complex[4.114325239939221, -0.46152754767328275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7912960889465013`, 1.3550572903983809`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0905044479565715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1024679173410115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 1, {
              Complex[5.881800536903073, -0.7474106269426304], 
              Complex[4.0905044479565715`, -2.1024679173410115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8727845695934517`, 1.0832883822835295`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9859714122405725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613645`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 2, {
              Complex[5.9859714122405725`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.45317756858613645`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.790482472550071, 1.3559265563979426`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8831374294478636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 1, {
              Complex[5.8831374294478636`, -0.7535254579157133], 
              Complex[4.092654956897793, -2.109452014313656]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8731925949629857`, 1.081621037458049}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 2, {
              Complex[5.985282459919064, 0.6366985832782693], 
              Complex[4.112089864956078, -0.4449224541797797]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.789680259857706, 1.3567859908768642`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.759563629082976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 1, {
              Complex[5.884444051922338, -0.759563629082976], 
              Complex[4.094763792064631, -2.1163496199598404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8735885494291913`, 1.0799658780610615`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898126`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6432061141597182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 2, {
              Complex[5.984621049898126, 0.6432061141597182], 
              Complex[4.1110325004689345`, -0.4367597639013433]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7888890582766885`, 1.3576358326709914`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 1, {
              Complex[5.885721715038686, -0.7655271940238011], 
              Complex[4.096832656761998, -2.1231630266947925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8739728366645874`, 1.0783226534568342`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 2, {
              Complex[5.983985890278379, 0.6496354995683529], 
              Complex[4.110013053613791, -0.4286871538884813]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7881084962128069`, 1.3584763127550672`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.771418122959341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 1, {
              Complex[5.886971648326271, -0.771418122959341], 
              Complex[4.098863152113465, -2.1298944357144083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8743458391924803`, 1.0766911209459984`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9833757701714365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 2, {
              Complex[5.9833757701714365`, 0.6559887487872512], 
              Complex[4.109029930978957, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.78733822159141, 1.3593076544859068`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 1, {
              Complex[5.888195006507387, -0.7772383070571713], 
              Complex[4.100856784915978, -2.136545961543078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8747079198682697`, 1.0750710455219263`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 2, {
              Complex[5.982789553325939, 0.6622677914714886], 
              Complex[4.108081633457669, -0.4128032540504377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.786577900504883, 1.3601300738497377`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7829895624892167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 1, {
              Complex[5.88939287527652, -0.7829895624892167], 
              Complex[4.102814974771636, -2.1431196363389544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8750594232342832`, 1.0734621996229434`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.404987717906231`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 2, {
              Complex[5.982226172350083, 0.6684744817167124], 
              Complex[4.1071667491158, -0.404987717906231]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7858272159740434`, 1.3609437797108248`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.890566276547081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 1, {
              Complex[5.890566276547081, -0.7886736342555827], 
              Complex[4.104739060573038, -2.1496174139664075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8754006767606501`, 1.071864362883253}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9816846234666565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.674610601893371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.397253760989882`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 2, {
              Complex[5.9816846234666565`, 0.674610601893371], 
              Complex[4.106283946706006, -0.397253760989882]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7850858668123624`, 1.3617489740590965`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 1, {
              Complex[5.891716173221935, -0.7942921997868309], 
              Complex[4.106630306409572, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8757319919833177`, 1.0702773218848616`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1054319697609305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 2, {
              Complex[5.981163961744248, 0.6806778662591644], 
              Complex[4.1054319697609305`, -0.38959945562569726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7843535665830947`, 1.3625458522550067`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8928434735373925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.162392724592142`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 1, {
              Complex[5.8928434735373925`, -0.7998468723371353], 
              Complex[4.108489906954297, -2.162392724592142]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8760536655490998`, 1.068700869912264}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 2, {
              Complex[5.980663296755008, 0.6866779243621379], 
              Complex[4.104609631205909, -0.3820229455501261]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.783630042640511, 1.3633346032702527`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 1, {
              Complex[5.893949035024501, -0.8053392041803527], 
              Complex[4.11031899238399, -2.1686738074506056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8763659801766022`, 1.067134806711273}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9801817886150515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3745224424647919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 2, {
              Complex[5.9801817886150515`, 0.6926123642464811], 
              Complex[4.103815808438449, -0.3745224424647919]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7829150352473242`, 1.3641154099233177`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 1, {
              Complex[5.8950336681265165`, -0.8107706896206484], 
              Complex[4.112118632879193, -2.174886099543966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8766692055409029`, 1.0655789382530265`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3670962227803742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 2, {
              Complex[5.979718644368705, 0.6984827154726524], 
              Complex[4.103049438827802, -0.3670962227803742]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7822082967612691`, 1.364888449109056}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 1, {
              Complex[5.896098139506871, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8769635990890456`, 1.0640330765039459`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35974262454091743`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 2, {
              Complex[5.979273114682199, 0.7042904519630283], 
              Complex[4.102309515593154, -0.35974262454091743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7815095908845182`, 1.3656538920217645`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 1, {
              Complex[5.897143175078252, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8772494067926553`, 1.0624970392022142`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9788444908162806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 2, {
              Complex[5.9788444908162806`, 0.7100369946836332], 
              Complex[4.101595084023626, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.780818691970253, 1.3664119043713534`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.87752686384337, 1.0609706496411515`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978432101850545`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 2, {
              Complex[5.978432101850545, 0.7157237141721114], 
              Complex[4.100905238007175, -0.34524693546904006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7801353843813221`, 1.3671626465923734`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788286036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1190422707459655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.199078825420977`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 1, {
              Complex[5.899177655127287, -0.8319161788286036], 
              Complex[4.1190422707459655`, -2.199078825420977]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.877796195296143, 1.059453736459734}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9780353121353675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538322`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 2, {
              Complex[5.9780353121353675`, 0.7213519329214121], 
              Complex[4.100239116839224, -0.338101803538322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.779459461896388, 1.3679062740457615`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.837064007532895`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2049702815786563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 1, {
              Complex[5.900168371555868, -0.837064007532895], 
              Complex[4.120708909659479, -2.2049702815786563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8780576166650225`, 1.057946133440395}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97765351894983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.726922927628197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 2, {
              Complex[5.97765351894983, 0.726922927628197], 
              Complex[4.099595902284808, -0.3310232058121981]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7787907271594574`, 1.3686429372132638`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12235147341849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 1, {
              Complex[5.901142200577947, -0.8421588862221204], 
              Complex[4.12235147341849, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8783113344755138`, 1.0564476793141508`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977286150346381`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.324009747999723`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 2, {
              Complex[5.977286150346381, 0.7324379313144279], 
              Complex[4.098974815870868, -0.324009747999723]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7781289911690763`, 1.3693727818845618`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 1, {
              Complex[5.9020997017701315`, -0.8472019743388878], 
              Complex[4.123970710601055, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8785575467772448`, 1.054958217573022}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387769`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 2, {
              Complex[5.976932663165014, 0.7378981353300631], 
              Complex[4.098375116387769, -0.31706008224295895`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7774740728038292`, 1.3700959493371787`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8787964436202937`, 1.0534775962896734`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 2, {
              Complex[5.976592541201492, 0.7433046912443021], 
              Complex[4.097796097581198, -0.31017290504537126`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7768257983811162`, 1.3708125765093016`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 1, {
              Complex[5.903967825152418, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.879028207498206, 1.0520056679441445`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178313`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 2, {
              Complex[5.976265293515785, 0.7486587126323615], 
              Complex[4.097237086017579, -0.30334695531178313`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7761840012464636`, 1.3715227961656589`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 1, {
              Complex[5.904879437628475, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.879253013760444, 1.0505422892575185`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97595045286828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 2, {
              Complex[5.97595045286828, 0.7539612767642827], 
              Complex[4.096697439107836, -0.2965810124932358]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7755485213908777`, 1.3722267370566543`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 1, {
              Complex[5.905776705860622, -0.8668782698647188], 
              Complex[4.130228184469744, -2.239105006921373]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8794710309967648`, 1.0490873210323428`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045617`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 2, {
              Complex[5.975647574272541, 0.7592134262018867], 
              Complex[4.096176543275776, -0.28987389483045617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7749192050939944`, 1.3729245240709407`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.906660069621736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 1, {
              Complex[5.906660069621736, -0.8716784802620264], 
              Complex[4.131740864527742, -2.244603004332967]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8796824213957781`, 1.0476406279996031`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9753562336545505`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900402`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 2, {
              Complex[5.9753562336545505`, 0.764416170309563], 
              Complex[4.095673812258773, -0.2832244576900402]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7742959045909652`, 1.3736162783816552`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 1, {
              Complex[5.907529948876621, -0.8764330896595153], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.879887341079722, 1.0462020786720445`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 2, {
              Complex[5.975076026609326, 0.7695704866842139], 
              Complex[4.095188685529604, -0.2766315919878305]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7736784777612251`, 1.3743021175865286`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937715`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1347082671764905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 1, {
              Complex[5.908386744937715, -0.8811430162906049], 
              Complex[4.1347082671764905`, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.880085940417346, 1.0447715452036124`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2700942226942855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 2, {
              Complex[5.974806567246683, 0.7746773225093267], 
              Complex[4.094720626829337, -0.2700942226942855]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7730667878374382`, 1.3749821558421012`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 1, {
              Complex[5.909230841539051, -0.8858091496519157], 
              Complex[4.136164053701613, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.880278364316575, 1.0433489032547971`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698485`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 2, {
              Complex[5.974547487118723, 0.7797375958378123], 
              Complex[4.094269122802149, -0.26361130741698485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.77246070313309, 1.3756565039922595`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266088855704737`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 1, {
              Complex[5.910062605835208, -0.8904323517124777], 
              Complex[4.137601902702118, -2.266088855704737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8804647524985074`, 1.0419340318636499`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9742984342223115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 2, {
              Complex[5.9742984342223115`, 0.7847521968079438], 
              Complex[4.093833681723804, -0.25718183505570613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.771860096787288, 1.376325269691328}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 1, {
              Complex[5.910882389331387, -0.8950134580602265], 
              Complex[4.139022292544099, -2.271338727751554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8806452397541658`, 1.04052681332225}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070431`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 2, {
              Complex[5.974059072070431, 0.7897219887964374], 
              Complex[4.093413832316265, -0.2508048245258127]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7712648465255223`, 1.376988557521931}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140425682224579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 1, {
              Complex[5.911690528750101, -0.8995532789895435], 
              Complex[4.140425682224579, -2.2765418365114742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8808199561852765`, 1.0391271330584038`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7706748344351637`, 1.3776464691078487`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 1, {
              Complex[5.912487346839559, -0.9040526005333869], 
              Complex[4.141812512404396, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8809890274302723`, 1.0377348795223467`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 2, {
              Complex[5.973608146499301, 0.7995304720360316], 
              Complex[4.092619119069028, -0.2382044074863151]}, 0}, "Tooltip"]
           & ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7700899467546596`, 1.3782991032220784`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1431832063736325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2868112886653567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 1, {
              Complex[5.913273153128292, -0.9085121854432783], 
              Complex[4.1431832063736325`, -2.2868112886653567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8811525748765787`, 1.0363499440782495`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2319791782739564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.2319791782739564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7695100736754144`, 1.3789465558903042`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 1, {
              Complex[5.914048244630215, -0.9129327741202399], 
              Complex[4.1445381709548, -2.291879330010544]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.881310715860187, 1.0349722209003103`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09188158151152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 2, {
              Complex[5.973192297371706, 0.8091694575484236], 
              Complex[4.09188158151152, -0.2258027633518866]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7689351091554633`, 1.3795889204899814`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 1, {
              Complex[5.914812906503919, -0.9173150854995428], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8814635638534112`, 1.033601606873234}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2196743146888657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 2, {
              Complex[5.972996827270754, 0.8139272921843683], 
              Complex[4.091533263417343, -0.2196743146888657]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7683649507440924`, 1.3802262878452325`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.915567412669662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.14720246192557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 1, {
              Complex[5.915567412669662, -0.9216598178919512], 
              Complex[4.14720246192557, -2.3018861057371836`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.881611228641674, 1.0322380014969068`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699708`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568593, -0.21359300783699708`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7677994994166613`, 1.3808587463177342`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3068263961017066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 1, {
              Complex[5.916312026387238, -0.9259676497839727], 
              Complex[4.148512526970577, -2.3068263961017066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8817538164900676`, 1.030881306795083}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.207558041034483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 2, {
              Complex[5.9726294970541804`, 0.8233232657606], 
              Complex[4.090875680564113, -0.207558041034483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7672386594189005`, 1.3814863818937806`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9170470007976235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 1, {
              Complex[5.9170470007976235`, -0.9302392405994732], 
              Complex[4.149808341378723, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8818914303004093`, 1.0295314272278833`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 2, {
              Complex[5.972457148662774, 0.8279627928769887], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7666823381200638`, 1.3821092782676974`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.91777257943106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 1, {
              Complex[5.91777257943106, -0.9344752314248258], 
              Complex[4.151090241310996, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.8820241697594327`, 1.028188269607965}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272945`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 2, {
              Complex[5.97229203538588, 0.8325642407352354], 
              Complex[4.090267865626448, -0.19562402887272945`]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.5017854283628767`, 1.1700279500517285`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 1, {
              Complex[4.976967927486166, 0.006887727487396987], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.401714513166993, 1.1829054568301065`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013243170301699064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 2, {
              Complex[7.398301539299035, -0.013243170301699064`], 
              Complex[8.800016052466027, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.501170702256321, 1.1700984290050052`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 1, {
              Complex[5.020988084142069, 0.007042959985368856], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4021781609488544`, 1.1828156904519644`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 2, {
              Complex[7.352914113679205, -0.013509876715323912`], 
              Complex[8.75509227462806, -1.1963255671672883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.5005480471445807`, 1.1701703920092204`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.057395324277087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 1, {
              Complex[5.057395324277087, 0.007197843246654417], 
              Complex[6.557943371421667, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4026519382158162`, 1.1827237771013548`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013751044852511824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 2, {
              Complex[7.315449803449272, -0.013751044852511824`], 
              Complex[8.718101741665087, -1.1964748219538666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4999175845647268`, 1.170243830911322}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961005435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 1, {
              Complex[5.089412494295964, 0.007354951961005435], 
              Complex[6.589330078860691, -1.1628888789503165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4031353168487872`, 1.1826298514755766`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 2, {
              Complex[7.282554763488937, -0.013979869598457893`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4992792804249542`, 1.1703187646377389`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 1, {
              Complex[5.118506250669166, 0.007515591774090766], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4036280757715052`, 1.1825339738020835`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960728994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.65633113389032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 2, {
              Complex[7.252703058118816, -0.014202465960728994`], 
              Complex[8.65633113389032, -1.1967364397628124`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4986330163686357`, 1.1703952273655907`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1454918259261815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007680628289981348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 1, {
              Complex[5.1454918259261815`, 0.007680628289981348], 
              Complex[6.644124842294817, -1.1627145990756094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.40413015408831, 1.1824361653396913`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000406`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 2, {
              Complex[7.225046713694153, -0.01442235766034948], 
              Complex[8.629176867782464, -1.1968585230000406`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4979786180017496`, 1.1704732639588975`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533852`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 1, {
              Complex[5.170878634413056, 0.007850743160533852], 
              Complex[6.668857252414806, -1.1626225207983636`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4046415915053123`, 1.1823364227607003`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436205`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 2, {
              Complex[7.199056007873822, -0.014641876121436205`], 
              Complex[8.603697599379135, -1.1969782988821365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.49731586799168, 1.1705529279620166`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.69232677922716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 1, {
              Complex[5.19501091123548, 0.008026538528972053], 
              Complex[6.69232677922716, -1.1625263894330444`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4051624994789436`, 1.1822347250851228`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274703`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 2, {
              Complex[7.174373102447972, -0.014862729232274703`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.496644512512579, 1.1706342807319507`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338763131`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 1, {
              Complex[5.2181348551047995`, 0.008208588338763131], 
              Complex[6.714779367617378, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4056930458564805`, 1.182131037333787}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.150742171455597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248022`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 2, {
              Complex[7.150742171455597, -0.015086273942248022`], 
              Complex[8.556435217312078, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4959642642740745`, 1.1707173911723612`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701837667`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 1, {
              Complex[5.240434389619401, 0.008397467701837667], 
              Complex[6.736398653893476, -1.1623199234705235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4062334463696151`, 1.1820253125041498`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596052`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 2, {
              Complex[7.127972189674163, -0.015313663264596052`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4952748035595536`, 1.170802335836929}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00859377229372981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 1, {
              Complex[5.262051805853028, 0.00859377229372981], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4067839600187142`, 1.1819174925824536`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028891`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 2, {
              Complex[7.1059154551031405`, -0.015545933419028891`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4945757779611735`, 1.1708891992948665`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178996`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7776762194252065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 1, {
              Complex[5.283100441464033, 0.008798133065178996], 
              Complex[6.7776762194252065`, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4073448868889171`, 1.1818075089410556`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.08445439867063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230012`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 2, {
              Complex[7.08445439867063, -0.015784060035230012`], 
              Complex[8.491799285559546, -1.1975915689762855`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4938668011572593`, 1.170978074710212}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 1, {
              Complex[5.303672866164795, 0.009011228909084911], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4079165676323857`, 1.1816952823007194`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587324`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 2, {
              Complex[7.063493070122277, -0.016028997503587324`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4931474509023805`, 1.1710690646180273`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935135`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 1, {
              Complex[5.323846388854408, 0.009233798770935135], 
              Complex[6.816993839756788, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.408499384202991, 1.1815807223508816`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942806058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 2, {
              Complex[7.042951411025012, -0.016281708942806058`], 
              Complex[8.451450795228002, -1.1978624312936876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4924172663005877`, 1.1711622819000642`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547516`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 1, {
              Complex[5.343686896016404, 0.009466654168547516], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.409093761624542, 1.1814637270716994`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016543191071888962`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 2, {
              Complex[7.022761264330783, -0.016543191071888962`], 
              Complex[8.431855025955326, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4916757443684578`, 1.1712578509767424`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00971069285821086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 1, {
              Complex[5.363251612071681, 0.00971069285821086], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4097001706915273`, 1.1813441817705232`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831153`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 2, {
              Complex[7.002863505905771, -0.016814496662831153`], 
              Complex[8.412563676597298, -1.1981586784333542`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4909223358478294`, 1.1713559092447527`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 1, {
              Complex[5.382591142510597, 0.009966914310096189], 
              Complex[6.873513478358426, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4103191315804102`, 1.1812219578228558`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 2, {
              Complex[6.983205922649462, -0.017096756417673824`], 
              Complex[8.39352505422987, -1.1983187142405296`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4901564401882263`, 1.1714566088024065`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102364376771995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 1, {
              Complex[5.401751028707841, 0.0102364376771995], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4109512184092652`, 1.1810969110888372`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304287`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 2, {
              Complex[6.963741599119121, -0.017391201699304287`], 
              Complex[8.374692817528386, -1.1984881127881413`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.489377399579972, 1.1715601185194695`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 1, {
              Complex[5.4207729647332625`, 0.010520523036427957`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4115970648354659`, 1.1809688799576648`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017699189379580503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 2, {
              Complex[6.944427656372563, -0.017699189379580503`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4885844918762254`, 1.171666626526157}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492478`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 1, {
              Complex[5.439695778207934, 0.010820596844492478`], 
              Complex[6.9282802700841595`, -1.1608460296816645`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4122573708322488`, 1.180837682951786}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644347`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 2, {
              Complex[6.925224236986867, -0.018022230071644347`], 
              Complex[8.337481607819116, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4877769221917714`, 1.1717763432189274`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 1, {
              Complex[5.458556246931597, 0.011138282794836918`], 
              Complex[6.946333169123368, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4129329108411504`, 1.1807031157979515`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018362021154623754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 2, {
              Complex[6.906093661793765, -0.018362021154623754`], 
              Complex[8.319026572634915, -1.1990651369525753`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4869538129038884`, 1.171889504910906}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775249`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 1, {
              Complex[5.47738980371477, 0.011475439606775249`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4136245435637642`, 1.1805649478407967`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 2, {
              Complex[6.886999703988066, -0.018720486277070774`], 
              Complex[8.30062424755183, -1.1992854341178676`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4861141917006078`, 1.1720063782953083`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.49623116962678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 1, {
              Complex[5.49623116962678, 0.011834207760463417`], 
              Complex[6.982345361327388, -1.160172170534845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4143332237390722`, 1.180422917633203}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8679069390373595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292608`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 2, {
              Complex[6.8679069390373595`, -0.019099823463292608`], 
              Complex[8.282240162776432, -1.1995227410964955`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4852569772170092`, 1.1721272659455275`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222368`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 1, {
              Complex[5.515114948423251, 0.012217067867222368`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.415060016359263, 1.1802767274817771`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848780136643827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.26384015300309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 2, {
              Complex[6.848780136643827, -0.019502564592186727`], 
              Complex[8.26384015300309, -1.1997792920739638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4843809616607953`, 1.1722525131521497`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.534076210934987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01262691431947491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 1, {
              Complex[5.534076210934987, 0.01262691431947491], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4158061139178744`, 1.180126036648719}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741088`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 2, {
              Complex[6.829583665251547, -0.019931649951741088`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4834847896398293`, 1.1723825165049406`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 1, {
              Complex[5.553151097008939, 0.013067149229433932`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.416572857473625, 1.1799704528032402`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 2, {
              Complex[6.810280880968053, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.2003609757255187`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4825669321456934`, 1.1725177347818592`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186447`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 1, {
              Complex[5.57237746397503, 0.013541803645186447`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4173617625729202`, 1.1798095211614357`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 2, {
              Complex[6.790833471518203, -0.020883251810279772`], 
              Complex[8.208195234091123, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4816256542869652`, 1.1726587029310958`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.59179561475532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 1, {
              Complex[5.59179561475532, 0.014055695951277586`], 
              Complex[7.073421269042285, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4181745514348088`, 1.1796427105293465`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.77120072180202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.189375273236829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 2, {
              Complex[6.77120072180202, -0.021414688765245098`], 
              Complex[8.189375273236829, -1.2010573992945917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4806589748563332`, 1.1728060502638156`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 1, {
              Complex[5.611449146258794, 0.014614641743299683`], 
              Complex[7.092108121115127, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4190131933123733`, 1.1794693951321646`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 2, {
              Complex[6.751338660172414, -0.021990680088691778`], 
              Complex[8.170351853484787, -1.2014600752208564`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4796646150826884`, 1.1729605244765766`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 1, {
              Complex[5.631385970822487, 0.01522573618198173], 
              Complex[7.111050585905176, -1.157734788294595]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.419879955677785, 1.1792888306110796`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671372`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 2, {
              Complex[6.731199032484281, -0.02261834895605755], 
              Complex[8.151078988162066, -1.2019071795671372`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.478639932846057, 1.1731230238972745`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251509`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015897740359760885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.130299515097566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 1, {
              Complex[5.651659582251509, 0.015897740359760885`], 
              Complex[7.130299515097566, -1.1572252835375136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4207774699518891`, 1.1791001217943402`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.710728032214631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 2, {
              Complex[6.710728032214631, -0.02330648209651109], 
              Complex[8.13150550216652, -1.2024066038908514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4775818370306344`, 1.1732946415763739`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 1, {
              Complex[5.6723306669868805`, 0.016641620135819515`], 
              Complex[7.149912504017515, -1.1566530214405542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4217088171019858`, 1.1789021786210783`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217648`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 2, {
              Complex[6.689864686007545, -0.024066068896217648`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4764866742464757`, 1.1734767268460085`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156005412968246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 1, {
              Complex[5.693469206036438, 0.017471313877762278`], 
              Complex[7.169955880282914, -1.156005412968246]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4226776408763422`, 1.178693654595605}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370829316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.091216389791244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 2, {
              Complex[6.668538748914902, -0.024911069370829316`], 
              Complex[8.091216389791244, -1.2036047239664343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.475350076333025, 1.1736709733336637`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805062`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 1, {
              Complex[5.715157284805062, 0.01840485331132215], 
              Complex[7.190507361138087, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.423688300261557, 1.1784728587856865`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 2, {
              Complex[6.646667892120967, -0.02585953521479532], 
              Complex[8.070356192382524, -1.2043323940004818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4741667509430407`, 1.1738795482784525`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01946604620382397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 1, {
              Complex[5.737492944039842, 0.01946604620382397], 
              Complex[7.211659694982883, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.424746078863568, 1.1782376265169778`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819092`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 2, {
              Complex[6.624153849873984, -0.02693529265819092], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4729301874376595`, 1.1741052886346304`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.760595598959389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02068708549653934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 1, {
              Complex[5.760595598959389, 0.02068708549653934], 
              Complex[7.233525786397049, -1.153418203138091]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.425857478981057, 1.177985123279133}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60087699850535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252907`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 2, {
              Complex[6.60087699850535, -0.028170551750252907`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4716322332556833`, 1.1743520096788438`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784613887852916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073541263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053025`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 1, {
              Complex[5.784613887852916, 0.022112751073541263`], 
              Complex[7.256246121108599, -1.1522392586053025`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4270306452077093`, 1.1777115361272343`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.576688506209679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 2, {
              Complex[6.576688506209679, -0.029610108260631308`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4702624661250188`, 1.1746250124900501`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.150817525269937`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 1, {
              Complex[5.809737407862617, 0.02380748722011311], 
              Complex[7.279999873987635, -1.150817525269937]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4282759921950474`, 1.177411566209715}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.551398595838172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.97967458803322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 2, {
              Complex[6.551398595838172, -0.03131842125415468], 
              Complex[7.97967458803322, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.46880723413783, 1.174931963813554}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8362148977187704`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025867986584034483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 1, {
              Complex[5.8362148977187704`, 0.025867986584034483`], 
              Complex[7.3050221318566, -1.1490639772295197`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4296071645539172`, 1.1770775489114365`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 2, {
              Complex[6.5247583609077076`, -0.03339219715471037], 
              Complex[7.954365525461625, -1.2104697460661467`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4672481393507069`, 1.1752845235948637`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632705032`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 1, {
              Complex[5.864383522178553, 0.028447097632705032`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.431042553233109, 1.17669782632629}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 2, {
              Complex[6.496430480050892, -0.03598429729320674], 
              Complex[7.927473033284, -1.2126821236194967`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4655595753610149`, 1.1757016080477805`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.143898450195406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 1, {
              Complex[5.894717893374837, 0.03180315785237445], 
              Complex[7.360277468735853, -1.143898450195406]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4326077579236252`, 1.176253484194999}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 2, {
              Complex[6.465940194681213, -0.03935307118737358], 
              Complex[7.898547952604838, -1.2156065553823725`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4637047365799356`, 1.1762166309510624`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093549137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 1, {
              Complex[5.927914095850698, 0.03641303093549137], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4343395777679646`, 1.1757111106138294`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 2, {
              Complex[6.432591283080758, -0.04397539380088787], 
              Complex[7.866930860848724, -1.2196865044147172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4616301130119984`, 1.1768957422124684`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.965024718764882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.42665483177688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 1, {
              Complex[5.965024718764882, 0.04326772266645264], 
              Complex[7.42665483177688, -1.1336280195460158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.436291516564384, 1.175004557475467}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.050842281493196174`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.831622543975559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 2, {
              Complex[6.395331027411175, -0.050842281493196174`], 
              Complex[7.831622543975559, -1.2258468389686634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4592681645784726`, 1.1778903728540753`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 1, {
              Complex[6.007534506136696, 0.05476808187732237], 
              Complex[7.466802670715169, -1.123122290976753]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4385311084286374`, 1.1739823954882145`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 2, {
              Complex[6.352674562767397, -0.06235459303258747], 
              Complex[7.7912056711960345`, -1.2363369885208018`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4566537110023619`, 1.179575892857512}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 1, {
              Complex[6.055705576569382, 0.07734359441247657], 
              Complex[7.512359287571743, -1.1022322984450355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4410235278953083`, 1.1722692563349013`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.257211079947235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 2, {
              Complex[6.304359656824844, -0.08494182361233364], 
              Complex[7.745383184720152, -1.257211079947235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4545182673906114`, 1.1823285296727972`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0979727560579535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11902724764148766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 1, {
              Complex[6.0979727560579535`, 0.11902724764148766`], 
              Complex[7.552491023448565, -1.0633012820313095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.443037254323001, 1.1694889141678684`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 2, {
              Complex[6.261951376465346, -0.12663696940988806`], 
              Complex[7.704988630788347, -1.2961258835777565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4535434455400553`, 1.185252892882233}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996513286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 1, {
              Complex[6.120724694194673, 0.16611165996513286`], 
              Complex[7.574268139734729, -1.0191412329171001`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4438906705767707`, 1.1665367609485928`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 2, {
              Complex[6.239060971061035, -0.17373265713468272`], 
              Complex[7.682951641637805, -1.3402694180832757`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4531664322147937`, 1.1877411805488003`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 1, {
              Complex[6.132202365530887, 0.20695392178184907`], 
              Complex[7.58536879774568, -0.9807872587669512]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4441465847399888`, 1.1640206001025495`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2274473706510705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.214585985032377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 2, {
              Complex[6.2274473706510705`, -0.214585985032377], 
              Complex[7.671593955391059, -1.3786065851349265`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4530130204092828`, 1.189863773356467}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 1, {
              Complex[6.138977875500194, 0.24191392575349455`], 
              Complex[7.591990895909476, -0.9479498476029725]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.444179198841299, 1.1618700523819145`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 2, {
              Complex[6.22053837960052, -0.24955685318475537`], 
              Complex[7.664717578441819, -1.4114269055666697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.452955617222807, 1.191728690498506}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2725610929770674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 1, {
              Complex[6.143492571886664, 0.2725610929770674], 
              Complex[7.596448189109472, -0.9191675975214387]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4441161009709047`, 1.1599770999800387`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125679`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.66000866572372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 2, {
              Complex[6.215892564752815, -0.2802146897125679], 
              Complex[7.66000866572372, -1.4401917896926066`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.452945481200874, 1.1934063028976165`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1467493959161805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30000093008350653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.89340537281411`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 1, {
              Complex[6.1467493959161805`, 0.30000093008350653`], 
              Complex[7.599694877117055, -0.89340537281411]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4440060279305904`, 1.1582713733139203`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307665007902555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 2, {
              Complex[6.212506903993476, -0.307665007902555], 
              Complex[7.656512931924067, -1.4659363812164754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4529608296272483`, 1.1949415431340544`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 1, {
              Complex[6.149229270200796, 0.32496389242763946`], 
              Complex[7.602190099828044, -0.8699776507064151]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4438707579337056`, 1.1567079410984837`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2099003979914995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33263826942312247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 2, {
              Complex[6.2099003979914995`, -0.33263826942312247`], 
              Complex[7.653771155925205, -1.4893462105216064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4529907078599174`, 1.1963644144601786`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271418`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 1, {
              Complex[6.151192034362996, 0.34794816918876065`], 
              Complex[7.604182742222913, -0.848416245271418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4437212412617595`, 1.1552568013342808`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2078131342882505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563266944840694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 2, {
              Complex[6.2078131342882505`, -0.35563266944840694`], 
              Complex[7.6515343755500105`, -1.5108894707826876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.453029114719509, 1.1976959087554475`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 1, {
              Complex[6.152791090696166, 0.3693076970042954], 
              Complex[7.605820205415675, -0.8283882117511522]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4435634748690542`, 1.1538969633545817`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.206091641374743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.377002150313453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 2, {
              Complex[6.206091641374743, -0.377002150313453], 
              Complex[7.649655116243798, -1.5308991136680348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4530725494541268`, 1.1989513125919395`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 1, {
              Complex[6.154123300626686, 0.3893033507690846], 
              Complex[7.607195850080814, -0.8096479618228548]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4434009554113734`, 1.1526131417618155`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549620734094958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 2, {
              Complex[6.204638991989324, -0.39700759233314253`], 
              Complex[7.648039947400696, -1.549620734094958]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4531188721094161`, 1.2001421329007407`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15525311268908`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 1, {
              Complex[6.15525311268908, 0.40813349152982514`], 
              Complex[7.608371984798496, -0.7920086413709154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4432358188698453`, 1.151393830763004}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777163`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 2, {
              Complex[6.203390674922197, -0.41584736171471215`], 
              Complex[7.646626493792042, -1.5672411924777163`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.453166728054712, 1.2012772723139358`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 1, {
              Complex[6.156225240135477, 0.4259529280523636], 
              Complex[7.60939196819019, -0.7753243442615722]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4430694160191173`, 1.150230128829482}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 2, {
              Complex[6.202301917203499, -0.4336762721416331], 
              Complex[7.6453713332226165`, -1.5839064009711152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4532152374846554`, 1.2023637780263299`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157071780468366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 1, {
              Complex[6.157071780468366, 0.44288515307919935`], 
              Complex[7.610287017953022, -0.7594786249471305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4429026229204052`, 1.1491149898367785`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 2, {
              Complex[6.201340564384263, -0.4506178210463806], 
              Complex[7.644243187304668, -1.5997328108831592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4532638186620361`, 1.203407337226422}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157816436754414`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 1, {
              Complex[6.157816436754414, 0.45903052180506415`], 
              Complex[7.611080255416451, -0.7443768154213578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4427360176736588`, 1.1480427276351444`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 2, {
              Complex[6.2004828590509335`, -0.46677236810008305`], 
              Complex[7.6432188767245925`, -1.6148150957352272`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.453312082760008, 1.204412615725118}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669327, -0.7299407258319837]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4425699855706464`, 1.1470086774222505`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 2, {
              Complex[6.199710822382092, -0.48222277324174173`], 
              Complex[7.642280807952738, -1.6292314506639924`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4533597689593478`, 1.2053834960418555`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682773966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 1, {
              Complex[6.1590677155468105`, 0.48927860682773966`], 
              Complex[7.612427484506159, -0.7161048892141159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4424047839932777`, 1.1460089576583916`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4970383900429073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 2, {
              Complex[6.199010567153121, -0.4970383900429073], 
              Complex[7.6414153511463985`, -1.6430473477012988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4534067031313302`, 1.206323248968059}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539054`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825418`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 1, {
              Complex[6.159599046539054, 0.5035094122855172], 
              Complex[7.613005749670385, -0.7028138366825418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4422405837265568`, 1.1450402985042778`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.656318260594247`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 2, {
              Complex[6.198371175040328, -0.5112779620899692], 
              Complex[7.640611758766885, -1.656318260594247]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4534527708340308`, 1.2072346598860024`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894211`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 1, {
              Complex[6.160079801248163, 0.5172145811965814], 
              Complex[7.613532572082193, -0.6900200786894211]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.442077495958373, 1.1440999155033493`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4534978992617913`, 1.2081201235569357`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576769`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 1, {
              Complex[6.160516992248921, 0.5304375419992586], 
              Complex[7.6140148915107115`, -0.6776825815576769]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4419155903263274`, 1.143185414794756}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 2, {
              Complex[6.197241770749234, -0.5382232399630632], 
              Complex[7.639157361075561, -1.681408654757819]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4535420449439733`, 1.2089817164561358`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61445840324093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699652`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 1, {
              Complex[6.160916358296958, 0.5432161176861706], 
              Complex[7.61445840324093, -0.6657655987699652]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4417549072154803`, 1.142294720779357}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204681`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 2, {
              Complex[6.1967389220498434`, -0.5510102042411112], 
              Complex[7.638493829265324, -1.6933049250204681`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.45358518522124, 1.209821252808463}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 1, {
              Complex[6.161282646160605, 0.5555834916479542], 
              Complex[7.6148678313818445`, -0.6542377611605088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4415954662787756`, 1.1414260200851492`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.196270595415879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 2, {
              Complex[6.196270595415879, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.453627312254349, 1.2106403285857692`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161619819931483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 1, {
              Complex[6.161619819931483, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4414372724251217`, 1.1405777175707952`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 2, {
              Complex[6.195832788389601, -0.5753794785718531], 
              Complex[7.637270060814722, -1.7159571961426485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4536684287612416`, 1.211440356474314}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 1, {
              Complex[6.161931218858729, 0.5791985860418384], 
              Complex[7.615599647619971, -0.6322417704324756]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.441280320079339, 1.1397484013590915`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873219`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 2, {
              Complex[6.1954221248841135`, -0.5870171355873219], 
              Complex[7.636702444963452, -1.7267655369464134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4537085449523155`, 1.2122225939728501`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 1, {
              Complex[6.162219678012526, 0.5904955973399486], 
              Complex[7.615928222964841, -0.6217269966329017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4411245962440906`, 1.1389368147397188`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.598322077084824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 2, {
              Complex[6.195035734438572, -0.598322077084824], 
              Complex[7.636160330682662, -1.7372588918245429`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4537476763080104`, 1.2129881661979556`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1624876216872115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 1, {
              Complex[6.1624876216872115`, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4409700827196388`, 1.1381418333647062`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133901`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63564124145883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 2, {
              Complex[6.194671158739191, -0.6093151811133901], 
              Complex[7.63564124145883, -1.7474570144780963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.453785841955973, 1.2137380845635795`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 1, {
              Complex[6.162737136528052, 0.6121732527479825], 
              Complex[7.616522978484024, -0.6015648318155971]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4408167577241586`, 1.1373624465696326`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19432627842157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 2, {
              Complex[6.19432627842157, -0.6200152737048318], 
              Complex[7.635143036145728, -1.7573777202744645`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4538230634796785`, 1.214473262210035}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038926`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 1, {
              Complex[6.162970029380979, 0.6225897638061423], 
              Complex[7.616793092860657, -0.5918834984038926]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4406645970827203`, 1.1365977419453552`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19399925515462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 2, {
              Complex[6.19399925515462, -0.6304394010704694], 
              Complex[7.63466385223734, -1.7670371430158245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4538593640406068`, 1.2151945268467639`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163187873495399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 1, {
              Complex[6.163187873495399, 0.6327459028649589], 
              Complex[7.617047237536005, -0.5824486239818051]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.440513575102836, 1.1358468924959162`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.45389476773024, 1.2159026315187895`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 1, {
              Complex[6.163392045750656, 0.642655799962885], 
              Complex[7.617286813480896, -0.5732468315559044]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4403636652203033`, 1.1351091458727411`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 2, {
              Complex[6.193392563005681, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4539292990917323`, 1.2165982636922328`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1635837568947665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6523323858111203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 1, {
              Complex[6.1635837568947665`, 0.6523323858111203], 
              Complex[7.617513055986499, -0.5642658778811124]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4402148404754676`, 1.1343838152897303`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 2, {
              Complex[6.193110249156134, -0.6602042845457751], 
              Complex[7.633325089631601, -1.7945880998355055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4539629827677445`, 1.2172820529684156`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1637640762927965`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6617875296457955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226202`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 1, {
              Complex[6.1637640762927965`, 0.6617875296457955], 
              Complex[7.617727059060542, -0.5554945233226202]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4400670738634374`, 1.1336702718097431`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63290752119261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 2, {
              Complex[6.192840447329172, -0.6696666607954203], 
              Complex[7.63290752119261, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4539958432424933`, 1.2179545776709837`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163933952324089`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.546922420377038`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 1, {
              Complex[6.163933952324089, 0.6710321572939456], 
              Complex[7.617929795566583, -0.546922420377038]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4399203385901522`, 1.1329679377580293`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 2, {
              Complex[6.192582182972332, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4540279046545685`, 1.2186163705006785`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 1, {
              Complex[6.164094229303429, 0.6800763528244183], 
              Complex[7.618122133957997, -0.5385400176762603]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4397746082577951`, 1.1322762810679872`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 2, {
              Complex[6.192334586512062, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4540591906630251`, 1.2192679234139303`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 1, {
              Complex[6.164245661604394, 0.6889294464957758], 
              Complex[7.6183048522674195`, -0.5303384769181545]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.439629856996997, 1.131594810403076}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 2, {
              Complex[6.192096879187744, -0.6968297409230598], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4540897243537036`, 1.2199096918514625`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6976000911985042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 1, {
              Complex[6.164388925515003, 0.6976000911985042], 
              Complex[7.618478649868707, -0.5223096006529584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4394860595588896`, 1.1309230709286933`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 2, {
              Complex[6.191868361155921, -0.7055072687737811], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4541195281759691`, 1.2205420984195956`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 1, {
              Complex[6.164524629243228, 0.7060963291837467], 
              Complex[7.618644157419197, -0.5144457692358491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.439343191376819, 1.1302606406313311`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1916484014469475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7140103074539125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 2, {
              Complex[6.1916484014469475`, -0.7140103074539125], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4541486239024193`, 1.2211655361083011`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.714425650549425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 1, {
              Complex[6.164653321403731, 0.714425650549425], 
              Complex[7.618801945306149, -0.5067398855588762]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.439201228605155, 1.1296071271009605`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6306376580477195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 2, {
              Complex[6.191436429442565, -0.7223463488774432], 
              Complex[7.6306376580477195`, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454177032605957, 1.221780371115246}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618952530856562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171731`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 1, {
              Complex[6.164775498250606, 0.7225950446980729], 
              Complex[7.618952530856562, -0.4991853264171731]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.439060148140805, 1.1289621647074086`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 2, {
              Complex[6.191231927609488, -0.7305223842033103], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4542047746499094`, 1.222386945333169}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49177589955865814`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 1, {
              Complex[6.164891609869035, 0.7306110457745109], 
              Complex[7.6190963845189446`, -0.49177589955865814`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4389199276317326`, 1.1283254121133874`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4542318696878953`, 1.2229855785483166`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 1, {
              Complex[6.165002065498246, 0.7384797729243929], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4387805454757947`, 1.1276965500764318`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.746420164884856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 2, {
              Complex[6.190843493278558, -0.746420164884856], 
              Complex[7.629624038754352, -1.8741167149612878`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4542583366709552`, 1.2235765703899115`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165107238125894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4773696043103947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 1, {
              Complex[6.165107238125894, 0.7462069660795168], 
              Complex[7.6193655747968485`, -0.4773696043103947]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.438641980812378, 1.1270752794998102`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 2, {
              Complex[6.190658739339741, -0.7541537725552647], 
              Complex[7.629300720152119, -1.881229052055075]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4542841938599667`, 1.2241602020642195`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 1, {
              Complex[6.165207468468806, 0.7537980178639987], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4385042135087747`, 1.1264613196988047`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 2, {
              Complex[6.190479804059834, -0.7617511664534368], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4543094588418968`, 1.2247367379015852`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1653030684343095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7612580021246107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 1, {
              Complex[6.1653030684343095`, 0.7612580021246107], 
              Complex[7.619612527276207, -0.4634787357769745]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4383672241428038`, 1.125854406854012}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4543341485487062`, 1.2253064267405018`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 1, {
              Complex[6.165394324140473, 0.7685916995129606], 
              Complex[7.619728472689179, -0.4567147272275413]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4382309939828053`, 1.1252542926276017`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 2, {
              Complex[6.190138095789615, -0.7765573210571979], 
              Complex[7.62836908977242, -1.9018116136847993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4543582792780583`, 1.2258695031691893`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204843003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268488906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 1, {
              Complex[6.1654814985597985`, 0.7758036204843003], 
              Complex[7.619839777837857, -0.45006588268488906`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4380955049658746`, 1.124660742922043}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 2, {
              Complex[6.18997473915616, -0.7837753757227324], 
              Complex[7.628070244122034, -1.9084361186447754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454381866715149, 1.2264261886422028`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 1, {
              Complex[6.1655648338407385`, 0.7828980260257032], 
              Complex[7.619946700555888, -0.4435281626164994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4379607396750385`, 1.1240735367637995`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304071`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 2, {
              Complex[6.189816028885474, -0.7908758482666076], 
              Complex[7.627776768560513, -1.9149493850304071`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4544049259551295`, 1.2269766924870942`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352175`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823143`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 1, {
              Complex[6.165644553352175, 0.7898789463823143], 
              Complex[7.620049479307305, -0.43709774610477986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4378266813158467`, 1.1234924652969505`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454427471525755, 1.2275212128140653`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004998`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 1, {
              Complex[6.165720863489107, 0.7967501980135656], 
              Complex[7.620148335014862, -0.4307710148004998]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4376933136928027`, 1.1229173308738125`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1895116073884004`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 2, {
              Complex[6.1895116073884004`, -0.8047399594318435], 
              Complex[7.627204921081203, -1.9276572903056561`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4544495174099354`, 1.228059937339793}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966915`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 1, {
              Complex[6.165793955271712, 0.8035153989801238], 
              Complex[7.620243472681647, -0.42454453835966915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.437560621185916, 1.1223479462313808`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 2, {
              Complex[6.189365468138804, -0.8115110351012249], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4544710770679978`, 1.2285930441351087`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925664`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 1, {
              Complex[6.1658640057650915`, 0.8101779829358521], 
              Complex[7.62033508283309, -0.41841506119925664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4374285887275748`, 1.1217841337438985`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 2, {
              Complex[6.189223116150438, -0.8181794321268682], 
              Complex[7.626651704878013, -1.9399635658707666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4544921634594683`, 1.229120702304966}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 1, {
              Complex[6.165931179342954, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283196]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4372972017799364`, 1.1212257247431385`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 2, {
              Complex[6.18908437282858, -0.8247484136793252], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.45451278906429, 1.229643072608023}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 1, {
              Complex[6.165995628815021, 0.8232081877787772], 
              Complex[7.620508417879312, -0.4064348848292457]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.437166446312914, 1.1206725588990527`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 2, {
              Complex[6.188949071546019, -0.8312210828762444], 
              Complex[7.626115517858932, -1.9518936417752972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4545329659033672`, 1.2301603080222792`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 1, {
              Complex[6.166057496435186, 0.8295818632429406], 
              Complex[7.620590462338552, -0.40057844477933857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.43703630878287, 1.1201244836543607`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 2, {
              Complex[6.188817056619654, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4545527055583864`, 1.2306725542623818`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 1, {
              Complex[6.1661169148049755`, 0.8358650512460934], 
              Complex[7.620669620363362, -0.3948075030162883]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.43690677611204, 1.1195813537074624`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 2, {
              Complex[6.188688182392475, -0.8438891593891126], 
              Complex[7.625594958504515, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454572019190911, 1.2311799502535616`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260576`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875824, -0.38911951616260576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4367778356687475`, 1.1190430305387107`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508243`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 2, {
              Complex[6.188562312408358, -0.8500900641121137], 
              Complex[7.625340148077106, -1.9691330946508243`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4545909175606837`, 1.2316826285665505`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16622889072462`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.848170571632535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 1, {
              Complex[6.16622889072462, 0.848170571632535], 
              Complex[7.620819808285303, -0.38351205693401563`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4366494752483914`, 1.1185093819756964`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 2, {
              Complex[6.1884393186687205`, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4546094110431795`, 1.232180715817341}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654465`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 1, {
              Complex[6.166281672121115, 0.8541979088518944], 
              Complex[7.620891083164294, -0.3779828069654465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4365216830552476`, 1.1179802817936815`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 2, {
              Complex[6.188319080961654, -0.8622384184423442], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454627509646389, 1.2326743330351946`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 1, {
              Complex[6.166332453213397, 0.8601447828394869], 
              Complex[7.620959962859786, -0.37252955019570755`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4363944476850388`, 1.1174556093477817`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4546452230268507`, 1.2331635960019263`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020565`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.866013429243351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 1, {
              Complex[6.166381329020565, 0.866013429243351], 
              Complex[7.621026552047415, -0.36715016675857515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4362677581082917`, 1.1169352492338582`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 2, {
              Complex[6.188086428148008, -0.8740646059731696], 
              Complex[7.6243541862563, -1.9909998552070276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4546625605049437`, 1.2336486155651583`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729594`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 1, {
              Complex[6.166428388729594, 0.8718059882315833], 
              Complex[7.621090949234538, -0.36184262733357503`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4361416036544405`, 1.1164190909754412`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 2, {
              Complex[6.187973806370099, -0.8798624212060279], 
              Complex[7.624115410024539, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454679531079485, 1.2341294979279436`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 1, {
              Complex[6.166473716138243, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489176`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4360159739966607`, 1.1159070287342765`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 2, {
              Complex[6.187863526329917, -0.8855861488792872], 
              Complex[7.623879500326577, -2.001493177613564]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4546961434416283`, 1.234606344916894}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 1, {
              Complex[6.166517390057898, 0.8831709599557604], 
              Complex[7.621213533499526, -0.3514353849611336]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4358908591374193`, 1.1153989610423558`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 2, {
              Complex[6.187755498701223, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454712405988097, 1.2350792542307416`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4357662493946912`, 1.1148947905535163`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.011713916936429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 2, {
              Complex[6.187649639046594, -0.8968191263829126], 
              Complex[7.623415888441285, -2.011713916936429]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4547283268338027`, 1.2355483196710382`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 1, {
              Complex[6.166600069913391, 0.8942551097650244], 
              Complex[7.621328396747193, -0.3412932099060138]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4356421353888413`, 1.1143944238128878`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684229`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 2, {
              Complex[6.187545867473453, -0.9023320727684229], 
              Complex[7.623188002862294, -2.0167264965813105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4547439138238305`, 1.2360136313565446`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 1, {
              Complex[6.166639211685018, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4355185080301205`, 1.1138977710426567`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.907778333231071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 2, {
              Complex[6.187444108319425, -0.907778333231071], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4547591745448698`, 1.2364752759226942`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 1, {
              Complex[6.166676972224923, 0.9050726361762728], 
              Complex[7.621436146769792, -0.3314026397464216]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.435395358506763, 1.1134047459427392`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 2, {
              Complex[6.187344289864064, -0.9131595788587057], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4547741163360683`, 1.2369333367073783`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.32654778410681545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 1, {
              Complex[6.166713410320053, 0.9103855526005629], 
              Complex[7.6214875266561215`, -0.32654778410681545`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4352726782736545`, 1.1129152655051353`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454788746299382, 1.237387893924186}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725156]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4351504590415332`, 1.11242924984082}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9237333923619042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 2, {
              Complex[6.187150206311987, -0.9237333923619042], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548030713094076`, 1.237839024824116}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 1, {
              Complex[6.166782538502953, 0.9208274215121253], 
              Complex[7.62158560981236, -0.3170116033119908]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4350286927667162`, 1.1119466220181602`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187055815209431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 2, {
              Complex[6.187055815209431, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548170980227455`, 1.2382868038466879`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827964`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 1, {
              Complex[6.166815330974628, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827964`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4349073716413125`, 1.111467307911929}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0455329646559166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 2, {
              Complex[6.186963112364547, -0.9340656567439877], 
              Complex[7.62187048400586, -2.0455329646559166`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548308328869182`, 1.2387313027612805`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307697651672017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 1, {
              Complex[6.166847006151042, 0.9310336510892635], 
              Complex[7.621677839037961, -0.307697651672017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4347864880838939`, 1.1109912360620862`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 2, {
              Complex[6.186872042200552, -0.9391447601963726], 
              Complex[7.621658530284445, -2.0501359962584584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548442821488403`, 1.2391725907994697`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 1, {
              Complex[6.166877608777316, 0.9360518228828755], 
              Complex[7.621721890926156, -0.3031207679165942]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4346660347306186`, 1.110518337541556}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548574518629036`, 1.2396107347790484`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621764633176272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831939`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 1, {
              Complex[6.166907181313368, 0.9410150937958545], 
              Complex[7.621764633176272, -0.2985956409831939]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4345460044267682`, 1.110048545832322}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 2, {
              Complex[6.186694590646787, -0.9491355712999281], 
              Complex[7.621240595073555, -2.0591841171322502`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548703478986649`, 1.2400457992203637`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077782`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 1, {
              Complex[6.166935764077782, 0.9459247030157969], 
              Complex[7.621806111976447, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4344263902186833`, 1.1095817967091959`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548829759481685`, 1.240477846455541}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.289695999477332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 1, {
              Complex[6.166963395380895, 0.9507818469782091], 
              Complex[7.621846371329063, -0.289695999477332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4343071853460696`, 1.1091180281307043`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 2, {
              Complex[6.186523065904125, -0.9589115304824554], 
              Complex[7.620830251250195, -2.06802955861316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4548953415329267`, 1.240906936731121}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 1, {
              Complex[6.166990111648028, 0.9555876813576079], 
              Complex[7.621885453180955, -0.2853192553735131]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4341883832346762`, 1.10865718013655}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0723790886678515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 2, {
              Complex[6.186439412474037, -0.9637219085313019], 
              Complex[7.620627795708714, -2.0723790886678515`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454907450010565, 1.2413331283045885`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4340699774892993`, 1.108199194751182}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.968482055038922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.076681249790104`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 2, {
              Complex[6.1863571084384, -0.968482055038922], 
              Complex[7.620427085927699, -2.076681249790104]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454919306581168, 1.2417564775352326`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 1, {
              Complex[6.1670409360276865`, 0.9650498513977596], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4339519618871137`, 1.1077440158930363`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 2, {
              Complex[6.186276113687408, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549309162933137`, 1.242177038969738}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4338343303713053`, 1.1072915892890351`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 2, {
              Complex[6.186196389837632, -0.977855938983315], 
              Complex[7.620030720208938, -2.08514752827235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549422840498412`, 1.2425948654228762`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167088495058987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 1, {
              Complex[6.167088495058987, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4337170770449974`, 1.1068418623939866`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 2, {
              Complex[6.186117900135718, -0.9824717320942185], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549534146133523`, 1.2430100080536353`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 1, {
              Complex[6.167111124103515, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.433600196165447, 1.1063947843145436`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381358`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 2, {
              Complex[6.186040609368664, -0.9870414080668144], 
              Complex[7.619640805534111, -2.093436192381358]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549643126114553`, 1.2434225164371013`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 1, {
              Complex[6.167133022935145, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4334836821385069`, 1.105950305737408}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9915659143613826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0975162200987905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 2, {
              Complex[6.18596448378006, -0.9915659143613826], 
              Complex[7.619448165918566, -2.0975162200987905`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549749825417748`, 1.2438324386323738`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 1, {
              Complex[6.1671542175655905`, 0.9878811887189861], 
              Complex[7.6221292001073655`, -0.2559512499133877]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4333675295133188`, 1.1055083788614974`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1015545476121806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.1015545476121806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.454985428776736, 1.2442398212467847`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 1, {
              Complex[6.167174732838953, 0.9923138310722672], 
              Complex[7.62216016161569, -0.25192599017451744`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4332517329772636`, 1.1050689573338086`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 2, {
              Complex[6.185815599931938, -1.0004830605740673`], 
              Complex[7.619067332909202, -2.105552017907876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4549956555681354`, 1.244644709496656}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790115`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 1, {
              Complex[6.167194592496085, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4331362873511129`, 1.1046319961887374`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 2, {
              Complex[6.185742780764411, -1.0048774519249073`], 
              Complex[7.618879068115524, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550056670515088`, 1.2450471472648306`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6222194862862445`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 1, {
              Complex[6.167213819234736, 1.0010525529976397`], 
              Complex[7.6222194862862445`, -0.24399459426719083`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.433021187584407, 1.1041974517906232`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 2, {
              Complex[6.185671004827052, -1.0092301787755908`], 
              Complex[7.618692192411459, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455015467250297, 1.2454471771551758`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167232434765789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 1, {
              Complex[6.167232434765789, 1.0053602784840994`], 
              Complex[7.622247902016086, -0.24008689867107663`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4329064287510185`, 1.1037652817793198`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550250600798456`, 1.2458448405442555`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167250459865911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 1, {
              Complex[6.167250459865911, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4327920060449164`, 1.1033354450185966`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183224795479365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 2, {
              Complex[6.185530473503021, -1.0178138586055243`], 
              Complex[7.6183224795479365`, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550344493512177`, 1.2462401776303484`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426833`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230236377805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278824`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 1, {
              Complex[6.167267914426833, 1.0138563914775602`], 
              Complex[7.62230236377805, -0.23238378615278824`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4326779147761102`, 1.1029079015471877`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 2, {
              Complex[6.185461666136162, -1.0220463622527833`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550436387748453`, 1.2466332274799763`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613988`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399613988`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4325641503667572`, 1.1024826125323357`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1287229171405833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 2, {
              Complex[6.185393797936862, -1.0262403046082478`], 
              Complex[7.617957948303619, -2.1287229171405833`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550526319640282`, 1.2470240280720961`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 1, {
              Complex[6.167301187347678, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4324507083474423`, 1.1020595402256605`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.132455946216316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 2, {
              Complex[6.185326845280092, -1.0303964059906554`], 
              Complex[7.617777553627534, -2.132455946216316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550614324382742`, 1.2474126163400958`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263987`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263987]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4323375843536073`, 1.1016386479212323`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550700436265103`, 1.247799028211728}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263512`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 1, {
              Complex[6.167332396649198, 1.0303918810590929`], 
              Complex[7.622402440275708, -0.21740714715263512`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.43222477412213, 1.1012198999156988`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.139817765412751`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 2, {
              Complex[6.185195596375154, -1.0385978654970522`], 
              Complex[7.617420370497284, -2.139817765412751]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.45507846887015, 1.248183298647104}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 1, {
              Complex[6.1673472689966875`, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4321122734880416`, 1.1008032614703516`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143447826428835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 2, {
              Complex[6.185131257036874, -1.0426445649584832`], 
              Complex[7.617243530524916, -2.143447826428835]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455086711426038, 1.2485654616748576`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21012316187055802`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.21012316187055802`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4320000783813798`, 1.1003886987750215`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.046656107578573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1470448063535943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 2, {
              Complex[6.185067746985584, -1.046656107578573], 
              Complex[7.617067825366964, -2.1470448063535943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4550947744692648`, 1.2489455504265943`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411305`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62247040088057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 1, {
              Complex[6.167375626411305, 1.0424154437428592`], 
              Complex[7.62247040088057, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4318881848241667`, 1.0999761789136908`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 2, {
              Complex[6.1850050465299, -1.0506331187508076`], 
              Complex[7.616893231354067, -2.1506092976644986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551026610958833`, 1.2493235971697119`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0463546938072399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247211`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 1, {
              Complex[6.167389140580846, 1.0463546938072399`], 
              Complex[7.622491801676729, -0.20296890336247211`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4317765889275107`, 1.0995656698317227`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551103743254914`, 1.2496996333387003`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497568`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 1, {
              Complex[6.167402230179721, 1.0502606417889435`], 
              Complex[7.622512604505212, -0.1994389915497568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4316652868888184`, 1.099157140304622}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184881999013919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 2, {
              Complex[6.184881999013919, -1.0584859643603295`], 
              Complex[7.616547285902738, -2.1576431046649516`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551179171037256`, 1.250073689564989}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16741490837917`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 1, {
              Complex[6.16741490837917, 1.054133863773935], 
              Complex[7.622532825482896, -0.1959398257910541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.431554274989123, 1.098750559908237}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848216158545455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 2, {
              Complex[6.1848216158545455`, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551252923046565`, 1.250445795705442}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 1, {
              Complex[6.167427187845094, 1.0579749207033111`], 
              Complex[7.62255248014975, -0.1924708750021308]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.431443549590511, 1.0983458989903194`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 2, {
              Complex[6.184761970036191, -1.0662077774973113`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455132502733074, 1.2508159808695565`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 1, {
              Complex[6.167439080761726, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4313331071336575`, 1.0979431286433745`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 2, {
              Complex[6.184703044981658, -1.0700209412330008`], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551395511266987`, 1.2511842734454515`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4312229441354434`, 1.0975422206787229`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18464482465708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 2, {
              Complex[6.18464482465708, -1.07380299123558], 
              Complex[7.615867768792523, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551464401582963`, 1.251550701124701}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0693104944757823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891855`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 1, {
              Complex[6.167461753408532, 1.0693104944757823`], 
              Complex[7.622608193566829, -0.18224020664891855`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4311130571866748`, 1.0971431476017135`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07755444648018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 2, {
              Complex[6.184587293548677, -1.07755444648018], 
              Complex[7.615700350735352, -2.1746975940818936`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551531724377065`, 1.2519152909260816`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.43100344294989, 1.0967458825880272`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 2, {
              Complex[6.1845304366407206`, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551597505138094`, 1.2522780692182853`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 1, {
              Complex[6.1674830149790685`, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4308940981572327`, 1.0963503994610049`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 2, {
              Complex[6.184474239394659, -1.0849675833073058`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551661768763977`, 1.2526390617416576`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 1, {
              Complex[6.1674931425517565`, 1.0803754306555198`], 
              Complex[7.622659319428154, -0.1722636310861379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4307850196084284`, 1.0959566726699577`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 2, {
              Complex[6.184418687729288, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551724539579858`, 1.2529982936290074`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692969`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 1, {
              Complex[6.167502947734984, 1.0840058730914166`], 
              Complex[7.622675401692969, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4306762041688166`, 1.095564677269397}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551785841355553`, 1.2533557894255407`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 1, {
              Complex[6.167512439903274, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4305676487674672`, 1.095174388899148}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184309466990744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.095870069699595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 2, {
              Complex[6.184309466990744, -1.095870069699595], 
              Complex[7.614877115758211, -2.191044458598743]}, -1}, "Tooltip"]
           & ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551845697322283`, 1.253711573107958}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 1, {
              Complex[6.167521628097823, 1.0911827145610284`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.430459350395359, 1.0947857837652883`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 2, {
              Complex[6.18425577187742, -1.0994481489240888`], 
              Complex[7.614715122272779, -2.1942339326893774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4551904130188706`, 1.2540656681027629`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 1, {
              Complex[6.167530521040912, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809714`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.430351306103623, 1.0943988386218857`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 2, {
              Complex[6.184202670231409, -1.1029989218798246`], 
              Complex[7.614553976335032, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455196116215659, 1.2544180973038173`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15616767823602062`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 1, {
              Complex[6.167539127149569, 1.0982504190677966`], 
              Complex[7.622735243365228, -0.15616767823602062`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4302435130018614`, 1.0940135307534762`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 2, {
              Complex[6.184150149994408, -1.1065228138938468`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552016814935655`, 1.2547688830891832`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16754745454856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 1, {
              Complex[6.16754745454856, 1.1017444013712936`], 
              Complex[7.622749136042125, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4301359682565087`, 1.0936298379582658`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.110020240242771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.203650078201037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 2, {
              Complex[6.184098199465816, -1.110020240242771], 
              Complex[7.614234167722325, -2.203650078201037]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552071109757996`, 1.2551180473372854`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.105212347289903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1499057000473825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 1, {
              Complex[6.167555511082705, 1.105212347289903], 
              Complex[7.622762622058505, -0.1499057000473825]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.430028669089267, 1.0932477385320034`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 2, {
              Complex[6.1840468072888495`, -1.1134916064718132`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552124067391998`, 1.2554656114424274`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4299216127755858`, 1.0928672112525009`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1839959624373115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.116937308701091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 2, {
              Complex[6.1839959624373115`, -1.116937308701091], 
              Complex[7.613917575212898, -2.209804519953592]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552175708155695`, 1.2558115963296934`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167570841605691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385754`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 1, {
              Complex[6.167570841605691, 1.1120717041858357`], 
              Complex[7.622788412421261, -0.14373989214385754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.429814796643195, 1.0924882353647678`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.120357733919819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 2, {
              Complex[6.183945654203009, -1.120357733919819], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455222605192969, 1.256156022469267}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 1, {
              Complex[6.167578129986961, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.429708218070701, 1.0921107905667289`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183895872183731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 2, {
              Complex[6.183895872183731, -1.1237532602689686`], 
              Complex[7.613604090254433, -2.2158640508356973`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552275118169558`, 1.2564989098901889`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.137667361282291`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 1, {
              Complex[6.167585176308896, 1.118831548607898], 
              Complex[7.622812688125852, -0.137667361282291]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4296018744862171`, 1.091734856995499}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 2, {
              Complex[6.1838466062718, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552322925917913`, 1.2568402781935857`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 1, {
              Complex[6.167591987181104, 1.1221750717795367`], 
              Complex[7.622824279772895, -0.1346652064140491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4294957633660461`, 1.0913604152141878`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 2, {
              Complex[6.183797846643169, -1.1304710863006693`], 
              Complex[7.613293610009215, -2.221831501514857]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552369493815938`, 1.2571801465653938`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.125494802176165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1316853443892286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 1, {
              Complex[6.167598568995438, 1.125494802176165], 
              Complex[7.622835518377032, -0.1316853443892286]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4293898822334064`, 1.0909874461992093`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 2, {
              Complex[6.183749583746966, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552414840114574`, 1.2575185337885972`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1287274488853231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 1, {
              Complex[6.167604927934658, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.1287274488853231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4292842286572076`, 1.0906159313280759`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 2, {
              Complex[6.183701808295564, -1.1370936450243203`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552458982685355`, 1.2578554582550099`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167611069980751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.12579120077420317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 1, {
              Complex[6.167611069980751, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.12579120077420317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4291788002508572`, 1.0902458523676468`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.230615910262511`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 2, {
              Complex[6.183654511255059, -1.140370057894864], 
              Complex[7.612833311505916, -2.230615910262511]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552501939030753`, 1.2581909379766123`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.429073594671112, 1.0898771914628231`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 2, {
              Complex[6.183607683836199, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552543726294334`, 1.2585249905964744`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 1, {
              Complex[6.167622726364391, 1.1385425856735314`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4289686096169663`, 1.0895099311256529`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 2, {
              Complex[6.183561317485685, -1.1468548029005141`], 
              Complex[7.612529927102651, -2.236364734026167]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552584361270404`, 1.2588576333992727`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167628251731052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878580925`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543315`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 1, {
              Complex[6.167628251731052, 1.1417483803738397`], 
              Complex[7.6228866878580925`, -0.11710925302543315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4288638428285827`, 1.089144054224844}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 2, {
              Complex[6.183515403877874, -1.1500637746045623`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552623860413465`, 1.2591888833214313`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981901966`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 1, {
              Complex[6.167633582276866, 1.1449323435024115`], 
              Complex[7.622895968318212, -0.11425653981901966`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4287592920862422`, 1.088779543975654}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 2, {
              Complex[6.183469934906837, -1.1532508941175417`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455266223984726, 1.259518756960886}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676387230910485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1480947778478883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1114239791129977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 1, {
              Complex[6.1676387230910485`, 1.1480947778478883`], 
              Complex[7.622904947075774, -0.1114239791129977]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4286549552093473`, 1.088416383930148}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61207985788809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 2, {
              Complex[6.183424902678743, -1.1564164644600654`], 
              Complex[7.61207985788809, -2.2448328483902134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552699515373575`, 1.2598472705865125`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 1, {
              Complex[6.167643679104284, 1.1512359798388987`], 
              Complex[7.622913630641642, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4285508300554433`, 1.0880545579678067`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183380299504599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 2, {
              Complex[6.183380299504599, -1.1595607822888856`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552735702480744`, 1.2601744401472048`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676484550945725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1543562397232343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042397054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 1, {
              Complex[6.1676484550945725`, 1.1543562397232343`], 
              Complex[7.622922025342647, -0.10581820042397054`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4284469145192775`, 1.0876940502864643`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 2, {
              Complex[6.183336117893253, -1.1626841380761954`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552770816351803`, 1.2605002812806476`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986418`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986418`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.428343206531881, 1.0873348453935727`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 2, {
              Complex[6.183292350544733, -1.165786816282607], 
              Complex[7.611635557076614, -2.2531216616761798`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552804871872516`, 1.260824809321769}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676574853892205`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 1, {
              Complex[6.1676574853892205`, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4282397040596944`, 1.0869769280977648`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.255846023621816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 2, {
              Complex[6.183248990343843, -1.1688690955240513`], 
              Complex[7.611488694403538, -2.255846023621816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552837883639003`, 1.2611480393109107`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167661748536481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 1, {
              Complex[6.167661748536481, 1.1635941800905012`], 
              Complex[7.622945536900381, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4281364051036982`, 1.0866202835007164`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183206030354023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 2, {
              Complex[6.183206030354023, -1.1719312487328406`], 
              Complex[7.611342435457721, -2.258551532233557]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552869865965203`, 1.2614699860017096`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16766584935682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635199`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 1, {
              Complex[6.16766584935682, 1.1666334563353575`], 
              Complex[7.622952835953341, -0.09483652966635199]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4280333076985945`, 1.086264896989286}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18316346381144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2612384403025065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 2, {
              Complex[6.18316346381144, -1.1749735433132207`], 
              Complex[7.611196771510035, -2.2612384403025065`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552900832890077`, 1.2617906638687113`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.169653154844329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 1, {
              Complex[6.167669791945717, 1.169653154844329], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4279304099119927`, 1.085910754227925}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119398`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61105169403139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 2, {
              Complex[6.183121284119398, -1.1779962412914968`], 
              Complex[7.61105169403139, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455293079818457, 1.2621100871147288`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745444`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 1, {
              Complex[6.167673580276671, 1.1726535322072744`], 
              Complex[7.622966660095128, -0.08945655490745444]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4278277098436385`, 1.0855578411513438`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183079484842854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 2, {
              Complex[6.183079484842854, -1.180999599461101], 
              Complex[7.610907194686493, -2.2665574406124445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552959775358392`, 1.26242826967795}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205584`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622973195741423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08679342975340572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 1, {
              Complex[6.167677218205584, 1.1756348399245444`], 
              Complex[7.622973195741423, -0.08679342975340572]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4277252056246483`, 1.0852061439574272`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4552987777666544`, 1.2627452252388067`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676807094749195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1785973245423347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 1, {
              Complex[6.1676807094749195`, 1.1785973245423347`], 
              Complex[7.622979487241573, -0.0841479006964719]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4276228954167813`, 1.0848556491003867`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990324, -2.271804947320255]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455301481811563, 1.263060967226621}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16768405771774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 1, {
              Complex[6.16768405771774, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4275207774117316`, 1.0845063432841386`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 2, {
              Complex[6.182956307473315, -1.1898961274694764`], 
              Complex[7.610477084885046, -2.274402470753615]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553040909470076`, 1.2633755088260255`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461522`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 1, {
              Complex[6.167687266461522, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.427418849830423, 1.0841582134559016`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.192824594488806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 2, {
              Complex[6.182915968564257, -1.192824594488806], 
              Complex[7.61033481839468, -2.276982807944708]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553066064257962`, 1.263688862983181}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689577`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 1, {
              Complex[6.167690339131856, 1.1873742336662854`], 
              Complex[7.622996945557652, -0.07631462931689577]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4273171109223608`, 1.083811246800003}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182875980145687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1957349319176869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 2, {
              Complex[6.182875980145687, -1.1957349319176869`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455309029477691, 1.2640010424117867`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 1, {
              Complex[6.167693279055961, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4272155589649624`, 1.0834654307318894`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2820927986688533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.2820927986688533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553113613099649`, 1.2643120595989}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425508]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4271141922629365`, 1.0831207528923257`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.28462287927539`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 2, {
              Complex[6.182797032640057, -1.2015021263830645`], 
              Complex[7.609911224902993, -2.28462287927539]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553136031079354`, 1.264621926810569}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 1, {
              Complex[6.167698773502735, 1.1959901616082877`], 
              Complex[7.623012376610672, -0.06863176520228129]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4270130091476687`, 1.0827772011417847`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 2, {
              Complex[6.182758062802262, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455315756035508, 1.2649306560972853`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4269120079766193`, 1.0824347635550093`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.289634248396078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.289634248396078]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553178212356666`, 1.2652382592992677`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2016476203371216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813283`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 1, {
              Complex[6.167703774577616, 1.2016476203371216`], 
              Complex[7.623021595813283, -0.06359063896214613]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.42681118713276, 1.0820934284157555`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553197998309857`, 1.2655447480515745`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4267105450239974`, 1.0817531842116899`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.212828715220383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432073`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 2, {
              Complex[6.182643106997765, -1.212828715220383], 
              Complex[7.609353652021762, -2.294581899432073]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455321692924102, 1.2658501337890655`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478145`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 1, {
              Complex[6.167708305685528, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478145]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4266100800826318`, 1.0814140196294526`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 2, {
              Complex[6.182605423099422, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455323501598187, 1.2661544277512031`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2100082561816607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 1, {
              Complex[6.1677104019634195`, 1.2100082561816607`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.426509790764835, 1.081075923549873}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 2, {
              Complex[6.182568048561962, -1.2183914626776442`], 
              Complex[7.6090778393267975`, -2.2994673862275175`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553252269173926`, 1.2664576409867079`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677123889507754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 1, {
              Complex[6.1677123889507754`, 1.2127624573020028`], 
              Complex[7.623037615868168, -0.05369518368470517]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4264096755501212`, 1.080738885043328}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553268699272988`, 1.2667597843580762`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 1, {
              Complex[6.167714269226695, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4263097329408545`, 1.0804028933652483`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182494209128501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 2, {
              Complex[6.182494209128501, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553284316553357`, 1.2670608685459563`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.218223004527287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 1, {
              Complex[6.167716045300302, 1.218223004527287], 
              Complex[7.623044476955637, -0.048837864018669234`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4262099614617614`, 1.0800679379517526`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 2, {
              Complex[6.182457735262817, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553299131112025`, 1.2673609040533937`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 1, {
              Complex[6.167717719612998, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4261103596594538`, 1.079734008415422}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 2, {
              Complex[6.1824215528129, -1.2293237938391437`], 
              Complex[7.608531912472354, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553313152872667`, 1.2676599012099543`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540653`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 1, {
              Complex[6.167719294540653, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4260109261019673`, 1.079401094541195}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3114188284924206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 2, {
              Complex[6.182385657532067, -1.2320177339512257`], 
              Complex[7.608396583634034, -2.3114188284924206`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553326391589598`, 1.2679578701757186`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.226296975161037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 1, {
              Complex[6.167720772395696, 1.226296975161037], 
              Complex[7.623053411554656, -0.041660895014681475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4259116593783145`, 1.079069186282386}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 2, {
              Complex[6.182350045264077, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553338856851545`, 1.2682548209451623`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 1, {
              Complex[6.16772215542913, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.039296961870488915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4258125580980494`, 1.0787382737568234`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 2, {
              Complex[6.182314711940598, -1.2373599104404132`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553350558085407`, 1.2685507633509225`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032507`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 1, {
              Complex[6.167723445832482, 1.2316038141805974`], 
              Complex[7.623058501641022, -0.03694694917032507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4257136208908425`, 1.0784083472430945`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553361504559745`, 1.268845707067453}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 1, {
              Complex[6.167724645739662, 1.2342350105444315`], 
              Complex[7.623060796195637, -0.03461069652302155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4256148464060636`, 1.0780793971769096`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723058`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 2, {
              Complex[6.182244866278791, -1.2426423085461484`], 
              Complex[7.607859712684855, -2.320721705723058]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553371705388412`, 1.2691396616145783`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048269`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 1, {
              Complex[6.167725757228776, 1.2368516153040956`], 
              Complex[7.6230629277676165`, -0.03228804631048269]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.425516233312382, 1.0777514141475626`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 2, {
              Complex[6.1822103462217495`, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553381169533866`, 1.2694326363609372`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726782323851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.239453792737311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 1, {
              Complex[6.167726782323851, 1.239453792737311], 
              Complex[7.623064899277237, -0.029978843623626066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4254177802973773`, 1.0774243888944979`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 2, {
              Complex[6.182176089667306, -1.2478662783795624`], 
              Complex[7.607593869964683, -2.3252906672740603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553389905810512`, 1.2697246405273381`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230667135775585`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 1, {
              Complex[6.167727722996507, 1.2420417043271579`], 
              Complex[7.6230667135775585`, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.425319486067153, 1.0770983123039743`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.327555074323918]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553397922887914`, 1.2700156831900125`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728581167581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 1, {
              Complex[6.167728581167581, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427072]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4252213493459651`, 1.0767731754058247`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1821083524852725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 2, {
              Complex[6.1821083524852725`, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553405229293899`, 1.2703057732837766`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2471753623160462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773041`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 1, {
              Complex[6.167729358708657, 1.2471753623160462`], 
              Complex[7.623069881638046, -0.02313041096773041]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4251233688758635`, 1.076448969370303}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 2, {
              Complex[6.182074864751301, -1.2555955212603065`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553411833417669`, 1.270594919605111}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 1, {
              Complex[6.167730057443583, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333081253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4250255434163357`, 1.0761256855050252`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 2, {
              Complex[6.182041626303248, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553417743512735`, 1.2708831308151454`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01862930319811857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 1, {
              Complex[6.167730679149904, 1.2522538276170267`], 
              Complex[7.623072453501178, -0.01862930319811857]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.424927871743964, 1.0758033152519937`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553422967699756`, 1.271170415442569}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4248303526520931`, 1.0754818501847019`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.338682294675321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 2, {
              Complex[6.181975883820567, -1.2632004444906193`], 
              Complex[7.606806236472661, -2.338682294675321]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553427513969417`, 1.2714567818864555`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133222896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4247329849504975`, 1.0751612820053194`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 2, {
              Complex[6.1819433732291715`, -1.2657084915461236`], 
              Complex[7.606676358179669, -2.340869773551443]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553431390185179`, 1.2717422384190147`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207093`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278048698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 1, {
              Complex[6.167732099207093, 1.2597706481409658`], 
              Complex[7.623075238225612, -0.011971590278048698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4246357674650718`, 1.0748416025419572`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 2, {
              Complex[6.181911098806735, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553434604085804`, 1.2720267931882643`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169417`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 1, {
              Complex[6.167732429696165, 1.26224993121657], 
              Complex[7.623075890104745, -0.00977686197169417]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4245386990375077`, 1.0745228037460033`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181879057432655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 2, {
              Complex[6.181879057432655, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553437163288194`, 1.2723104542206367`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725731, -0.007594168249853941]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.424441778525007, 1.0742048776895323`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 2, {
              Complex[6.181847246046555, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455343907528963, 1.2725932294235092`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230767933656285`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 1, {
              Complex[6.167732885836666, 1.2671698491615646`], 
              Complex[7.6230767933656285`, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4243450047999695`, 1.0738878165627845`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 2, {
              Complex[6.181815661646744, -1.2756098611309443`], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553440347470499`, 1.2728751265876719`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 1, {
              Complex[6.167733014505245, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4242483767497216`, 1.0735716126717125`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181784301288738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60603267803846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 2, {
              Complex[6.181784301288738, -1.2780531889506412`], 
              Complex[7.60603267803846, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455344098709649, 1.2731561533897247`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565681`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 1, {
              Complex[6.167733078856031, 1.272039137007607], 
              Complex[7.623077177565681, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4241518932762212`, 1.07325625843559}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553441001321075`, 1.2734363173944174`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733080307031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230771804391395`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0010188070462166473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 1, {
              Complex[6.167733080307031, 1.2744551244406341`], 
              Complex[7.6230771804391395`, 0.0010188070462166473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4240555532957928`, 1.0729417463846898`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455344039718769, 1.2737156260569238`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985724435`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 1, {
              Complex[6.167733020241881, 1.2768588459554964`], 
              Complex[7.62307705996065, 0.0031432198985724435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4239593557388555`, 1.0726280691580177`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 2, {
              Complex[6.181691535849002, -1.2853084672867792`], 
              Complex[7.605650891587858, -2.3579365364447966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455343918163203, 1.2739940867250583`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210561]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4238632995496614`, 1.0723152195011063`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 2, {
              Complex[6.181661043308228, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455343736148415, 1.2742717066414344`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 1, {
              Complex[6.167732720931719, 1.2816299944237617`], 
              Complex[7.623076457080134, 0.007358287782327438]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4237673836860494`, 1.0720031902638683`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 2, {
              Complex[6.181630760896248, -1.2900843444730696`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553434943470616`, 1.2745484929455693`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 1, {
              Complex[6.167732484290828, 1.2839976681063676`], 
              Complex[7.623075978637889, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4236716071191817`, 1.0716919743985007`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 2, {
              Complex[6.181600685983191, -1.2924543639191772`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553431934216576`, 1.274824452675933}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4235759688333125`, 1.0713815649574496`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 2, {
              Complex[6.181570815987222, -1.2948125987358026`], 
              Complex[7.605146784820534, -2.3661941636932524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455342834024769, 1.2750995927719448`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 1, {
              Complex[6.167731843316621, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4234804678255462`, 1.0710719550914203`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 2, {
              Complex[6.181541148373396, -1.2971591677080392`], 
              Complex[7.605021616198942, -2.3682311227994592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553424167992217`, 1.2753739200759222`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205368`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205368, 0.01565660770491158]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4233851031056075`, 1.0707631380474412`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3702573258609094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 2, {
              Complex[6.18151168065253, -1.2994941878134683`], 
              Complex[7.604896783758138, -2.3702573258609094`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455341942378276, 1.2756474413349752`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551784`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4232898736956134`, 1.0704551071669757`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455341411385833, 1.2759201632028618`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.423194778629854, 1.0701478558840805`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1814533351552905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3041300405165681`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 2, {
              Complex[6.1814533351552905`, -1.3041300405165681`], 
              Complex[7.604648113785144, -2.3742778964006486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553408244365968`, 1.2761920922417869`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 1, {
              Complex[6.167729923927074, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138642`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4230998169545768`, 1.0698413777236149`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 2, {
              Complex[6.181424452619748, -1.3064310983584508`], 
              Complex[7.604524269574324, -2.3762724760820655`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455340182136262, 1.2764632349241656`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4230049877277704`, 1.0695356662994848`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 2, {
              Complex[6.181395760456799, -1.3087210578909674`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553394850816883`, 1.2767335976343386`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.302524997762607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128268475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 1, {
              Complex[6.167728663570656, 1.302524997762607], 
              Complex[7.623068148652344, 0.025791400128268475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4229102900189678`, 1.0692307153129395`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 2, {
              Complex[6.181367256390405, -1.3110000275879246`], 
              Complex[7.604277546409373, -2.380230742900864]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553387338610653`, 1.2770031866702451`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834461`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 1, {
              Complex[6.167727961973396, 1.3047908452057129`], 
              Complex[7.623066695834461, 0.02778765853546761]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4228157229090372`, 1.0689265185509051`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3821946328738326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 2, {
              Complex[6.181338938184203, -1.3132681143229272`], 
              Complex[7.604154661093241, -2.3821946328738326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553379290540767`, 1.2772720082450588`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772721412525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.02977391807145811`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 1, {
              Complex[6.16772721412525, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145811]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4227212854899878`, 1.0686230698843617`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1813108036406295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 2, {
              Complex[6.1813108036406295`, -1.3155254234009868`], 
              Complex[7.604032089130617, -2.3841484932853487`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455337071232069, 1.2775400684887797`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 1, {
              Complex[6.167726421018415, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4226269768647788`, 1.0683203632667537`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.317772058589321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 2, {
              Complex[6.181282850600008, -1.317772058589321], 
              Complex[7.603909827464786, -2.3860924218560746`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553361609581963`, 1.2778073734497903`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 1, {
              Complex[6.167725583622502, 1.311524202717575], 
              Complex[7.623061744580699, 0.03371682926778467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4225327961471246`, 1.0680183927324483`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553351987875864`, 1.2780739290963747`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 1, {
              Complex[6.16772470288514, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4224387424613223`, 1.0677171523952222`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3222337148562802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 2, {
              Complex[6.181227480573278, -1.3222337148562802`], 
              Complex[7.6036662230346, -2.3899508672515024`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553341852674817`, 1.2783397413182003`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.315960638428035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983468`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 1, {
              Complex[6.167723779732553, 1.315960638428035], 
              Complex[7.623057965000035, 0.03762089710983468]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4223448149420619`, 1.0674166364467885`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 2, {
              Complex[6.181200059449697, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553331209373912`, 1.2786048159277634`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070128`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 1, {
              Complex[6.167722815070128, 1.3181634132423614`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.422251012734254, 1.0671168391553594`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181172811552509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3266538836292927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.393770722784652`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 2, {
              Complex[6.181172811552509, -1.3266538836292927`], 
              Complex[7.6034238242867636`, -2.393770722784652]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553320063292323`, 1.2788691586618044`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397212`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 1, {
              Complex[6.167721809782957, 1.3203560217257766`], 
              Complex[7.62305381611219, 0.04148686306397212]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4221573349928565`, 1.0668177548642395`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 2, {
              Complex[6.181145734899094, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455330841967467, 1.2791327751826873`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 1, {
              Complex[6.167720764736373, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4220637808827068`, 1.0665193779904545`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18111882753992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 2, {
              Complex[6.18111882753992, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.455329628369246, 1.2793956710797434`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.324711118586218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 1, {
              Complex[6.167719680776454, 1.324711118586218], 
              Complex[7.6230493091457, 0.045315447506474565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.4219703495783602`, 1.0662217030234133`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181092087557802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 2, {
              Complex[6.181092087557802, -1.3332080430544784`], 
              Complex[7.603062437136163, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553283660445337`, 1.2796578518705943`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.047215941208410626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.421877040263923, 1.065924724523595}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.401297572319007`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.401297572319007]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{-1.4553270554962447`, 1.2799193230024304`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{-1.421783852132895, 1.065628437121276}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181039102213561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.337527848075708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 2, {
              Complex[6.181039102213561, -1.337527848075708], 
              Complex[7.602822954346457, -2.403156285196984]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.639807225226917, 1.1700279500517288`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487388491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.4787533558490455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1631402225643404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[8.118560581075963, 0.006887727487388491], 
              Complex[6.4787533558490455`, -1.1631402225643404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7398781404228012`, 1.1829054568301065`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.539894192888829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013243170301698895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[10.539894192888829`, -0.013243170301698895`], 
              Complex[8.800016052466027, -1.1961486271318054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6404219513334717`, 1.1700984290050047`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368874`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163055469019636`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[8.162580737731862, 0.007042959985368874], 
              Complex[6.52215878639839, -1.163055469019636]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7394144926409398`, 1.1828156904519647`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269002`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01350987671532385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.755092274628062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[10.494506767269002`, -0.01350987671532385], 
              Complex[8.755092274628062, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6410446064452129`, 1.1701703920092204`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629725487625657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[8.198987977866881, 0.007197843246654785], 
              Complex[6.557943371421669, -1.1629725487625657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7389407153739764`, 1.1827237771013546`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039064`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[10.457042457039064`, -0.013751044852512901`], 
              Complex[8.718101741665087, -1.1964748219538675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6416750690250659`, 1.1702438309113217`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.23100514788576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961003822`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162888878950318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[8.23100514788576, 0.007354951961003822], 
              Complex[6.589330078860694, -1.162888878950318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7384573367410063`, 1.1826298514755766`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[10.42414741707873, -0.013979869598457921`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6423133731648394`, 1.1703187646377389`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[8.260098904258959, 0.007515591774090758], 
              Complex[6.61778553109412, -1.1628031728636479`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7379645778182866`, 1.1825339738020835`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.394295711708596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014202465960738788`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[10.394295711708596`, -0.014202465960738788`], 
              Complex[8.656331133890308, -1.1967364397628222`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.642959637221158, 1.1703952273655904`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076806282899812735`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756091`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[8.287084479515974, 0.0076806282899812735`], 
              Complex[6.644124842294815, -1.1627145990756091`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7374624995014827`, 1.1824361653396913`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660349779`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[10.366639367283947`, -0.014422357660349779`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.643614035588044, 1.1704732639588975`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002843`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160531302`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983663`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[8.312471288002843, 0.007850743160531302], 
              Complex[6.668857252414799, -1.1626225207983663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7369510620844812`, 1.1823364227607005`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121435745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[10.340648661463618`, -0.014641876121435745`], 
              Complex[8.603697599379137, -1.1969782988821362`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6442767855981126`, 1.1705529279620166`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972045`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.692326779227161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[8.336603564825273, 0.008026538528972045], 
              Complex[6.692326779227161, -1.1625263894330446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7364301541108498`, 1.1822347250851228`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01486272923227436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[10.315965756037766`, -0.01486272923227436], 
              Complex[8.579535601926915, -1.1970974543173973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6449481410772144`, 1.1706342807319507`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694592`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338763303`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931875`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[8.359727508694592, 0.008208588338763303], 
              Complex[6.7147793676173775`, -1.1624256923931875`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.735899607733313, 1.182131037333787}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.292334825045389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01508627394224807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[10.292334825045389`, -0.01508627394224807], 
              Complex[8.556435217312076, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6456283893157189`, 1.1707173911723616`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836869`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[8.382027043209192, 0.008397467701836869], 
              Complex[6.736398653893473, -1.1623199234705248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7353592072201784`, 1.1820253125041498`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015313663264596185`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[10.269564843263957`, -0.015313663264596185`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.64631785003024, 1.1708023358369288`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[8.40364445944282, 0.008593772293729816], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7348086935710791`, 1.1819174925824534`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[10.247508108692934`, -0.015545933419028875`], 
              Complex[8.512699415121855, -1.1974634260014823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.64701687562862, 1.1708891992948665`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053827`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[8.424693095053827, 0.008798133065178966], 
              Complex[6.777676219425207, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7342477667008755`, 1.1818075089410551`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015784060035231827`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[10.226047052260428`, -0.015784060035231827`], 
              Complex[8.491799285559553, -1.1975915689762868`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.647725852432534, 1.1709780747102123`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909081513`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619668458011307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[8.445265519754589, 0.009011228909081513], 
              Complex[6.797539667322055, -1.1619668458011307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.733676085957407, 1.1816952823007194`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[10.20508572371207, -0.01602899750358715], 
              Complex[8.471409637754663, -1.1977242798043064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6484452026874121`, 1.171069064618027}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[8.465439042444201, 0.009233798770935048], 
              Complex[6.816993839756788, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7330932693868024`, 1.181580722350881}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805177`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[10.184544064614808`, -0.016281708942805177`], 
              Complex[8.451450795228006, -1.1978624312936863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6491753872892059`, 1.1711622819000642`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547499`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[8.485279549606197, 0.009466654168547499], 
              Complex[6.836104162316991, -1.1616956277315165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7324988919652515`, 1.1814637270716992`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920574`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[10.164353917920574`, -0.016543191071888966`], 
              Complex[8.431855025955322, -1.1980069181435882`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6499169092213348`, 1.1712578509767424`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[8.504844265661474, 0.009710692858210825], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7318924828982654`, 1.1813441817705232`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[10.144456159495562`, -0.016814496662831885`], 
              Complex[8.412563676597296, -1.198158678433355]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.650670317741964, 1.1713559092447527`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7312735220093824`, 1.1812219578228556`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[10.124798576239256`, -0.017096756417673765`], 
              Complex[8.393525054229872, -1.1983187142405294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.651436213401567, 1.1714566088024068`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199157`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612201711252075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[8.543343682297632, 0.010236437677199157`], 
              Complex[6.891907468896066, -1.1612201711252075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7306414351805275`, 1.181096911088837}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[10.105334252708916`, -0.017391201699304238`], 
              Complex[8.374692817528388, -1.198488112788141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6522152540098207`, 1.1715601185194693`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036428395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.910150364313235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610395954830408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[8.562365618323057, 0.010520523036428395`], 
              Complex[6.910150364313235, -1.1610395954830408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7299955887543268`, 1.1809688799576648`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[10.086020309962356`, -0.017699189379580448`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6530081617135672`, 1.1716666265261573`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01082059684449242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.928280270084161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160846029681665`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[8.581288431797729, 0.01082059684449242], 
              Complex[6.928280270084161, -1.160846029681665]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.729335282757543, 1.1808376829517861`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.066816890576662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018022230071644284`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[10.066816890576662`, -0.018022230071644284`], 
              Complex[8.33748160781912, -1.1988599130234303`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6538157313980222`, 1.1717763432189272`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521388`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836947`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240902`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[8.600148900521388, 0.011138282794836947`], 
              Complex[6.946333169123366, -1.1606380604240902`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7286597427486416`, 1.1807031157979517`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624233`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[10.047686315383556`, -0.018362021154624233`], 
              Complex[8.319026572634915, -1.1990651369525758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6546388406859052`, 1.171889504910906}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775214`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[8.618982457304563, 0.011475439606775214`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7279681100260285`, 1.1805649478407967`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[10.02859235757786, -0.018720486277070795`], 
              Complex[8.300624247551832, -1.1992854341178676`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6554784618891856`, 1.1720063782953085`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463423`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[8.637823823216573, 0.011834207760463423`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7272594298507222`, 1.1804229176332028`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[10.009499592627154`, -0.019099823463292597`], 
              Complex[8.282240162776432, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6563356763727834`, 1.1721272659455275`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01221706786722248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159910198078305`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[8.656707602013043, 0.01221706786722248], 
              Complex[7.000371925640259, -1.159910198078305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7265326372305287`, 1.1802767274817774`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.99037279023362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[9.99037279023362, -0.019502564592186845`], 
              Complex[8.263840153003091, -1.1997792920739643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6572116919289983`, 1.172252513152149}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[8.675668864524779, 0.012626914319474904`], 
              Complex[7.018457172595781, -1.1596255988326742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.725786539671919, 1.180126036648719}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.97117631884134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[9.97117631884134, -0.019931649951741095`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.658107863949964, 1.1723825165049409`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598734`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229434393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[8.694743750598734, 0.013067149229434393`], 
              Complex[7.036635886648769, -1.1593153672755065`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7250197961161677`, 1.1799704528032402`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[9.951873534557844, -0.020390522922278616`], 
              Complex[8.226853738441676, -1.2003609757255187`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6590257214441, 1.1725177347818594`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645187473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0549443961207245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1589759311366719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[8.713970117564823, 0.013541803645187473`], 
              Complex[7.0549443961207245`, -1.1589759311366719`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7242308910168733`, 1.1798095211614357`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02088325181027976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[9.932426125107996, -0.02088325181027976], 
              Complex[8.208195234091123, -1.2006927729717154`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6599669993028283`, 1.172658702931096}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586030069798183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[8.733388268345111, 0.014055695951277604`], 
              Complex[7.073421269042282, -1.1586030069798183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.723418102154984, 1.1796427105293465`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765244935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[9.912793375391814, -0.021414688765244935`], 
              Complex[8.18937527323683, -1.2010573992945914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.66093367873346, 1.1728060502638153`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299529`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[8.753041799848585, 0.014614641743299529`], 
              Complex[7.092108121115126, -1.1581914085205158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7225794602774194`, 1.1794693951321644`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691886`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[9.892931313762208, -0.021990680088691886`], 
              Complex[8.170351853484789, -1.2014600752208562`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.661928038507105, 1.1729605244765766`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.772978624412278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[8.772978624412278, 0.01522573618198167], 
              Complex[7.111050585905174, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7217126979120094`, 1.1792888306110798`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057525`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[9.872791686074075, -0.022618348956057525`], 
              Complex[8.151078988162066, -1.2019071795671374`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6629527207437356`, 1.1731230238972747`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[8.793252235841301, 0.01589774035976075], 
              Complex[7.130299515097565, -1.157225283537514]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7208151836379026`, 1.17910012179434}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.023306482096512558`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.131505502166522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908525`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[9.852320685804425, -0.023306482096512558`], 
              Complex[8.131505502166522, -1.2024066038908525`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6640108165591583`, 1.1732946415763739`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819532`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[8.813923320576674, 0.016641620135819532`], 
              Complex[7.149912504017516, -1.1566530214405542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7198838364878077`, 1.1789021786210783`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[9.831457339597339, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.665105979343317, 1.1734767268460082`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[8.835061859626233, 0.017471313877762313`], 
              Complex[7.169955880282916, -1.1560054129682458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7189150127134505`, 1.1786936545956053`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[9.81013140250469, -0.02491106937082753], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6662425772567686`, 1.1736709733336637`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322075`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.018404853311322075`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7179043533282357`, 1.1784728587856865`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204332394000482`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479544], 
              Complex[8.070356192382524, -1.204332394000482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6674259026467528`, 1.1738795482784525`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629636`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203824108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629636, 0.019466046203824108`], 
              Complex[7.211659694982883, -1.1544135020746282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7168465747262254`, 1.178237626516978}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.026935292658188545`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.026935292658188545`], 
              Complex[8.048899928737553, -1.2051729191751666`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6686624661521339`, 1.1741052886346302`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549182`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496538995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549182, 0.020687085496538995`], 
              Complex[7.233525786397049, -1.153418203138091]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7157351746087366`, 1.177985123279133}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095144, -0.028170551750252903`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.66996042033411, 1.1743520096788436`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073539966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053036`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442705, 0.022112751073539966`], 
              Complex[7.256246121108595, -1.1522392586053036`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7145620083820834`, 1.1777115361272346`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631426`], 
              Complex[8.003719151417389, -1.2073216443878658`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6713301874647748`, 1.1746250124900501`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.02380748722011572], 
              Complex[7.279999873987634, -1.1508175252699346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7133166613947477`, 1.177411566209715}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427964, -0.03131842125415461], 
              Complex[7.979674588033217, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6727854194519636`, 1.174931963813554}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308562`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584034504`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308562, 0.025867986584034504`], 
              Complex[7.305022131856599, -1.1490639772295197`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7119854890358746`, 1.1770775489114365`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03339219715471052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210469746066147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.03339219715471052], 
              Complex[7.954365525461626, -1.210469746066147]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6743445142390858`, 1.1752845235948635`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768344`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632702298`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.331631661529259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468374259621612`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768344, 0.028447097632702298`], 
              Complex[7.331631661529259, -1.1468374259621612`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7105501003566845`, 1.17669782632629}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.03598429729320677], 
              Complex[7.927473033284, -1.2126821236194967`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6760330782287778`, 1.1757016080477805`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964629, 0.03180315785237416], 
              Complex[7.360277468735851, -1.1438984501954061`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7089848956661684`, 1.1762534841949988`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187375584`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187375584`], 
              Complex[7.89854795260484, -1.2156065553823743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.677887917009857, 1.1762166309510627`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.06950674944049`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155713`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.06950674944049, 0.036413030935491295`], 
              Complex[7.391618832430633, -1.1398036000155713`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7072530758218287`, 1.1757111106138287`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380089758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670558, -0.04397539380089758], 
              Complex[7.866930860848728, -1.2196865044147263`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6799625405777951`, 1.1768957422124684`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645221], 
              Complex[7.426654831776879, -1.1336280195460162`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7053011370254079`, 1.175004557475467}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000957, -0.05084228149319718], 
              Complex[7.831622543975549, -1.2258468389686643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.682324489011321, 1.1778903728540755`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732279], 
              Complex[7.466802670715167, -1.1231222909767526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7030615451611553`, 1.1739823954882145`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.49426721635719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.791205671196036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.49426721635719, -0.06235459303258733], 
              Complex[7.791205671196036, -1.2363369885208018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6849389425874308`, 1.179575892857512}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0773435944124776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.0773435944124776], 
              Complex[7.512359287571745, -1.1022322984450343`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.700569125694485, 1.1722692563349013`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414638, -0.08494182361233307], 
              Complex[7.745383184720152, -1.2572110799472342`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687074386199182, 1.1823285296727977`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647737`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647737, 0.11902724764149768`], 
              Complex[7.552491023448555, -1.0633012820313001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6985553992667917`, 1.169488914167869}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.126636969409872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055128, -0.126636969409872], 
              Complex[7.704988630788337, -1.2961258835777412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6880492080497373`, 1.1852528928822337`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996514074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5742681397347305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0191412329170928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784467, 0.16611165996514074`], 
              Complex[7.5742681397347305`, -1.0191412329170928`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6977019830130229`, 1.1665367609485928`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1737326571346823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650828, -0.1737326571346823], 
              Complex[7.682951641637805, -1.3402694180832753`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.688426221374999, 1.1877411805488003`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.2069539217818482], 
              Complex[7.58536879774568, -0.980787258766952]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6974460688498039`, 1.1640206001025495`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2145859850323753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.378606585134925`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240865, -0.2145859850323753], 
              Complex[7.671593955391062, -1.378606585134925]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6885796331805099`, 1.189863773356467}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28057052908999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59199089590948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.28057052908999, 0.24191392575349593`], 
              Complex[7.59199089590948, -0.9479498476029711]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6974134547484927`, 1.1618700523819143`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.24955685318475315`], 
              Complex[7.664717578441821, -1.4114269055666673`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6886370363669856`, 1.1917286904985063`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28508522547646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.28508522547646, 0.27256109297706876`], 
              Complex[7.596448189109473, -0.9191675975214375]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.697476552618887, 1.1599770999800387`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280214689712569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926077`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.280214689712569], 
              Complex[7.660008665723722, -1.4401917896926077`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6886471723889194`, 1.1934063028976165`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141116`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835051], 
              Complex[7.599694877117055, -0.8934053728141116]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6975866256592023`, 1.1582713733139203`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.354099557583266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076650079025534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6565129319240635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4659363812164738`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.354099557583266, -0.3076650079025534], 
              Complex[7.6565129319240635`, -1.4659363812164738`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6886318239625453`, 1.1949415431340555`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790604`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242765855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.869977650706397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790604, 0.32496389242765855`], 
              Complex[7.602190099828059, -0.869977650706397]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6977218956560869`, 1.1567079410984842`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581294, -0.3326382694231205], 
              Complex[7.653771155925207, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6886019457298747`, 1.1963644144601786`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3479481691887596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.3479481691887596], 
              Complex[7.604182742222917, -0.848416245271419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.697871412328034, 1.1552568013342808`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34940578787805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.651534375550015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.510889470782688`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.34940578787805, -0.3556326694484073], 
              Complex[7.651534375550015, -1.510889470782688]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6885635388702853`, 1.1976959087554475`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285959, 0.36930769700429517`], 
              Complex[7.605820205415673, -0.8283882117511524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.698029178720739, 1.1538969633545817`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3770021503134534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.3770021503134534], 
              Complex[7.649655116243796, -1.530899113668035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6885201041356674`, 1.1989513125919395`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.389303350769084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.389303350769084], 
              Complex[7.607195850080812, -0.8096479618228555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.69819169817842, 1.1526131417618155`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579122, -0.39700759233314564`], 
              Complex[7.648039947400702, -1.5496207340949613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6884737814803772`, 1.2001421329007407`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 1, {
              Complex[9.296845766278874, 0.40813349152982553`], 
              Complex[7.608371984798496, -0.7920086413709151]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.698356834719948, 1.1513938307630038`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4158473617147172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 2, {
              Complex[9.344983328511988, -0.4158473617147172], 
              Complex[7.6466264937920405`, -1.5672411924777212`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6884259255350813`, 1.2012772723139358`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29781789372527`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 1, {
              Complex[9.29781789372527, 0.4259529280523638], 
              Complex[7.60939196819019, -0.7753243442615719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6985232375706762`, 1.1502301288294823`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 2, {
              Complex[9.343894570793292, -0.4336762721416339], 
              Complex[7.6453713332226165`, -1.5839064009711161`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.688377416105138, 1.2023637780263299`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4428851530791995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 1, {
              Complex[9.298664434058159, 0.4428851530791995], 
              Complex[7.610287017953022, -0.7594786249471305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6986900306693893`, 1.1491149898367787`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 2, {
              Complex[9.342933217974055, -0.4506178210463807], 
              Complex[7.644243187304666, -1.5997328108831594`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6883288349277574`, 1.2034073372264218`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4590305218050602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 1, {
              Complex[9.299409090344204, 0.4590305218050602], 
              Complex[7.611080255416446, -0.7443768154213616]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6988566359161346`, 1.1480427276351444`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34207551264073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46677236810008255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.643218876724594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6148150957352267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 2, {
              Complex[9.34207551264073, -0.46677236810008255`], 
              Complex[7.643218876724594, -1.6148150957352267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6882805708297839`, 1.2044126157251178`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319841`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 1, {
              Complex[9.300069789499112, 0.4744718898931336], 
              Complex[7.611789218669329, -0.7299407258319841]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6990226680191454`, 1.147008677422251}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 2, {
              Complex[9.341303475971884, -0.48222277324174195`], 
              Complex[7.642280807952738, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6882328846304457`, 1.2053834960418552`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6991878695965157`, 1.1460089576583916`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 2, {
              Complex[9.340603220742913, -0.49703839004290706`], 
              Complex[7.641415351146397, -1.6430473477012988`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6881859504584624`, 1.2063232489680593`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 1, {
              Complex[9.301191700128847, 0.5035094122855177], 
              Complex[7.613005749670385, -0.7028138366825415]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6993520698632367`, 1.1450402985042778`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 2, {
              Complex[9.339963828630122, -0.5112779620899688], 
              Complex[7.640611758766885, -1.6563182605942466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6881398827557619`, 1.2072346598860024`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 1, {
              Complex[9.301672454837957, 0.5172145811965807], 
              Complex[7.613532572082195, -0.6900200786894217]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6995151576314196`, 1.1440999155033493`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 2, {
              Complex[9.339376581853779, -0.5249917680556032], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6880947543280014`, 1.2081201235569359`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.530437541999259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 1, {
              Complex[9.302109645838716, 0.530437541999259], 
              Complex[7.614014891510713, -0.6776825815576768]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6996770632634668`, 1.1431854147947562`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 2, {
              Complex[9.338834424339026, -0.5382232399630631], 
              Complex[7.63915736107556, -1.681408654757819]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6880506086458187`, 1.2089817164561358`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.665765598769965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 1, {
              Complex[9.302509011886752, 0.5432161176861708], 
              Complex[7.614458403240932, -0.665765598769965]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.699837746374314, 1.1422947207793568`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 2, {
              Complex[9.338331575639636, -0.5510102042411116], 
              Complex[7.638493829265323, -1.6933049250204684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6880074683685526`, 1.2098212528084629`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.654237761160508`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 1, {
              Complex[9.302875299750397, 0.5555834916479547], 
              Complex[7.6148678313818445`, -0.654237761160508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.6999971873110162`, 1.1414260200851492`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637866061694656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 2, {
              Complex[9.337863249005673, -0.5633858475760005], 
              Complex[7.637866061694656, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6879653413354445`, 1.2106403285857694`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.567568969325976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 1, {
              Complex[9.303212473521276, 0.567568969325976], 
              Complex[7.615247132185832, -0.6430713592597934]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.700155381164671, 1.140577717570795}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687924224828551, 1.211440356474314}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 1, {
              Complex[9.303523872448524, 0.5791985860418384], 
              Complex[7.615599647619973, -0.6322417704324756]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7003123335104553`, 1.139748401359092}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.587017135587317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63670244496346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.726765536946409`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 2, {
              Complex[9.337014778473916, -0.587017135587317], 
              Complex[7.63670244496346, -1.726765536946409]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6878841086374778`, 1.2122225939728501`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30381233160232`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.590495597339949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 1, {
              Complex[9.30381233160232, 0.590495597339949], 
              Complex[7.615928222964842, -0.6217269966329011]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.700468057345703, 1.138936814739719}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 2, {
              Complex[9.336628388028364, -0.5983220770848237], 
              Complex[7.636160330682661, -1.7372588918245426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6878449772817838`, 1.2129881661979554`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61623529799522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 1, {
              Complex[9.304080275277004, 0.6014808784641326], 
              Complex[7.61623529799522, -0.6115072877338228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.700622570870154, 1.1381418333647062`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133891`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 2, {
              Complex[9.336263812328987, -0.6093151811133891], 
              Complex[7.635641241458833, -1.7474570144780952`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6878068116338196`, 1.2137380845635792`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 1, {
              Complex[9.304329790117844, 0.6121732527479823], 
              Complex[7.616522978484024, -0.6015648318155971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7007758958656332`, 1.1373624465696326`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.757377720274465`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 2, {
              Complex[9.335918932011362, -0.6200152737048321], 
              Complex[7.635143036145728, -1.757377720274465]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687769590110115, 1.2144732622100347`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304562682970772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.591883498403893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 1, {
              Complex[9.304562682970772, 0.6225897638061416], 
              Complex[7.616793092860657, -0.591883498403893]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7009280565070715`, 1.136597741945355}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 2, {
              Complex[9.335591908744412, -0.6304394010704697], 
              Complex[7.63466385223734, -1.7670371430158245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6877332895491859`, 1.2151945268467639`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 1, {
              Complex[9.304780527085192, 0.6327459028649582], 
              Complex[7.617047237536007, -0.5824486239818056]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7010790784869583`, 1.1358468924959164`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335281138965442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 2, {
              Complex[9.335281138965442, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6876978858595542`, 1.2159026315187893`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 1, {
              Complex[9.304984699340448, 0.642655799962885], 
              Complex[7.617286813480894, -0.5732468315559043]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.70122898836949, 1.135109145872741}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 2, {
              Complex[9.334985216595475, -0.6505203737511223], 
              Complex[7.633756228225985, -1.7856295196238632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687663354498061, 1.2165982636922328`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811117`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 1, {
              Complex[9.305176410484558, 0.6523323858111211], 
              Complex[7.617513055986497, -0.5642658778811117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7013778131143251`, 1.1343838152897303`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 2, {
              Complex[9.334702902745928, -0.6602042845457754], 
              Complex[7.633325089631603, -1.7945880998355057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6876296708220482`, 1.2172820529684154`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.661787529645796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 1, {
              Complex[9.30535672988259, 0.661787529645796], 
              Complex[7.617727059060542, -0.5554945233226195]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7015255797263569`, 1.1336702718097431`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8033369326051627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 2, {
              Complex[9.334433100918964, -0.6696666607954198], 
              Complex[7.6329075211926085`, -1.8033369326051627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6875968103473002`, 1.2179545776709837`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 1, {
              Complex[9.305526605913883, 0.6710321572939453], 
              Complex[7.617929795566583, -0.5469224203770383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7016723149996422`, 1.1329679377580293`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.678918430486528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445572`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 2, {
              Complex[9.334174836562125, -0.678918430486528], 
              Complex[7.632502521562483, -1.8118863682445572`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6875647489352248`, 1.2186163705006783`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762599`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 1, {
              Complex[9.305686882893223, 0.6800763528244185], 
              Complex[7.618122133957997, -0.5385400176762599]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7018180453319975`, 1.1322762810679867`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 2, {
              Complex[9.333927240101856, -0.6879696797720988], 
              Complex[7.632109194769859, -1.8202459608400856`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6875334629267682`, 1.2192679234139303`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 1, {
              Complex[9.305838315194185, 0.6889294464957763], 
              Complex[7.618304852267418, -0.5303384769181541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7019627965927948`, 1.1315948104030762`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 2, {
              Complex[9.333689532777537, -0.6968297409230595], 
              Complex[7.631726736184743, -1.8284245513261357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6875029292360888`, 1.2199096918514625`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 1, {
              Complex[9.305981579104795, 0.697600091198504], 
              Complex[7.618478649868707, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.702106594030904, 1.1309230709286935`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 2, {
              Complex[9.333461014745714, -0.7055072687737806], 
              Complex[7.6313544207148105`, -1.836430339702474]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6874731254138242`, 1.2205420984195954`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306117282833021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 1, {
              Complex[9.306117282833021, 0.7060963291837468], 
              Complex[7.618644157419197, -0.5144457692358487]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7022494622129742`, 1.1302606406313307`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333241055036742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.714010307453912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 2, {
              Complex[9.333241055036742, -0.714010307453912], 
              Complex[7.630991592823768, -1.8442709480852426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6874440296873743`, 1.2211655361083011`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.506739885558876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 1, {
              Complex[9.306245974993525, 0.7144256505494251], 
              Complex[7.618801945306149, -0.506739885558876]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7023914249846368`, 1.12960712710096}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 2, {
              Complex[9.333029083032358, -0.7223463488774436], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6874156209838362`, 1.2217803711152466`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 1, {
              Complex[9.306368151840395, 0.7225950446980841], 
              Complex[7.61895253085656, -0.4991853264171625]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7025325054489893`, 1.1289621647074088`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 2, {
              Complex[9.332824581199283, -0.73052238420331], 
              Complex[7.630292075750293, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687387878939884, 1.2223869453331684`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306484263458826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457744995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518941`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49177589955866874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 1, {
              Complex[9.306484263458826, 0.7306110457744995], 
              Complex[7.619096384518941, -0.49177589955866874`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.702672725958061, 1.1283254121133874`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 2, {
              Complex[9.332627078865713, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6873607839018974`, 1.2229855785483166`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 1, {
              Complex[9.30659471908804, 0.7384797729243923], 
              Complex[7.619233935186141, -0.4845058056239242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7028121081139977`, 1.1276965500764318`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33243614686835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 2, {
              Complex[9.33243614686835, -0.7464201648848556], 
              Complex[7.629624038754352, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6873343169188384`, 1.2235765703899115`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.477369604310393`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 1, {
              Complex[9.306699891715686, 0.7462069660795185], 
              Complex[7.6193655747968485`, -0.477369604310393]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7029506727774146`, 1.1270752794998102`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687308459729827, 1.2241602020642195`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6194916623287705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 1, {
              Complex[9.306800122058597, 0.7537980178639988], 
              Complex[7.6194916623287705`, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.703088440081019, 1.1264613196988045`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62898401756861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 2, {
              Complex[9.332072457649629, -0.761751166453438], 
              Complex[7.62898401756861, -1.8882124861522425`]}, 0}, "Tooltip"]
           & ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6872831947478968`, 1.2247367379015857`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.463478735776971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 1, {
              Complex[9.306895722024104, 0.7612580021246147], 
              Complex[7.619612527276207, -0.463478735776971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7032254294469888`, 1.1258544068540122`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 2, {
              Complex[9.33189901102014, -0.7692174219206871], 
              Complex[7.62867358157315, -1.8950718287746993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6872585050410873`, 1.2253064267405016`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45671472722754314`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 1, {
              Complex[9.306986977730263, 0.7685916995129585], 
              Complex[7.619728472689176, -0.45671472722754314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7033616596069883`, 1.1252542926276012`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.776557321057196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628369089772418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 2, {
              Complex[9.331730749379407, -0.776557321057196], 
              Complex[7.628369089772418, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6872343743117344`, 1.225869503169189}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307074152149593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 1, {
              Complex[9.307074152149593, 0.7758036204842987], 
              Complex[7.619839777837859, -0.4500658826848904]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7034971486239172`, 1.1246607429220428`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 2, {
              Complex[9.331567392745953, -0.7837753757227327], 
              Complex[7.628070244122036, -1.9084361186447754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6872107868746438`, 1.2264261886422025`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30715748743053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44352816261650035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 1, {
              Complex[9.30715748743053, 0.7828980260257021], 
              Complex[7.619946700555886, -0.44352816261650035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.703631913914755, 1.1240735367637995`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 2, {
              Complex[9.331408682475267, -0.7908758482666056], 
              Complex[7.627776768560513, -1.914949385030405]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6871877276346632`, 1.2269766924870942`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4370977461047796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 1, {
              Complex[9.307237206941968, 0.7898789463823146], 
              Complex[7.620049479307305, -0.4370977461047796]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7037659722739469`, 1.123492465296951}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 2, {
              Complex[9.331254379194702, -0.7978627702556045], 
              Complex[7.627488406920755, -1.9213552355525552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6871651820640383`, 1.2275212128140653`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3073135170789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.796750198013566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6201483350148616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4307710148004995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 1, {
              Complex[9.3073135170789, 0.796750198013566], 
              Complex[7.6201483350148616`, -0.4307710148004995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.703899339896989, 1.1229173308738125`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 2, {
              Complex[9.331104260978194, -0.8047399594318435], 
              Complex[7.627204921081205, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6871431361798572`, 1.228059937339793}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.803515398980124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 1, {
              Complex[9.307386608861504, 0.803515398980124], 
              Complex[7.620243472681647, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7040320324038776`, 1.1223479462313808`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3309581217286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 2, {
              Complex[9.3309581217286, -0.811511035101225], 
              Complex[7.626926089324722, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6871215765217955`, 1.228593044135109}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925703`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 1, {
              Complex[9.307456659354886, 0.8101779829358519], 
              Complex[7.62033508283309, -0.41841506119925703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7041640648622178`, 1.1217841337438983`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.687100490130325, 1.2291207023049657`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 1, {
              Complex[9.307523832932748, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.704295451809858, 1.121225724743139}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 2, {
              Complex[9.330677026418373, -0.8247484136793252], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6870798645255034`, 1.229643072608023}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404815`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.406434884829246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 1, {
              Complex[9.307588282404815, 0.8232081877787769], 
              Complex[7.620508417879312, -0.406434884829246]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7044262072768797`, 1.120672558899053}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 2, {
              Complex[9.330541725135813, -0.8312210828762443], 
              Complex[7.626115517858932, -1.9518936417752972`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6870596876864263`, 1.2301603080222792`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307650150024978`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 1, {
              Complex[9.307650150024978, 0.8295818632429405], 
              Complex[7.620590462338551, -0.4005784447793387]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7045563448069236`, 1.120124483654361}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6870399480314069`, 1.230672554262382}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307709568394769`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39480750301628864`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 1, {
              Complex[9.307709568394769, 0.8358650512460933], 
              Complex[7.620669620363362, -0.39480750301628864`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7046858774777518`, 1.1195813537074624`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330280835982268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 2, {
              Complex[9.330280835982268, -0.8438891593891126], 
              Complex[7.625594958504517, -1.9634705130965748`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6870206343988832`, 1.2311799502535616`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3891195161626054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.3891195161626054]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7048148179210458`, 1.1190430305387107`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33015496599815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 2, {
              Complex[9.33015496599815, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6870017360291107`, 1.2316826285665503`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6208198082853045`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38351205693401635`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 1, {
              Complex[9.307821544314415, 0.8481705716325338], 
              Complex[7.6208198082853045`, -0.38351205693401635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7049431783414013`, 1.118509381975696}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562056684719375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 2, {
              Complex[9.330031972258515, -0.8562056684719375], 
              Complex[7.625088793917113, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686983242546615, 1.232180715817341}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 1, {
              Complex[9.307874325710909, 0.8541979088518958], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7050709705345457`, 1.1179802817936817`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 2, {
              Complex[9.329911734551452, -0.8622384184423428], 
              Complex[7.624840764016906, -1.9802187002360245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6869651439434037`, 1.2326743330351946`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 1, {
              Complex[9.30792510680319, 0.8601447828394874], 
              Complex[7.620959962859786, -0.3725295501957073]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.705198205904754, 1.1174556093477817`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329794139845038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 2, {
              Complex[9.329794139845038, -0.8681906520799054], 
              Complex[7.624595933940285, -1.9856462614276873`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6869474305629428`, 1.2331635960019263`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610358`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 1, {
              Complex[9.307973982610358, 0.8660134292433511], 
              Complex[7.621026552047415, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.705324895481501, 1.1169352492338578`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.9909998552070285`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6869300930848505`, 1.2336486155651583`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357775`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 1, {
              Complex[9.308021042319385, 0.8718059882315806], 
              Complex[7.621090949234534, -0.36184262733357775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7054510499353537`, 1.1164190909754408`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9962815121814683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 2, {
              Complex[9.329566459959892, -0.8798624212060274], 
              Complex[7.624115410024538, -1.9962815121814683`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6869131225103084`, 1.2341294979279438`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 1, {
              Complex[9.308066369728037, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489176`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7055766795931335`, 1.1159070287342765`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 2, {
              Complex[9.32945617991971, -0.8855861488792874], 
              Complex[7.623879500326575, -2.001493177613564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6868965101481652`, 1.2346063449168938`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 1, {
              Complex[9.308110043647691, 0.8831709599557607], 
              Complex[7.621213533499526, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7057017944523751`, 1.1153989610423563`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 2, {
              Complex[9.329348152291017, -0.8912377552298727], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6868802476016957`, 1.2350792542307416`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3463320308925905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.3463320308925905]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7058264041951023`, 1.114894790553516}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 2, {
              Complex[9.329242292636387, -0.8968191263829132], 
              Complex[7.623415888441285, -2.0117139169364293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.68686432675599, 1.235548319671038}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 1, {
              Complex[9.308192723503184, 0.8942551097650246], 
              Complex[7.621328396747195, -0.3412932099060134]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.705950518200953, 1.1143944238128876`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 2, {
              Complex[9.329138521063246, -0.9023320727684231], 
              Complex[7.623188002862294, -2.0167264965813105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686848739765963, 1.2360136313565446`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308231865274811`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 1, {
              Complex[9.308231865274811, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7060741455596737`, 1.1138977710426565`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 2, {
              Complex[9.329036761909217, -0.9077783332310712], 
              Complex[7.622962616349544, -2.0216761042737277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6868334790449246`, 1.2364752759226942`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 1, {
              Complex[9.308269625814717, 0.9050726361762729], 
              Complex[7.621436146769792, -0.3314026397464215]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7061972950830304`, 1.1134047459427392`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0265643248014458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 2, {
              Complex[9.328936943453858, -0.9131595788587066], 
              Complex[7.6227396483708265`, -2.0265643248014458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6868185372537259`, 1.2369333367073783`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62148752665612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 1, {
              Complex[9.308306063909846, 0.9103855526005631], 
              Complex[7.62148752665612, -0.3265477841068153]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.706319975316139, 1.1129152655051355`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 2, {
              Complex[9.328838997654193, -0.9184774165528231], 
              Complex[7.622519022338055, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6868039072904113`, 1.2373878939241858`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 1, {
              Complex[9.308341235139771, 0.9156366518516704], 
              Complex[7.621537327849359, -0.3217512420725154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7064421945482613`, 1.1124292498408201`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686789582280386, 1.2378390248241162`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31701160331199163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 1, {
              Complex[9.308375192092747, 0.9208274215121246], 
              Complex[7.62158560981236, -0.31701160331199163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7065639608230774`, 1.1119466220181602`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 2, {
              Complex[9.328648468799225, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6867755555670472`, 1.238286803846688}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 1, {
              Complex[9.30840798456442, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.706685281948481, 1.1114673079119295`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 2, {
              Complex[9.32855576595434, -0.9340656567439877], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686761820702876, 1.2387313027612805`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037959`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720178`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 1, {
              Complex[9.308439659740834, 0.9310336510892627], 
              Complex[7.621677839037959, -0.3076976516720178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7068061655059004`, 1.1109912360620862`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 2, {
              Complex[9.328464695790347, -0.9391447601963724], 
              Complex[7.621658530284445, -2.0501359962584584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686748371440953, 1.2391725907994695`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.303120767916594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 1, {
              Complex[9.30847026236711, 0.9360518228828755], 
              Complex[7.621721890926156, -0.303120767916594]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.706926618859174, 1.1105183375415564`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.054685974350639`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 2, {
              Complex[9.328375205370593, -0.9441676368090828], 
              Complex[7.621448586511419, -2.054685974350639]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6867352017268906`, 1.2396107347790482`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 1, {
              Complex[9.308499834903161, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7070466491630236`, 1.1100485458323215`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 2, {
              Complex[9.32828724423658, -0.9491355712999278], 
              Complex[7.621240595073557, -2.0591841171322494`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6867223056911294`, 1.240045799220364}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 1, {
              Complex[9.308528417667574, 0.9459247030157981], 
              Complex[7.621806111976445, -0.29412109620456584`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.70716626337111, 1.109581796709196}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 2, {
              Complex[9.328200764258012, -0.9540498035022785], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6867096776416242`, 1.2404778464555413`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 1, {
              Complex[9.308556048970688, 0.9507818469782096], 
              Complex[7.621846371329063, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.707285468243723, 1.109118028130704}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 2, {
              Complex[9.328115719493919, -0.9589115304824556], 
              Complex[7.620830251250196, -2.06802955861316]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866973120568676`, 1.2409069367311212`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 1, {
              Complex[9.308582765237823, 0.9555876813576086], 
              Complex[7.621885453180955, -0.2853192553735125]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7074042703551173`, 1.1086571801365497`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32803206606383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 2, {
              Complex[9.32803206606383, -0.9637219085313012], 
              Complex[7.620627795708714, -2.072379088667851]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866852035792277`, 1.2413331283045885`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9603433229418255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280989805362763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 1, {
              Complex[9.30860860112351, 0.9603433229418255], 
              Complex[7.621923397544282, -0.280989805362763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7075226761004942`, 1.1081991947511818`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 2, {
              Complex[9.327949762028192, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866733470086253`, 1.2417564775352328`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30863358961748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 1, {
              Complex[9.30863358961748, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7076406917026798`, 1.1077440158930363`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866617372964796`, 1.2421770389697382`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 1, {
              Complex[9.30865776214308, 0.9697083109361541], 
              Complex[7.6219960248466, -0.27246872803358424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.707758323218489, 1.107291589289035}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 2, {
              Complex[9.327789043427424, -0.9778559389833152], 
              Complex[7.620030720208936, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866503695399515`, 1.2425948654228762`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308681148648779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9743197118823447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26827515354053166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 1, {
              Complex[9.308681148648779, 0.9743197118823447], 
              Complex[7.622030779108827, -0.26827515354053166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7078755765447962`, 1.1068418623939869`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866392389764404`, 1.2430100080536353`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 1, {
              Complex[9.308703777693308, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7079924574243457`, 1.1063947843145436`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327633262958448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381359`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 2, {
              Complex[9.327633262958448, -0.9870414080668153], 
              Complex[7.619640805534103, -2.093436192381359]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866283409783382`, 1.243422516437101}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 1, {
              Complex[9.308725676524938, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774761984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7081089714512874`, 1.105950305737408}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866176710480196`, 1.2438324386323738`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133871`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 1, {
              Complex[9.308746871155384, 0.9878811887189867], 
              Complex[7.622129200107364, -0.2559512499133871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7082251240764754`, 1.105508378861497}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.101554547612181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 2, {
              Complex[9.327482144581792, -0.9960461687506839], 
              Complex[7.619257020505317, -2.101554547612181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6866072248130584`, 1.2442398212467844`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 1, {
              Complex[9.308767386428748, 0.9923138310722677], 
              Complex[7.62216016161569, -0.25192599017451683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7083409206125306`, 1.105068957333809}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327408253521732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 2, {
              Complex[9.327408253521732, -1.0004830605740669`], 
              Complex[7.619067332909202, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865969980216582`, 1.2446447094966562`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790134`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 1, {
              Complex[9.30878724608588, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7084563662386807`, 1.1046319961887379`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113643`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 2, {
              Complex[9.327335434354206, -1.0048774519249053`], 
              Complex[7.618879068115525, -2.109509448113643]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865869865382848`, 1.2450471472648306`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7085714660053872`, 1.1041974517906228`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566213`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 2, {
              Complex[9.327263658416845, -1.0092301787755904`], 
              Complex[7.618692192411457, -2.113427630566213]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865771863394972`, 1.245447177155176}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7086862248387757`, 1.1037652817793195`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865675935099471`, 1.2458448405442555`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 1, {
              Complex[9.308843113455703, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7088006475448771`, 1.1033354450185962`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1211493036241214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 2, {
              Complex[9.327123127092815, -1.0178138586055252`], 
              Complex[7.618322479547938, -2.1211493036241214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865582042385758`, 1.2462401776303484`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278965`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 1, {
              Complex[9.308860568016621, 1.0138563914775587`], 
              Complex[7.622302363778045, -0.23238378615278965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7089147388136834`, 1.1029079015471877`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 2, {
              Complex[9.327054319725958, -1.0220463622527833`], 
              Complex[7.618139580912274, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865490148149482`, 1.2466332274799763`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2285869439961421`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 1, {
              Complex[9.308877471091343, 1.0180462834838342`], 
              Complex[7.622328456276395, -0.2285869439961421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7090285032230363`, 1.102482612532335}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.02624030460825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 2, {
              Complex[9.326986451526654, -1.02624030460825], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865400216257653`, 1.2470240280720961`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765633`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 1, {
              Complex[9.308893840937472, 1.0221983660944398`], 
              Complex[7.622353819311706, -0.22482566197765633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7091419452423504`, 1.1020595402256605`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 2, {
              Complex[9.326919498869884, -1.0303964059906547`], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.68653122115152, 1.2474126163400958`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.026313338713697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 1, {
              Complex[9.3089096950579, 1.026313338713697], 
              Complex[7.62237847390638, -0.2210992776263989]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7092550692361863`, 1.1016386479212323`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617598369758898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.617598369758898, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865226099632833`, 1.2477990282117284`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308925050238992`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.030391881059093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 1, {
              Complex[9.308925050238992, 1.030391881059093], 
              Complex[7.622402440275709, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7093678794676628`, 1.1012198999156986`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.038597865497053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 2, {
              Complex[9.326788249964949, -1.038597865497053], 
              Complex[7.617420370497285, -2.1398177654127513`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865141847196436`, 1.2481832986471038`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0344346539072422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 1, {
              Complex[9.30893992258648, 1.0344346539072422`], 
              Complex[7.622425737866838, -0.21374864473986163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7094803801017517`, 1.100803261470351}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288384`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 2, {
              Complex[9.326723910626667, -1.0426445649584875`], 
              Complex[7.617243530524916, -2.1434478264288384`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6865059421637554`, 1.2485654616748578`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 1, {
              Complex[9.308954327559254, 1.0384422998042995`], 
              Complex[7.622448385395499, -0.2101231618705584]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.709592575208412, 1.1003886987750218`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326660400575378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1470448063535947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 2, {
              Complex[9.326660400575378, -1.0466561075785732`], 
              Complex[7.6170678253669655`, -2.1470448063535947`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686497879120527, 1.2489455504265943`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.709704468765626, 1.0999761789136908`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 2, {
              Complex[9.326597700119693, -1.0506331187508067`], 
              Complex[7.616893231354067, -2.1506092976644977`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864899924939094`, 1.249323597169712}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308981794170638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 1, {
              Complex[9.308981794170638, 1.04635469380724], 
              Complex[7.622491801676729, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.709816064662282, 1.099565669831724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32653579024921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 2, {
              Complex[9.32653579024921, -1.0545762069524505`], 
              Complex[7.616719725586928, -2.1541418767841747`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686482279264302, 1.2496996333387003`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 1, {
              Complex[9.308994883769515, 1.0502606417889437`], 
              Complex[7.622512604505212, -0.1994389915497566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7099273667009742`, 1.099157140304622}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 2, {
              Complex[9.326474652603714, -1.0584859643603295`], 
              Complex[7.616547285902739, -2.1576431046649516`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864747364860686`, 1.2500736895649893`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.1959398257910545]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7100383786006703`, 1.0987505599082366`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32641426944434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6163758908436705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1611135273463344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 2, {
              Complex[9.32641426944434, -1.0623629674380977`], 
              Complex[7.6163758908436705`, -2.1611135273463344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864673612851377`, 1.250445795705442}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622552480149748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 1, {
              Complex[9.309019841434887, 1.0579749207033111`], 
              Complex[7.622552480149748, -0.1924708750021308]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7101491039992827`, 1.0983458989903194`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1645536764876296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 2, {
              Complex[9.326354623625985, -1.0662077774973102`], 
              Complex[7.6162055196267024`, -2.1645536764876296`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864601508567196`, 1.2508159808695567`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 1, {
              Complex[9.309031734351517, 1.061784358908797], 
              Complex[7.622571583494798, -0.18903162196075954`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7102595464561352`, 1.0979431286433743`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 2, {
              Complex[9.326295698571451, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686453102463093, 1.2511842734454515`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622590149980672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.18562156282100895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 1, {
              Complex[9.309043252443765, 1.0655627106244425`], 
              Complex[7.622590149980672, -0.18562156282100895`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7103697094543509`, 1.0975422206787229`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686446213431498, 1.2515507011247011`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 1, {
              Complex[9.309054406998326, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7104795964031172`, 1.0971431476017133`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 2, {
              Complex[9.326179947138469, -1.0775544464801794`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864394811520862`, 1.2519152909260816`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30906520888366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 1, {
              Complex[9.30906520888366, 1.0730282159476652`], 
              Complex[7.622625727731573, -0.1788870749784164]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7105892106399037`, 1.096745882588027}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 2, {
              Complex[9.326123090230514, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864329030759833`, 1.2522780692182853`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 1, {
              Complex[9.30907566856886, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7106985554325609`, 1.096350399461005}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326066892984452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 2, {
              Complex[9.326066892984452, -1.0849675833073056`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864264767133959`, 1.2526390617416576`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30908579614155`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6226593194281556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 1, {
              Complex[9.30908579614155, 1.0803754306555198`], 
              Complex[7.6226593194281556`, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7108076339813658`, 1.0959566726699574`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.088630238875599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 2, {
              Complex[9.32601134131908, -1.088630238875599], 
              Complex[7.615203707337714, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864201996318084`, 1.2529982936290076`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053758934`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 1, {
              Complex[9.309095601324776, 1.0840058730914184`], 
              Complex[7.622675401692968, -0.16899242053758934`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.710916449420976, 1.0955646772693968`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61503997217078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1878289257658756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 2, {
              Complex[9.325956421591755, -1.0922642484964789`], 
              Complex[7.61503997217078, -2.1878289257658756`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6864140694542373`, 1.2533557894255407`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 1, {
              Complex[9.309105093493066, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7110250048223246`, 1.0951743888991479`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 2, {
              Complex[9.325902120580537, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686408083857565, 1.253711573107958}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 1, {
              Complex[9.309114281687616, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7111333031944354`, 1.0947857837652881`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 2, {
              Complex[9.325848425467223, -1.0994481489240941`], 
              Complex[7.614715122272787, -2.1942339326893823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686402240570922, 1.2540656681027627`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809695`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 1, {
              Complex[9.309123174630704, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809695`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7112413474861696`, 1.0943988386218855`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325795323821204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102998921879825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 2, {
              Complex[9.325795323821204, -1.102998921879825], 
              Complex[7.614553976335034, -2.1973977605017105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863965373741345`, 1.2544180973038175`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739364`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62273524336523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 1, {
              Complex[9.309131780739364, 1.0982504190677982`], 
              Complex[7.62273524336523, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7113491405879322`, 1.0940135307534755`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.200536344647329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 2, {
              Complex[9.325742803584207, -1.1065228138938534`], 
              Complex[7.614393662996275, -2.200536344647329]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686390972096229, 1.2547688830891832`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788943`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7114566853332833`, 1.0936298379582658`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32569085305561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 2, {
              Complex[9.32569085305561, -1.1100202402427715`], 
              Complex[7.614234167722326, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686385542613994, 1.2551180473372854`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 1, {
              Complex[9.309148164672498, 1.1052123472899036`], 
              Complex[7.622762622058505, -0.14990570004738188`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7115639845005257`, 1.093247738532003}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113491606471821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61407547637812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003824`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 2, {
              Complex[9.325639460878644, -1.113491606471821], 
              Complex[7.61407547637812, -2.206739345003824]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863802468505937`, 1.2554656114424274`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30915595791838`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 1, {
              Complex[9.30915595791838, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.711671040814209, 1.0928672112525002`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087011036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953604`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 2, {
              Complex[9.325588616027114, -1.1169373087011036`], 
              Complex[7.613917575212904, -2.209804519953604]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686375082774224, 1.2558115963296934`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 1, {
              Complex[9.309163495195483, 1.112071704185835], 
              Complex[7.622788412421259, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7117778569465985`, 1.092488235364768}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6137604508462084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 2, {
              Complex[9.325538307792806, -1.1203577339198192`], 
              Complex[7.6137604508462084`, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863700483968251`, 1.256156022469267}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155678`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7118844355190923`, 1.092110790566729}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123753260268964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 2, {
              Complex[9.325488525773522, -1.123753260268964], 
              Complex[7.613604090254429, -2.215864050835693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863651417728376`, 1.2564989098901886`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30917782989869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 1, {
              Complex[9.30917782989869, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7119907791035764`, 1.0917348569954992`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 2, {
              Complex[9.325439259861604, -1.1271242573129165`], 
              Complex[7.613448480758027, -2.2188591143084158`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863603609980011`, 1.256840278193586}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13466520641404972`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.13466520641404972`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7120968902237481`, 1.0913604152141878`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 2, {
              Complex[9.325390500232961, -1.1304710863006697`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863557042081971`, 1.2571801465653925`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438924218`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 1, {
              Complex[9.309191222585207, 1.1254948021761504`], 
              Complex[7.622835518377009, -0.13168534438924218`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7122027713563872`, 1.0909874461992093`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 2, {
              Complex[9.32534223733676, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863511695783353`, 1.2575185337885972`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 1, {
              Complex[9.309197581524451, 1.1287910849032745`], 
              Complex[7.6228464119461155`, -0.12872744888532286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.712308424932585, 1.0906159313280754`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 2, {
              Complex[9.325294461885356, -1.1370936450243199`], 
              Complex[7.612986036952771, -2.227709576352395]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863467553212579`, 1.2578554582550099`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420297`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 1, {
              Complex[9.309203723570544, 1.1320642574808069`], 
              Complex[7.622856968249287, -0.12579120077420297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7124138533389353`, 1.0902458523676473`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 2, {
              Complex[9.325247164844852, -1.140370057894864], 
              Complex[7.612833311505916, -2.2306159102625114`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863424596867158`, 1.2581909379766116`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669171`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790969447`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 1, {
              Complex[9.309209654512552, 1.1353146500669171`], 
              Complex[7.622867194825836, -0.12287628790969447`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7125190589186814`, 1.0898771914628231`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863382809603609`, 1.2585249905964744`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294204`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 1, {
              Complex[9.309215379954185, 1.1385425856735323`], 
              Complex[7.622877098993824, -0.11998240492294204`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7126240439728273`, 1.0895099311256529`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146854802900513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 2, {
              Complex[9.325153971075478, -1.146854802900513], 
              Complex[7.612529927102651, -2.236364734026166]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686334217462754, 1.258857633399273}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.141748380373843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1171092530254299`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 1, {
              Complex[9.309220905320855, 1.141748380373843], 
              Complex[7.6228866878581005`, -0.1171092530254299]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7127288107612115`, 1.089144054224844}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686330267548447, 1.259188883321431}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902048`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7128333615035514`, 1.0887795439756538`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32506258849663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 2, {
              Complex[9.32506258849663, -1.1532508941175421`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863264296050673`, 1.2595187569608866`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309231376680849`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075781`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 1, {
              Complex[9.309231376680849, 1.1480947778478907`], 
              Complex[7.622904947075781, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.712937698380446, 1.088416383930148}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32501755626854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 2, {
              Complex[9.32501755626854, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863227020524367`, 1.2598472705865127`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923633269408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761455`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 1, {
              Complex[9.30923633269408, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.71304182353435, 1.0880545579678065`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 2, {
              Complex[9.324972953094393, -1.1595607822888858`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.68631908334172, 1.2601744401472053`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1543562397232365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396872`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 1, {
              Complex[9.309241108684372, 1.1543562397232365`], 
              Complex[7.622922025342652, -0.10581820042396872`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7131457390705167`, 1.0876940502864645`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324928771483046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 2, {
              Complex[9.324928771483046, -1.1626841380761952`], 
              Complex[7.611783032412529, -2.2503781883626597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863155719546132`, 1.2605002812806474`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7132494470579116`, 1.087334845393573}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25312166167618`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 2, {
              Complex[9.324885004134526, -1.165786816282607], 
              Complex[7.611635557076614, -2.25312166167618]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863121664025418`, 1.260824809321769}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 1, {
              Complex[9.309250138979014, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7133529495300999`, 1.0869769280977646`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 2, {
              Complex[9.324841643933636, -1.168869095524048], 
              Complex[7.611488694403536, -2.2558460236218125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6863088652258924`, 1.2611480393109105`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800904988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922041178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 1, {
              Complex[9.309254402126268, 1.1635941800904988`], 
              Complex[7.622945536900375, -0.09755385922041178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7134562484860945`, 1.0866202835007166`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.171931248732842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2585515322335588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 2, {
              Complex[9.324798683943808, -1.171931248732842], 
              Complex[7.611342435457713, -2.2585515322335588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686305666993273, 1.2614699860017093`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 1, {
              Complex[9.309258502946616, 1.1666334563353578`], 
              Complex[7.622952835953342, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7135593458911997`, 1.086264896989286}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 2, {
              Complex[9.324756117401229, -1.1749735433132202`], 
              Complex[7.611196771510029, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686302570300785, 1.2617906638687109`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309262445535504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62295987523472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438433`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 1, {
              Complex[9.309262445535504, 1.1696531548443265`], 
              Complex[7.62295987523472, -0.09213750902438433]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7136622436778, 1.085910754227925}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.263906995519419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 2, {
              Complex[9.324713937709186, -1.1779962412914937`], 
              Complex[7.611051694031386, -2.263906995519419]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862995737713367`, 1.2621100871147288`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866465`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745505`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 1, {
              Complex[9.309266233866465, 1.1726535322072738`], 
              Complex[7.622966660095128, -0.08945655490745505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.713764943746155, 1.0855578411513436`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1809995994611011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6109071946864875`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 2, {
              Complex[9.324672138432643, -1.1809995994611011`], 
              Complex[7.6109071946864875`, -2.2665574406124445`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862966760539544`, 1.2624282696779496`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 1, {
              Complex[9.309269871795374, 1.1756348399245427`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7138674479651452`, 1.0852061439574274`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1839838695227543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 2, {
              Complex[9.32463071329305, -1.1839838695227543`], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862938758231383`, 1.262745225238807}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 1, {
              Complex[9.309273363064712, 1.1785973245423351`], 
              Complex[7.622979487241573, -0.0841479006964719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7139697581730104`, 1.0848556491003871`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2718049473202555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 2, {
              Complex[9.324589656163335, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.2718049473202555`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862911717782296`, 1.2630609672266209`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 1, {
              Complex[9.309276711307533, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306795]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.714071876178063, 1.0845063432841389`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 2, {
              Complex[9.324548961063108, -1.1898961274694762`], 
              Complex[7.610477084885046, -2.274402470753615]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862885626427868`, 1.2633755088260257`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051317`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 1, {
              Complex[9.309279920051317, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.714173803759369, 1.0841582134559018`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32450862215405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 2, {
              Complex[9.32450862215405, -1.1928245944888058`], 
              Complex[7.610334818394682, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686286047163997, 1.2636888629831808`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309282992721648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.187374233666283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229969455576505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 1, {
              Complex[9.309282992721648, 1.187374233666283], 
              Complex[7.6229969455576505`, -0.07631462931689799]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7142755426674328`, 1.0838112468000036`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.610193091068046, -2.2795461787176907`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862836241121018`, 1.2640010424117867`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.190263796755059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672779`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 1, {
              Complex[9.309285932645754, 1.190263796755059], 
              Complex[7.623002308533652, -0.07373724565672779]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7143770946248302`, 1.0834654307318894`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.282092798668853]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862812922798296`, 1.2643120595989}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055877`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1931356995946463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 1, {
              Complex[9.309288743055877, 1.1931356995946463`], 
              Complex[7.623007450776046, -0.07117636000425366]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7144784613268562`, 1.083120752892326}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 2, {
              Complex[9.32438968622985, -1.2015021263830652`], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686279050481857, 1.264621926810569}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 1, {
              Complex[9.309291427092525, 1.1959901616082877`], 
              Complex[7.623012376610668, -0.06863176520228129]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7145796444421249`, 1.0827772011417842`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609771071949929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 2, {
              Complex[9.324350716392054, -1.2043594268588766`], 
              Complex[7.609771071949929, -2.2871366280006606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862768975542866`, 1.2649306560972855`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154555`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 1, {
              Complex[9.309293987807608, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7146806456131727`, 1.0824347635550098`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.207199484841066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 2, {
              Complex[9.324312075535534, -1.207199484841066], 
              Complex[7.609631429922362, -2.2896342483960757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686274832354128, 1.2652382592992675`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.06359063896214552`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 1, {
              Complex[9.309296428167407, 1.201647620337122], 
              Complex[7.623021595813279, -0.06359063896214552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7147814664570336`, 1.0820934284157555`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 2, {
              Complex[9.324273758587012, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862728537588085`, 1.2655447480515745`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30929875105546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230258972966505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 1, {
              Complex[9.30929875105546, 1.204451035693495], 
              Complex[7.6230258972966505`, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7148821085657961`, 1.0817531842116894`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432069`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 2, {
              Complex[9.324235760587548, -1.2128287152203794`], 
              Complex[7.609353652021753, -2.294581899432069]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862709606656907`, 1.265850133789066}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7149825735071609`, 1.0814140196294526`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689214`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 2, {
              Complex[9.324198076689214, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862691519916058`, 1.2661544277512031`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.056146171569541894`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 1, {
              Complex[9.309303055553212, 1.2100082561816612`], 
              Complex[7.6230339035616055`, -0.056146171569541894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7150828628249586`, 1.0810759235498726`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 2, {
              Complex[9.324160702151756, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862674266724, 1.2664576409867079`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 1, {
              Complex[9.309305042540567, 1.2127624573020028`], 
              Complex[7.623037615868166, -0.05369518368470517]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7151829780396723`, 1.080738885043328}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862657836624946`, 1.2667597843580762`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 1, {
              Complex[9.30930692281649, 1.2155006436945393`], 
              Complex[7.623041139153995, -0.051259140663536915`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7152829206489373`, 1.0804028933652483`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 2, {
              Complex[9.324086862718293, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862642219344588`, 1.267060868545956}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7153826921280313`, 1.0800679379517524`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 2, {
              Complex[9.32405038885261, -1.2266143809612577`], 
              Complex[7.608667696724579, -2.30668231891301]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686262740478591, 1.2673609040533935`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931037320279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.046431178463023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 1, {
              Complex[9.30931037320279, 1.2209297255903706`], 
              Complex[7.6230476327242, -0.046431178463023]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7154822939303398`, 1.079734008415422}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 2, {
              Complex[9.324014206402692, -1.2293237938391435`], 
              Complex[7.608531912472353, -2.3090578022545656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862613383025276`, 1.2676599012099543`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.715581727487827, 1.0794010945411951`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 2, {
              Complex[9.323978311121861, -1.232017733951226], 
              Complex[7.608396583634034, -2.311418828492421]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862600144308344`, 1.2679578701757186`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313425985488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 1, {
              Complex[9.309313425985488, 1.2262969751610369`], 
              Complex[7.623053411554654, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.715680994211479, 1.0790691862823865`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.313765567006709`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.313765567006709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686258767904639, 1.268254820945162}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048871`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 1, {
              Complex[9.309314809018923, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.03929696187048871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7157800954917433`, 1.0787382737568232`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32390736553039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 2, {
              Complex[9.32390736553039, -1.2373599104404134`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862575977812542`, 1.268550763350922}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641019`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 1, {
              Complex[9.309316099422274, 1.2316038141805974`], 
              Complex[7.623058501641019, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.715879032698951, 1.0784083472430945`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32387230716855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607993274469599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 2, {
              Complex[9.32387230716855, -1.2400084963104758`], 
              Complex[7.607993274469599, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862565031338197`, 1.2688457070674533`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329456`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 1, {
              Complex[9.309317299329456, 1.2342350105444317`], 
              Complex[7.623060796195635, -0.03461069652302155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7159778071837308`, 1.0780793971769094`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3207217057230576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 2, {
              Complex[9.323837519868583, -1.2426423085461482`], 
              Complex[7.607859712684853, -2.3207217057230576`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862554830509522`, 1.269139661614578}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318410818571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306292776762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03228804631048228`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 1, {
              Complex[9.309318410818571, 1.2368516153040956`], 
              Complex[7.62306292776762, -0.03228804631048228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7160764202774115`, 1.0777514141475626`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 2, {
              Complex[9.323802999811543, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862545366364052`, 1.2694326363609376`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913643`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 1, {
              Complex[9.309319435913643, 1.2394537927373113`], 
              Complex[7.623064899277237, -0.02997884362362627]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7161748732924162`, 1.0774243888944979`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323768743257098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 2, {
              Complex[9.323768743257098, -1.2478662783795624`], 
              Complex[7.607593869964681, -2.3252906672740603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862536630087424`, 1.2697246405273381`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 1, {
              Complex[9.309320376586303, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7162731675226397`, 1.0770983123039746`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32373474654141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 2, {
              Complex[9.32373474654141, -1.2504567620199434`], 
              Complex[7.60746157901877, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686252861301002, 1.270015683190013}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757375`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02540017436427092`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 1, {
              Complex[9.309321234757375, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7163713042438276`, 1.0767731754058247`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 2, {
              Complex[9.323701006075066, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862521306604028`, 1.270305773283777}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096772899`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 1, {
              Complex[9.30932201229845, 1.247175362316048], 
              Complex[7.623069881638048, -0.02313041096772899]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7164692847139307`, 1.0764489693703025`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 2, {
              Complex[9.323667518341093, -1.2555955212603065`], 
              Complex[7.607198233627162, -2.3320444906306093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686251470248025, 1.2705949196051112`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.24972141827203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 1, {
              Complex[9.309322711033376, 1.24972141827203], 
              Complex[7.623071240785351, -0.020873501333081253`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7165671101734585`, 1.0761256855050247`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.334269792192463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.334269792192463]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862508792385207`, 1.2708831308151451`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01862930319811999`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 1, {
              Complex[9.309323332739696, 1.2522538276170252`], 
              Complex[7.623072453501176, -0.01862930319811999]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7166647818458296`, 1.0758033152519937`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 2, {
              Complex[9.323601287353112, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862503568198186`, 1.2711704154425687`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 1, {
              Complex[9.309323879150053, 1.2547727387804997`], 
              Complex[7.623073522330235, -0.016397676662069066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7167623009376995`, 1.0754818501847014`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862499021928519`, 1.2714567818864555`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 1, {
              Complex[9.309324351953515, 1.2572782977532329`], 
              Complex[7.623074449760662, -0.014178484133222693`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7168596686392952`, 1.0751612820053194`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.265708491546124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 2, {
              Complex[9.323536026818966, -1.265708491546124], 
              Complex[7.606676358179671, -2.3408697735514434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862495145712781`, 1.2717422384190147`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796897`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278046269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 1, {
              Complex[9.309324752796897, 1.2597706481409683`], 
              Complex[7.62307523822562, -0.011971590278046269`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7169568861247209`, 1.0748416025419572`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 2, {
              Complex[9.323503752396528, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862491931812122`, 1.2720267931882643`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307589010475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 1, {
              Complex[9.309325083285962, 1.2622499312165716`], 
              Complex[7.62307589010475, -0.00977686197169255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7170539545522856`, 1.0745228037460033`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 2, {
              Complex[9.323471711022448, -1.2706850606806677`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862489372609757`, 1.2723104542206363`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 1, {
              Complex[9.309325344986703, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7171508750647866`, 1.0742048776895325`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2731538632721078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 2, {
              Complex[9.323439899636348, -1.2731538632721078`], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862487460608313`, 1.2725932294235094`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325539426466`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076793365634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261941976`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 1, {
              Complex[9.309325539426466, 1.2671698491615675`], 
              Complex[7.623076793365634, -0.005423380261941976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7172476487898232`, 1.073887816562785}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 2, {
              Complex[9.323408315236538, -1.2756098611309443`], 
              Complex[7.606160666446716, -2.349497677693729]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862486188427437`, 1.2728751265876717`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255545658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 1, {
              Complex[9.309325668095038, 1.2696107553621172`], 
              Complex[7.623077049252295, -0.0032643712255545658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7173442768400726`, 1.0735716126717125`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862485548801436`, 1.2731561533897247`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821179458`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 1, {
              Complex[9.309325732445826, 1.2720391370076067`], 
              Complex[7.623077177565682, -0.0011170163821179458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7174407603135722`, 1.0732562584355896`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.280483979285027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 2, {
              Complex[9.323345815673619, -1.280483979285027], 
              Complex[7.605905055360047, -2.3537402377206167`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862485534576859`, 1.2734363173944174`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7175371002940005`, 1.0729417463846898`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862486138710238`, 1.273715626056924}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985720384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.0031432198985720384`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7176332978509388`, 1.0726280691580181`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 2, {
              Complex[9.323284189438796, -1.2853084672867794`], 
              Complex[7.605650891587858, -2.3579365364447975`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862487354265914`, 1.273994086725058}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076818174038`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.623076818174038, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7177293540401313`, 1.0723152195011065`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605524342857891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 2, {
              Complex[9.323253696898023, -1.2877024197670905`], 
              Complex[7.605524342857891, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862489174413777`, 1.2742717066414346`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325374521514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080136`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 1, {
              Complex[9.309325374521514, 1.2816299944237621`], 
              Complex[7.623076457080136, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7178252699037433`, 1.0720031902638685`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323223414486042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 2, {
              Complex[9.323223414486042, -1.2900843444730694`], 
              Complex[7.605398144582299, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686249159242732, 1.2745484929455693`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7179210464706118`, 1.0716919743985007`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 2, {
              Complex[9.323193339572983, -1.2924543639191772`], 
              Complex[7.605272293102371, -2.3641463383176777`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862494601681366`, 1.274824452675933}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933625`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 1, {
              Complex[9.309324844933625, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.718016684756481, 1.0713815649574496`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 2, {
              Complex[9.323163469577015, -1.2948125987358021`], 
              Complex[7.605146784820534, -2.366194163693252]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862498195650244`, 1.2750995927719448`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.718112185764248, 1.0710719550914203`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 2, {
              Complex[9.323133801963195, -1.2971591677080445`], 
              Complex[7.605021616198947, -2.3682311227994646`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862502367905727`, 1.275373920075922}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491239`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 1, {
              Complex[9.309324094995942, 1.2910305277808343`], 
              Complex[7.62307385820537, 0.01565660770491239]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7182075504841867`, 1.070763138047441}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 2, {
              Complex[9.323104334242323, -1.2994941878134683`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862507112115166`, 1.275647441334975}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371002`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.017704375485552187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 1, {
              Complex[9.309323640371002, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485552187`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7183027798941792`, 1.0704551071669757`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323075063969917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 2, {
              Complex[9.323075063969917, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862512422039606`, 1.2759201632028616`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 1, {
              Complex[9.309323134173038, 1.2956617974980966`], 
              Complex[7.623071891969078, 0.019741634295235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7183978749599396`, 1.0701478558840805`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 2, {
              Complex[9.323045988745086, -1.3041300405165714`], 
              Complex[7.604648113785146, -2.3742778964006517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862518291531974`, 1.2761920922417866`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 1, {
              Complex[9.309322577516866, 1.2979605814829254`], 
              Complex[7.623070748363669, 0.021768489241138642`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7184928366352175`, 1.069841377723615}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 2, {
              Complex[9.323017106209537, -1.3064310983584466`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862524714535325`, 1.2764632349241656`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491421`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 1, {
              Complex[9.309321971491421, 1.300248278779899], 
              Complex[7.623069500037889, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7185876658620232`, 1.0695356662994853`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 2, {
              Complex[9.322988414046595, -1.3087210578909663`], 
              Complex[7.604400748184572, -2.3782567241904515`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686253168508105, 1.2767335976343386`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321317160448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 1, {
              Complex[9.309321317160448, 1.3025249977626074`], 
              Complex[7.623068148652342, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7186823635708248`, 1.0692307153129395`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.311000027587925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3802307429008644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 2, {
              Complex[9.322959909980197, -1.311000027587925], 
              Complex[7.604277546409373, -2.3802307429008644`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862539197287283`, 1.2770031866702454`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 1, {
              Complex[9.309320615563188, 1.3047908452057133`], 
              Complex[7.623066695834459, 0.027787658535467812`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7187769306807554`, 1.0689265185509058`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591774001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.313268114322925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873831`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 2, {
              Complex[9.322931591774001, -1.313268114322925], 
              Complex[7.604154661093246, -2.382194632873831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862547245357153`, 1.2772720082450588`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145831`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 1, {
              Complex[9.309319867715043, 1.3070459263165173`], 
              Complex[7.623065143179328, 0.02977391807145831]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7188713680998058`, 1.0686230698843617`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 2, {
              Complex[9.32290345723042, -1.3155254234009868`], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862555823577243`, 1.2775400684887797`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250482`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 1, {
              Complex[9.309319074608206, 1.3092903447657454`], 
              Complex[7.623063492250482, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7189656767250145`, 1.0683203632667537`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 2, {
              Complex[9.322875504189797, -1.3177720585893213`], 
              Complex[7.603909827464783, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862564926315964`, 1.27780737344979}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3115242027175686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306174458069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0337168292677788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 1, {
              Complex[9.309318237212286, 1.3115242027175686`], 
              Complex[7.62306174458069, 0.0337168292677788]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.719059857442669, 1.068018392732448}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.320008122147406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 2, {
              Complex[9.322847730529492, -1.320008122147406], 
              Complex[7.603787873086824, -2.388026514879854]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862574548022062`, 1.2780739290963752`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474935`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672728`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 1, {
              Complex[9.309317356474935, 1.3137476008589233`], 
              Complex[7.623059901672728, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7191539111284704`, 1.0677171523952218`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32282013416307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 2, {
              Complex[9.32282013416307, -1.32223371485628], 
              Complex[7.6036662230346, -2.3899508672515015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862584683223119`, 1.2783397413182}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 1, {
              Complex[9.309316433322346, 1.3159606384280351`], 
              Complex[7.623057965000035, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7192478386477308`, 1.0674166364467885`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862595326524015`, 1.2786048159277634`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459821`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 1, {
              Complex[9.309315468659921, 1.3181634132423616`], 
              Complex[7.623055936007519, 0.03955859731459821]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7193416408555386`, 1.0671168391553596`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.686260647260562, 1.2788691586618044`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314463372752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 1, {
              Complex[9.309314463372752, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7194353185969362`, 1.0668177548642397`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 2, {
              Complex[9.322738388488887, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862618116223256`, 1.2791327751826869`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313418326166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 1, {
              Complex[9.309313418326166, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7195288727070868`, 1.0665193779904547`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6031826084226255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.397552720648037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 2, {
              Complex[9.322711481129712, -1.3310333426575822`], 
              Complex[7.6031826084226255`, -2.397552720648037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862630252205475`, 1.2793956710797432`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.045315447506474364`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7196223040114333`, 1.0662217030234138`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33320804305447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 2, {
              Complex[9.322684741147608, -1.33320804305447], 
              Complex[7.603062437136174, -2.3994297460778835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862642875452605`, 1.2796578518705939`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775061`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 1, {
              Complex[9.309311212320322, 1.326873793079005], 
              Complex[7.623046924775061, 0.04721594120841103]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7197156133258704`, 1.0659247245235945`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 2, {
              Complex[9.322658166657, -1.3353728477954119`], 
              Complex[7.602942553331129, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.6862655980935486`, 1.2799193230024304`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.329026673522427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 1, {
              Complex[9.309310052997452, 1.329026673522427], 
              Complex[7.623044454903902, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{1.7198088014568969`, 1.0656284371212763`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480757078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 2, {
              Complex[9.322631755803354, -1.3375278480757078`], 
              Complex[7.602822954346457, -2.403156285196984]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]tt)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]tt)\"", TraditionalForm]},
      ImageSize->900,
      Method->{"AxesInFront" -> False},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.6980000948375925, -0.6433017314670852}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375925, -0.6433017314670852], 
              Complex[1.795162677796044, -2.1401483895470963`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{4.6944263543752545`, 0.0066450711378179496`}],
            
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0066450711378179496`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.0066450711378179496`], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7333882582665043, -0.6165221792947959}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792947959`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.11202118197195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665043, -0.6165221792947959], 
              Complex[1.8301368298409655`, -2.11202118197195]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.654309125631486, 0.00671251078585357}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00671251078585357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163378148560237`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.00671251078585357], 
              Complex[6.155525231634676, -1.163378148560237]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7629774456127985, -0.595285574569809}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.595285574569809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922253`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127985, -0.595285574569809], 
              Complex[1.8593666135298337`, -2.0894057490922253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.621891868208896, 0.006786025025047818}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047818], 
              Complex[6.122517060306257, -1.1633711130594218`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7891581377234363, -0.5773156862277907}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234363, -0.5773156862277907], 
              Complex[1.8852354657886532`, -2.0700333477056208`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.593955318850741, 0.006863336573144883}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850741, 0.006863336573144883], 
              Complex[6.093988110787665, -1.1633606215314773`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8130202409023957, -0.5615718710865845}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8130202409023957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.8130202409023957, -0.5615718710865845], 
              Complex[1.908828689419146, -2.0528681311196006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5690366318402065`, 0.006943461497604819}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5690366318402065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006943461497604819`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0684753004536836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.5690366318402065`, 0.006943461497604819], 
              Complex[6.0684753004536836`, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.83517014589239, -0.5474736791133894}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.83517014589239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756488`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.83517014589239, -0.5474736791133894], 
              Complex[1.9307493118589263`, -2.037333072756488]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5463246331431195`, 0.007025882918871677}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871677], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8559867126628716, -0.5346576120369374}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104826`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628716, -0.5346576120369374], 
              Complex[1.9513735684640645`, -2.023067278104826]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.525314237109773, 0.007110298008162857}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.525314237109773`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162857`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.525314237109773, 0.007110298008162857], 
              Complex[6.023558855884934, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8757255721593915, -0.5228778864146406}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5228778864146406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0098270287962983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593915, -0.5228778864146406], 
              Complex[1.970954950697273, -2.0098270287962983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5056658326490995`, 0.007196517077880171}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880171`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880171], 
              Complex[6.0033102912691545`, -1.163298779461846]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8945689747906647, -0.5119589442981474}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906647, -0.5119589442981474], 
              Complex[1.9896739101964118`, -1.9974384540079664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.487138168550514, 0.007284416332243443}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243443], 
              Complex[5.984180253839811, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9126523619522133, -0.501770106216405}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.501770106216405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522133, -0.501770106216405], 
              Complex[2.0076643409453063`, -1.9857722832958535`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.469552623884142, 0.007373913179256355}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884142`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256355`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884142, 0.007373913179256355], 
              Complex[5.965990045977095, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.930079710208937, -0.4922109148816922}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.930079710208937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304528`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.930079710208937, -0.4922109148816922], 
              Complex[2.0250288646775303`, -1.9747292562304528`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.452772601155933, 0.007464952252032765}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252032765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348616004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155933, 0.007464952252032765], 
              Complex[5.948603001807254, -1.1632386348616004`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9469329539089915, -0.4832021231088814}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4832021231088814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089915, -0.4832021231088814], 
              Complex[2.0418482129451156`, -1.9642311559465848`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.4366908876556685`, 0.007557496991161311}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4366908876556685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007557496991161311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413441`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.4366908876556685`, 0.007557496991161311], 
              Complex[5.931911846413441, -1.1632165013453943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9632780610078034, -0.474679874998177}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.474679874998177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078034, -0.474679874998177], 
              Complex[2.058187273894045, -1.9542150231143454`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.421221515937319, 0.007651524322599274}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937319, 0.007651524322599274], 
              Complex[5.915830554816421, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9791691098460459, -0.46659179640833626`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460459`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460459, -0.46659179640833626`], 
              Complex[2.074099147574047, -1.944629270704492]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.406294309063905, 0.007747021157199403}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157199403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632698`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063905, 0.007747021157199403], 
              Complex[5.900288896133163, -1.1631693310632698`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9946511165926869, -0.45889427989730996`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926869`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926869, -0.45889427989730996`], 
              Complex[2.0896279570988043`, -1.9354309873904443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.391851102143665, 0.007843982012263393}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143665`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143665, 0.007843982012263393], 
              Complex[5.885228654304802, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.009762051806892, -0.451550545734929}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.451550545734929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806892, -0.451550545734929], 
              Complex[2.1048108525831095`, -1.9265840128958296`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377843050837107, 0.007942407351017726}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351017726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837107, 0.007942407351017726], 
              Complex[5.870600935988342, -1.1631183993398435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0245343135360971`, -0.4445292235923789}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0245343135360971`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4445292235923789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9180575310211605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.0245343135360971`, -0.4445292235923789], 
              Complex[2.119679474265543, -1.9180575310211605`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3642286676832285`, 0.008042302396705217}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.008042302396705217], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0389958259885548`, -0.43780329333443585`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885548`, -0.43780329333443585`], 
              Complex[2.1342610431682965`, -1.9098250195461772`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.350972359395372, 0.008143676269233518}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233518`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233518], 
              Complex[5.842482826256842, -1.1630637508268276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0531708739791166`, -0.43134927949334917`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949334917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1485791890132715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9018634521265014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791166`, -0.43134927949334917`], 
              Complex[2.1485791890132715`, -1.9018634521265014`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.338043317353645, 0.008246541346654023}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654023`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353645, 0.008246541346654023], 
              Complex[5.828925941917193, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0670807469468016`, -0.4251466287655521}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4251466287655521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468016`, -0.4251466287655521], 
              Complex[2.1626545888502196`, -1.8941526819126024`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3254146624079155`, 0.00835091278661437}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3254146624079155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00835091278661437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.3254146624079155`, 0.00835091278661437], 
              Complex[5.815666629983416, -1.1630053621640015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0807442431495677`, -0.41917722203755886`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41917722203755886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495677`, -0.41917722203755886`], 
              Complex[2.1765054667524413`, -1.8866749586802056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3130627762344576`, 0.008456808164000539}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008456808164000539`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.008456808164000539], 
              Complex[5.802681228429218, -1.1629747445437835`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0941780694739511`, -0.4134249869532397}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4134249869532397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739511`, -0.4134249869532397], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.300966771833883, 0.008564247194411546}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411546`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411546], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.107397162145416, -0.407875586750141}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.407875586750141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145416, -0.407875586750141], 
              Complex[2.203596585722579, -1.8723574121967346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2891080693657475`, 0.008673251522090974}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2891080693657475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008673251522090974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.2891080693657475`, 0.008673251522090974], 
              Complex[5.777450742552285, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.120414946688531, -0.402516167736111}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.120414946688531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.402516167736111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.120414946688531, -0.402516167736111], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.277470052807503, 0.008783844556995704}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995704], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1332435506568053`, -0.39733515240586287`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568053`, -0.39733515240586287`], 
              Complex[2.2299625053481065`, -1.8588039393045297`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.266037789390484, 0.008896051349859014}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349859014`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349859014], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1458939792326723`, -0.3923220684765708}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326723`, -0.3923220684765708], 
              Complex[2.2429020774149047`, -1.8522860400567263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2547977983402, 0.009009898497033198}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2547977983402`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033198`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.2547977983402, 0.009009898497033198], 
              Complex[5.741204286938841, -1.1628068690797766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1583762613396098`, -0.38746740648134814`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396098`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396098`, -0.38746740648134814`], 
              Complex[2.2556925367556304`, -1.8459279915891427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.243737858735289, 0.009125414068990407}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990407], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1706995721155868`, -0.3827625002813666}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3827625002813666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155868`, -0.3827625002813666], 
              Complex[2.2683426708688654`, -1.839721324914159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.232846848694922, 0.009242627557842194}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842194`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694922, 0.009242627557842194], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1828723362728415`, -0.3781994261302764}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3781994261302764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728415`, -0.3781994261302764], 
              Complex[2.280860535897551, -1.8336582973639242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.222114609872632, 0.009361569840391628}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391628], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1949023158791765`, -0.37377091687665037`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37377091687665037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.29325354314301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791765`, -0.37377091687665037`], 
              Complex[2.29325354314301, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.211531832555507, 0.009482273153988769}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988769`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555507, 0.009482273153988769], 
              Complex[5.695312895009786, -1.162653682569163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2067966853478913`, -0.3694702886103212}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3694702886103212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.3694702886103212], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.201089957665183, 0.009604771083122507}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122507`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122507], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2185620958524552`, -0.36529137760862784`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862784`], 
              Complex[2.317691837968342, -1.8162628290107483`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.190781092718281, 0.009729098555121803}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121803`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121803], 
              Complex[5.67322985816244, -1.1625702788705319`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2302047309418302`, -0.3612284858628572}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418302`, -0.3612284858628572], 
              Complex[2.329749338128146, -1.8107087471951673`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1805979393900845`, 0.009855291843704473}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1805979393900845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009855291843704473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.1805979393900845`, 0.009855291843704473], 
              Complex[5.662375502422984, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2417303547902065`, -0.35727633379543633`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35727633379543633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.35727633379543633`], 
              Complex[2.3417065077888246`, -1.8052679202454813`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.170533730780807, 0.009983388579384774}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384774], 
              Complex[5.651636660481891, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2531443542465808`, -0.353430019037376}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2531443542465808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.353430019037376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7999355549805414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.2531443542465808`, -0.353430019037376], 
              Complex[2.353568457177236, -1.7999355549805414`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.16058217684066, 0.010113427765967315`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967315`], 
              Complex[5.6410069952433215`, -1.1624360273853818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2644517756377347`, -0.34968498034030016`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034030016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377347`, -0.34968498034030016`], 
              Complex[2.3653399684829126`, -1.7947071904178582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.150737416691642, 0.010245449802525817`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.150737416691642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.150737416691642, 0.010245449802525817`], 
              Complex[5.630480598081045, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2756573571094836`, -0.34603696586050614`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2756573571094836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34603696586050614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.2756573571094836`, -0.34603696586050614`], 
              Complex[2.3770255275795718`, -1.7895786667158646`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140993976808082, 0.01037949651040011}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040011], 
              Complex[5.620051946974447, -1.1623400583917027`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2867655571559535`, -0.3424820051832389}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2867655571559535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3424820051832389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.784546097796433`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.2867655571559535`, -0.3424820051832389], 
              Complex[2.3886293519885573`, -1.784546097796433]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.131346734197311, 0.010515611164854404`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854404`], 
              Complex[5.609715869645587, -1.1622900299949552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2977805798777453`, -0.33901638456088035`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2977805798777453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33901638456088035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.2977805798777453`, -0.33901638456088035`], 
              Complex[2.4001554156192917`, -1.7796058471281269`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.121790883866403, 0.0106538385311294}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0106538385311294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.0106538385311294], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3087063974214084`, -0.33563662492447366`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214084`, -0.33563662492447366`], 
              Complex[2.4116074707342534`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11232190997813, 0.010794224904694064`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694064`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3195467699805936`, -0.3323394622978912}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3195467699805936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.3195467699805936`, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685131`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102935560194784, 0.010936818155564418`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194784`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564418`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194784, 0.010936818155564418`], 
              Complex[5.579215944909335, -1.1621313167255456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3303052636801032`, -0.3291218303014387}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014387], 
              Complex[2.434303571543257, -1.765305947424264]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093627822786881, 0.01108166777660794}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.01108166777660794], 
              Complex[5.569204368643545, -1.162075401828133]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.340985266615273, -0.32598084447903347`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.340985266615273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7607028906574198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.340985266615273, -0.32598084447903347`], 
              Complex[2.4455541794767464`, -1.7607028906574198`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.084394906148223, 0.011228824935798505`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162017910531272`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798505`], 
              Complex[5.559263729872352, -1.162017910531272]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3515900032787673`, -0.32291378822242106`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3515900032787673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.456743933131439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.3515900032787673`, -0.32291378822242106`], 
              Complex[2.456743933131439, -1.7561770369578587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.075233220412342, 0.011378342532423352`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423352`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.011378342532423352`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.362122547573208, -0.3199181000986168}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.46787573218371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573208, -0.3199181000986168], 
              Complex[2.46787573218371, -1.7517258685037118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.066139360909642, 0.01153027525728}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525728], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3725858345799589`, -0.31699136241415293`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799589`, -0.31699136241415293`], 
              Complex[2.478952345649963, -1.7473470068263872`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.057110093241812, 0.011684679656931245`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931245`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3829826712308153`, -0.3141312908727419}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3829826712308153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3141312908727419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.3829826712308153`, -0.3141312908727419], 
              Complex[2.4899764222920586`, -1.7430382027464775`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.04814233978115, 0.011841614202115795`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115795`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.393315746009415, -0.3113357252023987}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.393315746009415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586887`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.393315746009415, -0.3113357252023987], 
              Complex[2.500950500073135, -1.7387973272586887`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.039233167428712, 0.012001139360437757`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428712, 0.012001139360437757`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4035876377924144`, -0.30860262064445376`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30860262064445376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7346223632600883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924144`, -0.30860262064445376`], 
              Complex[2.5118770147723373`, -1.7346223632600883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.030379776487371, 0.012163317673485314`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485314`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485314`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4138008239261337`, -0.30593004021100256`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261337`, -0.30593004021100256`], 
              Complex[2.5227583078528273`, -1.7305113980298923`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.021579490524692, 0.012328213838552494`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552494`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552494`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4239576876222577`, -0.3033161476291149}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291149`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7264626163806056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222577`, -0.3033161476291149], 
              Complex[2.5335966336654487`, -1.7264626163806056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.012829747116558, 0.012495894795164319`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164319`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4340605247457119`, -0.3007592009004861}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4340605247457119`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3007592009004861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.722474294410549`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.4340605247457119`, -0.3007592009004861], 
              Complex[2.5443941660601186`, -1.722474294410549]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.004128089376172, 0.012666429816627385`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.472443222555007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376172, 0.012666429816627385`], 
              Complex[5.472443222555007, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4441115500589807`, -0.2982575464138699}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2982575464138699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589807`, -0.2982575464138699], 
              Complex[2.5551530044682584`, -1.7185447937963196`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.995472158184808, 0.012839890606854726`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854726`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4541129029793964`, -0.2958096135553037}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4541129029793964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2958096135553037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713101`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.4541129029793964`, -0.2958096135553037], 
              Complex[2.5658751795119747`, -1.7146725565713101`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.986859685050743, 0.013016351402742186`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742186`], 
              Complex[5.453670720869239, -1.161267218035427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4640666528993391`, -0.2934139097675647}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993391`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2934139097675647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.576562658189158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.710856100342705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993391`, -0.2934139097675647], 
              Complex[2.576562658189158, -1.710856100342705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9782884855315257`, 0.013195889082391402`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391402`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391402`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4739748041135787`, -0.29106901601605945`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135787`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.7070940139050703`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.969756453162239, 0.013378583279512466`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.969756453162239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.969756453162239, 0.013378583279512466`], 
              Complex[5.435044890840144, -1.161103942175881]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.483839300392978, -0.2887735826232169}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134369`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134369`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9612615538389253`, 0.013564516504362826`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9612615538389253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362826`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.9612615538389253`, 0.013564516504362826`], 
              Complex[5.425781575481577, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4936620292395195`, -0.28652632543776696`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395195`, -0.28652632543776696`], 
              Complex[2.608435730175938, -1.6997276376830055`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.952801820612014, 0.013753774271608687`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612014, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5034448258538131`, -0.2843260223090579}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5034448258538131`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2843260223090579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.696120846786332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.5034448258538131`, -0.2843260223090579], 
              Complex[2.619002982102259, -1.696120846786332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9443753488495013`, 0.013946445235532942`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013946445235532942`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.013946445235532942`], 
              Complex[5.407343930794649, -1.1608408715855627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5131894768429806`, -0.2821715098398554}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5131894768429806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2821715098398554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.5131894768429806`, -0.2821715098398554], 
              Complex[2.629544575183533, -1.6925634169220718`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9359802917339604`, 0.014142621333044086`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044086`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.014142621333044086`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5228977236939463`, -0.28006168039394325`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939463`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28006168039394325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939463`, -0.28006168039394325`], 
              Complex[2.640062184735898, -1.6890542385321832`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.927614856061183, 0.014342397934981635`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.532571266034649, -0.2779954793374566}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.532571266034649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.532571266034649, -0.2779954793374566], 
              Complex[2.6505574499902775`, -1.6855922534470884`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9192772983115907`, 0.014545874006250856`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1605540685141238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250856`], 
              Complex[5.379881023870965, -1.1605540685141238`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5422117647034568`, -0.2759719024950623}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034568`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034568`, -0.2759719024950623], 
              Complex[2.661031977113044, -1.6821764524403942`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.910965920968408, 0.014753152275367238`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367238`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5518208446451711`, -0.2739899938041933}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451711`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2739899938041933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768787`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451711`, -0.2739899938041933], 
              Complex[2.6714873420627194`, -1.6788058729768787`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9026790690591686`, 0.01496433941403484}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01496433941403484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.01496433941403484], 
              Complex[5.36168012892486, -1.1603484877775454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5614000976502445`, -0.27204884315225397`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6754795971390901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502445`, -0.27204884315225397`], 
              Complex[2.68192509329917, -1.6754795971390901`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.894415126899331, 0.015179546227436348`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436348`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5709510849523987`, -0.27014758438335235`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.672196749719544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335235`], 
              Complex[2.692346754360388, -1.672196749719544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8861725150187785`, 0.015398887855965262`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965262`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965262`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5804753396984255`, -0.2682853934625309}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2682853934625309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.2682853934625309], 
              Complex[2.702753826320577, -1.6689564964669]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8779496872537016`, 0.015622483989198311`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198311`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5899743693028514`, -0.26646148678673626`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028514`, -0.26646148678673626`], 
              Complex[2.713147790142197, -1.6657580424757261`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.869745127987924, 0.015850459092959724`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.869745127987924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.869745127987924, 0.015850459092959724`], 
              Complex[5.325475035055747, -1.1598991714712616`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.599449657699079, -0.26467511963294027`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.599449657699079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.723530108933592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.662600630710649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.599449657699079, -0.26467511963294027`], 
              Complex[2.723530108933592, -1.662600630710649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.86155734952905, 0.016082942650415957`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.86155734952905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.86155734952905, 0.016082942650415957`], 
              Complex[5.316455202430541, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6089026674977167`, -0.2629255847348711}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.73390223012297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348711], 
              Complex[2.73390223012297, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8533848896060525`, 0.016320069418202337`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.016320069418202337`], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6183348420620056`, -0.2612122109807515}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.74426558755872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620056`, -0.2612122109807515], 
              Complex[2.74426558755872, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8452263089759495`, 0.016561979698683872`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016561979698683872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759495`, 0.016561979698683872`], 
              Complex[5.298442228350345, -1.159525179549259]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.62774760750956, -0.2595343622253305}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.62774760750956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.62774760750956, -0.2595343622253305], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.837080189128189, 0.016808819629533102`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533102`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6371423746489984`, -0.2578914362102898}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6371423746489984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.6371423746489984`, -0.2578914362102898], 
              Complex[2.7649716908242423`, -1.6503675183549191`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8289451300761317`, 0.017060741491919468`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761317`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761317`, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6465205408595245`, -0.25628286358783076`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25628286358783076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595245`, -0.25628286358783076`], 
              Complex[2.775317254506115, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.820819748225798, 0.017317904038714273`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.017317904038714273`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6558834919210366`, -0.2547081070429701}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2547081070429701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6444801086473986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210366`, -0.2547081070429701], 
              Complex[2.7856596939652976`, -1.6444801086473986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.812702674312651, 0.017580472844237652`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237652`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.017580472844237652`], 
              Complex[5.262480372776144, -1.1589703924863026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6652326038019236`, -0.2531666605106764}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106764], 
              Complex[2.796000404700961, -1.6415917218573373`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8045925513977634`, 0.017848620677213597`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213597`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6745692444113933`, -0.2516580484846374}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.2516580484846374], 
              Complex[2.8063407801738802`, -1.6387395459042158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7964880329151702`, 0.01812252789874474}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7964880329151702`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01812252789874474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.7964880329151702`, 0.01812252789874474], 
              Complex[5.24450758044773, -1.1586661938251577`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.683894775322847, -0.2501818254149767}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.683894775322847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.683894775322847, -0.2501818254149767], 
              Complex[2.8166822136251173`, -1.6359231169716286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7883877807626547`, 0.018402382887287794`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287794`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770964`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287794`], 
              Complex[5.235518056794404, -1.1585067947770964`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6932105534745872`, -0.24873757519284695`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745872`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24873757519284695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745872`, -0.24873757519284695`], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7802904634285417`, 0.018688382492788258`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788258`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788258`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.702517932853939, -0.24732491072033722`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.702517932853939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.702517932853939, -0.24732491072033722`], 
              Complex[2.8373738371679265`, -1.6303957901157309`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.772194754147412, 0.018980732522336754`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336754`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7118182661707113`, -0.24594347356467763`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7118182661707113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.7118182661707113`, -0.24594347356467763`], 
              Complex[2.847726828892449, -1.6276841087738216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.764099329077837, 0.019279648259931007`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.764099329077837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259931007`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.764099329077837, 0.019279648259931007`], 
              Complex[5.208519392705084, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7211129065258048`, -0.24459293369624518`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24459293369624518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258048`, -0.24459293369624518`], 
              Complex[2.8580864854780335`, -1.6250066071493985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7560028654954847`, 0.01958535502317052}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954847`, 0.01958535502317052], 
              Complex[5.199504918610362, -1.1578159953084997`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7304032090806973`, -0.24327298931041919`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041919`], 
              Complex[2.8684542261798467`, -1.6223629642431856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.747904039995081, 0.01989808875998757}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995081`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995081, 0.01989808875998757], 
              Complex[5.190480530819804, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7396905327334806`, -0.24198336673385487`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7396905327334806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.7396905327334806`, -0.24198336673385487`], 
              Complex[2.8788314809349766`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.739801526694796, 0.02021809668881551}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02021809668881551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.02021809668881551], 
              Complex[5.181444746812216, -1.1574356372128114`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7489762418071484`, -0.24072382041628868`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978096`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071484`, -0.24072382041628868`], 
              Complex[2.8892196922375377`, -1.6171761114978096`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7316939954367316`, 0.020545637985932966`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985932966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985932966`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7582617077558227`, -0.23949413300958758`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7582617077558227`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23949413300958758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.7582617077558227`, -0.23949413300958758`], 
              Complex[2.8996203170476367`, -1.6146324008788793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7235801099771857`, 0.020880984524094977`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7235801099771857`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020880984524094977`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.7235801099771857`, 0.020880984524094977`], 
              Complex[5.163333010028644, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7675483108947159`, -0.2382941155363086}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947159`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947159`, -0.2382941155363086], 
              Complex[2.910034828740951, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7154585261603423`, 0.021224421666976127`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603423`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976127`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.154254035959911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603423`, 0.021224421666976127`], 
              Complex[5.154254035959911, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7768374421596609`, -0.2371236076506873}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7768374421596609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.7768374421596609`, -0.2371236076506873], 
              Complex[2.920464719105737, -1.6096433738762481`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.707327890069032, 0.02157624912441267}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7861305049022491`, -0.23598247799562655`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022491`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60719772995439`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022491`, -0.23598247799562655`], 
              Complex[2.930911500394466, -1.60719772995439]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6991868361460636`, 0.02193678187394727}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02193678187394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.02193678187394727], 
              Complex[5.136042207268361, -1.1563665913076093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7954289167267063`, -0.2348706246599857}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2348706246599857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267063`, -0.2348706246599857], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6910339852795415`, 0.022306351154756366`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795415`, 0.022306351154756366`], 
              Complex[5.126906229415364, -1.1561301764198548`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.804734111374893, -0.2337879757412097}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.804734111374893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.804734111374893, -0.2337879757412097], 
              Complex[2.9518618998259756`, -1.6024035870060644`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6828679428453777`, 0.022685305540684483`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684483`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8140475406660062`, -0.23273449001922947`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8140475406660062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23273449001922947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.600054942965845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.8140475406660062`, -0.23273449001922947`], 
              Complex[2.9623686641736464`, -1.600054942965845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.674687296700069, 0.0230740120998301}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.674687296700069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0230740120998301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1556320583248079`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.674687296700069, 0.0230740120998301], 
              Complex[5.108566172536498, -1.1556320583248079`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.823370676497873, -0.23171015774841427`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.823370676497873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23171015774841427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.597738540667868`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.823370676497873, -0.23171015774841427`], 
              Complex[2.9728986164633167`, -1.597738540667868]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6664906151164782`, 0.023472857648944804`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944804`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944804`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8327050129169928`, -0.2307150015754318}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169928`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2307150015754318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.595454389327372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169928`, -0.2307150015754318], 
              Complex[2.9834534044896497`, -1.595454389327372]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6582764446551637`, 0.02388225011180803}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02388225011180803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.02388225011180803], 
              Complex[5.090124379020649, -1.1550976637063441`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.842052068264839, -0.2297490775919429}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.842052068264839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.842052068264839, -0.2297490775919429], 
              Complex[2.994034710406032, -1.5932025328859931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.650043307963434, 0.024302619991774112`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.650043307963434`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774112`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.650043307963434, 0.024302619991774112`], 
              Complex[5.080861117956596, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8514133874083418`, -0.2288124765322978}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2288124765322978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.2288124765322978], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6417897014939595`, 0.024734421969833963`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6417897014939595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024734421969833963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.6417897014939595`, 0.024734421969833963`], 
              Complex[5.071567299655017, -1.1545236028247543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8607905440628354`, -0.22790532512782383`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8607905440628354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.588796062507649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.8607905440628354`, -0.22790532512782383`], 
              Complex[3.015283792410421, -1.588796062507649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6335140931343686`, 0.025178136640842938`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6335140931343686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025178136640842938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.6335140931343686`, 0.025178136640842938`], 
              Complex[5.0622411413021275`, -1.1542205266440744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8701851432162648`, -0.22702778763077067`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5866417233196022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162648`, -0.22702778763077067`], 
              Complex[3.0259551291896347`, -1.5866417233196022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6252149197388337`, 0.025634272402031193`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6252149197388337`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025634272402031193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.6252149197388337`, 0.025634272402031193`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8795988236639012`, -0.2261800675227635}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2261800675227635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.2261800675227635], 
              Complex[3.036660111236013, -1.5845202322015453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.616890584552165, 0.026103367509584273`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.616890584552165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026103367509584273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.616890584552165, 0.026103367509584273`], 
              Complex[5.0434844640179035`, -1.153579687141173]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8890332606633722`, -0.22536240942454497`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454497`], 
              Complex[3.0474006350962966`, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.608539454516405, 0.026585992320965892`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.608539454516405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.608539454516405, 0.026585992320965892`], 
              Complex[5.034050160698049, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.898490168720361, -0.22457510122598107`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.898490168720361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.898490168720361, -0.22457510122598107`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6001598574493725`, 0.027082751742796514`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796514`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796514`], 
              Complex[5.024575941774229, -1.152888750780241]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9079713045159428`, -0.2238184764577979}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2238184764577979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.2238184764577979], 
              Complex[3.068996160253663, -1.5783554980412635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5917500790840506`, 0.027594287906544515`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027594287906544515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840506`, 0.027594287906544515`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.917478469987143, -0.22309291692935712`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.917478469987143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.917478469987143, -0.22309291692935712`], 
              Complex[3.0798552314489043`, -1.5763682904678327`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5833083599570257`, 0.028121283097053456`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5833083599570257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.028121283097053456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.5833083599570257`, 0.028121283097053456`], 
              Complex[5.005499610747705, -1.15214256927739]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9270135155729469`, -0.22239885565995504`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9270135155729469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.090757992080275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.574415627556381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.9270135155729469`, -0.22239885565995504`], 
              Complex[3.090757992080275, -1.574415627556381]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.57483289213363, 0.028664462962103714`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.57483289213363`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028664462962103714`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.57483289213363, 0.028664462962103714`], 
              Complex[4.9958932747662494`, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9365783436386605`, -0.22173678013483517`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386605`, -0.22173678013483517`], 
              Complex[3.1017066390111183`, -1.5724980106155322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5663218157567322`, 0.029224600034819134`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5663218157567322`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.029224600034819134`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.5663218157567322`, 0.029224600034819134`], 
              Complex[4.986238567027153, -1.1513352953732714`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9461749120921603`, -0.2211072359212472}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2211072359212472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.11270344175382`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.2211072359212472], 
              Complex[3.11270344175382, -1.5706160035957248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.557773215405521, 0.02980251760487485}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.02980251760487485], 
              Complex[4.976533205571878, -1.1509067011120155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.955805238206233, -0.22051083068468322`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.955805238206233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22051083068468322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1237507472684634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.955805238206233, -0.22051083068468322`], 
              Complex[3.1237507472684634`, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5491851162499515`, 0.030399093979211297`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211297`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211297`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.965471402661748, -0.21994823865092963`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092963`], 
              Complex[3.134850985060283, -1.5669614161122607`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.540555479985998, 0.031015267178413918`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413918`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9751755538269589`, -0.21942020556585187`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5651903202724238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269589`, -0.21942020556585187`], 
              Complex[3.146006672598036, -1.5651903202724238`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5318822005363093`, 0.03165204012119633}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5318822005363093`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03165204012119633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.5318822005363093`, 0.03165204012119633], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9849199122885905`, -0.21892755421211502`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9849199122885905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21892755421211502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.9849199122885905`, -0.21892755421211502`], 
              Complex[3.157220421076431, -1.5634578154860739`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.523163099500529, 0.03231048635665909}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.523163099500529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665909`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923016`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.523163099500529, 0.03231048635665909], 
              Complex[4.937156797033987, -1.1490036558923016`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9947067756505612`, -0.21847119055042033`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505612`, -0.21847119055042033`], 
              Complex[3.1684949415466472`, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5143959213393177`, 0.03299175641234989}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234989], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0045385236161377`, -0.21805211056251347`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0045385236161377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1798330514396453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5601125038693655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.0045385236161377`, -0.21805211056251347`], 
              Complex[3.1798330514396453`, -1.5601125038693655`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.505578328276208, 0.033697084835816196`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.033697084835816196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.033697084835816196`], 
              Complex[4.917099209420433, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0144176233688644`, -0.2176714078844632}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0144176233688644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2176714078844632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.0144176233688644`, -0.2176714078844632], 
              Complex[3.191237681507363, -1.5585019153641582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.496707894901857, 0.03442779801852973}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.496707894901857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.496707894901857, 0.03442779801852973], 
              Complex[4.906968264234699, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0243466352667063`, -0.21733028233169854`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.202711883206814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5569343729898864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667063`, -0.21733028233169854`], 
              Complex[3.202711883206814, -1.5569343729898864`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4877821024662152`, 0.03518532290406062}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03518532290406062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.03518532290406062], 
              Complex[4.896765181899932, -1.1467428812221834`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.034328218862186, -0.21703004943242474`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.21703004943242474`], 
              Complex[3.2142588365513363`, -1.5554112852390443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4787983328457113`, 0.0359711966974785}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4787983328457113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0359711966974785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.4787983328457113`, 0.0359711966974785], 
              Complex[4.886486777365879, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.044365139258773, -0.21677215110365747`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.044365139258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2258818584516473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.044365139258773, -0.21677215110365747`], 
              Complex[3.2258818584516473`, -1.5539342010442931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4697538621751725`, 0.036787077710537165`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4697538621751725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.036787077710537165`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.145449795275427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.4697538621751725`, 0.036787077710537165`], 
              Complex[4.8761297293312476`, -1.145449795275427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.054460273810074, -0.21655816762459842`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.21655816762459842`], 
              Complex[3.237584411566567, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4606458541378564`, 0.037634757497710815`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4606458541378564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.037634757497710815`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.865690571363539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.4606458541378564`, 0.037634757497710815`], 
              Complex[4.865690571363539, -1.1447564293886003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0646166191629156`, -0.2163898310860748}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2163898310860748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.551125025378486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.2163898310860748], 
              Complex[3.249370113678695, -1.551125025378486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.45147135291243, 0.03851617446207765}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.45147135291243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03851617446207765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.45147135291243, 0.03851617446207765], 
              Complex[4.855165682495278, -1.1440291063659587`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0748372986380024`, -0.21626904052272816`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21626904052272816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54979686643061`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380024`, -0.21626904052272816`], 
              Complex[3.2612427476037626`, -1.54979686643061]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.442227275783197, 0.03943342913804186}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804186], 
              Complex[4.844551277287891, -1.1432655464271395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0851255699314044`, -0.2161978789674407}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2161978789674407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.2161978789674407], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4329104054302237`, 0.040388801390635616`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302237`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.040388801390635616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302237`, 0.040388801390635616`], 
              Complex[4.833843395364208, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0954848331061537`, -0.21617863270584645`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.285264830490968`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584645`], 
              Complex[3.285264830490968, -1.5473047611339115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.423517381930075, 0.041384769809504604`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.041384769809504604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.041384769809504604`], 
              Complex[4.823037890424123, -1.1416195640990148`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.105918638824221, -0.21621381305374007`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.105918638824221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.105918638824221, -0.21621381305374007`], 
              Complex[3.2974227667841576`, -1.546146059999975]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4140446945168277`, 0.04242403362064922}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04242403362064922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.04242403362064922], 
              Complex[4.812130418776984, -1.1407314794193446`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1164306967437954`, -0.21630618103294616`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1164306967437954`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21630618103294616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.1164306967437954`, -0.21630618103294616`], 
              Complex[3.3096846328660448`, -1.5450495423633643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.404488673178392, 0.0435095374916808}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.404488673178392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0435095374916808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.404488673178392, 0.0435095374916808], 
              Complex[4.801116427450052, -1.1397957791050348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1270248839729087`, -0.2164587753829217}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1270248839729087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2164587753829217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.322055203038721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.544018556274634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.1270248839729087`, -0.2164587753829217], 
              Complex[3.322055203038721, -1.544018556274634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3948454801970804`, 0.044644499668114845`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114845`], 
              Complex[4.78999114196779, -1.1388089172545461`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1377052534254433`, -0.21667494441768215`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1377052534254433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175475`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.1377052534254433`, -0.21667494441768215`], 
              Complex[3.334539485939788, -1.5430568024175475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3851111017883304`, 0.04583244395046668}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04583244395046668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.04583244395046668], 
              Complex[4.778749553944276, -1.1377669993932333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1484760418658873`, -0.21695838232209197`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209197`], 
              Complex[3.347142736911111, -1.5421683765599408`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.375281340051193, 0.04707723610641667}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.375281340051193`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04707723610641667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.375281340051193, 0.04707723610641667], 
              Complex[4.767386408695089, -1.136665739909798]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.15934167735015, -0.21731317057992386`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.541357818133694`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992386`], 
              Complex[3.359870470056671, -1.541357818133694]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.365351805523236, 0.048383125410603633`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410603633`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.135500413367616`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.048383125410603633`], 
              Complex[4.755896193160949, -1.135500413367616]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1703067856653018`, -0.21774382534019787`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1703067856653018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21774382534019787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.372728469582494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5406301659307435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.1703067856653018`, -0.21774382534019787`], 
              Complex[3.372728469582494, -1.5406301659307435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.355317910736984, 0.04975479211876499}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.355317910736984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.355317910736984, 0.04975479211876499], 
              Complex[4.744273124550121, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.181376195232895, -0.21825535165973986`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165973986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.21825535165973986`], 
              Complex[3.385722799858256, -1.5399910220686328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3451748653131745`, 0.05119740181429549}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3451748653131745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05119740181429549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622778`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.3451748653131745`, 0.05119740181429549], 
              Complex[4.732511140259883, -1.1329561151622778`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.192554939758106, -0.2188533057099164}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.192554939758106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2188533057099164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.192554939758106, -0.2188533057099164], 
              Complex[3.398859813435927, -1.5394466255711587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3349176733086154`, 0.05271666771536838}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05271666771536838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.05271666771536838], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2038482576658165`, -0.21954386620430988`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21954386620430988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.21954386620430988`], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3245411337774544`, 0.05431892219952717}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952717], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.215261587046473, -0.2203339164903332}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.215261587046473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.215261587046473, -0.2203339164903332], 
              Complex[3.4255887667699514`, -1.5386707368477486`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3140398458230234`, 0.05601119898888099}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3140398458230234`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.3140398458230234`, 0.05601119898888099], 
              Complex[4.696326724353139, -1.1285088210227603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.226800554414456, -0.22123113894674903`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.226800554414456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22123113894674903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.226800554414456, -0.22123113894674903`], 
              Complex[3.4391948727143986`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3034082198375008`, 0.057801327638013905`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375008`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.057801327638013905`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375008`, 0.057801327638013905`], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2384709550276787`, -0.22224412353114367`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2384709550276787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22224412353114367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.2384709550276787`, -0.22224412353114367`], 
              Complex[3.4529719736549263`, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.292640497180629, 0.05969804216878783}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180629, 0.05969804216878783], 
              Complex[4.671385007001144, -1.1250298694138174`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2502787217879465`, -0.22338249250843537`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2502787217879465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.2502787217879465`, -0.22338249250843537`], 
              Complex[3.4669278152904948`, -1.5384206511375547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.281730781277995, 0.06171110588324314}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.281730781277995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.281730781277995, 0.06171110588324314], 
              Complex[4.658646056679823, -1.1231061803689848`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2622298787838813`, -0.22465704353173377`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22465704353173377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838813`, -0.22465704353173377`], 
              Complex[3.481070345408924, -1.5386239263253445`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.270673084076976, 0.0638514545260297}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0638514545260297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.0638514545260297], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.274330474286138, -0.22607991328743204`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.259461393050655, 0.06613136000835815}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.259461393050655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.259461393050655, 0.06613136000835815], 
              Complex[4.6325923193910725`, -1.1188275290397083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.286586486377321, -0.2276647637711864}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.286586486377321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2276647637711864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.286586486377321, -0.2276647637711864], 
              Complex[3.509947843100934, -1.5395421364907356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2480897655672787`, 0.06856461676025169}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672787`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672787`, 0.06856461676025169], 
              Complex[4.619261335536664, -1.1164425322748182`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.299003692304085, -0.22942699279424644`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.299003692304085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.299003692304085, -0.22942699279424644`], 
              Complex[3.5246989546875493`, -1.5402906900657318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.236552459537739, 0.07116675231062836}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.236552459537739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.236552459537739, 0.07116675231062836], 
              Complex[4.605716884708898, -1.1138704540789932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3115874899792836`, -0.23138396931833938`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3115874899792836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23138396931833938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5412583702907805`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.3115874899792836`, -0.23138396931833938`], 
              Complex[3.5396687117196857`, -1.5412583702907805`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.224844111913217, 0.07395526269357484}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.224844111913217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.224844111913217, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3243426567556305`, -0.2335552923600304}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3243426567556305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.3243426567556305`, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046266`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2129599799115014`, 0.07694987142173917}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2129599799115014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07694987142173917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.2129599799115014`, 0.07694987142173917], 
              Complex[4.577957240848536, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3372730266129884`, -0.23596306901323055`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23596306901323055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136321`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.23596306901323055`], 
              Complex[3.5702919304393554`, -1.5439457760136321`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.200896263829859, 0.08017280757570089}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.200896263829859`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.200896263829859, 0.08017280757570089], 
              Complex[4.563728632846571, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3503810623577235`, -0.23863220192231416`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5457208265493538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577235`, -0.23863220192231416`], 
              Complex[3.5859564964599837`, -1.5457208265493538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1886505348460092`, 0.08364909334179298}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1886505348460092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08364909334179298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.1886505348460092`, 0.08364909334179298], 
              Complex[4.549260572342167, -1.1012616980470775`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.363667294709622, -0.24159066834690393`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.363667294709622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24159066834690393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.363667294709622, -0.24159066834690393`], 
              Complex[3.601860790294312, -1.5478264033073155`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1762222959316895`, 0.08740682313953875}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1762222959316895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08740682313953875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.1762222959316895`, 0.08740682313953875], 
              Complex[4.534550258420688, -1.097389646163949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3771295961517174`, -0.24486976056502383`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.618004732680665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5502998152929643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517174`, -0.24486976056502383`], 
              Complex[3.618004732680665, -1.5502998152929643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1636137080034556`, 0.09147740408549995}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034556`, 0.09147740408549995], 
              Complex[4.519597775965092, -1.0931607636269258`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3907622559358286`, -0.24850423935263444`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358286`, -0.24850423935263444`], 
              Complex[3.6343842753970157`, -1.5531827657019452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.150830514917903, 0.09589570953158887}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.150830514917903`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.150830514917903, 0.09589570953158887], 
              Complex[4.50440717897338, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.404554826889629, -0.25253232740394754`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889629, -0.25253232740394754`], 
              Complex[3.650990035081119, -1.5565214356849035`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1378831966654945`, 0.10070007254234242`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1378831966654945`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10070007254234242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.1378831966654945`, 0.10070007254234242`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4184907299124174`, -0.2569954375693104}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5603662733822412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.667805619167919, -1.5603662733822412`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1247883648757773`, 0.10593201418800258`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1247883648757773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10593201418800258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.1247883648757773`, 0.10593201418800258`], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4325456359616355`, -0.2619374941172033}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2619374941172033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.684805656152575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647713188313286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.2619374941172033], 
              Complex[3.684805656152575, -1.5647713188313286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1115703808320063`, 0.11163556486001087`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320063`, 0.11163556486001087`], 
              Complex[4.457537610074802, -1.0717748675240164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4466857074528354`, -0.2674036718059931}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059931], 
              Complex[3.7019536132591466`, -1.5697928508801493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0982631140723664`, 0.11785600339463051`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0982631140723664`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.0982631140723664`, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.460865879669165, -0.27343836455892556`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.460865879669165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7191996003365837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5754871190552315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.460865879669165, -0.27343836455892556`], 
              Complex[3.7191996003365837`, -1.5754871190552315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.084911660981809, 0.12463782579822877`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981809, 0.12463782579822877`], 
              Complex[4.425499081603798, -1.0576646374765928`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.475028497636533, -0.2800822323034718}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.475028497636533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.475028497636533, -0.2800822323034718], 
              Complex[3.736478521301462, -1.5819069561624788`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.071573707918283, 0.1320217921353984}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918283`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4093941501489144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918283, 0.1320217921353984], 
              Complex[4.4093941501489144`, -1.0495628600775768`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.489102772743466, -0.2873682998621297}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.489102772743466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2873682998621297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.489102772743466, -0.2873682998621297], 
              Complex[3.7537091204741744`, -1.5890972039111029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.058320074594352, 0.1400410254670659}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.058320074594352`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1400410254670659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.058320074594352, 0.1400410254670659], 
              Complex[4.393335070431696, -1.0407007016791032`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5030056270697796`, -0.29531732776612196`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697796`, -0.29531732776612196`], 
              Complex[3.770794613325991, -1.5970891666976452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0452338697500734`, 0.14871638271009882`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009882`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.516644453299159, -0.3039330313949988}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.516644453299159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101082`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.516644453299159, -0.3039330313949988], 
              Complex[3.787625571970204, -1.6058947337101082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.032407731242035, 0.15805167382144264`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.15805167382144264`], 
              Complex[4.361754274818787, -1.0205889908238697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5299220300509906`, -0.3131980951405524}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3131980951405524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509906`, -0.3131980951405524], 
              Complex[3.8040854242836257`, -1.6155012704525789`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0199389107132117`, 0.16802967600526228`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132117`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132117`, 0.16802967600526228`], 
              Complex[4.34645857273412, -1.0093399640268061`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5427432708771693`, -0.3230721172560292}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771693`, -0.3230721172560292], 
              Complex[3.8200582761098665`, -1.625868648866985]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.007922524597889, 0.1786100786041207}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1786100786041207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.1786100786041207], 
              Complex[4.331647428673965, -0.9973396858188018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.555022797842972, -0.3334924140604994}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.555022797842972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434281`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.555022797842972, -0.3334924140604994], 
              Complex[3.8354379364471796`, -1.6369295948434281`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.996443980542599, 0.18973028734408162`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.18973028734408162`], 
              Complex[4.317427040750872, -0.9846553249905687]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.566691838949067, -0.34437794490952983`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.566691838949067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490952983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.566691838949067, -0.34437794490952983`], 
              Complex[3.8501363909766333`, -1.6485937815375424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9855720799859253`, 0.20130934934495046`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934495046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859253`, 0.20130934934495046`], 
              Complex[4.3038854304700065`, -0.9713771047973323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5777029731444694`, -0.35563571212946227`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946227`], 
              Complex[3.864089926301709, -1.6607550217891223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9753542731474703`, 0.2132543530929577}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474703`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2132543530929577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.29108631848507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474703`, 0.2132543530929577], 
              Complex[4.29108631848507, -0.9576111105020126]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5880318511300824`, -0.36716827124164675`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5880318511300824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36716827124164675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.5880318511300824`, -0.36716827124164675`], 
              Complex[3.8772617652382877`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9658149382262047`, 0.22546793870233295`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9658149382262047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22546793870233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.9658149382262047`, 0.22546793870233295`], 
              Complex[4.2790664893039665`, -0.9434705428233613]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5976759196164494`, -0.37888080574180316`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.37888080574180316`], 
              Complex[3.889641123048907, -1.6861168153853252`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9569566571447035`, 0.23785537273090346`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23785537273090346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.23785537273090346`], 
              Complex[4.267836735050403, -0.9290672478326637]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6066509332628542`, -0.3906866010723906}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6066509332628542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3906866010723906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.6066509332628542`, -0.3906866010723906], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9487637036120304`, 0.25033002218771305`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771305`], 
              Complex[4.257385543344472, -0.9145049639864035]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.614986365799948, -0.40251041678371946`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.614986365799948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678371946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.614986365799948, -0.40251041678371946`], 
              Complex[3.912085621903241, -1.7121629626858914`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.941206632003138, 0.2628167267283538}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.941206632003138`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2628167267283538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.941206632003138, 0.2628167267283538], 
              Complex[4.247684254548457, -0.8998749672010711]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.622720730815854, -0.4142898642644486}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.622720730815854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4142898642644486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.725224034003568`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.622720730815854, -0.4142898642644486], 
              Complex[3.9222198214979063`, -1.725224034003568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.93424695657482, 0.2752531764187573}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2752531764187573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.2752531764187573], 
              Complex[4.238692484798848, -0.8852540673280818]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6298974852549244`, -0.42597525546826}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6298974852549244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42597525546826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.6298974852549244`, -0.42597525546826], 
              Complex[3.9316893781660758`, -1.7382225152116566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.927841247969024, 0.2875897604942168}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.2875897604942168], 
              Complex[4.230362981869568, -0.8707044591549238]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6365618226979435`, -0.43752848511674586`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6365618226979435`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43752848511674586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.6365618226979435`, -0.43752848511674586`], 
              Complex[3.9405445393067424`, -1.7511096707348448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9219443399347473`, 0.29978844959373085`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9219443399347473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.29978844959373085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.9219443399347473`, 0.29978844959373085`], 
              Complex[4.2226455060035075`, -0.8562747872176834]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6427583897826845`, -0.44892143644815663`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826845`, -0.44892143644815663`], 
              Complex[3.948835712532858, -1.763848614878014]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9165116129095963`, 0.31182120153934006`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934006`], 
              Complex[4.2154896572704255`, -0.8420018475938864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6485298058180127`, -0.4601342612759222}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6485298058180127`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4601342612759222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764123973101793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.6485298058180127`, -0.4601342612759222], 
              Complex[3.95661157787795, -1.7764123973101793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.911500474407813, 0.3236682414244005}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3236682414244005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.3236682414244005], 
              Complex[4.208846763357216, -0.8279125023887515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6539158085376195`, -0.4711537472500264}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6539158085376195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4711537472500264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.788782141660249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.6539158085376195`, -0.4711537472500264], 
              Complex[3.963917947183658, -1.788782141660249]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.906871213268679, 0.3353164289039029}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.906871213268679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.906871213268679, 0.3353164289039029], 
              Complex[4.202671020177383, -0.8140255411104013]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6589528500917994`, -0.48197187877303554`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500917994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48197187877303554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.800945377085379`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500917994`, -0.48197187877303554`], 
              Complex[3.970797171183352, -1.800945377085379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9025874036669035`, 0.3467578191386486}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669035`, 0.3467578191386486], 
              Complex[4.196920084784547, -0.8003533490732545]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.66367399535596, -0.49258462786579754`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.66367399535596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.66367399535596, -0.49258462786579754`], 
              Complex[3.9772879223008815`, -1.8128946175014515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8986160068062667`, 0.35798845368834886`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.35798845368834886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400257`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.35798845368834886`], 
              Complex[4.1915552925709445`, -0.7869033281400257]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.668109009751522, -0.5029909709021093}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751522, -0.5029909709021093], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.894927283100901, 0.36900737727295463`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.894927283100901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.894927283100901, 0.36900737727295463`], 
              Complex[4.1865416324253255`, -0.7736790656393466]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.672284556174856, -0.5131921073476411}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.672284556174856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.672284556174856, -0.5131921073476411], 
              Complex[3.989240598169982, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8914945952485147`, 0.3798158565375278}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485147`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.181847576794925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7606812732613816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485147`, 0.3798158565375278], 
              Complex[4.181847576794925, -0.7606812732613816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.67622444669189, -0.5231908494724433}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8882941565379956`, 0.3904167697900051}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379956`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.747908528278101`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379956`, 0.3904167697900051], 
              Complex[4.177444833357389, -0.747908528278101]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.679949913999627, -0.5329911517598119}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598119], 
              Complex[4.000015848490729, -1.858517093091783]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8853047593900265`, 0.4008141364346618}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346618], 
              Complex[4.173308062162179, -0.7353578512653347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.683479881251108, -0.5425977517885692}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885692], 
              Complex[4.005023753334011, -1.8693886729252436`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.882507505534356, 0.4110127578783307}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.882507505534356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.723025151975394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.882507505534356, 0.4110127578783307], 
              Complex[4.169414585788293, -0.723025151975394]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.686831218006914, -0.5520158986267103}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.686831218006914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.686831218006914, -0.5520158986267103], 
              Complex[4.009806376364359, -1.8800548315018006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8798855500604437`, 0.4210179459473809}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4210179459473809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.4210179459473809], 
              Complex[4.165744108890901, -0.7109055707023485]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6900189760399864`, -0.5612511491377957}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0143819008890915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8905208626824292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399864`, -0.5612511491377957], 
              Complex[4.0143819008890915`, -1.8905208626824292`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8774238656148405`, 0.4308353192168015}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148405`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148405`, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6930566024649254`, -0.5703092165540393}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6930566024649254`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.6930566024649254`, -0.5703092165540393], 
              Complex[4.018766629721939, -1.9007923754230047`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8751090292740487`, 0.44047065160543564`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44047065160543564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.44047065160543564`], 
              Complex[4.159001332605871, -0.6872839696368794]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6959561299187063`, -0.5791958590266274}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6959561299187063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5791958590266274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.6959561299187063`, -0.5791958590266274], 
              Complex[4.022975200759231, -1.9108751468578666`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.872929032365991, 0.44992976094784376`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.872929032365991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44992976094784376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.872929032365991, 0.44992976094784376`], 
              Complex[4.155898108440934, -0.6757704154937816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6987283448032713`, -0.5879167986060274}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6987283448032713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5879167986060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.6987283448032713`, -0.5879167986060274], 
              Complex[4.027020779081279, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.87087311222959, 0.45921842799560564`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.87087311222959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45921842799560564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.87087311222959, 0.45921842799560564`], 
              Complex[4.152955626516614, -0.6644471667545323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7013829352654026`, -0.5964776632911523}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911523], 
              Complex[4.030915226970466, -1.9304977888211978`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8689316042370314`, 0.4683423384869718}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370314`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370314`, 0.4683423384869718], 
              Complex[4.150162032533435, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7039286208715065`, -0.6048839465011079}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011079], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8670958121211547`, 0.4773070426385345}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4773070426385345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.4773070426385345], 
              Complex[4.147506625196922, -0.6423481214415796]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7063732659882276`, -0.6131409796537513}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8653578945969786`, 0.4861179277432377}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7087239788036013`, -0.6212539145605382}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7087239788036013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6212539145605382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.7087239788036013`, -0.6212539145605382], 
              Complex[4.041793889306879, -1.9586602887011337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8637107663426784`, 0.494780200584179}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426784`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.494780200584179`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426784`, 0.494780200584179], 
              Complex[4.142572556837011, -0.6209409489084494]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.710987197779322, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 1, {
              Complex[2.710987197779322, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8621480115494466`, 0.5032988771597041}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5032988771597041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 2, {
              Complex[2.8621480115494466`, 0.5032988771597041], 
              Complex[4.140277152714268, -0.6104830975830695]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.713168767151179, -0.6370671424983345}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.713168767151179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6370671424983345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 1, {
              Complex[2.713168767151179, -0.6370671424983345], 
              Complex[4.048461912051172, -1.9766512554854925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8606638084231757`, 0.5116787778163012}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8606638084231757`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.138086259166659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6001821017863895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 2, {
              Complex[2.8606638084231757`, 0.5116787778163012], 
              Complex[4.138086259166659, -0.6001821017863895]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7152740029142293`, -0.6447767740762025}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7152740029142293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6447767740762025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.985426861588554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 1, {
              Complex[2.7152740029142293`, -0.6447767740762025], 
              Complex[4.051642476470394, -1.985426861588554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.859252863201372, 0.5199245263444041}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.859252863201372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5199245263444041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 2, {
              Complex[2.859252863201372, 0.5199245263444041], 
              Complex[4.135993261431996, -0.5900329694879928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.717307750554921, -0.6523609855265131}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 1, {
              Complex[2.717307750554921, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8579103524231546`, 0.5280405519418736}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8579103524231546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5280405519418736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285694`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 2, {
              Complex[2.8579103524231546`, 0.5280405519418736], 
              Complex[4.133992114800526, -0.5800308993285694]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7192744356306138`, -0.6598239647344452}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 1, {
              Complex[2.7192744356306138`, -0.6598239647344452], 
              Complex[4.057727034812089, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8566318723517807`, 0.5360310932164645}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 2, {
              Complex[2.8566318723517807`, 0.5360310932164645], 
              Complex[4.132077284632825, -0.5701712799937028]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.721178108151079, -0.6671697152100752}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.721178108151079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0109304474081915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 1, {
              Complex[2.721178108151079, -0.6671697152100752], 
              Complex[4.060641656654435, -2.0109304474081915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8554133945952374`, 0.5439002036016087}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5439002036016087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212129`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 2, {
              Complex[2.8554133945952374`, 0.5439002036016087], 
              Complex[4.130243693579622, -0.5604496874212129]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.723022481587047, -0.6744020624307275}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.723022481587047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 1, {
              Complex[2.723022481587047, -0.6744020624307275], 
              Complex[4.063477543241719, -2.019171773366147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8542512270997307`, 0.5516517577146832}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8542512270997307`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5516517577146832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12848667506693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 2, {
              Complex[2.8542512270997307`, 0.5516517577146832], 
              Complex[4.12848667506693, -0.5508618804640691]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.724810967217476, -0.6815246607732997}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 1, {
              Complex[2.724810967217476, -0.6815246607732997], 
              Complex[4.066238999377148, -2.0272899835297697`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8531419798044717`, 0.5592894583048518}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 2, {
              Complex[2.8531419798044717`, 0.5592894583048518], 
              Complex[4.126801932234573, -0.5414037954825217]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.726546704428588, -0.6885410007735716}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.726546704428588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 1, {
              Complex[2.726546704428588, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8520825343446496`, 0.5668168435275389}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8520825343446496`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5668168435275389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 2, {
              Complex[2.8520825343446496`, 0.5668168435275389], 
              Complex[4.125185501625342, -0.5320715402250118]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.728232587492566, -0.695454416518052}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.728232587492566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.695454416518052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 1, {
              Complex[2.728232587492566, -0.695454416518052], 
              Complex[4.071554204602269, -2.043172220042137]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8510700172747567`, 0.5742372943510565}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 2, {
              Complex[2.8510700172747567`, 0.5742372943510565], 
              Complex[4.123633721017262, -0.5228613872697352]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7298712892804384`, -0.7022680930260654}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7298712892804384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7022680930260654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050943424924777`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 1, {
              Complex[2.7298712892804384`, -0.7022680930260654], 
              Complex[4.074115021277762, -2.050943424924777]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8501017763576963`, 0.5815540419531228}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8501017763576963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 2, {
              Complex[2.8501017763576963`, 0.5815540419531228], 
              Complex[4.12214320087372, -0.5137697672312345]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7314652823007664`, -0.7089850735194758}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 1, {
              Complex[2.7314652823007664`, -0.7089850735194758], 
              Complex[4.076615596606936, -2.0586058847208246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.849175359528075, 0.5887701750046824}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.849175359528075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5887701750046824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 2, {
              Complex[2.849175359528075, 0.5887701750046824], 
              Complex[4.120710798957501, -0.5047932618845047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.733016857401756, -0.7156082665076036}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 1, {
              Complex[2.733016857401756, -0.7156082665076036], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.848288496192057, 0.5958886467685788}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.495928597319203`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 2, {
              Complex[2.848288496192057, 0.5958886467685788], 
              Complex[4.1193335977160075`, -0.495928597319203]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7345281404282455`, -0.7221404526376911}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7345281404282455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 1, {
              Complex[2.7345281404282455`, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.847439080572326, 0.6029122819634526}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 2, {
              Complex[2.847439080572326, 0.6029122819634526], 
              Complex[4.118008884097688, -0.4871726372059109]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.736001107085406, -0.7285842912785055}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 1, {
              Complex[2.736001107085406, -0.7285842912785055], 
              Complex[4.083784124290591, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.846625156846318, 0.6098437833604627}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.846625156846318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 2, {
              Complex[2.846625156846318, 0.6098437833604627], 
              Complex[4.116734131505034, -0.478522376232896]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.737437596227138, -0.734942326817608}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.737437596227138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.734942326817608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 1, {
              Complex[2.737437596227138, -0.734942326817608], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.845844905859744, 0.616685738093365}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384025`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 2, {
              Complex[2.845844905859744, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384025`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7388393217580846`, -0.7412169946624543}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 1, {
              Complex[2.7388393217580846`, -0.7412169946624543], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8450966332264747`, 0.6234406236721284}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1143252399392205`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.46152754767328247`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.1143252399392205`, -0.46152754767328247`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.74020788331328, -0.7474106269426312}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.74020788331328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 1, {
              Complex[2.74020788331328, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8443787586507785`, 0.6301108136973939}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613556`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 2, {
              Complex[2.8443787586507785`, 0.6301108136973939], 
              Complex[4.113186842647121, -0.45317756858613556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7415447758580713`, -0.7535254579157125}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1094520143136553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 1, {
              Complex[2.7415447758580713`, -0.7535254579157125], 
              Complex[4.092654956897793, -2.1094520143136553`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.843689806329271, 0.636698583278269}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.636698583278269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417977994`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 2, {
              Complex[2.843689806329271, 0.636698583278269], 
              Complex[4.112089864956078, -0.44492245417977994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7428513983325447`, -0.7595636290829763}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7428513983325447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7595636290829763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 1, {
              Complex[2.7428513983325447`, -0.7595636290829763], 
              Complex[4.094763792064632, -2.1163496199598404`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.843028396308333, 0.643206114159718}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843028396308333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013437`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 2, {
              Complex[2.843028396308333, 0.643206114159718], 
              Complex[4.1110325004689345`, -0.4367597639013437]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.744129061448893, -0.7655271940238003}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 1, {
              Complex[2.744129061448893, -0.7655271940238003], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.842393236688586, 0.6496354995683531}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688586`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848105`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 2, {
              Complex[2.842393236688586, 0.6496354995683531], 
              Complex[4.110013053613793, -0.42868715388848105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7453789947364777`, -0.7714181229593399}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7453789947364777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714181229593399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 1, {
              Complex[2.7453789947364777`, -0.7714181229593399], 
              Complex[4.098863152113464, -2.1298944357144074`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8417831165816425`, 0.6559887487872507}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 2, {
              Complex[2.8417831165816425`, 0.6559887487872507], 
              Complex[4.109029930978955, -0.4207023721587479]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.746602352917594, -0.7772383070571708}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 1, {
              Complex[2.746602352917594, -0.7772383070571708], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.841196899736145, 0.6622677914714881}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.841196899736145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 2, {
              Complex[2.841196899736145, 0.6622677914714881], 
              Complex[4.108081633457669, -0.4128032540504382]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7478002216867257`, -0.7829895624892169}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 1, {
              Complex[2.7478002216867257`, -0.7829895624892169], 
              Complex[4.102814974771636, -2.1431196363389544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.84063351876029, 0.6684744817167123}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.84063351876029`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40498771790623117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 2, {
              Complex[2.84063351876029, 0.6684744817167123], 
              Complex[4.1071667491158, -0.40498771790623117`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.748973622957286, -0.7886736342555828}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 1, {
              Complex[2.748973622957286, -0.7886736342555828], 
              Complex[4.104739060573036, -2.1496174139664075`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8400919698768625`, 0.6746106018933712}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.39725376098988185`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 2, {
              Complex[2.8400919698768625`, 0.6746106018933712], 
              Complex[4.1062839467060055`, -0.39725376098988185`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.750123519632142, -0.794292199786831}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1560411738459275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409573, -2.1560411738459275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8395713081544542`, 0.6806778662591636}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 2, {
              Complex[2.8395713081544542`, 0.6806778662591636], 
              Complex[4.10543196976093, -0.38959945562569803`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7512508199475976`, -0.7998468723371362}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7512508199475976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 1, {
              Complex[2.7512508199475976`, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921433`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8390706431652144`, 0.686677924362138}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8390706431652144`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.686677924362138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38202294555012584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 2, {
              Complex[2.8390706431652144`, 0.686677924362138], 
              Complex[4.104609631205908, -0.38202294555012584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7523563814347085`, -0.8053392041803542}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 1, {
              Complex[2.7523563814347085`, -0.8053392041803542], 
              Complex[4.11031899238399, -2.1686738074506073`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8385891350252574`, 0.6926123642464802}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8385891350252574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.374522442464793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 2, {
              Complex[2.8385891350252574`, 0.6926123642464802], 
              Complex[4.103815808438448, -0.374522442464793]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7534410145367234`, -0.8107706896206488}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 1, {
              Complex[2.7534410145367234`, -0.8107706896206488], 
              Complex[4.112118632879193, -2.1748860995439667`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83812599077891, 0.6984827154726538}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83812599077891`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36709622278037246`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 2, {
              Complex[2.83812599077891, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.36709622278037246`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7545054859170786`, -0.8161427678288311}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 1, {
              Complex[2.7545054859170786`, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8376804610924067`, 0.7042904519630286}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409171`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 2, {
              Complex[2.8376804610924067`, 0.7042904519630286], 
              Complex[4.102309515593155, -0.3597426245409171]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7555505214884586`, -0.8214568255150109}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8372518372264883`, 0.7100369946836329}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3524600445185817`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 2, {
              Complex[2.8372518372264883`, 0.7100369946836329], 
              Complex[4.101595084023626, -0.3524600445185817]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7565768091901, -0.8267141994476594}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1931261038190124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 1, {
              Complex[2.7565768091901, -0.8267141994476594], 
              Complex[4.11735077080964, -2.1931261038190124`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836839448260752, 0.7157237141721119}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546903984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 2, {
              Complex[2.836839448260752, 0.7157237141721119], 
              Complex[4.100905238007176, -0.34524693546903984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.757585001537493, -0.8319161788285991}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.757585001537493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 1, {
              Complex[2.757585001537493, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836442658545575, 0.7213519329214123}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836442658545575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 2, {
              Complex[2.836442658545575, 0.7213519329214123], 
              Complex[4.100239116839225, -0.3381018035383218]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7585757179660733`, -0.8370640075328958}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 1, {
              Complex[2.7585757179660733`, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836060865360036, 0.7269229276281968}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 2, {
              Complex[2.836060865360036, 0.7269229276281968], 
              Complex[4.099595902284807, -0.3310232058121981]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.759549546988155, -0.84215888622212}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.84215888622212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.210801823435384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 1, {
              Complex[2.759549546988155, -0.84215888622212], 
              Complex[4.122351473418491, -2.210801823435384]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.835693496756588, 0.7324379313144278}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.835693496756588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972326`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 2, {
              Complex[2.835693496756588, 0.7324379313144278], 
              Complex[4.098974815870868, -0.32400974799972326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7605070481803384`, -0.8472019743388878}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7605070481803384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 1, {
              Complex[2.7605070481803384`, -0.8472019743388878], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8353400095752215`, 0.737898135330063}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.737898135330063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 2, {
              Complex[2.8353400095752215`, 0.737898135330063], 
              Complex[4.0983751163877695`, -0.31706008224295906`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.761448754016845, -0.8521943919901347}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.761448754016845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8521943919901347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125567334802809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2222903413273136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 1, {
              Complex[2.761448754016845, -0.8521943919901347], 
              Complex[4.125567334802809, -2.2222903413273136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.834999887611698, 0.7433046912443019}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834999887611698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 2, {
              Complex[2.834999887611698, 0.7433046912443019], 
              Complex[4.097796097581198, -0.31017290504537165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7623751715626246`, -0.857137221726082}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7623751715626246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 1, {
              Complex[2.7623751715626246`, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.834672639925991, 0.748658712632362}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834672639925991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.748658712632362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 2, {
              Complex[2.834672639925991, 0.748658712632362], 
              Complex[4.097237086017579, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.763286784038682, -0.862031510221407}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.763286784038682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.862031510221407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 1, {
              Complex[2.763286784038682, -0.862031510221407], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8343577992784867`, 0.7539612767642828}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 2, {
              Complex[2.8343577992784867`, 0.7539612767642828], 
              Complex[4.096697439107837, -0.2965810124932357]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.76418405227083, -0.8668782698647187}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.76418405227083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 1, {
              Complex[2.76418405227083, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.834054920682748, 0.7592134262018868}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834054920682748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045606`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 2, {
              Complex[2.834054920682748, 0.7592134262018868], 
              Complex[4.096176543275776, -0.28987389483045606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7650674160319424`, -0.8716784802620262}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7650674160319424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 1, {
              Complex[2.7650674160319424`, -0.8716784802620262], 
              Complex[4.131740864527741, -2.244603004332967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.833763580064758, 0.7644161703095633}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833763580064758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 2, {
              Complex[2.833763580064758, 0.7644161703095633], 
              Complex[4.095673812258773, -0.2832244576900397]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.765937295286828, -0.8764330896595156}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765937295286828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 1, {
              Complex[2.765937295286828, -0.8764330896595156], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8334833730195332`, 0.769570486684214}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.27663159198783]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.766794091347923, -0.8811430162906048}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.766794091347923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 1, {
              Complex[2.766794091347923, -0.8811430162906048], 
              Complex[4.134708267176491, -2.2554451338771333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.833213913656889, 0.7746773225093271}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833213913656889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 2, {
              Complex[2.833213913656889, 0.7746773225093271], 
              Complex[4.094720626829336, -0.27009422269428524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7676381879492564`, -0.8858091496519154}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 1, {
              Complex[2.7676381879492564`, -0.8858091496519154], 
              Complex[4.136164053701611, -2.2607913054940165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8329548335289294`, 0.7797375958378117}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8329548335289294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7797375958378117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2636113074169858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 2, {
              Complex[2.8329548335289294`, 0.7797375958378117], 
              Complex[4.094269122802148, -0.2636113074169858]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.768469952245414, -0.8904323517124779}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 1, {
              Complex[2.768469952245414, -0.8904323517124779], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8327057806325198`, 0.7847521968079443}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325198`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0938336817238055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.25718183505570524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 2, {
              Complex[2.8327057806325198`, 0.7847521968079443], 
              Complex[4.0938336817238055`, -0.25718183505570524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7692897357415927`, -0.8950134580602261}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544097`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 1, {
              Complex[2.7692897357415927`, -0.8950134580602261], 
              Complex[4.139022292544097, -2.2713387277515538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832466418480638, 0.7897219887964373}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.2508048245258131]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.770097875160308, -0.8995532789895441}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 1, {
              Complex[2.770097875160308, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83223642523709, 0.7946478095124517}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 2, {
              Complex[2.83223642523709, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.2444793235459518]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7708946932497662`, -0.9040526005333868}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7708946932497662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9040526005333868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 1, {
              Complex[2.7708946932497662`, -0.9040526005333868], 
              Complex[4.141812512404397, -2.2816990696412356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832015492909507, 0.7995304720360316}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 2, {
              Complex[2.832015492909507, 0.7995304720360316], 
              Complex[4.0926191190690275`, -0.2382044074863151]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.771680499538499, -0.9085121854432783}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 1, {
              Complex[2.771680499538499, -0.9085121854432783], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.831803326596092, 0.804370765804293}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831803326596092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.804370765804293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 2, {
              Complex[2.831803326596092, 0.804370765804293], 
              Complex[4.092243405309306, -0.23197917827395678`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7724555910404214`, -0.9129327741202401}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7724555910404214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 1, {
              Complex[2.7724555910404214`, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.831599643781914, 0.8091694575484224}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831599643781914`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.225802763351888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 2, {
              Complex[2.831599643781914, 0.8091694575484224], 
              Complex[4.0918815815115215`, -0.225802763351888]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.773220252914126, -0.917315085499543}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.917315085499543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 1, {
              Complex[2.773220252914126, -0.917315085499543], 
              Complex[4.145877797348456, -2.296904005989524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8314041736809608`, 0.8139272921843708}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809608`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886287`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 2, {
              Complex[2.8314041736809608`, 0.8139272921843708], 
              Complex[4.091533263417342, -0.21967431468886287`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7739747590798687`, -0.9216598178919513}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 1, {
              Complex[2.7739747590798687`, -0.9216598178919513], 
              Complex[4.147202461925569, -2.3018861057371844`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8312166566204735`, 0.8186449936599098}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.213593007836997`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 2, {
              Complex[2.8312166566204735`, 0.8186449936599098], 
              Complex[4.091198081568593, -0.213593007836997]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7747193727974437`, -0.9259676497839735}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7747193727974437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9259676497839735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 1, {
              Complex[2.7747193727974437`, -0.9259676497839735], 
              Complex[4.148512526970577, -2.306826396101708]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8310368434643864`, 0.8233232657606013}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448106`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 2, {
              Complex[2.8310368434643864`, 0.8233232657606013], 
              Complex[4.090875680564112, -0.20755804103448106`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7754543472078295`, -0.9302392405994727}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7754543472078295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 1, {
              Complex[2.7754543472078295`, -0.9302392405994727], 
              Complex[4.149808341378722, -2.311725622493253]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8308644950729813`, 0.8279627928769892}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20156863435089428`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 2, {
              Complex[2.8308644950729813`, 0.8279627928769892], 
              Complex[4.090565718362365, -0.20156863435089428`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7761799258412623`, -0.934475231424826}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7761799258412623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.934475231424826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 1, {
              Complex[2.7761799258412623`, -0.934475231424826], 
              Complex[4.151090241310992, -2.316584509692524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8306993817960873`, 0.8325642407352365}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 2, {
              Complex[2.8306993817960873`, 0.8325642407352365], 
              Complex[4.090267865626448, -0.19562402887272834`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8395927484273855`, -0.6433017314670886}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 1, {
              Complex[3.8395927484273855`, -0.6433017314670886], 
              Complex[1.795162677796044, -2.1401483895470994`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.836019007965047, 0.00664507113781796}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.836019007965047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00664507113781796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.196232266214943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 2, {
              Complex[7.836019007965047, 0.00664507113781796], 
              Complex[6.196232266214943, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.874980911856298, -0.616522179294801}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.874980911856298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.616522179294801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1120211819719548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 1, {
              Complex[3.874980911856298, -0.616522179294801], 
              Complex[1.8301368298409673`, -2.1120211819719548`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.795901779221279, 0.0067125107858549355`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0067125107858549355`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 2, {
              Complex[7.795901779221279, 0.0067125107858549355`], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9045700992025942`, -0.5952855745698099}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025942`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 1, {
              Complex[3.9045700992025942`, -0.5952855745698099], 
              Complex[1.859366613529838, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.763484521798688, 0.006786025025047784}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047784`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 2, {
              Complex[7.763484521798688, 0.006786025025047784], 
              Complex[6.122517060306257, -1.163371113059422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9307507913132285`, -0.577315686227792}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9307507913132285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.577315686227792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 1, {
              Complex[3.9307507913132285`, -0.577315686227792], 
              Complex[1.8852354657886525`, -2.0700333477056225`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.735547972440535, 0.006863336573144921}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 2, {
              Complex[7.735547972440535, 0.006863336573144921], 
              Complex[6.093988110787665, -1.1633606215314776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9546128944921866`, -0.5615718710865848}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 1, {
              Complex[3.9546128944921866`, -0.5615718710865848], 
              Complex[1.908828689419143, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.710629285429999, 0.006943461497604799}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604799`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 2, {
              Complex[7.710629285429999, 0.006943461497604799], 
              Complex[6.068475300453683, -1.163347697400969]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.976762799482184, -0.5474736791133856}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 1, {
              Complex[3.976762799482184, -0.5474736791133856], 
              Complex[1.9307493118589263`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.687917286732913, 0.007025882918871683}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 2, {
              Complex[7.687917286732913, 0.007025882918871683], 
              Complex[6.045167287063117, -1.1633328856106508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9975793662526633`, -0.5346576120369375}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9975793662526633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0230672781048264`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 1, {
              Complex[3.9975793662526633`, -0.5346576120369375], 
              Complex[1.9513735684640636`, -2.0230672781048264`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.666906890699566, 0.007110298008162861}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162861`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 2, {
              Complex[7.666906890699566, 0.007110298008162861], 
              Complex[6.023558855884933, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.017318225749185, -0.5228778864146381}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 1, {
              Complex[4.017318225749185, -0.5228778864146381], 
              Complex[1.9709549506972726`, -2.009827028796296]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.647258486238892, 0.007196517077880158}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.647258486238892`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007196517077880158`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 2, {
              Complex[7.647258486238892, 0.007196517077880158], 
              Complex[6.003310291269153, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.036161628380458, -0.5119589442981471}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 1, {
              Complex[4.036161628380458, -0.5119589442981471], 
              Complex[1.9896739101964112`, -1.9974384540079668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.628730822140306, 0.007284416332243424}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243424`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089611`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 2, {
              Complex[7.628730822140306, 0.007284416332243424], 
              Complex[5.984180253839811, -1.1632798309089611`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.054245015542007, -0.501770106216406}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.501770106216406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 1, {
              Complex[4.054245015542007, -0.501770106216406], 
              Complex[2.0076643409453068`, -1.9857722832958546`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.61114527747392, 0.007373913179249466}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.61114527747392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179249466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.96599004597708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 2, {
              Complex[7.61114527747392, 0.007373913179249466], 
              Complex[5.96599004597708, -1.1632597604074986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.071672363798729, -0.4922109148816928}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775294`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.974729256230454`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 1, {
              Complex[4.071672363798729, -0.4922109148816928], 
              Complex[2.0250288646775294`, -1.974729256230454]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.594365254745728, 0.007464952252033915}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.594365254745728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033915`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 2, {
              Complex[7.594365254745728, 0.007464952252033915], 
              Complex[5.948603001807256, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.088525607498784, -0.4832021231088834}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.041848212945115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9642311559465873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 1, {
              Complex[4.088525607498784, -0.4832021231088834], 
              Complex[2.041848212945115, -1.9642311559465873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.578283541245461, 0.0075574969911632525`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.578283541245461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.0075574969911632525`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.93191184641344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 2, {
              Complex[7.578283541245461, 0.0075574969911632525`], 
              Complex[5.93191184641344, -1.1632165013453923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.104870714597596, -0.4746798749981771}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143463`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 1, {
              Complex[4.104870714597596, -0.4746798749981771], 
              Complex[2.058187273894043, -1.9542150231143463`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.562814169527114, 0.007651524322599015}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.562814169527114`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 2, {
              Complex[7.562814169527114, 0.007651524322599015], 
              Complex[5.915830554816422, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.12076176343584, -0.46659179640833665`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 1, {
              Complex[4.12076176343584, -0.46659179640833665`], 
              Complex[2.074099147574049, -1.944629270704492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.547886962653699, 0.00774702115720029}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115720029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163169331063269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 2, {
              Complex[7.547886962653699, 0.00774702115720029], 
              Complex[5.900288896133163, -1.163169331063269]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.136243770182482, -0.45889427989730935`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.136243770182482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45889427989730935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 1, {
              Complex[4.136243770182482, -0.45889427989730935`], 
              Complex[2.0896279570988052`, -1.9354309873904436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.533443755733457, 0.00784398201226336}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00784398201226336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.8852286543048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 2, {
              Complex[7.533443755733457, 0.00784398201226336], 
              Complex[5.8852286543048, -1.1631443306747422`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.151354705396686, -0.45155054573493103`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573493103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 1, {
              Complex[4.151354705396686, -0.45155054573493103`], 
              Complex[2.1048108525831113`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5194357044269005`, 0.007942407351021122}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021122`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.16311839933984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 2, {
              Complex[7.5194357044269005`, 0.007942407351021122], 
              Complex[5.870600935988343, -1.16311839933984]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.166126967125892, -0.44452922359237934`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1196794742655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9180575310211614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 1, {
              Complex[4.166126967125892, -0.44452922359237934`], 
              Complex[2.1196794742655443`, -1.9180575310211614`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5058213212730225`, 0.008042302396705283}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705283`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 2, {
              Complex[7.5058213212730225`, 0.008042302396705283], 
              Complex[5.856364206404795, -1.1630915398400687`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.180588479578347, -0.4378032933344357}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4378032933344357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 1, {
              Complex[4.180588479578347, -0.4378032933344357], 
              Complex[2.134261043168295, -1.9098250195461774`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.492565012985164, 0.00814367626923343}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00814367626923343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 2, {
              Complex[7.492565012985164, 0.00814367626923343], 
              Complex[5.842482826256841, -1.1630637508268276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.19476352756891, -0.4313492794933509}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.19476352756891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4313492794933509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 1, {
              Complex[4.19476352756891, -0.4313492794933509], 
              Complex[2.148579189013273, -1.9018634521265034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.479635970943439, 0.008246541346654009}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654009`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 2, {
              Complex[7.479635970943439, 0.008246541346654009], 
              Complex[5.828925941917193, -1.1630350275077865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.208673400536594, -0.4251466287655523}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4251466287655523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.162654588850219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 1, {
              Complex[4.208673400536594, -0.4251466287655523], 
              Complex[2.162654588850219, -1.8941526819126022`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.4670073159977095`, 0.008350912786614356}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614356`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 2, {
              Complex[7.4670073159977095`, 0.008350912786614356], 
              Complex[5.815666629983417, -1.1630053621640013`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.22233689673936, -0.4191772220375585}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.22233689673936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4191772220375585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 1, {
              Complex[4.22233689673936, -0.4191772220375585], 
              Complex[2.1765054667524413`, -1.8866749586802054`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.454655429824251, 0.008456808164000547}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 2, {
              Complex[7.454655429824251, 0.008456808164000547], 
              Complex[5.802681228429218, -1.1629747445437835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.235770723063745, -0.4134249869532411}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.235770723063745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4134249869532411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.190147989832311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 1, {
              Complex[4.235770723063745, -0.4134249869532411], 
              Complex[2.190147989832311, -1.8794145456947635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.442559425423676, 0.00856424719441154}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00856424719441154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 2, {
              Complex[7.442559425423676, 0.00856424719441154], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.248989815735209, -0.4078755867501412}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2035965857225785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 1, {
              Complex[4.248989815735209, -0.4078755867501412], 
              Complex[2.2035965857225785`, -1.8723574121967355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.430700722955541, 0.008673251522090995}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 2, {
              Complex[7.430700722955541, 0.008673251522090995], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.262007600278324, -0.4025161677361114}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2168641997657033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8654909840009635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 1, {
              Complex[4.262007600278324, -0.4025161677361114], 
              Complex[2.2168641997657033`, -1.8654909840009635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.419062706397297, 0.008783844556995744}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995744`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 2, {
              Complex[7.419062706397297, 0.008783844556995744], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.274836204246599, -0.3973351524058626}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3973351524058626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 1, {
              Complex[4.274836204246599, -0.3973351524058626], 
              Complex[2.2299625053481056`, -1.8588039393045297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.4076304429802775`, 0.008896051349859017}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008896051349859017`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 2, {
              Complex[7.4076304429802775`, 0.008896051349859017], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.287486632822466, -0.39232206847657186`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847657186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567271`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 1, {
              Complex[4.287486632822466, -0.39232206847657186`], 
              Complex[2.2429020774149055`, -1.8522860400567271`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.396390451929993, 0.009009898497034048}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 2, {
              Complex[7.396390451929993, 0.009009898497034048], 
              Complex[5.741204286938842, -1.1628068690797757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.299968914929404, -0.38746740648134687`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.255692536755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8459279915891411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 1, {
              Complex[4.299968914929404, -0.38746740648134687`], 
              Complex[2.255692536755631, -1.8459279915891411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.3853305123250825`, 0.009125414068990438}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990438`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 2, {
              Complex[7.3853305123250825`, 0.009125414068990438], 
              Complex[5.729492775798816, -1.162770211346653]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.312292225705379, -0.3827625002813669}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.312292225705379`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 1, {
              Complex[4.312292225705379, -0.3827625002813669], 
              Complex[2.268342670868864, -1.839721324914159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.374439502284715, 0.009242627557842201}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842201`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 2, {
              Complex[7.374439502284715, 0.009242627557842201], 
              Complex[5.717947033532342, -1.1627324771191423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.324464989862635, -0.37819942613027685`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37819942613027685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639244`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 1, {
              Complex[4.324464989862635, -0.37819942613027685`], 
              Complex[2.280860535897551, -1.8336582973639244`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.363707263462426, 0.009361569840391612}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391612`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 2, {
              Complex[7.363707263462426, 0.009361569840391612], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.33649496946897, -0.37377091687664876`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.33649496946897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37377091687664876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2932535431430088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.827731808186949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 1, {
              Complex[4.33649496946897, -0.37377091687664876`], 
              Complex[2.2932535431430088`, -1.827731808186949]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.3531244861453, 0.00948227315398883}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00948227315398883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 2, {
              Complex[7.3531244861453, 0.00948227315398883], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.348389338937684, -0.36947028861032244`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 1, {
              Complex[4.348389338937684, -0.36947028861032244`], 
              Complex[2.3055285329225494`, -1.8219353264340106`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.342682611254977, 0.009604771083122523}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162612570599382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.162612570599382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.3601547494422475`, -0.3652913776086273}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 1, {
              Complex[4.3601547494422475`, -0.3652913776086273], 
              Complex[2.317691837968341, -1.8162628290107483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.332373746308075, 0.009729098555121796}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121796`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 2, {
              Complex[7.332373746308075, 0.009729098555121796], 
              Complex[5.67322985816244, -1.1625702788705319`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.371797384531623, -0.3612284858628568}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.371797384531623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3612284858628568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 1, {
              Complex[4.371797384531623, -0.3612284858628568], 
              Complex[2.329749338128146, -1.8107087471951664`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.322190592979878, 0.009855291843704476}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 2, {
              Complex[7.322190592979878, 0.009855291843704476], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.38332300838, -0.35727633379543666`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 1, {
              Complex[4.38332300838, -0.35727633379543666`], 
              Complex[2.3417065077888237`, -1.8052679202454824`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.3121263843706, 0.009983388579384737}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3121263843706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384737`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 2, {
              Complex[7.3121263843706, 0.009983388579384737], 
              Complex[5.65163666048189, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.394737007836374, -0.3534300190373758}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3534300190373758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 1, {
              Complex[4.394737007836374, -0.3534300190373758], 
              Complex[2.353568457177237, -1.799935554980541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.302174830430452, 0.0101134277659673}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0101134277659673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.641006995243321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 2, {
              Complex[7.302174830430452, 0.0101134277659673], 
              Complex[5.641006995243321, -1.1624360273853818`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.40604442922753, -0.34968498034030004`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34968498034030004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794707190417858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 1, {
              Complex[4.40604442922753, -0.34968498034030004`], 
              Complex[2.3653399684829144`, -1.794707190417858]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.292330070281435, 0.0102454498025258}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102454498025258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 2, {
              Complex[7.292330070281435, 0.0102454498025258], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.417250010699276, -0.3460369658605057}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 1, {
              Complex[4.417250010699276, -0.3460369658605057], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.282586630397876, 0.010379496510400108`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 2, {
              Complex[7.282586630397876, 0.010379496510400108`], 
              Complex[5.620051946974448, -1.162340058391703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.428358210745747, -0.3424820051832386}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3424820051832386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7845460977964327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 1, {
              Complex[4.428358210745747, -0.3424820051832386], 
              Complex[2.3886293519885573`, -1.7845460977964327`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.272939387787106, 0.010515611164854503`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 2, {
              Complex[7.272939387787106, 0.010515611164854503`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.439373233467539, -0.33901638456088024`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456088024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 1, {
              Complex[4.439373233467539, -0.33901638456088024`], 
              Complex[2.400155415619293, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.263383537456196, 0.010653838531129405`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 2, {
              Complex[7.263383537456196, 0.010653838531129405`], 
              Complex[5.599467510982896, -1.1622385897064984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.450299051011203, -0.3356366249244734}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7747545062354526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 1, {
              Complex[4.450299051011203, -0.3356366249244734], 
              Complex[2.411607470734254, -1.7747545062354526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.253914563567923, 0.010794224904694154`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.589302304154469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234662`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 2, {
              Complex[7.253914563567923, 0.010794224904694154`], 
              Complex[5.589302304154469, -1.1621856987234662`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.461139423570387, -0.3323394622978912}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 1, {
              Complex[4.461139423570387, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.244528213784578, 0.010936818155564383`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 2, {
              Complex[7.244528213784578, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.471897917269896, -0.3291218303014389}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 1, {
              Complex[4.471897917269896, -0.3291218303014389], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.235220476376673, 0.011081667776607955`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607955`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 2, {
              Complex[7.235220476376673, 0.011081667776607955`], 
              Complex[5.569204368643544, -1.162075401828133]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.482577920205065, -0.3259808444790322}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7607028906574185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 1, {
              Complex[4.482577920205065, -0.3259808444790322], 
              Complex[2.445554179476746, -1.7607028906574185`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.225987559738016, 0.011228824935798515`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 2, {
              Complex[7.225987559738016, 0.011228824935798515`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.49318265686856, -0.32291378822242117`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.49318265686856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 1, {
              Complex[4.49318265686856, -0.32291378822242117`], 
              Complex[2.4567439331314396`, -1.7561770369578587`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.216825874002135, 0.011378342532423336`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423336`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 2, {
              Complex[7.216825874002135, 0.011378342532423336`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.503715201163001, -0.31991810009861654`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31991810009861654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037111`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 1, {
              Complex[4.503715201163001, -0.31991810009861654`], 
              Complex[2.467875732183709, -1.7517258685037111`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.2077320144994355`, 0.011530275257279964`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.2077320144994355`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 2, {
              Complex[7.2077320144994355`, 0.011530275257279964`], 
              Complex[5.539580869749672, -1.1618980163266772`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.514178488169752, -0.31699136241415204`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4789523456499616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.747347006826386`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 1, {
              Complex[4.514178488169752, -0.31699136241415204`], 
              Complex[2.4789523456499616`, -1.747347006826386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.198702746831605, 0.011684679656931235`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931235`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 2, {
              Complex[7.198702746831605, 0.011684679656931235`], 
              Complex[5.529831896159835, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.524575324820609, -0.3141312908727424}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820609`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3141312908727424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 1, {
              Complex[4.524575324820609, -0.3141312908727424], 
              Complex[2.4899764222920586`, -1.7430382027464777`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.189734993370943, 0.011841614202115798`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370943`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 2, {
              Complex[7.189734993370943, 0.011841614202115798`], 
              Complex[5.520140327071445, -1.1617712515975434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.5349083995992086`, -0.31133572520239783`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5349083995992086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31133572520239783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7387973272586876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 1, {
              Complex[4.5349083995992086`, -0.31133572520239783`], 
              Complex[2.5009505000731345`, -1.7387973272586876`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.180825821018505, 0.012001139360437552`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 2, {
              Complex[7.180825821018505, 0.012001139360437552`], 
              Complex[5.510503169822831, -1.161705165156914]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.545180291382208, -0.30860262064445365`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30860262064445365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.734622363260088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 1, {
              Complex[4.545180291382208, -0.30860262064445365`], 
              Complex[2.5118770147723373`, -1.734622363260088]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.171972430077164, 0.01216331767348526}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01216331767348526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 2, {
              Complex[7.171972430077164, 0.01216331767348526], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.555393477515928, -0.30593004021100256`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7305113980298925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 1, {
              Complex[4.555393477515928, -0.30593004021100256`], 
              Complex[2.522758307852828, -1.7305113980298925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.163172144114485, 0.012328213838552468`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 2, {
              Complex[7.163172144114485, 0.012328213838552468`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.5655503412120515`, -0.3033161476291151}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5655503412120515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380606`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 1, {
              Complex[4.5655503412120515`, -0.3033161476291151], 
              Complex[2.5335966336654496`, -1.726462616380606]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.154422400706351, 0.012495894795164315`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 2, {
              Complex[7.154422400706351, 0.012495894795164315`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.575653178335505, -0.3007592009004852}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.575653178335505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3007592009004852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 1, {
              Complex[4.575653178335505, -0.3007592009004852], 
              Complex[2.5443941660601173`, -1.7224742944105478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.145720742965965, 0.012666429816627267`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627267`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 2, {
              Complex[7.145720742965965, 0.012666429816627267`], 
              Complex[5.4724432225550075`, -1.1614214951964696`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.585704203648775, -0.29825754641387064`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 1, {
              Complex[4.585704203648775, -0.29825754641387064`], 
              Complex[2.55515300446826, -1.7185447937963199`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.137064811774601, 0.012839890606854677`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 2, {
              Complex[7.137064811774601, 0.012839890606854677`], 
              Complex[5.463037520285708, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.59570555656919, -0.2958096135553047}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 1, {
              Complex[4.59570555656919, -0.2958096135553047], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.128452338640535, 0.013016351402742274`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 2, {
              Complex[7.128452338640535, 0.013016351402742274`], 
              Complex[5.453670720869239, -1.161267218035427]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.605659306489134, -0.2934139097675643}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 1, {
              Complex[4.605659306489134, -0.2934139097675643], 
              Complex[2.5765626581891587`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.119881139121319, 0.013195889082391348`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013195889082391348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 2, {
              Complex[7.119881139121319, 0.013195889082391348`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.615567457703372, -0.29106901601605945`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 1, {
              Complex[4.615567457703372, -0.29106901601605945`], 
              Complex[2.5872173486781156`, -1.7070940139050703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.111349106752032, 0.01337858327951254}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01337858327951254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 2, {
              Complex[7.111349106752032, 0.01337858327951254], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.625431953982773, -0.2887735826232166}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.625431953982773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 1, {
              Complex[4.625431953982773, -0.2887735826232166], 
              Complex[2.5978411048003505`, -1.7033849532134357`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.1028542074287175`, 0.013564516504362847`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1028542074287175`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362847`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 2, {
              Complex[7.1028542074287175`, 0.013564516504362847`], 
              Complex[5.425781575481576, -1.1610187499090083`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.635254682829314, -0.28652632543776696`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6084357301759398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6997276376830053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 1, {
              Complex[4.635254682829314, -0.28652632543776696`], 
              Complex[2.6084357301759398`, -1.6997276376830053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.094394474201806, 0.013753774271608692`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608692`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 2, {
              Complex[7.094394474201806, 0.013753774271608692`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.645037479443607, -0.2843260223090585}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6190029821022605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6961208467863325`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 1, {
              Complex[4.645037479443607, -0.2843260223090585], 
              Complex[2.6190029821022605`, -1.6961208467863325`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.085968002439294, 0.01394644523553291}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01394644523553291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 2, {
              Complex[7.085968002439294, 0.01394644523553291], 
              Complex[5.407343930794649, -1.1608408715855627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.654782130432772, -0.2821715098398556}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 1, {
              Complex[4.654782130432772, -0.2821715098398556], 
              Complex[2.629544575183531, -1.6925634169220725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.0775729453237535`, 0.014142621333044105`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0775729453237535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044105`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 2, {
              Complex[7.0775729453237535`, 0.014142621333044105`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.66449037728374, -0.2800616803939439}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.66449037728374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800616803939439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 1, {
              Complex[4.66449037728374, -0.2800616803939439], 
              Complex[2.640062184735899, -1.6890542385321838`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.069207509650975, 0.014342397934981625`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981625`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 2, {
              Complex[7.069207509650975, 0.014342397934981625`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.6741639196244416`, -0.2779954793374575}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6741639196244416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470893`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 1, {
              Complex[4.6741639196244416`, -0.2779954793374575], 
              Complex[2.6505574499902775`, -1.6855922534470893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.060869951901383, 0.014545874006250833`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901383`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250833`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 2, {
              Complex[7.060869951901383, 0.014545874006250833`], 
              Complex[5.379881023870964, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.683804418293251, -0.2759719024950629}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 1, {
              Complex[4.683804418293251, -0.2759719024950629], 
              Complex[2.661031977113045, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.052558574558201, 0.014753152275367323`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367323`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 2, {
              Complex[7.052558574558201, 0.014753152275367323`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.693413498234964, -0.27398999380419337`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27398999380419337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 1, {
              Complex[4.693413498234964, -0.27398999380419337`], 
              Complex[2.6714873420627194`, -1.6788058729768789`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.044271722648962, 0.014964339414035003`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 2, {
              Complex[7.044271722648962, 0.014964339414035003`], 
              Complex[5.36168012892486, -1.1603484877775454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.702992751240039, -0.27204884315225386`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6819250932991716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6754795971390894`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 1, {
              Complex[4.702992751240039, -0.27204884315225386`], 
              Complex[2.6819250932991716`, -1.6754795971390894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.036007780489124, 0.015179546227436348`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 2, {
              Complex[7.036007780489124, 0.015179546227436348`], 
              Complex[5.352606764651276, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.712543738542191, -0.27014758438335257`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27014758438335257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 1, {
              Complex[4.712543738542191, -0.27014758438335257`], 
              Complex[2.692346754360387, -1.6721967497195445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.027765168608571, 0.015398887855965332`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015398887855965332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 2, {
              Complex[7.027765168608571, 0.015398887855965332`], 
              Complex[5.343549216446446, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.722067993288218, -0.26828539346253194`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26828539346253194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669008`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 1, {
              Complex[4.722067993288218, -0.26828539346253194`], 
              Complex[2.702753826320576, -1.6689564964669008`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.019542340843494, 0.015622483989198301`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198301`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.33450584402538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 2, {
              Complex[7.019542340843494, 0.015622483989198301`], 
              Complex[5.33450584402538, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.731567022892644, -0.2664614867867361}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2664614867867361`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 1, {
              Complex[4.731567022892644, -0.2664614867867361], 
              Complex[2.713147790142196, -1.6657580424757261`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.011337781577717, 0.015850459092959828`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959828`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 2, {
              Complex[7.011337781577717, 0.015850459092959828`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.741042311288871, -0.26467511963294066`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 1, {
              Complex[4.741042311288871, -0.26467511963294066`], 
              Complex[2.7235301089335913`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.0031500031188445`, 0.01608294265041594}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0031500031188445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01608294265041594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 2, {
              Complex[7.0031500031188445`, 0.01608294265041594], 
              Complex[5.316455202430543, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.750495321087509, -0.26292558473487154`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.750495321087509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 1, {
              Complex[4.750495321087509, -0.26292558473487154`], 
              Complex[2.7339022301229705`, -1.6594835406566921`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.994977543195845, 0.016320069418202385`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159653617854765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 2, {
              Complex[6.994977543195845, 0.016320069418202385`], 
              Complex[5.307444781657182, -1.159653617854765]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.759927495651799, -0.2612122109807511}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.759927495651799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 1, {
              Complex[4.759927495651799, -0.2612122109807511], 
              Complex[2.7442655875587194`, -1.6564060870885486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.986818962565742, 0.016561979698683844`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565742`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 2, {
              Complex[6.986818962565742, 0.016561979698683844`], 
              Complex[5.2984422283503445`, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.769340261099353, -0.25953436222533105`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25953436222533105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.754621603545414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.653367618952438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 1, {
              Complex[4.769340261099353, -0.25953436222533105`], 
              Complex[2.754621603545414, -1.653367618952438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.978672842717983, 0.01680881962953307}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 2, {
              Complex[6.978672842717983, 0.01680881962953307], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.778735028238791, -0.2578914362102898}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.764971690824241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 1, {
              Complex[4.778735028238791, -0.2578914362102898], 
              Complex[2.764971690824241, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.970537783665924, 0.017060741491919475`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919475`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2804546327214155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 2, {
              Complex[6.970537783665924, 0.017060741491919475`], 
              Complex[5.2804546327214155`, -1.159256290802515]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.788113194449318, -0.2562828635878305}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2562828635878305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 1, {
              Complex[4.788113194449318, -0.2562828635878305], 
              Complex[2.775317254506115, -1.6474051996538635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.962412401815591, 0.017317904038714277`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714277`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 2, {
              Complex[6.962412401815591, 0.017317904038714277`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.797476145510829, -0.2547081070429693}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.797476145510829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652962`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647398`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 1, {
              Complex[4.797476145510829, -0.2547081070429693], 
              Complex[2.7856596939652962`, -1.644480108647398]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.954295327902444, 0.017580472844237614`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237614`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 2, {
              Complex[6.954295327902444, 0.017580472844237614`], 
              Complex[5.262480372776144, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.806825257391718, -0.2531666605106765}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.641591721857337`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 1, {
              Complex[4.806825257391718, -0.2531666605106765], 
              Complex[2.796000404700962, -1.641591721857337]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.9461852049875565`, 0.0178486206772136}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.9461852049875565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0178486206772136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.253494529973698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 2, {
              Complex[6.9461852049875565`, 0.0178486206772136], 
              Complex[5.253494529973698, -1.1588206660799292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8161618980011855`, -0.25165804848463746`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25165804848463746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 1, {
              Complex[4.8161618980011855`, -0.25165804848463746`], 
              Complex[2.8063407801738793`, -1.6387395459042158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.938080686504964, 0.018122527898744745`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 2, {
              Complex[6.938080686504964, 0.018122527898744745`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.825487428912641, -0.25018182541497647`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25018182541497647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 1, {
              Complex[4.825487428912641, -0.25018182541497647`], 
              Complex[2.816682213625118, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.929980434352448, 0.018402382887287818`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018402382887287818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 2, {
              Complex[6.929980434352448, 0.018402382887287818`], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.834803207064381, -0.24873757519284634`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.8270260998834296`, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.921883117018335, 0.018688382492788227`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018335`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 2, {
              Complex[6.921883117018335, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8441105864437315`, -0.24732491072033733`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8441105864437315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24732491072033733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 1, {
              Complex[4.8441105864437315`, -0.24732491072033733`], 
              Complex[2.8373738371679256`, -1.6303957901157313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.913787407737206, 0.018980732522336757`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 2, {
              Complex[6.913787407737206, 0.018980732522336757`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8534109197605035`, -0.24594347356467763`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8534109197605035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 1, {
              Complex[4.8534109197605035`, -0.24594347356467763`], 
              Complex[2.847726828892448, -1.6276841087738216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.90569198266763, 0.019279648259930976`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259930976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 2, {
              Complex[6.90569198266763, 0.019279648259930976`], 
              Complex[5.208519392705085, -1.1579970934399622`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.862705560115598, -0.24459293369624502`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 1, {
              Complex[4.862705560115598, -0.24459293369624502`], 
              Complex[2.858086485478033, -1.6250066071493985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.897595519085279, 0.01958535502317052}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 2, {
              Complex[6.897595519085279, 0.01958535502317052], 
              Complex[5.199504918610364, -1.1578159953084994`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.871995862670491, -0.24327298931042018`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931042018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.622362964243187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 1, {
              Complex[4.871995862670491, -0.24327298931042018`], 
              Complex[2.868454226179847, -1.622362964243187]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.889496693584875, 0.019898088759987564`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157628923856052`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 2, {
              Complex[6.889496693584875, 0.019898088759987564`], 
              Complex[5.190480530819805, -1.157628923856052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.881283186323275, -0.24198336673385498`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 1, {
              Complex[4.881283186323275, -0.24198336673385498`], 
              Complex[2.8788314809349784`, -1.6197528872232831`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.881394180284588, 0.020218096688815565`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815565`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 2, {
              Complex[6.881394180284588, 0.020218096688815565`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8905688953969415`, -0.24072382041628837`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 1, {
              Complex[4.8905688953969415`, -0.24072382041628837`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.873286649026525, 0.020545637985932896`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 2, {
              Complex[6.873286649026525, 0.020545637985932896`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.899854361345617, -0.23949413300958722`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.899620317047638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6146324008788784`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 1, {
              Complex[4.899854361345617, -0.23949413300958722`], 
              Complex[2.899620317047638, -1.6146324008788784`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.865172763566979, 0.02088098452409496}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02088098452409496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270224`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 2, {
              Complex[6.865172763566979, 0.02088098452409496], 
              Complex[5.163333010028644, -1.1570293877270224`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.909140964484508, -0.23829411553630872`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.909140964484508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9100348287409497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.612121547840818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 1, {
              Complex[4.909140964484508, -0.23829411553630872`], 
              Complex[2.9100348287409497`, -1.612121547840818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.857051179750135, 0.02122442166697627}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02122442166697627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 2, {
              Complex[6.857051179750135, 0.02122442166697627], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.918430095749454, -0.23712360765068738`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 1, {
              Complex[4.918430095749454, -0.23712360765068738`], 
              Complex[2.920464719105737, -1.6096433738762481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.848920543658824, 0.021576249124412635`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021576249124412635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1565950476836857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 2, {
              Complex[6.848920543658824, 0.021576249124412635`], 
              Complex[5.145157618862018, -1.1565950476836857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.927723158492043, -0.23598247799562727`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9309115003944672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6071977299543911`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 1, {
              Complex[4.927723158492043, -0.23598247799562727`], 
              Complex[2.9309115003944672`, -1.6071977299543911`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.840779489735858, 0.021936781873947226`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 2, {
              Complex[6.840779489735858, 0.021936781873947226`], 
              Complex[5.136042207268362, -1.1563665913076098`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.9370215703164995`, -0.234870624659986}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703164995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.234870624659986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.941376707437419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 1, {
              Complex[4.9370215703164995`, -0.234870624659986], 
              Complex[2.941376707437419, -1.6047844970867335`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.832626638869334, 0.02230635115475651}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02230635115475651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 2, {
              Complex[6.832626638869334, 0.02230635115475651], 
              Complex[5.126906229415363, -1.1561301764198546`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.946326764964685, -0.23378797574121}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23378797574121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060649`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 1, {
              Complex[4.946326764964685, -0.23378797574121], 
              Complex[2.9518618998259756`, -1.6024035870060649`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.824460596435172, 0.022685305540684493`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684493`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 2, {
              Complex[6.824460596435172, 0.022685305540684493`], 
              Complex[5.117748090945094, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.955640194255799, -0.23273449001922958`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 1, {
              Complex[4.955640194255799, -0.23273449001922958`], 
              Complex[2.9623686641736446`, -1.6000549429658453`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.8162799502898626`, 0.02307401209983014}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8162799502898626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02307401209983014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 2, {
              Complex[6.8162799502898626`, 0.02307401209983014], 
              Complex[5.108566172536499, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.9649633300876665`, -0.23171015774841358`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.972898616463317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5977385406678666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 1, {
              Complex[4.9649633300876665`, -0.23171015774841358`], 
              Complex[2.972898616463317, -1.5977385406678666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.8080832687062705`, 0.02347285764894477}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8080832687062705`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02347285764894477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0993588274563555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 2, {
              Complex[6.8080832687062705`, 0.02347285764894477], 
              Complex[5.0993588274563555`, -1.1553695984099268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.974297666506787, -0.23071500157543234`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23071500157543234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5954543893273725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 1, {
              Complex[4.974297666506787, -0.23071500157543234`], 
              Complex[2.9834534044896506`, -1.5954543893273725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.799869098244956, 0.023882250111808084`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808084`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 2, {
              Complex[6.799869098244956, 0.023882250111808084`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.983644721854632, -0.2297490775919431}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 1, {
              Complex[4.983644721854632, -0.2297490775919431], 
              Complex[2.9940347104060314`, -1.5932025328859936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.791635961553228, 0.024302619991774015`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.791635961553228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 2, {
              Complex[6.791635961553228, 0.024302619991774015`], 
              Complex[5.080861117956596, -1.15481581889049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.993006040998136, -0.22881247653229753`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 1, {
              Complex[4.993006040998136, -0.22881247653229753`], 
              Complex[3.0046442533861, -1.5909830513843408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.783382355083753, 0.02473442196983401}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02473442196983401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 2, {
              Complex[6.783382355083753, 0.02473442196983401], 
              Complex[5.071567299655017, -1.1545236028247545`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.002383197652629, -0.22790532512782447`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.002383197652629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22790532512782447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5887960625076496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 1, {
              Complex[5.002383197652629, -0.22790532512782447`], 
              Complex[3.0152837924104223`, -1.5887960625076496`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.775106746724163, 0.025178136640842865`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 2, {
              Complex[6.775106746724163, 0.025178136640842865`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.011777796806058, -0.2270277876307708}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.0259551291896347`, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.766807573328626, 0.025634272402031203`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 2, {
              Complex[6.766807573328626, 0.025634272402031203`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.021191477253694, -0.22618006752276337`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22618006752276337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 1, {
              Complex[5.021191477253694, -0.22618006752276337`], 
              Complex[3.036660111236013, -1.5845202322015448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.7584832381419595`, 0.026103367509584394`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026103367509584394`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 2, {
              Complex[6.7584832381419595`, 0.026103367509584394`], 
              Complex[5.043484464017904, -1.153579687141173]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.030625914253164, -0.22536240942454527`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 1, {
              Complex[5.030625914253164, -0.22536240942454527`], 
              Complex[3.0474006350962957`, -1.5824318310164633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.750132108106198, 0.026585992320965892`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 2, {
              Complex[6.750132108106198, 0.026585992320965892`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.040082822310154, -0.22457510122598123`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 1, {
              Complex[5.040082822310154, -0.22457510122598123`], 
              Complex[3.058178649759413, -1.5803768075197018`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.741752511039166, 0.027082751742796587`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.741752511039166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027082751742796587`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 2, {
              Complex[6.741752511039166, 0.027082751742796587`], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.049563958105736, -0.22381847645779854`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.578355498041264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 1, {
              Complex[5.049563958105736, -0.22381847645779854`], 
              Complex[3.0689961602536635`, -1.578355498041264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.733342732673844, 0.027594287906544415`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 2, {
              Complex[6.733342732673844, 0.027594287906544415`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.059071123576936, -0.2230929169293575}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2230929169293575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 1, {
              Complex[5.059071123576936, -0.2230929169293575], 
              Complex[3.0798552314489034`, -1.5763682904678338`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.724901013546819, 0.028121283097053466`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028121283097053466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 2, {
              Complex[6.724901013546819, 0.028121283097053466`], 
              Complex[5.005499610747705, -1.1521425692773901`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.0686061691627415`, -0.22239885565995443`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0686061691627415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563799`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 1, {
              Complex[5.0686061691627415`, -0.22239885565995443`], 
              Complex[3.0907579920802766`, -1.5744156275563799`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.716425545723423, 0.02866446296210374}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 2, {
              Complex[6.716425545723423, 0.02866446296210374], 
              Complex[4.9958932747662494`, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.078170997228453, -0.2217367801348355}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2217367801348355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 1, {
              Complex[5.078170997228453, -0.2217367801348355], 
              Complex[3.1017066390111157`, -1.5724980106155333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.707914469346526, 0.029224600034819224`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819224`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 2, {
              Complex[6.707914469346526, 0.029224600034819224`], 
              Complex[4.986238567027153, -1.1513352953732718`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.087767565681953, -0.22110723592124717`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1127034417538186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 1, {
              Complex[5.087767565681953, -0.22110723592124717`], 
              Complex[3.1127034417538186`, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.699365868995314, 0.02980251760487482}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 2, {
              Complex[6.699365868995314, 0.02980251760487482], 
              Complex[4.976533205571878, -1.1509067011120155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.097397891796026, -0.2205108306846833}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 1, {
              Complex[5.097397891796026, -0.2205108306846833], 
              Complex[3.123750747268463, -1.5687702376348136`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.6907777698397455`, 0.030399093979211242`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 2, {
              Complex[6.6907777698397455`, 0.030399093979211242`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.107064056251541, -0.21994823865092936`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 1, {
              Complex[5.107064056251541, -0.21994823865092936`], 
              Complex[3.134850985060283, -1.5669614161122603`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.682148133575791, 0.031015267178413856`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 2, {
              Complex[6.682148133575791, 0.031015267178413856`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.116768207416753, -0.21942020556585173`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272423`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 1, {
              Complex[5.116768207416753, -0.21942020556585173`], 
              Complex[3.146006672598036, -1.565190320272423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.673474854126103, 0.031652040121196406`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126103`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196406`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1495098349909931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 2, {
              Complex[6.673474854126103, 0.031652040121196406`], 
              Complex[4.947089201235957, -1.1495098349909931`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.126512565878384, -0.21892755421211527`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 1, {
              Complex[5.126512565878384, -0.21892755421211527`], 
              Complex[3.1572204210764316`, -1.563457815486074]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.664755753090323, 0.03231048635665902}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090323`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 2, {
              Complex[6.664755753090323, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1362994292403545`, -0.21847119055042008`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5617648582291666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 1, {
              Complex[5.1362994292403545`, -0.21847119055042008`], 
              Complex[3.168494941546648, -1.5617648582291666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.655988574929111, 0.03299175641234991}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641234991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 2, {
              Complex[6.655988574929111, 0.03299175641234991], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.14613117720593, -0.21805211056251347`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.14613117720593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 1, {
              Complex[5.14613117720593, -0.21805211056251347`], 
              Complex[3.179833051439645, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.647170981866001, 0.03369708483581623}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 2, {
              Complex[6.647170981866001, 0.03369708483581623], 
              Complex[4.917099209420433, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.156010276958657, -0.2176714078844637}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2176714078844637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 1, {
              Complex[5.156010276958657, -0.2176714078844637], 
              Complex[3.191237681507363, -1.5585019153641588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.638300548491651, 0.03442779801852966}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.638300548491651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 2, {
              Complex[6.638300548491651, 0.03442779801852966], 
              Complex[4.906968264234701, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1659392888565, -0.21733028233169835`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21733028233169835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989886`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 1, {
              Complex[5.1659392888565, -0.21733028233169835`], 
              Complex[3.2027118832068147`, -1.556934372989886]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.629374756056008, 0.035185322904060665`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.035185322904060665`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146742881222183`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 2, {
              Complex[6.629374756056008, 0.035185322904060665`], 
              Complex[4.896765181899932, -1.146742881222183]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.175920872451979, -0.21703004943242468`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5554112852390445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 1, {
              Complex[5.175920872451979, -0.21703004943242468`], 
              Complex[3.214258836551336, -1.5554112852390445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.620390986435504, 0.03597119669747853}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 2, {
              Complex[6.620390986435504, 0.03597119669747853], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1859577928485665`, -0.21677215110365722`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1859577928485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21677215110365722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 1, {
              Complex[5.1859577928485665`, -0.21677215110365722`], 
              Complex[3.225881858451648, -1.5539342010442931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.611346515764966, 0.03678707771053728}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 2, {
              Complex[6.611346515764966, 0.03678707771053728], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.196052927399867, -0.21655816762459867`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512189`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 1, {
              Complex[5.196052927399867, -0.21655816762459867`], 
              Complex[3.237584411566566, -1.552504823512189]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.60223850772765, 0.037634757497710856`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 2, {
              Complex[6.60223850772765, 0.037634757497710856`], 
              Complex[4.86569057136354, -1.1447564293886001`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.206209272752709, -0.21638983108607518`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21638983108607518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 1, {
              Complex[5.206209272752709, -0.21638983108607518`], 
              Complex[3.249370113678695, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.593064006502224, 0.038516174462077786`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502224`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077786`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8551656824952785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 2, {
              Complex[6.593064006502224, 0.038516174462077786`], 
              Complex[4.8551656824952785`, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.216429952227796, -0.21626904052272736`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549796866430609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 1, {
              Complex[5.216429952227796, -0.21626904052272736`], 
              Complex[3.261242747603762, -1.549796866430609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.583819929372991, 0.03943342913804211}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.583819929372991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271393`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 2, {
              Complex[6.583819929372991, 0.03943342913804211], 
              Complex[4.844551277287892, -1.1432655464271393`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.226718223521198, -0.21619787896744078`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21619787896744078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 1, {
              Complex[5.226718223521198, -0.21619787896744078`], 
              Complex[3.273206271632576, -1.5485226131825367`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.574503059020016, 0.04038880139063545}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04038880139063545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 2, {
              Complex[6.574503059020016, 0.04038880139063545], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.237077486695946, -0.21617863270584675`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 1, {
              Complex[5.237077486695946, -0.21617863270584675`], 
              Complex[3.2852648304909673`, -1.5473047611339124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.565110035519868, 0.04138476980950465}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 2, {
              Complex[6.565110035519868, 0.04138476980950465], 
              Complex[4.823037890424123, -1.141619564099015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.247511292414013, -0.21621381305374002`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 1, {
              Complex[5.247511292414013, -0.21621381305374002`], 
              Complex[3.2974227667841562`, -1.546146059999975]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.55563734810662, 0.04242403362064897}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.55563734810662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8121304187769836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.140731479419345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 2, {
              Complex[6.55563734810662, 0.04242403362064897], 
              Complex[4.8121304187769836`, -1.140731479419345]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.258023350333588, -0.21630618103294622`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.309684632866044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5450495423633648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 1, {
              Complex[5.258023350333588, -0.21630618103294622`], 
              Complex[3.309684632866044, -1.5450495423633648`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.546081326768185, 0.043509537491681925`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.043509537491681925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 2, {
              Complex[6.546081326768185, 0.043509537491681925`], 
              Complex[4.801116427450051, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.268617537562702, -0.2164587753829211}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2164587753829211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 1, {
              Complex[5.268617537562702, -0.2164587753829211], 
              Complex[3.3220552030387207`, -1.5440185562746334`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.536438133786875, 0.04464449966811471}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.789991141967791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 2, {
              Complex[6.536438133786875, 0.04464449966811471], 
              Complex[4.789991141967791, -1.1388089172545466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.279297907015237, -0.21667494441768237`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 1, {
              Complex[5.279297907015237, -0.21667494441768237`], 
              Complex[3.3345394859397888`, -1.5430568024175477`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.526703755378125, 0.04583244395046667}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378125`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04583244395046667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 2, {
              Complex[6.526703755378125, 0.04583244395046667], 
              Complex[4.778749553944276, -1.1377669993932331`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.290068695455681, -0.2169583823220915}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.290068695455681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2169583823220915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 1, {
              Complex[5.290068695455681, -0.2169583823220915], 
              Complex[3.347142736911111, -1.54216837655994]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.516873993640986, 0.047077236106414795`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106414795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399098006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 2, {
              Complex[6.516873993640986, 0.047077236106414795`], 
              Complex[4.767386408695087, -1.1366657399098006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.300934330939945, -0.21731317057992391`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 1, {
              Complex[5.300934330939945, -0.21731317057992391`], 
              Complex[3.359870470056673, -1.5413578181336933`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.50694445911303, 0.048383125410604036`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410604036`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 2, {
              Complex[6.50694445911303, 0.048383125410604036`], 
              Complex[4.75589619316095, -1.1355004133676156`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.311899439255095, -0.21774382534019782`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 1, {
              Complex[5.311899439255095, -0.21774382534019782`], 
              Complex[3.3727284695824946`, -1.5406301659307433`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.496910564326775, 0.04975479211876465}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037839`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 2, {
              Complex[6.496910564326775, 0.04975479211876465], 
              Complex[4.744273124550118, -1.1342657987037839`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.322968848822687, -0.218255351659741}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.218255351659741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 1, {
              Complex[5.322968848822687, -0.218255351659741], 
              Complex[3.385722799858256, -1.5399910220686348`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.486767518902967, 0.05119740181429564}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902967`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05119740181429564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 2, {
              Complex[6.486767518902967, 0.05119740181429564], 
              Complex[4.732511140259883, -1.1329561151622776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.334147593347899, -0.21885330570991685`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3988598134359265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 1, {
              Complex[5.334147593347899, -0.21885330570991685`], 
              Complex[3.3988598134359265`, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.476510326898408, 0.05271666771536851}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 2, {
              Complex[6.476510326898408, 0.05271666771536851], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.34544091125561, -0.2195438662043099}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2195438662043099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.412146155988547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 1, {
              Complex[5.34544091125561, -0.2195438662043099], 
              Complex[3.412146155988547, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.466133787367247, 0.054318922199527095`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054318922199527095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1300851667094982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 2, {
              Complex[6.466133787367247, 0.054318922199527095`], 
              Complex[4.70854473004717, -1.1300851667094982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.356854240636268, -0.22033391649033324`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22033391649033324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 1, {
              Complex[5.356854240636268, -0.22033391649033324`], 
              Complex[3.4255887667699536`, -1.5386707368477486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.455632499412816, 0.05601119898888057}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.455632499412816`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 2, {
              Complex[6.455632499412816, 0.05601119898888057], 
              Complex[4.696326724353138, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.368393208004248, -0.221231138946749}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.368393208004248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.221231138946749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 1, {
              Complex[5.368393208004248, -0.221231138946749], 
              Complex[3.4391948727143964`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.445000873427293, 0.057801327638013704`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.057801327638013704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 2, {
              Complex[6.445000873427293, 0.057801327638013704`], 
              Complex[4.683942648848311, -1.1268270341592395`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.380063608617472, -0.22224412353114423`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 1, {
              Complex[5.380063608617472, -0.22224412353114423`], 
              Complex[3.4529719736549263`, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.434233150770422, 0.059698042168787976`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168787976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 2, {
              Complex[6.434233150770422, 0.059698042168787976`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.3918713753777405`, -0.22338249250843528`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.3918713753777405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 1, {
              Complex[5.3918713753777405`, -0.22338249250843528`], 
              Complex[3.4669278152904957`, -1.5384206511375542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.423323434867787, 0.06171110588324154}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 2, {
              Complex[6.423323434867787, 0.06171110588324154], 
              Complex[4.658646056679822, -1.1231061803689866`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.403822532373675, -0.22465704353173413`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22465704353173413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 1, {
              Complex[5.403822532373675, -0.22465704353173413`], 
              Complex[3.4810703454089245`, -1.5386239263253452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.41226573766677, 0.06385145452602912}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.41226573766677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6457178539169055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.121043437540103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 2, {
              Complex[6.41226573766677, 0.06385145452602912], 
              Complex[4.6457178539169055`, -1.121043437540103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.4159231278759306`, -0.2260799132874317}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4159231278759306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2260799132874317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.495407647393269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5389924972372535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 1, {
              Complex[5.4159231278759306`, -0.2260799132874317], 
              Complex[3.495407647393269, -1.5389924972372535`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.401054046640448, 0.0661313600083585}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0661313600083585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397076`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 2, {
              Complex[6.401054046640448, 0.0661313600083585], 
              Complex[4.6325923193910725`, -1.1188275290397076`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.4281791399671135`, -0.227664763771187}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4281791399671135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.227664763771187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 1, {
              Complex[5.4281791399671135`, -0.227664763771187], 
              Complex[3.509947843100934, -1.5395421364907362`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.389682419157072, 0.06856461676025134}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157072`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 2, {
              Complex[6.389682419157072, 0.06856461676025134], 
              Complex[4.619261335536664, -1.1164425322748186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.440596345893877, -0.22942699279424592`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 1, {
              Complex[5.440596345893877, -0.22942699279424592`], 
              Complex[3.524698954687548, -1.5402906900657312`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.378145113127534, 0.07116675231062954}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127534`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113870454078992`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 2, {
              Complex[6.378145113127534, 0.07116675231062954], 
              Complex[4.605716884708901, -1.113870454078992]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.453180143569078, -0.23138396931833902`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5412583702907798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 1, {
              Complex[5.453180143569078, -0.23138396931833902`], 
              Complex[3.539668711719688, -1.5412583702907798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.366436765503008, 0.07395526269357332}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.366436765503008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 2, {
              Complex[6.366436765503008, 0.07395526269357332], 
              Complex[4.591951242060746, -1.1110909376562434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.465935310345425, -0.23355529236003078`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5548642858592667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 1, {
              Complex[5.465935310345425, -0.23355529236003078`], 
              Complex[3.5548642858592667`, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.354552633501295, 0.07694987142173926}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 2, {
              Complex[6.354552633501295, 0.07694987142173926], 
              Complex[4.577957240848536, -1.1080809366516993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.478865680202782, -0.23596306901322983`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901322983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 1, {
              Complex[5.478865680202782, -0.23596306901322983`], 
              Complex[3.5702919304393554`, -1.5439457760136317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.34248891741965, 0.08017280757570203}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.34248891741965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 2, {
              Complex[6.34248891741965, 0.08017280757570203], 
              Complex[4.563728632846567, -1.1048143601285858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.491973715947516, -0.23863220192231419`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.585956496459983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 1, {
              Complex[5.491973715947516, -0.23863220192231419`], 
              Complex[3.585956496459983, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.330243188435803, 0.08364909334179291}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 2, {
              Complex[6.330243188435803, 0.08364909334179291], 
              Complex[4.549260572342168, -1.1012616980470775`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5052599482994165`, -0.2415906683469038}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.547826403307315`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 1, {
              Complex[5.5052599482994165`, -0.2415906683469038], 
              Complex[3.601860790294313, -1.547826403307315]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.317814949521484, 0.08740682313953863}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 2, {
              Complex[6.317814949521484, 0.08740682313953863], 
              Complex[4.534550258420689, -1.097389646163949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.51872224974151, -0.24486976056502419`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.51872224974151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 1, {
              Complex[5.51872224974151, -0.24486976056502419`], 
              Complex[3.6180047326806646`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.305206361593249, 0.09147740408550006}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.305206361593249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408550006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 2, {
              Complex[6.305206361593249, 0.09147740408550006], 
              Complex[4.519597775965091, -1.0931607636269256`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5323549095256235`, -0.248504239352635}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5323549095256235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.248504239352635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 1, {
              Complex[5.5323549095256235`, -0.248504239352635], 
              Complex[3.6343842753970184`, -1.5531827657019457`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.292423168507695, 0.095895709531589}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.095895709531589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 2, {
              Complex[6.292423168507695, 0.095895709531589], 
              Complex[4.50440717897338, -1.0885332177365603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.546147480479421, -0.2525323274039474}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2525323274039474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 1, {
              Complex[5.546147480479421, -0.2525323274039474], 
              Complex[3.650990035081118, -1.5565214356849035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.279475850255288, 0.10070007254234209`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255288`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4889878567307235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0834607001253282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 2, {
              Complex[6.279475850255288, 0.10070007254234209`], 
              Complex[4.4889878567307235`, -1.0834607001253282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.56008338350221, -0.2569954375693104}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.56008338350221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 1, {
              Complex[5.56008338350221, -0.2569954375693104], 
              Complex[3.667805619167919, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.266381018465573, 0.10593201418800287`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 2, {
              Complex[6.266381018465573, 0.10593201418800287`], 
              Complex[4.473356207864625, -1.0778926376684697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5741382895514295`, -0.26193749411720313`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5647713188313284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 1, {
              Complex[5.5741382895514295`, -0.26193749411720313`], 
              Complex[3.6848056561525766`, -1.5647713188313284`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.2531630344217985`, 0.1116355648600116}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344217985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1116355648600116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 2, {
              Complex[6.2531630344217985`, 0.1116355648600116], 
              Complex[4.457537610074802, -1.0717748675240155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.588278361042629, -0.26740367180599306`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.588278361042629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26740367180599306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 1, {
              Complex[5.588278361042629, -0.26740367180599306`], 
              Complex[3.7019536132591475`, -1.5697928508801495`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.239855767662159, 0.11785600339463097`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239855767662159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 2, {
              Complex[6.239855767662159, 0.11785600339463097`], 
              Complex[4.44156860245767, -1.0650509901679481`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.602458533258957, -0.27343836455892495`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 1, {
              Complex[5.602458533258957, -0.27343836455892495`], 
              Complex[3.719199600336582, -1.5754871190552309`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.226504314571602, 0.12463782579822917`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.057664637476592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 2, {
              Complex[6.226504314571602, 0.12463782579822917`], 
              Complex[4.425499081603797, -1.057664637476592]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.616621151226329, -0.2800822323034728}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 1, {
              Complex[5.616621151226329, -0.2800822323034728], 
              Complex[3.736478521301465, -1.5819069561624797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.213166361508075, 0.13202179213539886`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 2, {
              Complex[6.213166361508075, 0.13202179213539886`], 
              Complex[4.409394150148914, -1.0495628600775764`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.6306954263332605`, -0.28736829986212964`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28736829986212964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 1, {
              Complex[5.6306954263332605`, -0.28736829986212964`], 
              Complex[3.7537091204741757`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.199912728184148, 0.140041025467066}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.140041025467066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 2, {
              Complex[6.199912728184148, 0.140041025467066], 
              Complex[4.393335070431697, -1.040700701679103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.644598280659571, -0.29531732776612085`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 1, {
              Complex[5.644598280659571, -0.29531732776612085`], 
              Complex[3.770794613325989, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.1868265233398665`, 0.1487163827100988}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740917, -1.0310467452404808`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.658237106888954, -0.3039330313949995}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.658237106888954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 1, {
              Complex[5.658237106888954, -0.3039330313949995], 
              Complex[3.787625571970205, -1.6058947337101088`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.174000384831828, 0.15805167382144333`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.174000384831828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 2, {
              Complex[6.174000384831828, 0.15805167382144333`], 
              Complex[4.361754274818786, -1.0205889908238686`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.671514683640783, -0.3131980951405518}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3131980951405518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 1, {
              Complex[5.671514683640783, -0.3131980951405518], 
              Complex[3.8040854242836257`, -1.6155012704525775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.161531564303005, 0.16802967600526267`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 2, {
              Complex[6.161531564303005, 0.16802967600526267`], 
              Complex[4.34645857273412, -1.0093399640268057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.684335924466963, -0.3230721172560285}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669845`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 1, {
              Complex[5.684335924466963, -0.3230721172560285], 
              Complex[3.8200582761098665`, -1.6258686488669845`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.1495151781876825`, 0.17861007860412006`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17861007860412006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 2, {
              Complex[6.1495151781876825`, 0.17861007860412006`], 
              Complex[4.331647428673965, -0.9973396858188028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.696615451432763, -0.3334924140604973}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 1, {
              Complex[5.696615451432763, -0.3334924140604973], 
              Complex[3.8354379364471765`, -1.6369295948434255`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.138036634132393, 0.18973028734408134`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 2, {
              Complex[6.138036634132393, 0.18973028734408134`], 
              Complex[4.317427040750873, -0.9846553249905693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.708284492538861, -0.34437794490953016`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490953016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 1, {
              Complex[5.708284492538861, -0.34437794490953016`], 
              Complex[3.850136390976634, -1.6485937815375424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.127164733575719, 0.20130934934494968`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934494968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 2, {
              Complex[6.127164733575719, 0.20130934934494968`], 
              Complex[4.3038854304700065`, -0.9713771047973333]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.719295626734264, -0.35563571212946327`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563571212946327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 1, {
              Complex[5.719295626734264, -0.35563571212946327`], 
              Complex[3.8640899263017108`, -1.6607550217891232`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.1169469267372625`, 0.21325435309295837`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 2, {
              Complex[6.1169469267372625`, 0.21325435309295837`], 
              Complex[4.291086318485069, -0.9576111105020118]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.729624504719875, -0.3671682712416456}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.877261765238287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6733000146368138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 1, {
              Complex[5.729624504719875, -0.3671682712416456], 
              Complex[3.877261765238287, -1.6733000146368138`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.107407591816001, 0.225467938702334}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591816001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.225467938702334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303969`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233601`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 2, {
              Complex[6.107407591816001, 0.225467938702334], 
              Complex[4.279066489303969, -0.9434705428233601]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.7392685732062425`, -0.378880805741801}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378880805741801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 1, {
              Complex[5.7392685732062425`, -0.378880805741801], 
              Complex[3.889641123048907, -1.6861168153853228`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.098549310734496, 0.23785537273090274`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23785537273090274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 2, {
              Complex[6.098549310734496, 0.23785537273090274`], 
              Complex[4.267836735050403, -0.9290672478326645]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.748243586852647, -0.3906866010723898}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 1, {
              Complex[5.748243586852647, -0.3906866010723898], 
              Complex[3.901239519558195, -1.6991015885376013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0903563572018244`, 0.25033002218771333`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 2, {
              Complex[6.0903563572018244`, 0.25033002218771333`], 
              Complex[4.257385543344473, -0.9145049639864032]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.756579019389742, -0.40251041678372}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.756579019389742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.712162962685892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 1, {
              Complex[5.756579019389742, -0.40251041678372], 
              Complex[3.912085621903242, -1.712162962685892]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.082799285592932, 0.26281672672835515`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.082799285592932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 2, {
              Complex[6.082799285592932, 0.26281672672835515`], 
              Complex[4.247684254548457, -0.8998749672010695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.7643133844056464`, -0.4142898642644484}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 1, {
              Complex[5.7643133844056464`, -0.4142898642644484], 
              Complex[3.9222198214979054`, -1.7252240340035676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.075839610164614, 0.27525317641875735`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 2, {
              Complex[6.075839610164614, 0.27525317641875735`], 
              Complex[4.238692484798849, -0.8852540673280818]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.771490138844716, -0.4259752554682592}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4259752554682592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 1, {
              Complex[5.771490138844716, -0.4259752554682592], 
              Complex[3.931689378166073, -1.7382225152116562`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.069433901558818, 0.2875897604942177}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 2, {
              Complex[6.069433901558818, 0.2875897604942177], 
              Complex[4.230362981869569, -0.8707044591549227]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.778154476287737, -0.43752848511674636`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 1, {
              Complex[5.778154476287737, -0.43752848511674636`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.063536993524539, 0.2997884495937324}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524539`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562747872176812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 2, {
              Complex[6.063536993524539, 0.2997884495937324], 
              Complex[4.222645506003506, -0.8562747872176812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.784351043372478, -0.44892143644815663`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 1, {
              Complex[5.784351043372478, -0.44892143644815663`], 
              Complex[3.948835712532857, -1.763848614878014]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.05810426649939, 0.3118212015393396}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.05810426649939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3118212015393396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 2, {
              Complex[6.05810426649939, 0.3118212015393396], 
              Complex[4.2154896572704255`, -0.8420018475938867]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.790122459407806, -0.4601342612759227}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.956611577877951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 1, {
              Complex[5.790122459407806, -0.4601342612759227], 
              Complex[3.956611577877951, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.053093127997608, 0.32366824142440037`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 2, {
              Complex[6.053093127997608, 0.32366824142440037`], 
              Complex[4.208846763357218, -0.8279125023887518]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.795508462127412, -0.4711537472500254}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 1, {
              Complex[5.795508462127412, -0.4711537472500254], 
              Complex[3.963917947183657, -1.7887821416602478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.048463866858472, 0.3353164289039024}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 2, {
              Complex[6.048463866858472, 0.3353164289039024], 
              Complex[4.202671020177383, -0.8140255411104017]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.800545503681593, -0.4819718787730382}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.800945377085382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 1, {
              Complex[5.800545503681593, -0.4819718787730382], 
              Complex[3.9707971711833534`, -1.800945377085382]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.044180057256696, 0.346757819138651}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.346757819138651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 2, {
              Complex[6.044180057256696, 0.346757819138651], 
              Complex[4.196920084784546, -0.8003533490732513]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.805266648945753, -0.49258462786579765`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014506`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 1, {
              Complex[5.805266648945753, -0.49258462786579765`], 
              Complex[3.9772879223008815`, -1.8128946175014506`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.04020866039606, 0.3579884536883505}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 2, {
              Complex[6.04020866039606, 0.3579884536883505], 
              Complex[4.1915552925709445`, -0.7869033281400235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.809701663341316, -0.5029909709021095}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341316`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 1, {
              Complex[5.809701663341316, -0.5029909709021095], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.036519936690694, 0.36900737727295563`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 2, {
              Complex[6.036519936690694, 0.36900737727295563`], 
              Complex[4.1865416324253255`, -0.7736790656393453]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.81387720976465, -0.5131921073476409}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8361393091196956`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 1, {
              Complex[5.81387720976465, -0.5131921073476409], 
              Complex[3.989240598169983, -1.8361393091196956`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.033087248838311, 0.37981585653752803`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.37981585653752803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 2, {
              Complex[6.033087248838311, 0.37981585653752803`], 
              Complex[4.1818475767949295`, -0.7606812732613808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.817817100281683, -0.5231908494724433}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 1, {
              Complex[5.817817100281683, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.029886810127787, 0.3904167697900055}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781002`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 2, {
              Complex[6.029886810127787, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781002]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.82154256758942, -0.5329911517598145}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.82154256758942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 1, {
              Complex[5.82154256758942, -0.5329911517598145], 
              Complex[4.000015848490729, -1.8585170930917858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.02689741297982, 0.40081413643466185`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.825072534840901, -0.5425977517885691}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.825072534840901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 1, {
              Complex[5.825072534840901, -0.5425977517885691], 
              Complex[4.005023753334011, -1.8693886729252436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.024100159124148, 0.411012757878331}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.411012757878331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 2, {
              Complex[6.024100159124148, 0.411012757878331], 
              Complex[4.169414585788292, -0.7230251519753932]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.828423871596708, -0.5520158986267109}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.828423871596708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 1, {
              Complex[5.828423871596708, -0.5520158986267109], 
              Complex[4.009806376364359, -1.8800548315018015`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.021478203650237, 0.4210179459473805}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023488`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 2, {
              Complex[6.021478203650237, 0.4210179459473805], 
              Complex[4.165744108890901, -0.7109055707023488]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.831611629629778, -0.5612511491377987}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 1, {
              Complex[5.831611629629778, -0.5612511491377987], 
              Complex[4.01438190088909, -1.8905208626824326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.019016519204634, 0.4308353192168015}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 2, {
              Complex[6.019016519204634, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8346492560547185`, -0.5703092165540392}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8346492560547185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 1, {
              Complex[5.8346492560547185`, -0.5703092165540392], 
              Complex[4.018766629721938, -1.9007923754230047`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.016701682863842, 0.44047065160543597`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44047065160543597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.687283969636879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 2, {
              Complex[6.016701682863842, 0.44047065160543597`], 
              Complex[4.159001332605871, -0.687283969636879]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.837548783508502, -0.5791958590266284}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 1, {
              Complex[5.837548783508502, -0.5791958590266284], 
              Complex[4.022975200759233, -1.9108751468578675`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.014521685955785, 0.4499297609478431}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937821`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 2, {
              Complex[6.014521685955785, 0.4499297609478431], 
              Complex[4.155898108440934, -0.6757704154937821]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.840320998393065, -0.5879167986060265}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 1, {
              Complex[5.840320998393065, -0.5879167986060265], 
              Complex[4.027020779081279, -1.9207750130848573`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.012465765819384, 0.4592184279956057}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 2, {
              Complex[6.012465765819384, 0.4592184279956057], 
              Complex[4.152955626516614, -0.6644471667545322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.842975588855197, -0.5964776632911527}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 1, {
              Complex[5.842975588855197, -0.5964776632911527], 
              Complex[4.030915226970467, -1.9304977888211983`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.010524257826823, 0.46834233848697243`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.46834233848697243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 2, {
              Complex[6.010524257826823, 0.46834233848697243`], 
              Complex[4.150162032533434, -0.6533083372307816]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8455212744613, -0.6048839465011079}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.940049209103389`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 1, {
              Complex[5.8455212744613, -0.6048839465011079], 
              Complex[4.034669253707697, -1.940049209103389]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.008688465710948, 0.47730704263853463`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 2, {
              Complex[6.008688465710948, 0.47730704263853463`], 
              Complex[4.147506625196923, -0.6423481214415793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.847965919578021, -0.6131409796537513}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.847965919578021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 1, {
              Complex[5.847965919578021, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721932`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.006950548186772, 0.4861179277432377}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086172]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.850316632393394, -0.6212539145605388}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 1, {
              Complex[5.850316632393394, -0.6212539145605388], 
              Complex[4.041793889306879, -1.9586602887011346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.00530341993248, 0.49478020058417976`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.00530341993248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49478020058417976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084482`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 2, {
              Complex[6.00530341993248, 0.49478020058417976`], 
              Complex[4.142572556837021, -0.6209409489084482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.852579851369117, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 1, {
              Complex[5.852579851369117, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.003740665139239, 0.5032988771597039}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597039`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 2, {
              Complex[6.003740665139239, 0.5032988771597039], 
              Complex[4.140277152714267, -0.6104830975830695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.854761420740972, -0.637067142498334}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.976651255485492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.976651255485492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0022564620129675`, 0.5116787778163024}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.600182101786388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 2, {
              Complex[6.0022564620129675`, 0.5116787778163024], 
              Complex[4.1380862591666565`, -0.600182101786388]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.856866656504023, -0.6447767740762026}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 1, {
              Complex[5.856866656504023, -0.6447767740762026], 
              Complex[4.051642476470394, -1.9854268615885544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0008455167911645`, 0.5199245263444042}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0008455167911645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431994`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 2, {
              Complex[6.0008455167911645`, 0.5199245263444042], 
              Complex[4.135993261431994, -0.5900329694879929]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.858900404144714, -0.6523609855265131}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.858900404144714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 1, {
              Complex[5.858900404144714, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.999503006012947, 0.5280405519418746}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 2, {
              Complex[5.999503006012947, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.860867089220407, -0.6598239647344448}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 1, {
              Complex[5.860867089220407, -0.6598239647344448], 
              Complex[4.057727034812089, -2.002562003206255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.998224525941573, 0.5360310932164655}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 2, {
              Complex[5.998224525941573, 0.5360310932164655], 
              Complex[4.132077284632823, -0.5701712799937015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.862770761740872, -0.6671697152100748}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.010930447408191`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 1, {
              Complex[5.862770761740872, -0.6671697152100748], 
              Complex[4.060641656654434, -2.010930447408191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.99700604818503, 0.5439002036016085}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 2, {
              Complex[5.99700604818503, 0.5439002036016085], 
              Complex[4.130243693579621, -0.5604496874212131]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.864615135176838, -0.6744020624307273}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864615135176838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 1, {
              Complex[5.864615135176838, -0.6744020624307273], 
              Complex[4.063477543241716, -2.019171773366147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.995843880689526, 0.5516517577146817}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.550861880464071`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 2, {
              Complex[5.995843880689526, 0.5516517577146817], 
              Complex[4.128486675066933, -0.550861880464071]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.866403620807269, -0.6815246607732992}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.866403620807269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0662389993771475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 1, {
              Complex[5.866403620807269, -0.6815246607732992], 
              Complex[4.0662389993771475`, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.994734633394265, 0.559289458304851}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.559289458304851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825229`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 2, {
              Complex[5.994734633394265, 0.559289458304851], 
              Complex[4.126801932234572, -0.5414037954825229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.868139358018381, -0.6885410007735722}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.035288909793964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 1, {
              Complex[5.868139358018381, -0.6885410007735722], 
              Complex[4.06892999644998, -2.035288909793964]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.993675187934444, 0.5668168435275395}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 2, {
              Complex[5.993675187934444, 0.5668168435275395], 
              Complex[4.125185501625342, -0.5320715402250109]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.869825241082359, -0.6954544165180522}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 1, {
              Complex[5.869825241082359, -0.6954544165180522], 
              Complex[4.071554204602269, -2.0431722200421376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.992662670864551, 0.5742372943510572}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697339`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 2, {
              Complex[5.992662670864551, 0.5742372943510572], 
              Complex[4.123633721017262, -0.5228613872697339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.871463942870232, -0.7022680930260665}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0741150212777635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.050943424924778`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 1, {
              Complex[5.871463942870232, -0.7022680930260665], 
              Complex[4.0741150212777635`, -2.050943424924778]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.991694429947489, 0.5815540419531245}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 2, {
              Complex[5.991694429947489, 0.5815540419531245], 
              Complex[4.12214320087372, -0.5137697672312324]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.87305793589056, -0.7089850735194754}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 1, {
              Complex[5.87305793589056, -0.7089850735194754], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9907680131178696`, 0.5887701750046829}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9907680131178696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845041`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 2, {
              Complex[5.9907680131178696`, 0.5887701750046829], 
              Complex[4.120710798957503, -0.5047932618845041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.874609510991549, -0.7156082665076033}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.066162816169295`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 1, {
              Complex[5.874609510991549, -0.7156082665076033], 
              Complex[4.079058856020895, -2.066162816169295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.989881149781852, 0.5958886467685798}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989881149781852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11933359771601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4959285973192018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 2, {
              Complex[5.989881149781852, 0.5958886467685798], 
              Complex[4.11933359771601, -0.4959285973192018]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.876120794018038, -0.7221404526376911}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 1, {
              Complex[5.876120794018038, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.98903173416212, 0.60291228196345}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98903173416212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.60291228196345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11800888409769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 2, {
              Complex[5.98903173416212, 0.60291228196345], 
              Complex[4.11800888409769, -0.4871726372059141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.877593760675199, -0.7285842912785059}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9882178104361135`, 0.609843783360462}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9882178104361135`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.609843783360462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232897`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 2, {
              Complex[5.9882178104361135`, 0.609843783360462], 
              Complex[4.116734131505035, -0.478522376232897]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.879030249816932, -0.7349423268176082}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 1, {
              Complex[5.879030249816932, -0.7349423268176082], 
              Complex[4.086071031729209, -2.088230594606227]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.987437559449537, 0.616685738093364}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384125`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 2, {
              Complex[5.987437559449537, 0.616685738093364], 
              Complex[4.115506983628505, -0.46997493375384125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.880431975347878, -0.7412169946624548}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 1, {
              Complex[5.880431975347878, -0.7412169946624548], 
              Complex[4.088310451090251, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.986689286816269, 0.6234406236721283}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 2, {
              Complex[5.986689286816269, 0.6234406236721283], 
              Complex[4.114325239939221, -0.46152754767328275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.881800536903073, -0.7474106269426304}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0905044479565715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1024679173410115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 1, {
              Complex[5.881800536903073, -0.7474106269426304], 
              Complex[4.0905044479565715`, -2.1024679173410115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9859714122405725`, 0.6301108136973931}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9859714122405725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613645`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 2, {
              Complex[5.9859714122405725`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.45317756858613645`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8831374294478636`, -0.7535254579157133}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8831374294478636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 1, {
              Complex[5.8831374294478636`, -0.7535254579157133], 
              Complex[4.092654956897793, -2.109452014313656]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.985282459919064, 0.6366985832782693}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 2, {
              Complex[5.985282459919064, 0.6366985832782693], 
              Complex[4.112089864956078, -0.4449224541797797]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.884444051922338, -0.759563629082976}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.759563629082976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 1, {
              Complex[5.884444051922338, -0.759563629082976], 
              Complex[4.094763792064631, -2.1163496199598404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.984621049898126, 0.6432061141597182}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898126`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6432061141597182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 2, {
              Complex[5.984621049898126, 0.6432061141597182], 
              Complex[4.1110325004689345`, -0.4367597639013433]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.885721715038686, -0.7655271940238011}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 1, {
              Complex[5.885721715038686, -0.7655271940238011], 
              Complex[4.096832656761998, -2.1231630266947925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.983985890278379, 0.6496354995683529}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 2, {
              Complex[5.983985890278379, 0.6496354995683529], 
              Complex[4.110013053613791, -0.4286871538884813]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.886971648326271, -0.771418122959341}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.771418122959341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 1, {
              Complex[5.886971648326271, -0.771418122959341], 
              Complex[4.098863152113465, -2.1298944357144083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9833757701714365`, 0.6559887487872512}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9833757701714365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 2, {
              Complex[5.9833757701714365`, 0.6559887487872512], 
              Complex[4.109029930978957, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.888195006507387, -0.7772383070571713}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 1, {
              Complex[5.888195006507387, -0.7772383070571713], 
              Complex[4.100856784915978, -2.136545961543078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.982789553325939, 0.6622677914714886}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 2, {
              Complex[5.982789553325939, 0.6622677914714886], 
              Complex[4.108081633457669, -0.4128032540504377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.88939287527652, -0.7829895624892167}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7829895624892167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 1, {
              Complex[5.88939287527652, -0.7829895624892167], 
              Complex[4.102814974771636, -2.1431196363389544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.982226172350083, 0.6684744817167124}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.404987717906231`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 2, {
              Complex[5.982226172350083, 0.6684744817167124], 
              Complex[4.1071667491158, -0.404987717906231]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.890566276547081, -0.7886736342555827}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.890566276547081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 1, {
              Complex[5.890566276547081, -0.7886736342555827], 
              Complex[4.104739060573038, -2.1496174139664075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9816846234666565`, 0.674610601893371}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9816846234666565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.674610601893371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.397253760989882`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 2, {
              Complex[5.9816846234666565`, 0.674610601893371], 
              Complex[4.106283946706006, -0.397253760989882]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.891716173221935, -0.7942921997868309}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 1, {
              Complex[5.891716173221935, -0.7942921997868309], 
              Complex[4.106630306409572, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.981163961744248, 0.6806778662591644}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1054319697609305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 2, {
              Complex[5.981163961744248, 0.6806778662591644], 
              Complex[4.1054319697609305`, -0.38959945562569726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8928434735373925`, -0.7998468723371353}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8928434735373925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.162392724592142`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 1, {
              Complex[5.8928434735373925`, -0.7998468723371353], 
              Complex[4.108489906954297, -2.162392724592142]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.980663296755008, 0.6866779243621379}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 2, {
              Complex[5.980663296755008, 0.6866779243621379], 
              Complex[4.104609631205909, -0.3820229455501261]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.893949035024501, -0.8053392041803527}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 1, {
              Complex[5.893949035024501, -0.8053392041803527], 
              Complex[4.11031899238399, -2.1686738074506056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9801817886150515`, 0.6926123642464811}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9801817886150515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3745224424647919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 2, {
              Complex[5.9801817886150515`, 0.6926123642464811], 
              Complex[4.103815808438449, -0.3745224424647919]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8950336681265165`, -0.8107706896206484}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 1, {
              Complex[5.8950336681265165`, -0.8107706896206484], 
              Complex[4.112118632879193, -2.174886099543966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.979718644368705, 0.6984827154726524}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3670962227803742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 2, {
              Complex[5.979718644368705, 0.6984827154726524], 
              Complex[4.103049438827802, -0.3670962227803742]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.896098139506871, -0.8161427678288311}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 1, {
              Complex[5.896098139506871, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.979273114682199, 0.7042904519630283}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35974262454091743`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 2, {
              Complex[5.979273114682199, 0.7042904519630283], 
              Complex[4.102309515593154, -0.35974262454091743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.897143175078252, -0.8214568255150109}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 1, {
              Complex[5.897143175078252, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9788444908162806`, 0.7100369946836332}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9788444908162806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 2, {
              Complex[5.9788444908162806`, 0.7100369946836332], 
              Complex[4.101595084023626, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.898169462779893, -0.8267141994476594}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.978432101850545, 0.7157237141721114}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978432101850545`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 2, {
              Complex[5.978432101850545, 0.7157237141721114], 
              Complex[4.100905238007175, -0.34524693546904006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.899177655127287, -0.8319161788286036}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788286036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1190422707459655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.199078825420977`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 1, {
              Complex[5.899177655127287, -0.8319161788286036], 
              Complex[4.1190422707459655`, -2.199078825420977]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9780353121353675`, 0.7213519329214121}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9780353121353675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538322`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 2, {
              Complex[5.9780353121353675`, 0.7213519329214121], 
              Complex[4.100239116839224, -0.338101803538322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.900168371555868, -0.837064007532895}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.837064007532895`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2049702815786563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 1, {
              Complex[5.900168371555868, -0.837064007532895], 
              Complex[4.120708909659479, -2.2049702815786563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.97765351894983, 0.726922927628197}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97765351894983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.726922927628197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 2, {
              Complex[5.97765351894983, 0.726922927628197], 
              Complex[4.099595902284808, -0.3310232058121981]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.901142200577947, -0.8421588862221204}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12235147341849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 1, {
              Complex[5.901142200577947, -0.8421588862221204], 
              Complex[4.12235147341849, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.977286150346381, 0.7324379313144279}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977286150346381`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.324009747999723`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 2, {
              Complex[5.977286150346381, 0.7324379313144279], 
              Complex[4.098974815870868, -0.324009747999723]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9020997017701315`, -0.8472019743388878}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 1, {
              Complex[5.9020997017701315`, -0.8472019743388878], 
              Complex[4.123970710601055, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976932663165014, 0.7378981353300631}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387769`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 2, {
              Complex[5.976932663165014, 0.7378981353300631], 
              Complex[4.098375116387769, -0.31706008224295895`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.903041407606638, -0.852194391990135}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976592541201492, 0.7433046912443021}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 2, {
              Complex[5.976592541201492, 0.7433046912443021], 
              Complex[4.097796097581198, -0.31017290504537126`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.903967825152418, -0.857137221726082}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 1, {
              Complex[5.903967825152418, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976265293515785, 0.7486587126323615}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.30334695531178313`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 2, {
              Complex[5.976265293515785, 0.7486587126323615], 
              Complex[4.097237086017579, -0.30334695531178313`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.904879437628475, -0.8620315102214068}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 1, {
              Complex[5.904879437628475, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.97595045286828, 0.7539612767642827}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97595045286828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 2, {
              Complex[5.97595045286828, 0.7539612767642827], 
              Complex[4.096697439107836, -0.2965810124932358]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.905776705860622, -0.8668782698647188}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 1, {
              Complex[5.905776705860622, -0.8668782698647188], 
              Complex[4.130228184469744, -2.239105006921373]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975647574272541, 0.7592134262018867}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045617`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 2, {
              Complex[5.975647574272541, 0.7592134262018867], 
              Complex[4.096176543275776, -0.28987389483045617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.906660069621736, -0.8716784802620264}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.906660069621736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 1, {
              Complex[5.906660069621736, -0.8716784802620264], 
              Complex[4.131740864527742, -2.244603004332967]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9753562336545505`, 0.764416170309563}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9753562336545505`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900402`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 2, {
              Complex[5.9753562336545505`, 0.764416170309563], 
              Complex[4.095673812258773, -0.2832244576900402]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.907529948876621, -0.8764330896595153}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 1, {
              Complex[5.907529948876621, -0.8764330896595153], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975076026609326, 0.7695704866842139}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 2, {
              Complex[5.975076026609326, 0.7695704866842139], 
              Complex[4.095188685529604, -0.2766315919878305]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.908386744937715, -0.8811430162906049}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937715`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1347082671764905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 1, {
              Complex[5.908386744937715, -0.8811430162906049], 
              Complex[4.1347082671764905`, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974806567246683, 0.7746773225093267}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2700942226942855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 2, {
              Complex[5.974806567246683, 0.7746773225093267], 
              Complex[4.094720626829337, -0.2700942226942855]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.909230841539051, -0.8858091496519157}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 1, {
              Complex[5.909230841539051, -0.8858091496519157], 
              Complex[4.136164053701613, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974547487118723, 0.7797375958378123}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698485`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 2, {
              Complex[5.974547487118723, 0.7797375958378123], 
              Complex[4.094269122802149, -0.26361130741698485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.910062605835208, -0.8904323517124777}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266088855704737`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 1, {
              Complex[5.910062605835208, -0.8904323517124777], 
              Complex[4.137601902702118, -2.266088855704737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9742984342223115`, 0.7847521968079438}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9742984342223115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 2, {
              Complex[5.9742984342223115`, 0.7847521968079438], 
              Complex[4.093833681723804, -0.25718183505570613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.910882389331387, -0.8950134580602265}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 1, {
              Complex[5.910882389331387, -0.8950134580602265], 
              Complex[4.139022292544099, -2.271338727751554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974059072070431, 0.7897219887964374}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070431`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 2, {
              Complex[5.974059072070431, 0.7897219887964374], 
              Complex[4.093413832316265, -0.2508048245258127]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.911690528750101, -0.8995532789895435}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140425682224579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 1, {
              Complex[5.911690528750101, -0.8995532789895435], 
              Complex[4.140425682224579, -2.2765418365114742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973829078826883, 0.7946478095124517}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.912487346839559, -0.9040526005333869}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 1, {
              Complex[5.912487346839559, -0.9040526005333869], 
              Complex[4.141812512404396, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973608146499301, 0.7995304720360316}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 2, {
              Complex[5.973608146499301, 0.7995304720360316], 
              Complex[4.092619119069028, -0.2382044074863151]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.913273153128292, -0.9085121854432783}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1431832063736325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2868112886653567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 1, {
              Complex[5.913273153128292, -0.9085121854432783], 
              Complex[4.1431832063736325`, -2.2868112886653567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9733959801858845`, 0.8043707658042932}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2319791782739564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.2319791782739564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.914048244630215, -0.9129327741202399}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 1, {
              Complex[5.914048244630215, -0.9129327741202399], 
              Complex[4.1445381709548, -2.291879330010544]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973192297371706, 0.8091694575484236}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09188158151152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 2, {
              Complex[5.973192297371706, 0.8091694575484236], 
              Complex[4.09188158151152, -0.2258027633518866]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.914812906503919, -0.9173150854995428}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 1, {
              Complex[5.914812906503919, -0.9173150854995428], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972996827270754, 0.8139272921843683}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2196743146888657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 2, {
              Complex[5.972996827270754, 0.8139272921843683], 
              Complex[4.091533263417343, -0.2196743146888657]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.915567412669662, -0.9216598178919512}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.915567412669662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.14720246192557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 1, {
              Complex[5.915567412669662, -0.9216598178919512], 
              Complex[4.14720246192557, -2.3018861057371836`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972809310210266, 0.8186449936599097}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699708`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568593, -0.21359300783699708`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.916312026387238, -0.9259676497839727}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3068263961017066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 1, {
              Complex[5.916312026387238, -0.9259676497839727], 
              Complex[4.148512526970577, -2.3068263961017066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9726294970541804`, 0.8233232657606}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.207558041034483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 2, {
              Complex[5.9726294970541804`, 0.8233232657606], 
              Complex[4.090875680564113, -0.207558041034483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9170470007976235`, -0.9302392405994732}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9170470007976235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 1, {
              Complex[5.9170470007976235`, -0.9302392405994732], 
              Complex[4.149808341378723, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972457148662774, 0.8279627928769887}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 2, {
              Complex[5.972457148662774, 0.8279627928769887], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.91777257943106, -0.9344752314248258}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.91777257943106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 1, {
              Complex[5.91777257943106, -0.9344752314248258], 
              Complex[4.151090241310996, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.97229203538588, 0.8325642407352354}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272945`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 2, {
              Complex[5.97229203538588, 0.8325642407352354], 
              Complex[4.090267865626448, -0.19562402887272945`]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{4.976967927486166, 0.006887727487396987}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 1, {
              Complex[4.976967927486166, 0.006887727487396987], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.398301539299035, -0.013243170301699064`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013243170301699064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 2, {
              Complex[7.398301539299035, -0.013243170301699064`], 
              Complex[8.800016052466027, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.020988084142069, 0.007042959985368856}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 1, {
              Complex[5.020988084142069, 0.007042959985368856], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.352914113679205, -0.013509876715323912`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 2, {
              Complex[7.352914113679205, -0.013509876715323912`], 
              Complex[8.75509227462806, -1.1963255671672883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.057395324277087, 0.007197843246654417}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.057395324277087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 1, {
              Complex[5.057395324277087, 0.007197843246654417], 
              Complex[6.557943371421667, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.315449803449272, -0.013751044852511824`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013751044852511824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 2, {
              Complex[7.315449803449272, -0.013751044852511824`], 
              Complex[8.718101741665087, -1.1964748219538666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.089412494295964, 0.007354951961005435}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961005435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 1, {
              Complex[5.089412494295964, 0.007354951961005435], 
              Complex[6.589330078860691, -1.1628888789503165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.282554763488937, -0.013979869598457893`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 2, {
              Complex[7.282554763488937, -0.013979869598457893`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.118506250669166, 0.007515591774090766}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 1, {
              Complex[5.118506250669166, 0.007515591774090766], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.252703058118816, -0.014202465960728994`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960728994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.65633113389032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 2, {
              Complex[7.252703058118816, -0.014202465960728994`], 
              Complex[8.65633113389032, -1.1967364397628124`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.1454918259261815`, 0.007680628289981348}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1454918259261815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007680628289981348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 1, {
              Complex[5.1454918259261815`, 0.007680628289981348], 
              Complex[6.644124842294817, -1.1627145990756094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.225046713694153, -0.01442235766034948}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000406`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 2, {
              Complex[7.225046713694153, -0.01442235766034948], 
              Complex[8.629176867782464, -1.1968585230000406`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.170878634413056, 0.007850743160533852}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533852`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 1, {
              Complex[5.170878634413056, 0.007850743160533852], 
              Complex[6.668857252414806, -1.1626225207983636`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.199056007873822, -0.014641876121436205`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436205`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 2, {
              Complex[7.199056007873822, -0.014641876121436205`], 
              Complex[8.603697599379135, -1.1969782988821365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.19501091123548, 0.008026538528972053}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.69232677922716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 1, {
              Complex[5.19501091123548, 0.008026538528972053], 
              Complex[6.69232677922716, -1.1625263894330444`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.174373102447972, -0.014862729232274703`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274703`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 2, {
              Complex[7.174373102447972, -0.014862729232274703`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.2181348551047995`, 0.008208588338763131}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338763131`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 1, {
              Complex[5.2181348551047995`, 0.008208588338763131], 
              Complex[6.714779367617378, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.150742171455597, -0.015086273942248022`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.150742171455597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248022`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 2, {
              Complex[7.150742171455597, -0.015086273942248022`], 
              Complex[8.556435217312078, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.240434389619401, 0.008397467701837667}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701837667`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 1, {
              Complex[5.240434389619401, 0.008397467701837667], 
              Complex[6.736398653893476, -1.1623199234705235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.127972189674163, -0.015313663264596052`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596052`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 2, {
              Complex[7.127972189674163, -0.015313663264596052`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.262051805853028, 0.00859377229372981}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00859377229372981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 1, {
              Complex[5.262051805853028, 0.00859377229372981], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{7.1059154551031405`, -0.015545933419028891`}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028891`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 2, {
              Complex[7.1059154551031405`, -0.015545933419028891`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.283100441464033, 0.008798133065178996}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178996`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7776762194252065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 1, {
              Complex[5.283100441464033, 0.008798133065178996], 
              Complex[6.7776762194252065`, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.08445439867063, -0.015784060035230012`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.08445439867063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230012`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 2, {
              Complex[7.08445439867063, -0.015784060035230012`], 
              Complex[8.491799285559546, -1.1975915689762855`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.303672866164795, 0.009011228909084911}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 1, {
              Complex[5.303672866164795, 0.009011228909084911], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.063493070122277, -0.016028997503587324`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587324`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 2, {
              Complex[7.063493070122277, -0.016028997503587324`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.323846388854408, 0.009233798770935135}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935135`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 1, {
              Complex[5.323846388854408, 0.009233798770935135], 
              Complex[6.816993839756788, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.042951411025012, -0.016281708942806058`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942806058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 2, {
              Complex[7.042951411025012, -0.016281708942806058`], 
              Complex[8.451450795228002, -1.1978624312936876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.343686896016404, 0.009466654168547516}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547516`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 1, {
              Complex[5.343686896016404, 0.009466654168547516], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.022761264330783, -0.016543191071888962`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016543191071888962`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 2, {
              Complex[7.022761264330783, -0.016543191071888962`], 
              Complex[8.431855025955326, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.363251612071681, 0.00971069285821086}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00971069285821086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 1, {
              Complex[5.363251612071681, 0.00971069285821086], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.002863505905771, -0.016814496662831153`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831153`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 2, {
              Complex[7.002863505905771, -0.016814496662831153`], 
              Complex[8.412563676597298, -1.1981586784333542`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.382591142510597, 0.009966914310096189}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 1, {
              Complex[5.382591142510597, 0.009966914310096189], 
              Complex[6.873513478358426, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.983205922649462, -0.017096756417673824`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 2, {
              Complex[6.983205922649462, -0.017096756417673824`], 
              Complex[8.39352505422987, -1.1983187142405296`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.401751028707841, 0.0102364376771995}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102364376771995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 1, {
              Complex[5.401751028707841, 0.0102364376771995], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.963741599119121, -0.017391201699304287`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304287`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 2, {
              Complex[6.963741599119121, -0.017391201699304287`], 
              Complex[8.374692817528386, -1.1984881127881413`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.4207729647332625`, 0.010520523036427957`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 1, {
              Complex[5.4207729647332625`, 0.010520523036427957`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.944427656372563, -0.017699189379580503`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017699189379580503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 2, {
              Complex[6.944427656372563, -0.017699189379580503`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.439695778207934, 0.010820596844492478`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492478`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 1, {
              Complex[5.439695778207934, 0.010820596844492478`], 
              Complex[6.9282802700841595`, -1.1608460296816645`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.925224236986867, -0.018022230071644347`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644347`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 2, {
              Complex[6.925224236986867, -0.018022230071644347`], 
              Complex[8.337481607819116, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.458556246931597, 0.011138282794836918`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 1, {
              Complex[5.458556246931597, 0.011138282794836918`], 
              Complex[6.946333169123368, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.906093661793765, -0.018362021154623754`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018362021154623754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 2, {
              Complex[6.906093661793765, -0.018362021154623754`], 
              Complex[8.319026572634915, -1.1990651369525753`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.47738980371477, 0.011475439606775249`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775249`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 1, {
              Complex[5.47738980371477, 0.011475439606775249`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.886999703988066, -0.018720486277070774`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 2, {
              Complex[6.886999703988066, -0.018720486277070774`], 
              Complex[8.30062424755183, -1.1992854341178676`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.49623116962678, 0.011834207760463417`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.49623116962678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 1, {
              Complex[5.49623116962678, 0.011834207760463417`], 
              Complex[6.982345361327388, -1.160172170534845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{6.8679069390373595`, -0.019099823463292608`}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8679069390373595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292608`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 2, {
              Complex[6.8679069390373595`, -0.019099823463292608`], 
              Complex[8.282240162776432, -1.1995227410964955`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.515114948423251, 0.012217067867222368`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222368`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 1, {
              Complex[5.515114948423251, 0.012217067867222368`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.848780136643827, -0.019502564592186727`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848780136643827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.26384015300309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 2, {
              Complex[6.848780136643827, -0.019502564592186727`], 
              Complex[8.26384015300309, -1.1997792920739638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.534076210934987, 0.01262691431947491}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.534076210934987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01262691431947491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 1, {
              Complex[5.534076210934987, 0.01262691431947491], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.829583665251547, -0.019931649951741088`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741088`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 2, {
              Complex[6.829583665251547, -0.019931649951741088`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.553151097008939, 0.013067149229433932`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 1, {
              Complex[5.553151097008939, 0.013067149229433932`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.810280880968053, -0.020390522922278664`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 2, {
              Complex[6.810280880968053, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.2003609757255187`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.57237746397503, 0.013541803645186447`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186447`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 1, {
              Complex[5.57237746397503, 0.013541803645186447`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.790833471518203, -0.020883251810279772`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 2, {
              Complex[6.790833471518203, -0.020883251810279772`], 
              Complex[8.208195234091123, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.59179561475532, 0.014055695951277586`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.59179561475532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 1, {
              Complex[5.59179561475532, 0.014055695951277586`], 
              Complex[7.073421269042285, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.77120072180202, -0.021414688765245098`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.77120072180202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.189375273236829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 2, {
              Complex[6.77120072180202, -0.021414688765245098`], 
              Complex[8.189375273236829, -1.2010573992945917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.611449146258794, 0.014614641743299683`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 1, {
              Complex[5.611449146258794, 0.014614641743299683`], 
              Complex[7.092108121115127, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.751338660172414, -0.021990680088691778`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 2, {
              Complex[6.751338660172414, -0.021990680088691778`], 
              Complex[8.170351853484787, -1.2014600752208564`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.631385970822487, 0.01522573618198173}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 1, {
              Complex[5.631385970822487, 0.01522573618198173], 
              Complex[7.111050585905176, -1.157734788294595]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.731199032484281, -0.02261834895605755}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671372`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 2, {
              Complex[6.731199032484281, -0.02261834895605755], 
              Complex[8.151078988162066, -1.2019071795671372`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.651659582251509, 0.015897740359760885`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251509`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015897740359760885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.130299515097566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 1, {
              Complex[5.651659582251509, 0.015897740359760885`], 
              Complex[7.130299515097566, -1.1572252835375136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.710728032214631, -0.02330648209651109}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.710728032214631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 2, {
              Complex[6.710728032214631, -0.02330648209651109], 
              Complex[8.13150550216652, -1.2024066038908514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.6723306669868805`, 0.016641620135819515`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 1, {
              Complex[5.6723306669868805`, 0.016641620135819515`], 
              Complex[7.149912504017515, -1.1566530214405542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.689864686007545, -0.024066068896217648`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217648`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 2, {
              Complex[6.689864686007545, -0.024066068896217648`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.693469206036438, 0.017471313877762278`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156005412968246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 1, {
              Complex[5.693469206036438, 0.017471313877762278`], 
              Complex[7.169955880282914, -1.156005412968246]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.668538748914902, -0.024911069370829316`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370829316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.091216389791244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 2, {
              Complex[6.668538748914902, -0.024911069370829316`], 
              Complex[8.091216389791244, -1.2036047239664343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.715157284805062, 0.01840485331132215}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805062`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 1, {
              Complex[5.715157284805062, 0.01840485331132215], 
              Complex[7.190507361138087, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.646667892120967, -0.02585953521479532}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 2, {
              Complex[6.646667892120967, -0.02585953521479532], 
              Complex[8.070356192382524, -1.2043323940004818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.737492944039842, 0.01946604620382397}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01946604620382397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 1, {
              Complex[5.737492944039842, 0.01946604620382397], 
              Complex[7.211659694982883, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.624153849873984, -0.02693529265819092}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819092`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 2, {
              Complex[6.624153849873984, -0.02693529265819092], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.760595598959389, 0.02068708549653934}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.760595598959389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02068708549653934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 1, {
              Complex[5.760595598959389, 0.02068708549653934], 
              Complex[7.233525786397049, -1.153418203138091]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.60087699850535, -0.028170551750252907`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60087699850535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252907`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 2, {
              Complex[6.60087699850535, -0.028170551750252907`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.784613887852916, 0.022112751073541263`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784613887852916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073541263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053025`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 1, {
              Complex[5.784613887852916, 0.022112751073541263`], 
              Complex[7.256246121108599, -1.1522392586053025`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.576688506209679, -0.029610108260631308`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.576688506209679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 2, {
              Complex[6.576688506209679, -0.029610108260631308`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.809737407862617, 0.02380748722011311}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.150817525269937`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 1, {
              Complex[5.809737407862617, 0.02380748722011311], 
              Complex[7.279999873987635, -1.150817525269937]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.551398595838172, -0.03131842125415468}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.551398595838172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.97967458803322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 2, {
              Complex[6.551398595838172, -0.03131842125415468], 
              Complex[7.97967458803322, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.8362148977187704`, 0.025867986584034483`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8362148977187704`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025867986584034483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 1, {
              Complex[5.8362148977187704`, 0.025867986584034483`], 
              Complex[7.3050221318566, -1.1490639772295197`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5247583609077076`, -0.03339219715471037}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 2, {
              Complex[6.5247583609077076`, -0.03339219715471037], 
              Complex[7.954365525461625, -1.2104697460661467`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.864383522178553, 0.028447097632705032`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632705032`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 1, {
              Complex[5.864383522178553, 0.028447097632705032`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.496430480050892, -0.03598429729320674}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 2, {
              Complex[6.496430480050892, -0.03598429729320674], 
              Complex[7.927473033284, -1.2126821236194967`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.894717893374837, 0.03180315785237445}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.143898450195406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 1, {
              Complex[5.894717893374837, 0.03180315785237445], 
              Complex[7.360277468735853, -1.143898450195406]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.465940194681213, -0.03935307118737358}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 2, {
              Complex[6.465940194681213, -0.03935307118737358], 
              Complex[7.898547952604838, -1.2156065553823725`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.927914095850698, 0.03641303093549137}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093549137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 1, {
              Complex[5.927914095850698, 0.03641303093549137], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.432591283080758, -0.04397539380088787}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 2, {
              Complex[6.432591283080758, -0.04397539380088787], 
              Complex[7.866930860848724, -1.2196865044147172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.965024718764882, 0.04326772266645264}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.965024718764882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.42665483177688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 1, {
              Complex[5.965024718764882, 0.04326772266645264], 
              Complex[7.42665483177688, -1.1336280195460158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.395331027411175, -0.050842281493196174`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.050842281493196174`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.831622543975559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 2, {
              Complex[6.395331027411175, -0.050842281493196174`], 
              Complex[7.831622543975559, -1.2258468389686634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.007534506136696, 0.05476808187732237}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 1, {
              Complex[6.007534506136696, 0.05476808187732237], 
              Complex[7.466802670715169, -1.123122290976753]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.352674562767397, -0.06235459303258747}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 2, {
              Complex[6.352674562767397, -0.06235459303258747], 
              Complex[7.7912056711960345`, -1.2363369885208018`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.055705576569382, 0.07734359441247657}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 1, {
              Complex[6.055705576569382, 0.07734359441247657], 
              Complex[7.512359287571743, -1.1022322984450355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.304359656824844, -0.08494182361233364}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.257211079947235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 2, {
              Complex[6.304359656824844, -0.08494182361233364], 
              Complex[7.745383184720152, -1.257211079947235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.0979727560579535`, 0.11902724764148766`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0979727560579535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11902724764148766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 1, {
              Complex[6.0979727560579535`, 0.11902724764148766`], 
              Complex[7.552491023448565, -1.0633012820313095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.261951376465346, -0.12663696940988806`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 2, {
              Complex[6.261951376465346, -0.12663696940988806`], 
              Complex[7.704988630788347, -1.2961258835777565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.120724694194673, 0.16611165996513286`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996513286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 1, {
              Complex[6.120724694194673, 0.16611165996513286`], 
              Complex[7.574268139734729, -1.0191412329171001`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.239060971061035, -0.17373265713468272`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 2, {
              Complex[6.239060971061035, -0.17373265713468272`], 
              Complex[7.682951641637805, -1.3402694180832757`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.132202365530887, 0.20695392178184907`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 1, {
              Complex[6.132202365530887, 0.20695392178184907`], 
              Complex[7.58536879774568, -0.9807872587669512]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2274473706510705`, -0.214585985032377}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2274473706510705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.214585985032377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 2, {
              Complex[6.2274473706510705`, -0.214585985032377], 
              Complex[7.671593955391059, -1.3786065851349265`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.138977875500194, 0.24191392575349455`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 1, {
              Complex[6.138977875500194, 0.24191392575349455`], 
              Complex[7.591990895909476, -0.9479498476029725]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.22053837960052, -0.24955685318475537`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 2, {
              Complex[6.22053837960052, -0.24955685318475537`], 
              Complex[7.664717578441819, -1.4114269055666697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.143492571886664, 0.2725610929770674}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2725610929770674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 1, {
              Complex[6.143492571886664, 0.2725610929770674], 
              Complex[7.596448189109472, -0.9191675975214387]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.215892564752815, -0.2802146897125679}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125679`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.66000866572372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 2, {
              Complex[6.215892564752815, -0.2802146897125679], 
              Complex[7.66000866572372, -1.4401917896926066`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1467493959161805`, 0.30000093008350653`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1467493959161805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30000093008350653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.89340537281411`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 1, {
              Complex[6.1467493959161805`, 0.30000093008350653`], 
              Complex[7.599694877117055, -0.89340537281411]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.212506903993476, -0.307665007902555}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307665007902555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 2, {
              Complex[6.212506903993476, -0.307665007902555], 
              Complex[7.656512931924067, -1.4659363812164754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.149229270200796, 0.32496389242763946`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 1, {
              Complex[6.149229270200796, 0.32496389242763946`], 
              Complex[7.602190099828044, -0.8699776507064151]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2099003979914995`, -0.33263826942312247`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2099003979914995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33263826942312247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 2, {
              Complex[6.2099003979914995`, -0.33263826942312247`], 
              Complex[7.653771155925205, -1.4893462105216064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.151192034362996, 0.34794816918876065`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271418`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 1, {
              Complex[6.151192034362996, 0.34794816918876065`], 
              Complex[7.604182742222913, -0.848416245271418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2078131342882505`, -0.35563266944840694`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2078131342882505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563266944840694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 2, {
              Complex[6.2078131342882505`, -0.35563266944840694`], 
              Complex[7.6515343755500105`, -1.5108894707826876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.152791090696166, 0.3693076970042954}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 1, {
              Complex[6.152791090696166, 0.3693076970042954], 
              Complex[7.605820205415675, -0.8283882117511522]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.206091641374743, -0.377002150313453}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.206091641374743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.377002150313453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 2, {
              Complex[6.206091641374743, -0.377002150313453], 
              Complex[7.649655116243798, -1.5308991136680348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.154123300626686, 0.3893033507690846}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 1, {
              Complex[6.154123300626686, 0.3893033507690846], 
              Complex[7.607195850080814, -0.8096479618228548]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.204638991989324, -0.39700759233314253`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549620734094958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 2, {
              Complex[6.204638991989324, -0.39700759233314253`], 
              Complex[7.648039947400696, -1.549620734094958]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15525311268908, 0.40813349152982514`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15525311268908`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 1, {
              Complex[6.15525311268908, 0.40813349152982514`], 
              Complex[7.608371984798496, -0.7920086413709154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.203390674922197, -0.41584736171471215`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777163`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 2, {
              Complex[6.203390674922197, -0.41584736171471215`], 
              Complex[7.646626493792042, -1.5672411924777163`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.156225240135477, 0.4259529280523636}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 1, {
              Complex[6.156225240135477, 0.4259529280523636], 
              Complex[7.60939196819019, -0.7753243442615722]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.202301917203499, -0.4336762721416331}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 2, {
              Complex[6.202301917203499, -0.4336762721416331], 
              Complex[7.6453713332226165`, -1.5839064009711152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.157071780468366, 0.44288515307919935`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157071780468366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 1, {
              Complex[6.157071780468366, 0.44288515307919935`], 
              Complex[7.610287017953022, -0.7594786249471305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.201340564384263, -0.4506178210463806}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 2, {
              Complex[6.201340564384263, -0.4506178210463806], 
              Complex[7.644243187304668, -1.5997328108831592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.157816436754414, 0.45903052180506415`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157816436754414`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 1, {
              Complex[6.157816436754414, 0.45903052180506415`], 
              Complex[7.611080255416451, -0.7443768154213578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2004828590509335`, -0.46677236810008305`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 2, {
              Complex[6.2004828590509335`, -0.46677236810008305`], 
              Complex[7.6432188767245925`, -1.6148150957352272`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15847713590932, 0.4744718898931343}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669327, -0.7299407258319837]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199710822382092, -0.48222277324174173`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 2, {
              Complex[6.199710822382092, -0.48222277324174173`], 
              Complex[7.642280807952738, -1.6292314506639924`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1590677155468105`, 0.48927860682773966`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682773966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 1, {
              Complex[6.1590677155468105`, 0.48927860682773966`], 
              Complex[7.612427484506159, -0.7161048892141159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199010567153121, -0.4970383900429073}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4970383900429073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 2, {
              Complex[6.199010567153121, -0.4970383900429073], 
              Complex[7.6414153511463985`, -1.6430473477012988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.159599046539054, 0.5035094122855172}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539054`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825418`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 1, {
              Complex[6.159599046539054, 0.5035094122855172], 
              Complex[7.613005749670385, -0.7028138366825418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.198371175040328, -0.5112779620899692}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.656318260594247`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 2, {
              Complex[6.198371175040328, -0.5112779620899692], 
              Complex[7.640611758766885, -1.656318260594247]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160079801248163, 0.5172145811965814}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894211`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 1, {
              Complex[6.160079801248163, 0.5172145811965814], 
              Complex[7.613532572082193, -0.6900200786894211]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197783928263984, -0.5249917680556042}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160516992248921, 0.5304375419992586}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576769`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 1, {
              Complex[6.160516992248921, 0.5304375419992586], 
              Complex[7.6140148915107115`, -0.6776825815576769]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197241770749234, -0.5382232399630632}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 2, {
              Complex[6.197241770749234, -0.5382232399630632], 
              Complex[7.639157361075561, -1.681408654757819]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160916358296958, 0.5432161176861706}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61445840324093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699652`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 1, {
              Complex[6.160916358296958, 0.5432161176861706], 
              Complex[7.61445840324093, -0.6657655987699652]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1967389220498434`, -0.5510102042411112}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204681`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 2, {
              Complex[6.1967389220498434`, -0.5510102042411112], 
              Complex[7.638493829265324, -1.6933049250204681`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161282646160605, 0.5555834916479542}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 1, {
              Complex[6.161282646160605, 0.5555834916479542], 
              Complex[7.6148678313818445`, -0.6542377611605088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.196270595415879, -0.5633858475760002}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.196270595415879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 2, {
              Complex[6.196270595415879, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161619819931483, 0.5675689693259762}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161619819931483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 1, {
              Complex[6.161619819931483, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195832788389601, -0.5753794785718531}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 2, {
              Complex[6.195832788389601, -0.5753794785718531], 
              Complex[7.637270060814722, -1.7159571961426485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161931218858729, 0.5791985860418384}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 1, {
              Complex[6.161931218858729, 0.5791985860418384], 
              Complex[7.615599647619971, -0.6322417704324756]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1954221248841135`, -0.5870171355873219}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873219`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 2, {
              Complex[6.1954221248841135`, -0.5870171355873219], 
              Complex[7.636702444963452, -1.7267655369464134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162219678012526, 0.5904955973399486}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 1, {
              Complex[6.162219678012526, 0.5904955973399486], 
              Complex[7.615928222964841, -0.6217269966329017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195035734438572, -0.598322077084824}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.598322077084824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 2, {
              Complex[6.195035734438572, -0.598322077084824], 
              Complex[7.636160330682662, -1.7372588918245429`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1624876216872115`, 0.6014808784641332}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1624876216872115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 1, {
              Complex[6.1624876216872115`, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.194671158739191, -0.6093151811133901}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133901`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63564124145883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 2, {
              Complex[6.194671158739191, -0.6093151811133901], 
              Complex[7.63564124145883, -1.7474570144780963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162737136528052, 0.6121732527479825}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 1, {
              Complex[6.162737136528052, 0.6121732527479825], 
              Complex[7.616522978484024, -0.6015648318155971]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.19432627842157, -0.6200152737048318}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19432627842157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 2, {
              Complex[6.19432627842157, -0.6200152737048318], 
              Complex[7.635143036145728, -1.7573777202744645`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162970029380979, 0.6225897638061423}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038926`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 1, {
              Complex[6.162970029380979, 0.6225897638061423], 
              Complex[7.616793092860657, -0.5918834984038926]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.19399925515462, -0.6304394010704694}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19399925515462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 2, {
              Complex[6.19399925515462, -0.6304394010704694], 
              Complex[7.63466385223734, -1.7670371430158245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163187873495399, 0.6327459028649589}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163187873495399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 1, {
              Complex[6.163187873495399, 0.6327459028649589], 
              Complex[7.617047237536005, -0.5824486239818051]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193688485375648, -0.6406030569368893}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163392045750656, 0.642655799962885}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 1, {
              Complex[6.163392045750656, 0.642655799962885], 
              Complex[7.617286813480896, -0.5732468315559044]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193392563005681, -0.6505203737511226}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 2, {
              Complex[6.193392563005681, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1635837568947665`, 0.6523323858111203}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1635837568947665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6523323858111203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 1, {
              Complex[6.1635837568947665`, 0.6523323858111203], 
              Complex[7.617513055986499, -0.5642658778811124]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193110249156134, -0.6602042845457751}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 2, {
              Complex[6.193110249156134, -0.6602042845457751], 
              Complex[7.633325089631601, -1.7945880998355055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1637640762927965`, 0.6617875296457955}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1637640762927965`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6617875296457955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226202`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 1, {
              Complex[6.1637640762927965`, 0.6617875296457955], 
              Complex[7.617727059060542, -0.5554945233226202]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192840447329172, -0.6696666607954203}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63290752119261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 2, {
              Complex[6.192840447329172, -0.6696666607954203], 
              Complex[7.63290752119261, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163933952324089, 0.6710321572939456}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163933952324089`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.546922420377038`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 1, {
              Complex[6.163933952324089, 0.6710321572939456], 
              Complex[7.617929795566583, -0.546922420377038]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192582182972332, -0.6789184304865283}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 2, {
              Complex[6.192582182972332, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164094229303429, 0.6800763528244183}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 1, {
              Complex[6.164094229303429, 0.6800763528244183], 
              Complex[7.618122133957997, -0.5385400176762603]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192334586512062, -0.6879696797720991}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 2, {
              Complex[6.192334586512062, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164245661604394, 0.6889294464957758}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 1, {
              Complex[6.164245661604394, 0.6889294464957758], 
              Complex[7.6183048522674195`, -0.5303384769181545]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192096879187744, -0.6968297409230598}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 2, {
              Complex[6.192096879187744, -0.6968297409230598], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164388925515003, 0.6976000911985042}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6976000911985042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 1, {
              Complex[6.164388925515003, 0.6976000911985042], 
              Complex[7.618478649868707, -0.5223096006529584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191868361155921, -0.7055072687737811}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 2, {
              Complex[6.191868361155921, -0.7055072687737811], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164524629243228, 0.7060963291837467}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 1, {
              Complex[6.164524629243228, 0.7060963291837467], 
              Complex[7.618644157419197, -0.5144457692358491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1916484014469475`, -0.7140103074539125}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1916484014469475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7140103074539125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 2, {
              Complex[6.1916484014469475`, -0.7140103074539125], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164653321403731, 0.714425650549425}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.714425650549425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 1, {
              Complex[6.164653321403731, 0.714425650549425], 
              Complex[7.618801945306149, -0.5067398855588762]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191436429442565, -0.7223463488774432}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6306376580477195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 2, {
              Complex[6.191436429442565, -0.7223463488774432], 
              Complex[7.6306376580477195`, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164775498250606, 0.7225950446980729}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618952530856562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171731`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 1, {
              Complex[6.164775498250606, 0.7225950446980729], 
              Complex[7.618952530856562, -0.4991853264171731]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191231927609488, -0.7305223842033103}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 2, {
              Complex[6.191231927609488, -0.7305223842033103], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164891609869035, 0.7306110457745109}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49177589955865814`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 1, {
              Complex[6.164891609869035, 0.7306110457745109], 
              Complex[7.6190963845189446`, -0.49177589955865814`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1910344252759195`, -0.738544949275635}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165002065498246, 0.7384797729243929}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 1, {
              Complex[6.165002065498246, 0.7384797729243929], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190843493278558, -0.746420164884856}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.746420164884856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 2, {
              Complex[6.190843493278558, -0.746420164884856], 
              Complex[7.629624038754352, -1.8741167149612878`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165107238125894, 0.7462069660795168}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165107238125894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4773696043103947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 1, {
              Complex[6.165107238125894, 0.7462069660795168], 
              Complex[7.6193655747968485`, -0.4773696043103947]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190658739339741, -0.7541537725552647}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 2, {
              Complex[6.190658739339741, -0.7541537725552647], 
              Complex[7.629300720152119, -1.881229052055075]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165207468468806, 0.7537980178639987}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 1, {
              Complex[6.165207468468806, 0.7537980178639987], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190479804059834, -0.7617511664534368}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 2, {
              Complex[6.190479804059834, -0.7617511664534368], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1653030684343095`, 0.7612580021246107}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1653030684343095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7612580021246107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 1, {
              Complex[6.1653030684343095`, 0.7612580021246107], 
              Complex[7.619612527276207, -0.4634787357769745]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1903063574303445`, -0.7692174219206874}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165394324140473, 0.7685916995129606}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 1, {
              Complex[6.165394324140473, 0.7685916995129606], 
              Complex[7.619728472689179, -0.4567147272275413]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190138095789615, -0.7765573210571979}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 2, {
              Complex[6.190138095789615, -0.7765573210571979], 
              Complex[7.62836908977242, -1.9018116136847993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1654814985597985`, 0.7758036204843003}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204843003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268488906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 1, {
              Complex[6.1654814985597985`, 0.7758036204843003], 
              Complex[7.619839777837857, -0.45006588268488906`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18997473915616, -0.7837753757227324}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 2, {
              Complex[6.18997473915616, -0.7837753757227324], 
              Complex[7.628070244122034, -1.9084361186447754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1655648338407385`, 0.7828980260257032}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 1, {
              Complex[6.1655648338407385`, 0.7828980260257032], 
              Complex[7.619946700555888, -0.4435281626164994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189816028885474, -0.7908758482666076}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304071`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 2, {
              Complex[6.189816028885474, -0.7908758482666076], 
              Complex[7.627776768560513, -1.9149493850304071`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165644553352175, 0.7898789463823143}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352175`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823143`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 1, {
              Complex[6.165644553352175, 0.7898789463823143], 
              Complex[7.620049479307305, -0.43709774610477986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189661725604909, -0.7978627702556053}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165720863489107, 0.7967501980135656}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004998`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 1, {
              Complex[6.165720863489107, 0.7967501980135656], 
              Complex[7.620148335014862, -0.4307710148004998]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1895116073884004`, -0.8047399594318435}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1895116073884004`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 2, {
              Complex[6.1895116073884004`, -0.8047399594318435], 
              Complex[7.627204921081203, -1.9276572903056561`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165793955271712, 0.8035153989801238}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966915`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 1, {
              Complex[6.165793955271712, 0.8035153989801238], 
              Complex[7.620243472681647, -0.42454453835966915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189365468138804, -0.8115110351012249}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 2, {
              Complex[6.189365468138804, -0.8115110351012249], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1658640057650915`, 0.8101779829358521}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925664`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 1, {
              Complex[6.1658640057650915`, 0.8101779829358521], 
              Complex[7.62033508283309, -0.41841506119925664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189223116150438, -0.8181794321268682}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 2, {
              Complex[6.189223116150438, -0.8181794321268682], 
              Complex[7.626651704878013, -1.9399635658707666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165931179342954, 0.8167412118766464}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 1, {
              Complex[6.165931179342954, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283196]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18908437282858, -0.8247484136793252}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 2, {
              Complex[6.18908437282858, -0.8247484136793252], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165995628815021, 0.8232081877787772}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 1, {
              Complex[6.165995628815021, 0.8232081877787772], 
              Complex[7.620508417879312, -0.4064348848292457]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188949071546019, -0.8312210828762444}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 2, {
              Complex[6.188949071546019, -0.8312210828762444], 
              Complex[7.626115517858932, -1.9518936417752972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166057496435186, 0.8295818632429406}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 1, {
              Complex[6.166057496435186, 0.8295818632429406], 
              Complex[7.620590462338552, -0.40057844477933857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188817056619654, -0.8376003934276777}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 2, {
              Complex[6.188817056619654, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1661169148049755`, 0.8358650512460934}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 1, {
              Complex[6.1661169148049755`, 0.8358650512460934], 
              Complex[7.620669620363362, -0.3948075030162883]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188688182392475, -0.8438891593891126}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 2, {
              Complex[6.188688182392475, -0.8438891593891126], 
              Complex[7.625594958504515, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166174007684912, 0.8420604340909559}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260576`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875824, -0.38911951616260576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188562312408358, -0.8500900641121137}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508243`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 2, {
              Complex[6.188562312408358, -0.8500900641121137], 
              Complex[7.625340148077106, -1.9691330946508243`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16622889072462, 0.848170571632535}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16622889072462`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.848170571632535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 1, {
              Complex[6.16622889072462, 0.848170571632535], 
              Complex[7.620819808285303, -0.38351205693401563`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1884393186687205`, -0.856205668471937}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 2, {
              Complex[6.1884393186687205`, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166281672121115, 0.8541979088518944}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654465`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 1, {
              Complex[6.166281672121115, 0.8541979088518944], 
              Complex[7.620891083164294, -0.3779828069654465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188319080961654, -0.8622384184423442}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 2, {
              Complex[6.188319080961654, -0.8622384184423442], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166332453213397, 0.8601447828394869}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 1, {
              Complex[6.166332453213397, 0.8601447828394869], 
              Complex[7.620959962859786, -0.37252955019570755`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188201486255246, -0.8681906520799051}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166381329020565, 0.866013429243351}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020565`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.866013429243351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 1, {
              Complex[6.166381329020565, 0.866013429243351], 
              Complex[7.621026552047415, -0.36715016675857515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188086428148008, -0.8740646059731696}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 2, {
              Complex[6.188086428148008, -0.8740646059731696], 
              Complex[7.6243541862563, -1.9909998552070276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166428388729594, 0.8718059882315833}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729594`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 1, {
              Complex[6.166428388729594, 0.8718059882315833], 
              Complex[7.621090949234538, -0.36184262733357503`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187973806370099, -0.8798624212060279}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 2, {
              Complex[6.187973806370099, -0.8798624212060279], 
              Complex[7.624115410024539, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166473716138243, 0.8775245100130518}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 1, {
              Complex[6.166473716138243, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489176`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187863526329917, -0.8855861488792872}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 2, {
              Complex[6.187863526329917, -0.8855861488792872], 
              Complex[7.623879500326577, -2.001493177613564]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166517390057898, 0.8831709599557604}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 1, {
              Complex[6.166517390057898, 0.8831709599557604], 
              Complex[7.621213533499526, -0.3514353849611336]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187755498701223, -0.8912377552298729}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 2, {
              Complex[6.187755498701223, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166559484680516, 0.8887472233381511}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187649639046594, -0.8968191263829126}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.011713916936429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 2, {
              Complex[6.187649639046594, -0.8968191263829126], 
              Complex[7.623415888441285, -2.011713916936429]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166600069913391, 0.8942551097650244}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 1, {
              Complex[6.166600069913391, 0.8942551097650244], 
              Complex[7.621328396747193, -0.3412932099060138]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187545867473453, -0.9023320727684229}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684229`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 2, {
              Complex[6.187545867473453, -0.9023320727684229], 
              Complex[7.623188002862294, -2.0167264965813105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166639211685018, 0.8996963572765849}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 1, {
              Complex[6.166639211685018, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187444108319425, -0.907778333231071}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.907778333231071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 2, {
              Complex[6.187444108319425, -0.907778333231071], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166676972224923, 0.9050726361762728}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 1, {
              Complex[6.166676972224923, 0.9050726361762728], 
              Complex[7.621436146769792, -0.3314026397464216]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187344289864064, -0.9131595788587057}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 2, {
              Complex[6.187344289864064, -0.9131595788587057], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166713410320053, 0.9103855526005629}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.32654778410681545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 1, {
              Complex[6.166713410320053, 0.9103855526005629], 
              Complex[7.6214875266561215`, -0.32654778410681545`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1872463440644, -0.9184774165528232}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166748581549979, 0.9156366518516704}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725156]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187150206311987, -0.9237333923619042}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9237333923619042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 2, {
              Complex[6.187150206311987, -0.9237333923619042], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166782538502953, 0.9208274215121253}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 1, {
              Complex[6.166782538502953, 0.9208274215121253], 
              Complex[7.62158560981236, -0.3170116033119908]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187055815209431, -0.9289289945966068}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187055815209431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 2, {
              Complex[6.187055815209431, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166815330974628, 0.9259592943584083}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827964`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 1, {
              Complex[6.166815330974628, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827964`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186963112364547, -0.9340656567439877}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0455329646559166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 2, {
              Complex[6.186963112364547, -0.9340656567439877], 
              Complex[7.62187048400586, -2.0455329646559166`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166847006151042, 0.9310336510892635}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307697651672017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 1, {
              Complex[6.166847006151042, 0.9310336510892635], 
              Complex[7.621677839037961, -0.307697651672017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186872042200552, -0.9391447601963726}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 2, {
              Complex[6.186872042200552, -0.9391447601963726], 
              Complex[7.621658530284445, -2.0501359962584584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166877608777316, 0.9360518228828755}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 1, {
              Complex[6.166877608777316, 0.9360518228828755], 
              Complex[7.621721890926156, -0.3031207679165942]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186782551780801, -0.9441676368090823}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166907181313368, 0.9410150937958545}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621764633176272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831939`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 1, {
              Complex[6.166907181313368, 0.9410150937958545], 
              Complex[7.621764633176272, -0.2985956409831939]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186694590646787, -0.9491355712999281}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 2, {
              Complex[6.186694590646787, -0.9491355712999281], 
              Complex[7.621240595073555, -2.0591841171322502`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166935764077782, 0.9459247030157969}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077782`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 1, {
              Complex[6.166935764077782, 0.9459247030157969], 
              Complex[7.621806111976447, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186608110668219, -0.9540498035022783}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166963395380895, 0.9507818469782091}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.289695999477332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 1, {
              Complex[6.166963395380895, 0.9507818469782091], 
              Complex[7.621846371329063, -0.289695999477332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186523065904125, -0.9589115304824554}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 2, {
              Complex[6.186523065904125, -0.9589115304824554], 
              Complex[7.620830251250195, -2.06802955861316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166990111648028, 0.9555876813576079}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 1, {
              Complex[6.166990111648028, 0.9555876813576079], 
              Complex[7.621885453180955, -0.2853192553735131]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186439412474037, -0.9637219085313019}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0723790886678515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 2, {
              Complex[6.186439412474037, -0.9637219085313019], 
              Complex[7.620627795708714, -2.0723790886678515`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167015947533717, 0.960343322941825}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1863571084384, -0.968482055038922}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.968482055038922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.076681249790104`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 2, {
              Complex[6.1863571084384, -0.968482055038922], 
              Complex[7.620427085927699, -2.076681249790104]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1670409360276865`, 0.9650498513977596}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 1, {
              Complex[6.1670409360276865`, 0.9650498513977596], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186276113687408, -0.9731930502608676}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 2, {
              Complex[6.186276113687408, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167065108553286, 0.9697083109361534}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186196389837632, -0.977855938983315}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 2, {
              Complex[6.186196389837632, -0.977855938983315], 
              Complex[7.620030720208938, -2.08514752827235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167088495058987, 0.974319711882344}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167088495058987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 1, {
              Complex[6.167088495058987, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186117900135718, -0.9824717320942185}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 2, {
              Complex[6.186117900135718, -0.9824717320942185], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167111124103515, 0.9788850321593936}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 1, {
              Complex[6.167111124103515, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186040609368664, -0.9870414080668144}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381358`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 2, {
              Complex[6.186040609368664, -0.9870414080668144], 
              Complex[7.619640805534111, -2.093436192381358]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167133022935145, 0.9834052186894812}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 1, {
              Complex[6.167133022935145, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18596448378006, -0.9915659143613826}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9915659143613826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0975162200987905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 2, {
              Complex[6.18596448378006, -0.9915659143613826], 
              Complex[7.619448165918566, -2.0975162200987905`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1671542175655905`, 0.9878811887189861}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 1, {
              Complex[6.1671542175655905`, 0.9878811887189861], 
              Complex[7.6221292001073655`, -0.2559512499133877]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1858894909919995`, -0.9960461687506831}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1015545476121806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.1015545476121806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167174732838953, 0.9923138310722672}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 1, {
              Complex[6.167174732838953, 0.9923138310722672], 
              Complex[7.62216016161569, -0.25192599017451744`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185815599931938, -1.0004830605740673`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 2, {
              Complex[6.185815599931938, -1.0004830605740673`], 
              Complex[7.619067332909202, -2.105552017907876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167194592496085, 0.9967040073387549}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790115`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 1, {
              Complex[6.167194592496085, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185742780764411, -1.0048774519249073`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 2, {
              Complex[6.185742780764411, -1.0048774519249073`], 
              Complex[7.618879068115524, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167213819234736, 1.0010525529976397`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6222194862862445`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 1, {
              Complex[6.167213819234736, 1.0010525529976397`], 
              Complex[7.6222194862862445`, -0.24399459426719083`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185671004827052, -1.0092301787755908`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 2, {
              Complex[6.185671004827052, -1.0092301787755908`], 
              Complex[7.618692192411459, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167232434765789, 1.0053602784840994`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167232434765789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 1, {
              Complex[6.167232434765789, 1.0053602784840994`], 
              Complex[7.622247902016086, -0.24008689867107663`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18560024457066, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167250459865911, 1.0096279702007271`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167250459865911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 1, {
              Complex[6.167250459865911, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185530473503021, -1.0178138586055243`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183224795479365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 2, {
              Complex[6.185530473503021, -1.0178138586055243`], 
              Complex[7.6183224795479365`, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167267914426833, 1.0138563914775602`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426833`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230236377805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278824`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 1, {
              Complex[6.167267914426833, 1.0138563914775602`], 
              Complex[7.62230236377805, -0.23238378615278824`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185461666136162, -1.0220463622527833`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 2, {
              Complex[6.185461666136162, -1.0220463622527833`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167284817501548, 1.0180462834838364`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613988`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399613988`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185393797936862, -1.0262403046082478`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1287229171405833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 2, {
              Complex[6.185393797936862, -1.0262403046082478`], 
              Complex[7.617957948303619, -2.1287229171405833`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167301187347678, 1.0221983660944405`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 1, {
              Complex[6.167301187347678, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185326845280092, -1.0303964059906554`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.132455946216316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 2, {
              Complex[6.185326845280092, -1.0303964059906554`], 
              Complex[7.617777553627534, -2.132455946216316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167317041468107, 1.0263133387136971`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263987`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263987]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18526078540529, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167332396649198, 1.0303918810590929`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263512`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 1, {
              Complex[6.167332396649198, 1.0303918810590929`], 
              Complex[7.622402440275708, -0.21740714715263512`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185195596375154, -1.0385978654970522`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.139817765412751`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 2, {
              Complex[6.185195596375154, -1.0385978654970522`], 
              Complex[7.617420370497284, -2.139817765412751]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1673472689966875`, 1.034434653907242}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 1, {
              Complex[6.1673472689966875`, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185131257036874, -1.0426445649584832`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143447826428835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 2, {
              Complex[6.185131257036874, -1.0426445649584832`], 
              Complex[7.617243530524916, -2.143447826428835]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16736167396946, 1.0384422998042997`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.21012316187055802`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.21012316187055802`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185067746985584, -1.046656107578573}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.046656107578573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1470448063535943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 2, {
              Complex[6.185067746985584, -1.046656107578573], 
              Complex[7.617067825366964, -2.1470448063535943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167375626411305, 1.0424154437428592`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411305`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62247040088057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 1, {
              Complex[6.167375626411305, 1.0424154437428592`], 
              Complex[7.62247040088057, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1850050465299, -1.0506331187508076`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 2, {
              Complex[6.1850050465299, -1.0506331187508076`], 
              Complex[7.616893231354067, -2.1506092976644986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167389140580846, 1.0463546938072399`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0463546938072399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247211`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 1, {
              Complex[6.167389140580846, 1.0463546938072399`], 
              Complex[7.622491801676729, -0.20296890336247211`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184943136659399, -1.0545762069524705`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167402230179721, 1.0502606417889435`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497568`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 1, {
              Complex[6.167402230179721, 1.0502606417889435`], 
              Complex[7.622512604505212, -0.1994389915497568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184881999013919, -1.0584859643603295`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184881999013919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 2, {
              Complex[6.184881999013919, -1.0584859643603295`], 
              Complex[7.616547285902738, -2.1576431046649516`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16741490837917, 1.054133863773935}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16741490837917`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 1, {
              Complex[6.16741490837917, 1.054133863773935], 
              Complex[7.622532825482896, -0.1959398257910541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1848216158545455`, -1.0623629674380988`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848216158545455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 2, {
              Complex[6.1848216158545455`, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167427187845094, 1.0579749207033111`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 1, {
              Complex[6.167427187845094, 1.0579749207033111`], 
              Complex[7.62255248014975, -0.1924708750021308]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184761970036191, -1.0662077774973113`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 2, {
              Complex[6.184761970036191, -1.0662077774973113`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167439080761726, 1.061784358908797}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 1, {
              Complex[6.167439080761726, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184703044981658, -1.0700209412330008`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 2, {
              Complex[6.184703044981658, -1.0700209412330008`], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167450598853971, 1.065562710624442}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18464482465708, -1.07380299123558}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18464482465708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 2, {
              Complex[6.18464482465708, -1.07380299123558], 
              Complex[7.615867768792523, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167461753408532, 1.0693104944757823`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0693104944757823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891855`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 1, {
              Complex[6.167461753408532, 1.0693104944757823`], 
              Complex[7.622608193566829, -0.18224020664891855`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184587293548677, -1.07755444648018}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07755444648018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 2, {
              Complex[6.184587293548677, -1.07755444648018], 
              Complex[7.615700350735352, -2.1746975940818936`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167472555293864, 1.0730282159476652`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1845304366407206`, -1.0812758127946427`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 2, {
              Complex[6.1845304366407206`, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674830149790685`, 1.0767163678318636`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 1, {
              Complex[6.1674830149790685`, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184474239394659, -1.0849675833073058`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 2, {
              Complex[6.184474239394659, -1.0849675833073058`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674931425517565`, 1.0803754306555198`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 1, {
              Complex[6.1674931425517565`, 1.0803754306555198`], 
              Complex[7.622659319428154, -0.1722636310861379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184418687729288, -1.0886302388755993`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 2, {
              Complex[6.184418687729288, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167502947734984, 1.0840058730914166`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692969`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 1, {
              Complex[6.167502947734984, 1.0840058730914166`], 
              Complex[7.622675401692969, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1843637680019645`, -1.092264248496479}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167512439903274, 1.087608152351}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 1, {
              Complex[6.167512439903274, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184309466990744, -1.095870069699595}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184309466990744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.095870069699595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 2, {
              Complex[6.184309466990744, -1.095870069699595], 
              Complex[7.614877115758211, -2.191044458598743]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167521628097823, 1.0911827145610284`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 1, {
              Complex[6.167521628097823, 1.0911827145610284`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18425577187742, -1.0994481489240888`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 2, {
              Complex[6.18425577187742, -1.0994481489240888`], 
              Complex[7.614715122272779, -2.1942339326893774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167530521040912, 1.0947299951246658`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 1, {
              Complex[6.167530521040912, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809714`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184202670231409, -1.1029989218798246`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 2, {
              Complex[6.184202670231409, -1.1029989218798246`], 
              Complex[7.614553976335032, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167539127149569, 1.0982504190677966`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15616767823602062`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 1, {
              Complex[6.167539127149569, 1.0982504190677966`], 
              Complex[7.622735243365228, -0.15616767823602062`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184150149994408, -1.1065228138938468`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 2, {
              Complex[6.184150149994408, -1.1065228138938468`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16754745454856, 1.1017444013712936`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16754745454856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 1, {
              Complex[6.16754745454856, 1.1017444013712936`], 
              Complex[7.622749136042125, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184098199465816, -1.110020240242771}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.110020240242771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.203650078201037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 2, {
              Complex[6.184098199465816, -1.110020240242771], 
              Complex[7.614234167722325, -2.203650078201037]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167555511082705, 1.105212347289903}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.105212347289903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1499057000473825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 1, {
              Complex[6.167555511082705, 1.105212347289903], 
              Complex[7.622762622058505, -0.1499057000473825]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1840468072888495`, -1.1134916064718132`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 2, {
              Complex[6.1840468072888495`, -1.1134916064718132`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167563304328588, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1839959624373115`, -1.116937308701091}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1839959624373115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.116937308701091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 2, {
              Complex[6.1839959624373115`, -1.116937308701091], 
              Complex[7.613917575212898, -2.209804519953592]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167570841605691, 1.1120717041858357`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167570841605691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385754`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 1, {
              Complex[6.167570841605691, 1.1120717041858357`], 
              Complex[7.622788412421261, -0.14373989214385754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183945654203009, -1.120357733919819}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.120357733919819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 2, {
              Complex[6.183945654203009, -1.120357733919819], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167578129986961, 1.1154638797377099`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 1, {
              Complex[6.167578129986961, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183895872183731, -1.1237532602689686`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183895872183731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 2, {
              Complex[6.183895872183731, -1.1237532602689686`], 
              Complex[7.613604090254433, -2.2158640508356973`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167585176308896, 1.118831548607898}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.137667361282291`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 1, {
              Complex[6.167585176308896, 1.118831548607898], 
              Complex[7.622812688125852, -0.137667361282291]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1838466062718, -1.1271242573129148`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 2, {
              Complex[6.1838466062718, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167591987181104, 1.1221750717795367`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 1, {
              Complex[6.167591987181104, 1.1221750717795367`], 
              Complex[7.622824279772895, -0.1346652064140491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183797846643169, -1.1304710863006693`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 2, {
              Complex[6.183797846643169, -1.1304710863006693`], 
              Complex[7.613293610009215, -2.221831501514857]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167598568995438, 1.125494802176165}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.125494802176165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1316853443892286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 1, {
              Complex[6.167598568995438, 1.125494802176165], 
              Complex[7.622835518377032, -0.1316853443892286]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183749583746966, -1.1337941004170398`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 2, {
              Complex[6.183749583746966, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167604927934658, 1.1287910849032743`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1287274488853231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 1, {
              Complex[6.167604927934658, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.1287274488853231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183701808295564, -1.1370936450243203`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 2, {
              Complex[6.183701808295564, -1.1370936450243203`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167611069980751, 1.1320642574808066`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167611069980751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 1, {
              Complex[6.167611069980751, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.12579120077420317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183654511255059, -1.140370057894864}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.230615910262511`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 2, {
              Complex[6.183654511255059, -1.140370057894864], 
              Complex[7.612833311505916, -2.230615910262511]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167617000922771, 1.1353146500669256`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183607683836199, -1.1436236694349757`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 2, {
              Complex[6.183607683836199, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167622726364391, 1.1385425856735314`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 1, {
              Complex[6.167622726364391, 1.1385425856735314`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183561317485685, -1.1468548029005141`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 2, {
              Complex[6.183561317485685, -1.1468548029005141`], 
              Complex[7.612529927102651, -2.236364734026167]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167628251731052, 1.1417483803738397`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167628251731052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878580925`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543315`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 1, {
              Complex[6.167628251731052, 1.1417483803738397`], 
              Complex[7.6228866878580925`, -0.11710925302543315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183515403877874, -1.1500637746045623`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 2, {
              Complex[6.183515403877874, -1.1500637746045623`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167633582276866, 1.1449323435024115`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981901966`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 1, {
              Complex[6.167633582276866, 1.1449323435024115`], 
              Complex[7.622895968318212, -0.11425653981901966`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183469934906837, -1.1532508941175417`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 2, {
              Complex[6.183469934906837, -1.1532508941175417`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676387230910485`, 1.1480947778478883`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676387230910485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1480947778478883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1114239791129977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 1, {
              Complex[6.1676387230910485`, 1.1480947778478883`], 
              Complex[7.622904947075774, -0.1114239791129977]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183424902678743, -1.1564164644600654`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61207985788809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 2, {
              Complex[6.183424902678743, -1.1564164644600654`], 
              Complex[7.61207985788809, -2.2448328483902134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167643679104284, 1.1512359798388987`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 1, {
              Complex[6.167643679104284, 1.1512359798388987`], 
              Complex[7.622913630641642, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183380299504599, -1.1595607822888856`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183380299504599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 2, {
              Complex[6.183380299504599, -1.1595607822888856`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676484550945725`, 1.1543562397232343`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676484550945725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1543562397232343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042397054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 1, {
              Complex[6.1676484550945725`, 1.1543562397232343`], 
              Complex[7.622922025342647, -0.10581820042397054`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183336117893253, -1.1626841380761954`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 2, {
              Complex[6.183336117893253, -1.1626841380761954`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167653055693024, 1.1574558417407834`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986418`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986418`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183292350544733, -1.165786816282607}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 2, {
              Complex[6.183292350544733, -1.165786816282607], 
              Complex[7.611635557076614, -2.2531216616761798`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676574853892205`, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676574853892205`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 1, {
              Complex[6.1676574853892205`, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183248990343843, -1.1688690955240513`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.255846023621816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 2, {
              Complex[6.183248990343843, -1.1688690955240513`], 
              Complex[7.611488694403538, -2.255846023621816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167661748536481, 1.1635941800905012`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167661748536481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 1, {
              Complex[6.167661748536481, 1.1635941800905012`], 
              Complex[7.622945536900381, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183206030354023, -1.1719312487328406`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183206030354023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 2, {
              Complex[6.183206030354023, -1.1719312487328406`], 
              Complex[7.611342435457721, -2.258551532233557]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16766584935682, 1.1666334563353575`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16766584935682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635199`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 1, {
              Complex[6.16766584935682, 1.1666334563353575`], 
              Complex[7.622952835953341, -0.09483652966635199]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18316346381144, -1.1749735433132207`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18316346381144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2612384403025065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 2, {
              Complex[6.18316346381144, -1.1749735433132207`], 
              Complex[7.611196771510035, -2.2612384403025065`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167669791945717, 1.169653154844329}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.169653154844329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 1, {
              Complex[6.167669791945717, 1.169653154844329], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183121284119398, -1.1779962412914968`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119398`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61105169403139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 2, {
              Complex[6.183121284119398, -1.1779962412914968`], 
              Complex[7.61105169403139, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167673580276671, 1.1726535322072744`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745444`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 1, {
              Complex[6.167673580276671, 1.1726535322072744`], 
              Complex[7.622966660095128, -0.08945655490745444]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183079484842854, -1.180999599461101}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183079484842854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 2, {
              Complex[6.183079484842854, -1.180999599461101], 
              Complex[7.610907194686493, -2.2665574406124445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167677218205584, 1.1756348399245444`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205584`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622973195741423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08679342975340572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 1, {
              Complex[6.167677218205584, 1.1756348399245444`], 
              Complex[7.622973195741423, -0.08679342975340572]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183038059703257, -1.183983869522754}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676807094749195`, 1.1785973245423347`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676807094749195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1785973245423347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 1, {
              Complex[6.1676807094749195`, 1.1785973245423347`], 
              Complex[7.622979487241573, -0.0841479006964719]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182997002573542, -1.1869492982198684`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990324, -2.271804947320255]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16768405771774, 1.1815412277835529`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16768405771774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 1, {
              Complex[6.16768405771774, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182956307473315, -1.1898961274694764`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 2, {
              Complex[6.182956307473315, -1.1898961274694764`], 
              Complex[7.610477084885046, -2.274402470753615]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167687266461522, 1.1844667866743102`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461522`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 1, {
              Complex[6.167687266461522, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182915968564257, -1.192824594488806}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.192824594488806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 2, {
              Complex[6.182915968564257, -1.192824594488806], 
              Complex[7.61033481839468, -2.276982807944708]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167690339131856, 1.1873742336662854`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.07631462931689577`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 1, {
              Complex[6.167690339131856, 1.1873742336662854`], 
              Complex[7.622996945557652, -0.07631462931689577]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182875980145687, -1.1957349319176869`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182875980145687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1957349319176869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 2, {
              Complex[6.182875980145687, -1.1957349319176869`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167693279055961, 1.1902637967550587`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 1, {
              Complex[6.167693279055961, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182836336650298, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2820927986688533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.2820927986688533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167696089466082, 1.193135699594645}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425508]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182797032640057, -1.2015021263830645`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.28462287927539`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 2, {
              Complex[6.182797032640057, -1.2015021263830645`], 
              Complex[7.609911224902993, -2.28462287927539]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167698773502735, 1.1959901616082877`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 1, {
              Complex[6.167698773502735, 1.1959901616082877`], 
              Complex[7.623012376610672, -0.06863176520228129]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182758062802262, -1.2043594268588769`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 2, {
              Complex[6.182758062802262, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167701334217814, 1.19882739809574}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182719421945745, -1.2071994848410685`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.289634248396078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.289634248396078]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167703774577616, 1.2016476203371216`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2016476203371216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813283`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 1, {
              Complex[6.167703774577616, 1.2016476203371216`], 
              Complex[7.623021595813283, -0.06359063896214613]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1826811049972195`, -1.210022511784006}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167706097465667, 1.2044510356934945`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182643106997765, -1.212828715220383}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.212828715220383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432073`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 2, {
              Complex[6.182643106997765, -1.212828715220383], 
              Complex[7.609353652021762, -2.294581899432073]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167708305685528, 1.2072378477042842`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478145`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 1, {
              Complex[6.167708305685528, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478145]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182605423099422, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 2, {
              Complex[6.182605423099422, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677104019634195`, 1.2100082561816607`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2100082561816607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 1, {
              Complex[6.1677104019634195`, 1.2100082561816607`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182568048561962, -1.2183914626776442`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 2, {
              Complex[6.182568048561962, -1.2183914626776442`], 
              Complex[7.6090778393267975`, -2.2994673862275175`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677123889507754`, 1.2127624573020028`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677123889507754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 1, {
              Complex[6.1677123889507754`, 1.2127624573020028`], 
              Complex[7.623037615868168, -0.05369518368470517]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1825309787497025`, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167714269226695, 1.2155006436945397`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 1, {
              Complex[6.167714269226695, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182494209128501, -1.2238893126698194`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182494209128501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 2, {
              Complex[6.182494209128501, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167716045300302, 1.218223004527287}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.218223004527287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 1, {
              Complex[6.167716045300302, 1.218223004527287], 
              Complex[7.623044476955637, -0.048837864018669234`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182457735262817, -1.2266143809612575`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 2, {
              Complex[6.182457735262817, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167717719612998, 1.2209297255903702`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 1, {
              Complex[6.167717719612998, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1824215528129, -1.2293237938391437`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 2, {
              Complex[6.1824215528129, -1.2293237938391437`], 
              Complex[7.608531912472354, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719294540653, 1.2236209893768368`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540653`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 1, {
              Complex[6.167719294540653, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182385657532067, -1.2320177339512257`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3114188284924206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 2, {
              Complex[6.182385657532067, -1.2320177339512257`], 
              Complex[7.608396583634034, -2.3114188284924206`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720772395696, 1.226296975161037}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.226296975161037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 1, {
              Complex[6.167720772395696, 1.226296975161037], 
              Complex[7.623053411554656, -0.041660895014681475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182350045264077, -1.2346963807243225`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 2, {
              Complex[6.182350045264077, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772215542913, 1.2289578590746733`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 1, {
              Complex[6.16772215542913, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.039296961870488915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182314711940598, -1.2373599104404132`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 2, {
              Complex[6.182314711940598, -1.2373599104404132`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723445832482, 1.2316038141805974`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032507`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 1, {
              Complex[6.167723445832482, 1.2316038141805974`], 
              Complex[7.623058501641022, -0.03694694917032507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182279653578758, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167724645739662, 1.2342350105444315`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 1, {
              Complex[6.167724645739662, 1.2342350105444315`], 
              Complex[7.623060796195637, -0.03461069652302155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182244866278791, -1.2426423085461484`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723058`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 2, {
              Complex[6.182244866278791, -1.2426423085461484`], 
              Complex[7.607859712684855, -2.320721705723058]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725757228776, 1.2368516153040956`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048269`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 1, {
              Complex[6.167725757228776, 1.2368516153040956`], 
              Complex[7.6230629277676165`, -0.03228804631048269]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1822103462217495`, -1.2452615144292976`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 2, {
              Complex[6.1822103462217495`, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167726782323851, 1.239453792737311}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726782323851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.239453792737311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 1, {
              Complex[6.167726782323851, 1.239453792737311], 
              Complex[7.623064899277237, -0.029978843623626066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182176089667306, -1.2478662783795624`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 2, {
              Complex[6.182176089667306, -1.2478662783795624`], 
              Complex[7.607593869964683, -2.3252906672740603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727722996507, 1.2420417043271579`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230667135775585`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 1, {
              Complex[6.167727722996507, 1.2420417043271579`], 
              Complex[7.6230667135775585`, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182142092951617, -1.2504567620199438`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.327555074323918]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167728581167581, 1.2446155088257418`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728581167581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 1, {
              Complex[6.167728581167581, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427072]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1821083524852725`, -1.2530331242405153`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1821083524852725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 2, {
              Complex[6.1821083524852725`, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729358708657, 1.2471753623160462`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2471753623160462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773041`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 1, {
              Complex[6.167729358708657, 1.2471753623160462`], 
              Complex[7.623069881638046, -0.02313041096773041]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182074864751301, -1.2555955212603065`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 2, {
              Complex[6.182074864751301, -1.2555955212603065`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730057443583, 1.2497214182720298`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 1, {
              Complex[6.167730057443583, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333081253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182041626303248, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 2, {
              Complex[6.182041626303248, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730679149904, 1.2522538276170267`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.01862930319811857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 1, {
              Complex[6.167730679149904, 1.2522538276170267`], 
              Complex[7.623072453501178, -0.01862930319811857]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182008633763318, -1.260679031577555}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731225560259, 1.2547727387804994`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181975883820567, -1.2632004444906193`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.338682294675321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 2, {
              Complex[6.181975883820567, -1.2632004444906193`], 
              Complex[7.606806236472661, -2.338682294675321]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731698363721, 1.2572782977532326`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133222896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1819433732291715`, -1.2657084915461236`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 2, {
              Complex[6.1819433732291715`, -1.2657084915461236`], 
              Complex[7.606676358179669, -2.340869773551443]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732099207093, 1.2597706481409658`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207093`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278048698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 1, {
              Complex[6.167732099207093, 1.2597706481409658`], 
              Complex[7.623075238225612, -0.011971590278048698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181911098806735, -1.2682033164767694`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 2, {
              Complex[6.181911098806735, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732429696165, 1.26224993121657}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169417`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 1, {
              Complex[6.167732429696165, 1.26224993121657], 
              Complex[7.623075890104745, -0.00977686197169417]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181879057432655, -1.2706850606806677`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181879057432655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 2, {
              Complex[6.181879057432655, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732691396911, 1.2647162859707828`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725731, -0.007594168249853941]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181847246046555, -1.273153863272108}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 2, {
              Complex[6.181847246046555, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732885836666, 1.2671698491615646`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230767933656285`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 1, {
              Complex[6.167732885836666, 1.2671698491615646`], 
              Complex[7.6230767933656285`, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181815661646744, -1.2756098611309443`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 2, {
              Complex[6.181815661646744, -1.2756098611309443`], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733014505245, 1.2696107553621176`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 1, {
              Complex[6.167733014505245, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181784301288738, -1.2780531889506412`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181784301288738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60603267803846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 2, {
              Complex[6.181784301288738, -1.2780531889506412`], 
              Complex[7.60603267803846, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733078856031, 1.272039137007607}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565681`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 1, {
              Complex[6.167733078856031, 1.272039137007607], 
              Complex[7.623077177565681, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181753162083825, -1.2804839792850273`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733080307031, 1.2744551244406341`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733080307031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230771804391395`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0010188070462166473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 1, {
              Complex[6.167733080307031, 1.2744551244406341`], 
              Complex[7.6230771804391395`, 0.0010188070462166473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181722241197679, -1.2829023625937932`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733020241881, 1.2768588459554964`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985724435`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 1, {
              Complex[6.167733020241881, 1.2768588459554964`], 
              Complex[7.62307705996065, 0.0031432198985724435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181691535849002, -1.2853084672867792`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 2, {
              Complex[6.181691535849002, -1.2853084672867792`], 
              Complex[7.605650891587858, -2.3579365364447966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677329000108365`, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210561]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181661043308228, -1.2877024197670908`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 2, {
              Complex[6.181661043308228, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732720931719, 1.2816299944237617`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 1, {
              Complex[6.167732720931719, 1.2816299944237617`], 
              Complex[7.623076457080134, 0.007358287782327438]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181630760896248, -1.2900843444730696`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 2, {
              Complex[6.181630760896248, -1.2900843444730696`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732484290828, 1.2839976681063676`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 1, {
              Complex[6.167732484290828, 1.2839976681063676`], 
              Complex[7.623075978637889, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181600685983191, -1.2924543639191772`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 2, {
              Complex[6.181600685983191, -1.2924543639191772`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732191343831, 1.2863535694098465`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181570815987222, -1.2948125987358026`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 2, {
              Complex[6.181570815987222, -1.2948125987358026`], 
              Complex[7.605146784820534, -2.3661941636932524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731843316621, 1.2886978170110814`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 1, {
              Complex[6.167731843316621, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181541148373396, -1.2971591677080392`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 2, {
              Complex[6.181541148373396, -1.2971591677080392`], 
              Complex[7.605021616198942, -2.3682311227994592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731441406146, 1.2910305277808336`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205368`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205368, 0.01565660770491158]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18151168065253, -1.2994941878134683`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3702573258609094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 2, {
              Complex[6.18151168065253, -1.2994941878134683`], 
              Complex[7.604896783758138, -2.3702573258609094`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730986781208, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551784`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181482410380124, -1.3018177742589643`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730480583245, 1.2956617974980968`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1814533351552905`, -1.3041300405165681`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1814533351552905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3041300405165681`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 2, {
              Complex[6.1814533351552905`, -1.3041300405165681`], 
              Complex[7.604648113785144, -2.3742778964006486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729923927074, 1.2979605814829254`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 1, {
              Complex[6.167729923927074, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138642`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181424452619748, -1.3064310983584508`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 2, {
              Complex[6.181424452619748, -1.3064310983584508`], 
              Complex[7.604524269574324, -2.3762724760820655`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729317901629, 1.3002482787798992`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181395760456799, -1.3087210578909674`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 2, {
              Complex[6.181395760456799, -1.3087210578909674`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167728663570656, 1.302524997762607}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.302524997762607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128268475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 1, {
              Complex[6.167728663570656, 1.302524997762607], 
              Complex[7.623068148652344, 0.025791400128268475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181367256390405, -1.3110000275879246`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 2, {
              Complex[6.181367256390405, -1.3110000275879246`], 
              Complex[7.604277546409373, -2.380230742900864]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727961973396, 1.3047908452057129`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 1, {
              Complex[6.167727961973396, 1.3047908452057129`], 
              Complex[7.623066695834461, 0.02778765853546761]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181338938184203, -1.3132681143229272`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3821946328738326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 2, {
              Complex[6.181338938184203, -1.3132681143229272`], 
              Complex[7.604154661093241, -2.3821946328738326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772721412525, 1.307045926316517}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772721412525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145811`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 1, {
              Complex[6.16772721412525, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145811]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1813108036406295`, -1.3155254234009868`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1813108036406295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 2, {
              Complex[6.1813108036406295`, -1.3155254234009868`], 
              Complex[7.604032089130617, -2.3841484932853487`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167726421018415, 1.3092903447657454`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 1, {
              Complex[6.167726421018415, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181282850600008, -1.317772058589321}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.317772058589321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 2, {
              Complex[6.181282850600008, -1.317772058589321], 
              Complex[7.603909827464786, -2.3860924218560746`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725583622502, 1.311524202717575}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 1, {
              Complex[6.167725583622502, 1.311524202717575], 
              Complex[7.623061744580699, 0.03371682926778467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181255076939699, -1.3200081221474058`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772470288514, 1.3137476008589228`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 1, {
              Complex[6.16772470288514, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181227480573278, -1.3222337148562802`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3222337148562802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 2, {
              Complex[6.181227480573278, -1.3222337148562802`], 
              Complex[7.6036662230346, -2.3899508672515024`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723779732553, 1.315960638428035}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.315960638428035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983468`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 1, {
              Complex[6.167723779732553, 1.315960638428035], 
              Complex[7.623057965000035, 0.03762089710983468]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181200059449697, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 2, {
              Complex[6.181200059449697, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167722815070128, 1.3181634132423614`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070128`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 1, {
              Complex[6.167722815070128, 1.3181634132423614`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181172811552509, -1.3266538836292927`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181172811552509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3266538836292927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.393770722784652`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 2, {
              Complex[6.181172811552509, -1.3266538836292927`], 
              Complex[7.6034238242867636`, -2.393770722784652]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167721809782957, 1.3203560217257766`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397212`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 1, {
              Complex[6.167721809782957, 1.3203560217257766`], 
              Complex[7.62305381611219, 0.04148686306397212]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181145734899094, -1.3288486541172815`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 2, {
              Complex[6.181145734899094, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720764736373, 1.3225385589351388`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 1, {
              Complex[6.167720764736373, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18111882753992, -1.331033342657582}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18111882753992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 2, {
              Complex[6.18111882753992, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719680776454, 1.324711118586218}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.324711118586218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 1, {
              Complex[6.167719680776454, 1.324711118586218], 
              Complex[7.6230493091457, 0.045315447506474565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181092087557802, -1.3332080430544784`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181092087557802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 2, {
              Complex[6.181092087557802, -1.3332080430544784`], 
              Complex[7.603062437136163, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167718558730529, 1.326873793079005}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.047215941208410626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181065513067208, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.401297572319007`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.401297572319007]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677173994076595`, 1.3290266735224265`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181039102213561, -1.337527848075708}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181039102213561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.337527848075708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 2, {
              Complex[6.181039102213561, -1.337527848075708], 
              Complex[7.602822954346457, -2.403156285196984]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.118560581075963, 0.006887727487388491}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487388491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.4787533558490455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1631402225643404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[8.118560581075963, 0.006887727487388491], 
              Complex[6.4787533558490455`, -1.1631402225643404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.539894192888829`, -0.013243170301698895`}],
            
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.539894192888829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013243170301698895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[10.539894192888829`, -0.013243170301698895`], 
              Complex[8.800016052466027, -1.1961486271318054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.162580737731862, 0.007042959985368874}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368874`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163055469019636`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[8.162580737731862, 0.007042959985368874], 
              Complex[6.52215878639839, -1.163055469019636]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.494506767269002`, -0.01350987671532385}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269002`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01350987671532385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.755092274628062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[10.494506767269002`, -0.01350987671532385], 
              Complex[8.755092274628062, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.198987977866881, 0.007197843246654785}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629725487625657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[8.198987977866881, 0.007197843246654785], 
              Complex[6.557943371421669, -1.1629725487625657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.457042457039064`, -0.013751044852512901`}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039064`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[10.457042457039064`, -0.013751044852512901`], 
              Complex[8.718101741665087, -1.1964748219538675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.23100514788576, 0.007354951961003822}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.23100514788576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961003822`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162888878950318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[8.23100514788576, 0.007354951961003822], 
              Complex[6.589330078860694, -1.162888878950318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.42414741707873, -0.013979869598457921`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[10.42414741707873, -0.013979869598457921`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.260098904258959, 0.007515591774090758}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[8.260098904258959, 0.007515591774090758], 
              Complex[6.61778553109412, -1.1628031728636479`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.394295711708596`, -0.014202465960738788`}],
            
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.394295711708596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014202465960738788`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[10.394295711708596`, -0.014202465960738788`], 
              Complex[8.656331133890308, -1.1967364397628222`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.287084479515974, 0.0076806282899812735`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076806282899812735`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756091`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[8.287084479515974, 0.0076806282899812735`], 
              Complex[6.644124842294815, -1.1627145990756091`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.366639367283947`, -0.014422357660349779`}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660349779`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[10.366639367283947`, -0.014422357660349779`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.312471288002843, 0.007850743160531302}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002843`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160531302`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983663`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[8.312471288002843, 0.007850743160531302], 
              Complex[6.668857252414799, -1.1626225207983663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.340648661463618`, -0.014641876121435745`}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121435745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[10.340648661463618`, -0.014641876121435745`], 
              Complex[8.603697599379137, -1.1969782988821362`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.336603564825273, 0.008026538528972045}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972045`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.692326779227161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[8.336603564825273, 0.008026538528972045], 
              Complex[6.692326779227161, -1.1625263894330446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.315965756037766`, -0.01486272923227436}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01486272923227436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[10.315965756037766`, -0.01486272923227436], 
              Complex[8.579535601926915, -1.1970974543173973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.359727508694592, 0.008208588338763303}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694592`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338763303`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931875`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[8.359727508694592, 0.008208588338763303], 
              Complex[6.7147793676173775`, -1.1624256923931875`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.292334825045389`, -0.01508627394224807}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.292334825045389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01508627394224807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[10.292334825045389`, -0.01508627394224807], 
              Complex[8.556435217312076, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.382027043209192, 0.008397467701836869}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836869`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[8.382027043209192, 0.008397467701836869], 
              Complex[6.736398653893473, -1.1623199234705248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.269564843263957`, -0.015313663264596185`}],
            
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015313663264596185`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[10.269564843263957`, -0.015313663264596185`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.40364445944282, 0.008593772293729816}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[8.40364445944282, 0.008593772293729816], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.247508108692934`, -0.015545933419028875`}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[10.247508108692934`, -0.015545933419028875`], 
              Complex[8.512699415121855, -1.1974634260014823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.424693095053827, 0.008798133065178966}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053827`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[8.424693095053827, 0.008798133065178966], 
              Complex[6.777676219425207, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.226047052260428`, -0.015784060035231827`}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015784060035231827`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[10.226047052260428`, -0.015784060035231827`], 
              Complex[8.491799285559553, -1.1975915689762868`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.445265519754589, 0.009011228909081513}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909081513`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619668458011307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[8.445265519754589, 0.009011228909081513], 
              Complex[6.797539667322055, -1.1619668458011307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.20508572371207, -0.01602899750358715}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[10.20508572371207, -0.01602899750358715], 
              Complex[8.471409637754663, -1.1977242798043064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.465439042444201, 0.009233798770935048}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[8.465439042444201, 0.009233798770935048], 
              Complex[6.816993839756788, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.184544064614808`, -0.016281708942805177`}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805177`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[10.184544064614808`, -0.016281708942805177`], 
              Complex[8.451450795228006, -1.1978624312936863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.485279549606197, 0.009466654168547499}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547499`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[8.485279549606197, 0.009466654168547499], 
              Complex[6.836104162316991, -1.1616956277315165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.164353917920574`, -0.016543191071888966`}],
            
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920574`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[10.164353917920574`, -0.016543191071888966`], 
              Complex[8.431855025955322, -1.1980069181435882`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.504844265661474, 0.009710692858210825}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[8.504844265661474, 0.009710692858210825], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.144456159495562`, -0.016814496662831885`}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[10.144456159495562`, -0.016814496662831885`], 
              Complex[8.412563676597296, -1.198158678433355]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.52418379610039, 0.00996691431009624}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.124798576239256`, -0.017096756417673765`}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[10.124798576239256`, -0.017096756417673765`], 
              Complex[8.393525054229872, -1.1983187142405294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.543343682297632, 0.010236437677199157`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199157`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612201711252075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[8.543343682297632, 0.010236437677199157`], 
              Complex[6.891907468896066, -1.1612201711252075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.105334252708916`, -0.017391201699304238`}],
            
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[10.105334252708916`, -0.017391201699304238`], 
              Complex[8.374692817528388, -1.198488112788141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.562365618323057, 0.010520523036428395`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036428395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.910150364313235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610395954830408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[8.562365618323057, 0.010520523036428395`], 
              Complex[6.910150364313235, -1.1610395954830408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.086020309962356`, -0.017699189379580448`}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[10.086020309962356`, -0.017699189379580448`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.581288431797729, 0.01082059684449242}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01082059684449242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.928280270084161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160846029681665`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[8.581288431797729, 0.01082059684449242], 
              Complex[6.928280270084161, -1.160846029681665]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.066816890576662`, -0.018022230071644284`}],
            
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.066816890576662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018022230071644284`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[10.066816890576662`, -0.018022230071644284`], 
              Complex[8.33748160781912, -1.1988599130234303`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.600148900521388, 0.011138282794836947`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521388`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836947`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240902`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[8.600148900521388, 0.011138282794836947`], 
              Complex[6.946333169123366, -1.1606380604240902`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.047686315383556`, -0.018362021154624233`}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624233`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[10.047686315383556`, -0.018362021154624233`], 
              Complex[8.319026572634915, -1.1990651369525758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.618982457304563, 0.011475439606775214`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775214`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[8.618982457304563, 0.011475439606775214`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.02859235757786, -0.018720486277070795`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[10.02859235757786, -0.018720486277070795`], 
              Complex[8.300624247551832, -1.1992854341178676`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.637823823216573, 0.011834207760463423`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463423`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[8.637823823216573, 0.011834207760463423`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.009499592627154`, -0.019099823463292597`}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[10.009499592627154`, -0.019099823463292597`], 
              Complex[8.282240162776432, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.656707602013043, 0.01221706786722248}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01221706786722248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159910198078305`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[8.656707602013043, 0.01221706786722248], 
              Complex[7.000371925640259, -1.159910198078305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.99037279023362, -0.019502564592186845`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.99037279023362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[9.99037279023362, -0.019502564592186845`], 
              Complex[8.263840153003091, -1.1997792920739643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.675668864524779, 0.012626914319474904`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[8.675668864524779, 0.012626914319474904`], 
              Complex[7.018457172595781, -1.1596255988326742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.97117631884134, -0.019931649951741095`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.97117631884134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[9.97117631884134, -0.019931649951741095`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.694743750598734, 0.013067149229434393`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598734`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229434393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[8.694743750598734, 0.013067149229434393`], 
              Complex[7.036635886648769, -1.1593153672755065`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.951873534557844, -0.020390522922278616`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[9.951873534557844, -0.020390522922278616`], 
              Complex[8.226853738441676, -1.2003609757255187`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.713970117564823, 0.013541803645187473`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645187473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0549443961207245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1589759311366719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[8.713970117564823, 0.013541803645187473`], 
              Complex[7.0549443961207245`, -1.1589759311366719`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.932426125107996, -0.02088325181027976}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02088325181027976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[9.932426125107996, -0.02088325181027976], 
              Complex[8.208195234091123, -1.2006927729717154`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.733388268345111, 0.014055695951277604`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586030069798183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[8.733388268345111, 0.014055695951277604`], 
              Complex[7.073421269042282, -1.1586030069798183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.912793375391814, -0.021414688765244935`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765244935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[9.912793375391814, -0.021414688765244935`], 
              Complex[8.18937527323683, -1.2010573992945914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.753041799848585, 0.014614641743299529`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299529`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[8.753041799848585, 0.014614641743299529`], 
              Complex[7.092108121115126, -1.1581914085205158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.892931313762208, -0.021990680088691886`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691886`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[9.892931313762208, -0.021990680088691886`], 
              Complex[8.170351853484789, -1.2014600752208562`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.772978624412278, 0.01522573618198167}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.772978624412278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[8.772978624412278, 0.01522573618198167], 
              Complex[7.111050585905174, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.872791686074075, -0.022618348956057525`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057525`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[9.872791686074075, -0.022618348956057525`], 
              Complex[8.151078988162066, -1.2019071795671374`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.793252235841301, 0.01589774035976075}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[8.793252235841301, 0.01589774035976075], 
              Complex[7.130299515097565, -1.157225283537514]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.852320685804425, -0.023306482096512558`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.023306482096512558`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.131505502166522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908525`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[9.852320685804425, -0.023306482096512558`], 
              Complex[8.131505502166522, -1.2024066038908525`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.813923320576674, 0.016641620135819532`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819532`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[8.813923320576674, 0.016641620135819532`], 
              Complex[7.149912504017516, -1.1566530214405542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.831457339597339, -0.024066068896217683`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[9.831457339597339, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.835061859626233, 0.017471313877762313`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[8.835061859626233, 0.017471313877762313`], 
              Complex[7.169955880282916, -1.1560054129682458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.81013140250469, -0.02491106937082753}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[9.81013140250469, -0.02491106937082753], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.856749938394854, 0.018404853311322075`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322075`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.018404853311322075`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.78826054571076, -0.02585953521479544}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204332394000482`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479544], 
              Complex[8.070356192382524, -1.204332394000482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.879085597629636, 0.019466046203824108`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629636`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203824108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629636, 0.019466046203824108`], 
              Complex[7.211659694982883, -1.1544135020746282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.76574650346378, -0.026935292658188545`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.026935292658188545`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.026935292658188545`], 
              Complex[8.048899928737553, -1.2051729191751666`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.902188252549182, 0.020687085496538995`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549182`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496538995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549182, 0.020687085496538995`], 
              Complex[7.233525786397049, -1.153418203138091]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.742469652095144, -0.028170551750252903`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095144, -0.028170551750252903`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.926206541442705, 0.022112751073539966`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073539966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053036`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442705, 0.022112751073539966`], 
              Complex[7.256246121108595, -1.1522392586053036`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.718281159799472, -0.029610108260631426`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631426`], 
              Complex[8.003719151417389, -1.2073216443878658`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.95133006145241, 0.02380748722011572}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.02380748722011572], 
              Complex[7.279999873987634, -1.1508175252699346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.692991249427964, -0.03131842125415461}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427964, -0.03131842125415461], 
              Complex[7.979674588033217, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.977807551308562, 0.025867986584034504`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308562`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584034504`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308562, 0.025867986584034504`], 
              Complex[7.305022131856599, -1.1490639772295197`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.6663510144975, -0.03339219715471052}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03339219715471052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210469746066147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.03339219715471052], 
              Complex[7.954365525461626, -1.210469746066147]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.005976175768344, 0.028447097632702298`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768344`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632702298`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.331631661529259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468374259621612`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768344, 0.028447097632702298`], 
              Complex[7.331631661529259, -1.1468374259621612`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.638023133640685, -0.03598429729320677}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.03598429729320677], 
              Complex[7.927473033284, -1.2126821236194967`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.036310546964629, 0.03180315785237416}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964629, 0.03180315785237416], 
              Complex[7.360277468735851, -1.1438984501954061`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.607532848271008, -0.039353071187375584`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187375584`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187375584`], 
              Complex[7.89854795260484, -1.2156065553823743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.06950674944049, 0.036413030935491295`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.06950674944049`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155713`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.06950674944049, 0.036413030935491295`], 
              Complex[7.391618832430633, -1.1398036000155713`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.574183936670558, -0.04397539380089758}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380089758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670558, -0.04397539380089758], 
              Complex[7.866930860848728, -1.2196865044147263`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.106617372354673, 0.04326772266645221}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645221], 
              Complex[7.426654831776879, -1.1336280195460162`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.536923681000957, -0.05084228149319718}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000957, -0.05084228149319718], 
              Complex[7.831622543975549, -1.2258468389686643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.149127159726488, 0.05476808187732279}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732279], 
              Complex[7.466802670715167, -1.1231222909767526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.49426721635719, -0.06235459303258733}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.49426721635719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.791205671196036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.49426721635719, -0.06235459303258733], 
              Complex[7.791205671196036, -1.2363369885208018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.197298230159177, 0.0773435944124776}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0773435944124776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.0773435944124776], 
              Complex[7.512359287571745, -1.1022322984450343`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.445952310414638, -0.08494182361233307}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414638, -0.08494182361233307], 
              Complex[7.745383184720152, -1.2572110799472342`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.239565409647737, 0.11902724764149768`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647737`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647737, 0.11902724764149768`], 
              Complex[7.552491023448555, -1.0633012820313001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.403544030055128, -0.126636969409872}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.126636969409872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055128, -0.126636969409872], 
              Complex[7.704988630788337, -1.2961258835777412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.262317347784467, 0.16611165996514074`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996514074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5742681397347305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0191412329170928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784467, 0.16611165996514074`], 
              Complex[7.5742681397347305`, -1.0191412329170928`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.380653624650828, -0.1737326571346823}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1737326571346823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650828, -0.1737326571346823], 
              Complex[7.682951641637805, -1.3402694180832753`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.27379501912068, 0.2069539217818482}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.2069539217818482], 
              Complex[7.58536879774568, -0.980787258766952]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.369040024240865, -0.2145859850323753}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2145859850323753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.378606585134925`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240865, -0.2145859850323753], 
              Complex[7.671593955391062, -1.378606585134925]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.28057052908999, 0.24191392575349593`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28057052908999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59199089590948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.28057052908999, 0.24191392575349593`], 
              Complex[7.59199089590948, -0.9479498476029711]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.362131033190314, -0.24955685318475315`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.24955685318475315`], 
              Complex[7.664717578441821, -1.4114269055666673`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.28508522547646, 0.27256109297706876`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28508522547646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.28508522547646, 0.27256109297706876`], 
              Complex[7.596448189109473, -0.9191675975214375]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.357485218342608, -0.280214689712569}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280214689712569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926077`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.280214689712569], 
              Complex[7.660008665723722, -1.4401917896926077`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.288342049505975, 0.3000009300835051}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141116`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835051], 
              Complex[7.599694877117055, -0.8934053728141116]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.354099557583266, -0.3076650079025534}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.354099557583266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076650079025534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6565129319240635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4659363812164738`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.354099557583266, -0.3076650079025534], 
              Complex[7.6565129319240635`, -1.4659363812164738`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.290821923790604, 0.32496389242765855`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790604`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242765855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.869977650706397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790604, 0.32496389242765855`], 
              Complex[7.602190099828059, -0.869977650706397]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.351493051581294, -0.3326382694231205}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581294, -0.3326382694231205], 
              Complex[7.653771155925207, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.292784687952791, 0.3479481691887596}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3479481691887596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.3479481691887596], 
              Complex[7.604182742222917, -0.848416245271419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.34940578787805, -0.3556326694484073}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34940578787805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.651534375550015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.510889470782688`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.34940578787805, -0.3556326694484073], 
              Complex[7.651534375550015, -1.510889470782688]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.294383744285959, 0.36930769700429517`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285959, 0.36930769700429517`], 
              Complex[7.605820205415673, -0.8283882117511524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.347684294964536, -0.3770021503134534}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3770021503134534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.3770021503134534], 
              Complex[7.649655116243796, -1.530899113668035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.29571595421648, 0.389303350769084}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.389303350769084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.389303350769084], 
              Complex[7.607195850080812, -0.8096479618228555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.346231645579122, -0.39700759233314564`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579122, -0.39700759233314564`], 
              Complex[7.648039947400702, -1.5496207340949613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.296845766278874, 0.40813349152982553`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 1, {
              Complex[9.296845766278874, 0.40813349152982553`], 
              Complex[7.608371984798496, -0.7920086413709151]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.344983328511988, -0.4158473617147172}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4158473617147172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 2, {
              Complex[9.344983328511988, -0.4158473617147172], 
              Complex[7.6466264937920405`, -1.5672411924777212`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.29781789372527, 0.4259529280523638}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29781789372527`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 1, {
              Complex[9.29781789372527, 0.4259529280523638], 
              Complex[7.60939196819019, -0.7753243442615719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.343894570793292, -0.4336762721416339}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 2, {
              Complex[9.343894570793292, -0.4336762721416339], 
              Complex[7.6453713332226165`, -1.5839064009711161`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.298664434058159, 0.4428851530791995}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4428851530791995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 1, {
              Complex[9.298664434058159, 0.4428851530791995], 
              Complex[7.610287017953022, -0.7594786249471305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.342933217974055, -0.4506178210463807}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 2, {
              Complex[9.342933217974055, -0.4506178210463807], 
              Complex[7.644243187304666, -1.5997328108831594`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.299409090344204, 0.4590305218050602}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4590305218050602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 1, {
              Complex[9.299409090344204, 0.4590305218050602], 
              Complex[7.611080255416446, -0.7443768154213616]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.34207551264073, -0.46677236810008255`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34207551264073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46677236810008255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.643218876724594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6148150957352267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 2, {
              Complex[9.34207551264073, -0.46677236810008255`], 
              Complex[7.643218876724594, -1.6148150957352267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.300069789499112, 0.4744718898931336}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319841`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 1, {
              Complex[9.300069789499112, 0.4744718898931336], 
              Complex[7.611789218669329, -0.7299407258319841]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.341303475971884, -0.48222277324174195`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 2, {
              Complex[9.341303475971884, -0.48222277324174195`], 
              Complex[7.642280807952738, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.300660369136605, 0.4892786068277399}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.340603220742913, -0.49703839004290706`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 2, {
              Complex[9.340603220742913, -0.49703839004290706`], 
              Complex[7.641415351146397, -1.6430473477012988`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.301191700128847, 0.5035094122855177}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 1, {
              Complex[9.301191700128847, 0.5035094122855177], 
              Complex[7.613005749670385, -0.7028138366825415]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.339963828630122, -0.5112779620899688}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 2, {
              Complex[9.339963828630122, -0.5112779620899688], 
              Complex[7.640611758766885, -1.6563182605942466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.301672454837957, 0.5172145811965807}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 1, {
              Complex[9.301672454837957, 0.5172145811965807], 
              Complex[7.613532572082195, -0.6900200786894217]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.339376581853779, -0.5249917680556032}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 2, {
              Complex[9.339376581853779, -0.5249917680556032], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302109645838716, 0.530437541999259}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.530437541999259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 1, {
              Complex[9.302109645838716, 0.530437541999259], 
              Complex[7.614014891510713, -0.6776825815576768]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.338834424339026, -0.5382232399630631}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 2, {
              Complex[9.338834424339026, -0.5382232399630631], 
              Complex[7.63915736107556, -1.681408654757819]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302509011886752, 0.5432161176861708}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.665765598769965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 1, {
              Complex[9.302509011886752, 0.5432161176861708], 
              Complex[7.614458403240932, -0.665765598769965]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.338331575639636, -0.5510102042411116}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 2, {
              Complex[9.338331575639636, -0.5510102042411116], 
              Complex[7.638493829265323, -1.6933049250204684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302875299750397, 0.5555834916479547}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.654237761160508`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 1, {
              Complex[9.302875299750397, 0.5555834916479547], 
              Complex[7.6148678313818445`, -0.654237761160508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337863249005673, -0.5633858475760005}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637866061694656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 2, {
              Complex[9.337863249005673, -0.5633858475760005], 
              Complex[7.637866061694656, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.303212473521276, 0.567568969325976}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.567568969325976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 1, {
              Complex[9.303212473521276, 0.567568969325976], 
              Complex[7.615247132185832, -0.6430713592597934]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337425441979393, -0.5753794785718535}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.303523872448524, 0.5791985860418384}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 1, {
              Complex[9.303523872448524, 0.5791985860418384], 
              Complex[7.615599647619973, -0.6322417704324756]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337014778473916, -0.587017135587317}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.587017135587317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63670244496346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.726765536946409`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 2, {
              Complex[9.337014778473916, -0.587017135587317], 
              Complex[7.63670244496346, -1.726765536946409]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30381233160232, 0.590495597339949}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30381233160232`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.590495597339949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 1, {
              Complex[9.30381233160232, 0.590495597339949], 
              Complex[7.615928222964842, -0.6217269966329011]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.336628388028364, -0.5983220770848237}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 2, {
              Complex[9.336628388028364, -0.5983220770848237], 
              Complex[7.636160330682661, -1.7372588918245426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304080275277004, 0.6014808784641326}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61623529799522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 1, {
              Complex[9.304080275277004, 0.6014808784641326], 
              Complex[7.61623529799522, -0.6115072877338228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.336263812328987, -0.6093151811133891}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133891`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 2, {
              Complex[9.336263812328987, -0.6093151811133891], 
              Complex[7.635641241458833, -1.7474570144780952`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304329790117844, 0.6121732527479823}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 1, {
              Complex[9.304329790117844, 0.6121732527479823], 
              Complex[7.616522978484024, -0.6015648318155971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.335918932011362, -0.6200152737048321}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.757377720274465`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 2, {
              Complex[9.335918932011362, -0.6200152737048321], 
              Complex[7.635143036145728, -1.757377720274465]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304562682970772, 0.6225897638061416}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304562682970772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.591883498403893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 1, {
              Complex[9.304562682970772, 0.6225897638061416], 
              Complex[7.616793092860657, -0.591883498403893]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.335591908744412, -0.6304394010704697}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 2, {
              Complex[9.335591908744412, -0.6304394010704697], 
              Complex[7.63466385223734, -1.7670371430158245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304780527085192, 0.6327459028649582}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 1, {
              Complex[9.304780527085192, 0.6327459028649582], 
              Complex[7.617047237536007, -0.5824486239818056]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.335281138965442, -0.6406030569368893}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335281138965442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 2, {
              Complex[9.335281138965442, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304984699340448, 0.642655799962885}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 1, {
              Complex[9.304984699340448, 0.642655799962885], 
              Complex[7.617286813480894, -0.5732468315559043]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334985216595475, -0.6505203737511223}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 2, {
              Complex[9.334985216595475, -0.6505203737511223], 
              Complex[7.633756228225985, -1.7856295196238632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305176410484558, 0.6523323858111211}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811117`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 1, {
              Complex[9.305176410484558, 0.6523323858111211], 
              Complex[7.617513055986497, -0.5642658778811117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334702902745928, -0.6602042845457754}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 2, {
              Complex[9.334702902745928, -0.6602042845457754], 
              Complex[7.633325089631603, -1.7945880998355057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30535672988259, 0.661787529645796}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.661787529645796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 1, {
              Complex[9.30535672988259, 0.661787529645796], 
              Complex[7.617727059060542, -0.5554945233226195]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334433100918964, -0.6696666607954198}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8033369326051627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 2, {
              Complex[9.334433100918964, -0.6696666607954198], 
              Complex[7.6329075211926085`, -1.8033369326051627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305526605913883, 0.6710321572939453}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 1, {
              Complex[9.305526605913883, 0.6710321572939453], 
              Complex[7.617929795566583, -0.5469224203770383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334174836562125, -0.678918430486528}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.678918430486528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445572`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 2, {
              Complex[9.334174836562125, -0.678918430486528], 
              Complex[7.632502521562483, -1.8118863682445572`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305686882893223, 0.6800763528244185}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762599`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 1, {
              Complex[9.305686882893223, 0.6800763528244185], 
              Complex[7.618122133957997, -0.5385400176762599]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333927240101856, -0.6879696797720988}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 2, {
              Complex[9.333927240101856, -0.6879696797720988], 
              Complex[7.632109194769859, -1.8202459608400856`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305838315194185, 0.6889294464957763}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 1, {
              Complex[9.305838315194185, 0.6889294464957763], 
              Complex[7.618304852267418, -0.5303384769181541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333689532777537, -0.6968297409230595}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 2, {
              Complex[9.333689532777537, -0.6968297409230595], 
              Complex[7.631726736184743, -1.8284245513261357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305981579104795, 0.697600091198504}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 1, {
              Complex[9.305981579104795, 0.697600091198504], 
              Complex[7.618478649868707, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333461014745714, -0.7055072687737806}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 2, {
              Complex[9.333461014745714, -0.7055072687737806], 
              Complex[7.6313544207148105`, -1.836430339702474]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306117282833021, 0.7060963291837468}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306117282833021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 1, {
              Complex[9.306117282833021, 0.7060963291837468], 
              Complex[7.618644157419197, -0.5144457692358487]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333241055036742, -0.714010307453912}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333241055036742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.714010307453912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 2, {
              Complex[9.333241055036742, -0.714010307453912], 
              Complex[7.630991592823768, -1.8442709480852426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306245974993525, 0.7144256505494251}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.506739885558876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 1, {
              Complex[9.306245974993525, 0.7144256505494251], 
              Complex[7.618801945306149, -0.506739885558876]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333029083032358, -0.7223463488774436}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 2, {
              Complex[9.333029083032358, -0.7223463488774436], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306368151840395, 0.7225950446980841}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 1, {
              Complex[9.306368151840395, 0.7225950446980841], 
              Complex[7.61895253085656, -0.4991853264171625]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332824581199283, -0.73052238420331}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 2, {
              Complex[9.332824581199283, -0.73052238420331], 
              Complex[7.630292075750293, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306484263458826, 0.7306110457744995}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306484263458826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457744995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518941`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49177589955866874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 1, {
              Complex[9.306484263458826, 0.7306110457744995], 
              Complex[7.619096384518941, -0.49177589955866874`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332627078865713, -0.738544949275635}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 2, {
              Complex[9.332627078865713, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30659471908804, 0.7384797729243923}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 1, {
              Complex[9.30659471908804, 0.7384797729243923], 
              Complex[7.619233935186141, -0.4845058056239242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33243614686835, -0.7464201648848556}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33243614686835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 2, {
              Complex[9.33243614686835, -0.7464201648848556], 
              Complex[7.629624038754352, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306699891715686, 0.7462069660795185}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.477369604310393`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 1, {
              Complex[9.306699891715686, 0.7462069660795185], 
              Complex[7.6193655747968485`, -0.477369604310393]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332251392929535, -0.7541537725552647}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306800122058597, 0.7537980178639988}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6194916623287705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 1, {
              Complex[9.306800122058597, 0.7537980178639988], 
              Complex[7.6194916623287705`, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332072457649629, -0.761751166453438}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62898401756861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 2, {
              Complex[9.332072457649629, -0.761751166453438], 
              Complex[7.62898401756861, -1.8882124861522425`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306895722024104, 0.7612580021246147}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.463478735776971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 1, {
              Complex[9.306895722024104, 0.7612580021246147], 
              Complex[7.619612527276207, -0.463478735776971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33189901102014, -0.7692174219206871}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 2, {
              Complex[9.33189901102014, -0.7692174219206871], 
              Complex[7.62867358157315, -1.8950718287746993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306986977730263, 0.7685916995129585}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45671472722754314`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 1, {
              Complex[9.306986977730263, 0.7685916995129585], 
              Complex[7.619728472689176, -0.45671472722754314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331730749379407, -0.776557321057196}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.776557321057196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628369089772418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 2, {
              Complex[9.331730749379407, -0.776557321057196], 
              Complex[7.628369089772418, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307074152149593, 0.7758036204842987}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307074152149593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 1, {
              Complex[9.307074152149593, 0.7758036204842987], 
              Complex[7.619839777837859, -0.4500658826848904]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331567392745953, -0.7837753757227327}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 2, {
              Complex[9.331567392745953, -0.7837753757227327], 
              Complex[7.628070244122036, -1.9084361186447754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30715748743053, 0.7828980260257021}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30715748743053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44352816261650035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 1, {
              Complex[9.30715748743053, 0.7828980260257021], 
              Complex[7.619946700555886, -0.44352816261650035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331408682475267, -0.7908758482666056}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 2, {
              Complex[9.331408682475267, -0.7908758482666056], 
              Complex[7.627776768560513, -1.914949385030405]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307237206941968, 0.7898789463823146}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4370977461047796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 1, {
              Complex[9.307237206941968, 0.7898789463823146], 
              Complex[7.620049479307305, -0.4370977461047796]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331254379194702, -0.7978627702556045}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 2, {
              Complex[9.331254379194702, -0.7978627702556045], 
              Complex[7.627488406920755, -1.9213552355525552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.3073135170789, 0.796750198013566}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3073135170789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.796750198013566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6201483350148616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4307710148004995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 1, {
              Complex[9.3073135170789, 0.796750198013566], 
              Complex[7.6201483350148616`, -0.4307710148004995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331104260978194, -0.8047399594318435}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 2, {
              Complex[9.331104260978194, -0.8047399594318435], 
              Complex[7.627204921081205, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307386608861504, 0.803515398980124}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.803515398980124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 1, {
              Complex[9.307386608861504, 0.803515398980124], 
              Complex[7.620243472681647, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.3309581217286, -0.811511035101225}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3309581217286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 2, {
              Complex[9.3309581217286, -0.811511035101225], 
              Complex[7.626926089324722, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307456659354886, 0.8101779829358519}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925703`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 1, {
              Complex[9.307456659354886, 0.8101779829358519], 
              Complex[7.62033508283309, -0.41841506119925703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330815769740232, -0.818179432126868}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307523832932748, 0.8167412118766464}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 1, {
              Complex[9.307523832932748, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330677026418373, -0.8247484136793252}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 2, {
              Complex[9.330677026418373, -0.8247484136793252], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307588282404815, 0.8232081877787769}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404815`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.406434884829246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 1, {
              Complex[9.307588282404815, 0.8232081877787769], 
              Complex[7.620508417879312, -0.406434884829246]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330541725135813, -0.8312210828762443}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 2, {
              Complex[9.330541725135813, -0.8312210828762443], 
              Complex[7.626115517858932, -1.9518936417752972`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307650150024978, 0.8295818632429405}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307650150024978`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 1, {
              Complex[9.307650150024978, 0.8295818632429405], 
              Complex[7.620590462338551, -0.4005784447793387]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330409710209448, -0.8376003934276777}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307709568394769, 0.8358650512460933}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307709568394769`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39480750301628864`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 1, {
              Complex[9.307709568394769, 0.8358650512460933], 
              Complex[7.620669620363362, -0.39480750301628864`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330280835982268, -0.8438891593891126}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330280835982268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 2, {
              Complex[9.330280835982268, -0.8438891593891126], 
              Complex[7.625594958504517, -1.9634705130965748`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307766661274705, 0.8420604340909561}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3891195161626054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.3891195161626054]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33015496599815, -0.850090064112114}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33015496599815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 2, {
              Complex[9.33015496599815, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307821544314415, 0.8481705716325338}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6208198082853045`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38351205693401635`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 1, {
              Complex[9.307821544314415, 0.8481705716325338], 
              Complex[7.6208198082853045`, -0.38351205693401635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330031972258515, -0.8562056684719375}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562056684719375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 2, {
              Complex[9.330031972258515, -0.8562056684719375], 
              Complex[7.625088793917113, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307874325710909, 0.8541979088518958}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 1, {
              Complex[9.307874325710909, 0.8541979088518958], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329911734551452, -0.8622384184423428}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 2, {
              Complex[9.329911734551452, -0.8622384184423428], 
              Complex[7.624840764016906, -1.9802187002360245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30792510680319, 0.8601447828394874}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 1, {
              Complex[9.30792510680319, 0.8601447828394874], 
              Complex[7.620959962859786, -0.3725295501957073]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329794139845038, -0.8681906520799054}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329794139845038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 2, {
              Complex[9.329794139845038, -0.8681906520799054], 
              Complex[7.624595933940285, -1.9856462614276873`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307973982610358, 0.8660134292433511}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610358`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 1, {
              Complex[9.307973982610358, 0.8660134292433511], 
              Complex[7.621026552047415, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329679081737801, -0.8740646059731706}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.9909998552070285`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308021042319385, 0.8718059882315806}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357775`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 1, {
              Complex[9.308021042319385, 0.8718059882315806], 
              Complex[7.621090949234534, -0.36184262733357775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329566459959892, -0.8798624212060274}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9962815121814683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 2, {
              Complex[9.329566459959892, -0.8798624212060274], 
              Complex[7.624115410024538, -1.9962815121814683`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308066369728037, 0.877524510013052}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 1, {
              Complex[9.308066369728037, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489176`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32945617991971, -0.8855861488792874}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 2, {
              Complex[9.32945617991971, -0.8855861488792874], 
              Complex[7.623879500326575, -2.001493177613564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308110043647691, 0.8831709599557607}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 1, {
              Complex[9.308110043647691, 0.8831709599557607], 
              Complex[7.621213533499526, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329348152291017, -0.8912377552298727}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 2, {
              Complex[9.329348152291017, -0.8912377552298727], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30815213827031, 0.888747223338151}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3463320308925905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.3463320308925905]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329242292636387, -0.8968191263829132}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 2, {
              Complex[9.329242292636387, -0.8968191263829132], 
              Complex[7.623415888441285, -2.0117139169364293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308192723503184, 0.8942551097650246}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 1, {
              Complex[9.308192723503184, 0.8942551097650246], 
              Complex[7.621328396747195, -0.3412932099060134]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329138521063246, -0.9023320727684231}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 2, {
              Complex[9.329138521063246, -0.9023320727684231], 
              Complex[7.623188002862294, -2.0167264965813105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308231865274811, 0.8996963572765849}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308231865274811`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 1, {
              Complex[9.308231865274811, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329036761909217, -0.9077783332310712}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 2, {
              Complex[9.329036761909217, -0.9077783332310712], 
              Complex[7.622962616349544, -2.0216761042737277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308269625814717, 0.9050726361762729}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 1, {
              Complex[9.308269625814717, 0.9050726361762729], 
              Complex[7.621436146769792, -0.3314026397464215]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328936943453858, -0.9131595788587066}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0265643248014458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 2, {
              Complex[9.328936943453858, -0.9131595788587066], 
              Complex[7.6227396483708265`, -2.0265643248014458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308306063909846, 0.9103855526005631}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62148752665612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 1, {
              Complex[9.308306063909846, 0.9103855526005631], 
              Complex[7.62148752665612, -0.3265477841068153]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328838997654193, -0.9184774165528231}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 2, {
              Complex[9.328838997654193, -0.9184774165528231], 
              Complex[7.622519022338055, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308341235139771, 0.9156366518516704}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 1, {
              Complex[9.308341235139771, 0.9156366518516704], 
              Complex[7.621537327849359, -0.3217512420725154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328742859901782, -0.923733392361904}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308375192092747, 0.9208274215121246}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31701160331199163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 1, {
              Complex[9.308375192092747, 0.9208274215121246], 
              Complex[7.62158560981236, -0.31701160331199163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328648468799225, -0.9289289945966068}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 2, {
              Complex[9.328648468799225, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30840798456442, 0.9259592943584083}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 1, {
              Complex[9.30840798456442, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32855576595434, -0.9340656567439877}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 2, {
              Complex[9.32855576595434, -0.9340656567439877], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308439659740834, 0.9310336510892627}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037959`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720178`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 1, {
              Complex[9.308439659740834, 0.9310336510892627], 
              Complex[7.621677839037959, -0.3076976516720178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328464695790347, -0.9391447601963724}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 2, {
              Complex[9.328464695790347, -0.9391447601963724], 
              Complex[7.621658530284445, -2.0501359962584584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30847026236711, 0.9360518228828755}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.303120767916594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 1, {
              Complex[9.30847026236711, 0.9360518228828755], 
              Complex[7.621721890926156, -0.303120767916594]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328375205370593, -0.9441676368090828}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.054685974350639`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 2, {
              Complex[9.328375205370593, -0.9441676368090828], 
              Complex[7.621448586511419, -2.054685974350639]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308499834903161, 0.9410150937958539}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 1, {
              Complex[9.308499834903161, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32828724423658, -0.9491355712999278}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 2, {
              Complex[9.32828724423658, -0.9491355712999278], 
              Complex[7.621240595073557, -2.0591841171322494`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308528417667574, 0.9459247030157981}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 1, {
              Complex[9.308528417667574, 0.9459247030157981], 
              Complex[7.621806111976445, -0.29412109620456584`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328200764258012, -0.9540498035022785}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 2, {
              Complex[9.328200764258012, -0.9540498035022785], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308556048970688, 0.9507818469782096}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 1, {
              Complex[9.308556048970688, 0.9507818469782096], 
              Complex[7.621846371329063, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328115719493919, -0.9589115304824556}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 2, {
              Complex[9.328115719493919, -0.9589115304824556], 
              Complex[7.620830251250196, -2.06802955861316]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308582765237823, 0.9555876813576086}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 1, {
              Complex[9.308582765237823, 0.9555876813576086], 
              Complex[7.621885453180955, -0.2853192553735125]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32803206606383, -0.9637219085313012}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32803206606383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 2, {
              Complex[9.32803206606383, -0.9637219085313012], 
              Complex[7.620627795708714, -2.072379088667851]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30860860112351, 0.9603433229418255}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9603433229418255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280989805362763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 1, {
              Complex[9.30860860112351, 0.9603433229418255], 
              Complex[7.621923397544282, -0.280989805362763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327949762028192, -0.9684820550389218}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 2, {
              Complex[9.327949762028192, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30863358961748, 0.9650498513977598}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30863358961748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 1, {
              Complex[9.30863358961748, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327868767277202, -0.9731930502608676}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30865776214308, 0.9697083109361541}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 1, {
              Complex[9.30865776214308, 0.9697083109361541], 
              Complex[7.6219960248466, -0.27246872803358424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327789043427424, -0.9778559389833152}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 2, {
              Complex[9.327789043427424, -0.9778559389833152], 
              Complex[7.620030720208936, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308681148648779, 0.9743197118823447}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308681148648779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9743197118823447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26827515354053166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 1, {
              Complex[9.308681148648779, 0.9743197118823447], 
              Complex[7.622030779108827, -0.26827515354053166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327710553725511, -0.9824717320942182}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308703777693308, 0.9788850321593936}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 1, {
              Complex[9.308703777693308, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327633262958448, -0.9870414080668153}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327633262958448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381359`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 2, {
              Complex[9.327633262958448, -0.9870414080668153], 
              Complex[7.619640805534103, -2.093436192381359]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308725676524938, 0.9834052186894812}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 1, {
              Complex[9.308725676524938, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774761984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327557137369855, -0.991565914361383}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308746871155384, 0.9878811887189867}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133871`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 1, {
              Complex[9.308746871155384, 0.9878811887189867], 
              Complex[7.622129200107364, -0.2559512499133871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327482144581792, -0.9960461687506839}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.101554547612181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 2, {
              Complex[9.327482144581792, -0.9960461687506839], 
              Complex[7.619257020505317, -2.101554547612181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308767386428748, 0.9923138310722677}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.25192599017451683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 1, {
              Complex[9.308767386428748, 0.9923138310722677], 
              Complex[7.62216016161569, -0.25192599017451683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327408253521732, -1.0004830605740669`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327408253521732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 2, {
              Complex[9.327408253521732, -1.0004830605740669`], 
              Complex[7.619067332909202, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30878724608588, 0.9967040073387549}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790134`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 1, {
              Complex[9.30878724608588, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327335434354206, -1.0048774519249053`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113643`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 2, {
              Complex[9.327335434354206, -1.0048774519249053`], 
              Complex[7.618879068115525, -2.109509448113643]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308806472824529, 1.0010525529976397`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327263658416845, -1.0092301787755904`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566213`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 2, {
              Complex[9.327263658416845, -1.0092301787755904`], 
              Complex[7.618692192411457, -2.113427630566213]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308825088355581, 1.0053602784840994`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327192898160455, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308843113455703, 1.0096279702007271`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 1, {
              Complex[9.308843113455703, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327123127092815, -1.0178138586055252`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1211493036241214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 2, {
              Complex[9.327123127092815, -1.0178138586055252`], 
              Complex[7.618322479547938, -2.1211493036241214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308860568016621, 1.0138563914775587`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278965`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 1, {
              Complex[9.308860568016621, 1.0138563914775587`], 
              Complex[7.622302363778045, -0.23238378615278965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327054319725958, -1.0220463622527833`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 2, {
              Complex[9.327054319725958, -1.0220463622527833`], 
              Complex[7.618139580912274, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308877471091343, 1.0180462834838342`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2285869439961421`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 1, {
              Complex[9.308877471091343, 1.0180462834838342`], 
              Complex[7.622328456276395, -0.2285869439961421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326986451526654, -1.02624030460825}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.02624030460825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 2, {
              Complex[9.326986451526654, -1.02624030460825], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308893840937472, 1.0221983660944398`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765633`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 1, {
              Complex[9.308893840937472, 1.0221983660944398`], 
              Complex[7.622353819311706, -0.22482566197765633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326919498869884, -1.0303964059906547`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 2, {
              Complex[9.326919498869884, -1.0303964059906547`], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.3089096950579, 1.026313338713697}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.026313338713697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 1, {
              Complex[9.3089096950579, 1.026313338713697], 
              Complex[7.62237847390638, -0.2210992776263989]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326853438995084, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617598369758898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.617598369758898, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308925050238992, 1.030391881059093}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308925050238992`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.030391881059093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 1, {
              Complex[9.308925050238992, 1.030391881059093], 
              Complex[7.622402440275709, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326788249964949, -1.038597865497053}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.038597865497053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 2, {
              Complex[9.326788249964949, -1.038597865497053], 
              Complex[7.617420370497285, -2.1398177654127513`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30893992258648, 1.0344346539072422`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0344346539072422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 1, {
              Complex[9.30893992258648, 1.0344346539072422`], 
              Complex[7.622425737866838, -0.21374864473986163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326723910626667, -1.0426445649584875`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288384`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 2, {
              Complex[9.326723910626667, -1.0426445649584875`], 
              Complex[7.617243530524916, -2.1434478264288384`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308954327559254, 1.0384422998042995`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 1, {
              Complex[9.308954327559254, 1.0384422998042995`], 
              Complex[7.622448385395499, -0.2101231618705584]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326660400575378, -1.0466561075785732`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326660400575378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1470448063535947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 2, {
              Complex[9.326660400575378, -1.0466561075785732`], 
              Complex[7.6170678253669655`, -2.1470448063535947`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308968280001098, 1.042415443742859}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326597700119693, -1.0506331187508067`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 2, {
              Complex[9.326597700119693, -1.0506331187508067`], 
              Complex[7.616893231354067, -2.1506092976644977`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308981794170638, 1.04635469380724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308981794170638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 1, {
              Complex[9.308981794170638, 1.04635469380724], 
              Complex[7.622491801676729, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32653579024921, -1.0545762069524505`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32653579024921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 2, {
              Complex[9.32653579024921, -1.0545762069524505`], 
              Complex[7.616719725586928, -2.1541418767841747`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308994883769515, 1.0502606417889437`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 1, {
              Complex[9.308994883769515, 1.0502606417889437`], 
              Complex[7.622512604505212, -0.1994389915497566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326474652603714, -1.0584859643603295`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 2, {
              Complex[9.326474652603714, -1.0584859643603295`], 
              Complex[7.616547285902739, -2.1576431046649516`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309007561968963, 1.0541338637739348`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.1959398257910545]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32641426944434, -1.0623629674380977`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32641426944434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6163758908436705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1611135273463344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 2, {
              Complex[9.32641426944434, -1.0623629674380977`], 
              Complex[7.6163758908436705`, -2.1611135273463344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309019841434887, 1.0579749207033111`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622552480149748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 1, {
              Complex[9.309019841434887, 1.0579749207033111`], 
              Complex[7.622552480149748, -0.1924708750021308]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326354623625985, -1.0662077774973102`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1645536764876296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 2, {
              Complex[9.326354623625985, -1.0662077774973102`], 
              Complex[7.6162055196267024`, -2.1645536764876296`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309031734351517, 1.061784358908797}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 1, {
              Complex[9.309031734351517, 1.061784358908797], 
              Complex[7.622571583494798, -0.18903162196075954`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326295698571451, -1.070020941233001}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 2, {
              Complex[9.326295698571451, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309043252443765, 1.0655627106244425`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622590149980672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 1, {
              Complex[9.309043252443765, 1.0655627106244425`], 
              Complex[7.622590149980672, -0.18562156282100895`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326237478246874, -1.0738029912355802`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309054406998326, 1.069310494475782}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 1, {
              Complex[9.309054406998326, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326179947138469, -1.0775544464801794`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 2, {
              Complex[9.326179947138469, -1.0775544464801794`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30906520888366, 1.0730282159476652`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30906520888366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 1, {
              Complex[9.30906520888366, 1.0730282159476652`], 
              Complex[7.622625727731573, -0.1788870749784164]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326123090230514, -1.081275812794643}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 2, {
              Complex[9.326123090230514, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30907566856886, 1.0767163678318636`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 1, {
              Complex[9.30907566856886, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326066892984452, -1.0849675833073056`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326066892984452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 2, {
              Complex[9.326066892984452, -1.0849675833073056`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30908579614155, 1.0803754306555198`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30908579614155`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6226593194281556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 1, {
              Complex[9.30908579614155, 1.0803754306555198`], 
              Complex[7.6226593194281556`, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32601134131908, -1.088630238875599}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.088630238875599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 2, {
              Complex[9.32601134131908, -1.088630238875599], 
              Complex[7.615203707337714, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309095601324776, 1.0840058730914184`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053758934`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 1, {
              Complex[9.309095601324776, 1.0840058730914184`], 
              Complex[7.622675401692968, -0.16899242053758934`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325956421591755, -1.0922642484964789`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61503997217078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1878289257658756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 2, {
              Complex[9.325956421591755, -1.0922642484964789`], 
              Complex[7.61503997217078, -2.1878289257658756`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309105093493066, 1.087608152351}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 1, {
              Complex[9.309105093493066, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325902120580537, -1.0958700696995953`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 2, {
              Complex[9.325902120580537, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309114281687616, 1.0911827145610276`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 1, {
              Complex[9.309114281687616, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325848425467223, -1.0994481489240941`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 2, {
              Complex[9.325848425467223, -1.0994481489240941`], 
              Complex[7.614715122272787, -2.1942339326893823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309123174630704, 1.0947299951246658`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809695`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 1, {
              Complex[9.309123174630704, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809695`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325795323821204, -1.102998921879825}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325795323821204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102998921879825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 2, {
              Complex[9.325795323821204, -1.102998921879825], 
              Complex[7.614553976335034, -2.1973977605017105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309131780739364, 1.0982504190677982`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739364`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62273524336523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 1, {
              Complex[9.309131780739364, 1.0982504190677982`], 
              Complex[7.62273524336523, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325742803584207, -1.1065228138938534`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.200536344647329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 2, {
              Complex[9.325742803584207, -1.1065228138938534`], 
              Complex[7.614393662996275, -2.200536344647329]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309140108138353, 1.1017444013712938`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788943`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32569085305561, -1.1100202402427715`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32569085305561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 2, {
              Complex[9.32569085305561, -1.1100202402427715`], 
              Complex[7.614234167722326, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309148164672498, 1.1052123472899036`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 1, {
              Complex[9.309148164672498, 1.1052123472899036`], 
              Complex[7.622762622058505, -0.14990570004738188`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325639460878644, -1.113491606471821}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113491606471821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61407547637812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003824`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 2, {
              Complex[9.325639460878644, -1.113491606471821], 
              Complex[7.61407547637812, -2.206739345003824]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30915595791838, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30915595791838`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 1, {
              Complex[9.30915595791838, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325588616027114, -1.1169373087011036`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087011036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953604`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 2, {
              Complex[9.325588616027114, -1.1169373087011036`], 
              Complex[7.613917575212904, -2.209804519953604]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309163495195483, 1.112071704185835}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 1, {
              Complex[9.309163495195483, 1.112071704185835], 
              Complex[7.622788412421259, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325538307792806, -1.1203577339198192`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6137604508462084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 2, {
              Complex[9.325538307792806, -1.1203577339198192`], 
              Complex[7.6137604508462084`, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309170783576755, 1.11546387973771}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155678`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325488525773522, -1.123753260268964}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123753260268964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 2, {
              Complex[9.325488525773522, -1.123753260268964], 
              Complex[7.613604090254429, -2.215864050835693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30917782989869, 1.1188315486078975`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30917782989869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 1, {
              Complex[9.30917782989869, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325439259861604, -1.1271242573129165`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 2, {
              Complex[9.325439259861604, -1.1271242573129165`], 
              Complex[7.613448480758027, -2.2188591143084158`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309184640770896, 1.1221750717795362`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13466520641404972`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.13466520641404972`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325390500232961, -1.1304710863006697`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 2, {
              Complex[9.325390500232961, -1.1304710863006697`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309191222585207, 1.1254948021761504`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438924218`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 1, {
              Complex[9.309191222585207, 1.1254948021761504`], 
              Complex[7.622835518377009, -0.13168534438924218`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32534223733676, -1.1337941004170398`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 2, {
              Complex[9.32534223733676, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309197581524451, 1.1287910849032745`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 1, {
              Complex[9.309197581524451, 1.1287910849032745`], 
              Complex[7.6228464119461155`, -0.12872744888532286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325294461885356, -1.1370936450243199`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 2, {
              Complex[9.325294461885356, -1.1370936450243199`], 
              Complex[7.612986036952771, -2.227709576352395]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309203723570544, 1.1320642574808069`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420297`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 1, {
              Complex[9.309203723570544, 1.1320642574808069`], 
              Complex[7.622856968249287, -0.12579120077420297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325247164844852, -1.140370057894864}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 2, {
              Complex[9.325247164844852, -1.140370057894864], 
              Complex[7.612833311505916, -2.2306159102625114`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309209654512552, 1.1353146500669171`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669171`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790969447`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 1, {
              Complex[9.309209654512552, 1.1353146500669171`], 
              Complex[7.622867194825836, -0.12287628790969447`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325200337425992, -1.1436236694349757`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309215379954185, 1.1385425856735323`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294204`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 1, {
              Complex[9.309215379954185, 1.1385425856735323`], 
              Complex[7.622877098993824, -0.11998240492294204`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325153971075478, -1.146854802900513}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146854802900513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 2, {
              Complex[9.325153971075478, -1.146854802900513], 
              Complex[7.612529927102651, -2.236364734026166]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309220905320855, 1.141748380373843}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.141748380373843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1171092530254299`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 1, {
              Complex[9.309220905320855, 1.141748380373843], 
              Complex[7.6228866878581005`, -0.1171092530254299]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325108057467666, -1.1500637746045623`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30922623586666, 1.1449323435024106`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902048`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32506258849663, -1.1532508941175421`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32506258849663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 2, {
              Complex[9.32506258849663, -1.1532508941175421`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309231376680849, 1.1480947778478907`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309231376680849`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075781`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 1, {
              Complex[9.309231376680849, 1.1480947778478907`], 
              Complex[7.622904947075781, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32501755626854, -1.1564164644600665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32501755626854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 2, {
              Complex[9.32501755626854, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30923633269408, 1.151235979838898}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923633269408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761455`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 1, {
              Complex[9.30923633269408, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324972953094393, -1.1595607822888858`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 2, {
              Complex[9.324972953094393, -1.1595607822888858`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309241108684372, 1.1543562397232365`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1543562397232365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396872`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 1, {
              Complex[9.309241108684372, 1.1543562397232365`], 
              Complex[7.622922025342652, -0.10581820042396872`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324928771483046, -1.1626841380761952`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324928771483046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 2, {
              Complex[9.324928771483046, -1.1626841380761952`], 
              Complex[7.611783032412529, -2.2503781883626597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309245709282818, 1.1574558417407832`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324885004134526, -1.165786816282607}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25312166167618`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 2, {
              Complex[9.324885004134526, -1.165786816282607], 
              Complex[7.611635557076614, -2.25312166167618]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309250138979014, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 1, {
              Complex[9.309250138979014, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324841643933636, -1.168869095524048}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 2, {
              Complex[9.324841643933636, -1.168869095524048], 
              Complex[7.611488694403536, -2.2558460236218125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309254402126268, 1.1635941800904988`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800904988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922041178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 1, {
              Complex[9.309254402126268, 1.1635941800904988`], 
              Complex[7.622945536900375, -0.09755385922041178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324798683943808, -1.171931248732842}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.171931248732842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2585515322335588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 2, {
              Complex[9.324798683943808, -1.171931248732842], 
              Complex[7.611342435457713, -2.2585515322335588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309258502946616, 1.1666334563353578`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 1, {
              Complex[9.309258502946616, 1.1666334563353578`], 
              Complex[7.622952835953342, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324756117401229, -1.1749735433132202`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 2, {
              Complex[9.324756117401229, -1.1749735433132202`], 
              Complex[7.611196771510029, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309262445535504, 1.1696531548443265`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309262445535504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62295987523472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438433`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 1, {
              Complex[9.309262445535504, 1.1696531548443265`], 
              Complex[7.62295987523472, -0.09213750902438433]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324713937709186, -1.1779962412914937`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.263906995519419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 2, {
              Complex[9.324713937709186, -1.1779962412914937`], 
              Complex[7.611051694031386, -2.263906995519419]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309266233866465, 1.1726535322072738`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866465`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745505`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 1, {
              Complex[9.309266233866465, 1.1726535322072738`], 
              Complex[7.622966660095128, -0.08945655490745505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324672138432643, -1.1809995994611011`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1809995994611011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6109071946864875`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 2, {
              Complex[9.324672138432643, -1.1809995994611011`], 
              Complex[7.6109071946864875`, -2.2665574406124445`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309269871795374, 1.1756348399245427`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 1, {
              Complex[9.309269871795374, 1.1756348399245427`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32463071329305, -1.1839838695227543`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1839838695227543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 2, {
              Complex[9.32463071329305, -1.1839838695227543`], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309273363064712, 1.1785973245423351`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 1, {
              Complex[9.309273363064712, 1.1785973245423351`], 
              Complex[7.622979487241573, -0.0841479006964719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324589656163335, -1.1869492982198684`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2718049473202555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 2, {
              Complex[9.324589656163335, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.2718049473202555`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309276711307533, 1.1815412277835529`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 1, {
              Complex[9.309276711307533, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306795]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324548961063108, -1.1898961274694762`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 2, {
              Complex[9.324548961063108, -1.1898961274694762`], 
              Complex[7.610477084885046, -2.274402470753615]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309279920051317, 1.1844667866743102`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051317`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 1, {
              Complex[9.309279920051317, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32450862215405, -1.1928245944888058`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32450862215405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 2, {
              Complex[9.32450862215405, -1.1928245944888058`], 
              Complex[7.610334818394682, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309282992721648, 1.187374233666283}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309282992721648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.187374233666283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229969455576505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 1, {
              Complex[9.309282992721648, 1.187374233666283], 
              Complex[7.6229969455576505`, -0.07631462931689799]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32446863373548, -1.195734931917687}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.610193091068046, -2.2795461787176907`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309285932645754, 1.190263796755059}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.190263796755059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672779`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 1, {
              Complex[9.309285932645754, 1.190263796755059], 
              Complex[7.623002308533652, -0.07373724565672779]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324428990240092, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.282092798668853]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309288743055877, 1.1931356995946463`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055877`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1931356995946463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 1, {
              Complex[9.309288743055877, 1.1931356995946463`], 
              Complex[7.623007450776046, -0.07117636000425366]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32438968622985, -1.2015021263830652`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 2, {
              Complex[9.32438968622985, -1.2015021263830652`], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309291427092525, 1.1959901616082877`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 1, {
              Complex[9.309291427092525, 1.1959901616082877`], 
              Complex[7.623012376610668, -0.06863176520228129]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324350716392054, -1.2043594268588766`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609771071949929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 2, {
              Complex[9.324350716392054, -1.2043594268588766`], 
              Complex[7.609771071949929, -2.2871366280006606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309293987807608, 1.19882739809574}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154555`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 1, {
              Complex[9.309293987807608, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324312075535534, -1.207199484841066}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.207199484841066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 2, {
              Complex[9.324312075535534, -1.207199484841066], 
              Complex[7.609631429922362, -2.2896342483960757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309296428167407, 1.201647620337122}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214552`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 1, {
              Complex[9.309296428167407, 1.201647620337122], 
              Complex[7.623021595813279, -0.06359063896214552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324273758587012, -1.210022511784006}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 2, {
              Complex[9.324273758587012, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30929875105546, 1.204451035693495}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30929875105546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230258972966505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 1, {
              Complex[9.30929875105546, 1.204451035693495], 
              Complex[7.6230258972966505`, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324235760587548, -1.2128287152203794`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432069`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 2, {
              Complex[9.324235760587548, -1.2128287152203794`], 
              Complex[7.609353652021753, -2.294581899432069]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30930095927532, 1.2072378477042842`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324198076689214, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689214`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 2, {
              Complex[9.324198076689214, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309303055553212, 1.2100082561816612`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.056146171569541894`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 1, {
              Complex[9.309303055553212, 1.2100082561816612`], 
              Complex[7.6230339035616055`, -0.056146171569541894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324160702151756, -1.218391462677644}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 2, {
              Complex[9.324160702151756, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309305042540567, 1.2127624573020028`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 1, {
              Complex[9.309305042540567, 1.2127624573020028`], 
              Complex[7.623037615868166, -0.05369518368470517]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324123632339496, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30930692281649, 1.2155006436945393`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 1, {
              Complex[9.30930692281649, 1.2155006436945393`], 
              Complex[7.623041139153995, -0.051259140663536915`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324086862718293, -1.2238893126698194`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 2, {
              Complex[9.324086862718293, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309308698890094, 1.2182230045272866`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32405038885261, -1.2266143809612577`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 2, {
              Complex[9.32405038885261, -1.2266143809612577`], 
              Complex[7.608667696724579, -2.30668231891301]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30931037320279, 1.2209297255903706`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931037320279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.046431178463023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 1, {
              Complex[9.30931037320279, 1.2209297255903706`], 
              Complex[7.6230476327242, -0.046431178463023]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324014206402692, -1.2293237938391435`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 2, {
              Complex[9.324014206402692, -1.2293237938391435`], 
              Complex[7.608531912472353, -2.3090578022545656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309311948130448, 1.2236209893768368`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323978311121861, -1.232017733951226}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 2, {
              Complex[9.323978311121861, -1.232017733951226], 
              Complex[7.608396583634034, -2.311418828492421]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309313425985488, 1.2262969751610369`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313425985488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 1, {
              Complex[9.309313425985488, 1.2262969751610369`], 
              Complex[7.623053411554654, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323942698853871, -1.2346963807243225`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.313765567006709`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.313765567006709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309314809018923, 1.2289578590746733`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048871`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 1, {
              Complex[9.309314809018923, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.03929696187048871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32390736553039, -1.2373599104404134`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32390736553039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 2, {
              Complex[9.32390736553039, -1.2373599104404134`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309316099422274, 1.2316038141805974`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641019`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 1, {
              Complex[9.309316099422274, 1.2316038141805974`], 
              Complex[7.623058501641019, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32387230716855, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32387230716855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607993274469599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 2, {
              Complex[9.32387230716855, -1.2400084963104758`], 
              Complex[7.607993274469599, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309317299329456, 1.2342350105444317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329456`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 1, {
              Complex[9.309317299329456, 1.2342350105444317`], 
              Complex[7.623060796195635, -0.03461069652302155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323837519868583, -1.2426423085461482`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3207217057230576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 2, {
              Complex[9.323837519868583, -1.2426423085461482`], 
              Complex[7.607859712684853, -2.3207217057230576`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309318410818571, 1.2368516153040956`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318410818571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306292776762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03228804631048228`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 1, {
              Complex[9.309318410818571, 1.2368516153040956`], 
              Complex[7.62306292776762, -0.03228804631048228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323802999811543, -1.2452615144292976`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 2, {
              Complex[9.323802999811543, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319435913643, 1.2394537927373113`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913643`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 1, {
              Complex[9.309319435913643, 1.2394537927373113`], 
              Complex[7.623064899277237, -0.02997884362362627]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323768743257098, -1.2478662783795624`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323768743257098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 2, {
              Complex[9.323768743257098, -1.2478662783795624`], 
              Complex[7.607593869964681, -2.3252906672740603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309320376586303, 1.2420417043271579`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 1, {
              Complex[9.309320376586303, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32373474654141, -1.2504567620199434`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32373474654141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 2, {
              Complex[9.32373474654141, -1.2504567620199434`], 
              Complex[7.60746157901877, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309321234757375, 1.2446155088257418`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757375`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02540017436427092`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 1, {
              Complex[9.309321234757375, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323701006075066, -1.2530331242405153`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 2, {
              Complex[9.323701006075066, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932201229845, 1.247175362316048}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.02313041096772899`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 1, {
              Complex[9.30932201229845, 1.247175362316048], 
              Complex[7.623069881638048, -0.02313041096772899]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323667518341093, -1.2555955212603065`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 2, {
              Complex[9.323667518341093, -1.2555955212603065`], 
              Complex[7.607198233627162, -2.3320444906306093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309322711033376, 1.24972141827203}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.24972141827203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 1, {
              Complex[9.309322711033376, 1.24972141827203], 
              Complex[7.623071240785351, -0.020873501333081253`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323634279893042, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.334269792192463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.334269792192463]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323332739696, 1.2522538276170252`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01862930319811999`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 1, {
              Complex[9.309323332739696, 1.2522538276170252`], 
              Complex[7.623072453501176, -0.01862930319811999]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323601287353112, -1.260679031577555}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 2, {
              Complex[9.323601287353112, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323879150053, 1.2547727387804997`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 1, {
              Complex[9.309323879150053, 1.2547727387804997`], 
              Complex[7.623073522330235, -0.016397676662069066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323568537410361, -1.2632004444906193`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324351953515, 1.2572782977532329`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 1, {
              Complex[9.309324351953515, 1.2572782977532329`], 
              Complex[7.623074449760662, -0.014178484133222693`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323536026818966, -1.265708491546124}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.265708491546124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 2, {
              Complex[9.323536026818966, -1.265708491546124], 
              Complex[7.606676358179671, -2.3408697735514434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324752796897, 1.2597706481409683`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796897`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278046269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 1, {
              Complex[9.309324752796897, 1.2597706481409683`], 
              Complex[7.62307523822562, -0.011971590278046269`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323503752396528, -1.2682033164767694`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 2, {
              Complex[9.323503752396528, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325083285962, 1.2622499312165716`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307589010475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 1, {
              Complex[9.309325083285962, 1.2622499312165716`], 
              Complex[7.62307589010475, -0.00977686197169255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323471711022448, -1.2706850606806677`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 2, {
              Complex[9.323471711022448, -1.2706850606806677`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325344986703, 1.2647162859707828`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 1, {
              Complex[9.309325344986703, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323439899636348, -1.2731538632721078`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2731538632721078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 2, {
              Complex[9.323439899636348, -1.2731538632721078`], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325539426466, 1.2671698491615675`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325539426466`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076793365634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261941976`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 1, {
              Complex[9.309325539426466, 1.2671698491615675`], 
              Complex[7.623076793365634, -0.005423380261941976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323408315236538, -1.2756098611309443`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 2, {
              Complex[9.323408315236538, -1.2756098611309443`], 
              Complex[7.606160666446716, -2.349497677693729]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325668095038, 1.2696107553621172`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255545658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 1, {
              Complex[9.309325668095038, 1.2696107553621172`], 
              Complex[7.623077049252295, -0.0032643712255545658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323376954878531, -1.2780531889506412`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325732445826, 1.2720391370076067`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821179458`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 1, {
              Complex[9.309325732445826, 1.2720391370076067`], 
              Complex[7.623077177565682, -0.0011170163821179458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323345815673619, -1.280483979285027}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.280483979285027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 2, {
              Complex[9.323345815673619, -1.280483979285027], 
              Complex[7.605905055360047, -2.3537402377206167`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325733896824, 1.2744551244406346`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32331489478747, -1.282902362593793}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325673831674, 1.2768588459554961`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985720384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.0031432198985720384`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323284189438796, -1.2853084672867794`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 2, {
              Complex[9.323284189438796, -1.2853084672867794`], 
              Complex[7.605650891587858, -2.3579365364447975`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932555360063, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076818174038`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.623076818174038, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323253696898023, -1.2877024197670905`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605524342857891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 2, {
              Complex[9.323253696898023, -1.2877024197670905`], 
              Complex[7.605524342857891, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325374521514, 1.2816299944237621`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325374521514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080136`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 1, {
              Complex[9.309325374521514, 1.2816299944237621`], 
              Complex[7.623076457080136, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323223414486042, -1.2900843444730694`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323223414486042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 2, {
              Complex[9.323223414486042, -1.2900843444730694`], 
              Complex[7.605398144582299, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325137880622, 1.2839976681063674`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323193339572983, -1.2924543639191772`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 2, {
              Complex[9.323193339572983, -1.2924543639191772`], 
              Complex[7.605272293102371, -2.3641463383176777`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324844933625, 1.2863535694098465`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933625`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 1, {
              Complex[9.309324844933625, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323163469577015, -1.2948125987358021`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 2, {
              Complex[9.323163469577015, -1.2948125987358021`], 
              Complex[7.605146784820534, -2.366194163693252]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324496906415, 1.2886978170110814`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323133801963195, -1.2971591677080445`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 2, {
              Complex[9.323133801963195, -1.2971591677080445`], 
              Complex[7.605021616198947, -2.3682311227994646`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324094995942, 1.2910305277808343`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491239`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 1, {
              Complex[9.309324094995942, 1.2910305277808343`], 
              Complex[7.62307385820537, 0.01565660770491239]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323104334242323, -1.2994941878134683`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 2, {
              Complex[9.323104334242323, -1.2994941878134683`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323640371002, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371002`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485552187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 1, {
              Complex[9.309323640371002, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485552187`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323075063969917, -1.3018177742589643`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323075063969917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 2, {
              Complex[9.323075063969917, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323134173038, 1.2956617974980966`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 1, {
              Complex[9.309323134173038, 1.2956617974980966`], 
              Complex[7.623071891969078, 0.019741634295235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323045988745086, -1.3041300405165714`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 2, {
              Complex[9.323045988745086, -1.3041300405165714`], 
              Complex[7.604648113785146, -2.3742778964006517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309322577516866, 1.2979605814829254`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 1, {
              Complex[9.309322577516866, 1.2979605814829254`], 
              Complex[7.623070748363669, 0.021768489241138642`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323017106209537, -1.3064310983584466`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 2, {
              Complex[9.323017106209537, -1.3064310983584466`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309321971491421, 1.300248278779899}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491421`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 1, {
              Complex[9.309321971491421, 1.300248278779899], 
              Complex[7.623069500037889, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322988414046595, -1.3087210578909663`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 2, {
              Complex[9.322988414046595, -1.3087210578909663`], 
              Complex[7.604400748184572, -2.3782567241904515`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309321317160448, 1.3025249977626074`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321317160448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 1, {
              Complex[9.309321317160448, 1.3025249977626074`], 
              Complex[7.623068148652342, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322959909980197, -1.311000027587925}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.311000027587925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3802307429008644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 2, {
              Complex[9.322959909980197, -1.311000027587925], 
              Complex[7.604277546409373, -2.3802307429008644`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309320615563188, 1.3047908452057133`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 1, {
              Complex[9.309320615563188, 1.3047908452057133`], 
              Complex[7.623066695834459, 0.027787658535467812`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322931591774001, -1.313268114322925}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591774001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.313268114322925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873831`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 2, {
              Complex[9.322931591774001, -1.313268114322925], 
              Complex[7.604154661093246, -2.382194632873831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319867715043, 1.3070459263165173`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145831`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 1, {
              Complex[9.309319867715043, 1.3070459263165173`], 
              Complex[7.623065143179328, 0.02977391807145831]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32290345723042, -1.3155254234009868`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 2, {
              Complex[9.32290345723042, -1.3155254234009868`], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319074608206, 1.3092903447657454`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250482`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 1, {
              Complex[9.309319074608206, 1.3092903447657454`], 
              Complex[7.623063492250482, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322875504189797, -1.3177720585893213`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 2, {
              Complex[9.322875504189797, -1.3177720585893213`], 
              Complex[7.603909827464783, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309318237212286, 1.3115242027175686`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3115242027175686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306174458069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0337168292677788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 1, {
              Complex[9.309318237212286, 1.3115242027175686`], 
              Complex[7.62306174458069, 0.0337168292677788]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322847730529492, -1.320008122147406}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.320008122147406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 2, {
              Complex[9.322847730529492, -1.320008122147406], 
              Complex[7.603787873086824, -2.388026514879854]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309317356474935, 1.3137476008589233`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474935`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672728`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 1, {
              Complex[9.309317356474935, 1.3137476008589233`], 
              Complex[7.623059901672728, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32282013416307, -1.32223371485628}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32282013416307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 2, {
              Complex[9.32282013416307, -1.32223371485628], 
              Complex[7.6036662230346, -2.3899508672515015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309316433322346, 1.3159606384280351`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 1, {
              Complex[9.309316433322346, 1.3159606384280351`], 
              Complex[7.623057965000035, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32279271303949, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309315468659921, 1.3181634132423616`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459821`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 1, {
              Complex[9.309315468659921, 1.3181634132423616`], 
              Complex[7.623055936007519, 0.03955859731459821]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322765465142302, -1.326653883629291}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309314463372752, 1.3203560217257764`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314463372752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 1, {
              Complex[9.309314463372752, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322738388488887, -1.3288486541172815`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 2, {
              Complex[9.322738388488887, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309313418326166, 1.3225385589351388`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313418326166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 1, {
              Complex[9.309313418326166, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322711481129712, -1.3310333426575822`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6031826084226255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.397552720648037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 2, {
              Complex[9.322711481129712, -1.3310333426575822`], 
              Complex[7.6031826084226255`, -2.397552720648037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309312334366247, 1.3247111185862175`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.045315447506474364`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322684741147608, -1.33320804305447}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33320804305447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 2, {
              Complex[9.322684741147608, -1.33320804305447], 
              Complex[7.603062437136174, -2.3994297460778835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309311212320322, 1.326873793079005}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 1, {
              Complex[9.309311212320322, 1.326873793079005], 
              Complex[7.623046924775061, 0.04721594120841103]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322658166657, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 2, {
              Complex[9.322658166657, -1.3353728477954119`], 
              Complex[7.602942553331129, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309310052997452, 1.329026673522427}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.329026673522427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 1, {
              Complex[9.309310052997452, 1.329026673522427], 
              Complex[7.623044454903902, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322631755803354, -1.3375278480757078`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480757078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 2, {
              Complex[9.322631755803354, -1.3375278480757078`], 
              Complex[7.602822954346457, -2.403156285196984]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->900,
      Method->{"AxesInFront" -> False},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.795162677796044, -2.1401483895470963`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375925, -0.6433017314670852], 
              Complex[1.795162677796044, -2.1401483895470963`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.196232266214944, -1.1633793876684915`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0066450711378179496`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.0066450711378179496`], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8301368298409655`, -2.11202118197195}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792947959`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.11202118197195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665043, -0.6165221792947959], 
              Complex[1.8301368298409655`, -2.11202118197195]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.155525231634676, -1.163378148560237}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00671251078585357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163378148560237`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.00671251078585357], 
              Complex[6.155525231634676, -1.163378148560237]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8593666135298337`, -2.0894057490922253`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.595285574569809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922253`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127985, -0.595285574569809], 
              Complex[1.8593666135298337`, -2.0894057490922253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.122517060306257, -1.1633711130594218`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047818], 
              Complex[6.122517060306257, -1.1633711130594218`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8852354657886532`, -2.0700333477056208`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234363, -0.5773156862277907], 
              Complex[1.8852354657886532`, -2.0700333477056208`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.093988110787665, -1.1633606215314773`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850741, 0.006863336573144883], 
              Complex[6.093988110787665, -1.1633606215314773`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.908828689419146, -2.0528681311196006`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8130202409023957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.8130202409023957, -0.5615718710865845], 
              Complex[1.908828689419146, -2.0528681311196006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0684753004536836`, -1.163347697400969}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5690366318402065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006943461497604819`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0684753004536836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.5690366318402065`, 0.006943461497604819], 
              Complex[6.0684753004536836`, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9307493118589263`, -2.037333072756488}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.83517014589239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756488`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.83517014589239, -0.5474736791133894], 
              Complex[1.9307493118589263`, -2.037333072756488]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.045167287063116, -1.1633328856106508`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871677], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9513735684640645`, -2.023067278104826}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104826`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628716, -0.5346576120369374], 
              Complex[1.9513735684640645`, -2.023067278104826]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.023558855884934, -1.163316510563181}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.525314237109773`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162857`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.525314237109773, 0.007110298008162857], 
              Complex[6.023558855884934, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.970954950697273, -2.0098270287962983`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5228778864146406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0098270287962983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593915, -0.5228778864146406], 
              Complex[1.970954950697273, -2.0098270287962983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0033102912691545`, -1.163298779461846}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880171`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880171], 
              Complex[6.0033102912691545`, -1.163298779461846]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9896739101964118`, -1.9974384540079664`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906647, -0.5119589442981474], 
              Complex[1.9896739101964118`, -1.9974384540079664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.984180253839811, -1.1632798309089607`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243443], 
              Complex[5.984180253839811, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0076643409453063`, -1.9857722832958535`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.501770106216405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522133, -0.501770106216405], 
              Complex[2.0076643409453063`, -1.9857722832958535`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.965990045977095, -1.1632597604074917`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884142`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256355`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884142, 0.007373913179256355], 
              Complex[5.965990045977095, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0250288646775303`, -1.9747292562304528`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.930079710208937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304528`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.930079710208937, -0.4922109148816922], 
              Complex[2.0250288646775303`, -1.9747292562304528`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.948603001807254, -1.1632386348616004`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252032765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348616004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155933, 0.007464952252032765], 
              Complex[5.948603001807254, -1.1632386348616004`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0418482129451156`, -1.9642311559465848`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4832021231088814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089915, -0.4832021231088814], 
              Complex[2.0418482129451156`, -1.9642311559465848`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.931911846413441, -1.1632165013453943`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4366908876556685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007557496991161311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413441`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.4366908876556685`, 0.007557496991161311], 
              Complex[5.931911846413441, -1.1632165013453943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.058187273894045, -1.9542150231143454`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.474679874998177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078034, -0.474679874998177], 
              Complex[2.058187273894045, -1.9542150231143454`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.915830554816421, -1.1631933926704505`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937319, 0.007651524322599274], 
              Complex[5.915830554816421, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.074099147574047, -1.944629270704492}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460459`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460459, -0.46659179640833626`], 
              Complex[2.074099147574047, -1.944629270704492]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.900288896133163, -1.1631693310632698`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157199403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632698`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063905, 0.007747021157199403], 
              Complex[5.900288896133163, -1.1631693310632698`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0896279570988043`, -1.9354309873904443`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926869`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926869, -0.45889427989730996`], 
              Complex[2.0896279570988043`, -1.9354309873904443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.885228654304802, -1.1631443306747422`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143665`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143665, 0.007843982012263393], 
              Complex[5.885228654304802, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1048108525831095`, -1.9265840128958296`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.451550545734929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806892, -0.451550545734929], 
              Complex[2.1048108525831095`, -1.9265840128958296`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.870600935988342, -1.1631183993398435`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351017726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837107, 0.007942407351017726], 
              Complex[5.870600935988342, -1.1631183993398435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.119679474265543, -1.9180575310211605`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0245343135360971`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4445292235923789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9180575310211605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.0245343135360971`, -0.4445292235923789], 
              Complex[2.119679474265543, -1.9180575310211605`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.856364206404795, -1.1630915398400685`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.008042302396705217], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1342610431682965`, -1.9098250195461772`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885548`, -0.43780329333443585`], 
              Complex[2.1342610431682965`, -1.9098250195461772`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.842482826256842, -1.1630637508268276`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233518`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233518], 
              Complex[5.842482826256842, -1.1630637508268276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1485791890132715`, -1.9018634521265014`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949334917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1485791890132715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9018634521265014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791166`, -0.43134927949334917`], 
              Complex[2.1485791890132715`, -1.9018634521265014`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.828925941917193, -1.1630350275077863`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654023`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353645, 0.008246541346654023], 
              Complex[5.828925941917193, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1626545888502196`, -1.8941526819126024`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4251466287655521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468016`, -0.4251466287655521], 
              Complex[2.1626545888502196`, -1.8941526819126024`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.815666629983416, -1.1630053621640015`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3254146624079155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00835091278661437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.3254146624079155`, 0.00835091278661437], 
              Complex[5.815666629983416, -1.1630053621640015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1765054667524413`, -1.8866749586802056`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41917722203755886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495677`, -0.41917722203755886`], 
              Complex[2.1765054667524413`, -1.8866749586802056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.802681228429218, -1.1629747445437835`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008456808164000539`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.008456808164000539], 
              Complex[5.802681228429218, -1.1629747445437835`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.19014798983231, -1.8794145456947622`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4134249869532397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739511`, -0.4134249869532397], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.789948806930199, -1.1629431621652235`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411546`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411546], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.203596585722579, -1.8723574121967346`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.407875586750141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145416, -0.407875586750141], 
              Complex[2.203596585722579, -1.8723574121967346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.777450742552285, -1.162910600549928}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2891080693657475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008673251522090974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.2891080693657475`, 0.008673251522090974], 
              Complex[5.777450742552285, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.216864199765705, -1.8654909840009626`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.120414946688531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.402516167736111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.120414946688531, -0.402516167736111], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.765170376285118, -1.162877043404163}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995704], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2299625053481065`, -1.8588039393045297`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568053`, -0.39733515240586287`], 
              Complex[2.2299625053481065`, -1.8588039393045297`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.75309273236891, -1.1628424727592266`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349859014`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349859014], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2429020774149047`, -1.8522860400567263`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326723`, -0.3923220684765708], 
              Complex[2.2429020774149047`, -1.8522860400567263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.741204286938841, -1.1628068690797766`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2547977983402`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033198`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.2547977983402, 0.009009898497033198], 
              Complex[5.741204286938841, -1.1628068690797766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2556925367556304`, -1.8459279915891427`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396098`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396098`, -0.38746740648134814`], 
              Complex[2.2556925367556304`, -1.8459279915891427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.729492775798816, -1.162770211346653}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990407], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2683426708688654`, -1.839721324914159}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3827625002813666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155868`, -0.3827625002813666], 
              Complex[2.2683426708688654`, -1.839721324914159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.717947033532342, -1.1627324771191423`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842194`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694922, 0.009242627557842194], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.280860535897551, -1.8336582973639242`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3781994261302764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728415`, -0.3781994261302764], 
              Complex[2.280860535897551, -1.8336582973639242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.706556857926958, -1.1626936425804282`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391628], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.29325354314301, -1.8277318081869505`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37377091687665037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.29325354314301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791765`, -0.37377091687665037`], 
              Complex[2.29325354314301, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.695312895009786, -1.162653682569163}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988769`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555507, 0.009482273153988769], 
              Complex[5.695312895009786, -1.162653682569163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.30552853292255, -1.8219353264340092`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3694702886103212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.3694702886103212], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.684206540989641, -1.1626125705993822`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122507`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122507], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.317691837968342, -1.8162628290107483`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862784`], 
              Complex[2.317691837968342, -1.8162628290107483`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.67322985816244, -1.1625702788705319`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121803`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121803], 
              Complex[5.67322985816244, -1.1625702788705319`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.329749338128146, -1.8107087471951673`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418302`, -0.3612284858628572], 
              Complex[2.329749338128146, -1.8107087471951673`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.662375502422984, -1.1625267782689677`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1805979393900845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009855291843704473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.1805979393900845`, 0.009855291843704473], 
              Complex[5.662375502422984, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3417065077888246`, -1.8052679202454813`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35727633379543633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.35727633379543633`], 
              Complex[2.3417065077888246`, -1.8052679202454813`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.651636660481891, -1.1624820383620078`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384774], 
              Complex[5.651636660481891, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.353568457177236, -1.7999355549805414`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2531443542465808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.353430019037376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7999355549805414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.2531443542465808`, -0.353430019037376], 
              Complex[2.353568457177236, -1.7999355549805414`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.6410069952433215`, -1.1624360273853818`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967315`], 
              Complex[5.6410069952433215`, -1.1624360273853818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3653399684829126`, -1.7947071904178582`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034030016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377347`, -0.34968498034030016`], 
              Complex[2.3653399684829126`, -1.7947071904178582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.630480598081045, -1.1623887122247345`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.150737416691642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.150737416691642, 0.010245449802525817`], 
              Complex[5.630480598081045, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3770255275795718`, -1.7895786667158646`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2756573571094836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34603696586050614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.2756573571094836`, -0.34603696586050614`], 
              Complex[2.3770255275795718`, -1.7895786667158646`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.620051946974447, -1.1623400583917027`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040011], 
              Complex[5.620051946974447, -1.1623400583917027`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3886293519885573`, -1.784546097796433}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2867655571559535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3424820051832389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.784546097796433`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.2867655571559535`, -0.3424820051832389], 
              Complex[2.3886293519885573`, -1.784546097796433]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.609715869645587, -1.1622900299949552`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854404`], 
              Complex[5.609715869645587, -1.1622900299949552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4001554156192917`, -1.7796058471281269`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2977805798777453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33901638456088035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.2977805798777453`, -0.33901638456088035`], 
              Complex[2.4001554156192917`, -1.7796058471281269`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.599467510982897, -1.1622385897064982`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0106538385311294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.0106538385311294], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4116074707342534`, -1.774754506235453}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214084`, -0.33563662492447366`], 
              Complex[2.4116074707342534`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.58930230415447, -1.1621856987234664`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694064`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4229890675144983`, -1.7699888755685131`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3195467699805936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.3195467699805936`, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685131`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.579215944909335, -1.1621313167255456`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194784`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564418`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194784, 0.010936818155564418`], 
              Complex[5.579215944909335, -1.1621313167255456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.434303571543257, -1.765305947424264}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014387], 
              Complex[2.434303571543257, -1.765305947424264]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.569204368643545, -1.162075401828133}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.01108166777660794], 
              Complex[5.569204368643545, -1.162075401828133]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4455541794767464`, -1.7607028906574198`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.340985266615273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7607028906574198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.340985266615273, -0.32598084447903347`], 
              Complex[2.4455541794767464`, -1.7607028906574198`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.559263729872352, -1.162017910531272}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162017910531272`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798505`], 
              Complex[5.559263729872352, -1.162017910531272]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.456743933131439, -1.7561770369578587`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3515900032787673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.456743933131439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.3515900032787673`, -0.32291378822242106`], 
              Complex[2.456743933131439, -1.7561770369578587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.549390383803342, -1.1619587976643726`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423352`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.011378342532423352`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.46787573218371, -1.7517258685037118`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.46787573218371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573208, -0.3199181000986168], 
              Complex[2.46787573218371, -1.7517258685037118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.539580869749673, -1.1618980163266774`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525728], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.478952345649963, -1.7473470068263872`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799589`, -0.31699136241415293`], 
              Complex[2.478952345649963, -1.7473470068263872`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.529831896159836, -1.1618355178234179`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931245`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4899764222920586`, -1.7430382027464775`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3829826712308153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3141312908727419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.3829826712308153`, -0.3141312908727419], 
              Complex[2.4899764222920586`, -1.7430382027464775`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.520140327071446, -1.1617712515975436`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115795`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.500950500073135, -1.7387973272586887`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.393315746009415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586887`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.393315746009415, -0.3113357252023987], 
              Complex[2.500950500073135, -1.7387973272586887`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.510503169822832, -1.1617051651569135`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428712, 0.012001139360437757`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5118770147723373`, -1.7346223632600883`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30860262064445376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7346223632600883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924144`, -0.30860262064445376`], 
              Complex[2.5118770147723373`, -1.7346223632600883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.500917563878367, -1.1616372039967813`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485314`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485314`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5227583078528273`, -1.7305113980298923`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261337`, -0.30593004021100256`], 
              Complex[2.5227583078528273`, -1.7305113980298923`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.4913807706423245`, -1.1615673115173935`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552494`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552494`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5335966336654487`, -1.7264626163806056`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291149`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7264626163806056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222577`, -0.3033161476291149], 
              Complex[2.5335966336654487`, -1.7264626163806056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.4818901641520625`, -1.1614954289364903`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164319`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5443941660601186`, -1.722474294410549}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4340605247457119`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3007592009004861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.722474294410549`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.4340605247457119`, -0.3007592009004861], 
              Complex[2.5443941660601186`, -1.722474294410549]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.472443222555007, -1.1614214951964699`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.472443222555007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376172, 0.012666429816627385`], 
              Complex[5.472443222555007, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5551530044682584`, -1.7185447937963196`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2982575464138699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589807`, -0.2982575464138699], 
              Complex[2.5551530044682584`, -1.7185447937963196`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.463037520285709, -1.161345446865949}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854726`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854726`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5658751795119747`, -1.7146725565713101`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4541129029793964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2958096135553037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713101`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.4541129029793964`, -0.2958096135553037], 
              Complex[2.5658751795119747`, -1.7146725565713101`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.453670720869239, -1.161267218035427}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742186`], 
              Complex[5.453670720869239, -1.161267218035427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.576562658189158, -1.710856100342705}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993391`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2934139097675647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.576562658189158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.710856100342705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993391`, -0.2934139097675647], 
              Complex[2.576562658189158, -1.710856100342705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.444340570285955, -1.1611867402067302`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391402`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391402`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.587217348678115, -1.7070940139050703`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135787`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.7070940139050703`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.435044890840144, -1.161103942175881}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.969756453162239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.969756453162239, 0.013378583279512466`], 
              Complex[5.435044890840144, -1.161103942175881]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5978411048003482`, -1.7033849532134369`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134369`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134369`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.425781575481577, -1.1610187499090083`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9612615538389253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362826`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.9612615538389253`, 0.013564516504362826`], 
              Complex[5.425781575481577, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.608435730175938, -1.6997276376830055`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395195`, -0.28652632543776696`], 
              Complex[2.608435730175938, -1.6997276376830055`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.416548582534639, -1.1609310864108735`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612014, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.619002982102259, -1.696120846786332}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5034448258538131`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2843260223090579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.696120846786332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.5034448258538131`, -0.2843260223090579], 
              Complex[2.619002982102259, -1.696120846786332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.407343930794649, -1.1608408715855627`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013946445235532942`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.013946445235532942`], 
              Complex[5.407343930794649, -1.1608408715855627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.629544575183533, -1.6925634169220718`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5131894768429806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2821715098398554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.5131894768429806`, -0.2821715098398554], 
              Complex[2.629544575183533, -1.6925634169220718`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.398165694955262, -1.1607480220888433`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044086`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.014142621333044086`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.640062184735898, -1.6890542385321832`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939463`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28006168039394325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939463`, -0.28006168039394325`], 
              Complex[2.640062184735898, -1.6890542385321832`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.389012001334582, -1.1606524511716514`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6505574499902775`, -1.6855922534470884`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.532571266034649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.532571266034649, -0.2779954793374566], 
              Complex[2.6505574499902775`, -1.6855922534470884`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.379881023870965, -1.1605540685141238`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1605540685141238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250856`], 
              Complex[5.379881023870965, -1.1605540685141238`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.661031977113044, -1.6821764524403942`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034568`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034568`, -0.2759719024950623], 
              Complex[2.661031977113044, -1.6821764524403942`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.3707709803622485`, -1.1604527800495485`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367238`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6714873420627194`, -1.6788058729768787`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451711`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2739899938041933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768787`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451711`, -0.2739899938041933], 
              Complex[2.6714873420627194`, -1.6788058729768787`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.36168012892486, -1.1603484877775454`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01496433941403484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.01496433941403484], 
              Complex[5.36168012892486, -1.1603484877775454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.68192509329917, -1.6754795971390901`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6754795971390901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502445`, -0.27204884315225397`], 
              Complex[2.68192509329917, -1.6754795971390901`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.352606764651277, -1.1602410895657407`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436348`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.692346754360388, -1.672196749719544}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.672196749719544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335235`], 
              Complex[2.692346754360388, -1.672196749719544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.343549216446447, -1.1601304789391282`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965262`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965262`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.702753826320577, -1.6689564964669}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2682853934625309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.2682853934625309], 
              Complex[2.702753826320577, -1.6689564964669]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.334505844025381, -1.160016544856252}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198311`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198311`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.713147790142197, -1.6657580424757261`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028514`, -0.26646148678673626`], 
              Complex[2.713147790142197, -1.6657580424757261`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.325475035055747, -1.1598991714712616`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.869745127987924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.869745127987924, 0.015850459092959724`], 
              Complex[5.325475035055747, -1.1598991714712616`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.723530108933592, -1.662600630710649}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.599449657699079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.723530108933592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.662600630710649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.599449657699079, -0.26467511963294027`], 
              Complex[2.723530108933592, -1.662600630710649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.316455202430541, -1.1597782378808235`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.86155734952905`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.86155734952905, 0.016082942650415957`], 
              Complex[5.316455202430541, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.73390223012297, -1.6594835406566912`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.73390223012297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348711], 
              Complex[2.73390223012297, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.307444781657183, -1.1596536178547647`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.016320069418202337`], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.74426558755872, -1.6564060870885489`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.74426558755872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620056`, -0.2612122109807515], 
              Complex[2.74426558755872, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.298442228350345, -1.159525179549259}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016561979698683872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759495`, 0.016561979698683872`], 
              Complex[5.298442228350345, -1.159525179549259]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7546216035454143`, -1.6533676189524371`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.62774760750956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.62774760750956, -0.2595343622253305], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.289446015816816, -1.159392785201224}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533102`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7649716908242423`, -1.6503675183549191`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6371423746489984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.6371423746489984`, -0.2578914362102898], 
              Complex[2.7649716908242423`, -1.6503675183549191`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.280454632721416, -1.1592562908025152`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761317`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761317`, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.775317254506115, -1.6474051996538635`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25628286358783076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595245`, -0.25628286358783076`], 
              Complex[2.775317254506115, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.271466580823748, -1.1591155457523543`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.017317904038714273`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7856596939652976`, -1.6444801086473986`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2547081070429701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6444801086473986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210366`, -0.2547081070429701], 
              Complex[2.7856596939652976`, -1.6444801086473986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.262480372776144, -1.1589703924863026`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237652`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.017580472844237652`], 
              Complex[5.262480372776144, -1.1589703924863026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.796000404700961, -1.6415917218573373`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106764], 
              Complex[2.796000404700961, -1.6415917218573373`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.253494529973697, -1.1588206660799292`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213597`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8063407801738802`, -1.6387395459042158`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.2516580484846374], 
              Complex[2.8063407801738802`, -1.6387395459042158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.24450758044773, -1.1586661938251577`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7964880329151702`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01812252789874474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.7964880329151702`, 0.01812252789874474], 
              Complex[5.24450758044773, -1.1586661938251577`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8166822136251173`, -1.6359231169716286`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.683894775322847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.683894775322847, -0.2501818254149767], 
              Complex[2.8166822136251173`, -1.6359231169716286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.235518056794404, -1.1585067947770964`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287794`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770964`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287794`], 
              Complex[5.235518056794404, -1.1585067947770964`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8270260998834287`, -1.6331420003581567`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745872`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24873757519284695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745872`, -0.24873757519284695`], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.226524494130514, -1.158342279268929}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788258`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788258`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8373738371679265`, -1.6303957901157309`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.702517932853939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.702517932853939, -0.24732491072033722`], 
              Complex[2.8373738371679265`, -1.6303957901157309`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.217525428068778, -1.1581724483922544`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336754`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.847726828892449, -1.6276841087738216`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7118182661707113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.7118182661707113`, -0.24594347356467763`], 
              Complex[2.847726828892449, -1.6276841087738216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.208519392705084, -1.1579970934399617`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.764099329077837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259931007`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.764099329077837, 0.019279648259931007`], 
              Complex[5.208519392705084, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8580864854780335`, -1.6250066071493985`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24459293369624518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258048`, -0.24459293369624518`], 
              Complex[2.8580864854780335`, -1.6250066071493985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.199504918610362, -1.1578159953084997`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954847`, 0.01958535502317052], 
              Complex[5.199504918610362, -1.1578159953084997`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8684542261798467`, -1.6223629642431856`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041919`], 
              Complex[2.8684542261798467`, -1.6223629642431856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.190480530819804, -1.1576289238560522`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995081`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995081, 0.01989808875998757], 
              Complex[5.190480530819804, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8788314809349766`, -1.6197528872232836`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7396905327334806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.7396905327334806`, -0.24198336673385487`], 
              Complex[2.8788314809349766`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.181444746812216, -1.1574356372128114`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02021809668881551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.02021809668881551], 
              Complex[5.181444746812216, -1.1574356372128114`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8892196922375377`, -1.6171761114978096`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978096`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071484`, -0.24072382041628868`], 
              Complex[2.8892196922375377`, -1.6171761114978096`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.1723960744723065`, -1.1572358810391412`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985932966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985932966`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.8996203170476367`, -1.6146324008788793`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7582617077558227`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23949413300958758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.7582617077558227`, -0.23949413300958758`], 
              Complex[2.8996203170476367`, -1.6146324008788793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.163333010028644, -1.1570293877270226`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7235801099771857`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020880984524094977`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.7235801099771857`, 0.020880984524094977`], 
              Complex[5.163333010028644, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.910034828740951, -1.6121215478408175`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947159`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947159`, -0.2382941155363086], 
              Complex[2.910034828740951, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.154254035959911, -1.156815875539666}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603423`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976127`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.154254035959911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603423`, 0.021224421666976127`], 
              Complex[5.154254035959911, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.920464719105737, -1.6096433738762481`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7768374421596609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.7768374421596609`, -0.2371236076506873], 
              Complex[2.920464719105737, -1.6096433738762481`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.145157618862019, -1.156595047683686}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.930911500394466, -1.60719772995439}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022491`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60719772995439`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022491`, -0.23598247799562655`], 
              Complex[2.930911500394466, -1.60719772995439]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.136042207268361, -1.1563665913076093`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02193678187394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.02193678187394727], 
              Complex[5.136042207268361, -1.1563665913076093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9413767074374184`, -1.6047844970867333`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2348706246599857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267063`, -0.2348706246599857], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.126906229415364, -1.1561301764198548`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795415`, 0.022306351154756366`], 
              Complex[5.126906229415364, -1.1561301764198548`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9518618998259756`, -1.6024035870060644`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.804734111374893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.804734111374893, -0.2337879757412097], 
              Complex[2.9518618998259756`, -1.6024035870060644`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.117748090945093, -1.1558854547185569`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684483`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9623686641736464`, -1.600054942965845}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8140475406660062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23273449001922947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.600054942965845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.8140475406660062`, -0.23273449001922947`], 
              Complex[2.9623686641736464`, -1.600054942965845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.108566172536498, -1.1556320583248079`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.674687296700069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0230740120998301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1556320583248079`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.674687296700069, 0.0230740120998301], 
              Complex[5.108566172536498, -1.1556320583248079`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9728986164633167`, -1.597738540667868}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.823370676497873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23171015774841427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.597738540667868`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.823370676497873, -0.23171015774841427`], 
              Complex[2.9728986164633167`, -1.597738540667868]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.099358827456356, -1.1553695984099268`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944804`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944804`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9834534044896497`, -1.595454389327372}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169928`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2307150015754318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.595454389327372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169928`, -0.2307150015754318], 
              Complex[2.9834534044896497`, -1.595454389327372]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.090124379020649, -1.1550976637063441`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02388225011180803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.02388225011180803], 
              Complex[5.090124379020649, -1.1550976637063441`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.994034710406032, -1.5932025328859931`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.842052068264839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.842052068264839, -0.2297490775919429], 
              Complex[2.994034710406032, -1.5932025328859931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.080861117956596, -1.15481581889049}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.650043307963434`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774112`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.650043307963434, 0.024302619991774112`], 
              Complex[5.080861117956596, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0046442533860986`, -1.5909830513843415`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2288124765322978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.2288124765322978], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.071567299655017, -1.1545236028247543`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6417897014939595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024734421969833963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.6417897014939595`, 0.024734421969833963`], 
              Complex[5.071567299655017, -1.1545236028247543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.015283792410421, -1.588796062507649}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8607905440628354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.588796062507649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.8607905440628354`, -0.22790532512782383`], 
              Complex[3.015283792410421, -1.588796062507649]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0622411413021275`, -1.1542205266440744`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6335140931343686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025178136640842938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.6335140931343686`, 0.025178136640842938`], 
              Complex[5.0622411413021275`, -1.1542205266440744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0259551291896347`, -1.5866417233196022`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5866417233196022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162648`, -0.22702778763077067`], 
              Complex[3.0259551291896347`, -1.5866417233196022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.05288081887921, -1.1539060716710012`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6252149197388337`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025634272402031193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.6252149197388337`, 0.025634272402031193`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.036660111236013, -1.5845202322015453`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2261800675227635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.2261800675227635], 
              Complex[3.036660111236013, -1.5845202322015453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0434844640179035`, -1.153579687141173}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.616890584552165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026103367509584273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.616890584552165, 0.026103367509584273`], 
              Complex[5.0434844640179035`, -1.153579687141173]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0474006350962966`, -1.582431831016463}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454497`], 
              Complex[3.0474006350962966`, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.034050160698049, -1.1532407877189192`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.608539454516405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.608539454516405, 0.026585992320965892`], 
              Complex[5.034050160698049, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.058178649759413, -1.5803768075197013`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.898490168720361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.898490168720361, -0.22457510122598107`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.024575941774229, -1.152888750780241}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796514`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796514`], 
              Complex[5.024575941774229, -1.152888750780241]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.068996160253663, -1.5783554980412635`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2238184764577979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.2238184764577979], 
              Complex[3.068996160253663, -1.5783554980412635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0150597853162315`, -1.152522913437557}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027594287906544515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840506`, 0.027594287906544515`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0798552314489043`, -1.5763682904678327`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.917478469987143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489043`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.917478469987143, -0.22309291692935712`], 
              Complex[3.0798552314489043`, -1.5763682904678327`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.005499610747705, -1.15214256927739}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5833083599570257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.028121283097053456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.5833083599570257`, 0.028121283097053456`], 
              Complex[5.005499610747705, -1.15214256927739]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.090757992080275, -1.574415627556381}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9270135155729469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.090757992080275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.574415627556381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.9270135155729469`, -0.22239885565995504`], 
              Complex[3.090757992080275, -1.574415627556381]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.9958932747662494`, -1.151746964778438}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.57483289213363`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028664462962103714`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.57483289213363, 0.028664462962103714`], 
              Complex[4.9958932747662494`, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.1017066390111183`, -1.5724980106155322`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386605`, -0.22173678013483517`], 
              Complex[3.1017066390111183`, -1.5724980106155322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.986238567027153, -1.1513352953732714`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5663218157567322`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.029224600034819134`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.5663218157567322`, 0.029224600034819134`], 
              Complex[4.986238567027153, -1.1513352953732714`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.11270344175382, -1.5706160035957248`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2211072359212472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.11270344175382`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.2211072359212472], 
              Complex[3.11270344175382, -1.5706160035957248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.976533205571878, -1.1509067011120155`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.02980251760487485], 
              Complex[4.976533205571878, -1.1509067011120155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.1237507472684634`, -1.5687702376348136`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.955805238206233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22051083068468322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1237507472684634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.955805238206233, -0.22051083068468322`], 
              Complex[3.1237507472684634`, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.966774831981249, -1.1504602618808104`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211297`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211297`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.134850985060283, -1.5669614161122607`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092963`], 
              Complex[3.134850985060283, -1.5669614161122607`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.956961006232221, -1.1499949921214252`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413918`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.146006672598036, -1.5651903202724238`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5651903202724238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269589`, -0.21942020556585187`], 
              Complex[3.146006672598036, -1.5651903202724238`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.947089201235956, -1.149509834990993}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5318822005363093`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03165204012119633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.5318822005363093`, 0.03165204012119633], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.157220421076431, -1.5634578154860739`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9849199122885905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21892755421211502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.9849199122885905`, -0.21892755421211502`], 
              Complex[3.157220421076431, -1.5634578154860739`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.937156797033987, -1.1490036558923016`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.523163099500529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665909`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923016`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.523163099500529, 0.03231048635665909], 
              Complex[4.937156797033987, -1.1490036558923016`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.1684949415466472`, -1.561764858229167}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505612`, -0.21847119055042033`], 
              Complex[3.1684949415466472`, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.927161074628285, -1.1484752352951793`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234989], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.1798330514396453`, -1.5601125038693655`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0045385236161377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1798330514396453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5601125038693655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.0045385236161377`, -0.21805211056251347`], 
              Complex[3.1798330514396453`, -1.5601125038693655`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.917099209420433, -1.1479232607580627`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.033697084835816196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.033697084835816196`], 
              Complex[4.917099209420433, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.191237681507363, -1.5585019153641582`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0144176233688644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2176714078844632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.0144176233688644`, -0.2176714078844632], 
              Complex[3.191237681507363, -1.5585019153641582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.906968264234699, -1.147346318045541}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.496707894901857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.496707894901857, 0.03442779801852973], 
              Complex[4.906968264234699, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.202711883206814, -1.5569343729898864`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.202711883206814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5569343729898864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667063`, -0.21733028233169854`], 
              Complex[3.202711883206814, -1.5569343729898864`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.896765181899932, -1.1467428812221834`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03518532290406062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.03518532290406062], 
              Complex[4.896765181899932, -1.1467428812221834`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.2142588365513363`, -1.5554112852390443`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.21703004943242474`], 
              Complex[3.2142588365513363`, -1.5554112852390443`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.886486777365879, -1.1461113015849471`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4787983328457113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0359711966974785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.4787983328457113`, 0.0359711966974785], 
              Complex[4.886486777365879, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.2258818584516473`, -1.5539342010442931`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.044365139258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2258818584516473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.044365139258773, -0.21677215110365747`], 
              Complex[3.2258818584516473`, -1.5539342010442931`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.8761297293312476`, -1.145449795275427}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4697538621751725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.036787077710537165`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.145449795275427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.4697538621751725`, 0.036787077710537165`], 
              Complex[4.8761297293312476`, -1.145449795275427]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.237584411566567, -1.5525048235121883`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.21655816762459842`], 
              Complex[3.237584411566567, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.865690571363539, -1.1447564293886003`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4606458541378564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.037634757497710815`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.865690571363539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.4606458541378564`, 0.037634757497710815`], 
              Complex[4.865690571363539, -1.1447564293886003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.249370113678695, -1.551125025378486}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2163898310860748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.551125025378486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.2163898310860748], 
              Complex[3.249370113678695, -1.551125025378486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.855165682495278, -1.1440291063659587`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.45147135291243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03851617446207765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.45147135291243, 0.03851617446207765], 
              Complex[4.855165682495278, -1.1440291063659587`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.2612427476037626`, -1.54979686643061}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21626904052272816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54979686643061`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380024`, -0.21626904052272816`], 
              Complex[3.2612427476037626`, -1.54979686643061]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.844551277287891, -1.1432655464271395`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804186], 
              Complex[4.844551277287891, -1.1432655464271395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.2732062716325756`, -1.5485226131825367`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2161978789674407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.2161978789674407], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.833843395364208, -1.142463267754563}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302237`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.040388801390635616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302237`, 0.040388801390635616`], 
              Complex[4.833843395364208, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.285264830490968, -1.5473047611339115`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.285264830490968`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584645`], 
              Complex[3.285264830490968, -1.5473047611339115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.823037890424123, -1.1416195640990148`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.041384769809504604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.041384769809504604`], 
              Complex[4.823037890424123, -1.1416195640990148`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.2974227667841576`, -1.546146059999975}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.105918638824221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.105918638824221, -0.21621381305374007`], 
              Complex[3.2974227667841576`, -1.546146059999975]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.812130418776984, -1.1407314794193446`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04242403362064922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.04242403362064922], 
              Complex[4.812130418776984, -1.1407314794193446`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.3096846328660448`, -1.5450495423633643`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1164306967437954`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21630618103294616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.1164306967437954`, -0.21630618103294616`], 
              Complex[3.3096846328660448`, -1.5450495423633643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.801116427450052, -1.1397957791050348`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.404488673178392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0435095374916808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.404488673178392, 0.0435095374916808], 
              Complex[4.801116427450052, -1.1397957791050348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.322055203038721, -1.544018556274634}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1270248839729087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2164587753829217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.322055203038721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.544018556274634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.1270248839729087`, -0.2164587753829217], 
              Complex[3.322055203038721, -1.544018556274634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.78999114196779, -1.1388089172545461`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114845`], 
              Complex[4.78999114196779, -1.1388089172545461`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.334539485939788, -1.5430568024175475`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1377052534254433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175475`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.1377052534254433`, -0.21667494441768215`], 
              Complex[3.334539485939788, -1.5430568024175475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.778749553944276, -1.1377669993932333`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04583244395046668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.04583244395046668], 
              Complex[4.778749553944276, -1.1377669993932333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.347142736911111, -1.5421683765599408`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209197`], 
              Complex[3.347142736911111, -1.5421683765599408`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.767386408695089, -1.136665739909798}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.375281340051193`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04707723610641667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.375281340051193, 0.04707723610641667], 
              Complex[4.767386408695089, -1.136665739909798]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.359870470056671, -1.541357818133694}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.541357818133694`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992386`], 
              Complex[3.359870470056671, -1.541357818133694]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.755896193160949, -1.135500413367616}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410603633`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.135500413367616`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.048383125410603633`], 
              Complex[4.755896193160949, -1.135500413367616]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.372728469582494, -1.5406301659307435`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1703067856653018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21774382534019787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.372728469582494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5406301659307435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.1703067856653018`, -0.21774382534019787`], 
              Complex[3.372728469582494, -1.5406301659307435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.744273124550121, -1.1342657987037832`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.355317910736984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.355317910736984, 0.04975479211876499], 
              Complex[4.744273124550121, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.385722799858256, -1.5399910220686328`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165973986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.21825535165973986`], 
              Complex[3.385722799858256, -1.5399910220686328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.732511140259883, -1.1329561151622778`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3451748653131745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05119740181429549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622778`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.3451748653131745`, 0.05119740181429549], 
              Complex[4.732511140259883, -1.1329561151622778`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.398859813435927, -1.5394466255711587`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.192554939758106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2188533057099164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.192554939758106, -0.2188533057099164], 
              Complex[3.398859813435927, -1.5394466255711587`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.720603889841739, -1.1315649486154922`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05271666771536838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.05271666771536838], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.4121461559885473`, -1.5390039371286066`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21954386620430988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.21954386620430988`], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.70854473004717, -1.130085166709498}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952717], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.4255887667699514`, -1.5386707368477486`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.215261587046473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.215261587046473, -0.2203339164903332], 
              Complex[3.4255887667699514`, -1.5386707368477486`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.696326724353139, -1.1285088210227603`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3140398458230234`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.3140398458230234`, 0.05601119898888099], 
              Complex[4.696326724353139, -1.1285088210227603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.4391948727143986`, -1.5384557370705048`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.226800554414456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22123113894674903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.226800554414456, -0.22123113894674903`], 
              Complex[3.4391948727143986`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.683942648848311, -1.1268270341592392`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375008`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.057801327638013905`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375008`, 0.057801327638013905`], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.4529719736549263`, -1.5383687126232317`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2384709550276787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22224412353114367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.2384709550276787`, -0.22224412353114367`], 
              Complex[3.4529719736549263`, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.671385007001144, -1.1250298694138174`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180629, 0.05969804216878783], 
              Complex[4.671385007001144, -1.1250298694138174`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.4669278152904948`, -1.5384206511375547`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2502787217879465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.2502787217879465`, -0.22338249250843537`], 
              Complex[3.4669278152904948`, -1.5384206511375547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.658646056679823, -1.1231061803689848`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.281730781277995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.281730781277995, 0.06171110588324314], 
              Complex[4.658646056679823, -1.1231061803689848`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.481070345408924, -1.5386239263253445`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22465704353173377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838813`, -0.22465704353173377`], 
              Complex[3.481070345408924, -1.5386239263253445`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.645717853916905, -1.1210434375401022`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0638514545260297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.0638514545260297], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.49540764739327, -1.538992497237254}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6325923193910725`, -1.1188275290397083`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.259461393050655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.259461393050655, 0.06613136000835815], 
              Complex[4.6325923193910725`, -1.1188275290397083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.509947843100934, -1.5395421364907356`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.286586486377321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2276647637711864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.286586486377321, -0.2276647637711864], 
              Complex[3.509947843100934, -1.5395421364907356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.619261335536664, -1.1164425322748182`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672787`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672787`, 0.06856461676025169], 
              Complex[4.619261335536664, -1.1164425322748182`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.5246989546875493`, -1.5402906900657318`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.299003692304085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.299003692304085, -0.22942699279424644`], 
              Complex[3.5246989546875493`, -1.5402906900657318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.605716884708898, -1.1138704540789932`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.236552459537739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.236552459537739, 0.07116675231062836], 
              Complex[4.605716884708898, -1.1138704540789932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.5396687117196857`, -1.5412583702907805`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3115874899792836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23138396931833938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5412583702907805`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.3115874899792836`, -0.23138396931833938`], 
              Complex[3.5396687117196857`, -1.5412583702907805`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.591951242060749, -1.1110909376562412`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.224844111913217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.224844111913217, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.554864285859265, -1.5424680817046266`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3243426567556305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.3243426567556305`, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046266`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.577957240848536, -1.1080809366516995`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2129599799115014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07694987142173917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.2129599799115014`, 0.07694987142173917], 
              Complex[4.577957240848536, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.5702919304393554`, -1.5439457760136321`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23596306901323055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136321`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.23596306901323055`], 
              Complex[3.5702919304393554`, -1.5439457760136321`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.563728632846571, -1.1048143601285867`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.200896263829859`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.200896263829859, 0.08017280757570089], 
              Complex[4.563728632846571, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.5859564964599837`, -1.5457208265493538`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5457208265493538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577235`, -0.23863220192231416`], 
              Complex[3.5859564964599837`, -1.5457208265493538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.549260572342167, -1.1012616980470775`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1886505348460092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08364909334179298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.1886505348460092`, 0.08364909334179298], 
              Complex[4.549260572342167, -1.1012616980470775`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.601860790294312, -1.5478264033073155`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.363667294709622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24159066834690393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.363667294709622, -0.24159066834690393`], 
              Complex[3.601860790294312, -1.5478264033073155`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.534550258420688, -1.097389646163949}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1762222959316895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.08740682313953875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.1762222959316895`, 0.08740682313953875], 
              Complex[4.534550258420688, -1.097389646163949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.618004732680665, -1.5502998152929643`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.618004732680665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5502998152929643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517174`, -0.24486976056502383`], 
              Complex[3.618004732680665, -1.5502998152929643`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.519597775965092, -1.0931607636269258`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034556`, 0.09147740408549995], 
              Complex[4.519597775965092, -1.0931607636269258`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.6343842753970157`, -1.5531827657019452`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358286`, -0.24850423935263444`], 
              Complex[3.6343842753970157`, -1.5531827657019452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.50440717897338, -1.0885332177365603`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.150830514917903`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.150830514917903, 0.09589570953158887], 
              Complex[4.50440717897338, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.650990035081119, -1.5565214356849035`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889629, -0.25253232740394754`], 
              Complex[3.650990035081119, -1.5565214356849035`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.488987856730723, -1.083460700125328}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1378831966654945`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10070007254234242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.1378831966654945`, 0.10070007254234242`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.667805619167919, -1.5603662733822412`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5603662733822412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.667805619167919, -1.5603662733822412`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.473356207864622, -1.0778926376684699`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1247883648757773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.10593201418800258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.1247883648757773`, 0.10593201418800258`], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.684805656152575, -1.5647713188313286`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2619374941172033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.684805656152575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647713188313286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.2619374941172033], 
              Complex[3.684805656152575, -1.5647713188313286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.457537610074802, -1.0717748675240164`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320063`, 0.11163556486001087`], 
              Complex[4.457537610074802, -1.0717748675240164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.7019536132591466`, -1.5697928508801493`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059931], 
              Complex[3.7019536132591466`, -1.5697928508801493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.44156860245767, -1.0650509901679486`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0982631140723664`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.0982631140723664`, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.7191996003365837`, -1.5754871190552315`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.460865879669165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7191996003365837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5754871190552315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.460865879669165, -0.27343836455892556`], 
              Complex[3.7191996003365837`, -1.5754871190552315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.425499081603798, -1.0576646374765928`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981809, 0.12463782579822877`], 
              Complex[4.425499081603798, -1.0576646374765928`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.736478521301462, -1.5819069561624788`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.475028497636533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.475028497636533, -0.2800822323034718], 
              Complex[3.736478521301462, -1.5819069561624788`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.4093941501489144`, -1.0495628600775768`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918283`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4093941501489144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918283, 0.1320217921353984], 
              Complex[4.4093941501489144`, -1.0495628600775768`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.7537091204741744`, -1.5890972039111029`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.489102772743466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2873682998621297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.489102772743466, -0.2873682998621297], 
              Complex[3.7537091204741744`, -1.5890972039111029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.393335070431696, -1.0407007016791032`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.058320074594352`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1400410254670659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.058320074594352, 0.1400410254670659], 
              Complex[4.393335070431696, -1.0407007016791032`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.770794613325991, -1.5970891666976452`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697796`, -0.29531732776612196`], 
              Complex[3.770794613325991, -1.5970891666976452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377418633740917, -1.0310467452404806`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009882`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.787625571970204, -1.6058947337101082`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.516644453299159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101082`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.516644453299159, -0.3039330313949988], 
              Complex[3.787625571970204, -1.6058947337101082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.361754274818787, -1.0205889908238697`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.15805167382144264`], 
              Complex[4.361754274818787, -1.0205889908238697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.8040854242836257`, -1.6155012704525789`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3131980951405524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509906`, -0.3131980951405524], 
              Complex[3.8040854242836257`, -1.6155012704525789`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.34645857273412, -1.0093399640268061`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132117`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132117`, 0.16802967600526228`], 
              Complex[4.34645857273412, -1.0093399640268061`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.8200582761098665`, -1.625868648866985}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771693`, -0.3230721172560292], 
              Complex[3.8200582761098665`, -1.625868648866985]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.331647428673965, -0.9973396858188018}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1786100786041207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.1786100786041207], 
              Complex[4.331647428673965, -0.9973396858188018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.8354379364471796`, -1.6369295948434281`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.555022797842972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434281`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.555022797842972, -0.3334924140604994], 
              Complex[3.8354379364471796`, -1.6369295948434281`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.317427040750872, -0.9846553249905687}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.18973028734408162`], 
              Complex[4.317427040750872, -0.9846553249905687]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.8501363909766333`, -1.6485937815375424`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.566691838949067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490952983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.566691838949067, -0.34437794490952983`], 
              Complex[3.8501363909766333`, -1.6485937815375424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3038854304700065`, -0.9713771047973323}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859253`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934495046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859253`, 0.20130934934495046`], 
              Complex[4.3038854304700065`, -0.9713771047973323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.864089926301709, -1.6607550217891223`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946227`], 
              Complex[3.864089926301709, -1.6607550217891223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.29108631848507, -0.9576111105020126}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474703`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2132543530929577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.29108631848507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474703`, 0.2132543530929577], 
              Complex[4.29108631848507, -0.9576111105020126]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.8772617652382877`, -1.6733000146368147`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5880318511300824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36716827124164675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.5880318511300824`, -0.36716827124164675`], 
              Complex[3.8772617652382877`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2790664893039665`, -0.9434705428233613}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9658149382262047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22546793870233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.9658149382262047`, 0.22546793870233295`], 
              Complex[4.2790664893039665`, -0.9434705428233613]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.889641123048907, -1.6861168153853252`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.37888080574180316`], 
              Complex[3.889641123048907, -1.6861168153853252`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.267836735050403, -0.9290672478326637}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23785537273090346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.23785537273090346`], 
              Complex[4.267836735050403, -0.9290672478326637]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.901239519558195, -1.699101588537602}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6066509332628542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3906866010723906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.6066509332628542`, -0.3906866010723906], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.257385543344472, -0.9145049639864035}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771305`], 
              Complex[4.257385543344472, -0.9145049639864035]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.912085621903241, -1.7121629626858914`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.614986365799948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678371946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.614986365799948, -0.40251041678371946`], 
              Complex[3.912085621903241, -1.7121629626858914`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.247684254548457, -0.8998749672010711}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.941206632003138`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2628167267283538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.941206632003138, 0.2628167267283538], 
              Complex[4.247684254548457, -0.8998749672010711]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.9222198214979063`, -1.725224034003568}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.622720730815854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4142898642644486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.725224034003568`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.622720730815854, -0.4142898642644486], 
              Complex[3.9222198214979063`, -1.725224034003568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.238692484798848, -0.8852540673280818}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2752531764187573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.2752531764187573], 
              Complex[4.238692484798848, -0.8852540673280818]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.9316893781660758`, -1.7382225152116566`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6298974852549244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42597525546826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.6298974852549244`, -0.42597525546826], 
              Complex[3.9316893781660758`, -1.7382225152116566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.230362981869568, -0.8707044591549238}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549238`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.2875897604942168], 
              Complex[4.230362981869568, -0.8707044591549238]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.9405445393067424`, -1.7511096707348448`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6365618226979435`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43752848511674586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.6365618226979435`, -0.43752848511674586`], 
              Complex[3.9405445393067424`, -1.7511096707348448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2226455060035075`, -0.8562747872176834}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9219443399347473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.29978844959373085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.9219443399347473`, 0.29978844959373085`], 
              Complex[4.2226455060035075`, -0.8562747872176834]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.948835712532858, -1.763848614878014}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826845`, -0.44892143644815663`], 
              Complex[3.948835712532858, -1.763848614878014]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2154896572704255`, -0.8420018475938864}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934006`], 
              Complex[4.2154896572704255`, -0.8420018475938864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.95661157787795, -1.7764123973101793`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6485298058180127`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4601342612759222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764123973101793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.6485298058180127`, -0.4601342612759222], 
              Complex[3.95661157787795, -1.7764123973101793`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.208846763357216, -0.8279125023887515}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3236682414244005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.3236682414244005], 
              Complex[4.208846763357216, -0.8279125023887515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.963917947183658, -1.788782141660249}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6539158085376195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4711537472500264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.788782141660249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.6539158085376195`, -0.4711537472500264], 
              Complex[3.963917947183658, -1.788782141660249]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.202671020177383, -0.8140255411104013}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.906871213268679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.906871213268679, 0.3353164289039029], 
              Complex[4.202671020177383, -0.8140255411104013]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.970797171183352, -1.800945377085379}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500917994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48197187877303554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.800945377085379`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500917994`, -0.48197187877303554`], 
              Complex[3.970797171183352, -1.800945377085379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.196920084784547, -0.8003533490732545}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669035`, 0.3467578191386486], 
              Complex[4.196920084784547, -0.8003533490732545]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.9772879223008815`, -1.8128946175014515`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.66367399535596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.66367399535596, -0.49258462786579754`], 
              Complex[3.9772879223008815`, -1.8128946175014515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1915552925709445`, -0.7869033281400257}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.35798845368834886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400257`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.35798845368834886`], 
              Complex[4.1915552925709445`, -0.7869033281400257]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.9834252194900257`, -1.8246261926386427`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751522, -0.5029909709021093], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1865416324253255`, -0.7736790656393466}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.894927283100901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.894927283100901, 0.36900737727295463`], 
              Complex[4.1865416324253255`, -0.7736790656393466]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.989240598169982, -1.836139309119696}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.672284556174856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.672284556174856, -0.5131921073476411], 
              Complex[3.989240598169982, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.181847576794925, -0.7606812732613816}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485147`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.181847576794925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7606812732613816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485147`, 0.3798158565375278], 
              Complex[4.181847576794925, -0.7606812732613816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.994762358551031, -1.847435309214209}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.177444833357389, -0.747908528278101}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379956`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.747908528278101`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379956`, 0.3904167697900051], 
              Complex[4.177444833357389, -0.747908528278101]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.000015848490729, -1.858517093091783}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598119], 
              Complex[4.000015848490729, -1.858517093091783]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.173308062162179, -0.7353578512653347}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346618], 
              Complex[4.173308062162179, -0.7353578512653347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.005023753334011, -1.8693886729252436`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885692], 
              Complex[4.005023753334011, -1.8693886729252436`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.169414585788293, -0.723025151975394}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.882507505534356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.723025151975394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.882507505534356, 0.4110127578783307], 
              Complex[4.169414585788293, -0.723025151975394]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.009806376364359, -1.8800548315018006`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.686831218006914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.686831218006914, -0.5520158986267103], 
              Complex[4.009806376364359, -1.8800548315018006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.165744108890901, -0.7109055707023485}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4210179459473809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.4210179459473809], 
              Complex[4.165744108890901, -0.7109055707023485]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.0143819008890915`, -1.8905208626824292`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0143819008890915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8905208626824292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399864`, -0.5612511491377957], 
              Complex[4.0143819008890915`, -1.8905208626824292`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.162278456114007, -0.6989937377997083}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148405`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148405`, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.018766629721939, -1.9007923754230047`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6930566024649254`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.6930566024649254`, -0.5703092165540393], 
              Complex[4.018766629721939, -1.9007923754230047`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.159001332605871, -0.6872839696368794}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44047065160543564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.44047065160543564`], 
              Complex[4.159001332605871, -0.6872839696368794]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.022975200759231, -1.9108751468578666`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6959561299187063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5791958590266274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.6959561299187063`, -0.5791958590266274], 
              Complex[4.022975200759231, -1.9108751468578666`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.155898108440934, -0.6757704154937816}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.872929032365991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44992976094784376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.872929032365991, 0.44992976094784376`], 
              Complex[4.155898108440934, -0.6757704154937816]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.027020779081279, -1.9207750130848582`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6987283448032713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5879167986060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.6987283448032713`, -0.5879167986060274], 
              Complex[4.027020779081279, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.152955626516614, -0.6644471667545323}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.87087311222959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45921842799560564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.87087311222959, 0.45921842799560564`], 
              Complex[4.152955626516614, -0.6644471667545323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.030915226970466, -1.9304977888211978`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911523], 
              Complex[4.030915226970466, -1.9304977888211978`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.150162032533435, -0.6533083372307825}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370314`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370314`, 0.4683423384869718], 
              Complex[4.150162032533435, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.034669253707697, -1.9400492091033885`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011079], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.147506625196922, -0.6423481214415796}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4773070426385345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.4773070426385345], 
              Complex[4.147506625196922, -0.6423481214415796]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.038292547177894, -1.9494348877721928`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.144979724610491, -0.6315608361086175}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.041793889306879, -1.9586602887011337`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7087239788036013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6212539145605382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.7087239788036013`, -0.6212539145605382], 
              Complex[4.041793889306879, -1.9586602887011337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.142572556837011, -0.6209409489084494}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426784`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.494780200584179`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426784`, 0.494780200584179], 
              Complex[4.142572556837011, -0.6209409489084494]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.04518125724443, -1.9677307066670984`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 1, {
              Complex[2.710987197779322, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140277152714268, -0.6104830975830695}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5032988771597041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 2, {
              Complex[2.8621480115494466`, 0.5032988771597041], 
              Complex[4.140277152714268, -0.6104830975830695]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.048461912051172, -1.9766512554854925`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.713168767151179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6370671424983345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 1, {
              Complex[2.713168767151179, -0.6370671424983345], 
              Complex[4.048461912051172, -1.9766512554854925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.138086259166659, -0.6001821017863895}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8606638084231757`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.138086259166659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6001821017863895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 2, {
              Complex[2.8606638084231757`, 0.5116787778163012], 
              Complex[4.138086259166659, -0.6001821017863895]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.051642476470394, -1.985426861588554}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7152740029142293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6447767740762025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.985426861588554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 1, {
              Complex[2.7152740029142293`, -0.6447767740762025], 
              Complex[4.051642476470394, -1.985426861588554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.135993261431996, -0.5900329694879928}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.859252863201372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5199245263444041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 2, {
              Complex[2.859252863201372, 0.5199245263444041], 
              Complex[4.135993261431996, -0.5900329694879928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.054729003187752, -1.9940622616524242`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 1, {
              Complex[2.717307750554921, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524242`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.133992114800526, -0.5800308993285694}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8579103524231546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5280405519418736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285694`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 2, {
              Complex[2.8579103524231546`, 0.5280405519418736], 
              Complex[4.133992114800526, -0.5800308993285694]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.057727034812089, -2.002562003206256}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 1, {
              Complex[2.7192744356306138`, -0.6598239647344452], 
              Complex[4.057727034812089, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.132077284632825, -0.5701712799937028}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 2, {
              Complex[2.8566318723517807`, 0.5360310932164645], 
              Complex[4.132077284632825, -0.5701712799937028]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.060641656654435, -2.0109304474081915`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.721178108151079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0109304474081915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 1, {
              Complex[2.721178108151079, -0.6671697152100752], 
              Complex[4.060641656654435, -2.0109304474081915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.130243693579622, -0.5604496874212129}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5439002036016087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212129`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 2, {
              Complex[2.8554133945952374`, 0.5439002036016087], 
              Complex[4.130243693579622, -0.5604496874212129]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.063477543241719, -2.019171773366147}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.723022481587047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 1, {
              Complex[2.723022481587047, -0.6744020624307275], 
              Complex[4.063477543241719, -2.019171773366147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.12848667506693, -0.5508618804640691}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8542512270997307`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5516517577146832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12848667506693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 2, {
              Complex[2.8542512270997307`, 0.5516517577146832], 
              Complex[4.12848667506693, -0.5508618804640691]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.066238999377148, -2.0272899835297697`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 1, {
              Complex[2.724810967217476, -0.6815246607732997], 
              Complex[4.066238999377148, -2.0272899835297697`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.126801932234573, -0.5414037954825217}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 2, {
              Complex[2.8531419798044717`, 0.5592894583048518], 
              Complex[4.126801932234573, -0.5414037954825217]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.06892999644998, -2.0352889097939637`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.726546704428588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 1, {
              Complex[2.726546704428588, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.125185501625342, -0.5320715402250118}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8520825343446496`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5668168435275389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 2, {
              Complex[2.8520825343446496`, 0.5668168435275389], 
              Complex[4.125185501625342, -0.5320715402250118]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.071554204602269, -2.043172220042137}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.728232587492566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.695454416518052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 1, {
              Complex[2.728232587492566, -0.695454416518052], 
              Complex[4.071554204602269, -2.043172220042137]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.123633721017262, -0.5228613872697352}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 2, {
              Complex[2.8510700172747567`, 0.5742372943510565], 
              Complex[4.123633721017262, -0.5228613872697352]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.074115021277762, -2.050943424924777}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7298712892804384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7022680930260654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050943424924777`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 1, {
              Complex[2.7298712892804384`, -0.7022680930260654], 
              Complex[4.074115021277762, -2.050943424924777]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.12214320087372, -0.5137697672312345}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8501017763576963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 2, {
              Complex[2.8501017763576963`, 0.5815540419531228], 
              Complex[4.12214320087372, -0.5137697672312345]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.076615596606936, -2.0586058847208246`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 1, {
              Complex[2.7314652823007664`, -0.7089850735194758], 
              Complex[4.076615596606936, -2.0586058847208246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.120710798957501, -0.5047932618845047}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.849175359528075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5887701750046824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 2, {
              Complex[2.849175359528075, 0.5887701750046824], 
              Complex[4.120710798957501, -0.5047932618845047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.079058856020895, -2.0661628161692955`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 1, {
              Complex[2.733016857401756, -0.7156082665076036], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1193335977160075`, -0.495928597319203}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.495928597319203`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 2, {
              Complex[2.848288496192057, 0.5958886467685788], 
              Complex[4.1193335977160075`, -0.495928597319203]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.081447520434109, -2.07361729918916}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7345281404282455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 1, {
              Complex[2.7345281404282455`, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.118008884097688, -0.4871726372059109}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 2, {
              Complex[2.847439080572326, 0.6029122819634526], 
              Complex[4.118008884097688, -0.4871726372059109]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.083784124290591, -2.080972283429037}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 1, {
              Complex[2.736001107085406, -0.7285842912785055], 
              Complex[4.083784124290591, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.116734131505034, -0.478522376232896}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.846625156846318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 2, {
              Complex[2.846625156846318, 0.6098437833604627], 
              Complex[4.116734131505034, -0.478522376232896]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.086071031729208, -2.088230594606227}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.737437596227138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.734942326817608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 1, {
              Complex[2.737437596227138, -0.734942326817608], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.115506983628505, -0.46997493375384025`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384025`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 2, {
              Complex[2.845844905859744, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384025`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.088310451090251, -2.095394940608318}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 1, {
              Complex[2.7388393217580846`, -0.7412169946624543], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1143252399392205`, -0.46152754767328247`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1143252399392205`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.46152754767328247`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.1143252399392205`, -0.46152754767328247`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.090504447956572, -2.1024679173410123`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.74020788331328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 1, {
              Complex[2.74020788331328, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.113186842647121, -0.45317756858613556`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613556`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 2, {
              Complex[2.8443787586507785`, 0.6301108136973939], 
              Complex[4.113186842647121, -0.45317756858613556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.092654956897793, -2.1094520143136553`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1094520143136553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 1, {
              Complex[2.7415447758580713`, -0.7535254579157125], 
              Complex[4.092654956897793, -2.1094520143136553`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.112089864956078, -0.44492245417977994`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.636698583278269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417977994`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 2, {
              Complex[2.843689806329271, 0.636698583278269], 
              Complex[4.112089864956078, -0.44492245417977994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.094763792064632, -2.1163496199598404`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7428513983325447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7595636290829763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 1, {
              Complex[2.7428513983325447`, -0.7595636290829763], 
              Complex[4.094763792064632, -2.1163496199598404`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1110325004689345`, -0.4367597639013437}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843028396308333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013437`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 2, {
              Complex[2.843028396308333, 0.643206114159718], 
              Complex[4.1110325004689345`, -0.4367597639013437]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.096832656761998, -2.1231630266947916`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 1, {
              Complex[2.744129061448893, -0.7655271940238003], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.110013053613793, -0.42868715388848105`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688586`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848105`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 2, {
              Complex[2.842393236688586, 0.6496354995683531], 
              Complex[4.110013053613793, -0.42868715388848105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.098863152113464, -2.1298944357144074`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7453789947364777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714181229593399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 1, {
              Complex[2.7453789947364777`, -0.7714181229593399], 
              Complex[4.098863152113464, -2.1298944357144074`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.109029930978955, -0.4207023721587479}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 2, {
              Complex[2.8417831165816425`, 0.6559887487872507], 
              Complex[4.109029930978955, -0.4207023721587479]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.100856784915977, -2.136545961543077}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 1, {
              Complex[2.746602352917594, -0.7772383070571708], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.108081633457669, -0.4128032540504382}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.841196899736145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 2, {
              Complex[2.841196899736145, 0.6622677914714881], 
              Complex[4.108081633457669, -0.4128032540504382]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.102814974771636, -2.1431196363389544`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 1, {
              Complex[2.7478002216867257`, -0.7829895624892169], 
              Complex[4.102814974771636, -2.1431196363389544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1071667491158, -0.40498771790623117`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.84063351876029`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40498771790623117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 2, {
              Complex[2.84063351876029, 0.6684744817167123], 
              Complex[4.1071667491158, -0.40498771790623117`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.104739060573036, -2.1496174139664075`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 1, {
              Complex[2.748973622957286, -0.7886736342555828], 
              Complex[4.104739060573036, -2.1496174139664075`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1062839467060055`, -0.39725376098988185`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.39725376098988185`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 2, {
              Complex[2.8400919698768625`, 0.6746106018933712], 
              Complex[4.1062839467060055`, -0.39725376098988185`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.106630306409573, -2.1560411738459275`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1560411738459275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409573, -2.1560411738459275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.10543196976093, -0.38959945562569803`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 2, {
              Complex[2.8395713081544542`, 0.6806778662591636], 
              Complex[4.10543196976093, -0.38959945562569803`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.108489906954296, -2.1623927245921433`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7512508199475976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 1, {
              Complex[2.7512508199475976`, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921433`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.104609631205908, -0.38202294555012584`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8390706431652144`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.686677924362138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38202294555012584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 2, {
              Complex[2.8390706431652144`, 0.686677924362138], 
              Complex[4.104609631205908, -0.38202294555012584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.11031899238399, -2.1686738074506073`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 1, {
              Complex[2.7523563814347085`, -0.8053392041803542], 
              Complex[4.11031899238399, -2.1686738074506073`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.103815808438448, -0.374522442464793}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8385891350252574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.374522442464793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 2, {
              Complex[2.8385891350252574`, 0.6926123642464802], 
              Complex[4.103815808438448, -0.374522442464793]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.112118632879193, -2.1748860995439667`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 1, {
              Complex[2.7534410145367234`, -0.8107706896206488], 
              Complex[4.112118632879193, -2.1748860995439667`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1030494388277985`, -0.36709622278037246`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83812599077891`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36709622278037246`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 2, {
              Complex[2.83812599077891, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.36709622278037246`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.1138898427456025`, -2.181031216937887}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 1, {
              Complex[2.7545054859170786`, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102309515593155, -0.3597426245409171}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409171`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 2, {
              Complex[2.8376804610924067`, 0.7042904519630286], 
              Complex[4.102309515593155, -0.3597426245409171]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.115633584193734, -2.1871107175367754`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.101595084023626, -0.3524600445185817}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3524600445185817`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 2, {
              Complex[2.8372518372264883`, 0.7100369946836329], 
              Complex[4.101595084023626, -0.3524600445185817]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.11735077080964, -2.1931261038190124`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1931261038190124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 1, {
              Complex[2.7565768091901, -0.8267141994476594], 
              Complex[4.11735077080964, -2.1931261038190124`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.100905238007176, -0.34524693546903984`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546903984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 2, {
              Complex[2.836839448260752, 0.7157237141721119], 
              Complex[4.100905238007176, -0.34524693546903984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.119042270745964, -2.199078825420972}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.757585001537493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 1, {
              Complex[2.757585001537493, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.100239116839225, -0.3381018035383218}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836442658545575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 2, {
              Complex[2.836442658545575, 0.7213519329214123], 
              Complex[4.100239116839225, -0.3381018035383218]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.120708909659479, -2.204970281578657}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 1, {
              Complex[2.7585757179660733`, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.099595902284807, -0.3310232058121981}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 2, {
              Complex[2.836060865360036, 0.7269229276281968], 
              Complex[4.099595902284807, -0.3310232058121981]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.122351473418491, -2.210801823435384}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.84215888622212`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.210801823435384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 1, {
              Complex[2.759549546988155, -0.84215888622212], 
              Complex[4.122351473418491, -2.210801823435384]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.098974815870868, -0.32400974799972326`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.835693496756588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972326`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 2, {
              Complex[2.835693496756588, 0.7324379313144278], 
              Complex[4.098974815870868, -0.32400974799972326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.123970710601056, -2.2165747562234497`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7605070481803384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 1, {
              Complex[2.7605070481803384`, -0.8472019743388878], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0983751163877695`, -0.31706008224295906`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.737898135330063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 2, {
              Complex[2.8353400095752215`, 0.737898135330063], 
              Complex[4.0983751163877695`, -0.31706008224295906`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.125567334802809, -2.2222903413273136`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.761448754016845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8521943919901347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125567334802809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2222903413273136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 1, {
              Complex[2.761448754016845, -0.8521943919901347], 
              Complex[4.125567334802809, -2.2222903413273136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.097796097581198, -0.31017290504537165`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834999887611698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 2, {
              Complex[2.834999887611698, 0.7433046912443019], 
              Complex[4.097796097581198, -0.31017290504537165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.127142026771302, -2.2279497982353833`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7623751715626246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 1, {
              Complex[2.7623751715626246`, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.097237086017579, -0.3033469553117824}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834672639925991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.748658712632362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 2, {
              Complex[2.834672639925991, 0.748658712632362], 
              Complex[4.097237086017579, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.128695436382012, -2.2335543063870658`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.763286784038682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.862031510221407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 1, {
              Complex[2.763286784038682, -0.862031510221407], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.096697439107837, -0.2965810124932357}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 2, {
              Complex[2.8343577992784867`, 0.7539612767642828], 
              Complex[4.096697439107837, -0.2965810124932357]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.130228184469746, -2.239105006921373}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.76418405227083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 1, {
              Complex[2.76418405227083, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.096176543275776, -0.28987389483045606`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.834054920682748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045606`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 2, {
              Complex[2.834054920682748, 0.7592134262018868], 
              Complex[4.096176543275776, -0.28987389483045606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.131740864527741, -2.244603004332967}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7650674160319424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 1, {
              Complex[2.7650674160319424`, -0.8716784802620262], 
              Complex[4.131740864527741, -2.244603004332967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.095673812258773, -0.2832244576900397}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833763580064758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 2, {
              Complex[2.833763580064758, 0.7644161703095633], 
              Complex[4.095673812258773, -0.2832244576900397]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.133234044285656, -2.25004936804117}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765937295286828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 1, {
              Complex[2.765937295286828, -0.8764330896595156], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.095188685529604, -0.27663159198783}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.27663159198783]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.134708267176491, -2.2554451338771333`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.766794091347923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 1, {
              Complex[2.766794091347923, -0.8811430162906048], 
              Complex[4.134708267176491, -2.2554451338771333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.094720626829336, -0.27009422269428524`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.833213913656889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 2, {
              Complex[2.833213913656889, 0.7746773225093271], 
              Complex[4.094720626829336, -0.27009422269428524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.136164053701611, -2.2607913054940165`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 1, {
              Complex[2.7676381879492564`, -0.8858091496519154], 
              Complex[4.136164053701611, -2.2607913054940165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.094269122802148, -0.2636113074169858}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8329548335289294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7797375958378117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2636113074169858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 2, {
              Complex[2.8329548335289294`, 0.7797375958378117], 
              Complex[4.094269122802148, -0.2636113074169858]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.137601902702118, -2.2660888557047376`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 1, {
              Complex[2.768469952245414, -0.8904323517124779], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0938336817238055`, -0.25718183505570524`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325198`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0938336817238055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.25718183505570524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 2, {
              Complex[2.8327057806325198`, 0.7847521968079443], 
              Complex[4.0938336817238055`, -0.25718183505570524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.139022292544097, -2.2713387277515538`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544097`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 1, {
              Complex[2.7692897357415927`, -0.8950134580602261], 
              Complex[4.139022292544097, -2.2713387277515538`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093413832316266, -0.2508048245258131}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.2508048245258131]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.1404256822245795`, -2.2765418365114747`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 1, {
              Complex[2.770097875160308, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0930091226416065`, -0.2444793235459518}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 2, {
              Complex[2.83223642523709, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.2444793235459518]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.141812512404397, -2.2816990696412356`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7708946932497662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9040526005333868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 1, {
              Complex[2.7708946932497662`, -0.9040526005333868], 
              Complex[4.141812512404397, -2.2816990696412356`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0926191190690275`, -0.2382044074863151}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 2, {
              Complex[2.832015492909507, 0.7995304720360316], 
              Complex[4.0926191190690275`, -0.2382044074863151]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.143183206373633, -2.286811288665357}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 1, {
              Complex[2.771680499538499, -0.9085121854432783], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.092243405309306, -0.23197917827395678`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831803326596092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.804370765804293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 2, {
              Complex[2.831803326596092, 0.804370765804293], 
              Complex[4.092243405309306, -0.23197917827395678`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.1445381709548, -2.291879330010544}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7724555910404214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 1, {
              Complex[2.7724555910404214`, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0918815815115215`, -0.225802763351888}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.831599643781914`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.225802763351888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 2, {
              Complex[2.831599643781914, 0.8091694575484224], 
              Complex[4.0918815815115215`, -0.225802763351888]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.145877797348456, -2.296904005989524}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.917315085499543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 1, {
              Complex[2.773220252914126, -0.917315085499543], 
              Complex[4.145877797348456, -2.296904005989524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.091533263417342, -0.21967431468886287`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809608`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886287`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 2, {
              Complex[2.8314041736809608`, 0.8139272921843708], 
              Complex[4.091533263417342, -0.21967431468886287`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.147202461925569, -2.3018861057371844`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 1, {
              Complex[2.7739747590798687`, -0.9216598178919513], 
              Complex[4.147202461925569, -2.3018861057371844`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.091198081568593, -0.213593007836997}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.213593007836997`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 2, {
              Complex[2.8312166566204735`, 0.8186449936599098], 
              Complex[4.091198081568593, -0.213593007836997]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.148512526970577, -2.306826396101708}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7747193727974437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9259676497839735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 1, {
              Complex[2.7747193727974437`, -0.9259676497839735], 
              Complex[4.148512526970577, -2.306826396101708]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090875680564112, -0.20755804103448106`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448106`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 2, {
              Complex[2.8310368434643864`, 0.8233232657606013], 
              Complex[4.090875680564112, -0.20755804103448106`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.149808341378722, -2.311725622493253}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7754543472078295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 1, {
              Complex[2.7754543472078295`, -0.9302392405994727], 
              Complex[4.149808341378722, -2.311725622493253]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090565718362365, -0.20156863435089428`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20156863435089428`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 2, {
              Complex[2.8308644950729813`, 0.8279627928769892], 
              Complex[4.090565718362365, -0.20156863435089428`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{4.151090241310992, -2.316584509692524}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7761799258412623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.934475231424826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 1, {
              Complex[2.7761799258412623`, -0.934475231424826], 
              Complex[4.151090241310992, -2.316584509692524]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090267865626448, -0.19562402887272834`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 2, {
              Complex[2.8306993817960873`, 0.8325642407352365], 
              Complex[4.090267865626448, -0.19562402887272834`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.795162677796044, -2.240148389547099}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.795162677796044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1401483895470994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 1, {
              Complex[3.8395927484273855`, -0.6433017314670886], 
              Complex[1.795162677796044, -2.1401483895470994`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.196232266214943, -1.2633793876684913`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.836019007965047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00664507113781796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.196232266214943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 2, {
              Complex[7.836019007965047, 0.00664507113781796], 
              Complex[6.196232266214943, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8301368298409673`, -2.212021181971955}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.874980911856298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.616522179294801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1120211819719548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 1, {
              Complex[3.874980911856298, -0.616522179294801], 
              Complex[1.8301368298409673`, -2.1120211819719548`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.155525231634676, -1.2633781485602358`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0067125107858549355`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 2, {
              Complex[7.795901779221279, 0.0067125107858549355`], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.859366613529838, -2.189405749092226}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025942`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 1, {
              Complex[3.9045700992025942`, -0.5952855745698099], 
              Complex[1.859366613529838, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.122517060306257, -1.263371113059422}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047784`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 2, {
              Complex[7.763484521798688, 0.006786025025047784], 
              Complex[6.122517060306257, -1.163371113059422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.8852354657886525`, -2.170033347705622}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9307507913132285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.577315686227792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 1, {
              Complex[3.9307507913132285`, -0.577315686227792], 
              Complex[1.8852354657886525`, -2.0700333477056225`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.093988110787665, -1.2633606215314777`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 2, {
              Complex[7.735547972440535, 0.006863336573144921], 
              Complex[6.093988110787665, -1.1633606215314776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.908828689419143, -2.1528681311196007`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 1, {
              Complex[3.9546128944921866`, -0.5615718710865848], 
              Complex[1.908828689419143, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.068475300453683, -1.2633476974009692`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604799`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 2, {
              Complex[7.710629285429999, 0.006943461497604799], 
              Complex[6.068475300453683, -1.163347697400969]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9307493118589263`, -2.1373330727564843`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 1, {
              Complex[3.976762799482184, -0.5474736791133856], 
              Complex[1.9307493118589263`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.045167287063117, -1.2633328856106507`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 2, {
              Complex[7.687917286732913, 0.007025882918871683], 
              Complex[6.045167287063117, -1.1633328856106508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9513735684640636`, -2.1230672781048265`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9975793662526633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0230672781048264`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 1, {
              Complex[3.9975793662526633`, -0.5346576120369375], 
              Complex[1.9513735684640636`, -2.0230672781048264`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.023558855884933, -1.263316510563181}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162861`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 2, {
              Complex[7.666906890699566, 0.007110298008162861], 
              Complex[6.023558855884933, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9709549506972726`, -2.109827028796296}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 1, {
              Complex[4.017318225749185, -0.5228778864146381], 
              Complex[1.9709549506972726`, -2.009827028796296]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.003310291269153, -1.2632987794618458`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.647258486238892`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007196517077880158`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 2, {
              Complex[7.647258486238892, 0.007196517077880158], 
              Complex[6.003310291269153, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{1.9896739101964112`, -2.0974384540079667`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 1, {
              Complex[4.036161628380458, -0.5119589442981471], 
              Complex[1.9896739101964112`, -1.9974384540079668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.984180253839811, -1.2632798309089612`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243424`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089611`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 2, {
              Complex[7.628730822140306, 0.007284416332243424], 
              Complex[5.984180253839811, -1.1632798309089611`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0076643409453068`, -2.0857722832958547`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.501770106216406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9857722832958546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 1, {
              Complex[4.054245015542007, -0.501770106216406], 
              Complex[2.0076643409453068`, -1.9857722832958546`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.96599004597708, -1.2632597604074987`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.61114527747392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179249466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.96599004597708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 2, {
              Complex[7.61114527747392, 0.007373913179249466], 
              Complex[5.96599004597708, -1.1632597604074986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0250288646775294`, -2.0747292562304542`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4922109148816928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775294`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.974729256230454`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 1, {
              Complex[4.071672363798729, -0.4922109148816928], 
              Complex[2.0250288646775294`, -1.974729256230454]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.948603001807256, -1.2632386348615994`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.594365254745728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033915`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 2, {
              Complex[7.594365254745728, 0.007464952252033915], 
              Complex[5.948603001807256, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.041848212945115, -2.064231155946587}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.041848212945115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9642311559465873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 1, {
              Complex[4.088525607498784, -0.4832021231088834], 
              Complex[2.041848212945115, -1.9642311559465873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.93191184641344, -1.2632165013453924`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.578283541245461`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0075574969911632525`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.93191184641344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 2, {
              Complex[7.578283541245461, 0.0075574969911632525`], 
              Complex[5.93191184641344, -1.1632165013453923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.058187273894043, -2.054215023114346}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143463`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 1, {
              Complex[4.104870714597596, -0.4746798749981771], 
              Complex[2.058187273894043, -1.9542150231143463`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.915830554816422, -1.263193392670451}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.562814169527114`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007651524322599015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 2, {
              Complex[7.562814169527114, 0.007651524322599015], 
              Complex[5.915830554816422, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.074099147574049, -2.044629270704492}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.074099147574049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.944629270704492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 1, {
              Complex[4.12076176343584, -0.46659179640833665`], 
              Complex[2.074099147574049, -1.944629270704492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.900288896133163, -1.263169331063269}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115720029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163169331063269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 2, {
              Complex[7.547886962653699, 0.00774702115720029], 
              Complex[5.900288896133163, -1.163169331063269]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.0896279570988052`, -2.0354309873904435`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.136243770182482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45889427989730935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0896279570988052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9354309873904436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 1, {
              Complex[4.136243770182482, -0.45889427989730935`], 
              Complex[2.0896279570988052`, -1.9354309873904436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.8852286543048, -1.2631443306747423`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00784398201226336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.8852286543048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 2, {
              Complex[7.533443755733457, 0.00784398201226336], 
              Complex[5.8852286543048, -1.1631443306747422`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.1048108525831113`, -2.0265840128958312`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573493103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 1, {
              Complex[4.151354705396686, -0.45155054573493103`], 
              Complex[2.1048108525831113`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.870600935988343, -1.26311839933984}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021122`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.16311839933984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 2, {
              Complex[7.5194357044269005`, 0.007942407351021122], 
              Complex[5.870600935988343, -1.16311839933984]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.1196794742655443`, -2.0180575310211615`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1196794742655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9180575310211614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 1, {
              Complex[4.166126967125892, -0.44452922359237934`], 
              Complex[2.1196794742655443`, -1.9180575310211614`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.856364206404795, -1.2630915398400686`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705283`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 2, {
              Complex[7.5058213212730225`, 0.008042302396705283], 
              Complex[5.856364206404795, -1.1630915398400687`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.134261043168295, -2.0098250195461778`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4378032933344357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 1, {
              Complex[4.180588479578347, -0.4378032933344357], 
              Complex[2.134261043168295, -1.9098250195461774`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.842482826256841, -1.2630637508268274`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00814367626923343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 2, {
              Complex[7.492565012985164, 0.00814367626923343], 
              Complex[5.842482826256841, -1.1630637508268276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.148579189013273, -2.0018634521265035`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.19476352756891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4313492794933509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 1, {
              Complex[4.19476352756891, -0.4313492794933509], 
              Complex[2.148579189013273, -1.9018634521265034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.828925941917193, -1.2630350275077866`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654009`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 2, {
              Complex[7.479635970943439, 0.008246541346654009], 
              Complex[5.828925941917193, -1.1630350275077865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.162654588850219, -1.994152681912602}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4251466287655523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.162654588850219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 1, {
              Complex[4.208673400536594, -0.4251466287655523], 
              Complex[2.162654588850219, -1.8941526819126022`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.815666629983417, -1.2630053621640014`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614356`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 2, {
              Complex[7.4670073159977095`, 0.008350912786614356], 
              Complex[5.815666629983417, -1.1630053621640013`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.1765054667524413`, -1.9866749586802053`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.22233689673936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4191772220375585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524413`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8866749586802054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 1, {
              Complex[4.22233689673936, -0.4191772220375585], 
              Complex[2.1765054667524413`, -1.8866749586802054`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.802681228429218, -1.2629747445437836`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 2, {
              Complex[7.454655429824251, 0.008456808164000547], 
              Complex[5.802681228429218, -1.1629747445437835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.190147989832311, -1.9794145456947634`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.235770723063745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4134249869532411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.190147989832311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 1, {
              Complex[4.235770723063745, -0.4134249869532411], 
              Complex[2.190147989832311, -1.8794145456947635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.7899488069302, -1.2629431621652236`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00856424719441154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 2, {
              Complex[7.442559425423676, 0.00856424719441154], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.2035965857225785`, -1.9723574121967355`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2035965857225785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 1, {
              Complex[4.248989815735209, -0.4078755867501412], 
              Complex[2.2035965857225785`, -1.8723574121967355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.7774507425522845`, -1.262910600549928}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 2, {
              Complex[7.430700722955541, 0.008673251522090995], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.2168641997657033`, -1.9654909840009633`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2168641997657033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8654909840009635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 1, {
              Complex[4.262007600278324, -0.4025161677361114], 
              Complex[2.2168641997657033`, -1.8654909840009635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.765170376285118, -1.2628770434041632`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995744`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 2, {
              Complex[7.419062706397297, 0.008783844556995744], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.2299625053481056`, -1.9588039393045298`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3973351524058626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045297`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 1, {
              Complex[4.274836204246599, -0.3973351524058626], 
              Complex[2.2299625053481056`, -1.8588039393045297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.753092732368909, -1.2628424727592265`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008896051349859017`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 2, {
              Complex[7.4076304429802775`, 0.008896051349859017], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.2429020774149055`, -1.952286040056727}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847657186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567271`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 1, {
              Complex[4.287486632822466, -0.39232206847657186`], 
              Complex[2.2429020774149055`, -1.8522860400567271`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.741204286938842, -1.2628068690797758`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 2, {
              Complex[7.396390451929993, 0.009009898497034048], 
              Complex[5.741204286938842, -1.1628068690797757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.255692536755631, -1.9459279915891412`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.255692536755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8459279915891411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 1, {
              Complex[4.299968914929404, -0.38746740648134687`], 
              Complex[2.255692536755631, -1.8459279915891411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.729492775798816, -1.262770211346653}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990438`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 2, {
              Complex[7.3853305123250825`, 0.009125414068990438], 
              Complex[5.729492775798816, -1.162770211346653]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.268342670868864, -1.9397213249141592`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.312292225705379`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.839721324914159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 1, {
              Complex[4.312292225705379, -0.3827625002813669], 
              Complex[2.268342670868864, -1.839721324914159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.717947033532342, -1.2627324771191422`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842201`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 2, {
              Complex[7.374439502284715, 0.009242627557842201], 
              Complex[5.717947033532342, -1.1627324771191423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.280860535897551, -1.9336582973639245`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37819942613027685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639244`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 1, {
              Complex[4.324464989862635, -0.37819942613027685`], 
              Complex[2.280860535897551, -1.8336582973639244`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.706556857926958, -1.2626936425804285`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391612`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 2, {
              Complex[7.363707263462426, 0.009361569840391612], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.2932535431430088`, -1.9277318081869488`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.33649496946897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37377091687664876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2932535431430088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.827731808186949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 1, {
              Complex[4.33649496946897, -0.37377091687664876`], 
              Complex[2.2932535431430088`, -1.827731808186949]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.695312895009786, -1.2626536825691625`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00948227315398883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 2, {
              Complex[7.3531244861453, 0.00948227315398883], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.3055285329225494`, -1.9219353264340104`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 1, {
              Complex[4.348389338937684, -0.36947028861032244`], 
              Complex[2.3055285329225494`, -1.8219353264340106`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.684206540989642, -1.2626125705993818`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162612570599382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.162612570599382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.317691837968341, -1.9162628290107484`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8162628290107483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 1, {
              Complex[4.3601547494422475`, -0.3652913776086273], 
              Complex[2.317691837968341, -1.8162628290107483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.67322985816244, -1.262570278870532}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121796`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705319`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 2, {
              Complex[7.332373746308075, 0.009729098555121796], 
              Complex[5.67322985816244, -1.1625702788705319`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.329749338128146, -1.9107087471951665`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.371797384531623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3612284858628568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 1, {
              Complex[4.371797384531623, -0.3612284858628568], 
              Complex[2.329749338128146, -1.8107087471951664`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.662375502422984, -1.2625267782689678`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 2, {
              Complex[7.322190592979878, 0.009855291843704476], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.3417065077888237`, -1.9052679202454823`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 1, {
              Complex[4.38332300838, -0.35727633379543666`], 
              Complex[2.3417065077888237`, -1.8052679202454824`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.65163666048189, -1.2624820383620081`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3121263843706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384737`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 2, {
              Complex[7.3121263843706, 0.009983388579384737], 
              Complex[5.65163666048189, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.353568457177237, -1.899935554980541}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3534300190373758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.353568457177237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 1, {
              Complex[4.394737007836374, -0.3534300190373758], 
              Complex[2.353568457177237, -1.799935554980541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.641006995243321, -1.2624360273853819`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0101134277659673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.641006995243321`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624360273853818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 2, {
              Complex[7.302174830430452, 0.0101134277659673], 
              Complex[5.641006995243321, -1.1624360273853818`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.3653399684829144`, -1.894707190417858}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34968498034030004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794707190417858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 1, {
              Complex[4.40604442922753, -0.34968498034030004`], 
              Complex[2.3653399684829144`, -1.794707190417858]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.630480598081044, -1.2623887122247346`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102454498025258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 2, {
              Complex[7.292330070281435, 0.0102454498025258], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.3770255275795718`, -1.889578666715864}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 1, {
              Complex[4.417250010699276, -0.3460369658605057], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.620051946974448, -1.2623400583917028`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 2, {
              Complex[7.282586630397876, 0.010379496510400108`], 
              Complex[5.620051946974448, -1.162340058391703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.3886293519885573`, -1.8845460977964326`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3424820051832386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3886293519885573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7845460977964327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 1, {
              Complex[4.428358210745747, -0.3424820051832386], 
              Complex[2.3886293519885573`, -1.7845460977964327`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.609715869645588, -1.262290029994955}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 2, {
              Complex[7.272939387787106, 0.010515611164854503`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.400155415619293, -1.8796058471281263`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456088024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 1, {
              Complex[4.439373233467539, -0.33901638456088024`], 
              Complex[2.400155415619293, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.599467510982896, -1.2622385897064985`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 2, {
              Complex[7.263383537456196, 0.010653838531129405`], 
              Complex[5.599467510982896, -1.1622385897064984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.411607470734254, -1.8747545062354523`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7747545062354526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 1, {
              Complex[4.450299051011203, -0.3356366249244734], 
              Complex[2.411607470734254, -1.7747545062354526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.589302304154469, -1.262185698723466}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.589302304154469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234662`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 2, {
              Complex[7.253914563567923, 0.010794224904694154`], 
              Complex[5.589302304154469, -1.1621856987234662`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.4229890675144983`, -1.8699888755685132`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 1, {
              Complex[4.461139423570387, -0.3323394622978912], 
              Complex[2.4229890675144983`, -1.7699888755685134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.579215944909336, -1.2621313167255457`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 2, {
              Complex[7.244528213784578, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.434303571543256, -1.865305947424264}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 1, {
              Complex[4.471897917269896, -0.3291218303014389], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.569204368643544, -1.262075401828133}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607955`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162075401828133`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 2, {
              Complex[7.235220476376673, 0.011081667776607955`], 
              Complex[5.569204368643544, -1.162075401828133]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.445554179476746, -1.8607028906574186`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7607028906574185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 1, {
              Complex[4.482577920205065, -0.3259808444790322], 
              Complex[2.445554179476746, -1.7607028906574185`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.559263729872352, -1.2620179105312723`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 2, {
              Complex[7.225987559738016, 0.011228824935798515`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.4567439331314396`, -1.8561770369578585`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.49318265686856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561770369578587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 1, {
              Complex[4.49318265686856, -0.32291378822242117`], 
              Complex[2.4567439331314396`, -1.7561770369578587`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.549390383803342, -1.2619587976643725`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423336`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643726`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 2, {
              Complex[7.216825874002135, 0.011378342532423336`], 
              Complex[5.549390383803342, -1.1619587976643726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.467875732183709, -1.851725868503711}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31991810009861654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037111`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 1, {
              Complex[4.503715201163001, -0.31991810009861654`], 
              Complex[2.467875732183709, -1.7517258685037111`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.539580869749672, -1.2618980163266773`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.2077320144994355`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266772`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 2, {
              Complex[7.2077320144994355`, 0.011530275257279964`], 
              Complex[5.539580869749672, -1.1618980163266772`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.4789523456499616`, -1.847347006826386}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4789523456499616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.747347006826386`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 1, {
              Complex[4.514178488169752, -0.31699136241415204`], 
              Complex[2.4789523456499616`, -1.747347006826386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.529831896159835, -1.261835517823418}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931235`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 2, {
              Complex[7.198702746831605, 0.011684679656931235`], 
              Complex[5.529831896159835, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.4899764222920586`, -1.8430382027464773`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820609`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3141312908727424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 1, {
              Complex[4.524575324820609, -0.3141312908727424], 
              Complex[2.4899764222920586`, -1.7430382027464777`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.520140327071445, -1.2617712515975434`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370943`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 2, {
              Complex[7.189734993370943, 0.011841614202115798`], 
              Complex[5.520140327071445, -1.1617712515975434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5009505000731345`, -1.8387973272586875`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5349083995992086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31133572520239783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7387973272586876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 1, {
              Complex[4.5349083995992086`, -0.31133572520239783`], 
              Complex[2.5009505000731345`, -1.7387973272586876`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.510503169822831, -1.261705165156914}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 2, {
              Complex[7.180825821018505, 0.012001139360437552`], 
              Complex[5.510503169822831, -1.161705165156914]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5118770147723373`, -1.8346223632600878`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30860262064445365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5118770147723373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.734622363260088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 1, {
              Complex[4.545180291382208, -0.30860262064445365`], 
              Complex[2.5118770147723373`, -1.734622363260088]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.500917563878367, -1.2616372039967811`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01216331767348526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 2, {
              Complex[7.171972430077164, 0.01216331767348526], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.522758307852828, -1.8305113980298926`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30593004021100256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7305113980298925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 1, {
              Complex[4.555393477515928, -0.30593004021100256`], 
              Complex[2.522758307852828, -1.7305113980298925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.4913807706423245`, -1.2615673115173935`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4913807706423245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 2, {
              Complex[7.163172144114485, 0.012328213838552468`], 
              Complex[5.4913807706423245`, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5335966336654496`, -1.8264626163806061`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5655503412120515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380606`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 1, {
              Complex[4.5655503412120515`, -0.3033161476291151], 
              Complex[2.5335966336654496`, -1.726462616380606]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.4818901641520625`, -1.2614954289364901`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164315`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 2, {
              Complex[7.154422400706351, 0.012495894795164315`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5443941660601173`, -1.8224742944105476`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.575653178335505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3007592009004852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5443941660601173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 1, {
              Complex[4.575653178335505, -0.3007592009004852], 
              Complex[2.5443941660601173`, -1.7224742944105478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.4724432225550075`, -1.2614214951964697`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627267`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 2, {
              Complex[7.145720742965965, 0.012666429816627267`], 
              Complex[5.4724432225550075`, -1.1614214951964696`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.55515300446826, -1.81854479379632}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 1, {
              Complex[4.585704203648775, -0.29825754641387064`], 
              Complex[2.55515300446826, -1.7185447937963199`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.463037520285708, -1.261345446865949}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854677`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 2, {
              Complex[7.137064811774601, 0.012839890606854677`], 
              Complex[5.463037520285708, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5658751795119756`, -1.814672556571311}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 1, {
              Complex[4.59570555656919, -0.2958096135553047], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.453670720869239, -1.2612672180354272`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742274`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161267218035427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 2, {
              Complex[7.128452338640535, 0.013016351402742274`], 
              Complex[5.453670720869239, -1.161267218035427]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5765626581891587`, -1.8108561003427044`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 1, {
              Complex[4.605659306489134, -0.2934139097675643], 
              Complex[2.5765626581891587`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.444340570285955, -1.2611867402067303`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013195889082391348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 2, {
              Complex[7.119881139121319, 0.013195889082391348`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5872173486781156`, -1.8070940139050704`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 1, {
              Complex[4.615567457703372, -0.29106901601605945`], 
              Complex[2.5872173486781156`, -1.7070940139050703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.435044890840143, -1.2611039421758812`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01337858327951254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 2, {
              Complex[7.111349106752032, 0.01337858327951254], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.5978411048003505`, -1.8033849532134358`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.625431953982773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 1, {
              Complex[4.625431953982773, -0.2887735826232166], 
              Complex[2.5978411048003505`, -1.7033849532134357`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.425781575481576, -1.2610187499090084`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1028542074287175`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013564516504362847`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 2, {
              Complex[7.1028542074287175`, 0.013564516504362847`], 
              Complex[5.425781575481576, -1.1610187499090083`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.6084357301759398`, -1.7997276376830054`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6084357301759398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6997276376830053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 1, {
              Complex[4.635254682829314, -0.28652632543776696`], 
              Complex[2.6084357301759398`, -1.6997276376830053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.416548582534639, -1.2609310864108734`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608692`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 2, {
              Complex[7.094394474201806, 0.013753774271608692`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.6190029821022605`, -1.7961208467863325`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6190029821022605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6961208467863325`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 1, {
              Complex[4.645037479443607, -0.2843260223090585], 
              Complex[2.6190029821022605`, -1.6961208467863325`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.407343930794649, -1.2608408715855628`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01394644523553291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 2, {
              Complex[7.085968002439294, 0.01394644523553291], 
              Complex[5.407343930794649, -1.1608408715855627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.629544575183531, -1.7925634169220726`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.629544575183531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6925634169220725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 1, {
              Complex[4.654782130432772, -0.2821715098398556], 
              Complex[2.629544575183531, -1.6925634169220725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.398165694955262, -1.2607480220888432`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0775729453237535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014142621333044105`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 2, {
              Complex[7.0775729453237535`, 0.014142621333044105`], 
              Complex[5.398165694955262, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.640062184735899, -1.789054238532184}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.66449037728374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800616803939439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 1, {
              Complex[4.66449037728374, -0.2800616803939439], 
              Complex[2.640062184735899, -1.6890542385321838`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.389012001334582, -1.2606524511716515`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981625`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 2, {
              Complex[7.069207509650975, 0.014342397934981625`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.6505574499902775`, -1.7855922534470892`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6741639196244416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6505574499902775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6855922534470893`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 1, {
              Complex[4.6741639196244416`, -0.2779954793374575], 
              Complex[2.6505574499902775`, -1.6855922534470893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.379881023870964, -1.2605540685141239`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901383`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250833`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 2, {
              Complex[7.060869951901383, 0.014545874006250833`], 
              Complex[5.379881023870964, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.661031977113045, -1.7821764524403947`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.661031977113045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 1, {
              Complex[4.683804418293251, -0.2759719024950629], 
              Complex[2.661031977113045, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.3707709803622485`, -1.2604527800495482`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367323`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 2, {
              Complex[7.052558574558201, 0.014753152275367323`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.6714873420627194`, -1.778805872976879}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27398999380419337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6714873420627194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6788058729768789`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 1, {
              Complex[4.693413498234964, -0.27398999380419337`], 
              Complex[2.6714873420627194`, -1.6788058729768789`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.36168012892486, -1.2603484877775453`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 2, {
              Complex[7.044271722648962, 0.014964339414035003`], 
              Complex[5.36168012892486, -1.1603484877775454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.6819250932991716`, -1.7754795971390893`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6819250932991716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6754795971390894`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 1, {
              Complex[4.702992751240039, -0.27204884315225386`], 
              Complex[2.6819250932991716`, -1.6754795971390894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.352606764651276, -1.2602410895657403`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 2, {
              Complex[7.036007780489124, 0.015179546227436348`], 
              Complex[5.352606764651276, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.692346754360387, -1.7721967497195446`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27014758438335257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 1, {
              Complex[4.712543738542191, -0.27014758438335257`], 
              Complex[2.692346754360387, -1.6721967497195445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.343549216446446, -1.260130478939128}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015398887855965332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 2, {
              Complex[7.027765168608571, 0.015398887855965332`], 
              Complex[5.343549216446446, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.702753826320576, -1.768956496466901}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26828539346253194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669008`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 1, {
              Complex[4.722067993288218, -0.26828539346253194`], 
              Complex[2.702753826320576, -1.6689564964669008`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.33450584402538, -1.2600165448562517`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198301`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.33450584402538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 2, {
              Complex[7.019542340843494, 0.015622483989198301`], 
              Complex[5.33450584402538, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.713147790142196, -1.7657580424757262`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2664614867867361`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.713147790142196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6657580424757261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 1, {
              Complex[4.731567022892644, -0.2664614867867361], 
              Complex[2.713147790142196, -1.6657580424757261`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.325475035055748, -1.259899171471262}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959828`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 2, {
              Complex[7.011337781577717, 0.015850459092959828`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.7235301089335913`, -1.7626006307106497`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 1, {
              Complex[4.741042311288871, -0.26467511963294066`], 
              Complex[2.7235301089335913`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.316455202430543, -1.2597782378808233`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.0031500031188445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01608294265041594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 2, {
              Complex[7.0031500031188445`, 0.01608294265041594], 
              Complex[5.316455202430543, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.7339022301229705`, -1.7594835406566922`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.750495321087509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 1, {
              Complex[4.750495321087509, -0.26292558473487154`], 
              Complex[2.7339022301229705`, -1.6594835406566921`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.307444781657182, -1.2596536178547648`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159653617854765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 2, {
              Complex[6.994977543195845, 0.016320069418202385`], 
              Complex[5.307444781657182, -1.159653617854765]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.7442655875587194`, -1.7564060870885485`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.759927495651799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 1, {
              Complex[4.759927495651799, -0.2612122109807511], 
              Complex[2.7442655875587194`, -1.6564060870885486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.2984422283503445`, -1.259525179549259}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565742`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 2, {
              Complex[6.986818962565742, 0.016561979698683844`], 
              Complex[5.2984422283503445`, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.754621603545414, -1.753367618952438}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25953436222533105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.754621603545414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.653367618952438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 1, {
              Complex[4.769340261099353, -0.25953436222533105`], 
              Complex[2.754621603545414, -1.653367618952438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.289446015816816, -1.2593927852012239`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 2, {
              Complex[6.978672842717983, 0.01680881962953307], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.764971690824241, -1.7503675183549192`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.764971690824241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 1, {
              Complex[4.778735028238791, -0.2578914362102898], 
              Complex[2.764971690824241, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.2804546327214155`, -1.259256290802515}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919475`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.2804546327214155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 2, {
              Complex[6.970537783665924, 0.017060741491919475`], 
              Complex[5.2804546327214155`, -1.159256290802515]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.775317254506115, -1.7474051996538633`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2562828635878305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 1, {
              Complex[4.788113194449318, -0.2562828635878305], 
              Complex[2.775317254506115, -1.6474051996538635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.271466580823748, -1.2591155457523544`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714277`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 2, {
              Complex[6.962412401815591, 0.017317904038714277`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.7856596939652962`, -1.7444801086473978`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.797476145510829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652962`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647398`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 1, {
              Complex[4.797476145510829, -0.2547081070429693], 
              Complex[2.7856596939652962`, -1.644480108647398]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.262480372776144, -1.2589703924863027`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017580472844237614`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 2, {
              Complex[6.954295327902444, 0.017580472844237614`], 
              Complex[5.262480372776144, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.796000404700962, -1.7415917218573371`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.641591721857337`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 1, {
              Complex[4.806825257391718, -0.2531666605106765], 
              Complex[2.796000404700962, -1.641591721857337]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.253494529973698, -1.258820666079929}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.9461852049875565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0178486206772136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.253494529973698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 2, {
              Complex[6.9461852049875565`, 0.0178486206772136], 
              Complex[5.253494529973698, -1.1588206660799292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.8063407801738793`, -1.7387395459042159`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25165804848463746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 1, {
              Complex[4.8161618980011855`, -0.25165804848463746`], 
              Complex[2.8063407801738793`, -1.6387395459042158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.24450758044773, -1.2586661938251582`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 2, {
              Complex[6.938080686504964, 0.018122527898744745`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.816682213625118, -1.7359231169716283`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25018182541497647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 1, {
              Complex[4.825487428912641, -0.25018182541497647`], 
              Complex[2.816682213625118, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.235518056794405, -1.2585067947770958`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018402382887287818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 2, {
              Complex[6.929980434352448, 0.018402382887287818`], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.8270260998834296`, -1.733142000358156}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.8270260998834296`, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.226524494130514, -1.2583422792689294`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018335`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 2, {
              Complex[6.921883117018335, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.8373738371679256`, -1.7303957901157312`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8441105864437315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24732491072033733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 1, {
              Complex[4.8441105864437315`, -0.24732491072033733`], 
              Complex[2.8373738371679256`, -1.6303957901157313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.217525428068778, -1.2581724483922543`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336757`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 2, {
              Complex[6.913787407737206, 0.018980732522336757`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.847726828892448, -1.7276841087738217`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8534109197605035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24594347356467763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 1, {
              Complex[4.8534109197605035`, -0.24594347356467763`], 
              Complex[2.847726828892448, -1.6276841087738216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.208519392705085, -1.257997093439962}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019279648259930976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 2, {
              Complex[6.90569198266763, 0.019279648259930976`], 
              Complex[5.208519392705085, -1.1579970934399622`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.858086485478033, -1.7250066071493986`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 1, {
              Complex[4.862705560115598, -0.24459293369624502`], 
              Complex[2.858086485478033, -1.6250066071493985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.199504918610364, -1.2578159953084995`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 2, {
              Complex[6.897595519085279, 0.01958535502317052], 
              Complex[5.199504918610364, -1.1578159953084994`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.868454226179847, -1.722362964243187}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931042018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.622362964243187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 1, {
              Complex[4.871995862670491, -0.24327298931042018`], 
              Complex[2.868454226179847, -1.622362964243187]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.190480530819805, -1.257628923856052}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157628923856052`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 2, {
              Complex[6.889496693584875, 0.019898088759987564`], 
              Complex[5.190480530819805, -1.157628923856052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.8788314809349784`, -1.719752887223283}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 1, {
              Complex[4.881283186323275, -0.24198336673385498`], 
              Complex[2.8788314809349784`, -1.6197528872232831`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.181444746812216, -1.2574356372128108`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815565`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 2, {
              Complex[6.881394180284588, 0.020218096688815565`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.8892196922375373`, -1.717176111497809}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 1, {
              Complex[4.8905688953969415`, -0.24072382041628837`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.1723960744723065`, -1.2572358810391413`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 2, {
              Complex[6.873286649026525, 0.020545637985932896`], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.899620317047638, -1.7146324008788782`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.899620317047638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6146324008788784`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 1, {
              Complex[4.899854361345617, -0.23949413300958722`], 
              Complex[2.899620317047638, -1.6146324008788784`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.163333010028644, -1.2570293877270224`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02088098452409496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.163333010028644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270224`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 2, {
              Complex[6.865172763566979, 0.02088098452409496], 
              Complex[5.163333010028644, -1.1570293877270224`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9100348287409497`, -1.7121215478408178`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.909140964484508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9100348287409497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.612121547840818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 1, {
              Complex[4.909140964484508, -0.23829411553630872`], 
              Complex[2.9100348287409497`, -1.612121547840818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.1542540359599105`, -1.2568158755396661`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02122442166697627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 2, {
              Complex[6.857051179750135, 0.02122442166697627], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.920464719105737, -1.7096433738762482`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 1, {
              Complex[4.918430095749454, -0.23712360765068738`], 
              Complex[2.920464719105737, -1.6096433738762481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.145157618862018, -1.2565950476836856`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021576249124412635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1565950476836857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 2, {
              Complex[6.848920543658824, 0.021576249124412635`], 
              Complex[5.145157618862018, -1.1565950476836857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9309115003944672`, -1.707197729954391}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9309115003944672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6071977299543911`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 1, {
              Complex[4.927723158492043, -0.23598247799562727`], 
              Complex[2.9309115003944672`, -1.6071977299543911`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.136042207268362, -1.2563665913076099`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 2, {
              Complex[6.840779489735858, 0.021936781873947226`], 
              Complex[5.136042207268362, -1.1563665913076098`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.941376707437419, -1.7047844970867336`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703164995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.234870624659986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.941376707437419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 1, {
              Complex[4.9370215703164995`, -0.234870624659986], 
              Complex[2.941376707437419, -1.6047844970867335`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.126906229415363, -1.2561301764198547`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02230635115475651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198546`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 2, {
              Complex[6.832626638869334, 0.02230635115475651], 
              Complex[5.126906229415363, -1.1561301764198546`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9518618998259756`, -1.702403587006065}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23378797574121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060649`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 1, {
              Complex[4.946326764964685, -0.23378797574121], 
              Complex[2.9518618998259756`, -1.6024035870060649`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.117748090945094, -1.255885454718557}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684493`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 2, {
              Complex[6.824460596435172, 0.022685305540684493`], 
              Complex[5.117748090945094, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9623686641736446`, -1.7000549429658451`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 1, {
              Complex[4.955640194255799, -0.23273449001922958`], 
              Complex[2.9623686641736446`, -1.6000549429658453`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.108566172536499, -1.255632058324808}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8162799502898626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02307401209983014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.108566172536499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 2, {
              Complex[6.8162799502898626`, 0.02307401209983014], 
              Complex[5.108566172536499, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.972898616463317, -1.6977385406678667`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.972898616463317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5977385406678666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 1, {
              Complex[4.9649633300876665`, -0.23171015774841358`], 
              Complex[2.972898616463317, -1.5977385406678666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0993588274563555`, -1.255369598409927}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8080832687062705`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02347285764894477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0993588274563555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 2, {
              Complex[6.8080832687062705`, 0.02347285764894477], 
              Complex[5.0993588274563555`, -1.1553695984099268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9834534044896506`, -1.6954543893273726`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23071500157543234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9834534044896506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5954543893273725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 1, {
              Complex[4.974297666506787, -0.23071500157543234`], 
              Complex[2.9834534044896506`, -1.5954543893273725`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.090124379020649, -1.2550976637063445`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808084`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 2, {
              Complex[6.799869098244956, 0.023882250111808084`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{2.9940347104060314`, -1.6932025328859934`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2297490775919431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 1, {
              Complex[4.983644721854632, -0.2297490775919431], 
              Complex[2.9940347104060314`, -1.5932025328859936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.080861117956596, -1.2548158188904899`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.791635961553228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024302619991774015`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 2, {
              Complex[6.791635961553228, 0.024302619991774015`], 
              Complex[5.080861117956596, -1.15481581889049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0046442533861, -1.690983051384341}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 1, {
              Complex[4.993006040998136, -0.22881247653229753`], 
              Complex[3.0046442533861, -1.5909830513843408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.071567299655017, -1.2545236028247546`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02473442196983401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1545236028247545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 2, {
              Complex[6.783382355083753, 0.02473442196983401], 
              Complex[5.071567299655017, -1.1545236028247545`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0152837924104223`, -1.6887960625076495`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.002383197652629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22790532512782447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5887960625076496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 1, {
              Complex[5.002383197652629, -0.22790532512782447`], 
              Complex[3.0152837924104223`, -1.5887960625076496`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0622411413021275`, -1.2542205266440742`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 2, {
              Complex[6.775106746724163, 0.025178136640842865`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259551291896347`, -1.686641723319602}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.0259551291896347`, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.05288081887921, -1.2539060716710013`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 2, {
              Complex[6.766807573328626, 0.025634272402031203`], 
              Complex[5.05288081887921, -1.1539060716710012`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.036660111236013, -1.6845202322015447`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22618006752276337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 1, {
              Complex[5.021191477253694, -0.22618006752276337`], 
              Complex[3.036660111236013, -1.5845202322015448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.043484464017904, -1.2535796871411728`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026103367509584394`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153579687141173`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 2, {
              Complex[6.7584832381419595`, 0.026103367509584394`], 
              Complex[5.043484464017904, -1.153579687141173]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0474006350962957`, -1.6824318310164634`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 1, {
              Complex[5.030625914253164, -0.22536240942454527`], 
              Complex[3.0474006350962957`, -1.5824318310164633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.034050160698048, -1.2532407877189191`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320965892`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 2, {
              Complex[6.750132108106198, 0.026585992320965892`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.058178649759413, -1.6803768075197019`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 1, {
              Complex[5.040082822310154, -0.22457510122598123`], 
              Complex[3.058178649759413, -1.5803768075197018`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.024575941774229, -1.2528887507802409`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.741752511039166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027082751742796587`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 2, {
              Complex[6.741752511039166, 0.027082751742796587`], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0689961602536635`, -1.6783554980412638`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.578355498041264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 1, {
              Complex[5.049563958105736, -0.22381847645779854`], 
              Complex[3.0689961602536635`, -1.578355498041264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.0150597853162315`, -1.252522913437557}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 2, {
              Complex[6.733342732673844, 0.027594287906544415`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0798552314489034`, -1.6763682904678336`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2230929169293575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 1, {
              Complex[5.059071123576936, -0.2230929169293575], 
              Complex[3.0798552314489034`, -1.5763682904678338`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.005499610747705, -1.25214256927739}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028121283097053466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 2, {
              Complex[6.724901013546819, 0.028121283097053466`], 
              Complex[5.005499610747705, -1.1521425692773901`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0907579920802766`, -1.67441562755638}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0686061691627415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22239885565995443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563799`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 1, {
              Complex[5.0686061691627415`, -0.22239885565995443`], 
              Complex[3.0907579920802766`, -1.5744156275563799`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.9958932747662494`, -1.2517469647784378`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9958932747662494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 2, {
              Complex[6.716425545723423, 0.02866446296210374], 
              Complex[4.9958932747662494`, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.1017066390111157`, -1.6724980106155334`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2217367801348355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 1, {
              Complex[5.078170997228453, -0.2217367801348355], 
              Complex[3.1017066390111157`, -1.5724980106155333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.986238567027153, -1.251335295373272}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819224`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732718`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 2, {
              Complex[6.707914469346526, 0.029224600034819224`], 
              Complex[4.986238567027153, -1.1513352953732718`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.1127034417538186`, -1.6706160035957247`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1127034417538186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 1, {
              Complex[5.087767565681953, -0.22110723592124717`], 
              Complex[3.1127034417538186`, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.976533205571878, -1.2509067011120156`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 2, {
              Complex[6.699365868995314, 0.02980251760487482], 
              Complex[4.976533205571878, -1.1509067011120155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.123750747268463, -1.6687702376348135`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 1, {
              Complex[5.097397891796026, -0.2205108306846833], 
              Complex[3.123750747268463, -1.5687702376348136`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.966774831981249, -1.2504602618808105`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 2, {
              Complex[6.6907777698397455`, 0.030399093979211242`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.134850985060283, -1.6669614161122603`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.134850985060283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5669614161122603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 1, {
              Complex[5.107064056251541, -0.21994823865092936`], 
              Complex[3.134850985060283, -1.5669614161122603`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.956961006232221, -1.2499949921214253`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1499949921214252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 2, {
              Complex[6.682148133575791, 0.031015267178413856`], 
              Complex[4.956961006232221, -1.1499949921214252`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.146006672598036, -1.6651903202724232`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272423`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 1, {
              Complex[5.116768207416753, -0.21942020556585173`], 
              Complex[3.146006672598036, -1.565190320272423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.947089201235957, -1.249509834990993}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126103`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196406`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1495098349909931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 2, {
              Complex[6.673474854126103, 0.031652040121196406`], 
              Complex[4.947089201235957, -1.1495098349909931`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.1572204210764316`, -1.663457815486074}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 1, {
              Complex[5.126512565878384, -0.21892755421211527`], 
              Complex[3.1572204210764316`, -1.563457815486074]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.937156797033987, -1.2490036558923021`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090323`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 2, {
              Complex[6.664755753090323, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.168494941546648, -1.6617648582291664`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5617648582291666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 1, {
              Complex[5.1362994292403545`, -0.21847119055042008`], 
              Complex[3.168494941546648, -1.5617648582291666`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.927161074628285, -1.2484752352951793`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641234991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 2, {
              Complex[6.655988574929111, 0.03299175641234991], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.179833051439645, -1.6601125038693656`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.14613117720593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 1, {
              Complex[5.14613117720593, -0.21805211056251347`], 
              Complex[3.179833051439645, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.917099209420433, -1.2479232607580628`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 2, {
              Complex[6.647170981866001, 0.03369708483581623], 
              Complex[4.917099209420433, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.191237681507363, -1.658501915364159}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2176714078844637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 1, {
              Complex[5.156010276958657, -0.2176714078844637], 
              Complex[3.191237681507363, -1.5585019153641588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.906968264234701, -1.247346318045541}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.638300548491651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03442779801852966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 2, {
              Complex[6.638300548491651, 0.03442779801852966], 
              Complex[4.906968264234701, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.2027118832068147`, -1.6569343729898858`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21733028233169835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989886`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 1, {
              Complex[5.1659392888565, -0.21733028233169835`], 
              Complex[3.2027118832068147`, -1.556934372989886]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.896765181899932, -1.2467428812221828`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.035185322904060665`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146742881222183`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 2, {
              Complex[6.629374756056008, 0.035185322904060665`], 
              Complex[4.896765181899932, -1.146742881222183]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.214258836551336, -1.6554112852390446`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5554112852390445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 1, {
              Complex[5.175920872451979, -0.21703004943242468`], 
              Complex[3.214258836551336, -1.5554112852390445`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.886486777365879, -1.246111301584947}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 2, {
              Complex[6.620390986435504, 0.03597119669747853], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.225881858451648, -1.6539342010442932`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1859577928485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21677215110365722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 1, {
              Complex[5.1859577928485665`, -0.21677215110365722`], 
              Complex[3.225881858451648, -1.5539342010442931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.8761297293312476`, -1.2454497952754269`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 2, {
              Complex[6.611346515764966, 0.03678707771053728], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.237584411566566, -1.6525048235121889`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512189`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 1, {
              Complex[5.196052927399867, -0.21655816762459867`], 
              Complex[3.237584411566566, -1.552504823512189]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.86569057136354, -1.2447564293886}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 2, {
              Complex[6.60223850772765, 0.037634757497710856`], 
              Complex[4.86569057136354, -1.1447564293886001`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.249370113678695, -1.6511250253784864`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21638983108607518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.249370113678695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 1, {
              Complex[5.206209272752709, -0.21638983108607518`], 
              Complex[3.249370113678695, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.8551656824952785`, -1.2440291063659585`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502224`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077786`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.8551656824952785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 2, {
              Complex[6.593064006502224, 0.038516174462077786`], 
              Complex[4.8551656824952785`, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.261242747603762, -1.6497968664306089`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549796866430609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 1, {
              Complex[5.216429952227796, -0.21626904052272736`], 
              Complex[3.261242747603762, -1.549796866430609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.844551277287892, -1.2432655464271394`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.583819929372991`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271393`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 2, {
              Complex[6.583819929372991, 0.03943342913804211], 
              Complex[4.844551277287892, -1.1432655464271393`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.273206271632576, -1.6485226131825368`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21619787896744078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 1, {
              Complex[5.226718223521198, -0.21619787896744078`], 
              Complex[3.273206271632576, -1.5485226131825367`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.833843395364207, -1.242463267754563}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04038880139063545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 2, {
              Complex[6.574503059020016, 0.04038880139063545], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.2852648304909673`, -1.6473047611339124`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909673`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 1, {
              Complex[5.237077486695946, -0.21617863270584675`], 
              Complex[3.2852648304909673`, -1.5473047611339124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.823037890424123, -1.2416195640990149`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 2, {
              Complex[6.565110035519868, 0.04138476980950465], 
              Complex[4.823037890424123, -1.141619564099015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.2974227667841562`, -1.646146059999975}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2974227667841562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.546146059999975`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 1, {
              Complex[5.247511292414013, -0.21621381305374002`], 
              Complex[3.2974227667841562`, -1.546146059999975]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.8121304187769836`, -1.2407314794193451`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.55563734810662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8121304187769836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.140731479419345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 2, {
              Complex[6.55563734810662, 0.04242403362064897], 
              Complex[4.8121304187769836`, -1.140731479419345]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.309684632866044, -1.6450495423633646`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.309684632866044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5450495423633648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 1, {
              Complex[5.258023350333588, -0.21630618103294622`], 
              Complex[3.309684632866044, -1.5450495423633648`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.801116427450051, -1.2397957791050334`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.043509537491681925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 2, {
              Complex[6.546081326768185, 0.043509537491681925`], 
              Complex[4.801116427450051, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.3220552030387207`, -1.6440185562746334`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2164587753829211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 1, {
              Complex[5.268617537562702, -0.2164587753829211], 
              Complex[3.3220552030387207`, -1.5440185562746334`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.789991141967791, -1.2388089172545467`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.789991141967791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 2, {
              Complex[6.536438133786875, 0.04464449966811471], 
              Complex[4.789991141967791, -1.1388089172545466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.3345394859397888`, -1.6430568024175478`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 1, {
              Complex[5.279297907015237, -0.21667494441768237`], 
              Complex[3.3345394859397888`, -1.5430568024175477`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.778749553944276, -1.237766999393233}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378125`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04583244395046667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 2, {
              Complex[6.526703755378125, 0.04583244395046667], 
              Complex[4.778749553944276, -1.1377669993932331`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.347142736911111, -1.6421683765599402`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.290068695455681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2169583823220915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 1, {
              Complex[5.290068695455681, -0.2169583823220915], 
              Complex[3.347142736911111, -1.54216837655994]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.767386408695087, -1.2366657399098007`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106414795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399098006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 2, {
              Complex[6.516873993640986, 0.047077236106414795`], 
              Complex[4.767386408695087, -1.1366657399098006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.359870470056673, -1.6413578181336934`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 1, {
              Complex[5.300934330939945, -0.21731317057992391`], 
              Complex[3.359870470056673, -1.5413578181336933`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.75589619316095, -1.2355004133676155`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.048383125410604036`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 2, {
              Complex[6.50694445911303, 0.048383125410604036`], 
              Complex[4.75589619316095, -1.1355004133676156`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.3727284695824946`, -1.6406301659307434`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 1, {
              Complex[5.311899439255095, -0.21774382534019782`], 
              Complex[3.3727284695824946`, -1.5406301659307433`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.744273124550118, -1.2342657987037837`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037839`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 2, {
              Complex[6.496910564326775, 0.04975479211876465], 
              Complex[4.744273124550118, -1.1342657987037839`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.385722799858256, -1.6399910220686347`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.218255351659741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 1, {
              Complex[5.322968848822687, -0.218255351659741], 
              Complex[3.385722799858256, -1.5399910220686348`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.732511140259883, -1.2329561151622774`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902967`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05119740181429564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 2, {
              Complex[6.486767518902967, 0.05119740181429564], 
              Complex[4.732511140259883, -1.1329561151622776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.3988598134359265`, -1.6394466255711593`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3988598134359265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 1, {
              Complex[5.334147593347899, -0.21885330570991685`], 
              Complex[3.3988598134359265`, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.720603889841738, -1.2315649486154923`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 2, {
              Complex[6.476510326898408, 0.05271666771536851], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.412146155988547, -1.6390039371286067`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2195438662043099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.412146155988547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 1, {
              Complex[5.34544091125561, -0.2195438662043099], 
              Complex[3.412146155988547, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.70854473004717, -1.2300851667094983`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054318922199527095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1300851667094982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 2, {
              Complex[6.466133787367247, 0.054318922199527095`], 
              Complex[4.70854473004717, -1.1300851667094982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.4255887667699536`, -1.6386707368477484`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22033391649033324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386707368477486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 1, {
              Complex[5.356854240636268, -0.22033391649033324`], 
              Complex[3.4255887667699536`, -1.5386707368477486`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.696326724353138, -1.2285088210227606`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.455632499412816`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 2, {
              Complex[6.455632499412816, 0.05601119898888057], 
              Complex[4.696326724353138, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.4391948727143964`, -1.638455737070505}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.368393208004248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.221231138946749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 1, {
              Complex[5.368393208004248, -0.221231138946749], 
              Complex[3.4391948727143964`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.683942648848311, -1.2268270341592393`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.057801327638013704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 2, {
              Complex[6.445000873427293, 0.057801327638013704`], 
              Complex[4.683942648848311, -1.1268270341592395`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.4529719736549263`, -1.6383687126232325`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4529719736549263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 1, {
              Complex[5.380063608617472, -0.22224412353114423`], 
              Complex[3.4529719736549263`, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.671385007001143, -1.225029869413817}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168787976`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 2, {
              Complex[6.434233150770422, 0.059698042168787976`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.4669278152904957`, -1.638420651137554}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.3918713753777405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22338249250843528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4669278152904957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384206511375542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 1, {
              Complex[5.3918713753777405`, -0.22338249250843528`], 
              Complex[3.4669278152904957`, -1.5384206511375542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.658646056679822, -1.2231061803689867`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06171110588324154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.658646056679822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 2, {
              Complex[6.423323434867787, 0.06171110588324154], 
              Complex[4.658646056679822, -1.1231061803689866`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.4810703454089245`, -1.638623926325345}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22465704353173413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 1, {
              Complex[5.403822532373675, -0.22465704353173413`], 
              Complex[3.4810703454089245`, -1.5386239263253452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6457178539169055`, -1.221043437540103}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.41226573766677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6457178539169055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.121043437540103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 2, {
              Complex[6.41226573766677, 0.06385145452602912], 
              Complex[4.6457178539169055`, -1.121043437540103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.495407647393269, -1.6389924972372534`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4159231278759306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2260799132874317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.495407647393269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5389924972372535`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 1, {
              Complex[5.4159231278759306`, -0.2260799132874317], 
              Complex[3.495407647393269, -1.5389924972372535`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6325923193910725`, -1.2188275290397077`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0661313600083585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397076`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 2, {
              Complex[6.401054046640448, 0.0661313600083585], 
              Complex[4.6325923193910725`, -1.1188275290397076`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.509947843100934, -1.6395421364907363`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4281791399671135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.227664763771187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.509947843100934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395421364907362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 1, {
              Complex[5.4281791399671135`, -0.227664763771187], 
              Complex[3.509947843100934, -1.5395421364907362`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.619261335536664, -1.2164425322748185`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157072`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 2, {
              Complex[6.389682419157072, 0.06856461676025134], 
              Complex[4.619261335536664, -1.1164425322748186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.524698954687548, -1.6402906900657312`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 1, {
              Complex[5.440596345893877, -0.22942699279424592`], 
              Complex[3.524698954687548, -1.5402906900657312`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.605716884708901, -1.2138704540789922`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127534`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113870454078992`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 2, {
              Complex[6.378145113127534, 0.07116675231062954], 
              Complex[4.605716884708901, -1.113870454078992]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.539668711719688, -1.64125837029078}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5412583702907798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 1, {
              Complex[5.453180143569078, -0.23138396931833902`], 
              Complex[3.539668711719688, -1.5412583702907798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.591951242060746, -1.2110909376562435`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.366436765503008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07395526269357332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 2, {
              Complex[6.366436765503008, 0.07395526269357332], 
              Complex[4.591951242060746, -1.1110909376562434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.5548642858592667`, -1.6424680817046267`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5548642858592667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 1, {
              Complex[5.465935310345425, -0.23355529236003078`], 
              Complex[3.5548642858592667`, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.577957240848536, -1.2080809366516994`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 2, {
              Complex[6.354552633501295, 0.07694987142173926], 
              Complex[4.577957240848536, -1.1080809366516993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.5702919304393554`, -1.6439457760136316`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901322983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5439457760136317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 1, {
              Complex[5.478865680202782, -0.23596306901322983`], 
              Complex[3.5702919304393554`, -1.5439457760136317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.563728632846567, -1.2048143601285857`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.34248891741965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 2, {
              Complex[6.34248891741965, 0.08017280757570203], 
              Complex[4.563728632846567, -1.1048143601285858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.585956496459983, -1.6457208265493541`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.585956496459983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 1, {
              Complex[5.491973715947516, -0.23863220192231419`], 
              Complex[3.585956496459983, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.549260572342168, -1.2012616980470776`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 2, {
              Complex[6.330243188435803, 0.08364909334179291], 
              Complex[4.549260572342168, -1.1012616980470775`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.601860790294313, -1.6478264033073151`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.547826403307315`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 1, {
              Complex[5.5052599482994165`, -0.2415906683469038], 
              Complex[3.601860790294313, -1.547826403307315]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.534550258420689, -1.197389646163949}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.097389646163949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 2, {
              Complex[6.317814949521484, 0.08740682313953863], 
              Complex[4.534550258420689, -1.097389646163949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.6180047326806646`, -1.6502998152929647`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.51872224974151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 1, {
              Complex[5.51872224974151, -0.24486976056502419`], 
              Complex[3.6180047326806646`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.519597775965091, -1.1931607636269257`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.305206361593249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408550006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 2, {
              Complex[6.305206361593249, 0.09147740408550006], 
              Complex[4.519597775965091, -1.0931607636269256`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.6343842753970184`, -1.6531827657019458`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5323549095256235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.248504239352635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6343842753970184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5531827657019457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 1, {
              Complex[5.5323549095256235`, -0.248504239352635], 
              Complex[3.6343842753970184`, -1.5531827657019457`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.50440717897338, -1.1885332177365602`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.095895709531589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.50440717897338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 2, {
              Complex[6.292423168507695, 0.095895709531589], 
              Complex[4.50440717897338, -1.0885332177365603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.650990035081118, -1.6565214356849034`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2525323274039474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5565214356849035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 1, {
              Complex[5.546147480479421, -0.2525323274039474], 
              Complex[3.650990035081118, -1.5565214356849035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.4889878567307235`, -1.1834607001253283`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255288`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4889878567307235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0834607001253282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 2, {
              Complex[6.279475850255288, 0.10070007254234209`], 
              Complex[4.4889878567307235`, -1.0834607001253282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.667805619167919, -1.6603662733822409`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.56008338350221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 1, {
              Complex[5.56008338350221, -0.2569954375693104], 
              Complex[3.667805619167919, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.473356207864625, -1.1778926376684695`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 2, {
              Complex[6.266381018465573, 0.10593201418800287`], 
              Complex[4.473356207864625, -1.0778926376684697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.6848056561525766`, -1.6647713188313282`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5647713188313284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 1, {
              Complex[5.5741382895514295`, -0.26193749411720313`], 
              Complex[3.6848056561525766`, -1.5647713188313284`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.457537610074802, -1.1717748675240156`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344217985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1116355648600116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 2, {
              Complex[6.2531630344217985`, 0.1116355648600116], 
              Complex[4.457537610074802, -1.0717748675240155`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.7019536132591475`, -1.6697928508801496`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.588278361042629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26740367180599306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 1, {
              Complex[5.588278361042629, -0.26740367180599306`], 
              Complex[3.7019536132591475`, -1.5697928508801495`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.44156860245767, -1.1650509901679482`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239855767662159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 2, {
              Complex[6.239855767662159, 0.11785600339463097`], 
              Complex[4.44156860245767, -1.0650509901679481`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.719199600336582, -1.6754871190552307`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27343836455892495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552309`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 1, {
              Complex[5.602458533258957, -0.27343836455892495`], 
              Complex[3.719199600336582, -1.5754871190552309`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.425499081603797, -1.157664637476592}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.057664637476592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 2, {
              Complex[6.226504314571602, 0.12463782579822917`], 
              Complex[4.425499081603797, -1.057664637476592]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.736478521301465, -1.6819069561624795`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 1, {
              Complex[5.616621151226329, -0.2800822323034728], 
              Complex[3.736478521301465, -1.5819069561624797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.409394150148914, -1.1495628600775762`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 2, {
              Complex[6.213166361508075, 0.13202179213539886`], 
              Complex[4.409394150148914, -1.0495628600775764`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.7537091204741757`, -1.6890972039111027`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28736829986212964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 1, {
              Complex[5.6306954263332605`, -0.28736829986212964`], 
              Complex[3.7537091204741757`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.393335070431697, -1.1407007016791029`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.140041025467066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 2, {
              Complex[6.199912728184148, 0.140041025467066], 
              Complex[4.393335070431697, -1.040700701679103]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.770794613325989, -1.6970891666976438`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 1, {
              Complex[5.644598280659571, -0.29531732776612085`], 
              Complex[3.770794613325989, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377418633740917, -1.1310467452404807`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740917, -1.0310467452404808`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.787625571970205, -1.705894733710109}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.658237106888954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3039330313949995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6058947337101088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 1, {
              Complex[5.658237106888954, -0.3039330313949995], 
              Complex[3.787625571970205, -1.6058947337101088`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.361754274818786, -1.1205889908238686`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.174000384831828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15805167382144333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 2, {
              Complex[6.174000384831828, 0.15805167382144333`], 
              Complex[4.361754274818786, -1.0205889908238686`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8040854242836257`, -1.7155012704525776`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3131980951405518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 1, {
              Complex[5.671514683640783, -0.3131980951405518], 
              Complex[3.8040854242836257`, -1.6155012704525775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.34645857273412, -1.1093399640268058`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 2, {
              Complex[6.161531564303005, 0.16802967600526267`], 
              Complex[4.34645857273412, -1.0093399640268057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8200582761098665`, -1.7258686488669843`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669845`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 1, {
              Complex[5.684335924466963, -0.3230721172560285], 
              Complex[3.8200582761098665`, -1.6258686488669845`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.331647428673965, -1.097339685818803}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17861007860412006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 2, {
              Complex[6.1495151781876825`, 0.17861007860412006`], 
              Complex[4.331647428673965, -0.9973396858188028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8354379364471765`, -1.7369295948434256`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3334924140604973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 1, {
              Complex[5.696615451432763, -0.3334924140604973], 
              Complex[3.8354379364471765`, -1.6369295948434255`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.317427040750873, -1.0846553249905693`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 2, {
              Complex[6.138036634132393, 0.18973028734408134`], 
              Complex[4.317427040750873, -0.9846553249905693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.850136390976634, -1.7485937815375423`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34437794490953016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 1, {
              Complex[5.708284492538861, -0.34437794490953016`], 
              Complex[3.850136390976634, -1.6485937815375424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3038854304700065`, -1.0713771047973333`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934494968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.3038854304700065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9713771047973333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 2, {
              Complex[6.127164733575719, 0.20130934934494968`], 
              Complex[4.3038854304700065`, -0.9713771047973333]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8640899263017108`, -1.7607550217891232`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563571212946327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 1, {
              Complex[5.719295626734264, -0.35563571212946327`], 
              Complex[3.8640899263017108`, -1.6607550217891232`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.291086318485069, -1.0576111105020118`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020118`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 2, {
              Complex[6.1169469267372625`, 0.21325435309295837`], 
              Complex[4.291086318485069, -0.9576111105020118]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.877261765238287, -1.7733000146368139`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.877261765238287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6733000146368138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 1, {
              Complex[5.729624504719875, -0.3671682712416456], 
              Complex[3.877261765238287, -1.6733000146368138`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.279066489303969, -1.0434705428233602`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591816001`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.225467938702334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303969`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233601`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 2, {
              Complex[6.107407591816001, 0.225467938702334], 
              Complex[4.279066489303969, -0.9434705428233601]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.889641123048907, -1.7861168153853226`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378880805741801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 1, {
              Complex[5.7392685732062425`, -0.378880805741801], 
              Complex[3.889641123048907, -1.6861168153853228`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.267836735050403, -1.0290672478326646`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23785537273090274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 2, {
              Complex[6.098549310734496, 0.23785537273090274`], 
              Complex[4.267836735050403, -0.9290672478326645]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.901239519558195, -1.7991015885376012`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 1, {
              Complex[5.748243586852647, -0.3906866010723898], 
              Complex[3.901239519558195, -1.6991015885376013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.257385543344473, -1.0145049639864032`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 2, {
              Complex[6.0903563572018244`, 0.25033002218771333`], 
              Complex[4.257385543344473, -0.9145049639864032]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.912085621903242, -1.8121629626858922`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.756579019389742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.40251041678372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.712162962685892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 1, {
              Complex[5.756579019389742, -0.40251041678372], 
              Complex[3.912085621903242, -1.712162962685892]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.247684254548457, -0.9998749672010694}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.082799285592932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 2, {
              Complex[6.082799285592932, 0.26281672672835515`], 
              Complex[4.247684254548457, -0.8998749672010695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9222198214979054`, -1.8252240340035677`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 1, {
              Complex[5.7643133844056464`, -0.4142898642644484], 
              Complex[3.9222198214979054`, -1.7252240340035676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.238692484798849, -0.9852540673280817}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 2, {
              Complex[6.075839610164614, 0.27525317641875735`], 
              Complex[4.238692484798849, -0.8852540673280818]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.931689378166073, -1.838222515211656}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4259752554682592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 1, {
              Complex[5.771490138844716, -0.4259752554682592], 
              Complex[3.931689378166073, -1.7382225152116562`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.230362981869569, -0.9707044591549226}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 2, {
              Complex[6.069433901558818, 0.2875897604942177], 
              Complex[4.230362981869569, -0.8707044591549227]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9405445393067433`, -1.8511096707348453`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 1, {
              Complex[5.778154476287737, -0.43752848511674636`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.222645506003506, -0.9562747872176812}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524539`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562747872176812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 2, {
              Complex[6.063536993524539, 0.2997884495937324], 
              Complex[4.222645506003506, -0.8562747872176812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.948835712532857, -1.8638486148780138`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44892143644815663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.763848614878014`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 1, {
              Complex[5.784351043372478, -0.44892143644815663`], 
              Complex[3.948835712532857, -1.763848614878014]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.2154896572704255`, -0.9420018475938868}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.05810426649939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3118212015393396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8420018475938867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 2, {
              Complex[6.05810426649939, 0.3118212015393396], 
              Complex[4.2154896572704255`, -0.8420018475938867]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.956611577877951, -1.8764123973101798`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.956611577877951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 1, {
              Complex[5.790122459407806, -0.4601342612759227], 
              Complex[3.956611577877951, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.208846763357218, -0.9279125023887518}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 2, {
              Complex[6.053093127997608, 0.32366824142440037`], 
              Complex[4.208846763357218, -0.8279125023887518]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.963917947183657, -1.8887821416602477`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 1, {
              Complex[5.795508462127412, -0.4711537472500254], 
              Complex[3.963917947183657, -1.7887821416602478`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.202671020177383, -0.9140255411104017}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 2, {
              Complex[6.048463866858472, 0.3353164289039024], 
              Complex[4.202671020177383, -0.8140255411104017]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9707971711833534`, -1.900945377085382}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.800945377085382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 1, {
              Complex[5.800545503681593, -0.4819718787730382], 
              Complex[3.9707971711833534`, -1.800945377085382]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.196920084784546, -0.9003533490732513}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.346757819138651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 2, {
              Complex[6.044180057256696, 0.346757819138651], 
              Complex[4.196920084784546, -0.8003533490732513]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9772879223008815`, -1.9128946175014505`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49258462786579765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8128946175014506`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 1, {
              Complex[5.805266648945753, -0.49258462786579765`], 
              Complex[3.9772879223008815`, -1.8128946175014506`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1915552925709445`, -0.8869033281400236}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 2, {
              Complex[6.04020866039606, 0.3579884536883505], 
              Complex[4.1915552925709445`, -0.7869033281400235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9834252194900257`, -1.9246261926386425`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341316`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 1, {
              Complex[5.809701663341316, -0.5029909709021095], 
              Complex[3.9834252194900257`, -1.8246261926386427`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1865416324253255`, -0.8736790656393454}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 2, {
              Complex[6.036519936690694, 0.36900737727295563`], 
              Complex[4.1865416324253255`, -0.7736790656393453]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.989240598169983, -1.9361393091196957`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8361393091196956`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 1, {
              Complex[5.81387720976465, -0.5131921073476409], 
              Complex[3.989240598169983, -1.8361393091196956`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1818475767949295`, -0.8606812732613809}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.37981585653752803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 2, {
              Complex[6.033087248838311, 0.37981585653752803`], 
              Complex[4.1818475767949295`, -0.7606812732613808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.994762358551031, -1.9474353092142092`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 1, {
              Complex[5.817817100281683, -0.5231908494724433], 
              Complex[3.994762358551031, -1.847435309214209]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.177444833357386, -0.8479085282781001}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781002`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 2, {
              Complex[6.029886810127787, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781002]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.000015848490729, -1.9585170930917857`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.82154256758942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 1, {
              Complex[5.82154256758942, -0.5329911517598145], 
              Complex[4.000015848490729, -1.8585170930917858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.173308062162179, -0.8353578512653347}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.005023753334011, -1.9693886729252437`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.825072534840901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 1, {
              Complex[5.825072534840901, -0.5425977517885691], 
              Complex[4.005023753334011, -1.8693886729252436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.169414585788292, -0.8230251519753933}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124148`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.411012757878331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 2, {
              Complex[6.024100159124148, 0.411012757878331], 
              Complex[4.169414585788292, -0.7230251519753932]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.009806376364359, -1.9800548315018016`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.828423871596708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5520158986267109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8800548315018015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 1, {
              Complex[5.828423871596708, -0.5520158986267109], 
              Complex[4.009806376364359, -1.8800548315018015`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.165744108890901, -0.8109055707023488}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023488`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 2, {
              Complex[6.021478203650237, 0.4210179459473805], 
              Complex[4.165744108890901, -0.7109055707023488]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.01438190088909, -1.9905208626824327`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 1, {
              Complex[5.831611629629778, -0.5612511491377987], 
              Complex[4.01438190088909, -1.8905208626824326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.162278456114007, -0.7989937377997083}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 2, {
              Complex[6.019016519204634, 0.4308353192168015], 
              Complex[4.162278456114007, -0.6989937377997083]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.018766629721938, -2.000792375423005}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8346492560547185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5703092165540392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 1, {
              Complex[5.8346492560547185`, -0.5703092165540392], 
              Complex[4.018766629721938, -1.9007923754230047`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.159001332605871, -0.787283969636879}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44047065160543597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.687283969636879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 2, {
              Complex[6.016701682863842, 0.44047065160543597`], 
              Complex[4.159001332605871, -0.687283969636879]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.022975200759233, -2.0108751468578676`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 1, {
              Complex[5.837548783508502, -0.5791958590266284], 
              Complex[4.022975200759233, -1.9108751468578675`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.155898108440934, -0.7757704154937822}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937821`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 2, {
              Complex[6.014521685955785, 0.4499297609478431], 
              Complex[4.155898108440934, -0.6757704154937821]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.027020779081279, -2.020775013084857}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 1, {
              Complex[5.840320998393065, -0.5879167986060265], 
              Complex[4.027020779081279, -1.9207750130848573`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.152955626516614, -0.7644471667545322}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 2, {
              Complex[6.012465765819384, 0.4592184279956057], 
              Complex[4.152955626516614, -0.6644471667545322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.030915226970467, -2.030497788821198}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 1, {
              Complex[5.842975588855197, -0.5964776632911527], 
              Complex[4.030915226970467, -1.9304977888211983`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.150162032533434, -0.7533083372307817}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.46834233848697243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 2, {
              Complex[6.010524257826823, 0.46834233848697243`], 
              Complex[4.150162032533434, -0.6533083372307816]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.034669253707697, -2.040049209103389}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.940049209103389`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 1, {
              Complex[5.8455212744613, -0.6048839465011079], 
              Complex[4.034669253707697, -1.940049209103389]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.147506625196923, -0.7423481214415792}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 2, {
              Complex[6.008688465710948, 0.47730704263853463`], 
              Complex[4.147506625196923, -0.6423481214415793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.038292547177894, -2.0494348877721933`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.847965919578021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 1, {
              Complex[5.847965919578021, -0.6131409796537513], 
              Complex[4.038292547177894, -1.9494348877721932`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.144979724610491, -0.7315608361086173}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086172]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.041793889306879, -2.0586602887011347`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9586602887011346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 1, {
              Complex[5.850316632393394, -0.6212539145605388], 
              Complex[4.041793889306879, -1.9586602887011346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.142572556837021, -0.7209409489084483}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.00530341993248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49478020058417976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.142572556837021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6209409489084482`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 2, {
              Complex[6.00530341993248, 0.49478020058417976`], 
              Complex[4.142572556837021, -0.6209409489084482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.045181257244431, -2.0677307066670982`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 1, {
              Complex[5.852579851369117, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140277152714267, -0.7104830975830696}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597039`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 2, {
              Complex[6.003740665139239, 0.5032988771597039], 
              Complex[4.140277152714267, -0.6104830975830695]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.048461912051172, -2.076651255485492}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.976651255485492`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.976651255485492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1380862591666565`, -0.700182101786388}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.600182101786388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 2, {
              Complex[6.0022564620129675`, 0.5116787778163024], 
              Complex[4.1380862591666565`, -0.600182101786388]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.051642476470394, -2.0854268615885543`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 1, {
              Complex[5.856866656504023, -0.6447767740762026], 
              Complex[4.051642476470394, -1.9854268615885544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.135993261431994, -0.6900329694879929}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0008455167911645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431994`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 2, {
              Complex[6.0008455167911645`, 0.5199245263444042], 
              Complex[4.135993261431994, -0.5900329694879929]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.054729003187752, -2.094062261652424}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.858900404144714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265131`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 1, {
              Complex[5.858900404144714, -0.6523609855265131], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.133992114800525, -0.6800308993285685}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 2, {
              Complex[5.999503006012947, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.057727034812089, -2.102562003206255}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 1, {
              Complex[5.860867089220407, -0.6598239647344448], 
              Complex[4.057727034812089, -2.002562003206255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.132077284632823, -0.6701712799937015}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5701712799937015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 2, {
              Complex[5.998224525941573, 0.5360310932164655], 
              Complex[4.132077284632823, -0.5701712799937015]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.060641656654434, -2.1109304474081907`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.010930447408191`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 1, {
              Complex[5.862770761740872, -0.6671697152100748], 
              Complex[4.060641656654434, -2.010930447408191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.130243693579621, -0.6604496874212132}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 2, {
              Complex[5.99700604818503, 0.5439002036016085], 
              Complex[4.130243693579621, -0.5604496874212131]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.063477543241716, -2.1191717733661473`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864615135176838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.019171773366147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 1, {
              Complex[5.864615135176838, -0.6744020624307273], 
              Complex[4.063477543241716, -2.019171773366147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.128486675066933, -0.650861880464071}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.550861880464071`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 2, {
              Complex[5.995843880689526, 0.5516517577146817], 
              Complex[4.128486675066933, -0.550861880464071]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.0662389993771475`, -2.12728998352977}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.866403620807269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0662389993771475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 1, {
              Complex[5.866403620807269, -0.6815246607732992], 
              Complex[4.0662389993771475`, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.126801932234572, -0.6414037954825229}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.559289458304851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825229`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 2, {
              Complex[5.994734633394265, 0.559289458304851], 
              Complex[4.126801932234572, -0.5414037954825229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.06892999644998, -2.1352889097939642`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.035288909793964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 1, {
              Complex[5.868139358018381, -0.6885410007735722], 
              Complex[4.06892999644998, -2.035288909793964]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.125185501625342, -0.632071540225011}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250109`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 2, {
              Complex[5.993675187934444, 0.5668168435275395], 
              Complex[4.125185501625342, -0.5320715402250109]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.071554204602269, -2.1431722200421377`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 1, {
              Complex[5.869825241082359, -0.6954544165180522], 
              Complex[4.071554204602269, -2.0431722200421376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.123633721017262, -0.622861387269734}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697339`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 2, {
              Complex[5.992662670864551, 0.5742372943510572], 
              Complex[4.123633721017262, -0.5228613872697339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.0741150212777635`, -2.1509434249247783`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0741150212777635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.050943424924778`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 1, {
              Complex[5.871463942870232, -0.7022680930260665], 
              Complex[4.0741150212777635`, -2.050943424924778]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.12214320087372, -0.6137697672312324}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 2, {
              Complex[5.991694429947489, 0.5815540419531245], 
              Complex[4.12214320087372, -0.5137697672312324]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.076615596606936, -2.158605884720824}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 1, {
              Complex[5.87305793589056, -0.7089850735194754], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.120710798957503, -0.6047932618845041}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9907680131178696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845041`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 2, {
              Complex[5.9907680131178696`, 0.5887701750046829], 
              Complex[4.120710798957503, -0.5047932618845041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.079058856020895, -2.1661628161692947`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.066162816169295`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 1, {
              Complex[5.874609510991549, -0.7156082665076033], 
              Complex[4.079058856020895, -2.066162816169295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11933359771601, -0.5959285973192019}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989881149781852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11933359771601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4959285973192018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 2, {
              Complex[5.989881149781852, 0.5958886467685798], 
              Complex[4.11933359771601, -0.4959285973192018]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.081447520434109, -2.1736172991891602`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 1, {
              Complex[5.876120794018038, -0.7221404526376911], 
              Complex[4.081447520434109, -2.07361729918916]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11800888409769, -0.5871726372059141}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98903173416212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.60291228196345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11800888409769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 2, {
              Complex[5.98903173416212, 0.60291228196345], 
              Complex[4.11800888409769, -0.4871726372059141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.083784124290591, -2.1809722834290377`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.116734131505035, -0.578522376232897}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9882178104361135`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.609843783360462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.478522376232897`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 2, {
              Complex[5.9882178104361135`, 0.609843783360462], 
              Complex[4.116734131505035, -0.478522376232897]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.086071031729209, -2.1882305946062273`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 1, {
              Complex[5.879030249816932, -0.7349423268176082], 
              Complex[4.086071031729209, -2.088230594606227]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.115506983628505, -0.5699749337538412}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384125`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 2, {
              Complex[5.987437559449537, 0.616685738093364], 
              Complex[4.115506983628505, -0.46997493375384125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.088310451090251, -2.195394940608318}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 1, {
              Complex[5.880431975347878, -0.7412169946624548], 
              Complex[4.088310451090251, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.114325239939221, -0.5615275476732827}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 2, {
              Complex[5.986689286816269, 0.6234406236721283], 
              Complex[4.114325239939221, -0.46152754767328275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.0905044479565715`, -2.2024679173410115`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0905044479565715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1024679173410115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 1, {
              Complex[5.881800536903073, -0.7474106269426304], 
              Complex[4.0905044479565715`, -2.1024679173410115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.113186842647121, -0.5531775685861364}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9859714122405725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45317756858613645`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 2, {
              Complex[5.9859714122405725`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.45317756858613645`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.092654956897793, -2.2094520143136562`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8831374294478636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 1, {
              Complex[5.8831374294478636`, -0.7535254579157133], 
              Complex[4.092654956897793, -2.109452014313656]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.112089864956078, -0.5449224541797798}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 2, {
              Complex[5.985282459919064, 0.6366985832782693], 
              Complex[4.112089864956078, -0.4449224541797797]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.094763792064631, -2.2163496199598405`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.759563629082976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 1, {
              Complex[5.884444051922338, -0.759563629082976], 
              Complex[4.094763792064631, -2.1163496199598404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1110325004689345`, -0.5367597639013433}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898126`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6432061141597182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1110325004689345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4367597639013433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 2, {
              Complex[5.984621049898126, 0.6432061141597182], 
              Complex[4.1110325004689345`, -0.4367597639013433]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.096832656761998, -2.2231630266947926`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 1, {
              Complex[5.885721715038686, -0.7655271940238011], 
              Complex[4.096832656761998, -2.1231630266947925`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.110013053613791, -0.5286871538884813}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 2, {
              Complex[5.983985890278379, 0.6496354995683529], 
              Complex[4.110013053613791, -0.4286871538884813]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.098863152113465, -2.2298944357144084`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.771418122959341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 1, {
              Complex[5.886971648326271, -0.771418122959341], 
              Complex[4.098863152113465, -2.1298944357144083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.109029930978957, -0.5207023721587472}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9833757701714365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 2, {
              Complex[5.9833757701714365`, 0.6559887487872512], 
              Complex[4.109029930978957, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.100856784915978, -2.236545961543078}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 1, {
              Complex[5.888195006507387, -0.7772383070571713], 
              Complex[4.100856784915978, -2.136545961543078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.108081633457669, -0.5128032540504377}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4128032540504377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 2, {
              Complex[5.982789553325939, 0.6622677914714886], 
              Complex[4.108081633457669, -0.4128032540504377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.102814974771636, -2.2431196363389545`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7829895624892167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1431196363389544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 1, {
              Complex[5.88939287527652, -0.7829895624892167], 
              Complex[4.102814974771636, -2.1431196363389544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1071667491158, -0.504987717906231}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.404987717906231`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 2, {
              Complex[5.982226172350083, 0.6684744817167124], 
              Complex[4.1071667491158, -0.404987717906231]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.104739060573038, -2.2496174139664076`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.890566276547081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 1, {
              Complex[5.890566276547081, -0.7886736342555827], 
              Complex[4.104739060573038, -2.1496174139664075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.106283946706006, -0.49725376098988205`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9816846234666565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.674610601893371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.397253760989882`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 2, {
              Complex[5.9816846234666565`, 0.674610601893371], 
              Complex[4.106283946706006, -0.397253760989882]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.106630306409572, -2.256041173845927}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 1, {
              Complex[5.891716173221935, -0.7942921997868309], 
              Complex[4.106630306409572, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1054319697609305`, -0.48959945562569723`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744248`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1054319697609305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 2, {
              Complex[5.981163961744248, 0.6806778662591644], 
              Complex[4.1054319697609305`, -0.38959945562569726`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.108489906954297, -2.262392724592142}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8928434735373925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7998468723371353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.162392724592142`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 1, {
              Complex[5.8928434735373925`, -0.7998468723371353], 
              Complex[4.108489906954297, -2.162392724592142]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.104609631205909, -0.48202294555012615`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501261`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 2, {
              Complex[5.980663296755008, 0.6866779243621379], 
              Complex[4.104609631205909, -0.3820229455501261]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.11031899238399, -2.2686738074506057`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1686738074506056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 1, {
              Complex[5.893949035024501, -0.8053392041803527], 
              Complex[4.11031899238399, -2.1686738074506056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.103815808438449, -0.47452244246479186`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9801817886150515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6926123642464811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3745224424647919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 2, {
              Complex[5.9801817886150515`, 0.6926123642464811], 
              Complex[4.103815808438449, -0.3745224424647919]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.112118632879193, -2.274886099543966}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 1, {
              Complex[5.8950336681265165`, -0.8107706896206484], 
              Complex[4.112118632879193, -2.174886099543966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.103049438827802, -0.46709622278037416`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3670962227803742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 2, {
              Complex[5.979718644368705, 0.6984827154726524], 
              Complex[4.103049438827802, -0.3670962227803742]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.1138898427456025`, -2.2810312169378872`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937887`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 1, {
              Complex[5.896098139506871, -0.8161427678288311], 
              Complex[4.1138898427456025`, -2.181031216937887]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102309515593154, -0.4597426245409174}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35974262454091743`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 2, {
              Complex[5.979273114682199, 0.7042904519630283], 
              Complex[4.102309515593154, -0.35974262454091743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.115633584193734, -2.2871107175367755`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 1, {
              Complex[5.897143175078252, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.101595084023626, -0.452460044518581}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9788444908162806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7100369946836332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 2, {
              Complex[5.9788444908162806`, 0.7100369946836332], 
              Complex[4.101595084023626, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.11735077080964, -2.293126103819013}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.100905238007175, -0.44524693546904004`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978432101850545`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 2, {
              Complex[5.978432101850545, 0.7157237141721114], 
              Complex[4.100905238007175, -0.34524693546904006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.1190422707459655`, -2.299078825420977}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788286036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1190422707459655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.199078825420977`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 1, {
              Complex[5.899177655127287, -0.8319161788286036], 
              Complex[4.1190422707459655`, -2.199078825420977]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.100239116839224, -0.438101803538322}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9780353121353675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538322`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 2, {
              Complex[5.9780353121353675`, 0.7213519329214121], 
              Complex[4.100239116839224, -0.338101803538322]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.120708909659479, -2.3049702815786564`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.837064007532895`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2049702815786563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 1, {
              Complex[5.900168371555868, -0.837064007532895], 
              Complex[4.120708909659479, -2.2049702815786563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.099595902284808, -0.43102320581219805`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97765351894983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.726922927628197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121981`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 2, {
              Complex[5.97765351894983, 0.726922927628197], 
              Complex[4.099595902284808, -0.3310232058121981]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.12235147341849, -2.3108018234353844`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12235147341849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 1, {
              Complex[5.901142200577947, -0.8421588862221204], 
              Complex[4.12235147341849, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.098974815870868, -0.42400974799972296`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977286150346381`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.324009747999723`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 2, {
              Complex[5.977286150346381, 0.7324379313144279], 
              Complex[4.098974815870868, -0.324009747999723]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.123970710601055, -2.3165747562234493`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 1, {
              Complex[5.9020997017701315`, -0.8472019743388878], 
              Complex[4.123970710601055, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.098375116387769, -0.417060082242959}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387769`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 2, {
              Complex[5.976932663165014, 0.7378981353300631], 
              Complex[4.098375116387769, -0.31706008224295895`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.12556733480281, -2.3222903413273137`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.097796097581198, -0.4101729050453713}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 2, {
              Complex[5.976592541201492, 0.7433046912443021], 
              Complex[4.097796097581198, -0.31017290504537126`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.127142026771302, -2.3279497982353834`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.857137221726082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 1, {
              Complex[5.903967825152418, -0.857137221726082], 
              Complex[4.127142026771302, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.097237086017579, -0.40334695531178316`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097237086017579`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178313`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 2, {
              Complex[5.976265293515785, 0.7486587126323615], 
              Complex[4.097237086017579, -0.30334695531178313`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.128695436382012, -2.3335543063870654`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 1, {
              Complex[5.904879437628475, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.096697439107836, -0.3965810124932358}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97595045286828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 2, {
              Complex[5.97595045286828, 0.7539612767642827], 
              Complex[4.096697439107836, -0.2965810124932358]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.130228184469744, -2.3391050069213732`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 1, {
              Complex[5.905776705860622, -0.8668782698647188], 
              Complex[4.130228184469744, -2.239105006921373]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.096176543275776, -0.3898738948304562}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045617`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 2, {
              Complex[5.975647574272541, 0.7592134262018867], 
              Complex[4.096176543275776, -0.28987389483045617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.131740864527742, -2.344603004332967}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.906660069621736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.244603004332967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 1, {
              Complex[5.906660069621736, -0.8716784802620264], 
              Complex[4.131740864527742, -2.244603004332967]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.095673812258773, -0.3832244576900402}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9753562336545505`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900402`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 2, {
              Complex[5.9753562336545505`, 0.764416170309563], 
              Complex[4.095673812258773, -0.2832244576900402]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.133234044285656, -2.3500493680411703`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 1, {
              Complex[5.907529948876621, -0.8764330896595153], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.095188685529604, -0.3766315919878305}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 2, {
              Complex[5.975076026609326, 0.7695704866842139], 
              Complex[4.095188685529604, -0.2766315919878305]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.1347082671764905`, -2.3554451338771334`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937715`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1347082671764905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 1, {
              Complex[5.908386744937715, -0.8811430162906049], 
              Complex[4.1347082671764905`, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.094720626829337, -0.37009422269428555`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2700942226942855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 2, {
              Complex[5.974806567246683, 0.7746773225093267], 
              Complex[4.094720626829337, -0.2700942226942855]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.136164053701613, -2.3607913054940166`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 1, {
              Complex[5.909230841539051, -0.8858091496519157], 
              Complex[4.136164053701613, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.094269122802149, -0.3636113074169849}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698485`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 2, {
              Complex[5.974547487118723, 0.7797375958378123], 
              Complex[4.094269122802149, -0.26361130741698485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.137601902702118, -2.366088855704737}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266088855704737`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 1, {
              Complex[5.910062605835208, -0.8904323517124777], 
              Complex[4.137601902702118, -2.266088855704737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093833681723804, -0.35718183505570616`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9742984342223115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 2, {
              Complex[5.9742984342223115`, 0.7847521968079438], 
              Complex[4.093833681723804, -0.25718183505570613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.139022292544099, -2.3713387277515543`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 1, {
              Complex[5.910882389331387, -0.8950134580602265], 
              Complex[4.139022292544099, -2.271338727751554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093413832316265, -0.35080482452581274`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070431`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2508048245258127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 2, {
              Complex[5.974059072070431, 0.7897219887964374], 
              Complex[4.093413832316265, -0.2508048245258127]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.140425682224579, -2.3765418365114743`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140425682224579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 1, {
              Complex[5.911690528750101, -0.8995532789895435], 
              Complex[4.140425682224579, -2.2765418365114742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.0930091226416065`, -0.344479323545952}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.141812512404396, -2.3816990696412357`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 1, {
              Complex[5.912487346839559, -0.9040526005333869], 
              Complex[4.141812512404396, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.092619119069028, -0.33820440748631514`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 2, {
              Complex[5.973608146499301, 0.7995304720360316], 
              Complex[4.092619119069028, -0.2382044074863151]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.1431832063736325`, -2.3868112886653567`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1431832063736325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2868112886653567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 1, {
              Complex[5.913273153128292, -0.9085121854432783], 
              Complex[4.1431832063736325`, -2.2868112886653567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.092243405309306, -0.3319791782739564}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2319791782739564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.2319791782739564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.1445381709548, -2.391879330010544}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 1, {
              Complex[5.914048244630215, -0.9129327741202399], 
              Complex[4.1445381709548, -2.291879330010544]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.09188158151152, -0.3258027633518866}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09188158151152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 2, {
              Complex[5.973192297371706, 0.8091694575484236], 
              Complex[4.09188158151152, -0.2258027633518866]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.145877797348456, -2.396904005989524}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 1, {
              Complex[5.914812906503919, -0.9173150854995428], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.091533263417343, -0.3196743146888657}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2196743146888657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 2, {
              Complex[5.972996827270754, 0.8139272921843683], 
              Complex[4.091533263417343, -0.2196743146888657]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.14720246192557, -2.4018861057371836`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.915567412669662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.14720246192557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 1, {
              Complex[5.915567412669662, -0.9216598178919512], 
              Complex[4.14720246192557, -2.3018861057371836`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.091198081568593, -0.3135930078369971}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699708`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568593, -0.21359300783699708`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.148512526970577, -2.4068263961017067`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3068263961017066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 1, {
              Complex[5.916312026387238, -0.9259676497839727], 
              Complex[4.148512526970577, -2.3068263961017066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090875680564113, -0.307558041034483}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.207558041034483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 2, {
              Complex[5.9726294970541804`, 0.8233232657606], 
              Complex[4.090875680564113, -0.207558041034483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.149808341378723, -2.4117256224932535`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9170470007976235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 1, {
              Complex[5.9170470007976235`, -0.9302392405994732], 
              Complex[4.149808341378723, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090565718362365, -0.3015686343508945}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 2, {
              Complex[5.972457148662774, 0.8279627928769887], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.151090241310996, -2.416584509692523}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.91777257943106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 1, {
              Complex[5.91777257943106, -0.9344752314248258], 
              Complex[4.151090241310996, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.090267865626448, -0.2956240288727295}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272945`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 2, {
              Complex[5.97229203538588, 0.8325642407352354], 
              Complex[4.090267865626448, -0.19562402887272945`]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.478753355849043, -1.1631402225643317`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 1, {
              Complex[4.976967927486166, 0.006887727487396987], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.800016052466027, -1.1961486271318056`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013243170301699064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 2, {
              Complex[7.398301539299035, -0.013243170301699064`], 
              Complex[8.800016052466027, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.52215878639839, -1.1630554690196362`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368856`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 1, {
              Complex[5.020988084142069, 0.007042959985368856], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.75509227462806, -1.1963255671672883`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 2, {
              Complex[7.352914113679205, -0.013509876715323912`], 
              Complex[8.75509227462806, -1.1963255671672883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.557943371421667, -1.162972548762566}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.057395324277087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 1, {
              Complex[5.057395324277087, 0.007197843246654417], 
              Complex[6.557943371421667, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.718101741665087, -1.1964748219538666`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013751044852511824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 2, {
              Complex[7.315449803449272, -0.013751044852511824`], 
              Complex[8.718101741665087, -1.1964748219538666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.589330078860691, -1.1628888789503165`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961005435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 1, {
              Complex[5.089412494295964, 0.007354951961005435], 
              Complex[6.589330078860691, -1.1628888789503165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.685690080337725, -1.1966097210740347`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 2, {
              Complex[7.282554763488937, -0.013979869598457893`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.61778553109412, -1.1628031728636479`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 1, {
              Complex[5.118506250669166, 0.007515591774090766], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.65633113389032, -1.1967364397628124`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960728994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.65633113389032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 2, {
              Complex[7.252703058118816, -0.014202465960728994`], 
              Complex[8.65633113389032, -1.1967364397628124`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.644124842294817, -1.1627145990756094`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1454918259261815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007680628289981348`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 1, {
              Complex[5.1454918259261815`, 0.007680628289981348], 
              Complex[6.644124842294817, -1.1627145990756094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.629176867782464, -1.1968585230000406`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000406`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 2, {
              Complex[7.225046713694153, -0.01442235766034948], 
              Complex[8.629176867782464, -1.1968585230000406`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.668857252414806, -1.1626225207983636`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533852`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 1, {
              Complex[5.170878634413056, 0.007850743160533852], 
              Complex[6.668857252414806, -1.1626225207983636`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.603697599379135, -1.1969782988821365`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436205`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 2, {
              Complex[7.199056007873822, -0.014641876121436205`], 
              Complex[8.603697599379135, -1.1969782988821365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.69232677922716, -1.1625263894330444`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.69232677922716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 1, {
              Complex[5.19501091123548, 0.008026538528972053], 
              Complex[6.69232677922716, -1.1625263894330444`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.579535601926915, -1.1970974543173976`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274703`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 2, {
              Complex[7.174373102447972, -0.014862729232274703`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.714779367617378, -1.1624256923931877`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338763131`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 1, {
              Complex[5.2181348551047995`, 0.008208588338763131], 
              Complex[6.714779367617378, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.556435217312078, -1.197217311276035}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.150742171455597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248022`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 2, {
              Complex[7.150742171455597, -0.015086273942248022`], 
              Complex[8.556435217312078, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.736398653893476, -1.1623199234705235`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701837667`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 1, {
              Complex[5.240434389619401, 0.008397467701837667], 
              Complex[6.736398653893476, -1.1623199234705235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.534205636043778, -1.1973389757687458`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596052`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 2, {
              Complex[7.127972189674163, -0.015313663264596052`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.757326609412582, -1.1622085635431993`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00859377229372981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 1, {
              Complex[5.262051805853028, 0.00859377229372981], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.512699415121855, -1.1974634260014825`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028891`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 2, {
              Complex[7.1059154551031405`, -0.015545933419028891`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.7776762194252065`, -1.1620910662296873`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178996`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7776762194252065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 1, {
              Complex[5.283100441464033, 0.008798133065178996], 
              Complex[6.7776762194252065`, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.491799285559546, -1.1975915689762855`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.08445439867063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230012`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 2, {
              Complex[7.08445439867063, -0.015784060035230012`], 
              Complex[8.491799285559546, -1.1975915689762855`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.797539667322055, -1.161966845801127}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 1, {
              Complex[5.303672866164795, 0.009011228909084911], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.471409637754663, -1.1977242798043068`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587324`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 2, {
              Complex[7.063493070122277, -0.016028997503587324`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.816993839756788, -1.161835265847092}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935135`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 1, {
              Complex[5.323846388854408, 0.009233798770935135], 
              Complex[6.816993839756788, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.451450795228002, -1.1978624312936876`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942806058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 2, {
              Complex[7.042951411025012, -0.016281708942806058`], 
              Complex[8.451450795228002, -1.1978624312936876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.836104162316992, -1.1616956277315165`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547516`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 1, {
              Complex[5.343686896016404, 0.009466654168547516], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.431855025955326, -1.1980069181435884`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016543191071888962`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 2, {
              Complex[7.022761264330783, -0.016543191071888962`], 
              Complex[8.431855025955326, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.854927356440139, -1.1615471581185315`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00971069285821086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 1, {
              Complex[5.363251612071681, 0.00971069285821086], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.412563676597298, -1.1981586784333542`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831153`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 2, {
              Complex[7.002863505905771, -0.016814496662831153`], 
              Complex[8.412563676597298, -1.1981586784333542`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.873513478358426, -1.1613889949346565`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 1, {
              Complex[5.382591142510597, 0.009966914310096189], 
              Complex[6.873513478358426, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.39352505422987, -1.1983187142405296`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673824`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 2, {
              Complex[6.983205922649462, -0.017096756417673824`], 
              Complex[8.39352505422987, -1.1983187142405296`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.891907468896068, -1.161220171125207}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0102364376771995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 1, {
              Complex[5.401751028707841, 0.0102364376771995], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.374692817528386, -1.1984881127881413`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304287`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 2, {
              Complex[6.963741599119121, -0.017391201699304287`], 
              Complex[8.374692817528386, -1.1984881127881413`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.9101503643132345`, -1.1610395954830415`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427957`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 1, {
              Complex[5.4207729647332625`, 0.010520523036427957`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.356024721208028, -1.1986680693372453`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017699189379580503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 2, {
              Complex[6.944427656372563, -0.017699189379580503`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.9282802700841595`, -1.1608460296816645`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492478`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 1, {
              Complex[5.439695778207934, 0.010820596844492478`], 
              Complex[6.9282802700841595`, -1.1608460296816645`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.337481607819116, -1.1988599130234303`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644347`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 2, {
              Complex[6.925224236986867, -0.018022230071644347`], 
              Complex[8.337481607819116, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.946333169123368, -1.1606380604240905`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 1, {
              Complex[5.458556246931597, 0.011138282794836918`], 
              Complex[6.946333169123368, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.319026572634915, -1.1990651369525753`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018362021154623754`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 2, {
              Complex[6.906093661793765, -0.018362021154623754`], 
              Complex[8.319026572634915, -1.1990651369525753`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.964343616618659, -1.1604140653041306`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775249`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 1, {
              Complex[5.47738980371477, 0.011475439606775249`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.30062424755183, -1.1992854341178676`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070774`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 2, {
              Complex[6.886999703988066, -0.018720486277070774`], 
              Complex[8.30062424755183, -1.1992854341178676`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.982345361327388, -1.160172170534845}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.49623116962678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463417`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 1, {
              Complex[5.49623116962678, 0.011834207760463417`], 
              Complex[6.982345361327388, -1.160172170534845]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.282240162776432, -1.1995227410964955`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8679069390373595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292608`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 2, {
              Complex[6.8679069390373595`, -0.019099823463292608`], 
              Complex[8.282240162776432, -1.1995227410964955`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.00037192564026, -1.1599101980783053`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222368`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 1, {
              Complex[5.515114948423251, 0.012217067867222368`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.26384015300309, -1.1997792920739638`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848780136643827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.26384015300309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 2, {
              Complex[6.848780136643827, -0.019502564592186727`], 
              Complex[8.26384015300309, -1.1997792920739638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.018457172595782, -1.1596255988326747`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.534076210934987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01262691431947491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 1, {
              Complex[5.534076210934987, 0.01262691431947491], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.245389779169422, -1.2000576866004602`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741088`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 2, {
              Complex[6.829583665251547, -0.019931649951741088`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.036635886648769, -1.1593153672755068`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 1, {
              Complex[5.553151097008939, 0.013067149229433932`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.226853738441678, -1.2003609757255187`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 2, {
              Complex[6.810280880968053, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.2003609757255187`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.054944396120724, -1.1589759311366727`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186447`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 1, {
              Complex[5.57237746397503, 0.013541803645186447`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.208195234091123, -1.2006927729717154`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 2, {
              Complex[6.790833471518203, -0.020883251810279772`], 
              Complex[8.208195234091123, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.073421269042285, -1.158603006979818}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.59179561475532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 1, {
              Complex[5.59179561475532, 0.014055695951277586`], 
              Complex[7.073421269042285, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.189375273236829, -1.2010573992945917`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.77120072180202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.189375273236829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 2, {
              Complex[6.77120072180202, -0.021414688765245098`], 
              Complex[8.189375273236829, -1.2010573992945917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.092108121115127, -1.1581914085205158`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 1, {
              Complex[5.611449146258794, 0.014614641743299683`], 
              Complex[7.092108121115127, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.170351853484787, -1.2014600752208564`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 2, {
              Complex[6.751338660172414, -0.021990680088691778`], 
              Complex[8.170351853484787, -1.2014600752208564`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.111050585905176, -1.157734788294595}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 1, {
              Complex[5.631385970822487, 0.01522573618198173], 
              Complex[7.111050585905176, -1.157734788294595]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.151078988162066, -1.2019071795671372`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671372`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 2, {
              Complex[6.731199032484281, -0.02261834895605755], 
              Complex[8.151078988162066, -1.2019071795671372`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.130299515097566, -1.1572252835375136`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251509`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015897740359760885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.130299515097566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 1, {
              Complex[5.651659582251509, 0.015897740359760885`], 
              Complex[7.130299515097566, -1.1572252835375136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.13150550216652, -1.2024066038908514`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.710728032214631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 2, {
              Complex[6.710728032214631, -0.02330648209651109], 
              Complex[8.13150550216652, -1.2024066038908514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.149912504017515, -1.1566530214405542`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819515`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 1, {
              Complex[5.6723306669868805`, 0.016641620135819515`], 
              Complex[7.149912504017515, -1.1566530214405542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.11157350310953, -1.202968247517296}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217648`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 2, {
              Complex[6.689864686007545, -0.024066068896217648`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.169955880282914, -1.156005412968246}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156005412968246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 1, {
              Complex[5.693469206036438, 0.017471313877762278`], 
              Complex[7.169955880282914, -1.156005412968246]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.091216389791244, -1.2036047239664343`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370829316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.091216389791244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 2, {
              Complex[6.668538748914902, -0.024911069370829316`], 
              Complex[8.091216389791244, -1.2036047239664343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.190507361138087, -1.1552661200223417`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805062`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 1, {
              Complex[5.715157284805062, 0.01840485331132215], 
              Complex[7.190507361138087, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.070356192382524, -1.2043323940004818`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004818`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 2, {
              Complex[6.646667892120967, -0.02585953521479532], 
              Complex[8.070356192382524, -1.2043323940004818`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.211659694982883, -1.1544135020746285`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01946604620382397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 1, {
              Complex[5.737492944039842, 0.01946604620382397], 
              Complex[7.211659694982883, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.048899928737553, -1.2051729191751688`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819092`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 2, {
              Complex[6.624153849873984, -0.02693529265819092], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.233525786397049, -1.153418203138091}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.760595598959389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02068708549653934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 1, {
              Complex[5.760595598959389, 0.02068708549653934], 
              Complex[7.233525786397049, -1.153418203138091]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.026734477486407, -1.2061556750293858`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60087699850535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252907`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 2, {
              Complex[6.60087699850535, -0.028170551750252907`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.256246121108599, -1.1522392586053025`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784613887852916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073541263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053025`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 1, {
              Complex[5.784613887852916, 0.022112751073541263`], 
              Complex[7.256246121108599, -1.1522392586053025`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{8.003719151417389, -1.2073216443878656`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.576688506209679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 2, {
              Complex[6.576688506209679, -0.029610108260631308`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.279999873987635, -1.150817525269937}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.150817525269937`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 1, {
              Complex[5.809737407862617, 0.02380748722011311], 
              Complex[7.279999873987635, -1.150817525269937]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.97967458803322, -1.2087299874638697`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.551398595838172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.97967458803322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 2, {
              Complex[6.551398595838172, -0.03131842125415468], 
              Complex[7.97967458803322, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.3050221318566, -1.1490639772295197`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8362148977187704`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.025867986584034483`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 1, {
              Complex[5.8362148977187704`, 0.025867986584034483`], 
              Complex[7.3050221318566, -1.1490639772295197`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.954365525461625, -1.2104697460661467`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 2, {
              Complex[6.5247583609077076`, -0.03339219715471037], 
              Complex[7.954365525461625, -1.2104697460661467`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.3316316615292605`, -1.1468374259621588`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632705032`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 1, {
              Complex[5.864383522178553, 0.028447097632705032`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.927473033284, -1.2126821236194967`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 2, {
              Complex[6.496430480050892, -0.03598429729320674], 
              Complex[7.927473033284, -1.2126821236194967`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.360277468735853, -1.143898450195406}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.143898450195406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 1, {
              Complex[5.894717893374837, 0.03180315785237445], 
              Complex[7.360277468735853, -1.143898450195406]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.898547952604838, -1.2156065553823725`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 2, {
              Complex[6.465940194681213, -0.03935307118737358], 
              Complex[7.898547952604838, -1.2156065553823725`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.391618832430633, -1.1398036000155711`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093549137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 1, {
              Complex[5.927914095850698, 0.03641303093549137], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.866930860848724, -1.2196865044147172`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 2, {
              Complex[6.432591283080758, -0.04397539380088787], 
              Complex[7.866930860848724, -1.2196865044147172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.42665483177688, -1.1336280195460158`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.965024718764882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.42665483177688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 1, {
              Complex[5.965024718764882, 0.04326772266645264], 
              Complex[7.42665483177688, -1.1336280195460158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.831622543975559, -1.2258468389686634`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.050842281493196174`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.831622543975559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 2, {
              Complex[6.395331027411175, -0.050842281493196174`], 
              Complex[7.831622543975559, -1.2258468389686634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.466802670715169, -1.123122290976753}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 1, {
              Complex[6.007534506136696, 0.05476808187732237], 
              Complex[7.466802670715169, -1.123122290976753]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.7912056711960345`, -1.2363369885208018`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 2, {
              Complex[6.352674562767397, -0.06235459303258747], 
              Complex[7.7912056711960345`, -1.2363369885208018`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.512359287571743, -1.1022322984450355`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 1, {
              Complex[6.055705576569382, 0.07734359441247657], 
              Complex[7.512359287571743, -1.1022322984450355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.745383184720152, -1.257211079947235}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.257211079947235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 2, {
              Complex[6.304359656824844, -0.08494182361233364], 
              Complex[7.745383184720152, -1.257211079947235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.552491023448565, -1.0633012820313095`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0979727560579535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11902724764148766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 1, {
              Complex[6.0979727560579535`, 0.11902724764148766`], 
              Complex[7.552491023448565, -1.0633012820313095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.704988630788347, -1.2961258835777565`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 2, {
              Complex[6.261951376465346, -0.12663696940988806`], 
              Complex[7.704988630788347, -1.2961258835777565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.574268139734729, -1.0191412329171001`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996513286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 1, {
              Complex[6.120724694194673, 0.16611165996513286`], 
              Complex[7.574268139734729, -1.0191412329171001`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.682951641637805, -1.3402694180832757`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 2, {
              Complex[6.239060971061035, -0.17373265713468272`], 
              Complex[7.682951641637805, -1.3402694180832757`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.58536879774568, -0.9807872587669512}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 1, {
              Complex[6.132202365530887, 0.20695392178184907`], 
              Complex[7.58536879774568, -0.9807872587669512]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.671593955391059, -1.3786065851349265`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2274473706510705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.214585985032377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 2, {
              Complex[6.2274473706510705`, -0.214585985032377], 
              Complex[7.671593955391059, -1.3786065851349265`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.591990895909476, -0.9479498476029725}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 1, {
              Complex[6.138977875500194, 0.24191392575349455`], 
              Complex[7.591990895909476, -0.9479498476029725]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.664717578441819, -1.4114269055666697`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 2, {
              Complex[6.22053837960052, -0.24955685318475537`], 
              Complex[7.664717578441819, -1.4114269055666697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.596448189109472, -0.9191675975214387}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2725610929770674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 1, {
              Complex[6.143492571886664, 0.2725610929770674], 
              Complex[7.596448189109472, -0.9191675975214387]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.66000866572372, -1.4401917896926066`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125679`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.66000866572372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 2, {
              Complex[6.215892564752815, -0.2802146897125679], 
              Complex[7.66000866572372, -1.4401917896926066`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.599694877117055, -0.89340537281411}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1467493959161805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30000093008350653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.89340537281411`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 1, {
              Complex[6.1467493959161805`, 0.30000093008350653`], 
              Complex[7.599694877117055, -0.89340537281411]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.656512931924067, -1.4659363812164754`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307665007902555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 2, {
              Complex[6.212506903993476, -0.307665007902555], 
              Complex[7.656512931924067, -1.4659363812164754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.602190099828044, -0.8699776507064151}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 1, {
              Complex[6.149229270200796, 0.32496389242763946`], 
              Complex[7.602190099828044, -0.8699776507064151]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.653771155925205, -1.4893462105216064`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2099003979914995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33263826942312247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 2, {
              Complex[6.2099003979914995`, -0.33263826942312247`], 
              Complex[7.653771155925205, -1.4893462105216064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.604182742222913, -0.848416245271418}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271418`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 1, {
              Complex[6.151192034362996, 0.34794816918876065`], 
              Complex[7.604182742222913, -0.848416245271418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6515343755500105`, -1.5108894707826876`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2078131342882505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563266944840694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826876`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 2, {
              Complex[6.2078131342882505`, -0.35563266944840694`], 
              Complex[7.6515343755500105`, -1.5108894707826876`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.605820205415675, -0.8283882117511522}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 1, {
              Complex[6.152791090696166, 0.3693076970042954], 
              Complex[7.605820205415675, -0.8283882117511522]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.649655116243798, -1.5308991136680348`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.206091641374743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.377002150313453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243798`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680348`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 2, {
              Complex[6.206091641374743, -0.377002150313453], 
              Complex[7.649655116243798, -1.5308991136680348`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.607195850080814, -0.8096479618228548}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 1, {
              Complex[6.154123300626686, 0.3893033507690846], 
              Complex[7.607195850080814, -0.8096479618228548]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.648039947400696, -1.549620734094958}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.549620734094958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 2, {
              Complex[6.204638991989324, -0.39700759233314253`], 
              Complex[7.648039947400696, -1.549620734094958]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.608371984798496, -0.7920086413709154}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15525311268908`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 1, {
              Complex[6.15525311268908, 0.40813349152982514`], 
              Complex[7.608371984798496, -0.7920086413709154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.646626493792042, -1.5672411924777163`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777163`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 2, {
              Complex[6.203390674922197, -0.41584736171471215`], 
              Complex[7.646626493792042, -1.5672411924777163`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.60939196819019, -0.7753243442615722}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 1, {
              Complex[6.156225240135477, 0.4259529280523636], 
              Complex[7.60939196819019, -0.7753243442615722]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6453713332226165`, -1.5839064009711152`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 2, {
              Complex[6.202301917203499, -0.4336762721416331], 
              Complex[7.6453713332226165`, -1.5839064009711152`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.610287017953022, -0.7594786249471305}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157071780468366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 1, {
              Complex[6.157071780468366, 0.44288515307919935`], 
              Complex[7.610287017953022, -0.7594786249471305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.644243187304668, -1.5997328108831592`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 2, {
              Complex[6.201340564384263, -0.4506178210463806], 
              Complex[7.644243187304668, -1.5997328108831592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.611080255416451, -0.7443768154213578}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.157816436754414`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 1, {
              Complex[6.157816436754414, 0.45903052180506415`], 
              Complex[7.611080255416451, -0.7443768154213578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6432188767245925`, -1.6148150957352272`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 2, {
              Complex[6.2004828590509335`, -0.46677236810008305`], 
              Complex[7.6432188767245925`, -1.6148150957352272`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.611789218669327, -0.7299407258319837}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669327, -0.7299407258319837]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.642280807952738, -1.6292314506639924`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 2, {
              Complex[6.199710822382092, -0.48222277324174173`], 
              Complex[7.642280807952738, -1.6292314506639924`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.612427484506159, -0.7161048892141159}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682773966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 1, {
              Complex[6.1590677155468105`, 0.48927860682773966`], 
              Complex[7.612427484506159, -0.7161048892141159]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6414153511463985`, -1.6430473477012988`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4970383900429073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 2, {
              Complex[6.199010567153121, -0.4970383900429073], 
              Complex[7.6414153511463985`, -1.6430473477012988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.613005749670385, -0.7028138366825418}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539054`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825418`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 1, {
              Complex[6.159599046539054, 0.5035094122855172], 
              Complex[7.613005749670385, -0.7028138366825418]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.640611758766885, -1.656318260594247}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.656318260594247`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 2, {
              Complex[6.198371175040328, -0.5112779620899692], 
              Complex[7.640611758766885, -1.656318260594247]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.613532572082193, -0.6900200786894211}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248163`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894211`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 1, {
              Complex[6.160079801248163, 0.5172145811965814], 
              Complex[7.613532572082193, -0.6900200786894211]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6398614242223575`, -1.6690916835589533`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6140148915107115`, -0.6776825815576769}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992586`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576769`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 1, {
              Complex[6.160516992248921, 0.5304375419992586], 
              Complex[7.6140148915107115`, -0.6776825815576769]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.639157361075561, -1.681408654757819}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 2, {
              Complex[6.197241770749234, -0.5382232399630632], 
              Complex[7.639157361075561, -1.681408654757819]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.61445840324093, -0.6657655987699652}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61445840324093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699652`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 1, {
              Complex[6.160916358296958, 0.5432161176861706], 
              Complex[7.61445840324093, -0.6657655987699652]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.638493829265324, -1.6933049250204681`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204681`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 2, {
              Complex[6.1967389220498434`, -0.5510102042411112], 
              Complex[7.638493829265324, -1.6933049250204681`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6148678313818445`, -0.6542377611605088}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 1, {
              Complex[6.161282646160605, 0.5555834916479542], 
              Complex[7.6148678313818445`, -0.6542377611605088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6378660616946545`, -1.7048118676611494`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.196270595415879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 2, {
              Complex[6.196270595415879, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.615247132185832, -0.643071359259793}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161619819931483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 1, {
              Complex[6.161619819931483, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.637270060814722, -1.7159571961426485`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 2, {
              Complex[6.195832788389601, -0.5753794785718531], 
              Complex[7.637270060814722, -1.7159571961426485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.615599647619971, -0.6322417704324756}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 1, {
              Complex[6.161931218858729, 0.5791985860418384], 
              Complex[7.615599647619971, -0.6322417704324756]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.636702444963452, -1.7267655369464134`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873219`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 2, {
              Complex[6.1954221248841135`, -0.5870171355873219], 
              Complex[7.636702444963452, -1.7267655369464134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.615928222964841, -0.6217269966329017}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 1, {
              Complex[6.162219678012526, 0.5904955973399486], 
              Complex[7.615928222964841, -0.6217269966329017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.636160330682662, -1.7372588918245429`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.598322077084824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 2, {
              Complex[6.195035734438572, -0.598322077084824], 
              Complex[7.636160330682662, -1.7372588918245429`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.616235297995222, -0.6115072877338223}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1624876216872115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 1, {
              Complex[6.1624876216872115`, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.63564124145883, -1.7474570144780963`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133901`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63564124145883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 2, {
              Complex[6.194671158739191, -0.6093151811133901], 
              Complex[7.63564124145883, -1.7474570144780963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.616522978484024, -0.6015648318155971}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 1, {
              Complex[6.162737136528052, 0.6121732527479825], 
              Complex[7.616522978484024, -0.6015648318155971]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.635143036145728, -1.7573777202744645`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19432627842157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744645`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 2, {
              Complex[6.19432627842157, -0.6200152737048318], 
              Complex[7.635143036145728, -1.7573777202744645`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.616793092860657, -0.5918834984038926}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038926`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 1, {
              Complex[6.162970029380979, 0.6225897638061423], 
              Complex[7.616793092860657, -0.5918834984038926]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.63466385223734, -1.7670371430158245`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.19399925515462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 2, {
              Complex[6.19399925515462, -0.6304394010704694], 
              Complex[7.63466385223734, -1.7670371430158245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.617047237536005, -0.5824486239818051}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163187873495399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 1, {
              Complex[6.163187873495399, 0.6327459028649589], 
              Complex[7.617047237536005, -0.5824486239818051]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.634202060478484, -1.7764499494328057`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.617286813480896, -0.5732468315559044}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 1, {
              Complex[6.163392045750656, 0.642655799962885], 
              Complex[7.617286813480896, -0.5732468315559044]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.633756228225985, -1.7856295196238638`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 2, {
              Complex[6.193392563005681, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.617513055986499, -0.5642658778811124}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1635837568947665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6523323858111203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 1, {
              Complex[6.1635837568947665`, 0.6523323858111203], 
              Complex[7.617513055986499, -0.5642658778811124]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.633325089631601, -1.7945880998355055`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 2, {
              Complex[6.193110249156134, -0.6602042845457751], 
              Complex[7.633325089631601, -1.7945880998355055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.617727059060542, -0.5554945233226202}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1637640762927965`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6617875296457955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226202`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 1, {
              Complex[6.1637640762927965`, 0.6617875296457955], 
              Complex[7.617727059060542, -0.5554945233226202]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.63290752119261, -1.8033369326051631`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63290752119261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 2, {
              Complex[6.192840447329172, -0.6696666607954203], 
              Complex[7.63290752119261, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.617929795566583, -0.546922420377038}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163933952324089`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.546922420377038`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 1, {
              Complex[6.163933952324089, 0.6710321572939456], 
              Complex[7.617929795566583, -0.546922420377038]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.632502521562484, -1.8118863682445574`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 2, {
              Complex[6.192582182972332, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.618122133957997, -0.5385400176762603}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 1, {
              Complex[6.164094229303429, 0.6800763528244183], 
              Complex[7.618122133957997, -0.5385400176762603]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.632109194769857, -1.8202459608400863`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 2, {
              Complex[6.192334586512062, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6183048522674195`, -0.5303384769181545}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 1, {
              Complex[6.164245661604394, 0.6889294464957758], 
              Complex[7.6183048522674195`, -0.5303384769181545]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.631726736184741, -1.8284245513261357`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 2, {
              Complex[6.192096879187744, -0.6968297409230598], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.618478649868707, -0.5223096006529584}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6976000911985042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 1, {
              Complex[6.164388925515003, 0.6976000911985042], 
              Complex[7.618478649868707, -0.5223096006529584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6313544207148105`, -1.8364303397024744`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 2, {
              Complex[6.191868361155921, -0.7055072687737811], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.618644157419197, -0.5144457692358491}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 1, {
              Complex[6.164524629243228, 0.7060963291837467], 
              Complex[7.618644157419197, -0.5144457692358491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.630991592823766, -1.8442709480852433`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1916484014469475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7140103074539125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 2, {
              Complex[6.1916484014469475`, -0.7140103074539125], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.618801945306149, -0.5067398855588762}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.714425650549425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 1, {
              Complex[6.164653321403731, 0.714425650549425], 
              Complex[7.618801945306149, -0.5067398855588762]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6306376580477195`, -1.8519534759784038`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6306376580477195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 2, {
              Complex[6.191436429442565, -0.7223463488774432], 
              Complex[7.6306376580477195`, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.618952530856562, -0.4991853264171731}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618952530856562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171731`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 1, {
              Complex[6.164775498250606, 0.7225950446980729], 
              Complex[7.618952530856562, -0.4991853264171731]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.630292075750293, -1.8594845489107188`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 2, {
              Complex[6.191231927609488, -0.7305223842033103], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6190963845189446`, -0.49177589955865814`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49177589955865814`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 1, {
              Complex[6.164891609869035, 0.7306110457745109], 
              Complex[7.6190963845189446`, -0.49177589955865814`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.629954352907652, -1.8668703613890223`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619233935186141, -0.4845058056239236}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 1, {
              Complex[6.165002065498246, 0.7384797729243929], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.629624038754352, -1.8741167149612878`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.746420164884856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 2, {
              Complex[6.190843493278558, -0.746420164884856], 
              Complex[7.629624038754352, -1.8741167149612878`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6193655747968485`, -0.4773696043103947}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165107238125894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4773696043103947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 1, {
              Complex[6.165107238125894, 0.7462069660795168], 
              Complex[7.6193655747968485`, -0.4773696043103947]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.629300720152119, -1.881229052055075}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 2, {
              Complex[6.190658739339741, -0.7541537725552647], 
              Complex[7.629300720152119, -1.881229052055075]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619491662328772, -0.47036218420022063`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 1, {
              Complex[6.165207468468806, 0.7537980178639987], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.628984017568608, -1.8882124861522416`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 2, {
              Complex[6.190479804059834, -0.7617511664534368], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619612527276207, -0.4634787357769745}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1653030684343095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7612580021246107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 1, {
              Complex[6.1653030684343095`, 0.7612580021246107], 
              Complex[7.619612527276207, -0.4634787357769745]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.628673581573148, -1.8950718287746993`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619728472689179, -0.4567147272275413}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 1, {
              Complex[6.165394324140473, 0.7685916995129606], 
              Complex[7.619728472689179, -0.4567147272275413]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.62836908977242, -1.9018116136847993`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 2, {
              Complex[6.190138095789615, -0.7765573210571979], 
              Complex[7.62836908977242, -1.9018116136847993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619839777837857, -0.45006588268488906`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204843003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268488906`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 1, {
              Complex[6.1654814985597985`, 0.7758036204843003], 
              Complex[7.619839777837857, -0.45006588268488906`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.628070244122034, -1.9084361186447754`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 2, {
              Complex[6.18997473915616, -0.7837753757227324], 
              Complex[7.628070244122034, -1.9084361186447754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.619946700555888, -0.4435281626164994}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 1, {
              Complex[6.1655648338407385`, 0.7828980260257032], 
              Complex[7.619946700555888, -0.4435281626164994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.627776768560513, -1.9149493850304071`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304071`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 2, {
              Complex[6.189816028885474, -0.7908758482666076], 
              Complex[7.627776768560513, -1.9149493850304071`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620049479307305, -0.43709774610477986`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352175`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823143`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 1, {
              Complex[6.165644553352175, 0.7898789463823143], 
              Complex[7.620049479307305, -0.43709774610477986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.627488406920755, -1.9213552355525556`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620148335014862, -0.4307710148004998}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004998`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 1, {
              Complex[6.165720863489107, 0.7967501980135656], 
              Complex[7.620148335014862, -0.4307710148004998]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.627204921081203, -1.9276572903056561`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1895116073884004`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 2, {
              Complex[6.1895116073884004`, -0.8047399594318435], 
              Complex[7.627204921081203, -1.9276572903056561`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620243472681647, -0.42454453835966915`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966915`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 1, {
              Complex[6.165793955271712, 0.8035153989801238], 
              Complex[7.620243472681647, -0.42454453835966915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.62692608932472, -1.9338589813326057`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 2, {
              Complex[6.189365468138804, -0.8115110351012249], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62033508283309, -0.41841506119925664`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925664`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 1, {
              Complex[6.1658640057650915`, 0.8101779829358521], 
              Complex[7.62033508283309, -0.41841506119925664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.626651704878013, -1.9399635658707666`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 2, {
              Complex[6.189223116150438, -0.8181794321268682], 
              Complex[7.626651704878013, -1.9399635658707666`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620423342802423, -0.4123794904283196}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 1, {
              Complex[6.165931179342954, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283196]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.626381574608516, -1.9459741384224638`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 2, {
              Complex[6.18908437282858, -0.8247484136793252], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620508417879312, -0.4064348848292457}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 1, {
              Complex[6.165995628815021, 0.8232081877787772], 
              Complex[7.620508417879312, -0.4064348848292457]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.626115517858932, -1.9518936417752972`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 2, {
              Complex[6.188949071546019, -0.8312210828762444], 
              Complex[7.626115517858932, -1.9518936417752972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620590462338552, -0.40057844477933857`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 1, {
              Complex[6.166057496435186, 0.8295818632429406], 
              Complex[7.620590462338552, -0.40057844477933857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.625853365402524, -1.9577248770820381`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 2, {
              Complex[6.188817056619654, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620669620363362, -0.3948075030162883}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 1, {
              Complex[6.1661169148049755`, 0.8358650512460934], 
              Complex[7.620669620363362, -0.3948075030162883]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.625594958504515, -1.9634705130965748`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 2, {
              Complex[6.188688182392475, -0.8438891593891126], 
              Complex[7.625594958504515, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620746026875824, -0.38911951616260576`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260576`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875824, -0.38911951616260576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.625340148077106, -1.9691330946508243`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508243`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 2, {
              Complex[6.188562312408358, -0.8500900641121137], 
              Complex[7.625340148077106, -1.9691330946508243`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620819808285303, -0.38351205693401563`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16622889072462`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.848170571632535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 1, {
              Complex[6.16622889072462, 0.848170571632535], 
              Complex[7.620819808285303, -0.38351205693401563`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.625088793917112, -1.9747150504476334`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 2, {
              Complex[6.1884393186687205`, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620891083164294, -0.3779828069654465}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654465`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 1, {
              Complex[6.166281672121115, 0.8541979088518944], 
              Complex[7.620891083164294, -0.3779828069654465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.624840764016902, -1.9802187002360259`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 2, {
              Complex[6.188319080961654, -0.8622384184423442], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.620959962859786, -0.37252955019570755`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 1, {
              Complex[6.166332453213397, 0.8601447828394869], 
              Complex[7.620959962859786, -0.37252955019570755`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.624595933940285, -1.9856462614276869`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621026552047415, -0.36715016675857515`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020565`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.866013429243351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 1, {
              Complex[6.166381329020565, 0.866013429243351], 
              Complex[7.621026552047415, -0.36715016675857515`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6243541862563, -1.9909998552070276`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 2, {
              Complex[6.188086428148008, -0.8740646059731696], 
              Complex[7.6243541862563, -1.9909998552070276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621090949234538, -0.36184262733357503`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729594`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 1, {
              Complex[6.166428388729594, 0.8718059882315833], 
              Complex[7.621090949234538, -0.36184262733357503`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.624115410024539, -1.996281512181469}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 2, {
              Complex[6.187973806370099, -0.8798624212060279], 
              Complex[7.624115410024539, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621153247217728, -0.35660498791489176`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 1, {
              Complex[6.166473716138243, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489176`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.623879500326577, -2.001493177613564}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 2, {
              Complex[6.187863526329917, -0.8855861488792872], 
              Complex[7.623879500326577, -2.001493177613564]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621213533499526, -0.3514353849611336}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 1, {
              Complex[6.166517390057898, 0.8831709599557604], 
              Complex[7.621213533499526, -0.3514353849611336]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.623646357838642, -2.006636716272229}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 2, {
              Complex[6.187755498701223, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621271890668613, -0.34633203089259046`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.623415888441285, -2.011713916936429}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.011713916936429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 2, {
              Complex[6.187649639046594, -0.8968191263829126], 
              Complex[7.623415888441285, -2.011713916936429]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621328396747193, -0.3412932099060138}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060138`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 1, {
              Complex[6.166600069913391, 0.8942551097650244], 
              Complex[7.621328396747193, -0.3412932099060138]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.623188002862294, -2.0167264965813105`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684229`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 2, {
              Complex[6.187545867473453, -0.9023320727684229], 
              Complex[7.623188002862294, -2.0167264965813105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621383125508848, -0.33631727407995976`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 1, {
              Complex[6.166639211685018, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.622962616349545, -2.0216761042737277`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.907778333231071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 2, {
              Complex[6.187444108319425, -0.907778333231071], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621436146769792, -0.3314026397464216}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 1, {
              Complex[6.166676972224923, 0.9050726361762728], 
              Complex[7.621436146769792, -0.3314026397464216]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6227396483708265`, -2.026564324801445}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 2, {
              Complex[6.187344289864064, -0.9131595788587057], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6214875266561215`, -0.32654778410681545`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.32654778410681545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 1, {
              Complex[6.166713410320053, 0.9103855526005629], 
              Complex[7.6214875266561215`, -0.32654778410681545`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.622519022338055, -2.0313926820579584`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621537327849361, -0.3217512420725156}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725156]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.62230066535352, -2.036162642202724}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9237333923619042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 2, {
              Complex[6.187150206311987, -0.9237333923619042], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62158560981236, -0.3170116033119908}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 1, {
              Complex[6.166782538502953, 0.9208274215121253], 
              Complex[7.62158560981236, -0.3170116033119908]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.622084507976147, -2.040875616614767}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187055815209431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 2, {
              Complex[6.187055815209431, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621632428997374, -0.31232750948827964`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827964`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 1, {
              Complex[6.166815330974628, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827964`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.62187048400586, -2.0455329646559166`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0455329646559166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 2, {
              Complex[6.186963112364547, -0.9340656567439877], 
              Complex[7.62187048400586, -2.0455329646559166`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621677839037961, -0.307697651672017}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.307697651672017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 1, {
              Complex[6.166847006151042, 0.9310336510892635], 
              Complex[7.621677839037961, -0.307697651672017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.621658530284445, -2.0501359962584584`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 2, {
              Complex[6.186872042200552, -0.9391447601963726], 
              Complex[7.621658530284445, -2.0501359962584584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621721890926156, -0.3031207679165942}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 1, {
              Complex[6.166877608777316, 0.9360518228828755], 
              Complex[7.621721890926156, -0.3031207679165942]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.621448586511419, -2.0546859743506385`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621764633176272, -0.2985956409831939}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621764633176272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831939`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 1, {
              Complex[6.166907181313368, 0.9410150937958545], 
              Complex[7.621764633176272, -0.2985956409831939]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.621240595073555, -2.0591841171322502`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 2, {
              Complex[6.186694590646787, -0.9491355712999281], 
              Complex[7.621240595073555, -2.0591841171322502`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621806111976447, -0.29412109620456683`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077782`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 1, {
              Complex[6.166935764077782, 0.9459247030157969], 
              Complex[7.621806111976447, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6210345008869025`, -2.0636316002114743`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621846371329063, -0.289695999477332}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.289695999477332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 1, {
              Complex[6.166963395380895, 0.9507818469782091], 
              Complex[7.621846371329063, -0.289695999477332]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.620830251250195, -2.06802955861316}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 2, {
              Complex[6.186523065904125, -0.9589115304824554], 
              Complex[7.620830251250195, -2.06802955861316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621885453180955, -0.2853192553735131}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735131`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 1, {
              Complex[6.166990111648028, 0.9555876813576079], 
              Complex[7.621885453180955, -0.2853192553735131]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.620627795708714, -2.0723790886678515`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313019`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0723790886678515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 2, {
              Complex[6.186439412474037, -0.9637219085313019], 
              Complex[7.620627795708714, -2.0723790886678515`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621923397544282, -0.2809898053627634}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.620427085927699, -2.076681249790104}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.968482055038922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.076681249790104`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 2, {
              Complex[6.1863571084384, -0.968482055038922], 
              Complex[7.620427085927699, -2.076681249790104]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.621960242608855, -0.276706626137473}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 1, {
              Complex[6.1670409360276865`, 0.9650498513977596], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.620228075574522, -2.0809370661539037`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 2, {
              Complex[6.186276113687408, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6219960248466, -0.27246872803358463`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.620030720208938, -2.08514752827235}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 2, {
              Complex[6.186196389837632, -0.977855938983315], 
              Complex[7.620030720208938, -2.08514752827235]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622030779108829, -0.2682751535405323}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167088495058987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 1, {
              Complex[6.167088495058987, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.619834977180716, -2.089313594488205}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 2, {
              Complex[6.186117900135718, -0.9824717320942185], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6220645387168675`, -0.26412497589424166`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 1, {
              Complex[6.167111124103515, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.619640805534111, -2.093436192381358}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381358`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 2, {
              Complex[6.186040609368664, -0.9870414080668144], 
              Complex[7.619640805534111, -2.093436192381358]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6220973355465995`, -0.26001729774762006`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 1, {
              Complex[6.167133022935145, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.619448165918566, -2.0975162200987905`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9915659143613826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0975162200987905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 2, {
              Complex[6.18596448378006, -0.9915659143613826], 
              Complex[7.619448165918566, -2.0975162200987905`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6221292001073655`, -0.2559512499133877}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189861`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 1, {
              Complex[6.1671542175655905`, 0.9878811887189861], 
              Complex[7.6221292001073655`, -0.2559512499133877]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.619257020505318, -2.1015545476121806`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1015545476121806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.1015545476121806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62216016161569, -0.25192599017451744`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 1, {
              Complex[6.167174732838953, 0.9923138310722672], 
              Complex[7.62216016161569, -0.25192599017451744`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.619067332909202, -2.105552017907876}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 2, {
              Complex[6.185815599931938, -1.0004830605740673`], 
              Complex[7.619067332909202, -2.105552017907876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622190248064221, -0.24794070215790115`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790115`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 1, {
              Complex[6.167194592496085, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790115`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.618879068115524, -2.1095094481136445`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 2, {
              Complex[6.185742780764411, -1.0048774519249073`], 
              Complex[7.618879068115524, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6222194862862445`, -0.24399459426719083`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6222194862862445`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 1, {
              Complex[6.167213819234736, 1.0010525529976397`], 
              Complex[7.6222194862862445`, -0.24399459426719083`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.618692192411459, -2.113427630566214}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 2, {
              Complex[6.185671004827052, -1.0092301787755908`], 
              Complex[7.618692192411459, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622247902016086, -0.24008689867107663`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167232434765789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 1, {
              Complex[6.167232434765789, 1.0053602784840994`], 
              Complex[7.622247902016086, -0.24008689867107663`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.618506673321678, -2.1173073338233785`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622275519945756, -0.23621687034352842`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167250459865911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 1, {
              Complex[6.167250459865911, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6183224795479365`, -2.121149303624121}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183224795479365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 2, {
              Complex[6.185530473503021, -1.0178138586055243`], 
              Complex[7.6183224795479365`, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62230236377805, -0.23238378615278824`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426833`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230236377805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278824`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 1, {
              Complex[6.167267914426833, 1.0138563914775602`], 
              Complex[7.62230236377805, -0.23238378615278824`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.618139580912272, -2.124954263799971}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 2, {
              Complex[6.185461666136162, -1.0220463622527833`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622328456276393, -0.22858694399613988`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613988`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399613988`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.617957948303619, -2.1287229171405833`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1287229171405833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 2, {
              Complex[6.185393797936862, -1.0262403046082478`], 
              Complex[7.617957948303619, -2.1287229171405833`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622353819311706, -0.22482566197765572`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347678`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 1, {
              Complex[6.167301187347678, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.617777553627534, -2.132455946216316}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.132455946216316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 2, {
              Complex[6.185326845280092, -1.0303964059906554`], 
              Complex[7.617777553627534, -2.132455946216316]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622378473906381, -0.2210992776263987}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263987`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263987]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6175983697588965`, -2.136154014160339}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622402440275708, -0.21740714715263512`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263512`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 1, {
              Complex[6.167332396649198, 1.0303918810590929`], 
              Complex[7.622402440275708, -0.21740714715263512`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.617420370497284, -2.139817765412751}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.139817765412751`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 2, {
              Complex[6.185195596375154, -1.0385978654970522`], 
              Complex[7.617420370497284, -2.139817765412751]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622425737866838, -0.21374864473986205`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 1, {
              Complex[6.1673472689966875`, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.617243530524916, -2.143447826428835}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143447826428835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 2, {
              Complex[6.185131257036874, -1.0426445649584832`], 
              Complex[7.617243530524916, -2.143447826428835]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622448385395499, -0.21012316187055802`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21012316187055802`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.21012316187055802`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.617067825366964, -2.1470448063535943`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.046656107578573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1470448063535943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 2, {
              Complex[6.185067746985584, -1.046656107578573], 
              Complex[7.617067825366964, -2.1470448063535943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62247040088057, -0.20653010668373498`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411305`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62247040088057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 1, {
              Complex[6.167375626411305, 1.0424154437428592`], 
              Complex[7.62247040088057, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.616893231354067, -2.1506092976644986`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 2, {
              Complex[6.1850050465299, -1.0506331187508076`], 
              Complex[7.616893231354067, -2.1506092976644986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622491801676729, -0.20296890336247211`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0463546938072399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247211`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 1, {
              Complex[6.167389140580846, 1.0463546938072399`], 
              Complex[7.622491801676729, -0.20296890336247211`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.61671972558691, -2.1541418767841933`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622512604505212, -0.1994389915497568}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497568`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 1, {
              Complex[6.167402230179721, 1.0502606417889435`], 
              Complex[7.622512604505212, -0.1994389915497568]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.616547285902738, -2.1576431046649516`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184881999013919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 2, {
              Complex[6.184881999013919, -1.0584859643603295`], 
              Complex[7.616547285902738, -2.1576431046649516`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622532825482896, -0.1959398257910541}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16741490837917`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 1, {
              Complex[6.16741490837917, 1.054133863773935], 
              Complex[7.622532825482896, -0.1959398257910541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.616375890843669, -2.1611135273463358`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848216158545455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 2, {
              Complex[6.1848216158545455`, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62255248014975, -0.1924708750021308}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 1, {
              Complex[6.167427187845094, 1.0579749207033111`], 
              Complex[7.62255248014975, -0.1924708750021308]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6162055196267024`, -2.164553676487631}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 2, {
              Complex[6.184761970036191, -1.0662077774973113`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6225715834948, -0.18903162196075954`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 1, {
              Complex[6.167439080761726, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.616036152115315, -2.1679640698763754`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 2, {
              Complex[6.184703044981658, -1.0700209412330008`], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62259014998067, -0.18562156282100936`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.615867768792523, -2.1713452119143026`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18464482465708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 2, {
              Complex[6.18464482465708, -1.07380299123558], 
              Complex[7.615867768792523, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622608193566829, -0.18224020664891855`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0693104944757823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891855`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 1, {
              Complex[6.167461753408532, 1.0693104944757823`], 
              Complex[7.622608193566829, -0.18224020664891855`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.615700350735352, -2.1746975940818936`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07755444648018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 2, {
              Complex[6.184587293548677, -1.07755444648018], 
              Complex[7.615700350735352, -2.1746975940818936`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622625727731571, -0.1788870749784164}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.615533879590611, -2.17802169538267}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 2, {
              Complex[6.1845304366407206`, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622642765492878, -0.17556170138642158`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 1, {
              Complex[6.1674830149790685`, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6153683375518915`, -2.1813179827683107`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 2, {
              Complex[6.184474239394659, -1.0849675833073058`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622659319428154, -0.1722636310861379}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 1, {
              Complex[6.1674931425517565`, 1.0803754306555198`], 
              Complex[7.622659319428154, -0.1722636310861379]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.615203707337716, -2.1845869115455567`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 2, {
              Complex[6.184418687729288, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622675401692969, -0.16899242053759095`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734984`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692969`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 1, {
              Complex[6.167502947734984, 1.0840058730914166`], 
              Complex[7.622675401692969, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6150399721707815`, -2.187828925765876}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622691024038829, -0.16574763707454077`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 1, {
              Complex[6.167512439903274, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614877115758211, -2.191044458598743}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184309466990744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.095870069699595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 2, {
              Complex[6.184309466990744, -1.095870069699595], 
              Complex[7.614877115758211, -2.191044458598743]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622706197830052, -0.16252885854692958`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 1, {
              Complex[6.167521628097823, 1.0911827145610284`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614715122272779, -2.1942339326893774`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 2, {
              Complex[6.18425577187742, -1.0994481489240888`], 
              Complex[7.614715122272779, -2.1942339326893774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622720934059783, -0.15933567297809714`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 1, {
              Complex[6.167530521040912, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809714`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614553976335032, -2.1973977605017105`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 2, {
              Complex[6.184202670231409, -1.1029989218798246`], 
              Complex[7.614553976335032, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622735243365228, -0.15616767823602062`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15616767823602062`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 1, {
              Complex[6.167539127149569, 1.0982504190677966`], 
              Complex[7.622735243365228, -0.15616767823602062`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614393662996269, -2.2005363446473227`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 2, {
              Complex[6.184150149994408, -1.1065228138938468`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622749136042125, -0.15302448171788982`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16754745454856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 1, {
              Complex[6.16754745454856, 1.1017444013712936`], 
              Complex[7.622749136042125, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614234167722325, -2.203650078201037}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.110020240242771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.203650078201037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 2, {
              Complex[6.184098199465816, -1.110020240242771], 
              Complex[7.614234167722325, -2.203650078201037]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622762622058505, -0.1499057000473825}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.105212347289903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1499057000473825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 1, {
              Complex[6.167555511082705, 1.105212347289903], 
              Complex[7.622762622058505, -0.1499057000473825]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.614075476378116, -2.2067393450038164`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 2, {
              Complex[6.1840468072888495`, -1.1134916064718132`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622775711067788, -0.14681095878399056`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399056`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613917575212898, -2.209804519953592}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1839959624373115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.116937308701091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 2, {
              Complex[6.1839959624373115`, -1.116937308701091], 
              Complex[7.613917575212898, -2.209804519953592]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622788412421261, -0.14373989214385754`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167570841605691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385754`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 1, {
              Complex[6.167570841605691, 1.1120717041858357`], 
              Complex[7.622788412421261, -0.14373989214385754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613760450846203, -2.212845969284587}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.120357733919819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 2, {
              Complex[6.183945654203009, -1.120357733919819], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622800735179931, -0.14069214273155717`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 1, {
              Complex[6.167578129986961, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613604090254433, -2.2158640508356973`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183895872183731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 2, {
              Complex[6.183895872183731, -1.1237532602689686`], 
              Complex[7.613604090254433, -2.2158640508356973`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622812688125852, -0.137667361282291}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.137667361282291`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 1, {
              Complex[6.167585176308896, 1.118831548607898], 
              Complex[7.622812688125852, -0.137667361282291]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613448480758017, -2.218859114308414}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 2, {
              Complex[6.1838466062718, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622824279772895, -0.1346652064140491}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 1, {
              Complex[6.167591987181104, 1.1221750717795367`], 
              Complex[7.622824279772895, -0.1346652064140491]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613293610009215, -2.221831501514857}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 2, {
              Complex[6.183797846643169, -1.1304710863006693`], 
              Complex[7.613293610009215, -2.221831501514857]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622835518377032, -0.1316853443892286}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.125494802176165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1316853443892286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 1, {
              Complex[6.167598568995438, 1.125494802176165], 
              Complex[7.622835518377032, -0.1316853443892286]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.613139465980372, -2.224781546616249}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 2, {
              Complex[6.183749583746966, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6228464119461155`, -0.1287274488853231}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1287274488853231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 1, {
              Complex[6.167604927934658, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.1287274488853231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612986036952771, -2.227709576352396}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 2, {
              Complex[6.183701808295564, -1.1370936450243203`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622856968249287, -0.12579120077420317`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167611069980751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 1, {
              Complex[6.167611069980751, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.12579120077420317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612833311505916, -2.230615910262511}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.230615910262511`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 2, {
              Complex[6.183654511255059, -1.140370057894864], 
              Complex[7.612833311505916, -2.230615910262511]}, -1}, "Tooltip"]
           & ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622867194825846, -0.12287628790968678`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612681278507311, -2.2335008608977986`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 2, {
              Complex[6.183607683836199, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622877098993824, -0.11998240492294286`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 1, {
              Complex[6.167622726364391, 1.1385425856735314`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612529927102651, -2.236364734026167}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 2, {
              Complex[6.183561317485685, -1.1468548029005141`], 
              Complex[7.612529927102651, -2.236364734026167]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6228866878580925`, -0.11710925302543315`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167628251731052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878580925`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543315`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 1, {
              Complex[6.167628251731052, 1.1417483803738397`], 
              Complex[7.6228866878580925`, -0.11710925302543315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612379246706457, -2.2392078288294064`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 2, {
              Complex[6.183515403877874, -1.1500637746045623`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622895968318212, -0.11425653981901966`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981901966`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 1, {
              Complex[6.167633582276866, 1.1449323435024115`], 
              Complex[7.622895968318212, -0.11425653981901966`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.612229226993079, -2.2420304380931957`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 2, {
              Complex[6.183469934906837, -1.1532508941175417`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622904947075774, -0.1114239791129977}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676387230910485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1480947778478883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1114239791129977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 1, {
              Complex[6.1676387230910485`, 1.1480947778478883`], 
              Complex[7.622904947075774, -0.1114239791129977]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.61207985788809, -2.2448328483902134`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61207985788809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 2, {
              Complex[6.183424902678743, -1.1564164644600654`], 
              Complex[7.61207985788809, -2.2448328483902134`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622913630641642, -0.10861129074761375`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 1, {
              Complex[6.167643679104284, 1.1512359798388987`], 
              Complex[7.622913630641642, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.611931129560043, -2.2476153402566923`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183380299504599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 2, {
              Complex[6.183380299504599, -1.1595607822888856`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622922025342647, -0.10581820042397054`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676484550945725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1543562397232343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042397054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 1, {
              Complex[6.1676484550945725`, 1.1543562397232343`], 
              Complex[7.622922025342647, -0.10581820042397054`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.61178303241253, -2.2503781883626597`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 2, {
              Complex[6.183336117893253, -1.1626841380761954`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622930137328205, -0.10304443953986418`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986418`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986418`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.611635557076614, -2.2531216616761798`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 2, {
              Complex[6.183292350544733, -1.165786816282607], 
              Complex[7.611635557076614, -2.2531216616761798`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622937972576472, -0.10028974503145566`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676574853892205`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 1, {
              Complex[6.1676574853892205`, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.611488694403538, -2.255846023621816}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.255846023621816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 2, {
              Complex[6.183248990343843, -1.1688690955240513`], 
              Complex[7.611488694403538, -2.255846023621816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622945536900381, -0.09755385922040954}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167661748536481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 1, {
              Complex[6.167661748536481, 1.1635941800905012`], 
              Complex[7.622945536900381, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.611342435457721, -2.258551532233557}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183206030354023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 2, {
              Complex[6.183206030354023, -1.1719312487328406`], 
              Complex[7.611342435457721, -2.258551532233557]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622952835953341, -0.09483652966635199}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16766584935682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635199`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 1, {
              Complex[6.16766584935682, 1.1666334563353575`], 
              Complex[7.622952835953341, -0.09483652966635199]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.611196771510035, -2.2612384403025065`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18316346381144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2612384403025065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 2, {
              Complex[6.18316346381144, -1.1749735433132207`], 
              Complex[7.611196771510035, -2.2612384403025065`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6229598752347245`, -0.09213750902438231}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.169653154844329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 1, {
              Complex[6.167669791945717, 1.169653154844329], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.61105169403139, -2.2639069955194215`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119398`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61105169403139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 2, {
              Complex[6.183121284119398, -1.1779962412914968`], 
              Complex[7.61105169403139, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622966660095128, -0.08945655490745444}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745444`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 1, {
              Complex[6.167673580276671, 1.1726535322072744`], 
              Complex[7.622966660095128, -0.08945655490745444]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.610907194686493, -2.2665574406124445`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183079484842854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 2, {
              Complex[6.183079484842854, -1.180999599461101], 
              Complex[7.610907194686493, -2.2665574406124445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622973195741423, -0.08679342975340572}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205584`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622973195741423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08679342975340572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 1, {
              Complex[6.167677218205584, 1.1756348399245444`], 
              Complex[7.622973195741423, -0.08679342975340572]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.610763265327906, -2.2691900134801815`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622979487241573, -0.0841479006964719}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676807094749195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1785973245423347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 1, {
              Complex[6.1676807094749195`, 1.1785973245423347`], 
              Complex[7.622979487241573, -0.0841479006964719]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.610619897990324, -2.271804947320255}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320255`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990324, -2.271804947320255]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622985539529303, -0.08151973944306815}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16768405771774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 1, {
              Complex[6.16768405771774, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.610477084885046, -2.274402470753615}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 2, {
              Complex[6.182956307473315, -1.1898961274694764`], 
              Complex[7.610477084885046, -2.274402470753615]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622991357408529, -0.07890872215171531}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461522`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 1, {
              Complex[6.167687266461522, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.61033481839468, -2.276982807944708}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.192824594488806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 2, {
              Complex[6.182915968564257, -1.192824594488806], 
              Complex[7.61033481839468, -2.276982807944708]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.622996945557652, -0.07631462931689577}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.07631462931689577`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 1, {
              Complex[6.167690339131856, 1.1873742336662854`], 
              Complex[7.622996945557652, -0.07631462931689577]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.610193091068048, -2.27954617871769}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182875980145687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1957349319176869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 2, {
              Complex[6.182875980145687, -1.1957349319176869`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623002308533652, -0.07373724565672798}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 1, {
              Complex[6.167693279055961, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6100518956152605`, -2.2820927986688533`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2820927986688533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.2820927986688533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623007450776046, -0.07117636000425508}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425508]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.609911224902993, -2.28462287927539}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.28462287927539`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 2, {
              Complex[6.182797032640057, -1.2015021263830645`], 
              Complex[7.609911224902993, -2.28462287927539]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623012376610672, -0.06863176520228129}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 1, {
              Complex[6.167698773502735, 1.1959901616082877`], 
              Complex[7.623012376610672, -0.06863176520228129]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.60977107194993, -2.2871366280006615`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 2, {
              Complex[6.182758062802262, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623017090253322, -0.06610325800154536}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.609631429922364, -2.289634248396078}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.289634248396078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.289634248396078]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623021595813283, -0.06359063896214613}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2016476203371216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813283`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214613`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 1, {
              Complex[6.167703774577616, 1.2016476203371216`], 
              Complex[7.623021595813283, -0.06359063896214613]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.609492292129979, -2.2921159401997615`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623025897296652, -0.061093712358079776`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.609353652021762, -2.294581899432073}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.212828715220383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432073`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 2, {
              Complex[6.182643106997765, -1.212828715220383], 
              Complex[7.609353652021762, -2.294581899432073]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62302999860963, -0.05861228608478145}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478145`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 1, {
              Complex[6.167708305685528, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478145]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.609215503182054, -2.2970323184881387`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 2, {
              Complex[6.182605423099422, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230339035616055`, -0.0561461715695423}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2100082561816607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 1, {
              Complex[6.1677104019634195`, 1.2100082561816607`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6090778393267975`, -2.2994673862275175`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 2, {
              Complex[6.182568048561962, -1.2183914626776442`], 
              Complex[7.6090778393267975`, -2.2994673862275175`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623037615868168, -0.05369518368470517}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677123889507754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 1, {
              Complex[6.1677123889507754`, 1.2127624573020028`], 
              Complex[7.623037615868168, -0.05369518368470517]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608940654299824, -2.301887288061049}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623041139153995, -0.051259140663536505`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 1, {
              Complex[6.167714269226695, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608803942069356, -2.3042922060350675`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182494209128501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 2, {
              Complex[6.182494209128501, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623044476955637, -0.048837864018669234`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.218223004527287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 1, {
              Complex[6.167716045300302, 1.218223004527287], 
              Complex[7.623044476955637, -0.048837864018669234`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608667696724579, -2.30668231891301}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 2, {
              Complex[6.182457735262817, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623047632724201, -0.0464311784630236}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 1, {
              Complex[6.167717719612998, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608531912472354, -2.3090578022545656`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 2, {
              Complex[6.1824215528129, -1.2293237938391437`], 
              Complex[7.608531912472354, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62305060982792, -0.04403891183311732}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540653`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 1, {
              Complex[6.167719294540653, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608396583634034, -2.3114188284924206`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3114188284924206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 2, {
              Complex[6.182385657532067, -1.2320177339512257`], 
              Complex[7.608396583634034, -2.3114188284924206`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623053411554656, -0.041660895014681475`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.226296975161037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 1, {
              Complex[6.167720772395696, 1.226296975161037], 
              Complex[7.623053411554656, -0.041660895014681475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608261704642392, -2.3137655670067088`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 2, {
              Complex[6.182350045264077, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623056041114285, -0.039296961870488915`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 1, {
              Complex[6.16772215542913, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.039296961870488915`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.608127270038647, -2.3160981841972363`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 2, {
              Complex[6.182314711940598, -1.2373599104404132`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623058501641022, -0.03694694917032507}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032507`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 1, {
              Complex[6.167723445832482, 1.2316038141805974`], 
              Complex[7.623058501641022, -0.03694694917032507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6079932744696, -2.3184168435535706`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623060796195637, -0.03461069652302155}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 1, {
              Complex[6.167724645739662, 1.2342350105444315`], 
              Complex[7.623060796195637, -0.03461069652302155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607859712684855, -2.320721705723058}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723058`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 2, {
              Complex[6.182244866278791, -1.2426423085461484`], 
              Complex[7.607859712684855, -2.320721705723058]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230629277676165`, -0.03228804631048269}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048269`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 1, {
              Complex[6.167725757228776, 1.2368516153040956`], 
              Complex[7.6230629277676165`, -0.03228804631048269]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607726579534131, -2.32301292857686}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 2, {
              Complex[6.1822103462217495`, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623064899277237, -0.029978843623626066`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726782323851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.239453792737311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 1, {
              Complex[6.167726782323851, 1.239453792737311], 
              Complex[7.623064899277237, -0.029978843623626066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607593869964683, -2.3252906672740603`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 2, {
              Complex[6.182176089667306, -1.2478662783795624`], 
              Complex[7.607593869964683, -2.3252906672740603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230667135775585`, -0.02768293620018037}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230667135775585`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 1, {
              Complex[6.167727722996507, 1.2420417043271579`], 
              Complex[7.6230667135775585`, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.60746157901877, -2.327555074323918}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.327555074323918]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230683734563724`, -0.02540017436427072}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728581167581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 1, {
              Complex[6.167728581167581, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427072]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607329701831238, -2.32980629964634}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1821083524852725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 2, {
              Complex[6.1821083524852725`, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623069881638046, -0.02313041096773041}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2471753623160462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773041`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 1, {
              Complex[6.167729358708657, 1.2471753623160462`], 
              Complex[7.623069881638046, -0.02313041096773041]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607198233627164, -2.3320444906306093`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 2, {
              Complex[6.182074864751301, -1.2555955212603065`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62307124078535, -0.020873501333081253`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 1, {
              Complex[6.167730057443583, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333081253`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.607067169719584, -2.3342697921924636`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 2, {
              Complex[6.182041626303248, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623072453501178, -0.01862930319811857}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01862930319811857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 1, {
              Complex[6.167730679149904, 1.2522538276170267`], 
              Complex[7.623072453501178, -0.01862930319811857]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6069365055072815`, -2.3364823468295484`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623073522330235, -0.016397676662069472`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606806236472661, -2.338682294675321}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.338682294675321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 2, {
              Complex[6.181975883820567, -1.2632004444906193`], 
              Complex[7.606806236472661, -2.338682294675321]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623074449760662, -0.014178484133222896`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222896`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133222896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606676358179669, -2.340869773551443}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 2, {
              Complex[6.1819433732291715`, -1.2657084915461236`], 
              Complex[7.606676358179669, -2.340869773551443]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623075238225612, -0.011971590278048698`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207093`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278048698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 1, {
              Complex[6.167732099207093, 1.2597706481409658`], 
              Complex[7.623075238225612, -0.011971590278048698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606546866271806, -2.343044919018727}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 2, {
              Complex[6.181911098806735, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623075890104745, -0.00977686197169417}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169417`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 1, {
              Complex[6.167732429696165, 1.26224993121657], 
              Complex[7.623075890104745, -0.00977686197169417]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606417756470163, -2.345207864426671}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181879057432655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 2, {
              Complex[6.181879057432655, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623076407725731, -0.007594168249853941}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725731, -0.007594168249853941]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606289024571562, -2.3473587409616403`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 2, {
              Complex[6.181847246046555, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230767933656285`, -0.005423380261944609}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230767933656285`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 1, {
              Complex[6.167732885836666, 1.2671698491615646`], 
              Complex[7.6230767933656285`, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.606160666446714, -2.349497677693729}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 2, {
              Complex[6.181815661646744, -1.2756098611309443`], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623077049252295, -0.0032643712255543632`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 1, {
              Complex[6.167733014505245, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.60603267803846, -2.351624801622354}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181784301288738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60603267803846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 2, {
              Complex[6.181784301288738, -1.2780531889506412`], 
              Complex[7.60603267803846, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623077177565681, -0.0011170163821177432`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565681`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 1, {
              Complex[6.167733078856031, 1.272039137007607], 
              Complex[7.623077177565681, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605905055360047, -2.3537402377206176`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{7.6230771804391395`, 0.0010188070462166473`}],
            
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733080307031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230771804391395`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0010188070462166473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 1, {
              Complex[6.167733080307031, 1.2744551244406341`], 
              Complex[7.6230771804391395`, 0.0010188070462166473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605777794493473, -2.355844108978483}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62307705996065, 0.0031432198985724435`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985724435`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 1, {
              Complex[6.167733020241881, 1.2768588459554964`], 
              Complex[7.62307705996065, 0.0031432198985724435`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605650891587858, -2.3579365364447966`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 2, {
              Complex[6.181691535849002, -1.2853084672867792`], 
              Complex[7.605650891587858, -2.3579365364447966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62307681817404, 0.005256341116210561}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210561]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.60552434285789, -2.360017639268197}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 2, {
              Complex[6.181661043308228, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623076457080134, 0.007358287782327438}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 1, {
              Complex[6.167732720931719, 1.2816299944237617`], 
              Complex[7.623076457080134, 0.007358287782327438]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605398144582298, -2.3620875347369377`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 2, {
              Complex[6.181630760896248, -1.2900843444730696`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623075978637889, 0.009449175160798436}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 1, {
              Complex[6.167732484290828, 1.2839976681063676`], 
              Complex[7.623075978637889, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605272293102373, -2.3641463383176777`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 2, {
              Complex[6.181600685983191, -1.2924543639191772`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623075384765489, 0.011529116733913576`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605146784820534, -2.3661941636932524`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 2, {
              Complex[6.181570815987222, -1.2948125987358026`], 
              Complex[7.605146784820534, -2.3661941636932524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62307467734139, 0.013598224239136585`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 1, {
              Complex[6.167731843316621, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.605021616198942, -2.3682311227994592`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 2, {
              Complex[6.181541148373396, -1.2971591677080392`], 
              Complex[7.605021616198942, -2.3682311227994592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623073858205368, 0.01565660770491158}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205368`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205368, 0.01565660770491158]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604896783758138, -2.3702573258609094`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3702573258609094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 2, {
              Complex[6.18151168065253, -1.2994941878134683`], 
              Complex[7.604896783758138, -2.3702573258609094`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623072929159484, 0.017704375485551784`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551784`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604772284075737, -2.37227288142594}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623071891969078, 0.019741634295235}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604648113785144, -2.3742778964006486`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1814533351552905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3041300405165681`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 2, {
              Complex[6.1814533351552905`, -1.3041300405165681`], 
              Complex[7.604648113785144, -2.3742778964006486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623070748363671, 0.021768489241138642`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 1, {
              Complex[6.167729923927074, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138642`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604524269574324, -2.3762724760820655`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820655`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 2, {
              Complex[6.181424452619748, -1.3064310983584508`], 
              Complex[7.604524269574324, -2.3762724760820655`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623069500037891, 0.023785043855733566`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6044007481845695`, -2.3782567241904524`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 2, {
              Complex[6.181395760456799, -1.3087210578909674`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623068148652344, 0.025791400128268475`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.302524997762607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128268475`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 1, {
              Complex[6.167728663570656, 1.302524997762607], 
              Complex[7.623068148652344, 0.025791400128268475`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604277546409373, -2.380230742900864}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 2, {
              Complex[6.181367256390405, -1.3110000275879246`], 
              Complex[7.604277546409373, -2.380230742900864]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623066695834461, 0.02778765853546761}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834461`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 1, {
              Complex[6.167727961973396, 1.3047908452057129`], 
              Complex[7.623066695834461, 0.02778765853546761]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604154661093241, -2.3821946328738326`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3821946328738326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 2, {
              Complex[6.181338938184203, -1.3132681143229272`], 
              Complex[7.604154661093241, -2.3821946328738326`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623065143179327, 0.02977391807145811}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772721412525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145811`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 1, {
              Complex[6.16772721412525, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145811]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.604032089130617, -2.3841484932853487`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1813108036406295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 2, {
              Complex[6.1813108036406295`, -1.3155254234009868`], 
              Complex[7.604032089130617, -2.3841484932853487`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623063492250484, 0.03175027627696591}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 1, {
              Complex[6.167726421018415, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603909827464786, -2.3860924218560746`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.317772058589321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 2, {
              Complex[6.181282850600008, -1.317772058589321], 
              Complex[7.603909827464786, -2.3860924218560746`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623061744580699, 0.03371682926778467}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 1, {
              Complex[6.167725583622502, 1.311524202717575], 
              Complex[7.623061744580699, 0.03371682926778467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603787873086824, -2.388026514879854}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623059901672726, 0.03567367176254808}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 1, {
              Complex[6.16772470288514, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6036662230346, -2.3899508672515024`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3222337148562802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 2, {
              Complex[6.181227480573278, -1.3222337148562802`], 
              Complex[7.6036662230346, -2.3899508672515024`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623057965000035, 0.03762089710983468}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.315960638428035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983468`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 1, {
              Complex[6.167723779732553, 1.315960638428035], 
              Complex[7.623057965000035, 0.03762089710983468]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603544874391759, -2.3918655724939386`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 2, {
              Complex[6.181200059449697, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623055936007519, 0.03955859731459801}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070128`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 1, {
              Complex[6.167722815070128, 1.3181634132423614`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.6034238242867636`, -2.393770722784652}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181172811552509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3266538836292927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.393770722784652`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 2, {
              Complex[6.181172811552509, -1.3266538836292927`], 
              Complex[7.6034238242867636`, -2.393770722784652]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62305381611219, 0.04148686306397212}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397212`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 1, {
              Complex[6.167721809782957, 1.3203560217257766`], 
              Complex[7.62305381611219, 0.04148686306397212]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603303069891951, -2.395666408981521}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 2, {
              Complex[6.181145734899094, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.62305160670384, 0.04340578375245147}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 1, {
              Complex[6.167720764736373, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245147]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603182608422626, -2.3975527206480365`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18111882753992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 2, {
              Complex[6.18111882753992, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.6230493091457, 0.045315447506474565`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.324711118586218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 1, {
              Complex[6.167719680776454, 1.324711118586218], 
              Complex[7.6230493091457, 0.045315447506474565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.603062437136163, -2.3994297460778915`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181092087557802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 2, {
              Complex[6.181092087557802, -1.3332080430544784`], 
              Complex[7.603062437136163, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623046924775063, 0.047215941208410626`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.047215941208410626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.602942553331131, -2.401297572319007}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.401297572319007`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.401297572319007]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{7.623044454903904, 0.04910735051999627}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.602822954346457, -2.403156285196984}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181039102213561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.337527848075708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 2, {
              Complex[6.181039102213561, -1.337527848075708], 
              Complex[7.602822954346457, -2.403156285196984]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.4787533558490455`, -1.2631402225643402`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487388491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.4787533558490455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1631402225643404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[8.118560581075963, 0.006887727487388491], 
              Complex[6.4787533558490455`, -1.1631402225643404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.800016052466027, -1.2961486271318055`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.539894192888829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013243170301698895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.800016052466027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[10.539894192888829`, -0.013243170301698895`], 
              Complex[8.800016052466027, -1.1961486271318054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.52215878639839, -1.2630554690196358`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368874`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163055469019636`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[8.162580737731862, 0.007042959985368874], 
              Complex[6.52215878639839, -1.163055469019636]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.755092274628062, -1.2963255671672886`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269002`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01350987671532385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.755092274628062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[10.494506767269002`, -0.01350987671532385], 
              Complex[8.755092274628062, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.557943371421669, -1.2629725487625656`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629725487625657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[8.198987977866881, 0.007197843246654785], 
              Complex[6.557943371421669, -1.1629725487625657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.718101741665087, -1.2964748219538675`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039064`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[10.457042457039064`, -0.013751044852512901`], 
              Complex[8.718101741665087, -1.1964748219538675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.589330078860694, -1.2628888789503179`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.23100514788576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961003822`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.589330078860694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162888878950318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[8.23100514788576, 0.007354951961003822], 
              Complex[6.589330078860694, -1.162888878950318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.685690080337725, -1.2966097210740348`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013979869598457921`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[10.42414741707873, -0.013979869598457921`], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.61778553109412, -1.262803172863648}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[8.260098904258959, 0.007515591774090758], 
              Complex[6.61778553109412, -1.1628031728636479`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.656331133890308, -1.296736439762822}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.394295711708596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014202465960738788`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[10.394295711708596`, -0.014202465960738788`], 
              Complex[8.656331133890308, -1.1967364397628222`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.644124842294815, -1.262714599075609}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076806282899812735`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756091`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[8.287084479515974, 0.0076806282899812735`], 
              Complex[6.644124842294815, -1.1627145990756091`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.629176867782464, -1.2968585230000411`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660349779`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[10.366639367283947`, -0.014422357660349779`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.668857252414799, -1.2626225207983661`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002843`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160531302`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983663`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[8.312471288002843, 0.007850743160531302], 
              Complex[6.668857252414799, -1.1626225207983663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.603697599379137, -1.2969782988821363`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121435745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[10.340648661463618`, -0.014641876121435745`], 
              Complex[8.603697599379137, -1.1969782988821362`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.692326779227161, -1.2625263894330445`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008026538528972045`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.692326779227161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[8.336603564825273, 0.008026538528972045], 
              Complex[6.692326779227161, -1.1625263894330446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.579535601926915, -1.2970974543173972`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01486272923227436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[10.315965756037766`, -0.01486272923227436], 
              Complex[8.579535601926915, -1.1970974543173973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.7147793676173775`, -1.2624256923931874`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694592`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338763303`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931875`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[8.359727508694592, 0.008208588338763303], 
              Complex[6.7147793676173775`, -1.1624256923931875`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.556435217312076, -1.297217311276035}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.292334825045389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01508627394224807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[10.292334825045389`, -0.01508627394224807], 
              Complex[8.556435217312076, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.736398653893473, -1.2623199234705247`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836869`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[8.382027043209192, 0.008397467701836869], 
              Complex[6.736398653893473, -1.1623199234705248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.534205636043778, -1.297338975768746}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015313663264596185`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[10.269564843263957`, -0.015313663264596185`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.757326609412581, -1.2622085635431992`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[8.40364445944282, 0.008593772293729816], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.512699415121855, -1.2974634260014823`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[10.247508108692934`, -0.015545933419028875`], 
              Complex[8.512699415121855, -1.1974634260014823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.777676219425207, -1.2620910662296874`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053827`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[8.424693095053827, 0.008798133065178966], 
              Complex[6.777676219425207, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.491799285559553, -1.297591568976287}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015784060035231827`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[10.226047052260428`, -0.015784060035231827`], 
              Complex[8.491799285559553, -1.1975915689762868`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.797539667322055, -1.2619668458011308`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909081513`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619668458011307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[8.445265519754589, 0.009011228909081513], 
              Complex[6.797539667322055, -1.1619668458011307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.471409637754663, -1.2977242798043065`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[10.20508572371207, -0.01602899750358715], 
              Complex[8.471409637754663, -1.1977242798043064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.816993839756788, -1.261835265847092}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935048`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.816993839756788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[8.465439042444201, 0.009233798770935048], 
              Complex[6.816993839756788, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.451450795228006, -1.2978624312936862`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805177`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[10.184544064614808`, -0.016281708942805177`], 
              Complex[8.451450795228006, -1.1978624312936863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.836104162316991, -1.2616956277315166`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547499`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[8.485279549606197, 0.009466654168547499], 
              Complex[6.836104162316991, -1.1616956277315165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.431855025955322, -1.2980069181435883`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920574`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[10.164353917920574`, -0.016543191071888966`], 
              Complex[8.431855025955322, -1.1980069181435882`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.854927356440139, -1.2615471581185318`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[8.504844265661474, 0.009710692858210825], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.412563676597296, -1.2981586784333552`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831885`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[10.144456159495562`, -0.016814496662831885`], 
              Complex[8.412563676597296, -1.198158678433355]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.873513478358425, -1.2613889949346566`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.393525054229872, -1.2983187142405295`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673765`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[10.124798576239256`, -0.017096756417673765`], 
              Complex[8.393525054229872, -1.1983187142405294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.891907468896066, -1.2612201711252076`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199157`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612201711252075`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[8.543343682297632, 0.010236437677199157`], 
              Complex[6.891907468896066, -1.1612201711252075`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.374692817528388, -1.2984881127881411`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304238`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[10.105334252708916`, -0.017391201699304238`], 
              Complex[8.374692817528388, -1.198488112788141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.910150364313235, -1.261039595483041}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036428395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.910150364313235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610395954830408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[8.562365618323057, 0.010520523036428395`], 
              Complex[6.910150364313235, -1.1610395954830408`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.356024721208028, -1.2986680693372452`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[10.086020309962356`, -0.017699189379580448`], 
              Complex[8.356024721208028, -1.1986680693372453`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.928280270084161, -1.2608460296816648`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01082059684449242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.928280270084161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160846029681665`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[8.581288431797729, 0.01082059684449242], 
              Complex[6.928280270084161, -1.160846029681665]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.33748160781912, -1.2988599130234304`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.066816890576662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018022230071644284`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[10.066816890576662`, -0.018022230071644284`], 
              Complex[8.33748160781912, -1.1988599130234303`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.946333169123366, -1.26063806042409}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521388`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836947`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240902`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[8.600148900521388, 0.011138282794836947`], 
              Complex[6.946333169123366, -1.1606380604240902`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.319026572634915, -1.2990651369525759`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624233`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1990651369525758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[10.047686315383556`, -0.018362021154624233`], 
              Complex[8.319026572634915, -1.1990651369525758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.964343616618659, -1.2604140653041305`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775214`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[8.618982457304563, 0.011475439606775214`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.300624247551832, -1.2992854341178675`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070795`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[10.02859235757786, -0.018720486277070795`], 
              Complex[8.300624247551832, -1.1992854341178676`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{6.982345361327388, -1.2601721705348452`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463423`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[8.637823823216573, 0.011834207760463423`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.282240162776432, -1.2995227410964953`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292597`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.282240162776432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[10.009499592627154`, -0.019099823463292597`], 
              Complex[8.282240162776432, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.000371925640259, -1.259910198078305}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01221706786722248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159910198078305`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[8.656707602013043, 0.01221706786722248], 
              Complex[7.000371925640259, -1.159910198078305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.263840153003091, -1.2997792920739644`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.99037279023362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019502564592186845`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[9.99037279023362, -0.019502564592186845`], 
              Complex[8.263840153003091, -1.1997792920739643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.018457172595781, -1.259625598832674}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[8.675668864524779, 0.012626914319474904`], 
              Complex[7.018457172595781, -1.1596255988326742`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.245389779169422, -1.30005768660046}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.97117631884134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.245389779169422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[9.97117631884134, -0.019931649951741095`], 
              Complex[8.245389779169422, -1.2000576866004602`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.036635886648769, -1.2593153672755066`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598734`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229434393`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755065`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[8.694743750598734, 0.013067149229434393`], 
              Complex[7.036635886648769, -1.1593153672755065`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.226853738441676, -1.3003609757255188`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278616`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[9.951873534557844, -0.020390522922278616`], 
              Complex[8.226853738441676, -1.2003609757255187`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.0549443961207245`, -1.258975931136672}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645187473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0549443961207245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1589759311366719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[8.713970117564823, 0.013541803645187473`], 
              Complex[7.0549443961207245`, -1.1589759311366719`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.208195234091123, -1.3006927729717153`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02088325181027976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[9.932426125107996, -0.02088325181027976], 
              Complex[8.208195234091123, -1.2006927729717154`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.073421269042282, -1.2586030069798184`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277604`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586030069798183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[8.733388268345111, 0.014055695951277604`], 
              Complex[7.073421269042282, -1.1586030069798183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.18937527323683, -1.3010573992945915`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765244935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[9.912793375391814, -0.021414688765244935`], 
              Complex[8.18937527323683, -1.2010573992945914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.092108121115126, -1.258191408520516}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299529`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[8.753041799848585, 0.014614641743299529`], 
              Complex[7.092108121115126, -1.1581914085205158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.170351853484789, -1.3014600752208563`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691886`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[9.892931313762208, -0.021990680088691886`], 
              Complex[8.170351853484789, -1.2014600752208562`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.111050585905174, -1.2577347882945948`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.772978624412278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01522573618198167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.111050585905174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[8.772978624412278, 0.01522573618198167], 
              Complex[7.111050585905174, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.151078988162066, -1.3019071795671375`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057525`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2019071795671374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[9.872791686074075, -0.022618348956057525`], 
              Complex[8.151078988162066, -1.2019071795671374`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.130299515097565, -1.257225283537514}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[8.793252235841301, 0.01589774035976075], 
              Complex[7.130299515097565, -1.157225283537514]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.131505502166522, -1.3024066038908526`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.023306482096512558`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.131505502166522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908525`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[9.852320685804425, -0.023306482096512558`], 
              Complex[8.131505502166522, -1.2024066038908525`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.149912504017516, -1.2566530214405542`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819532`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[8.813923320576674, 0.016641620135819532`], 
              Complex[7.149912504017516, -1.1566530214405542`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.11157350310953, -1.302968247517296}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[9.831457339597339, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.169955880282916, -1.2560054129682459`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[8.835061859626233, 0.017471313877762313`], 
              Complex[7.169955880282916, -1.1560054129682458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.09121638979124, -1.3036047239664328`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[9.81013140250469, -0.02491106937082753], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.190507361138085, -1.2552661200223416`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322075`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.018404853311322075`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.070356192382524, -1.304332394000482}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204332394000482`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479544], 
              Complex[8.070356192382524, -1.204332394000482]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.211659694982883, -1.2544135020746283`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629636`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203824108`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629636, 0.019466046203824108`], 
              Complex[7.211659694982883, -1.1544135020746282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.048899928737553, -1.3051729191751666`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.026935292658188545`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.026935292658188545`], 
              Complex[8.048899928737553, -1.2051729191751666`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.233525786397049, -1.2534182031380912`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549182`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496538995`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.153418203138091`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549182, 0.020687085496538995`], 
              Complex[7.233525786397049, -1.153418203138091]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.026734477486407, -1.306155675029386}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095144, -0.028170551750252903`], 
              Complex[8.026734477486407, -1.2061556750293858`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.256246121108595, -1.2522392586053035`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073539966`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053036`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442705, 0.022112751073539966`], 
              Complex[7.256246121108595, -1.1522392586053036`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.003719151417389, -1.307321644387866}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631426`], 
              Complex[8.003719151417389, -1.2073216443878658`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.279999873987634, -1.2508175252699345`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02380748722011572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.02380748722011572], 
              Complex[7.279999873987634, -1.1508175252699346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.979674588033217, -1.3087299874638696`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03131842125415461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427964, -0.03131842125415461], 
              Complex[7.979674588033217, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.305022131856599, -1.2490639772295196`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308562`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584034504`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295197`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308562, 0.025867986584034504`], 
              Complex[7.305022131856599, -1.1490639772295197`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.954365525461626, -1.3104697460661472`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03339219715471052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210469746066147`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.03339219715471052], 
              Complex[7.954365525461626, -1.210469746066147]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.331631661529259, -1.246837425962161}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768344`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632702298`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.331631661529259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468374259621612`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768344, 0.028447097632702298`], 
              Complex[7.331631661529259, -1.1468374259621612`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.927473033284, -1.3126821236194965`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194967`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.03598429729320677], 
              Complex[7.927473033284, -1.2126821236194967`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.360277468735851, -1.2438984501954062`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03180315785237416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954061`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964629, 0.03180315785237416], 
              Complex[7.360277468735851, -1.1438984501954061`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.89854795260484, -1.3156065553823744`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187375584`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187375584`], 
              Complex[7.89854795260484, -1.2156065553823743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.391618832430633, -1.2398036000155712`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.06950674944049`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155713`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.06950674944049, 0.036413030935491295`], 
              Complex[7.391618832430633, -1.1398036000155713`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.866930860848728, -1.3196865044147261`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380089758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670558, -0.04397539380089758], 
              Complex[7.866930860848728, -1.2196865044147263`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.426654831776879, -1.2336280195460163`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645221], 
              Complex[7.426654831776879, -1.1336280195460162`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.831622543975549, -1.3258468389686644`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000957, -0.05084228149319718], 
              Complex[7.831622543975549, -1.2258468389686643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.466802670715167, -1.2231222909767527`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732279], 
              Complex[7.466802670715167, -1.1231222909767526`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.791205671196036, -1.3363369885208018`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.49426721635719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.06235459303258733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.791205671196036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.49426721635719, -0.06235459303258733], 
              Complex[7.791205671196036, -1.2363369885208018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.512359287571745, -1.2022322984450344`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0773435944124776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.0773435944124776], 
              Complex[7.512359287571745, -1.1022322984450343`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.745383184720152, -1.3572110799472343`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414638, -0.08494182361233307], 
              Complex[7.745383184720152, -1.2572110799472342`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.552491023448555, -1.1633012820313}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647737`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647737, 0.11902724764149768`], 
              Complex[7.552491023448555, -1.0633012820313001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.704988630788337, -1.3961258835777413`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.126636969409872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055128, -0.126636969409872], 
              Complex[7.704988630788337, -1.2961258835777412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.5742681397347305`, -1.1191412329170929`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996514074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5742681397347305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0191412329170928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784467, 0.16611165996514074`], 
              Complex[7.5742681397347305`, -1.0191412329170928`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.682951641637805, -1.4402694180832754`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1737326571346823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650828, -0.1737326571346823], 
              Complex[7.682951641637805, -1.3402694180832753`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.58536879774568, -1.080787258766952}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.2069539217818482], 
              Complex[7.58536879774568, -0.980787258766952]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.671593955391062, -1.4786065851349248`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2145859850323753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.378606585134925`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240865, -0.2145859850323753], 
              Complex[7.671593955391062, -1.378606585134925]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.59199089590948, -1.0479498476029712`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28057052908999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59199089590948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.28057052908999, 0.24191392575349593`], 
              Complex[7.59199089590948, -0.9479498476029711]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.664717578441821, -1.5114269055666674`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.24955685318475315`], 
              Complex[7.664717578441821, -1.4114269055666673`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.596448189109473, -1.0191675975214376`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.28508522547646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.28508522547646, 0.27256109297706876`], 
              Complex[7.596448189109473, -0.9191675975214375]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.660008665723722, -1.5401917896926076`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280214689712569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926077`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.280214689712569], 
              Complex[7.660008665723722, -1.4401917896926077`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.599694877117055, -0.9934053728141116}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141116`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835051], 
              Complex[7.599694877117055, -0.8934053728141116]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6565129319240635`, -1.5659363812164737`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.354099557583266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076650079025534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6565129319240635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4659363812164738`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.354099557583266, -0.3076650079025534], 
              Complex[7.6565129319240635`, -1.4659363812164738`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.602190099828059, -0.9699776507063971}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790604`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242765855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.869977650706397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790604, 0.32496389242765855`], 
              Complex[7.602190099828059, -0.869977650706397]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.653771155925207, -1.5893462105216047`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581294, -0.3326382694231205], 
              Complex[7.653771155925207, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.604182742222917, -0.948416245271419}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3479481691887596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.848416245271419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.3479481691887596], 
              Complex[7.604182742222917, -0.848416245271419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.651534375550015, -1.610889470782688}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34940578787805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.651534375550015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.510889470782688`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.34940578787805, -0.3556326694484073], 
              Complex[7.651534375550015, -1.510889470782688]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.605820205415673, -0.9283882117511524}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285959, 0.36930769700429517`], 
              Complex[7.605820205415673, -0.8283882117511524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.649655116243796, -1.630899113668035}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3770021503134534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.3770021503134534], 
              Complex[7.649655116243796, -1.530899113668035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.607195850080812, -0.9096479618228555}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.389303350769084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.389303350769084], 
              Complex[7.607195850080812, -0.8096479618228555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.648039947400702, -1.6496207340949613`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39700759233314564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949613`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579122, -0.39700759233314564`], 
              Complex[7.648039947400702, -1.5496207340949613`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.608371984798496, -0.8920086413709151}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40813349152982553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 1, {
              Complex[9.296845766278874, 0.40813349152982553`], 
              Complex[7.608371984798496, -0.7920086413709151]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6466264937920405`, -1.667241192477721}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4158473617147172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 2, {
              Complex[9.344983328511988, -0.4158473617147172], 
              Complex[7.6466264937920405`, -1.5672411924777212`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.60939196819019, -0.8753243442615719}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29781789372527`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 1, {
              Complex[9.29781789372527, 0.4259529280523638], 
              Complex[7.60939196819019, -0.7753243442615719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6453713332226165`, -1.6839064009711162`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5839064009711161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 2, {
              Complex[9.343894570793292, -0.4336762721416339], 
              Complex[7.6453713332226165`, -1.5839064009711161`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.610287017953022, -0.8594786249471306}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058159`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4428851530791995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610287017953022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 1, {
              Complex[9.298664434058159, 0.4428851530791995], 
              Complex[7.610287017953022, -0.7594786249471305]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.644243187304666, -1.6997328108831595`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 2, {
              Complex[9.342933217974055, -0.4506178210463807], 
              Complex[7.644243187304666, -1.5997328108831594`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.611080255416446, -0.8443768154213616}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4590305218050602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 1, {
              Complex[9.299409090344204, 0.4590305218050602], 
              Complex[7.611080255416446, -0.7443768154213616]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.643218876724594, -1.7148150957352268`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.34207551264073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46677236810008255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.643218876724594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6148150957352267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 2, {
              Complex[9.34207551264073, -0.46677236810008255`], 
              Complex[7.643218876724594, -1.6148150957352267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.611789218669329, -0.8299407258319842}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319841`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 1, {
              Complex[9.300069789499112, 0.4744718898931336], 
              Complex[7.611789218669329, -0.7299407258319841]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.642280807952738, -1.7292314506639928`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48222277324174195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 2, {
              Complex[9.341303475971884, -0.48222277324174195`], 
              Complex[7.642280807952738, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.612427484506159, -0.8161048892141154}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.641415351146397, -1.7430473477012989`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477012988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 2, {
              Complex[9.340603220742913, -0.49703839004290706`], 
              Complex[7.641415351146397, -1.6430473477012988`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.613005749670385, -0.8028138366825415}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 1, {
              Complex[9.301191700128847, 0.5035094122855177], 
              Complex[7.613005749670385, -0.7028138366825415]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.640611758766885, -1.7563182605942464`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 2, {
              Complex[9.339963828630122, -0.5112779620899688], 
              Complex[7.640611758766885, -1.6563182605942466`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.613532572082195, -0.7900200786894217}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 1, {
              Complex[9.301672454837957, 0.5172145811965807], 
              Complex[7.613532572082195, -0.6900200786894217]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.639861424222358, -1.7690916835589525`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 2, {
              Complex[9.339376581853779, -0.5249917680556032], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.614014891510713, -0.7776825815576769}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.530437541999259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 1, {
              Complex[9.302109645838716, 0.530437541999259], 
              Complex[7.614014891510713, -0.6776825815576768]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.63915736107556, -1.7814086547578192`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.681408654757819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 2, {
              Complex[9.338834424339026, -0.5382232399630631], 
              Complex[7.63915736107556, -1.681408654757819]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.614458403240932, -0.7657655987699651}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.665765598769965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 1, {
              Complex[9.302509011886752, 0.5432161176861708], 
              Complex[7.614458403240932, -0.665765598769965]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.638493829265323, -1.7933049250204685`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 2, {
              Complex[9.338331575639636, -0.5510102042411116], 
              Complex[7.638493829265323, -1.6933049250204684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6148678313818445`, -0.754237761160508}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.654237761160508`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 1, {
              Complex[9.302875299750397, 0.5555834916479547], 
              Complex[7.6148678313818445`, -0.654237761160508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.637866061694656, -1.8048118676611498`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637866061694656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 2, {
              Complex[9.337863249005673, -0.5633858475760005], 
              Complex[7.637866061694656, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.615247132185832, -0.7430713592597934}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.567568969325976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 1, {
              Complex[9.303212473521276, 0.567568969325976], 
              Complex[7.615247132185832, -0.6430713592597934]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.637270060814722, -1.8159571961426484`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.615599647619973, -0.7322417704324756}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 1, {
              Complex[9.303523872448524, 0.5791985860418384], 
              Complex[7.615599647619973, -0.6322417704324756]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.63670244496346, -1.8267655369464089`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.587017135587317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63670244496346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.726765536946409`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 2, {
              Complex[9.337014778473916, -0.587017135587317], 
              Complex[7.63670244496346, -1.726765536946409]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.615928222964842, -0.7217269966329011}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30381233160232`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.590495597339949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 1, {
              Complex[9.30381233160232, 0.590495597339949], 
              Complex[7.615928222964842, -0.6217269966329011]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.636160330682661, -1.8372588918245425`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 2, {
              Complex[9.336628388028364, -0.5983220770848237], 
              Complex[7.636160330682661, -1.7372588918245426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.61623529799522, -0.7115072877338228}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61623529799522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 1, {
              Complex[9.304080275277004, 0.6014808784641326], 
              Complex[7.61623529799522, -0.6115072877338228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.635641241458833, -1.8474570144780953`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133891`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 2, {
              Complex[9.336263812328987, -0.6093151811133891], 
              Complex[7.635641241458833, -1.7474570144780952`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.616522978484024, -0.701564831815597}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 1, {
              Complex[9.304329790117844, 0.6121732527479823], 
              Complex[7.616522978484024, -0.6015648318155971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.635143036145728, -1.8573777202744646`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.757377720274465`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 2, {
              Complex[9.335918932011362, -0.6200152737048321], 
              Complex[7.635143036145728, -1.757377720274465]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.616793092860657, -0.6918834984038931}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304562682970772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.591883498403893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 1, {
              Complex[9.304562682970772, 0.6225897638061416], 
              Complex[7.616793092860657, -0.591883498403893]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.63466385223734, -1.8670371430158246`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 2, {
              Complex[9.335591908744412, -0.6304394010704697], 
              Complex[7.63466385223734, -1.7670371430158245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.617047237536007, -0.6824486239818056}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 1, {
              Complex[9.304780527085192, 0.6327459028649582], 
              Complex[7.617047237536007, -0.5824486239818056]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.634202060478484, -1.8764499494328057`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335281138965442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 2, {
              Complex[9.335281138965442, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.617286813480894, -0.6732468315559043}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.642655799962885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 1, {
              Complex[9.304984699340448, 0.642655799962885], 
              Complex[7.617286813480894, -0.5732468315559043]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.633756228225985, -1.885629519623863}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 2, {
              Complex[9.334985216595475, -0.6505203737511223], 
              Complex[7.633756228225985, -1.7856295196238632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.617513055986497, -0.6642658778811117}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5642658778811117`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 1, {
              Complex[9.305176410484558, 0.6523323858111211], 
              Complex[7.617513055986497, -0.5642658778811117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.633325089631603, -1.8945880998355056`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 2, {
              Complex[9.334702902745928, -0.6602042845457754], 
              Complex[7.633325089631603, -1.7945880998355057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.617727059060542, -0.6554945233226195}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.661787529645796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 1, {
              Complex[9.30535672988259, 0.661787529645796], 
              Complex[7.617727059060542, -0.5554945233226195]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6329075211926085`, -1.9033369326051628`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8033369326051627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 2, {
              Complex[9.334433100918964, -0.6696666607954198], 
              Complex[7.6329075211926085`, -1.8033369326051627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.617929795566583, -0.6469224203770383}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 1, {
              Complex[9.305526605913883, 0.6710321572939453], 
              Complex[7.617929795566583, -0.5469224203770383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.632502521562483, -1.911886368244557}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.678918430486528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445572`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 2, {
              Complex[9.334174836562125, -0.678918430486528], 
              Complex[7.632502521562483, -1.8118863682445572`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.618122133957997, -0.6385400176762599}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762599`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 1, {
              Complex[9.305686882893223, 0.6800763528244185], 
              Complex[7.618122133957997, -0.5385400176762599]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.632109194769859, -1.9202459608400855`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 2, {
              Complex[9.333927240101856, -0.6879696797720988], 
              Complex[7.632109194769859, -1.8202459608400856`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.618304852267418, -0.630338476918154}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181541`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 1, {
              Complex[9.305838315194185, 0.6889294464957763], 
              Complex[7.618304852267418, -0.5303384769181541]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.631726736184743, -1.9284245513261358`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 2, {
              Complex[9.333689532777537, -0.6968297409230595], 
              Complex[7.631726736184743, -1.8284245513261357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.618478649868707, -0.6223096006529586}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 1, {
              Complex[9.305981579104795, 0.697600091198504], 
              Complex[7.618478649868707, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6313544207148105`, -1.936430339702474}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 2, {
              Complex[9.333461014745714, -0.7055072687737806], 
              Complex[7.6313544207148105`, -1.836430339702474]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.618644157419197, -0.6144457692358488}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306117282833021`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 1, {
              Complex[9.306117282833021, 0.7060963291837468], 
              Complex[7.618644157419197, -0.5144457692358487]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.630991592823768, -1.9442709480852425`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333241055036742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.714010307453912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 2, {
              Complex[9.333241055036742, -0.714010307453912], 
              Complex[7.630991592823768, -1.8442709480852426`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.618801945306149, -0.606739885558876}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.506739885558876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 1, {
              Complex[9.306245974993525, 0.7144256505494251], 
              Complex[7.618801945306149, -0.506739885558876]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.630637658047721, -1.9519534759784036`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 2, {
              Complex[9.333029083032358, -0.7223463488774436], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.61895253085656, -0.5991853264171625}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 1, {
              Complex[9.306368151840395, 0.7225950446980841], 
              Complex[7.61895253085656, -0.4991853264171625]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.630292075750293, -1.9594845489107189`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 2, {
              Complex[9.332824581199283, -0.73052238420331], 
              Complex[7.630292075750293, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619096384518941, -0.5917758995586687}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306484263458826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457744995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518941`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49177589955866874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 1, {
              Complex[9.306484263458826, 0.7306110457744995], 
              Complex[7.619096384518941, -0.49177589955866874`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.629954352907652, -1.9668703613890224`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 2, {
              Complex[9.332627078865713, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619233935186141, -0.5845058056239242}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239242`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 1, {
              Complex[9.30659471908804, 0.7384797729243923], 
              Complex[7.619233935186141, -0.4845058056239242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.629624038754352, -1.9741167149612875`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33243614686835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 2, {
              Complex[9.33243614686835, -0.7464201648848556], 
              Complex[7.629624038754352, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6193655747968485`, -0.577369604310393}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6193655747968485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.477369604310393`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 1, {
              Complex[9.306699891715686, 0.7462069660795185], 
              Complex[7.6193655747968485`, -0.477369604310393]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.629300720152121, -1.9812290520550748`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6194916623287705`, -0.5703621842002206}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058597`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6194916623287705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 1, {
              Complex[9.306800122058597, 0.7537980178639988], 
              Complex[7.6194916623287705`, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.62898401756861, -1.9882124861522423`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649629`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62898401756861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 2, {
              Complex[9.332072457649629, -0.761751166453438], 
              Complex[7.62898401756861, -1.8882124861522425`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619612527276207, -0.563478735776971}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.463478735776971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 1, {
              Complex[9.306895722024104, 0.7612580021246147], 
              Complex[7.619612527276207, -0.463478735776971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.62867358157315, -1.9950718287746994`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 2, {
              Complex[9.33189901102014, -0.7692174219206871], 
              Complex[7.62867358157315, -1.8950718287746993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619728472689176, -0.5567147272275431}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45671472722754314`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 1, {
              Complex[9.306986977730263, 0.7685916995129585], 
              Complex[7.619728472689176, -0.45671472722754314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.628369089772418, -2.001811613684797}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379407`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.776557321057196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628369089772418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 2, {
              Complex[9.331730749379407, -0.776557321057196], 
              Complex[7.628369089772418, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619839777837859, -0.5500658826848904}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307074152149593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 1, {
              Complex[9.307074152149593, 0.7758036204842987], 
              Complex[7.619839777837859, -0.4500658826848904]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.628070244122036, -2.0084361186447754`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 2, {
              Complex[9.331567392745953, -0.7837753757227327], 
              Complex[7.628070244122036, -1.9084361186447754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.619946700555886, -0.5435281626165004}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30715748743053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44352816261650035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 1, {
              Complex[9.30715748743053, 0.7828980260257021], 
              Complex[7.619946700555886, -0.44352816261650035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.627776768560513, -2.014949385030405}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 2, {
              Complex[9.331408682475267, -0.7908758482666056], 
              Complex[7.627776768560513, -1.914949385030405]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620049479307305, -0.5370977461047796}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4370977461047796`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 1, {
              Complex[9.307237206941968, 0.7898789463823146], 
              Complex[7.620049479307305, -0.4370977461047796]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.627488406920755, -2.0213552355525555`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 2, {
              Complex[9.331254379194702, -0.7978627702556045], 
              Complex[7.627488406920755, -1.9213552355525552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6201483350148616`, -0.5307710148004995}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3073135170789`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.796750198013566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6201483350148616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4307710148004995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 1, {
              Complex[9.3073135170789, 0.796750198013566], 
              Complex[7.6201483350148616`, -0.4307710148004995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.627204921081205, -2.027657290305656}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 2, {
              Complex[9.331104260978194, -0.8047399594318435], 
              Complex[7.627204921081205, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620243472681647, -0.524544538359669}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.803515398980124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 1, {
              Complex[9.307386608861504, 0.803515398980124], 
              Complex[7.620243472681647, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.626926089324722, -2.033858981332606}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3309581217286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 2, {
              Complex[9.3309581217286, -0.811511035101225], 
              Complex[7.626926089324722, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62033508283309, -0.5184150611992571}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925703`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 1, {
              Complex[9.307456659354886, 0.8101779829358519], 
              Complex[7.62033508283309, -0.41841506119925703`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6266517048780145`, -2.039963565870766}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620423342802423, -0.5123794904283194}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 1, {
              Complex[9.307523832932748, 0.8167412118766464], 
              Complex[7.620423342802423, -0.4123794904283194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.626381574608514, -2.0459741384224643`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 2, {
              Complex[9.330677026418373, -0.8247484136793252], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620508417879312, -0.506434884829246}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404815`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.406434884829246`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 1, {
              Complex[9.307588282404815, 0.8232081877787769], 
              Complex[7.620508417879312, -0.406434884829246]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.626115517858932, -2.051893641775297}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 2, {
              Complex[9.330541725135813, -0.8312210828762443], 
              Complex[7.626115517858932, -1.9518936417752972`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620590462338551, -0.5005784447793387}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307650150024978`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 1, {
              Complex[9.307650150024978, 0.8295818632429405], 
              Complex[7.620590462338551, -0.4005784447793387]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.625853365402524, -2.0577248770820384`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620669620363362, -0.4948075030162886}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307709568394769`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39480750301628864`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 1, {
              Complex[9.307709568394769, 0.8358650512460933], 
              Complex[7.620669620363362, -0.39480750301628864`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.625594958504517, -2.0634705130965747`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330280835982268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 2, {
              Complex[9.330280835982268, -0.8438891593891126], 
              Complex[7.625594958504517, -1.9634705130965748`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620746026875822, -0.48911951616260546`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3891195161626054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.3891195161626054]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.625340148077104, -2.069133094650825}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33015496599815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 2, {
              Complex[9.33015496599815, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6208198082853045`, -0.4835120569340164}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6208198082853045`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.38351205693401635`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 1, {
              Complex[9.307821544314415, 0.8481705716325338], 
              Complex[7.6208198082853045`, -0.38351205693401635`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.625088793917113, -2.0747150504476335`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8562056684719375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 2, {
              Complex[9.330031972258515, -0.8562056684719375], 
              Complex[7.625088793917113, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620891083164294, -0.47798280696544515`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 1, {
              Complex[9.307874325710909, 0.8541979088518958], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.624840764016906, -2.0802187002360246`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 2, {
              Complex[9.329911734551452, -0.8622384184423428], 
              Complex[7.624840764016906, -1.9802187002360245`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.620959962859786, -0.4725295501957073}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 1, {
              Complex[9.30792510680319, 0.8601447828394874], 
              Complex[7.620959962859786, -0.3725295501957073]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.624595933940285, -2.085646261427687}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329794139845038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 2, {
              Complex[9.329794139845038, -0.8681906520799054], 
              Complex[7.624595933940285, -1.9856462614276873`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621026552047415, -0.46715016675857507`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610358`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621026552047415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 1, {
              Complex[9.307973982610358, 0.8660134292433511], 
              Complex[7.621026552047415, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6243541862563, -2.0909998552070284`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9909998552070285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.9909998552070285`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621090949234534, -0.4618426273335778}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357775`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 1, {
              Complex[9.308021042319385, 0.8718059882315806], 
              Complex[7.621090949234534, -0.36184262733357775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.624115410024538, -2.096281512181468}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9962815121814683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 2, {
              Complex[9.329566459959892, -0.8798624212060274], 
              Complex[7.624115410024538, -1.9962815121814683`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621153247217728, -0.45660498791489174`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489176`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 1, {
              Complex[9.308066369728037, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489176`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.623879500326575, -2.101493177613564}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.001493177613564`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 2, {
              Complex[9.32945617991971, -0.8855861488792874], 
              Complex[7.623879500326575, -2.001493177613564]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621213533499526, -0.4514353849611332}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 1, {
              Complex[9.308110043647691, 0.8831709599557607], 
              Complex[7.621213533499526, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.623646357838642, -2.106636716272229}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 2, {
              Complex[9.329348152291017, -0.8912377552298727], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621271890668614, -0.44633203089259055`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3463320308925905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.3463320308925905]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.623415888441285, -2.1117139169364294`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 2, {
              Complex[9.329242292636387, -0.8968191263829132], 
              Complex[7.623415888441285, -2.0117139169364293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621328396747195, -0.4412932099060134}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060134`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 1, {
              Complex[9.308192723503184, 0.8942551097650246], 
              Complex[7.621328396747195, -0.3412932099060134]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.623188002862294, -2.1167264965813106`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0167264965813105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 2, {
              Complex[9.329138521063246, -0.9023320727684231], 
              Complex[7.623188002862294, -2.0167264965813105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621383125508848, -0.4363172740799598}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308231865274811`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 1, {
              Complex[9.308231865274811, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.622962616349544, -2.1216761042737278`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 2, {
              Complex[9.329036761909217, -0.9077783332310712], 
              Complex[7.622962616349544, -2.0216761042737277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621436146769792, -0.4314026397464215}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3314026397464215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 1, {
              Complex[9.308269625814717, 0.9050726361762729], 
              Complex[7.621436146769792, -0.3314026397464215]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6227396483708265`, -2.126564324801446}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0265643248014458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 2, {
              Complex[9.328936943453858, -0.9131595788587066], 
              Complex[7.6227396483708265`, -2.0265643248014458`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62148752665612, -0.42654778410681526`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62148752665612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 1, {
              Complex[9.308306063909846, 0.9103855526005631], 
              Complex[7.62148752665612, -0.3265477841068153]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.622519022338055, -2.1313926820579585`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 2, {
              Complex[9.328838997654193, -0.9184774165528231], 
              Complex[7.622519022338055, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621537327849359, -0.4217512420725154}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 1, {
              Complex[9.308341235139771, 0.9156366518516704], 
              Complex[7.621537327849359, -0.3217512420725154]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.62230066535352, -2.136162642202724}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62158560981236, -0.4170116033119916}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31701160331199163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 1, {
              Complex[9.308375192092747, 0.9208274215121246], 
              Complex[7.62158560981236, -0.31701160331199163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.622084507976147, -2.140875616614767}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 2, {
              Complex[9.328648468799225, -0.9289289945966068], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621632428997374, -0.41232750948827984`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 1, {
              Complex[9.30840798456442, 0.9259592943584083], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.62187048400586, -2.145532964655917}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 2, {
              Complex[9.32855576595434, -0.9340656567439877], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621677839037959, -0.4076976516720178}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037959`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720178`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 1, {
              Complex[9.308439659740834, 0.9310336510892627], 
              Complex[7.621677839037959, -0.3076976516720178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.621658530284445, -2.1501359962584585`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0501359962584584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 2, {
              Complex[9.328464695790347, -0.9391447601963724], 
              Complex[7.621658530284445, -2.0501359962584584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621721890926156, -0.403120767916594}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.303120767916594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 1, {
              Complex[9.30847026236711, 0.9360518228828755], 
              Complex[7.621721890926156, -0.303120767916594]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.621448586511419, -2.154685974350639}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.054685974350639`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 2, {
              Complex[9.328375205370593, -0.9441676368090828], 
              Complex[7.621448586511419, -2.054685974350639]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62176463317627, -0.39859564098319433`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 1, {
              Complex[9.308499834903161, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.621240595073557, -2.1591841171322494`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 2, {
              Complex[9.32828724423658, -0.9491355712999278], 
              Complex[7.621240595073557, -2.0591841171322494`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621806111976445, -0.3941210962045658}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456584`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 1, {
              Complex[9.308528417667574, 0.9459247030157981], 
              Complex[7.621806111976445, -0.29412109620456584`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6210345008869025`, -2.1636316002114744`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 2, {
              Complex[9.328200764258012, -0.9540498035022785], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621846371329063, -0.38969599947733174`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 1, {
              Complex[9.308556048970688, 0.9507818469782096], 
              Complex[7.621846371329063, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.620830251250196, -2.1680295586131595`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.06802955861316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 2, {
              Complex[9.328115719493919, -0.9589115304824556], 
              Complex[7.620830251250196, -2.06802955861316]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621885453180955, -0.3853192553735125}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 1, {
              Complex[9.308582765237823, 0.9555876813576086], 
              Complex[7.621885453180955, -0.2853192553735125]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.620627795708714, -2.1723790886678507`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32803206606383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 2, {
              Complex[9.32803206606383, -0.9637219085313012], 
              Complex[7.620627795708714, -2.072379088667851]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621923397544282, -0.380989805362763}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9603433229418255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.280989805362763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 1, {
              Complex[9.30860860112351, 0.9603433229418255], 
              Complex[7.621923397544282, -0.280989805362763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.620427085927699, -2.1766812497901036`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 2, {
              Complex[9.327949762028192, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.621960242608855, -0.376706626137473}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30863358961748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 1, {
              Complex[9.30863358961748, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.620228075574522, -2.180937066153904}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6219960248466, -0.3724687280335842}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 1, {
              Complex[9.30865776214308, 0.9697083109361541], 
              Complex[7.6219960248466, -0.27246872803358424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.620030720208936, -2.18514752827235}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 2, {
              Complex[9.327789043427424, -0.9778559389833152], 
              Complex[7.620030720208936, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622030779108827, -0.3682751535405317}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308681148648779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9743197118823447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26827515354053166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 1, {
              Complex[9.308681148648779, 0.9743197118823447], 
              Complex[7.622030779108827, -0.26827515354053166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.619834977180716, -2.189313594488205}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6220645387168675`, -0.3641249758942417}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 1, {
              Complex[9.308703777693308, 0.9788850321593936], 
              Complex[7.6220645387168675`, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.619640805534103, -2.193436192381359}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327633262958448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381359`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 2, {
              Complex[9.327633262958448, -0.9870414080668153], 
              Complex[7.619640805534103, -2.093436192381359]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6220973355465995`, -0.36001729774761987`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 1, {
              Complex[9.308725676524938, 0.9834052186894812], 
              Complex[7.6220973355465995`, -0.26001729774761984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.619448165918566, -2.197516220098791}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622129200107364, -0.3559512499133871}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189867`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133871`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 1, {
              Complex[9.308746871155384, 0.9878811887189867], 
              Complex[7.622129200107364, -0.2559512499133871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.619257020505317, -2.201554547612181}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.101554547612181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 2, {
              Complex[9.327482144581792, -0.9960461687506839], 
              Complex[7.619257020505317, -2.101554547612181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62216016161569, -0.3519259901745168}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62216016161569`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 1, {
              Complex[9.308767386428748, 0.9923138310722677], 
              Complex[7.62216016161569, -0.25192599017451683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.619067332909202, -2.205552017907876}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327408253521732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0004830605740669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 2, {
              Complex[9.327408253521732, -1.0004830605740669`], 
              Complex[7.619067332909202, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622190248064221, -0.34794070215790135`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790134`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 1, {
              Complex[9.30878724608588, 0.9967040073387549], 
              Complex[7.622190248064221, -0.24794070215790134`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.618879068115525, -2.2095094481136432`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113643`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 2, {
              Complex[9.327335434354206, -1.0048774519249053`], 
              Complex[7.618879068115525, -2.109509448113643]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622219486286243, -0.34399459426719087`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719083`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719083`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.618692192411457, -2.2134276305662133`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566213`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 2, {
              Complex[9.327263658416845, -1.0092301787755904`], 
              Complex[7.618692192411457, -2.113427630566213]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622247902016085, -0.34008689867107683`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.618506673321678, -2.217307333823378}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622275519945756, -0.33621687034352843`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352842`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 1, {
              Complex[9.308843113455703, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.618322479547938, -2.2211493036241214`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1211493036241214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 2, {
              Complex[9.327123127092815, -1.0178138586055252`], 
              Complex[7.618322479547938, -2.1211493036241214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622302363778045, -0.33238378615278963`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278965`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 1, {
              Complex[9.308860568016621, 1.0138563914775587`], 
              Complex[7.622302363778045, -0.23238378615278965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.618139580912274, -2.224954263799971}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 2, {
              Complex[9.327054319725958, -1.0220463622527833`], 
              Complex[7.618139580912274, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622328456276395, -0.32858694399614213`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2285869439961421`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 1, {
              Complex[9.308877471091343, 1.0180462834838342`], 
              Complex[7.622328456276395, -0.2285869439961421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6179579483036175`, -2.228722917140585}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.02624030460825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 2, {
              Complex[9.326986451526654, -1.02624030460825], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622353819311706, -0.32482566197765633`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765633`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 1, {
              Complex[9.308893840937472, 1.0221983660944398`], 
              Complex[7.622353819311706, -0.22482566197765633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.617777553627534, -2.2324559462163154`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0303964059906547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 2, {
              Complex[9.326919498869884, -1.0303964059906547`], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62237847390638, -0.3210992776263989}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.026313338713697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 1, {
              Complex[9.3089096950579, 1.026313338713697], 
              Complex[7.62237847390638, -0.2210992776263989]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.617598369758898, -2.236154014160339}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617598369758898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.617598369758898, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622402440275709, -0.31740714715263535`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308925050238992`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.030391881059093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 1, {
              Complex[9.308925050238992, 1.030391881059093], 
              Complex[7.622402440275709, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.617420370497285, -2.2398177654127513`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.038597865497053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 2, {
              Complex[9.326788249964949, -1.038597865497053], 
              Complex[7.617420370497285, -2.1398177654127513`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622425737866838, -0.31374864473986164`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0344346539072422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986163`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 1, {
              Complex[9.30893992258648, 1.0344346539072422`], 
              Complex[7.622425737866838, -0.21374864473986163`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.617243530524916, -2.2434478264288384`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288384`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 2, {
              Complex[9.326723910626667, -1.0426445649584875`], 
              Complex[7.617243530524916, -2.1434478264288384`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622448385395499, -0.31012316187055844`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 1, {
              Complex[9.308954327559254, 1.0384422998042995`], 
              Complex[7.622448385395499, -0.2101231618705584]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6170678253669655`, -2.247044806353595}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326660400575378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1470448063535947`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 2, {
              Complex[9.326660400575378, -1.0466561075785732`], 
              Complex[7.6170678253669655`, -2.1470448063535947`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622470400880571, -0.3065301066837352}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.616893231354067, -2.250609297664498}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1506092976644977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 2, {
              Complex[9.326597700119693, -1.0506331187508067`], 
              Complex[7.616893231354067, -2.1506092976644977`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622491801676729, -0.3029689033624719}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308981794170638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 1, {
              Complex[9.308981794170638, 1.04635469380724], 
              Complex[7.622491801676729, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.616719725586928, -2.2541418767841748`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32653579024921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 2, {
              Complex[9.32653579024921, -1.0545762069524505`], 
              Complex[7.616719725586928, -2.1541418767841747`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622512604505212, -0.2994389915497566}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1994389915497566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 1, {
              Complex[9.308994883769515, 1.0502606417889437`], 
              Complex[7.622512604505212, -0.1994389915497566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.616547285902739, -2.2576431046649517`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0584859643603295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1576431046649516`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 2, {
              Complex[9.326474652603714, -1.0584859643603295`], 
              Complex[7.616547285902739, -2.1576431046649516`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622532825482894, -0.2959398257910545}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1959398257910545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.1959398257910545]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6163758908436705`, -2.2611135273463345`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32641426944434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6163758908436705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1611135273463344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 2, {
              Complex[9.32641426944434, -1.0623629674380977`], 
              Complex[7.6163758908436705`, -2.1611135273463344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622552480149748, -0.2924708750021308}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622552480149748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021308`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 1, {
              Complex[9.309019841434887, 1.0579749207033111`], 
              Complex[7.622552480149748, -0.1924708750021308]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6162055196267024`, -2.2645536764876297`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1645536764876296`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 2, {
              Complex[9.326354623625985, -1.0662077774973102`], 
              Complex[7.6162055196267024`, -2.1645536764876296`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622571583494798, -0.28903162196075954`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 1, {
              Complex[9.309031734351517, 1.061784358908797], 
              Complex[7.622571583494798, -0.18903162196075954`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.616036152115315, -2.2679640698763754`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 2, {
              Complex[9.326295698571451, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622590149980672, -0.285621562821009}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622590149980672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100895`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 1, {
              Complex[9.309043252443765, 1.0655627106244425`], 
              Complex[7.622590149980672, -0.18562156282100895`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.615867768792523, -2.271345211914303}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622608193566829, -0.28224020664891897`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 1, {
              Complex[9.309054406998326, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.615700350735352, -2.2746975940818928`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 2, {
              Complex[9.326179947138469, -1.0775544464801794`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622625727731573, -0.2788870749784164}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30906520888366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 1, {
              Complex[9.30906520888366, 1.0730282159476652`], 
              Complex[7.622625727731573, -0.1788870749784164]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.615533879590611, -2.27802169538267}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 2, {
              Complex[9.326123090230514, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622642765492878, -0.2755617013864216}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0767163678318636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642158`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 1, {
              Complex[9.30907566856886, 1.0767163678318636`], 
              Complex[7.622642765492878, -0.17556170138642158`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6153683375518915`, -2.2813179827683108`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326066892984452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 2, {
              Complex[9.326066892984452, -1.0849675833073056`], 
              Complex[7.6153683375518915`, -2.1813179827683107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6226593194281556`, -0.2722636310861379}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30908579614155`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6226593194281556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 1, {
              Complex[9.30908579614155, 1.0803754306555198`], 
              Complex[7.6226593194281556`, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.615203707337714, -2.2845869115455564`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.088630238875599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 2, {
              Complex[9.32601134131908, -1.088630238875599], 
              Complex[7.615203707337714, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622675401692968, -0.2689924205375893}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.16899242053758934`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 1, {
              Complex[9.309095601324776, 1.0840058730914184`], 
              Complex[7.622675401692968, -0.16899242053758934`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.61503997217078, -2.2878289257658757`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61503997217078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1878289257658756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 2, {
              Complex[9.325956421591755, -1.0922642484964789`], 
              Complex[7.61503997217078, -2.1878289257658756`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622691024038829, -0.2657476370745408}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.087608152351`", " ", "\[ImaginaryI]"}]}], ",", 
                    
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.16574763707454077`", " ", "\[ImaginaryI]"}]}]}]
                  , "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 1, {
              Complex[9.309105093493066, 1.087608152351], 
              Complex[7.622691024038829, -0.16574763707454077`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.614877115758213, -2.2910444585987433`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 2, {
              Complex[9.325902120580537, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622706197830052, -0.2625288585469304}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 1, {
              Complex[9.309114281687616, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.614715122272787, -2.2942339326893824`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1942339326893823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 2, {
              Complex[9.325848425467223, -1.0994481489240941`], 
              Complex[7.614715122272787, -2.1942339326893823`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622720934059783, -0.25933567297809695`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809695`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 1, {
              Complex[9.309123174630704, 1.0947299951246658`], 
              Complex[7.622720934059783, -0.15933567297809695`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.614553976335034, -2.2973977605017106`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325795323821204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102998921879825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614553976335034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 2, {
              Complex[9.325795323821204, -1.102998921879825], 
              Complex[7.614553976335034, -2.1973977605017105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62273524336523, -0.2561676782360194}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739364`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0982504190677982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62273524336523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 1, {
              Complex[9.309131780739364, 1.0982504190677982`], 
              Complex[7.62273524336523, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.614393662996275, -2.300536344647329}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.200536344647329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 2, {
              Complex[9.325742803584207, -1.1065228138938534`], 
              Complex[7.614393662996275, -2.200536344647329]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622749136042124, -0.25302448171788944`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788943`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.614234167722326, -2.303650078201037}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32569085305561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 2, {
              Complex[9.32569085305561, -1.1100202402427715`], 
              Complex[7.614234167722326, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622762622058505, -0.24990570004738188`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 1, {
              Complex[9.309148164672498, 1.1052123472899036`], 
              Complex[7.622762622058505, -0.14990570004738188`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.61407547637812, -2.306739345003824}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.113491606471821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61407547637812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003824`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 2, {
              Complex[9.325639460878644, -1.113491606471821], 
              Complex[7.61407547637812, -2.206739345003824]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622775711067786, -0.24681095878399056`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30915595791838`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 1, {
              Complex[9.30915595791838, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.613917575212904, -2.3098045199536035`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087011036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.209804519953604`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 2, {
              Complex[9.325588616027114, -1.1169373087011036`], 
              Complex[7.613917575212904, -2.209804519953604]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622788412421259, -0.24373989214385836`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195483`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 1, {
              Complex[9.309163495195483, 1.112071704185835], 
              Complex[7.622788412421259, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6137604508462084`, -2.312845969284587}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6137604508462084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 2, {
              Complex[9.325538307792806, -1.1203577339198192`], 
              Complex[7.6137604508462084`, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622800735179931, -0.24069214273155679`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155678`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.613604090254429, -2.315864050835693}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123753260268964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 2, {
              Complex[9.325488525773522, -1.123753260268964], 
              Complex[7.613604090254429, -2.215864050835693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622812688125852, -0.2376673612822912}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30917782989869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 1, {
              Complex[9.30917782989869, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.613448480758027, -2.318859114308416}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758027`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 2, {
              Complex[9.325439259861604, -1.1271242573129165`], 
              Complex[7.613448480758027, -2.2188591143084158`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622824279772895, -0.23466520641404973`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13466520641404972`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.13466520641404972`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6132936100092135`, -2.3218315015148576`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 2, {
              Complex[9.325390500232961, -1.1304710863006697`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622835518377009, -0.23168534438924218`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438924218`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 1, {
              Complex[9.309191222585207, 1.1254948021761504`], 
              Complex[7.622835518377009, -0.13168534438924218`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.613139465980372, -2.324781546616249}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.224781546616249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 2, {
              Complex[9.32534223733676, -1.1337941004170398`], 
              Complex[7.613139465980372, -2.224781546616249]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6228464119461155`, -0.2287274488853229}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 1, {
              Complex[9.309197581524451, 1.1287910849032745`], 
              Complex[7.6228464119461155`, -0.12872744888532286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612986036952771, -2.327709576352395}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 2, {
              Complex[9.325294461885356, -1.1370936450243199`], 
              Complex[7.612986036952771, -2.227709576352395]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622856968249287, -0.22579120077420298`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420297`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 1, {
              Complex[9.309203723570544, 1.1320642574808069`], 
              Complex[7.622856968249287, -0.12579120077420297`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612833311505916, -2.330615910262511}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.140370057894864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 2, {
              Complex[9.325247164844852, -1.140370057894864], 
              Complex[7.612833311505916, -2.2306159102625114`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622867194825836, -0.2228762879096945}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669171`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790969447`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 1, {
              Complex[9.309209654512552, 1.1353146500669171`], 
              Complex[7.622867194825836, -0.12287628790969447`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612681278507311, -2.3335008608977987`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622877098993824, -0.21998240492294205`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294204`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 1, {
              Complex[9.309215379954185, 1.1385425856735323`], 
              Complex[7.622877098993824, -0.11998240492294204`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612529927102651, -2.336364734026166}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146854802900513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 2, {
              Complex[9.325153971075478, -1.146854802900513], 
              Complex[7.612529927102651, -2.236364734026166]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6228866878581005`, -0.2171092530254299}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.141748380373843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.1171092530254299`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 1, {
              Complex[9.309220905320855, 1.141748380373843], 
              Complex[7.6228866878581005`, -0.1171092530254299]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612379246706456, -2.3392078288294065`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622895968318212, -0.2142565398190205}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902048`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.612229226993079, -2.3420304380931958`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32506258849663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2420304380931957`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 2, {
              Complex[9.32506258849663, -1.1532508941175421`], 
              Complex[7.612229226993079, -2.2420304380931957`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622904947075781, -0.21142397911299568`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309231376680849`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075781`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 1, {
              Complex[9.309231376680849, 1.1480947778478907`], 
              Complex[7.622904947075781, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6120798578880935`, -2.3448328483902143`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32501755626854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 2, {
              Complex[9.32501755626854, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622913630641643, -0.20861129074761456`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923633269408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761455`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 1, {
              Complex[9.30923633269408, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611931129560043, -2.3476153402566924`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 2, {
              Complex[9.324972953094393, -1.1595607822888858`], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622922025342652, -0.20581820042396873`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1543562397232365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396872`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 1, {
              Complex[9.309241108684372, 1.1543562397232365`], 
              Complex[7.622922025342652, -0.10581820042396872`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611783032412529, -2.3503781883626598`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324928771483046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 2, {
              Complex[9.324928771483046, -1.1626841380761952`], 
              Complex[7.611783032412529, -2.2503781883626597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622930137328205, -0.203044439539864}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611635557076614, -2.3531216616761803`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25312166167618`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 2, {
              Complex[9.324885004134526, -1.165786816282607], 
              Complex[7.611635557076614, -2.25312166167618]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622937972576472, -0.20028974503145566`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 1, {
              Complex[9.309250138979014, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611488694403536, -2.3558460236218126`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 2, {
              Complex[9.324841643933636, -1.168869095524048], 
              Complex[7.611488694403536, -2.2558460236218125`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622945536900375, -0.19755385922041177`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800904988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622945536900375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09755385922041178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 1, {
              Complex[9.309254402126268, 1.1635941800904988`], 
              Complex[7.622945536900375, -0.09755385922041178]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611342435457713, -2.3585515322335584`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.171931248732842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2585515322335588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 2, {
              Complex[9.324798683943808, -1.171931248732842], 
              Complex[7.611342435457713, -2.2585515322335588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622952835953342, -0.1948365296663516}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 1, {
              Complex[9.309258502946616, 1.1666334563353578`], 
              Complex[7.622952835953342, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611196771510029, -2.361238440302506}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 2, {
              Complex[9.324756117401229, -1.1749735433132202`], 
              Complex[7.611196771510029, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62295987523472, -0.19213750902438434`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309262445535504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62295987523472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438433`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 1, {
              Complex[9.309262445535504, 1.1696531548443265`], 
              Complex[7.62295987523472, -0.09213750902438433]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.611051694031386, -2.363906995519419}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.263906995519419`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 2, {
              Complex[9.324713937709186, -1.1779962412914937`], 
              Complex[7.611051694031386, -2.263906995519419]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622966660095128, -0.18945655490745505`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866465`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622966660095128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745505`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 1, {
              Complex[9.309266233866465, 1.1726535322072738`], 
              Complex[7.622966660095128, -0.08945655490745505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6109071946864875`, -2.3665574406124446`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1809995994611011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6109071946864875`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2665574406124445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 2, {
              Complex[9.324672138432643, -1.1809995994611011`], 
              Complex[7.6109071946864875`, -2.2665574406124445`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6229731957414195`, -0.18679342975340715`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 1, {
              Complex[9.309269871795374, 1.1756348399245427`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610763265327906, -2.3691900134801815`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1839838695227543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 2, {
              Complex[9.32463071329305, -1.1839838695227543`], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622979487241573, -0.1841479006964719}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964719`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 1, {
              Complex[9.309273363064712, 1.1785973245423351`], 
              Complex[7.622979487241573, -0.0841479006964719]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610619897990325, -2.3718049473202556`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2718049473202555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 2, {
              Complex[9.324589656163335, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.2718049473202555`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622985539529303, -0.18151973944306796`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 1, {
              Complex[9.309276711307533, 1.1815412277835529`], 
              Complex[7.622985539529303, -0.08151973944306795]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610477084885046, -2.374402470753615}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.274402470753615`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 2, {
              Complex[9.324548961063108, -1.1898961274694762`], 
              Complex[7.610477084885046, -2.274402470753615]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.622991357408529, -0.17890872215171552`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051317`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 1, {
              Complex[9.309279920051317, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610334818394682, -2.3769828079447075`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32450862215405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 2, {
              Complex[9.32450862215405, -1.1928245944888058`], 
              Complex[7.610334818394682, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6229969455576505`, -0.176314629316898}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309282992721648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.187374233666283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229969455576505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 1, {
              Complex[9.309282992721648, 1.187374233666283], 
              Complex[7.6229969455576505`, -0.07631462931689799]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610193091068046, -2.3795461787176904`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.610193091068046, -2.2795461787176907`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623002308533652, -0.1737372456567278}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.190263796755059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672779`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 1, {
              Complex[9.309285932645754, 1.190263796755059], 
              Complex[7.623002308533652, -0.07373724565672779]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.610051895615262, -2.382092798668853}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.282092798668853]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623007450776046, -0.17117636000425368`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055877`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1931356995946463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 1, {
              Complex[9.309288743055877, 1.1931356995946463`], 
              Complex[7.623007450776046, -0.07117636000425366]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609911224902993, -2.384622879275391}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2015021263830652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 2, {
              Complex[9.32438968622985, -1.2015021263830652`], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623012376610668, -0.1686317652022813}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228129`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 1, {
              Complex[9.309291427092525, 1.1959901616082877`], 
              Complex[7.623012376610668, -0.06863176520228129]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609771071949929, -2.3871366280006607`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609771071949929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 2, {
              Complex[9.324350716392054, -1.2043594268588766`], 
              Complex[7.609771071949929, -2.2871366280006606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623017090253322, -0.16610325800154557`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154555`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 1, {
              Complex[9.309293987807608, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154555]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609631429922362, -2.3896342483960757`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.207199484841066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 2, {
              Complex[9.324312075535534, -1.207199484841066], 
              Complex[7.609631429922362, -2.2896342483960757`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623021595813279, -0.16359063896214554`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214552`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 1, {
              Complex[9.309296428167407, 1.201647620337122], 
              Complex[7.623021595813279, -0.06359063896214552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609492292129979, -2.3921159401997616`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 2, {
              Complex[9.324273758587012, -1.210022511784006], 
              Complex[7.609492292129979, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6230258972966505`, -0.16109371235807937`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30929875105546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230258972966505`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 1, {
              Complex[9.30929875105546, 1.204451035693495], 
              Complex[7.6230258972966505`, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609353652021753, -2.394581899432069}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.294581899432069`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 2, {
              Complex[9.324235760587548, -1.2128287152203794`], 
              Complex[7.609353652021753, -2.294581899432069]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62302999860963, -0.15861228608478187`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.609215503182054, -2.397032318488139}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689214`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 2, {
              Complex[9.324198076689214, -1.215618298858686], 
              Complex[7.609215503182054, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6230339035616055`, -0.15614617156954191`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.056146171569541894`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 1, {
              Complex[9.309303055553212, 1.2100082561816612`], 
              Complex[7.6230339035616055`, -0.056146171569541894`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6090778393267975`, -2.3994673862275167`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 2, {
              Complex[9.324160702151756, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623037615868166, -0.15369518368470517`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 1, {
              Complex[9.309305042540567, 1.2127624573020028`], 
              Complex[7.623037615868166, -0.05369518368470517]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608940654299824, -2.401887288061049}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623041139153995, -0.15125914066353693`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 1, {
              Complex[9.30930692281649, 1.2155006436945393`], 
              Complex[7.623041139153995, -0.051259140663536915`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608803942069356, -2.4042922060350675`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 2, {
              Complex[9.324086862718293, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623044476955635, -0.14883786401866925`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608667696724579, -2.40668231891301}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 2, {
              Complex[9.32405038885261, -1.2266143809612577`], 
              Complex[7.608667696724579, -2.30668231891301]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6230476327242, -0.146431178463023}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931037320279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.046431178463023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 1, {
              Complex[9.30931037320279, 1.2209297255903706`], 
              Complex[7.6230476327242, -0.046431178463023]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608531912472353, -2.4090578022545657`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 2, {
              Complex[9.324014206402692, -1.2293237938391435`], 
              Complex[7.608531912472353, -2.3090578022545656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62305060982792, -0.14403891183311732`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311732`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608396583634034, -2.411418828492421}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 2, {
              Complex[9.323978311121861, -1.232017733951226], 
              Complex[7.608396583634034, -2.311418828492421]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623053411554654, -0.14166089501468168`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313425985488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 1, {
              Complex[9.309313425985488, 1.2262969751610369`], 
              Complex[7.623053411554654, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608261704642392, -2.413765567006709}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.313765567006709`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.313765567006709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623056041114285, -0.13929696187048873`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048871`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 1, {
              Complex[9.309314809018923, 1.2289578590746733`], 
              Complex[7.623056041114285, -0.03929696187048871]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.608127270038647, -2.4160981841972364`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32390736553039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 2, {
              Complex[9.32390736553039, -1.2373599104404134`], 
              Complex[7.608127270038647, -2.3160981841972363`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623058501641019, -0.13694694917032468`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422274`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641019`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 1, {
              Complex[9.309316099422274, 1.2316038141805974`], 
              Complex[7.623058501641019, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607993274469599, -2.4184168435535702`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32387230716855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607993274469599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 2, {
              Complex[9.32387230716855, -1.2400084963104758`], 
              Complex[7.607993274469599, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623060796195635, -0.13461069652302157`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329456`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03461069652302155`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 1, {
              Complex[9.309317299329456, 1.2342350105444317`], 
              Complex[7.623060796195635, -0.03461069652302155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607859712684853, -2.4207217057230577`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2426423085461482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3207217057230576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 2, {
              Complex[9.323837519868583, -1.2426423085461482`], 
              Complex[7.607859712684853, -2.3207217057230576`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62306292776762, -0.1322880463104823}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318410818571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306292776762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03228804631048228`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 1, {
              Complex[9.309318410818571, 1.2368516153040956`], 
              Complex[7.62306292776762, -0.03228804631048228]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607726579534131, -2.42301292857686}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 2, {
              Complex[9.323802999811543, -1.2452615144292976`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623064899277237, -0.12997884362362627`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913643`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 1, {
              Complex[9.309319435913643, 1.2394537927373113`], 
              Complex[7.623064899277237, -0.02997884362362627]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607593869964681, -2.4252906672740604`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323768743257098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 2, {
              Complex[9.323768743257098, -1.2478662783795624`], 
              Complex[7.607593869964681, -2.3252906672740603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62306671357756, -0.12768293620018037`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 1, {
              Complex[9.309320376586303, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.60746157901877, -2.427555074323918}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32373474654141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 2, {
              Complex[9.32373474654141, -1.2504567620199434`], 
              Complex[7.60746157901877, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6230683734563724`, -0.12540017436427092`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757375`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230683734563724`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.02540017436427092`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 1, {
              Complex[9.309321234757375, 1.2446155088257418`], 
              Complex[7.6230683734563724`, -0.02540017436427092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607329701831238, -2.42980629964634}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 2, {
              Complex[9.323701006075066, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623069881638048, -0.123130410967729}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096772899`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 1, {
              Complex[9.30932201229845, 1.247175362316048], 
              Complex[7.623069881638048, -0.02313041096772899]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607198233627162, -2.432044490630609}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 2, {
              Complex[9.323667518341093, -1.2555955212603065`], 
              Complex[7.607198233627162, -2.3320444906306093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623071240785351, -0.12087350133308127`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.24972141827203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333081253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 1, {
              Complex[9.309322711033376, 1.24972141827203], 
              Complex[7.623071240785351, -0.020873501333081253`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.607067169719584, -2.434269792192463}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.334269792192463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.334269792192463]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623072453501176, -0.11862930319812}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01862930319811999`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 1, {
              Complex[9.309323332739696, 1.2522538276170252`], 
              Complex[7.623072453501176, -0.01862930319811999]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6069365055072815`, -2.4364823468295485`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 2, {
              Complex[9.323601287353112, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623073522330235, -0.11639767666206907`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 1, {
              Complex[9.309323879150053, 1.2547727387804997`], 
              Complex[7.623073522330235, -0.016397676662069066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606806236472662, -2.4386822946753206`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623074449760662, -0.11417848413322271`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133222693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 1, {
              Complex[9.309324351953515, 1.2572782977532329`], 
              Complex[7.623074449760662, -0.014178484133222693`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606676358179671, -2.4408697735514435`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.265708491546124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 2, {
              Complex[9.323536026818966, -1.265708491546124], 
              Complex[7.606676358179671, -2.3408697735514434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62307523822562, -0.11197159027804626`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796897`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.011971590278046269`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 1, {
              Complex[9.309324752796897, 1.2597706481409683`], 
              Complex[7.62307523822562, -0.011971590278046269`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606546866271806, -2.4430449190187264`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 2, {
              Complex[9.323503752396528, -1.2682033164767694`], 
              Complex[7.606546866271806, -2.343044919018727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62307589010475, -0.10977686197169255`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307589010475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.00977686197169255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 1, {
              Complex[9.309325083285962, 1.2622499312165716`], 
              Complex[7.62307589010475, -0.00977686197169255]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606417756470162, -2.445207864426671}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 2, {
              Complex[9.323471711022448, -1.2706850606806677`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, "Tooltip"]& ]\
}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623076407725729, -0.10759416824985353`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 1, {
              Complex[9.309325344986703, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606289024571562, -2.4473587409616404`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2731538632721078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 2, {
              Complex[9.323439899636348, -1.2731538632721078`], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623076793365634, -0.10542338026194198`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325539426466`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076793365634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261941976`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 1, {
              Complex[9.309325539426466, 1.2671698491615675`], 
              Complex[7.623076793365634, -0.005423380261941976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606160666446716, -2.449497677693729}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 2, {
              Complex[9.323408315236538, -1.2756098611309443`], 
              Complex[7.606160666446716, -2.349497677693729]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623077049252295, -0.10326437122555457`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255545658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 1, {
              Complex[9.309325668095038, 1.2696107553621172`], 
              Complex[7.623077049252295, -0.0032643712255545658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.606032678038458, -2.4516248016223536`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623077177565682, -0.10111701638211794`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821179458`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 1, {
              Complex[9.309325732445826, 1.2720391370076067`], 
              Complex[7.623077177565682, -0.0011170163821179458`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605905055360047, -2.453740237720617}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.280483979285027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 2, {
              Complex[9.323345815673619, -1.280483979285027], 
              Complex[7.605905055360047, -2.3537402377206167`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623077180439138, -0.09898119295378295}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605777794493471, -2.455844108978483}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62307705996065, -0.09685678010142795}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0031432198985720384`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.0031432198985720384`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605650891587858, -2.4579365364447976`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 2, {
              Complex[9.323284189438796, -1.2853084672867794`], 
              Complex[7.605650891587858, -2.3579365364447975`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623076818174038, -0.09474365888378923}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076818174038`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.623076818174038, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605524342857891, -2.460017639268197}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605524342857891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 2, {
              Complex[9.323253696898023, -1.2877024197670905`], 
              Complex[7.605524342857891, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623076457080136, -0.09264171221767256}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325374521514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080136`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 1, {
              Complex[9.309325374521514, 1.2816299944237621`], 
              Complex[7.623076457080136, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605398144582299, -2.4620875347369378`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323223414486042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 2, {
              Complex[9.323223414486042, -1.2900843444730694`], 
              Complex[7.605398144582299, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623075978637889, -0.09055082483920177}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605272293102371, -2.464146338317678}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 2, {
              Complex[9.323193339572983, -1.2924543639191772`], 
              Complex[7.605272293102371, -2.3641463383176777`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623075384765489, -0.08847088326608642}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933625`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 1, {
              Complex[9.309324844933625, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605146784820534, -2.466194163693252}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 2, {
              Complex[9.323163469577015, -1.2948125987358021`], 
              Complex[7.605146784820534, -2.366194163693252]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62307467734139, -0.08640177576086341}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136585`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.605021616198947, -2.4682311227994647`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 2, {
              Complex[9.323133801963195, -1.2971591677080445`], 
              Complex[7.605021616198947, -2.3682311227994646`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62307385820537, -0.08434339229508761}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491239`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 1, {
              Complex[9.309324094995942, 1.2910305277808343`], 
              Complex[7.62307385820537, 0.01565660770491239]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604896783758137, -2.470257325860909}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 2, {
              Complex[9.323104334242323, -1.2994941878134683`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623072929159485, -0.08229562451444782}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371002`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.017704375485552187`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 1, {
              Complex[9.309323640371002, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485552187`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604772284075737, -2.47227288142594}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323075063969917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.37227288142594`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 2, {
              Complex[9.323075063969917, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.37227288142594]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623071891969078, -0.080258365704765}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019741634295235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 1, {
              Complex[9.309323134173038, 1.2956617974980966`], 
              Complex[7.623071891969078, 0.019741634295235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604648113785146, -2.4742778964006518`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 2, {
              Complex[9.323045988745086, -1.3041300405165714`], 
              Complex[7.604648113785146, -2.3742778964006517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623070748363669, -0.07823151075886135}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138642`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 1, {
              Complex[9.309322577516866, 1.2979605814829254`], 
              Complex[7.623070748363669, 0.021768489241138642`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.60452426957432, -2.4762724760820616`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 2, {
              Complex[9.323017106209537, -1.3064310983584466`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623069500037889, -0.07621495614426664}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491421`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 1, {
              Complex[9.309321971491421, 1.300248278779899], 
              Complex[7.623069500037889, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604400748184572, -2.4782567241904516`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904515`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 2, {
              Complex[9.322988414046595, -1.3087210578909663`], 
              Complex[7.604400748184572, -2.3782567241904515`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623068148652342, -0.07420859987173112}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321317160448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 1, {
              Complex[9.309321317160448, 1.3025249977626074`], 
              Complex[7.623068148652342, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604277546409373, -2.4802307429008645`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.311000027587925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3802307429008644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 2, {
              Complex[9.322959909980197, -1.311000027587925], 
              Complex[7.604277546409373, -2.3802307429008644`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623066695834459, -0.07221234146453219}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 1, {
              Complex[9.309320615563188, 1.3047908452057133`], 
              Complex[7.623066695834459, 0.027787658535467812`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604154661093246, -2.482194632873831}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591774001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.313268114322925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873831`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 2, {
              Complex[9.322931591774001, -1.313268114322925], 
              Complex[7.604154661093246, -2.382194632873831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623065143179328, -0.07022608192854168}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145831`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 1, {
              Complex[9.309319867715043, 1.3070459263165173`], 
              Complex[7.623065143179328, 0.02977391807145831]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.604032089130615, -2.4841484932853484`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 2, {
              Complex[9.32290345723042, -1.3155254234009868`], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623063492250482, -0.06824972372303428}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250482`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 1, {
              Complex[9.309319074608206, 1.3092903447657454`], 
              Complex[7.623063492250482, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.603909827464783, -2.486092421856075}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 2, {
              Complex[9.322875504189797, -1.3177720585893213`], 
              Complex[7.603909827464783, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62306174458069, -0.0662831707322212}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3115242027175686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306174458069`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0337168292677788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 1, {
              Complex[9.309318237212286, 1.3115242027175686`], 
              Complex[7.62306174458069, 0.0337168292677788]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.603787873086824, -2.488026514879854}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.320008122147406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 2, {
              Complex[9.322847730529492, -1.320008122147406], 
              Complex[7.603787873086824, -2.388026514879854]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623059901672728, -0.06432632823745192}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474935`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672728`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 1, {
              Complex[9.309317356474935, 1.3137476008589233`], 
              Complex[7.623059901672728, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6036662230346, -2.4899508672515016`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32282013416307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6036662230346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 2, {
              Complex[9.32282013416307, -1.32223371485628], 
              Complex[7.6036662230346, -2.3899508672515015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623057965000035, -0.062379102890164906`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 1, {
              Complex[9.309316433322346, 1.3159606384280351`], 
              Complex[7.623057965000035, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.603544874391759, -2.4918655724939387`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623055936007519, -0.06044140268540179}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459821`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 1, {
              Complex[9.309315468659921, 1.3181634132423616`], 
              Complex[7.623055936007519, 0.03955859731459821]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6034238242867636`, -2.493770722784651}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62305381611219, -0.05851313693602808}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314463372752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 1, {
              Complex[9.309314463372752, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.603303069891951, -2.495666408981521}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 2, {
              Complex[9.322738388488887, -1.3288486541172815`], 
              Complex[7.603303069891951, -2.395666408981521]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.62305160670384, -0.05659421624754812}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309313418326166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 1, {
              Complex[9.309313418326166, 1.3225385589351388`], 
              Complex[7.62305160670384, 0.04340578375245188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.6031826084226255`, -2.497552720648037}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6031826084226255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.397552720648037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 2, {
              Complex[9.322711481129712, -1.3310333426575822`], 
              Complex[7.6031826084226255`, -2.397552720648037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6230493091457, -0.054684552493525634`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.045315447506474364`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.603062437136174, -2.4994297460778836`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33320804305447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603062437136174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3994297460778835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 2, {
              Complex[9.322684741147608, -1.33320804305447], 
              Complex[7.603062437136174, -2.3994297460778835`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623046924775061, -0.05278405879158897}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775061`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 1, {
              Complex[9.309311212320322, 1.326873793079005], 
              Complex[7.623046924775061, 0.04721594120841103]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.602942553331129, -2.5012975723190065`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 2, {
              Complex[9.322658166657, -1.3353728477954119`], 
              Complex[7.602942553331129, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.623044454903902, -0.05089264948000332}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997452`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.329026673522427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 1, {
              Complex[9.309310052997452, 1.329026673522427], 
              Complex[7.623044454903902, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{7.602822954346457, -2.503156285196984}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480757078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.403156285196984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 2, {
              Complex[9.322631755803354, -1.3375278480757078`], 
              Complex[7.602822954346457, -2.403156285196984]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]\[Tau])\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]\[Tau])\"", TraditionalForm]},
      ImageSize->900,
      Method->{"AxesInFront" -> False},
      ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztfQmUVMW5/2f3rDAgqFExRnGNyUuMmsT3jonHSCTJe/+s5h/zQnDh5J88
RUQ2hVm7Z3pWZtiGZQaQTZAdgdnZVxUhCMgmw7DDzBA2gYHZ6O5/Vd2qunXv
rbr3ds+ceM4LYvd0f7fut/6+76tbd+lfDRjx+l/fGjDijb8M6P3zYQOGvP7G
X4b3/tnbwxDJewuANxvglqG9AX8OA7C3MPpfeMvDb3ibknqAfPZCuK0R1pbM
hj1XgnAbocWg9yBc2TsPpm06B+103xJh3/3CuEufTITCmkY87nbGsv0srBlb
Atu/DIJl34/ZoOYjUJKSAxvP3wAPoXWDcPASbMt/BwKYX6gZjq+fCXlpyZA8
MhUK5m6FxrYQGRlub4TynALYfCFItAhDd7Tvl7BjdhYk+/Nh3OwNcOxYDUwK
BCAnZwIs2/0l3NDMgFDzcViWNwKSi7fDpWDYI5hy8aNCyKtq5CZPcas2Uqcy
4INFp1qh5fhCyEibDZ9daodQ+3n4bFYG5K8lboT2f6yG3EAZNLSFqdrdIHhx
C+SmlcLBa0G4VrsYMpN9sATxCV75HOb4xyITb5CRwUvboMA3B060sH290N5Y
Djl5a+HcjTAoFL7NoDCxK3QDmk5shnHJebD1Ygs0rMyCrBX10Mb803oezp5v
gRD63Fw3CdIK90JTKCzqm5+1CE634TCcgzW5AVhR34a2tkNjRQAC5cR/EG49
CfP9BfDJpSDXN3R1DxSmlcCRZid9RwyEwcNHwIgR6DVsMLzx+hAoqDkFLSEk
pNwPQ1PzoLCoCIrQq7AgE/zFH8FF5ITrteMgZcwXcC3M9Q23noKFWaPho4sI
i+EWODE3C8btvkLNK4H0MfuwecgtV+HzcT6YdqSZ6xtu2g9FKROg9nok/g2H
oOXMFpjom4T8ewNaT62AvLGr4eiVGwgQl6GuKhfSp9fCdSS07fRiyMrfDBeC
YQ5j5Mezq/Iht+wMCkkImk9sgrV7LhP4thybARmFu+EK1hePq8qBnKqz2N9e
BolzayE3aymcaVOqrEq9i7A1ZyQU7W9CvmiBM1vnwuh0lHopfiicXgUHrwY1
85rrYEagBOE1BLEsrtfrYHFuMWy5wPh11/JpawFkLUV2hK5B7ZzR4E95C94c
kgaZuSWw5Xw7d9fVzyeAf0YdNCvzLkHq5vZ/fALF76bC/JOt8TyNW+HksgKY
tvcqDjGvSKErsGtyHiw92aKqSAlW5A0fBsNHZsKUioPQFAwnUF44M+dOXI2K
URgY/7b6Khg/Zw9cCYat/HmlRS5prq+DhuYQrbReYkZz/WE400xLZalj4f5f
Sn2Je6QVTi1MgYGvD0TfBg7E78NG74Avg1p9eou8x6G+dQ62LZgAOf50SEvz
Q9H8j6CxNTSUsmmum4xK1x6SK2+zXYJNUFtdCjmopaSkZUHx8j1wqT08mG0O
tcG5HQtgjD8NUlPTIX/WejjeHBrMoRWCa4emQGr+J7hxDOVMr8CByhIIpKVA
SmoGFKDec6I5NEi0Stu5aX8pZIz7CC7coDsnEEhc2jYGUsZt1ppb+0X4bEYa
qqINuCAPkRgzWNj1ymcTISWvCupIbUH+KE2HMZvO42KhuSmeFIR81Dd2X7qh
qbrIBxnzj0NLmLFC+XtlF4xNnwxfoJweIrLfNRlSEftjCLB4330LMyB93jGc
p29q5v2R/Ikleu+Y7Ye0iZWw73wbqa5vc05tcHbdAlh+qInQMfXaoXGQXLAL
GzSID7sGB4uTUcahopOcDKNGvAmvvzkcUgpWQH0btUfT69rRPbC3oYVzazn2
HqTnoRYQFLjhmUkepE09itXVhh2fDek563C75DFFdWHPJD9MPUB001VGGFzg
g4BWXOnes9De6+H8DWb8fzPj0Uzl1McLoCg5HUrWHodmFKVhVACZAsxOA9/i
U9AapurhYnUDLmydArkf7MelxRDg4Szoh0sgJYc0Bxgk+LKhLAMGj5wJ28+i
WUL7JdgzHyXAnDosVoRqc91cCBTvhMtBwSwEwgOzwZ+7Eg6heh5qvwCfzfVB
7vJTGA/UrH6USfDaYagoSoGidWT28jazFjWec2uL4J2Br8OQgio41RICnkEI
JLtn58D07ZegSTfpbWp1y+llMKW0Eg5eaoMbTcdgTdEoyF2luVj3DOpr1QFI
nbwC5k4IQHqKD0bPXAtH0PyIpQPuVR9NyIUPUTUfwpO3BU6u8MNbAwfD8LcG
wtAxm+F8e9iQhtQDB+fB9BVncDgItflIKaRpOf2WMKzt3CE4eKoZgmRO1Ahb
kSvG/f0y/j6YuiJ0rRaW5BdD9SfjIdVUa9obKyFrZD6MzUmH5NRsKF62E861
hUQJTfvQbmN30XaOpLRdgctN7RiIzNK2+moYM2EDnGtnnOOhraEMAhnvwx6U
Zzeaz8BHxWkw9uNLRFFDWqKhZ5aBL3Um7LyIuOLkX4ihcoRkxGA65tqhEmT+
WjjTGkJ21sMWFJS8rRcJu8E85mhOc6oK8t8dhGIuGoqCce0gFPunk0ndUMoz
dHUvTEvLhfKj1yHYdh52Tk+DXDoJHsIx2gqnK4tgwnoCAKYOnhL50ufBPjR/
DraehW2TUiB3IylpRuvi6DRlNhT6UOVNToXsaaug7lqQV3tUk/6+eCxkjBoJ
I99JgTxUmM+0hHT5CMeb0HzRiFFyaOEbBG+gxjOQvIZB4c7LpNbw1oPT6+R6
mFGQAckjRkLW9HVwuoXG1qtBuCYAQ9DuHtrBBqJsGZiyAE61hoVsuYZmg1Mh
MArPN1Igf84mqG9hneOf232f1Ah/+9vf9LeX8BvdhEzAX+hOcKuEdkcHaF/7
iva9qctNXfALH6+Eb7mJ95u6/GvochPvN3X5V9LFCe+PSmhDJbRhnTxORhtk
1tWrzcjCdAB5+w1+i1EbZBr+ooP9N4fj4d+gw61LUF20JagrB6BwhA8qG9tV
a0kx0Ui0LA9pq7ldyBHOhbPnoKnddq3HG5nQO7iZIbiypxjSRoxA3/CKZyIk
F60nB5ucjWRhRxPnuBQToVb3kwHy1ZR4ykpcErFnX8ZsbGuD8LSnIDz9aXhP
kPYAdbxpkUNbvbZfqSCCY405uYLFseQJCPtBe017qoQPZaF2XILQNFCuH9jj
q4ypkddVVyO/+3TB8PuohXZLAx7mPOHQPt6d4KwkXXBAIjhOddTupXrZHX+7
CTnSISAYn23Qwb4ecAbZPXQGObdHwSBHYOCPjZQByoEZP9EZ+NBrXl+YFjmX
dlSmsmJ0LqNvj4BLucyY3NtdMbifASgYRPvnQLigQNswocNMcXwD5Jw3eeXk
kG3jqMlBJLDVd5vOe/Q97kzmzJ9/Xmfet6+B+YbMDXB1RJI9c71Z38cLWsjI
9rXXwMB3/APjoXlUgs4373YglcOpv3MJVVU6d/wiHhIk5CTlQNOIrpG7hUvo
398oobraKCHQNQCX3haCOu7hCCX06yc6XvOaKCErKcvo/UKXNnyDScBgfOIJ
axzGCzYYvBSxBBGZ+JWdbZRQ1LvI4KXrvq9HKEH00pNPajaJEtb61hokfDni
a+4k3Cui9ac/tXppgpBil4bqEi4OdVlVNAlxFrTWIglr1qwx1IdLw/Ucvjjc
XX3Q+McbsHr5oYdQN9P+q6mpEX3VESExhkBsfughTYYXXsPeEsePZbKG3SZ6
zKZsfF0RiE0PPgiOYv4xuBcXc/Xd7q6qCBdoisvEXr2cBMbC/j8/aexUW3Jg
qhtHcqlCtBruuYdIZFKzcf7IpC59eoBRKprhRSDVGD7kWCbwSZRSGN98PCs+
+XflwaUhPXSBpS4F3iMWHyGaMzgwJc5lUgvuKoDG1+/STS2JVKqpIP1CcK5S
6pgHxkDjQEGqC1uTKI2AFufZmjUa066SwnUEIfkWQZMqDDyZJmMfGBux/Uks
wqRDUdNrasjGREUwFqOuwJTpi3pPKBTSlRkvKhOVW5AyFRVqZUwxGmiX5+M7
7Bkao/Jyku8e8s2rx4wJipXE7ejDD9vHrSOu6mETtxixJL78Mt++6HvfU8dt
gqDMsdd668rM6eteGUncuDKmclnQp486bkpl3pcoQ3TRVIgzRIvgVosU4eqR
1NDQCy/AE4JflKpMfnyyRZUpDv3idpsgsfggN7BNe556CjFQgIXpsc63zqDH
P0Y94Rif25lzxPhgnTTnBBUhykezcCVeiulOuP6f+MtDXJ+Trz/mUp8YY7Cq
qjxEKs0uOrSN6eb36zF75RV4AdUjZcwmUv6nBj3C9Tr15rec1LrT3k1tTGuf
j28+9OqrLGKW7tshLVw557qiQK8TcusFBHBDj55E+Z8e9ChX67SzWqwcYhDg
qSGaguIVNzuHcfVMJXuU0D8ssZsUnddY66hG4tl/SM1E9868IlYQISvPo0nO
LTaTrA75MwYqkO8EhZOYz0SX4iUB5O6rijydi+qZMtyTqZz6oY9x9eqHfieS
cJcjx1WR7hci3Y+FH49gV3lyB6NYc+9SvfGILxV5/LKgu8W1TPfavzyt17uh
97ltRyYsdGGqCq6VAeGCWJ6F9olyHZTJPpnuVPmzgZYJfqlNx7IAoIvZochh
XEs9t3QtJWBgWmIHSLWc+fwMOPvGnYYFs8kOzYx1WBERGGkUDV0cMk3Awj8k
WAgj5/pRYWVYeAVhw9BvptCdZj0/Cz5/8bu6k5e/ZnWwot+YAMFneDJACPo2
iJVBAEQIYf3ll19WwldUec+Lj0ehcpwBHVh9g7eNKImRYPmMAiXbs7LUKBH1
Nkx55vZ17WoRJVUYBpqsGkG3RDukC+7nNpjgIpYOy/SkpANwudPe911dlryT
NrDp06ePsgOKqkcKmzvdu9+2HObl8XHHXUDIMltVun+Fsw29Ioe+V+L+Y0zv
zExllXkVfTfAprQDvu9l7/scpBvrmgboZ2Qw7S021IkQEuwIIdZ2lafUpfsj
OoMbboeLOxfA2Cw/+P05MKniEL4WW3aG7V5KEyMog6Bl8iBWMcENtTIIoiyq
qqxUVzHmg6X9lsKG536i+2BTQOIDF+eUQ3DjwhYoTJsE2y7dgFDbGViVmwal
+8il8LJzbcwNDBB+UuCsaLAt5kImHlQUFOwqxFsJ6qnUExt8GwygvjL59wZP
dN6J7hBc3jkaUicdhGvkYu0gXNySC6ml5HypzFX3mVwVIDVVj6zxiMM5+Q8w
V5mKllPiMFcdKj9kSJyT7/QxuOp+hkjJ2XcPdwO+xS8L/ItP87sFr9eOh+T8
HfguA/28+H0UgWK6IM0ce6ZN4dirggrCBsoaZdIw+3EcPnv1t9z+A0P6wySu
MLseoJv5egDKDNldKbP773A5JD8t3VtSO9HfjmTLHgUE8CTaLlumU1X2D36J
m79/yJ+tJaMnOFybQFXRkiGleL9242T4BpzflAOpU7WLB2TeeMgmG5xcoaEh
RkPD6tXseGEX84apG4bQDN4uIZg36gY+w71R9+azojfcXyIRD8GLW6EwZRxs
OtsGwetHYUVWCpTub1JervCITSdReoLmRawEFDsUDRWDAmFOmRfMDSeGP8vd
cOKdPlY3OFywEUey4/zOxTDWlwwjk7NgUvkBfBukrI0+YoKBnyDdYTZBYRAr
KQrbZRmB12bQfnYZ8R7PiD+qMkI2H/qmjfrWmiYcOaKujmLIczo3lx/0fkJh
JOuAWAxCsno1gZvx1h/FuuZkxrdsunieAC3L+QIxCsK4rSwK4qKwCwhGGYV/
o+JCWpB5FlEAdZckjmwKtln0PJr5i/ihNUQ9q54Rnee/4zL5+WkjBYAGDOBm
bLRJATvnMwsafH3189KZP3RrgVMGd7PraUIU1tngH2/JRCVNGYWZoPX2A2/r
jY0s/tTVaNfP2BjyuI0hYhIYDDHDSUjkNcwQSRJgGaIhlmAwQ5b1W6KvT9C1
NidDnpAYokU9hkRkNWqZdLJpgFVZmbb+4PfHSmBVbZMdFFrcHNzMDXGZRc1Z
71tvPFDZnG01h1jzlGBEBvIykG7nUJLMXVGAVQV5T9DGkYtwjOrT0irmniEg
zIJl/ZdZLCCzRptlxe9LAhIrCHJIclk0ylTgok0HR0OZ6dyWftiW5+2jYbLl
h1RHZksl0jEDFyJVxlvAxXMFRwFHEg1fwczBVssjo0762QK4Pni0n27O4WpH
c/7DZdLLekisJOmXilkinhOiMcCxUMaFGYIPYuc9/OeIDHlGmfTaNAEbgwPT
XR6UOAnGFoo205Qxn0zAopRZP0eVMy6K2I8l+S8DmSEw2J5+/SBOgrD5LP/N
CSOgDBmgLMjcln7W/Hey5Vmb/M9F4GFH/obY6Pkvi837YjmTVGMsCoWdIUCc
ixrMcVWQTeY8J5SAMuRybI4fNw1V2qj7ixCgWQ4FmmYPs8gCtveF5InUoj42
YBPN6WEHNiE671FdZNWZXaGBgcD+48bgbfPogI3+jRFX55/Kq7OsEPR0H5pS
0WyMJLTNw0qgEB6aQ+pZzVxqGl56Eit1/cKZjqb9zCZGVrtkMYrRYqQvGGin
tRONYcJHzHjmLNiE2SszidmEB279ayq3aV+gSDG1+bmkHMQp0WaJULwEcOwy
K0s5QNqyo3LxzKAAOiJrPhV1zP8aN+BY4K9OE5v/lFcCWVhuk4QlnoUFN1Ac
Aw1vRVRhRSVgt8NgoVnIVpk9C5g9Pv2q0GNZf3XC2C+FyGB7+iElZYW6p+hu
Fhl8jgnhUhaeApt64KXb8IxNWg8WUls+9+VwW/ZmFTrZ8msblA1AurEGGkFg
spV1wGuoA+wBevgIh/2XQ2/LWES37fHlRWLNbyWRYdaI04HbxMiwFrpypWAV
jQwtbX4yPt6KNaEMsAixgzb2XzW744HZdMyvo60x8F9ONr0oL9axkiDdIQlS
gqRSp5ojhALI186FyiXmEM5SWQ4tombvFSLFjqWnOJj2B/eF4Q7HiFnq9khm
pZBOMhyywJkrH7/sfzEd8MXKg7Dx+eciMvG/Jf1IFrqvmWsFvrQOv5BLZIgc
LiJSLOUCImNclEBm26HKQ+hgor/hYMLJtj/Jw6eZF0PCh8shDeGdSnDG6hUE
/6UWDpKAVBY+0UoVSJcIkyXDsZ+LCPaX1JR4SbW3RFCo9olyhP5NYqLs2hV2
5bASoUvpANkhoZN9r8ijyEwUQWq4IJOBtF+/LqJ1egRfs7POAlP9esps0i80
6Zb5+xLBUsO0Fx0sOlk6wGSpD6mPohknCeZd4uRCLDeaxTyeuKjqFvdzaXEs
TV4zZHHbwA2eN/VlKtzK4kqM/X/ybiG2dFZSezkCVp6Yv3dpZbwTapezulr2
haX2kEuGbeaU/2OTlWLfuMdcdcg1L/jda7iMKt7G4F+6NDjBRb1lNuN6G2kl
ekMeWzFTmdn8bjNjpnYlWscZrdQtfSEiQ/WMzSWlWZGxzOJNmZsi7jCDhDkV
y1j80mepljbzdfvMTWIeEDNXr8jPiDmBSWyTwhPsbKuIcdnVCha8Rxr7IYLL
Gd4TqAdw4IXV+nvtPdCNmJGg9yIR7bonHrfxRJzEE12FmiaC31LTVlLGtVW1
EeNhmA0eEiQNi11PYnKFV1IANGAkqt2iH+DQqx4Srb4x/0X7Jyh95TJ/2E35
tRW1xtWQRbMc/fWuvOPFU+BguRi5NHUeFIEjzkG1pnAbseQ+/UhC9Irbz8w7
bmnsb3Z2EqvQ2JE4jlhD6lDxGn3WUJVLMWUCiHZn6EcteHnJyaHJJgBi4OGT
shnkkB6IgqwOCykJD6p6LcpL3o5o78Vmfs/G2B4008x91ZJplTT6p+dP5Uae
nzHCycZ0SanpIukx33S0KYZ/p4tS97Pag49Y8C7MNKOJt5nyw3ZGWMX6i7gQ
So/OJjuY6hPCyTrqSqQuNjlRniTfJbs8ILU6os/MbLc0q5voLFVeRyxoqLHp
Pk5+CggzG7HuUugn2CD/FYmOsmtfDDrKeoOTjvnyWtfFRrc/2uhm8d9qNnMr
t87cLLoR1Qpt0NXVRq3fRqLWWsFlfgTo9SgFzs8YTvBR7DCJHmcfVjsd/zMS
HdcLrjOE1QX0JkWv408E/2Ma22ar60bBn5GmyVQ3usbx+RquKsLM9WkbdeNU
6m4WXMvDP1MLv5O6M+3VTSIyEwwTbInajwkTP1FtUf0ElfpbVQnvwttz7dW/
lchMkqov+0xRoy3jJBjMMQ9D7FhZwRbhvMYKGCz7OJJyYbJsoWKWsZJ0Vh+Z
LYhXsN1G3u80tConU93SEM9uTrZuN9Wg+Y/+CdWgocjW1Y62LreJIrJXZu43
yXu8QR+pXp9ReXjq7Ef/MMI8JApeEgemQ7GgY29C6QbByzugIH06HGum/anJ
8RF+fCVLtE87t5mkss8QW2E2eRdNPmajuFmwk8jYJ9RitlLkzszuVjOjf3Cg
Vop6WdqdzEKzOTITbczWwltnU/smCbay53pa7+bwGu7mYE+vE32i38nRgUcW
Kqc1KDiTLEExKsDWWixPMDQ9SJBNg82HiVjGeD5eLiOGlnDHhxc6Wohvg93o
3wD7AwUQqq20hOI+Og7DrPHQXtj9yTLwpYhaRPkAQ6bA4erDJNUxHvARcvjI
GrkCOIXXzIcpOcPhzXdFBbwRPL2whm7VEKguMBMkQQ41H4EP8mcaAhD9MwyZ
JloJ9itrgKiJ/WP8amg4WPEkHl0wDc3FycHHxIgZ4bzFBx+bA5uhbtVhTa0j
a9wzWkW3shirvD0+Yo7MRpXXIuWoGYtRcbiyFkJflDGvFUesGmZUV1MHR9Yc
ceyl5r0ThHTwEy5kM66fmu8tdnmNRYVZo2NAYHO4Wuaq0fidHnPwx4E2H4X3
AqmQmpqKUg+/eyE18B4cpU3nYdcu5fhZTZWorZApMUawiysRbIbGk8fh+PHj
SAn87oXjJxuhOehGidUqh2JnHipn8R0nCI6RCPZGKTjGHIKJFkHovfUMrCjx
weA3h4Evv9BDfuXOC0UTF8HJlkhkcfBWHcaf2a+1CcCBQpn8Gxfh4+nT4JOz
5C7Ib9nK2sJ2Qof2Qq8aLXNg82GYHJiL6nEIvm3LdI0kaWJp5BBUDE3RlAq5
MoOCX8L2aSPhreE+yC0o8EBBQQHiXjBhgUuHrqGMTKhhnc4EHru0CsjUC7XC
mTVToPTDrbD/2EkPnDx5Eu128vRZaHGFLaaeCVvabUhJTh4zf0+Xhu4IvFew
jPyqoJvQWbCX6MZV3TUVjEgyqir/PFyaRadgQUYalK7cAn/ftcsDu3btQlrv
+vwwXL3hxqs7yfdYq/vQd03fWKu+m7PptnvJZ3Hhy6I3OqqytYttl42zbusn
8wGa7TbVbYLlH8yB2bNmeWDWrFnI3lkfVENDqxsfrJckouEeDBpKD7sCQAwt
q+mIvClLd8WmLE4WPbQ5O0ZOjmNpJJC1oS+QywVs/aL629n7OMXVKdZuP9un
rlcMDR3Sw2FusF5e27THnnQxJix+DJPs86FyXuuESCuiHycZKotxF5e0GAnN
o6RZ4GVLjjWSabYrs7+uhl8NaaInCdOpWFYLg+gY/WQt7N/zGezeVwsnz7fg
H1171EVGWmq9drL4Xnm48AEcm7vKQsi2y8aZt23ya2dltFgmSWLZRUKLkdAi
gIwtOdZIllVoUwXnMTLSbxUyxUvhH7x2ArYtL4Xs5GTwF4yDiVNKYUrxWMj3
jYSRgSmw7KOj+JkhbqqopSf+gJCftY+Z09/O3scJN05YcvnZwy4tEhuGaW7A
w2Ski2FiQ9rOroEZk+dC1Y7jcLk9xC4FJT/jePEIfFoxG4qnr4KzbfqjCCyh
ms52wqtx1eiVh16rtc89IZxLCqtAS5TQYiU0r5L2nIGGKbbfo/1c0wl/8fNG
Qza0NdSREXy/j80tUJBqGmpgTeMaGs+fGWiYYvddtW1142rpGLvtjOZmm+pv
NPu44YU+H7RA30t+NLSVHiawVa5g6xVooz8q+qAK7+l8Si7FW4IEtt0YbQDh
Qf69Qt7xhek6zUPeYw00EvZqti2Ofzdt9zB29KGy+MWuBatuqAZYDOSFPYKp
iOYhhDhCMg/hm2Mh+0C2eRM+fbiYXHwmbEOfNbLXQJbRukhoPch7LwMt50CO
K5g40cyfxVuN2fRcPKJXLi6xH34WY+9R1qlYa11CAMhgkcqSBD7LFNgKU+Ar
LNvtAl9RX2EJPKKJgTcP4ZtjIWt/lnkTD7y4DX1mQRbJMloXCa2HhBYnAYhH
SbPgUCMnEvw4lb5vy+fxo93A4S9spUDS+pRtKTf8OAtZfxrRleSWHB+h0e/4
W6KEFiuheZW0OAONvLTvHvLl2/pmfzi6z2XoVdnBv1XohStxuYJWhdUNEWvK
6aYQfYmbvYbN7GejcKzL68uhqqGKfGZYoDQP+ZJoGCLuEgwH+Wdt7NPke2VD
JZTVl1nGsM+y7YzmZpvqbzT7uOHl3++PkySiR0lT1IBYSzvBuantkkC22cxJ
HqQxk623C7U6101u9qe8pLnJPmfjH7YAMlnub8gPWep1Y7RKCj7E/xB5v4tD
xk24nGimsIBHcKxYrrH/XfVwLy/++HU/bQ6moypCRUXQQ7weK/M7ZAqOjxfW
ylqbLsHFK/ZH4S+xmZYqHrmkCGqF0a8XLE8kxU2LDJHHfolVTGYtgeOlyY23
YO+KUDU3RwGqD1EvyqDKvZhASKIHTR5NFhzK74ppPQt7amZDUdpwGD4yBUYO
HQzpMz/DTwrkDwKzePd34qS0xuLZ7pKO43HhxG8rnRhjcJwCar1toIYcpzkp
jjjDfGKJ+zCJbGL+E32p+PyW4NMYVgRaT8Gi/ByYWrYDjn3ZTk4oh5qPwqLc
EjjcHFa69df8UNrgTnwfCW46fgJoWUtkPQrv/2PKxIQmj+BbVg/ZddJmh2GU
iYkpom5z9ma6LYZ8Fuga+YcG8pacLUrv4dOK4l+7bZGM6ex98OcfycIcbIaz
V9v5FSr4EYtXvqiASXN240frkTDry7j/JS5ciAfouYQXi3CsMcKVQmRfYAtU
xjkGW10xFWTxKX4suOxJ+uw7/suCuSlrE48a+qyRvQayIu5xdKhIltG6KGmP
WTBjFzsnWjSfzb3H9N0rOJMNIY9SijFWU3Lh0pGtUL5gBhTnjITBQ0dD5ZHr
BCLKtP+5PO3j2ZFYJsWBERNk19/Kk117/tuthtjji4XsPm/ybwIf+kfjDzIA
xEhocRJaF5c0xk+MvkdJUxQcBTnWQGZFXyxr5ibAEslEF1cy9TjfgMufr4f1
2/bCkTON0FC3GUpz58GJFps49xUP52nmx+uZb5zqkff/K8/4fyfkHziGt7ay
llzDwf7abYtkTGfvQ6HnVZYceRmSViwFOdZAZk1N1eRENJjoIhrYA1CDVz+H
mQUL4WSrTfSft6n/sWxBhqW6ual/RHa+j0fczvNOtCg+a30j3jBJME8amL9M
dNFfvHG2X4DtWz6BXfu+gIN7t8PGsjlQlJ4DH+y+jCf1Shc+J0mgOFUC/YSX
bPyMqjDk5uJjqlyyeJaHKuzq1Rq9p4SWKKHFSmheJe05Aw1T7L5H+xn/pldH
/+IfKcM+UtHoj5hF9F0/aYBoDQ1ostlI8fE7A007IFd/V21bjb7LxthtZzQ3
21R/o9mnI7xUNvFHHAuT+fctiRZPnpa/rWweTJ8yESaVzIRFlR9D7UVtxqo8
dH5WlWWYlqkXpu/ywy0pqGMkuZFgomVnh2EwAGGNP2s3B4fJbXU440QaxlZ1
NdsWx7+btnsouxrpmYkGNENaTF7YlZiKaB5CiCMk8xC+GZ+ZOGDehByNv8UY
tqHPGtlrIMtoXSS0HhJanISmqdWTqBFpTpjzjD1qxHQIMUeAlHLl60cSuMTY
9LOH7GGjlc8YA2wGDAjn0LBmZVlRItJw2CsqjCjB303b7VBSUV9vQQmiiSgx
D+Gb8WmM/eZNHCXiNvSZIUIky2hdJLQeElqchOZRIkcB2q6WNGAAkwHnVvnx
xxxZLWqth6qlO+DSDebyELQ1XSEX5ipr0TMiuOhpSq+kFmnL710Njcyu8eK/
D1MM9O8fBp9PeyWRdy+BzMqVGq2nhJYoocVKaF4lLc5Awy/63UO+fJtv9vvD
UX0uQzlXWdmxv1XIvcEgfqKsnFaFT4aEyLkS+pV8wy/DZq9hs36uBA1D6VGF
wMTWUASah3xJNAwRdwkKn7Wxfcj3SvS9TDKGfZZtZzQ321R/o9mnI7xUNqHv
tgUn1lLCcCHQikKCtAkKGd9VfkRqTXg0y79+CMb7S2BF2WKYPbkQMkcOhaHD
0SunEhrb1LP8Z1jBEC87wP+EfL+bQSiknhyjycNdJMVjeIrTHJFlagJ5j+Gp
Q8HaRAR148CLBFweeidRuR4YsOsifK4RY/b6UoV7x6UUwNyKDbB93zE4e6UN
Qm1nYdXspXCqRe3e/xBLao1WVvlZ/YB+/HSH0KfFkkrLZ0/afHG5MVUwpKJW
D8WShMtHiB3Ost//EtNZ81aMId2FvirDZSJno0+DZ1lc5SWuKi6ogbPtNtfF
Py2Zx3gkraanxC/sL4JcNzrxCARsqrtXdwcT/yRdHjAXxQoOGi+fjbA1KMmU
babM/GALnL/YTDCqNP8Hymmc8WIP9vRo0XxkNr5DGxnnJ+coZK2IFX/hQD7G
bKxHgAWbYbCL5E0zDNFO0/XS3BKhfsgCyX7y1hxIPDdIpOhmUbQg+Ffc/QZI
euXlkVy0aLpNq+3CTvj8tBaVOO78FqjfuxMu2F0B+X0Wf6yLeAWPYFtXeZQS
BHCa+3yItuDfcYcbqhN/bqCQa2IQNLOSIHjtCGyYXQj5kxfAqk/2wfGzX8K1
thvQ1nwVLpz+AnasWwJTi8bC+xuOwrVgWGnlk9wlknQUyhR7JhizNJcsqmrR
y8y0mCieHbbgL4YH1ZBTMwQztQDjwhOEphM7oOqDEijIeBeGvjUQBg15F9IL
SmB+zU44dS2oXgrktskQKuRagsS2ONrSWAjF0L0i1BBxxq6faDaeMJ3u5vju
CRdwkyka4xSEAdRG62zDkDsz3CjJfifGCS3xSkW9RFGDgn+lCsoOCIU0iExB
h5DHRqLg/7BWFLZOpBXnyKe5Ufa7LkIeJyjKlmm8KkUHy4v4e4Iyrp4EIf8p
UN7oFIbEGqeSAasBzNMOBsTxzFrVWA+Z+zPJJX8IClZD7J71EPEPepL37zBb
zEGpsUcNLhSGmcbbdLCedynS6iBCpXMe6hDxz3MaDZcEkRkuLgR6VEEcSgfr
+TzK0XDZAxx0g5x/aFNm0L/ZRFJ/PK8WyexsG4OGm/K/sqEeVtaXQeBAAF+Y
bEWljR3qH840Pf+CrT07lVr204tigcAvixWj5F23hIu1f5CFGV6KH7xURoPd
OO1UmdlvhIhQYyuKgh367DX7wDwpvKYKYXF+QEbkv10pWEUvYbWWbz7TlsDM
UjBGUl56wVgIL3/6Dit+4ixC/biNOIjgFygFE2I0ldm/ahpIF7hKtqS7vM6J
8VC2xMdscpbdx6REBvsFAJan/v1zo9dEy78uhiVRsSTirUJYlVFNpVpjpaoa
zsCrn77LIupuYsifSGlep6nRf8tAdIkQILJ/OnMbgVWK4dJHVwpoq8aJ1piY
PIHPD8gW/A1aaCgZFa0W8vYkqxk8EHibjw7AB4H9Py3l0nEtdCX9ERtcMunM
BxZc+g0R0G3PO5AXifQEY4qavG+HQZ8hRReh1x+kiVFqVkY/2n+EVYlMQYWc
sGO1zhRyEi/Y9f90ilQ0eQqMzVMdyfvDzA+hsFGRane5mGkIRLIBBq5m7A/R
oqgqCvqJU8k0ImCTApFJl1QCvAUv/isTkEmXpUBk0sutdmMbsbeZdOwHqXRz
Cri2/UHR8wFj6PEW7ZIQB9vLieejiPuDNp43lz4L6rKp9KqO2R4n9bxwKt4i
OMcAuCjMfsDG6Y4Vn0nHgHt+4yAuHTe/CKTHWZweqrbP8lwD1kZGa3asxd/V
VTYYy+0cZ8dqJ/IFR4tZbbE1j/Ue9N5v22TByQusUvVqzi7hJ4F9WXBtNslj
ZRqzxxH70MxKvxNofomb4t2b2WcK546AjVeZwP5oHswEvvppsiuHcoFCGENI
WFamjUMLqMB+20YIAke5Eng/E2hKl+0BG4GjuUvncIGBA/MjEyjOC9C/eS/r
Aulvj1kF+vfP4wIHbE+JTKDQfEOvojmn36b2j6Y7+QXQsPrnaip+P9WYXN6i
+1Tp0kIucB8S9GND5YlMoJCK8/qHlS5lAstI7hsrjiuB+oG3MR/X/dTGr0xq
lWQ2E4HUBAt8fgGGKTQZO4YK01roS5H7VBMWr11aT//tfiIMt1BhxKl4zFgq
qZKY9QehzmRbJekljf8qhsD/YH91KSuiYjLJuXujmClu6hkXKKBy/ivOAjWQ
ONglE/gNRXnB4VJ24SKDN6OAJruKxAySn9O4vfqqDhIWOj/xaRSI/IYDSKqr
6cBxBklRwJFL8umSUkFy6MgklUcbtnuZJMyxv1UaBz77IVPsTHHChNpPhJIU
+ZydTQdOoNAVpfTd+HZkQoQQ7RJC1IlCjMm8ro86t8bR8aauHZlBZVaPGZCg
G/R7waA/RiAkztBRmBAEADKmmPJ/fNUvOf+nVv/WpuZxroKbUvQ4GLg+v/FN
zvWFjYNdlbivO0CXx1oXEnmsuRAFannOd4oQwVOzQUOtIcgdFxInrSnICjJm
IuX/vdW/tg1ypPwZiBh/JxBFyp/BaSL3jwFOrvjfI8KpjzEQhki7cJLWffF1
sfJzldE+2d6oqAmS2Bm034Fbb2uK9lCfi4z+2fSCrsYasAa0cyssaJOcg8Z/
Zddy5vEOw5lHh7OLdEx0j5Xnptjgj5liAw0+Y7E/b8hOTFueQd9R1WzAYFBN
fSqQndNzfHS9frrw7oh89yuu4JOrfzOZcxIVtD3Lx847RPpUezs3sgrpwo3s
WMLulB1/Qrab596r9BInt0yvByt/wfV6uPL/WPVSnoJjp9SieiC+pmKsRUXe
gydT/XpX/lyln0NljjU0+dky5ibouGLei3kF4+h5iwAD/wcq/11Q/pnI+Esm
EFb+kTuH85fMHaz8leBw5m+TFJ3iH1NwRXAz/neXfZ/zv6fs6Qj4I/D0U4Bn
iktk6hNbzlIFdsbSlIyuZrWumd/VEWdInG1g3pmetjDvkOZObumQ5qoCw5j3
XPEkZ3778u9HxDzkBMCeKx4RmH/TFXPeWNH04Pz3jK5h2anzfzh6/uJZZfQv
5Sk9O3X+T0TsnLuZ5/+s816NXq8xzJR0ADOcuSqsJR32vE1dYcyTPnyQM+++
7BGbusJZSvq8SV+Dp13VFc7c78A86cOHbPW1ZS6czPhFNM6wZY469Ad/CuPf
QWTdrePMe9F98c1B7PIA5BID38Rld3O+XZZ+PSK+/fqp+XbEGfggT9S5Uz2N
LwwQr5ewMI9bqnskfsk9ETHHt76IzPlxdWcwF13St69wLNyRWN5tE8vSTuAr
eoRN2UpdOsNcPeRIVnCLoHDEQEZG9Fra8cW3kWLe+HR9MGjkG7OkJ+cbu/h2
V3zJW0XnMbhLYNDrK9DAuySJM4hZ3D0aBj0FBrd9BQw8ggnexd06n4GeBXa7
uYJ75yp+y5KunIHnK2KQKDBIjIZBAmdwSzQMPEt6CE6MAj4Jy54VamufqBda
I71xxKBEzxXLkAI/Qq9n0ZxraXSLqNHd9GHQ466yMmD3Id1TVmZdv8O3prpZ
BbUf04nK2K5zUub2Y9wp03PFCq7M7cuXK5VRr2zqytiMMS1tkrcyuQrWtUs9
OIq1S0NwVGM67A/3S5RR3nkQmSIOa5LKze4yN+nDD7n47suWRV5/OpVBt2gY
9K6s5AwerqyMnMEK4e7FioaGyBmY7i50z4C8vfjPHW6aDpC33+A3V83/q9D4
nzr8UQltqIQ2rJPHyWiD/hfpequEdkcHaF/7iva9qctNXfCr+02839TlX0gX
C97D2jyCvb2kbTJ1W+0mB3Rs/P8BMGNQ5g==\
\>"]]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classified saddles using lines-based map", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "d2S"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"d2S", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"0", ",", "2"}], "]"}], "[", "S", "]"}], "[", 
      RowBox[{"t", ",", "tt"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       
       RowBox[{"\"\<B\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"\"\<Bad\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Brown"}], ",", 
          RowBox[{"2", "\[Rule]", "Brown"}], ",", 
          RowBox[{"3", "\[Rule]", "Brown"}]}], "\[RightAssociation]"}]}]}], 
      "\[IndentingNewLine]", "\[RightAssociation]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"selectionCache", "=", 
      RowBox[{"ClassifyQuantumOrbits", "[", 
       RowBox[{
       "saddlePoints", ",", "classifierFunction", ",", "sortingFunction"}], 
       RowBox[{"(*", 
        RowBox[{",", 
         RowBox[{"DiscardedLabels", "\[Rule]", 
          RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "*)"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Values", "[", "\[IndentingNewLine]", 
            RowBox[{"MapIndexed", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Function", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"assoc", ",", "key"}], "}"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Graphics", "[", 
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", 
                    RowBox[{"key", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", 
                   RowBox[{"Thickness", "[", "0.003", "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Line", "[", 
                    RowBox[{"Values", "[", "assoc", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"index", ",", 
                    RowBox[{"key", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
               "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"AssociationTranspose", "[", "\[IndentingNewLine]", 
               RowBox[{"Apply", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Function", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "time"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<tt\>\"", "\[Rule]", 
                    RowBox[{"t", "-", "\[Tau]"}]}], ",", 
                    RowBox[{"\"\<t\>\"", "\[Rule]", "t"}], ",", 
                    RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
                    RowBox[{"\[Tau]", "+", " ", 
                    RowBox[{"0.1", " ", "\[ImaginaryI]", " ", 
                    FractionBox["1", 
                    RowBox[{"\[Pi]", " ", "\[Omega]"}]], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"\[Tau]", "-", "t"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}]}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
                  "]"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"selection", "[", "index", "]"}], ",", 
                 RowBox[{"{", "2", "}"}]}], "]"}], "\[IndentingNewLine]", 
               "]"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
            "]"}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"index", ",", 
             RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
         RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "1200", "}"}], ",", 
            RowBox[{"{", "700", "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<Re(\[Omega]\>\"", "<>", "time", "<>", "\"\<)\>\""}], 
            ",", 
            RowBox[{
            "\"\<Im(\[Omega]\>\"", "<>", "time", "<>", "\"\<)\>\""}]}], 
           "}"}]}], "\[IndentingNewLine]", ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<AxesInFront\>\"", "\[Rule]", "False"}], "}"}]}]}], 
        "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"time", ",", 
         RowBox[{"{", 
          RowBox[{"\"\<tt\>\"", ",", "\"\<t\>\"", ",", "\"\<\[Tau]\>\""}], 
          "}"}]}], "}"}]}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV13c81t8XAPB7G7QkkoaGEWWVipR1j7SMQookhUg0jEQiGpS07DIyUkiI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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "1"}], "}"}]],
         Annotation[#, {"Discard", 1}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nlYjk0XAPDSHkqkvBRKEqVIC20jSsqWSkkS2lSWFqKFLBGJVtGibCGU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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "2"}], "}"}]],
         Annotation[#, {"Discard", 2}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{1.7399179755419685`, 1.1829150513430053`}, {
           1.7395019194070571`, 1.1828367302459346`}, {1.7390877971690997`, 
           1.1827591436160152`}, {1.73867482452399, 1.1826821042449285`}, {
           1.7382625096524005`, 1.182605495912646}, {1.737850505133432, 
           1.1825292375518723`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "3"}], "}"}]],
         Annotation[#, {"Discard", 3}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{-1.4016746780478258`, 
           1.1829150513430053`}, {-1.4020907341827356`, 
           1.1828367302459346`}, {-1.4025048564206946`, 
           1.1827591436160152`}, {-1.4029178290658042`, 
           1.1826821042449285`}, {-1.403330143937394, 
           1.182605495912646}, {-1.4037421484563606`, 1.1825292375518723`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "4"}], "}"}]],
         Annotation[#, {"Discard", 4}, "Tooltip"]& ]}, 
       {GrayLevel[0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVVnlcTtv3rlRUrqEkFFeaDEUhldTKTVKEEEWDoRLSiEI3pFRSShJCCiHR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           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "1"}], "}"}]],
         Annotation[#, {"A", 1}, "Tooltip"]& ]}, 
       {RGBColor[0, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nk8VdsXAHApqaS5vMjUazRTkl5smtCgKEKoR6YopPyoaDCkVIhQpCiV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           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "2"}], "}"}]],
         Annotation[#, {"A", 2}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVlnlYTtv7xjcSyUlK0WAoRYkMoYG6dzhNaCRFRVFCKUfI8CsypChpQKeU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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "1"}], "}"}]],
         Annotation[#, {"B", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nk4VevbB3CS6pBMaZJQ6FQylKFBvoYTxdGglKFopKKiwRvNJakQIjJl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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "2"}], "}"}]],
         Annotation[#, {"B", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 
         NCache[
          Rational[2, 3], 0.6666666666666666]], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1Hk4VWsbB2AyNaCUOnSUKCGVZCjCYxZKZB6iiCLRhOKUBkXSgAapCEVF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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "1"}], "}"}]],
         Annotation[#, {"D", 1}, "Tooltip"]& ]}, 
       {RGBColor[0.5, 0, 0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV13k4VVsbAHCSVIaUeUiGBjKrdEneRLm5IppICCkNQomKFA2IkqI0I1Qu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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "2"}], "}"}]],
         Annotation[#, {"D", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwd1XlYjd3XB/BUGhCaKBooUZqkQZGWktMkNGlSPKVUSkRpQBkTlaEnEhol
kfKEigqN0hwhyS9UNCh19i65k951v3+c61yf6wx7r7W+e99LPQJtvXh5eHhG
8cW+HztuHHXbkIH8OVvWBhZzwe1rzAJVYGD4ncvSJ+hUZ5gqMmbA523NFf4n
XNg/Ui5ubcqAWMU/STZoY399zwEOAzprN6imodt0fGZftGBA6HO80wh6Q/zS
dUabGagscVIzecoFm0MlamNbGLjvOPUoEX0zz2nZYxsGrsiP8Q6iq/MWBh6z
ZyBa+rmySQkXRvXqPWwcGRDn6Vt7HX3owhx3DRcGEnYpbhtHS56/UCvpxoCs
38HjdqVcmM7KFRfaxUC8qftAAfr0HpmSmZ4MPJbRypEo40Lspe5N87wZeCJi
2xWK/t4VZKbky0D5YMZ/XegN76Z3mfszkNT2y9ziGRea6uQ2hgUycNE/6/Vj
9EqrnPziIAb296seV3rOhaHA6QjBEAbepM2MS0JvmC5M8A5jYE13uu68F1xY
/axl8t0RBkwfX62IQaccT3jnHMXA7hr500LlXHBZpuczcpKB15yBD+fRk0fi
ZW5EM3A2219VogLr0xGJdz/PwIPuRpqOtpXbE29wgQEvx+xq3UoubKkM1NJM
YODZ6DdOC9pZ6mOH8VUGHvGZGAdVceHimm9bD11noFTtU5ZMNRc2T9k3vUpl
YMxMIbkFrRjcsZJzi4FtJZyzF2q4wLEXYobuMJBaPKjn+pILYz9P19bcZyDu
Vdugbi0XXBlev/cFDKiMnk9TeMWF5lU//ZSLGRDmMXBQquPC1J3p4qoyBvY5
fEzaWM8Fb+fOW08rGVh4Lyz4dAMXHKw1wmTrGLjrOlPpVyMXehenzRNqZeBm
EedobjMXZiXI8aS3M2CpmB9d28qF7VdueS/5wkDDXYP0i21cWM/vLNk4wEDA
d5eEzHYuZBd5xJwYY+DwpfyJc11cGNm2stD4LwN5yjNsWwe4INbQ/xV4J+FM
QU1p/TjWv+6OXj3fJNTJ+Pb+4SFgvO6NuD//JDSq/5uUJ0zATPWz6R004xCy
yFaUQLfls94C9PlLMrpaUgTSQvIaM9AdZgICEXIEmrjWYSfRHI4i39ZlBKKz
z2m7op+c9tOsVCHguFfujjp6pYnN5e8aBPa8CpOcwvXnVz02rNUmEGBq9L0O
7bhx16l9+gRo6lXhJLS0pVDjF0MC+jF5Ul7o8BBbEWVj/D3z9chq9NSnQhXO
JgK9W/WP8KB7dfx0NlgQOHPZf1Mz1hsSv/e6tDUBRkn/Vwq6bcjf8u02Aj90
lmcFsp/P31QVbE+gT+CrizG61NhFb8qRgOHzKDkJ9I8F96MDXAlsFpflfp8x
CTX92btr3QmcNfzTVoqufnXcfJ4HgZcJu6ouo0fcX53a6EVgvaVCqS86QPKU
mbcPgefDckXG6OuVWmmhewl82Xw+fxH6+c+RkxH7CEQ+10ylPJPgtGO0JfAA
gXfF/0Y2o2N6HW22HyIgma5oeQ9t+DGvTPMwgRmzYCIazS878exPGIESH/uT
XjxsPw+MlB0hkM3t69mI7n+66MvBSNx/a8YCRXTq3xmS8icIGF3eKsaHltf1
FXhxisDSqL7W7mnMU3b5csdoAnZ7ErdWo9d7x3T1xGC/VfJOZ6Nnu4ok+MYS
GPUr2XcOHaoncbM3nkBjYsjMfegnJ4PtnC8RqHd9ZWqLrk9NFahOICDX2bBi
DTqjey6vyhUCSadrc2TQHaQo9nQSgZl1q2p40Uc/efd3JBP4+F9WaD/mV9NH
wlHlJgHYMVrags5pXS16IJXA4UMCF4rRKpPcrQXpBOIz/w6koXV+nDAfysT8
8Uk3xqCPBXLUFW4T6LharHUQbXholobNHQLSTR6Sbmi9Wu3Q8LsEGoSeHTJD
597r10vJJfBL9+Lm1WjBB4YJpXkEfIPKrsmiQ00tH719QKDzCcdZmP1/M7fn
/QV4Pm6Znx2bYkByYHb7xCMCejqM4le0k7LdEr4iArty7qk0o+PEHxQLPSHw
1r/6Sil6RGHNC+ESAv/xvPS5i458mmMvUEZAlIdzMwktLXbu8t9nBK6vHNKK
RgdkqCdyXxC4EBGxLARdY9AU8rWCwKBVZZAXOuzdtW1NVQSOReYsckDHepSv
Lawh0FKybNEmdJbPmc3JtQR0cwwDddHB7WY3wusIlBsKSy1Huw/HgWMDAevZ
BWIL0fbbJK1WNWGebgW4CaG19394PbMF6x+PGv/9h4ENJnID71sJkGKjzkE0
OIRl3n5DgO+TgMj/0IZOHfOD3hK4K8SJbkGrSSdsXPuewG6JYItKtKfAzs3T
7Xh/XJSyLUSvN/RbV95B4KDNi9Qc1iuclkR1Erg4JaB1E32swmKW4f8IJGRd
4r+E3hvWLTjWReCN2zzp02jrh7Yr7n0hUPFJPyAMnTjXLsS9m0CGYst0ANrL
Rpt3Xi8BT5m0Zg+0u0TH+9JvBI5sPfLREe2oVsfn00cgJn6DgjXa/P3yy/MH
cD93WjJM0FseFMUXDhJYvERqhz766r4f/C5DBCZ6ha010PZBn6eZYQKakmmH
lqEVFN3PXRshsODhx9ZF6FMKX/N0uQQ+HKjyFEW7OqQcbiYEsoJ9VITQ+TVH
hr3HCMjLdC6dnsTnp7eC7J9xAudrDDaPox/fGp1zYYLA56z07CG08cicl/IM
AZsYA+1etJaYs33eJIFreWrDnejr+yPL1k7h/fvvvfdt6M86I7Oq/xJwbxoc
bkC/ceoxteahEP5xhXY1euT6zoNvZlCwmErJLEMP/bM6xZGPgpVoIhSi2yMm
Gz7wU2jaayuQjxb8pCLoIkCh56Hir2x0s+Ffu3ZBCpxyZ9F0tMLt2Kf2whTm
RFjYJ6NHx8qMm2dR4BZZPU9AW1rYjJjNoZAuX2YTh552/dTwTISCh8jfWdHo
2+2tn7TnUbh9MGgginVyqEr2fApFL47/DEcv7B5/LCVGwbfqinQwejJqS8xZ
cQrNV+R9AtHZQ+454xIU3kTGdfiic92+LfZcQCGxy37/bjTfyxPfGhdSqFw4
pLwTTToL5q6RpvAkuIXPBS3F+/5ayiIKbrJHeBzQS7RWx/HL4PdpoNw29IXO
gSEfWQpXL2q4WaHX1cwur5ej8G7J+lIO2qzp1Gz1JRTq3RXXmbD9fqr6OnYp
BfuIvR/Wo8UnSqUHFSjsF8m4YoA2sun8ZraMwkLe7UG66DmZkkaZShSWxEr5
a6Ejoz8pTi2nUCFx9KQ6OnPy0g0HZVxfTbpYBe07HZ6bq0LB4egp4eXoD5r1
jryqFB6XOB1WQPe4pmVsV6MwdE1rhjyaR4L/Uo46hdynubcXowd1fiyf1KBg
fct3jxQ6JmCdj9UqXO+R8EZJtNeLcqdkLQqHJVcZiKHv8qz/8301hcn84xbz
0BJWztt1dCh8Vsg6OAddGv6fX6QuhReFJkXCaLXkZsNXepgXO34JQXb/29Rb
RPUprAhNjOFH91vpKDsbUJhWy1zIi065bWSeupbC1NTHsmmGATerq9o96zAv
P39GTKFv2YcPrVhPQT/kos0kuspXMszPiIJxwH6j3+guqbMf7gHWO9fU5Bda
QaNH9McGCsODL3aMoY2ENJRUTTD/3TfjCHrnwI4FvhspxC5OaBtFX7Zy7csy
pbD7t7PWCLpWUTDlyyYKyxfdzxxGx+utXitjRuG3lbnqEPqMa8ZzB3MKH870
vRxEF1aJasVbUJD5ZhU2gK430bxUbUmhLV0L+tGu0SlfJ60onBByke5D63hN
rNCypvAj9Izgd/SbufWeXlsoKO4IE/6GlrZLTkraivOQH5frRau0d9XWbaMg
vKrcrAfdYD/716QNhXxu6slu9MjLE0pqdhRMy51ef0X35WVsd7WnINtToM26
3+BZbIwDOi4k+wsaIuXrCrdT+PnaX531ZK6gaLcjBancndWf2f0a5HvOdaaw
cUA6kPVrUU6VvgvWq7tnJevOWqLj4Uphu7DEry50XMX7onM7KIjdH2pj3b1T
eGuBG/ZDu6KStZhK0p92dwoTQbv+3wnj5yv+7sTzPjPpDWtd6d4MxX/wPBsb
UNbix2+kmnngeVojqcSud70786mfJwWdvCkv1kc/947F7qbQJ1tdyLpFiWOX
50XhdZ7RQrYehYT0tiZvCpY6RtGsK12bIob3UGhQSRJg+7FE+YaliC+FnPyl
iazd9dpMVP0ovI1+sJrtJ3+4gbf5XrxPxBZ3seYtOVu42x/zslk/me1/+8NQ
3agACidfdXmy8xHRfNqTvA/n9bB/HTu/H4oT1Y8CKSjUaiiw8738+n1H434K
B+zOLmDnb9I1sezbAQqtmi1SbD7UA8aypoIoiFd8Vmbz463vsVPiEAWBX/9y
2HwdzW+yXRmMeTSuPfADvXZO9XEIoTCYuP0um8ffe+uG7A5TSN0rM8Lm1fq7
e9KeUOxH4bgJm2f9nKkT4WF4v/RVZLB5L5kpmx8bTuH/APwiKLM=
           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "1"}], "}"}]],
         Annotation[#, {"C", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0.5, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV13k0lVsUAHBDHmUIRclQiIzXrGTYGaIkIaGQUkohY8iQoV4IrwjNJZkz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           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "2"}], "}"}]],
         Annotation[#, {"C", 2}, "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]tt)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]tt)\"", TraditionalForm]},
      ImageSize->{{1200}, {700}},
      Method->{"AxesInFront" -> False},
      PlotRangeClipping->True,
      PlotRangePadding->None]},
    {
     GraphicsBox[{
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1Xk4VlsXAHBTcvZruEjRZCzpFmlQMq3SdEUSChUSTZS4pYiQoiSlKMmQ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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "1"}], "}"}]],
         Annotation[#, {"Discard", 1}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVUXc4lY8XVxmVJFFpKERKpfEtIjpFlFJCKcoeCYVKoYymEFKEMrJKIuoO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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "2"}], "}"}]],
         Annotation[#, {"Discard", 2}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{10.834135988275978`, -0.012055739782186938`}, {
           10.876435471981898`, -0.011949285676132263`}, {
           10.91073602135632, -0.011873440576463185`}, {
           10.940388143334381`, -0.011815298319183352`}, {
           10.966914215304493`, -0.011769056829642027`}, {
           10.991158412678693`, -0.011731532239340068`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "3"}], "}"}]],
         Annotation[#, {"Discard", 3}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{7.692543334686184, -0.012055739782186886`}, {
           7.734842818392105, -0.01194928567613217}, {
           7.769143367766525, -0.011873440576434906`}, {
           7.798795489744536, -0.011815298319210184`}, {
           7.8253215617146985`, -0.011769056829642247`}, {
           7.849565759088899, -0.011731532239340129`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "4"}], "}"}]],
         Annotation[#, {"Discard", 4}, "Tooltip"]& ]}, 
       {GrayLevel[0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVVnk41OsXnxm+X9cSUbYsIZKiUmgR79tGSCREVwtKaaGUKyp0XVuKFhFa
SEnZS9kdkZIZjG0w2ZN1xr6vP78/znOe83zOc855zq7o4GpxjkahUEaW6f+8
o/6OCa91N2KG7ffjPu0C2YqV7/o9etDHBx+y7+f+hkMlIilmF3uRGfuoVbjQ
b5B7JfuoDPehGbnZwlOenZCtoU3u5+1H89efPj433QETd7sLvuT0oyNVTv49
/3VAlIUE0j87gBY0ywz7ZTrAcm/E6xGCg4q8Cs9fzGuHbDguZxbLQa+nLHOm
7NtB+J/uHDctLirqD97sK9wOhok4QKdkWU4K1nbwbYNip0fWBqaDaG4lX1QZ
pxU2XV/rp147iPSH6R9V7Vshw5bqfsJqCHVPBrPim1vg6F6J8M11Q0gF5OUC
TrWAmEAdnlcdRj/5Y/ZpdTeDsOEbSe+zw+iLn92njdebwbLGUiL31TD6PJG/
Zpq3GaqvVnz62TSMNIaUabtjfkGA/p99JWIj6PLpeK1o7V9QnJrrmWs8ghoO
TX9k1LIhbS/ZUnR3BEULh68KdWfDzYeaEt1ZI8jA9ZbW6zVsEItbu2sndwRJ
XFZSry1uAomnhgsliqPINOrQpeErTWBd0cAJtxpF5T+ciEqZJvB4PxjyOWgU
DT//LnmA0QjPG7w8t+SNoqBFbaPNPo1Qv2H2niB3FH2VTTh5SasRaGz+rqPy
Y4gbKchuHmiA942BAgJmY8h+e8xnp7cN0G7aMrXbZwwtgrjE0JkGuODJUR1I
HUNHg4zFT8k3AOUsb4JC6xgqMrcIfdHCAiefjVIdQuOIT/3wyLOXLNiaN1em
qTuOhD6+kNWzZ4Hw4ol0SedxRFvo2n1ThQUqH6RvRUaMo/yiwTe7BurhzHF4
9LlkHK2vXvvj2sd6aGCHyf8zPI7Y8438YrfqoaqwT6xFdgJlWbvmCx2sh336
q9QHD02g2ywHmtXKeki5HTSVfGMCzeneK25troNeDpslGzuBBoYmIl9+qIPi
4C08e+kTqC3G8luwZx28CT//UHZyAmXmJq2LMKqDvqEF148Kk8gqa49i7po6
6KbHXSdMJpFU4I0UDqcWgnQizKTcJ9G+zWVaKkW1oK7Y8pz7chL5ep+N/Du8
FtRitv8KLJtEX2OiFYOca8HJsMutb2QSTSRP/BePaiHM48aX1TJTyM6ntzpB
ohbOVG3pEjwwhaoXedxCBmsgqvWpavXlKTSm9l7J5EcNfM5LjnZ6OoU8CzcO
t8XWgO1RXcPKgimUtNVS88CtGggr5aoKdE+hY+mH/dysa+CPvJOarPA06iQr
S89tqwFdMd1NpM40mqcmSkqL1EBwRjel/OQ0kuwNrg3kVENWYIKbs/80eqgu
9CClvBqOBRzR706eRgbbJlYEvK+GuL9WSu2rm0akT+axFcHV4LxSJ8l7bho5
7V75ADlXQ8mPhugXSjOIMKBKSRtXg+Huf/+NNZpB32JzfSI2VcNXZfZk0NUZ
1LC2yStzRTWkv9MJsImcQQvs7D7XYSbQorRzVhbOoJZRbl1pLRMc1xmv+tQ1
g3yiWy99ymLCDiuDVXsFZ5FHyG0enedM2KzTvj1fcxbpHZAVN7nLBJ2RbRwV
m1m0K/6C3rATE6Se7Un38Z5FNfHXdNeZMiF70Wak/M0sOqxRP9SxnQl263Pl
+emz6IUo1W6jDBNiklrf6o7MIm+fB3GzNCYEvCXHHCXnUE3SKZ7XrCoQtH93
zU9vDi3V++UcT6yCsjOt92Mc51DBQpXjqltVEMDXlZYSvKzvEqhXc6QKZCy8
DfLS5tC4eUjho3VV8IT3RkFp/RyaUlgfYzZTCc2pFL/KuTnks4XvGz+zEvi4
RnwNivNIW8LFqfBdJUgZsfLbDefRJYdAziXfSqCpkNLcK/NoWmR+YeWJSlgh
GRa+8GQeDZd/9k3WqgRf5dmkVbnz6IQVO0pvZSX0GKu0b21ftseipJVwKiCV
XvbFmlxA/1q+Oa9fXgH6nyh5AeoLKEmqITUlsQIeSf+6U2yxgJgHdT+LBlWA
ZexAhKDnArr45ODYxQsVMJ/T9cbx1QIiC6s25RpVwE2THUcYpQvIVpjqSlGv
APP9OXsNOQvIQyVcDolUALPs2A6W2CLS3fkvx2OMAXVpOcNeuxZR2JhsX3Ij
A8x71u/ecWYRyd+Mu9NeyICweLUBocBFFLHb/B/xBAZMivzTs5CyiEJVJPnM
QhngfLp0rVD9Itom3VL90IMBh+W/Pt41v4iMB324rfYM0MucMw1at4SMnZ9x
9UwZcF5kymXWeAmZaawZ+LiLAYW3dys/dltCct97H+xXZcDB3JupR6OX0Ndj
3pKT4gz4bv3DXrd4Cc06fnOpJhjQ4N6bcLR/CV1ROKDRMkkHfj5LbxN+CnY1
bkxR7KNDRkPCfIAcBXsnicolNtMhu0c0oVmTgh+X+od4VdPhbuG9NlMDCl7X
bkh784MO9pGass0nKPicPitqK9DB8uGO1iBXCpYMZT7RyKbDs/fMLKv/KLix
qsnj/Uc6xJ3SPHwgioIv2kpqZabSQeZgpLl1KgUzopl7TyfTIT/+7wcPSiiY
fq6ssiCJDr4mwm0DjRRctYXK6VrG++UjdlwfpOC80tzigTQ6dAYde6XCS8W+
rCjmQCYduM+QDrGGiju9RNWp+cv+r1C0V2+l4p1HrGqMS+nwpLWXa2lAxdfA
nDLApMOer/UVP+2oOHn+1DO+NjpkOrDs3K9TcaLsj4jyITpMPAjUP3GPip1e
W0Q68DDg/ibKtltxVFx0IMOFZw0Dep6tE/2VTcXiBiXs7u3L8rm1VbeZVCwo
cNTU9CgD9OV/uDv2UrFzukq9txsDpL6cV3xMoWHRI31qjEgG2BqFzApK0zDD
/Wxb2FcGmDXMqtdp0nCQCPfblmEGvM9d9YtrTMNNby+7yytXwNnX+kJ2Z2l4
s5erTMvJChB3mQ1X9KZhOz3/iwsvKiAm89YkfkbDVD1EX/enAm5Rbbfnf6Th
xfY96fzL8xT1ZW1EeAUNT6f5LfmEVMKjnYJO5b00bMooc77GqQT96FB/O14e
vDT3yaXreBU4CW6eNFTgwX9xPRLmK6vA5WqWXuAeHuzp3Wh7R40JtrsmPoja
8uBY7T8Lz92Y8KHZ7zbbnQc3SX72elrChMGKsvGqxzx4fJOZsbJcNXzcdOg6
O40HN6uYx/L4VkOiUnrBLwYPFi2bI1uX97VjYP+X1D4efG3DDZr+2RpoAlem
KsmLI96qJ3h118D2+MzbEkq8OJJyNzD+ei1UL/wuNtTjxVriY8RVwTrgtcos
Cz7Oi3+aeiTrpNQBd0N/edpVXtyRMPlw+Hg9yD6WznsaxItPX/hSbiTAgs5E
v3ylV7z4TtpO4/xiFpzuEBI0zlz2t97QNs1n+f6308wFynjxhoeuhk9RI5x8
MVZxic2LFRrfnqZRm2Cu9Nv0nQFefPOD1Iq85f8lWi2JajW3jCv4v87xY4M2
YZPBJ0Bg4RU/szT2/wLHicc5KZIEVjv43tOD0gxrS3P/PaVM4DI16qxCXjPk
fV11butWAv+A+WmWWwvsW6Ggs1OXwG2944IOqq3wgOIkFnyQwLVLu8NjG1vB
Y1W5mZYZgRXvMZLvBrTB+5M2wUY2BE5LMPD3lWoHNs+nHNYZAu8c+8QWvdwO
FHu2Xe8FAt97eTd/tqAdhE4/Dw++SmDbzDz3/cIdcDmcfvibB4FzV7MnJuw6
QC8j6mScN4GV1Yb05T50gGu6XtIGfwLDjcPT3yY6oL83dJ99CIEjXunIzaBO
qH4e4nb0EYFDhkS+lgZ1AgW4nYsRBD5DNP3WYXbCdx++RJfnBB7bsPqYjcRv
sOvaaPk2bjl+BZ5w7b9/w7G7HeS7BAKHXhisa3r5G5qqdbw8kgh8+WnGb7OO
39CfYSG8Jp3Af0dpbXit1AWbQmJqH2US2O4UI47t0AXxDx896cgmcLt4fjft
dRf8Oh/aKFhA4PkcrKLc3gUCImHjYl8JLN6UqWIo9wfaGBv4Zr4R+GTaP6Y3
bP+AtV8praiMwFdYZq8/hf8BzyaU4cxYro/A5kqhqj/gf3g8a6qKwDKdf60L
/KsbWCa2MZdqCZyR3fRSbW83vFrQKP7OIvBjw8dDsze7QUPR9KYAm8Drf/J4
UNO74XLilpEdLQQOz0o+sr+7G8yE1IzN2wksYeFk8l2mB0x5nO5b/ibwnxtc
ykPzHjgl+Tn1YPeyfYkDpW//64HNUWsjlfsI/Ey0/5NQdg8cfmIjOzpA4IJG
TvrP/h6YjSf50gYJPHqt8lKHbC+coHHF7EYIzBN2wMHmSC8wLkwNzYwRuGOe
2bnNpxdGVdT3B08SuLRFS8Q9rRcCNge+E5hZzq9RUatSWy9opReles8R2IHX
VwEL94GLDbXzz8Jy/wma3GHu6YOz+gHFmEJiSM7wbLjYB2tUdMrDaCQ2a63y
sHnWB76RapdreUns4s+bY13aB+XbVcWF+Ehcpxt2un6kD9osxdV385O4Rkni
aoNcP6D1DmKnBEn8W0e89rRRP7iKOirfXEFii8Cd1tdu9IO9bXJOkAiJ82Nf
pwi/6oeKOHuVh6IkNnRScN/9sx+KBX2/hK4i8Xk/E82p0X5Y7aOU/Z84iQPv
Pzc3lB2A+4lF19wkScyuu6KucXAA4tY7q9pIk3jj4BB/0pUB2GMxJa0jQ+LS
rJUyJU8HQJw8GCgkR+IttVY+HgUDYFBg8+GXPInzDJIOlHcNgLXtw7x4BRIL
86teKBDkQHlD2fBZJRKfUy5mWWzjQNNOvztrlUncvPovl/s2HDhfQz6pVSHx
/Zn8+UveHGg+cPfMXVUS66re2j8WzwH6PuVVamokJuIOTaz7yQG343tZ5RtJ
3DGqnL3E5cCTOsdaJ3US63eGqQSJcUFbyHnbggaJVc7w0wt1uNA0FSEduoXE
75VCNr49wYUHlzJSpDVJHLp/PnePNxfGh1eIxW4jcfSeV70BcVxIcEy4oKhF
4pPhXuL+37iAnTbWvNAmsWdQftTOHi78D06svRU=
           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "1"}], "}"}]],
         Annotation[#, {"A", 1}, "Tooltip"]& ]}, 
       {RGBColor[0, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1mk01I33AHCh78wYY2aEbCmlEip67C33Cj3WipRKC5WmlJ+pZIkyVCRL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           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "2"}], "}"}]],
         Annotation[#, {"A", 2}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVVnk41d33NVQicedPQhnL2ESayO4VkZQmNHwlIVKG8BpSpgwlKRGaiIgo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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "1"}], "}"}]],
         Annotation[#, {"B", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV02k4lWsXB3ChU5RQtJ+997N3SYMhQman1iocRKeIg0ppECppUOY5ZJ4p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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "2"}], "}"}]],
         Annotation[#, {"B", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 
         NCache[
          Rational[2, 3], 0.6666666666666666]], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwd1Hk4lVsXAHBTiFDXOZyKVFRESCFD1itjqUz5SEiDZL6mjAfhmrrIkJlQ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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "1"}], "}"}]],
         Annotation[#, {"D", 1}, "Tooltip"]& ]}, 
       {RGBColor[0.5, 0, 0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1Xk0FVwQAHAtqEjJ9rxHUrakEiH7jbSiqGhRlBKhpCLahCyhly2hUFFJ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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "2"}], "}"}]],
         Annotation[#, {"D", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwd1Hc81d8bAPDKTikhLbn3hkiIZCXPxy8qZY9IqShZIdkjK19kpmuvJKFI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           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "1"}], "}"}]],
         Annotation[#, {"C", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0.5, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1Hc4ll8YB3AjkURm0lDv+yIjFBJKT5OKioySVJJVQvwqEtl7k5FEGYko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           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "2"}], "}"}]],
         Annotation[#, {"C", 2}, "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->{{1200}, {700}},
      Method->{"AxesInFront" -> False},
      PlotRangeClipping->True,
      PlotRangePadding->None]},
    {
     GraphicsBox[{
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVVnk0Vuv3J973PedUEpGpQRokdA3louyiIr6UoUxXyZWQlArJnKlcFyWJ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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "1"}], "}"}]],
         Annotation[#, {"Discard", 1}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVlXk8Vdv7x41n731KQiqREhWlhC6SPJUGsy+FKBmS1JWQVFeEDCW5olLm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           "]],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "2"}], "}"}]],
         Annotation[#, {"Discard", 2}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{9.094218012734009, -1.2949707911251922`}, {
           9.13693355257484, -1.294786015922067}, {
           9.17164822418722, -1.2946325841924784`}, {
           9.201713318810391, -1.2944974025641118`}, {
           9.228651705652092, -1.2943745527422879`}, {
           9.253307907545262, -1.2942607697912125`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "3"}], "}"}]],
         Annotation[#, {"Discard", 3}, "Tooltip"]& ]}, 
       {GrayLevel[0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[
          LineBox[{{9.094218012734009, -1.1949707911251923`}, {
           9.13693355257484, -1.194786015922067}, {
           9.17164822418722, -1.19463258419245}, {
           9.20171331881034, -1.1944974025641386`}, {
           9.228651705652092, -1.1943745527422884`}, {
           9.25330790754526, -1.1942607697912124`}}],
          RowBox[{"{", 
            RowBox[{"\"Discard\"", ",", "4"}], "}"}]],
         Annotation[#, {"Discard", 4}, "Tooltip"]& ]}, 
       {GrayLevel[0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVV3k0ldsb/s7sHJzzNZNQyXANmdIkziuVXEoTcVOmJNFgSBqUyHRNcdFg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           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "1"}], "}"}]],
         Annotation[#, {"A", 1}, "Tooltip"]& ]}, 
       {RGBColor[0, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nk4VlsXAHC3QkTOO0uGkvAhU1JRWs0XDUopZSyUITQSEUrIEA1c4uJG
SN10Q6VY14dknjJmzJjI+x6SUH37++M85/k9++x99t5nrbXPyhMeBx0XCAkJ
Ccj1//sj8JIVvJOGbhH33LVJNIaY/vnbtmRpGFepO6VLnNH9RvainzRkbzAU
VSemNY+6GtlJg+anLyIriBVWppyU3yUNDW4PLjOJZ1aZHwZNaegXpAgWEFsY
LK1XkJYGM5gvEyTSuOTbx7KTC6Whw+iQZg9x6tlaunqCBxvvd+2vIi7+8qe/
RhcP7LYY7sgnXhPfcs+migelFSfkUogVTlkt213Agw7Fb8OhxDUXlK/UZfFA
iFv+2JN4pR3v8GA8DyZFK88eIb7x0cb+8k0eVDpXG2wmPo11df6+POhJHxFT
JJ4akCocdeNBWW9XjzCx4MPphuc2PGg7s//NyH0ag6z2TjeY8eDi98mkSuLg
br6s0XYe3GC+Csomru5yYNDreOBs2H0qnHilvOSREVUeSOWKmbgQm0oqS8jK
kveFHV39O/GQxMvGUCkynrjrVyXiruvFhWoLyfPO7nlCxM8Ncrb+nObCfm0l
uw8JNEYN+qgIfeaC4eTwRC7xiRXNgWt6uJB897lNJPF2I27atSYuJDkpPnQg
dl4fJCP0jgvLLM6jAbGoeN6DlDdcoIxvPpAitvr5Q+3kMy78qOWb9MfTqGYW
VLLzIRcMDFue5BG33RFJ23WfC/abpEpvECvv37HKIZoLfr/YwRbEMpz83MRg
LmSNLhxRItbf927wiw8XdGbi+wV/0Hj9s+1xS08uLH+l515IHFL0qK7DkQsO
i+r8Qojl9LSoc8e50GTxU9SMeP975rzcAS5MDE78xiMe2hod1LWLC79OOdp1
xtEoGx2b+nQTF57GPOOlENvlRDjc0eXCbePc5SeIF/rp9YeocqEuusVWkfhE
WBZEyHNhRkGktTeWRoaz96NkNhcW5eecTyJuvV11pFicC548VDlKPOOYHcoX
4kJ8wa0Bipipvj9Y4xsHZOQFCeX3aDTT9ku6MM6BgLLlhleIy61mVN71k/a2
7FxN4rrK74HKHRzQt06Y7r5L40+lvKW36jnwF6U/EUG8PHNI/7dyDmDF8ogN
xPI1zqevFHKA765Z0HeH7MfrVo5QLgdi3KMcQ4krXmnkhz/iACs/+rIGcTV9
vlQ+lQNGCnm9NbdpNOn3xpdxHGgySbzuRrx6wu8/llEcUO6Z37uY2Cz2W8iv
6xywX/GHUmoM6d9mejLblwOurWsm9IlT7O/tsjrHgaO+HncqomncIONC9ogD
ntH016PEdfVp1lW2HLinqTg7cIvGggc6z0MtyPuStYLOENuPdpob7+WAs8gC
DzqKxmPHlJoldnDg1IxSynniQA3x2kYDDsj/yJvkR9J4RHy0JUGHA+6tZrtc
iGWi94c5qHLgdvDsuZ4IMt7a2qtaChzw6hI3NyPeYN9xeI7DAb1H7KI34TQ6
ZT3IKJfgQLdGdZgScWntBOPuQg5o9X4OC7lJY3LstI7dLBvCj/OiB8OIdY3S
1QVsQM03rkbE+xS9xaaH2dAbzv8UE0ry0cVmvqibDYdi9jf3hJB6IhSz/EYz
GyqEmr6qEDuYnF9kWs2GOvVHlMsNGnffEzskWcKG4jbJkfRgGpOOtzysfsWG
6U7K8MN1Uj92vPgjNIcNmxTPlIkR//GyuBQy2HD97Z4tOtdoXDsoXzaVxIbK
uaXWB4Jo3CE7rJt2lw3xOxfXOQeS/bKdT98XzoaUh5u3+gTQeP9Hf+5kIBvu
7pQ5HnSVxo0yyVO3vdmweaECBvrTKDUfOKPuwQa3M+Hi3n401n8XO1jkyIa/
nH+9d7hCo2bXs2hjKzbs6mXn7PalcTa6dGvNQTbIJfKVV/jQ+HFsDf93Yzbc
8KkoHPcm83c3VnqzhQ22XxwET71oXJzz90llfTb4vArRd7pEo7r1nHaIBhte
/mn5XeoijbFXEpZ0K7KBm1mQ+Pg8jUbFoR5qy9hwzDP0suE5Um8ec5pdpdjQ
+aSh67Unydd1qTmpwmwwXTi9ZI0HjWl5h89VzbHgVfvTjVFnaJwr7AoeEbBg
c6HwrW5XGhOiOAdnhlmQabtitZwLiffGFxtmu1hQtmCBsPFpGnW2CceON7Gg
KWG5sr0Tydd6p38bKlhwxeu1m4MDiVe+2OKHyIJr2WaZB07QaJ14Kd85jwWb
Cv1iVOxofBsnv1Q2mwUBdlPlA9Y0escNGr9JYUE7xaoPOU7jzdrURONYFpgc
3ERJWdLY7HdXuyScBWqK3TXeFiQ/FTqUVQNZEPpUXq3EnJxn7Q2xXpdYkFK8
Un7MjEaDUd/IHFcWjG9ouyTYS6PnfK1Eox0LVMt+r683oTF7z6IlHw6T9esY
RYfsJvVzuuNspQkLvl3a0cvcQWPERKNc8hYWLJxrf+gB5Hwrsus6oseCD7/y
riZsIvFyY7nnpCoLxoSFnt/aQKNr53CwpxwL8ir3qpvq0UhNKxbVMFgwYaHv
8k6L1FftpodiIiywUwTfBeo0KvIHXivOMoHyGhqYXE1j1RU/J94XJsTVOMXF
rqDRfdpzfrCPCWUZ39v6ZWjkbBzHiGYmWDks0XrPJvPJO9sjVsGEr2kz222X
0hh+W+/S8TdMaHXCd76iNI7arYi8+pQJo1cWHFQQIvl+IE32wl9MSBrL0jKa
EWAtlSa1/h4TVnCOGVVNCFBaML77bQgTqjwFz14MCTDVANMUfJhwvXBLG90p
wOIWMYmtbkwo/7W9yblRgF9HHL1UbZiwvj3QRLRcgGtf9Qi/388Ez9ZrrOcF
AjS5q8LetpX0vxDVeOCJAC+USlif1WXCIx1ebOmfAmznxynZr2KC2ADr3EiU
AB/b+Xoy2EwoKqWUYv0E+NTwrdm1RWS9iY9rU10EWK57x/DVFAPmU6X7Ow4L
0C3Czu/FAAMWqOVbSmwR4NG2LYXX3zOgbonpqR+rBSgyb3xLrZQBogHrRs6J
C/Bm1y/R/OcMEIneWqwzxsdGOLphwwMG8Ji024IqPn7zxzNvbzNAao1Led5D
PvbtLBH1CWKAwu/re9Su8vHVKvd8j3MMMOGvUjh8iI82WzaLvT3BgIKMgKyt
ynxc/V7rxH1zBoSIPh/VG53As9HL/1iykwEzhw9/NA2awElHkaI16xnwz2/K
nsGcCbRtUg1lqjHAPWrT0n/TvuCxPtb9EjkGnN9bpvhJ+wt+ahap2s5kQJhh
xqbPBeNYEuTGihYl429eMpq8fRw3s6f4KT8omC0xj31bNYYHJAJqXKcoUDvl
YyF0aAxnjgnvGvhMAZXJiK/r/Iz54XOaP/opcM2csE9w+ow6zjIHszopMKtq
/PBEMIoxs2LjH5opaHumb7XNfxRFxb78CK2jQP1ZuslViVGc26Ptml5BgaGn
Z4p/4idU7mExVUop+KLr0b9f8xO2e4iXLUIKHj6Kjp8tHsEHJXtAv4ACQeUo
BBwZwcEL2sty8yjwMM/u6voyjDE+Gtlezyi4br5VWzJ0GA/nOi7yfUKR87cw
TXjVMGaXdDa+zKJgsIgrXohDGOnaelDjIQXOj/3lVG2GcBXUGjX8RYHv97uT
Bj8H0Vri678Pkimor9mx+1PyICpcs3BKSaQge41DrvL2QZw2d2WVxlPwI6Tp
49DwAEpkSswuiaPg3V/l6XJRA/hjVXL0xbsUnM2mmLhuAHVyzG/+jKFgX39Y
JHb3Y5yidX3aLQou/MeqnRXWj4fi5n2dIim4vfqY9DO9fkzfZ9ywNZwi/0ue
jRF9H3Ho632DdWEUGCl9+pp46yNeUQ/dsSWEAskV3NZWo4+oWnggwSaYgvC+
ek29iT70CqtZcPsaBYHxytJZKX0YxEixbgukgP7oKalp3odKmTUp2gEU/Pe/
EoMFIn34tjamJd6fAtjZXLP7dS8WvrqwnOVHgVW9n2mNZy8macUl3velIFWh
T3eHSi/aLdKM1fWhoOht5h7Twh6Us1Q52OpNQVYES6llTQ96R08ph3mR+ZSy
D8imdKP/nQuXdl8i63NKKGKwu7Hh3uxjxkUKWs90tTwK60IJUXcYPk9B1DjX
r1OoC9dWBzwtP0eBjbmfaOLlTow0+B7wz1kK7kXd3Ngz+QHF/5TcnuFJwan0
m0aJHh9w+HjdzXQPCsxtz6ZVjHXg2M8Hk4/dKQhZ+tXCxrUDZZ5WyheeoSCM
N5Zw4HM75peO/dPsRkFvyKjYfbd27Nv78vi0KwXDn2SjdCfaUDjwWoU8sbeT
tQ11vg1V9WZy9rmQ9l0BsxozrdgU/rYy2Jl879H3KoH+rbhe3aap5DQFBpZt
48IirXhm+5Obi4mVMrl3cqNa8K5g4Ln5KQosbm1IuCHdgkMu2zjpThTMJRjg
xQfNOHmt02vekYKKiKopX61mXKxxMcOSeCSpzv7Om/f4d8C+c28cSPx6iNjm
m7zHO8oLs5SIUxIbLvS0N2Fokr387ZMU8PjLLMVcmnB0j0nGImLW5QPjmnON
yJSIlrlygsTj8+hNppGN+ILfYTZjT4GIds1lyxWNKKkbqXSZOGyt6s9DuQ14
dCrr7E87kq895rs3Gjdg4/tCTiixS6Tk9G899XiGUTHBIZZZ+bj60cV6PK2u
3pthS0GHbPETLcl6LBm69W4zcWdl7LplpnVIhXeFt9pQwLb86ujrV4v0HqWl
F4kjGcIO/s9q0KsiSo9LvPHJTJfMcDXe9zcfLLCm4Cr1d76xfDWu1MwQPUnc
rp+5cNGRKtRdlnNtKfHMyMol22Mq0UDYZ1uhFQXHutdvE6qpQL250TUexFPf
VU3XiVfg/wDFXYTc
           "]],
          RowBox[{"{", 
            RowBox[{"\"A\"", ",", "2"}], "}"}]],
         Annotation[#, {"A", 2}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwVVnlUjd0Xfu98u9W9r5IkRIlKhqRJ0m4wJCWpRBGFZGwk6qOZNFPGNJAi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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "1"}], "}"}]],
         Annotation[#, {"B", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0, 1], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1Hk4V1sXB3Ayl3R+symuIQkNopJuWRK9GijSZMhYXBpIiLjhmlNKSClc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           "]],
          RowBox[{"{", 
            RowBox[{"\"B\"", ",", "2"}], "}"}]],
         Annotation[#, {"B", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 
         NCache[
          Rational[2, 3], 0.6666666666666666]], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwd03k0Vl8XB/AoURokKc9wo5Lil6hEoeeaEiVTIpQiipIx81hCogzxZEhl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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "1"}], "}"}]],
         Annotation[#, {"D", 1}, "Tooltip"]& ]}, 
       {RGBColor[0.5, 0, 0.5], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nk01c0bAPD7/V4RFcX7Ut58XUJkDSlbDYkW3pBISlnKnigpUZZ0RYWy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           "]],
          RowBox[{"{", 
            RowBox[{"\"D\"", ",", "2"}], "}"}]],
         Annotation[#, {"D", 2}, "Tooltip"]& ]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwd1Xc8V28bB3BkpWSkjO+wkpIdoaibX4hKpJLSQrSRhlmS9eSnULZHg5SR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           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "1"}], "}"}]],
         Annotation[#, {"C", 1}, "Tooltip"]& ]}, 
       {RGBColor[1, 0.5, 0], Thickness[0.003], 
        TagBox[
         TooltipBox[LineBox[CompressedData["
1:eJwV1nk8Fd0bAPA7MyIVkn6Kl3Fvlkghire0HBLpzZospcVStpRESkmSJCSF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           "]],
          RowBox[{"{", 
            RowBox[{"\"C\"", ",", "2"}], "}"}]],
         Annotation[#, {"C", 2}, "Tooltip"]& ]}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]\[Tau])\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]\[Tau])\"", TraditionalForm]},
      ImageSize->{{1200}, {700}},
      Method->{"AxesInFront" -> False},
      PlotRangeClipping->True,
      PlotRangePadding->None]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Watching the Hessian for branch cuts", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "HessianRoot"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"HessianRoot[S,t,\[Tau]] calculates the Hessian root \
\!\(\*SqrtBox[FractionBox[SuperscriptBox[\((2  \[Pi])\), \(2\)], \
\(\*SuperscriptBox[\(\[ImaginaryI]\), \(2\)] Det[\*SubsuperscriptBox[\(\
\[PartialD]\), \({t, tt}\), \(2\)]S]\)]]\).\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info123674213737-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       
       RowBox[{"\"\<B\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"keyColour", "[", 
      RowBox[{"\"\<D\>\"", ",", "_"}], "]"}], "=", "Cyan"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction"}], 
      RowBox[{"(*", 
       RowBox[{",", 
        RowBox[{"DiscardedLabels", "\[Rule]", 
         RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "*)"}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Function", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"n", ",", "t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", "n"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", "\[IndentingNewLine]", 
                    RowBox[{"ReIm", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"HessianRoot", "[", 
                    RowBox[{"S", ",", "t", ",", "\[Tau]"}], "]"}]], "+", 
                    RowBox[{"0.0001", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"\[Tau]", "-", "t"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}], 
                    "\[IndentingNewLine]", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", "n", ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "}"}]}], "]"}]}], "}"}]}], 
                   "\[IndentingNewLine]", "]"}], "@*", 
                  RowBox[{"Apply", "[", "Sequence", "]"}], "@*", "Flatten", "@*",
                   "List"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"selection", "[", 
                  RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "]"}], 
               "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[CapitalOmega]", ",", 
                RowBox[{"Keys", "[", 
                 RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"index", ",", 
              RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}]}], "*)"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "900", "}"}], ",", 
            RowBox[{"{", "900", "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Re(\!\(\*SqrtBox[\(\*SuperscriptBox[\(\[ImaginaryI]\), \(2\)]\
\\\ \*SubsuperscriptBox[\(\[PartialD]\), \({t, tt}\), \(2\)]S\)]\))\>\"", 
            ",", "\"\<Im(\!\(\*SqrtBox[\(\*SuperscriptBox[\(\[ImaginaryI]\), \
\(2\)]\\\ \*SubsuperscriptBox[\(\[PartialD]\), \({t, tt}\), \
\(2\)]S\)]\))\>\""}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Function", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"n", ",", "t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", "n"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", "t"}], "+", 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"\[Tau]", "-", "t"}], "]"}]}], ",", 
                    RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", "n", ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "}"}]}], "]"}]}], "}"}]}], 
                   "\[IndentingNewLine]", "]"}], "@*", 
                  RowBox[{"Apply", "[", "Sequence", "]"}], "@*", "Flatten", "@*",
                   "List"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"selection", "[", 
                  RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "]"}], 
               "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[CapitalOmega]", ",", 
                RowBox[{"Keys", "[", 
                 RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"index", ",", 
              RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "900"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{{
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004833426533306348, -0.004746920363323854}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.632189772884385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8383554163654666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5874585404782884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210239963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 1, {
              Complex[3.632189772884385, -0.8383554163654666], 
              Complex[1.5874585404782884`, -2.3355245210239963`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0007975019186896107, -0.004746920363323948}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4905971192945886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8383554163654704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5874585404782842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210240003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 2, {
              Complex[0.4905971192945886, -0.8383554163654704], 
              Complex[1.5874585404782842`, -2.3355245210240003`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0030175113069637128`, 0.0031504635493594195`}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.834135988275976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01205573978218699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.094218012734007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 3, {
              Complex[10.834135988275976`, -0.01205573978218699], 
              Complex[9.094218012734007, -1.1949707911251923`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.003331670572322708, 0.0031504635493594473`}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.692543334686185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.012055739782186827`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.09421801273401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 4, {
              Complex[7.692543334686185, -0.012055739782186827`], 
              Complex[9.09421801273401, -1.1949707911251923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0005164960455137322, -0.005460793922534256}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6066222862308037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8682153108705755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5611274843968312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291787`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 1, {
              Complex[3.6066222862308037`, -0.8682153108705755], 
              Complex[1.5611274843968312`, -2.3644087056291787`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0008306553108727232, -0.005460793922534337}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.46502963264100744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.868215310870579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5611274843968284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 2, {
              Complex[0.46502963264100744`, -0.868215310870579], 
              Complex[1.5611274843968284`, -2.3644087056291823`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0034788140502284076`, 0.003587770052662493}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.876435471981889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011949285676122938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.136933552574833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 3, {
              Complex[10.876435471981889`, -0.011949285676122938`], 
              Complex[9.136933552574833, -1.1947860159220576`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0037929733155875433`, 0.003587770052662474}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.734842818392103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01194928567613202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.13693355257484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 4, {
              Complex[7.734842818392103, -0.01194928567613202], 
              Complex[9.13693355257484, -1.1947860159220667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0005219582872827844, -0.005997156258617174}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5867917162410965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5405103103336057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.387780403540836`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "Discard", 1, {
              Complex[3.5867917162410965`, -0.8925142454403441], 
              Complex[1.5405103103336057`, -2.387780403540836]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0008361175526417157, -0.005997156258617151}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4451990626513003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.540510310333603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3877804035408325`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "Discard", 2, {
              Complex[0.4451990626513003, -0.8925142454403411], 
              Complex[1.540510310333603, -2.3877804035408325`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0038133488782295484`, 0.0039054146095121958`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.910736021356321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011873440576436094`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.171648224187221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1946325841924512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "Discard", 3, {
              Complex[10.910736021356321`, -0.011873440576436094`], 
              Complex[9.171648224187221, -1.1946325841924512`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.00412750814358849, 0.0039054146095121906`}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "4", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.769143367766525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011873440576434954`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.17164822418722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.19463258419245`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "Discard", 4, {
              Complex[7.769143367766525, -0.011873440576434954`], 
              Complex[9.17164822418722, -1.19463258419245]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0005138155450644308, -0.0064380273850921585`}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5703092163900387`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5232245875485029`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.407908376507515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 1, {
              Complex[3.5703092163900387`, -0.9135287061735095], 
              Complex[1.5232245875485029`, -2.407908376507515]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0008279748104234085, -0.006438027385092199}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4287165628002437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.523224587548502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4079083765075175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 2, {
              Complex[0.4287165628002437, -0.9135287061735121], 
              Complex[1.523224587548502, -2.4079083765075175`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00407959021318103, 0.004158632975225076}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.94038814333433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011815298319208752`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 3, {
              Complex[10.94038814333433, -0.011815298319208752`], 
              Complex[9.20171331881034, -1.194497402564137]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00439374947854, 0.004158632975225077}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.798795489744536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01181529831920876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 4, {
              Complex[7.798795489744536, -0.01181529831920876], 
              Complex[9.20171331881034, -1.194497402564137]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004976824785343244, -0.006817949350314518}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5560864689304044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5081859946803688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4258284901011873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "Discard", 1, {
              Complex[3.5560864689304044`, -0.9322995873452297], 
              Complex[1.5081859946803688`, -2.4258284901011873`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0008118417438932904, -0.006817949350314499}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4144938153406103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.508185994680368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4258284901011864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "Discard", 2, {
              Complex[0.4144938153406103, -0.9322995873452282], 
              Complex[1.508185994680368, -2.4258284901011864`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.004302139787015163, 0.004370658518222564}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.966914215304485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011769056829642613`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.228651705652085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "Discard", 3, {
              Complex[10.966914215304485`, -0.011769056829642613`], 
              Complex[9.228651705652085, -1.1943745527422884`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.004616299052374261, 0.004370658518222583}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "4", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8253215617147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011769056829649287`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.228651705652094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "Discard", 4, {
              Complex[7.8253215617147, -0.011769056829649287`], 
              Complex[9.228651705652094, -1.1943745527422953`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004763697588522891, -0.007155068220565552}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.543518627975134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4947924622029343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 1, {
              Complex[3.543518627975134, -0.9494075862605201], 
              Complex[1.4947924622029343`, -2.4421177901257014`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0007905290242112798, -0.007155068220565548}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.40192597438534255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.494792462202936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 2, {
              Complex[0.40192597438534255`, -0.9494075862605198], 
              Complex[1.494792462202936, -2.4421177901257014`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.004493914842658165, 0.004553687085993728}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.991158412678699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011731532239331113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.253307907545267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 3, {
              Complex[10.991158412678699`, -0.011731532239331113`], 
              Complex[9.253307907545267, -1.1942607697912035`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.004808074108017163, 0.004553687085993608}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.849565759088899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011731532239340082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.25330790754526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 4, {
              Complex[7.849565759088899, -0.011731532239340082`], 
              Complex[9.25330790754526, -1.1942607697912124`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004514821733639276, -0.007460216499252455}],
            RowBox[{"{", 
              
              RowBox[{"16.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.532228336666828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4826686902970212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.45713719067949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "Discard", 1, {
              Complex[3.532228336666828, -0.9652164447599713], 
              Complex[1.4826686902970212`, -2.45713719067949]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000765641438722922, -0.007460216499252515}],
            
            RowBox[{"{", 
              
              RowBox[{"16.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.39063568307703384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4826686902970199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.457137190679493`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "Discard", 2, {
              Complex[0.39063568307703384`, -0.9652164447599751], 
              Complex[1.4826686902970199`, -2.457137190679493]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004240190163965008, -0.007740430493807633}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5219614272863144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9799721862678735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4715621017597873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.471130430093209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "Discard", 1, {
              Complex[3.5219614272863144`, -0.9799721862678735], 
              Complex[1.4715621017597873`, -2.471130430093209]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0007381782817554896, -0.0077404304938076636`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.38036877369652167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9799721862678751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4715621017597882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4711304300932104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "Discard", 2, {
              Complex[0.38036877369652167`, -0.9799721862678751], 
              Complex[1.4715621017597882`, -2.4711304300932104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000394642194360701, -0.008000564610222166}],
            
            RowBox[{"{", 
              
              RowBox[{"16.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5125370745305697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9938506052393002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4612931389803365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.484271399542434`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "Discard", 1, {
              Complex[3.5125370745305697`, -0.9938506052393002], 
              Complex[1.4612931389803365`, -2.484271399542434]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0007088014597197021, -0.008000564610222157}],
            RowBox[{"{", 
              
              RowBox[{"16.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.37094442094077773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9938506052392997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4612931389803379`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4842713995424335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "Discard", 2, {
              Complex[0.37094442094077773`, -0.9938506052392997], 
              Complex[1.4612931389803379`, -2.4842713995424335`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0003638109102615262, -0.008244123174888195}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.503821225666987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.006982614287426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4517287827631657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296525`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "Discard", 1, {
              Complex[3.503821225666987, -1.006982614287426], 
              Complex[1.4517287827631657`, -2.4966893902296525`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0006779701756204555, -0.008244123174888172}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3622285720771921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0069826142874234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4517287827631644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "Discard", 2, {
              Complex[0.3622285720771921, -1.0069826142874234`], 
              Complex[1.4517287827631644`, -2.4966893902296494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00033185541107140384`, -0.008473726957332986}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4957112579472582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4427672678721806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5084836837647715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "Discard", 1, {
              Complex[3.4957112579472582`, -1.0194689005855273`], 
              Complex[1.4427672678721806`, -2.5084836837647715`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0006460146764303744, -0.008473726957332962}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3541186043574641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.44276726787218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.508483683764771`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "Discard", 2, {
              Complex[0.3541186043574641, -1.0194689005855264`], 
              Complex[1.44276726787218, -2.508483683764771]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0002990201265734812, -0.00869139238305569}],
            
            RowBox[{"{", 
              
              RowBox[{"17.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4881265575136493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0313889380536854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4343287018663806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "Discard", 1, {
              Complex[3.4881265575136493`, -1.0313889380536854`], 
              Complex[1.4343287018663806`, -2.519732518631915]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0006131793919324715, -0.008691392383055723}],
            RowBox[{"{", 
              
              RowBox[{"17.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3465339039238557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.031388938053689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4343287018663795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631919`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "Discard", 2, {
              Complex[0.3465339039238557, -1.031388938053689], 
              Complex[1.4343287018663795`, -2.519732518631919]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0002654902613827918, -0.008898707482565004}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4810024450236203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0428068062799816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4263490191882389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5304988762356877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "Discard", 1, {
              Complex[3.4810024450236203`, -1.0428068062799816`], 
              Complex[1.4263490191882389`, -2.5304988762356877`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000579649526741735, -0.008898707482564992}],
            
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.33940979143382616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0428068062799807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4263490191882378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.530498876235687`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "Discard", 2, {
              Complex[0.33940979143382616`, -1.0428068062799807`], 
              Complex[1.4263490191882378`, -2.530498876235687]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00023140890136998625`, -0.009096947519762063}],
            RowBox[{"{", 
              
              RowBox[{"17.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.474286100253405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4187759266798956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5408343661536392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "Discard", 1, {
              Complex[3.474286100253405, -1.0537751001493318`], 
              Complex[1.4187759266798956`, -2.5408343661536392`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0005455681667289563, -0.009096947519762056}],
            RowBox[{"{", 
              
              RowBox[{"17.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.33269344666361156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.418775926679894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5408343661536397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "Discard", 2, {
              Complex[0.33269344666361156`, -1.0537751001493318`], 
              Complex[1.418775926679894, -2.5408343661536397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00019688841492088833`, -0.009287153675492531}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4679337359736433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.06433764500318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4115660932135865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "Discard", 1, {
              Complex[3.4679337359736433`, -1.06433764500318], 
              Complex[1.4115660932135865`, -2.5507819227528166`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0005110476802798508, -0.009287153675492514}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.32634108238384935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0643376450031767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4115660932135874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "Discard", 2, {
              Complex[0.32634108238384935`, -1.0643376450031767`], 
              Complex[1.4115660932135874`, -2.5507819227528135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00016201828247473609`, -0.00947018819083718}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4619085826471014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.404683146512056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.560377729861402`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "Discard", 1, {
              Complex[3.4619085826471014`, -1.0745314357254354`], 
              Complex[1.404683146512056, -2.560377729861402]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00047617754783368975`, -0.009470188190837186}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.32031592905730694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4046831465120544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5603777298614023`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "Discard", 2, {
              Complex[0.32031592905730694`, -1.0745314357254354`], 
              Complex[1.4046831465120544`, -2.5603777298614023`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000126870612677054, -0.009646773999712388}],
            
            RowBox[{"{", 
              
              RowBox[{"17.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4561794165348236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501943`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.398096210752566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5696526277620455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "Discard", 1, {
              Complex[3.4561794165348236`, -1.0843880551501943`], 
              Complex[1.398096210752566, -2.5696526277620455`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004410298780360514, -0.009646773999712357}],
            RowBox[{"{", 
              
              RowBox[{"17.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3145867629450303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3980962107525663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.569652627762044`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "Discard", 2, {
              Complex[0.3145867629450303, -1.0843880551501937`], 
              Complex[1.3980962107525663`, -2.569652627762044]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009150411575663443, -0.009817523842674257}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4507194621757376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939347333651823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3917788166049063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "Discard", 1, {
              Complex[3.4507194621757376`, -1.0939347333651823`], 
              Complex[1.3917788166049063`, -2.5786331633102058`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0004056633811155729, -0.009817523842674238}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.30912680858594205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939347333651805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3917788166049048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "Discard", 2, {
              Complex[0.30912680858594205`, -1.0939347333651805`], 
              Complex[1.3917788166049048`, -2.5786331633102035`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005596702159498619, -0.009982962066345913}],
            RowBox[{"{", 
              
              RowBox[{"17.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4455055590441432`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1031951533323339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3857080739861731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "Discard", 1, {
              Complex[3.4455055590441432`, -1.1031951533323339`], 
              Complex[1.3857080739861731`, -2.587342388059074]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00037012628695395894`, -0.009982962066345906}],
            RowBox[{"{", 
              
              RowBox[{"17.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.30391290545435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1031951533323334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.385708073986173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "Discard", 2, {
              Complex[0.30391290545435, -1.1031951533323334`], 
              Complex[1.385708073986173, -2.587342388059074]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000020299259681598914`, -0.010143541223696165`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.440517518589483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3798640340783366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "Discard", 1, {
              Complex[3.440517518589483, -1.1121900734843542`], 
              Complex[1.3798640340783366`, -2.5958004746630317`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0003344585250406259, -0.010143541223696203`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.29892486499969306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3798640340783381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "Discard", 2, {
              Complex[0.29892486499969306`, -1.1121900734843577`], 
              Complex[1.3798640340783381`, -2.5958004746630365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000015465887457191707`, -0.010299654906143952`}],
            RowBox[{"{", 
              
              RowBox[{"17.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4357376210557065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.120937815790952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6040251997705024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "Discard", 1, {
              Complex[3.4357376210557065`, -1.120937815790952], 
              Complex[1.3742291902547281`, -2.6040251997705024`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0002986933779017902, -0.010299654906143997`}],
            RowBox[{"{", 
              
              RowBox[{"17.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2941449674659141`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1209378157909546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.604025199770505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "Discard", 2, {
              Complex[0.2941449674659141, -1.1209378157909546`], 
              Complex[1.3742291902547281`, -2.604025199770505]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00005130051306757112, -0.010451647796878186`}],
            RowBox[{"{", 
              
              RowBox[{"18.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4311502166452144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.129454653282832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3687880826648213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6120323271837886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "Discard", 1, {
              Complex[3.4311502166452144`, -1.129454653282832], 
              Complex[1.3687880826648213`, -2.6120323271837886`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00026285875229138406`, -0.010451647796878164`}],
            RowBox[{"{", 
              
              RowBox[{"18.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2895575630554191`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1294546532828313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3687880826648193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.612032327183787`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "Discard", 2, {
              Complex[0.2895575630554191, -1.1294546532828313`], 
              Complex[1.3687880826648193`, -2.612032327183787]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00008718109686796561, -0.010599823642900345`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.426741405743924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377551213057147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3635269813327329`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "Discard", 1, {
              Complex[3.426741405743924, -1.1377551213057147`], 
              Complex[1.3635269813327329`, -2.6198359153990136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00022697816849103462`, -0.010599823642900321`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2851487521541328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1377551213057142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3635269813327346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "Discard", 2, {
              Complex[0.2851487521541328, -1.1377551213057142`], 
              Complex[1.3635269813327346`, -2.6198359153990136`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001230877266036171, -0.010744451646203638`}],
            RowBox[{"{", 
              
              RowBox[{"18.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4224987798606765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3584336295287167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6274485670330767`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "Discard", 1, {
              Complex[3.4224987798606765`, -1.1458522701333511`], 
              Complex[1.3584336295287167`, -2.6274485670330767`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0001910715387554359, -0.010744451646203643`}],
            RowBox[{"{", 
              
              RowBox[{"18.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2809061262708882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3584336295287214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.627448567033079`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "Discard", 2, {
              Complex[0.2809061262708882, -1.1458522701333518`], 
              Complex[1.3584336295287214`, -2.627448567033079]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00015900347936225552`, -0.010885771638815328`}],
            RowBox[{"{", 
              
              RowBox[{"18.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.41841120976327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1537578719399622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3534970339779715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.634881633043194`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "Discard", 1, {
              Complex[3.41841120976327, -1.1537578719399622`], 
              Complex[1.3534970339779715`, -2.634881633043194]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001551557859967175, -0.0108857716388153}],
            RowBox[{"{", 
              
              RowBox[{"18.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2768185561734762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1537578719399602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3534970339779717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6348816330431903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "Discard", 2, {
              Complex[0.2768185561734762, -1.1537578719399602`], 
              Complex[1.3534970339779717`, -2.6348816330431903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001949139253619779, -0.011023998311380161`}],
            RowBox[{"{", 
              
              RowBox[{"18.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4144686707126652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.348707291872495`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "Discard", 1, {
              Complex[3.4144686707126652`, -1.1614825918531306`], 
              Complex[1.348707291872495, -2.6421453813855136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011924533999699773`, -0.01102399831138017}],
            RowBox[{"{", 
              
              RowBox[{"18.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2728760171228721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3487072918724958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "Discard", 2, {
              Complex[0.2728760171228721, -1.1614825918531306`], 
              Complex[1.3487072918724958`, -2.6421453813855136`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023080672663566127`, -0.01115932469731132}],
            RowBox[{"{", 
              
              RowBox[{"18.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.410662097155336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1690361304484036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3440554470967183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6492491374148304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "Discard", 1, {
              Complex[3.410662097155336, -1.1690361304484036`], 
              Complex[1.3440554470967183`, -2.6492491374148304`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00008335253872335272, -0.01115932469731133}],
            RowBox[{"{", 
              
              RowBox[{"18.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2690694435655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1690361304484052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3440554470967194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.649249137414832`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "Discard", 2, {
              Complex[0.2690694435655443, -1.1690361304484052`], 
              Complex[1.3440554470967194`, -2.649249137414832]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0002666713099704376, -0.01129192506568351}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4069832610263204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.176427343324966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3395333698600238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "Discard", 1, {
              Complex[3.4069832610263204`, -1.176427343324966], 
              Complex[1.3395333698600238`, -2.656201401617177]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004748795538851547, -0.011291925065683519`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.26539060743652637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1764273433249663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.339533369860022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "Discard", 2, {
              Complex[0.26539060743652637`, -1.1764273433249663`], 
              Complex[1.339533369860022, -2.656201401617177]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0003024985984786058, -0.011421957340292051`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4034246691397003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1836643421288453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3351336552455113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.663009949003302`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "Discard", 1, {
              Complex[3.4034246691397003`, -1.1836643421288453`], 
              Complex[1.3351336552455113`, -2.663009949003302]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000011660666880390631`, -0.01142195734029206}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2618320155499074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.183664342128846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3351336552455122`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6630099490033023`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "Discard", 2, {
              Complex[0.2618320155499074, -1.183664342128846], 
              Complex[1.3351336552455122`, -2.6630099490033023`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0003382807898497743, -0.011549565135816946`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.399979476133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "Discard", 1, {
              Complex[3.399979476133, -1.1907545804380442`], 
              Complex[1.330849537168034, -2.6696819135459715`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000024121524490821578`, -0.011549565135816961`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.258386822543207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "Discard", 2, {
              Complex[0.258386822543207, -1.1907545804380446`], 
              Complex[1.330849537168034, -2.6696819135459737`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00037401117206118317`, -0.011674879482187267`}],
            RowBox[{"{", 
              
              RowBox[{"18.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.396641410179813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977049272038105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3266748149775132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.67622386032944`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "Discard", 1, {
              Complex[3.396641410179813, -1.1977049272038105`], 
              Complex[1.3266748149775132`, -2.67622386032944]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00005985190670220712, -0.0116748794821873}],
            RowBox[{"{", 
              
              RowBox[{"18.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2550487565900203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1977049272038123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3266748149775125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.676223860329442`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "Discard", 2, {
              Complex[0.2550487565900203, -1.1977049272038123`], 
              Complex[1.3266748149775125`, -2.676223860329442]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0004096839693587444, -0.011798020293216674`}],
            RowBox[{"{", 
              
              RowBox[{"19.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3934047092561204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3226037905108854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "Discard", 1, {
              Complex[3.3934047092561204`, -1.204521729892243], 
              Complex[1.3226037905108854`, -2.682641847533846]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00009552470399978315, -0.01179802029321669}],
            RowBox[{"{", 
              
              RowBox[{"19.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.25181205566632714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3226037905108852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "Discard", 2, {
              Complex[0.25181205566632714`, -1.204521729892243], 
              Complex[1.3226037905108852`, -2.682641847533846]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0004452942128671779, -0.011919097624091834`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.39026406618571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3186312138329304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.688941479956369`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "Discard", 1, {
              Complex[3.39026406618571, -1.2112108690459429`], 
              Complex[1.3186312138329304`, -2.688941479956369]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00013113494750817973`, -0.011919097624091851`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.248671412595918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.318631213832932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6889414799563705`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "Discard", 2, {
              Complex[0.248671412595918, -1.2112108690459433`], 
              Complex[1.318631213832932, -2.6889414799563705`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00048083763136276157`, -0.012038212753434117`}],
            RowBox[{"{", 
              
              RowBox[{"19.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3872145810322905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2177778056554156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3147522362459452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.69512795544381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "Discard", 1, {
              Complex[3.3872145810322905`, -1.2177778056554156`], 
              Complex[1.3147522362459452`, -2.69512795544381]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00016667836600378668`, -0.01203821275343413}],
            RowBox[{"{", 
              
              RowBox[{"19.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.24562192744249728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2177778056554163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3147522362459447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6951279554438115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "Discard", 2, {
              Complex[0.24562192744249728`, -1.2177778056554163`], 
              Complex[1.3147522362459447`, -2.6951279554438115`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00051631055864956, -0.012155459118756033`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3842517196741237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2242276224707729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3109623694144825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.701206105354477`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "Discard", 1, {
              Complex[3.3842517196741237`, -1.2242276224707729`], 
              Complex[1.3109623694144825`, -2.701206105354477]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020215129329057685`, -0.012155459118756063`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.24265906608433005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2242276224707753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3109623694144812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7012061053544794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "Discard", 2, {
              Complex[0.24265906608433005`, -1.2242276224707753`], 
              Complex[1.3109623694144812`, -2.7012061053544794`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0005517098546827953, -0.012270923128725653`}],
            RowBox[{"{", 
              
              RowBox[{"19.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.381371277608826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.230565060179537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.307257449661592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7071804299643993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "Discard", 1, {
              Complex[3.381371277608826, -1.230565060179537], 
              Complex[1.307257449661592, -2.7071804299643993`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023755058932380967`, -0.012270923128725698`}],
            RowBox[{"{", 
              
              RowBox[{"19.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23977862401903308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2305650601795397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3072574496615919`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.707180429964402`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "Discard", 2, {
              Complex[0.23977862401903308`, -1.2305650601795397`], 
              Complex[1.3072574496615919`, -2.707180429964402]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0005870328381333271, -0.012384684871377618`}],
            RowBox[{"{", 
              
              RowBox[{"19.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.378569348204635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.30363360666026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7130551295714294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "Discard", 1, {
              Complex[3.378569348204635, -1.2367945492132952`], 
              Complex[1.30363360666026, -2.7130551295714294`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027287357277432973`, -0.012384684871377604`}],
            RowBox[{"{", 
              
              RowBox[{"19.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23697669461484225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3036336066602605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.71305512957143`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "Discard", 2, {
              Complex[0.23697669461484225`, -1.2367945492132955`], 
              Complex[1.3036336066602605`, -2.71305512957143]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0006222772285194125, -0.012496818734006685`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3758422947494764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3000872358777424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7188341319212634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "Discard", 1, {
              Complex[3.3758422947494764`, -1.2429202378151198`], 
              Complex[1.3000872358777424`, -2.7188341319212634`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00030811796316042246`, -0.012496818734006683`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2342496411596838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.300087235877743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.718834131921264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "Discard", 2, {
              Complex[0.2342496411596838, -1.2429202378151196`], 
              Complex[1.300087235877743, -2.718834131921264]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0006574410963760603, -0.012607393947756602`}],
            RowBox[{"{", 
              
              RowBox[{"19.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3731867257580617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2489460168942261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2966149742384296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7245211164750502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "Discard", 1, {
              Complex[3.3731867257580617`, -1.2489460168942261`], 
              Complex[1.2966149742384296`, -2.7245211164750502`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0003432818310170397, -0.012607393947756557`}],
            RowBox[{"{", 
              
              RowBox[{"19.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23159407216826933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.248946016894224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2966149742384314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.724521116475047`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "Discard", 2, {
              Complex[0.23159407216826933`, -1.248946016894224], 
              Complex[1.2966149742384314`, -2.724521116475047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.000692522820204815, -0.01271647506771889}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.370599473085614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.254875542108594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.293213678558499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.730119535953448`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "Discard", 1, {
              Complex[3.370599473085614, -1.254875542108594], 
              Complex[1.293213678558499, -2.730119535953448]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00037836355484585854`, -0.012716475067718865`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22900681949582008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2548755421085922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2932136785584984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7301195359534463`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "Discard", 2, {
              Complex[0.22900681949582008`, -1.2548755421085922`], 
              Complex[1.2932136785584984`, -2.7301195359534463`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0007275210491678762, -0.012824122397577185`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.368077572468845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2898804063769864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7356326355228924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "Discard", 1, {
              Complex[3.368077572468845, -1.2607122535464201`], 
              Complex[1.2898804063769864`, -2.7356326355228924`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00041336178380888775`, -0.01282412239757719}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22648491887905142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2898804063769855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.735632635522893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "Discard", 2, {
              Complex[0.22648491887905142`, -1.2607122535464206`], 
              Complex[1.2898804063769855`, -2.735632635522893]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0007624346706656712, -0.012930392366379339`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365618246173949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2866123988665321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7410634699329792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "Discard", 1, {
              Complex[3.365618246173949, -1.2664593933197807`], 
              Complex[1.2866123988665321`, -2.7410634699329792`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00044827540530668696`, -0.01293039236637934}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22402559258415555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2866123988665328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.741063469932979`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "Discard", 2, {
              Complex[0.22402559258415555`, -1.2664593933197807`], 
              Complex[1.2866123988665328`, -2.741063469932979]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0007972627820832085, -0.013035337863830316`}],
            RowBox[{"{", 
              
              RowBox[{"20.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3632188874800852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2721200213365205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2834070655552816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7464149188671136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "Discard", 1, {
              Complex[3.3632188874800852`, -1.2721200213365205`], 
              Complex[1.2834070655552816`, -2.7464149188671136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00048310351672427396`, -0.013035337863830291`}],
            RowBox[{"{", 
              
              RowBox[{"20.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22162623389028935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2721200213365198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2834070655552792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.746414918867112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "Discard", 2, {
              Complex[0.22162623389028935`, -1.2721200213365198`], 
              Complex[1.2834070655552792`, -2.746414918867112]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0008320046661055063, -0.013139008539518176`}],
            RowBox[{"{", 
              
              RowBox[{"20.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3608770467672016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2776970294771413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2802619706314171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7516897007297403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "Discard", 1, {
              Complex[3.3608770467672016`, -1.2776970294771413`], 
              Complex[1.2802619706314171`, -2.7516897007297403`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0005178454007465221, -0.01313900853951816}],
            RowBox[{"{", 
              
              RowBox[{"20.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21928439317740805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2776970294771406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2802619706314173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.75168970072974`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "Discard", 2, {
              Complex[0.21928439317740805`, -1.2776970294771406`], 
              Complex[1.2802619706314173`, -2.75168970072974]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0008666597690989633, -0.01324145107067403}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.358590419010691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2771748206351425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.756890385061134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "Discard", 1, {
              Complex[3.358590419010691, -1.2831931543706478`], 
              Complex[1.2771748206351425`, -2.756890385061134]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0005525005037399606, -0.01324145107067405}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21699776542089913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2771748206351434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7568903850611353`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "Discard", 2, {
              Complex[0.21699776542089913`, -1.2831931543706483`], 
              Complex[1.2771748206351434`, -2.7568903850611353`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0009012276821362639, -0.013342709402392109`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3563568325133555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2886109889360127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.274143453370581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7620194037437003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "Discard", 1, {
              Complex[3.3563568325133555`, -1.2886109889360127`], 
              Complex[1.274143453370581, -2.7620194037437003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0005870684167772646, -0.013342709402392131`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21476417892356292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.288610988936014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2741434533705815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.762019403743701`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "Discard", 2, {
              Complex[0.21476417892356292`, -1.288610988936014], 
              Complex[1.2741434533705815`, -2.762019403743701]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0009357081243044747, -0.013442824963672453`}],
            RowBox[{"{", 
              
              RowBox[{"20.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.354174238728878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2939529928328564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2711658278935796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "Discard", 1, {
              Complex[3.354174238728878, -1.2939529928328564`], 
              Complex[1.2711658278935796`, -2.7670790611410547`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0006215488589454743, -0.01344282496367245}],
            RowBox[{"{", 
              
              RowBox[{"20.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21258158513908437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.293952992832856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2711658278935793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410534`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "Discard", 2, {
              Complex[0.21258158513908437`, -1.293952992832856], 
              Complex[1.2711658278935793`, -2.7670790611410534`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0009701009279931014, -0.013541836862176838`}],
            RowBox[{"{", 
              
              RowBox[{"20.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.352040703050758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2682400154509323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919705`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "Discard", 1, {
              Complex[3.352040703050758, -1.2992215019455444`], 
              Complex[1.2682400154509323`, -2.7720715432919705`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0006559416626341028, -0.013541836862176849`}],
            RowBox[{"{", 
              
              RowBox[{"20.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21044804946096587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2682400154509332`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "Discard", 2, {
              Complex[0.21044804946096587`, -1.2992215019455449`], 
              Complex[1.2682400154509332`, -2.7720715432919714`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0010044060259022697`, -0.013639782060190293`}],
            RowBox[{"{", 
              
              RowBox[{"20.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3499543964575493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3044187370084819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2653641912632538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "Discard", 1, {
              Complex[3.3499543964575493`, -1.3044187370084819`], 
              Complex[1.2653641912632538`, -2.776998926265093]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0006902467605432894, -0.013639782060190305`}],
            RowBox[{"{", 
              
              RowBox[{"20.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20836174286775633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.304418737008481`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2653641912632545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "Discard", 2, {
              Complex[0.20836174286775633`, -1.304418737008481], 
              Complex[1.2653641912632545`, -2.776998926265093]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001038623439549764, -0.013736695533943894`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.347913587919471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2625366270577851`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "Discard", 1, {
              Complex[3.347913587919471, -1.3095468114663606`], 
              Complex[1.2625366270577851`, -2.7818631837665047`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0007244641741907946, -0.013736695533943922`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20632093432967819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2625366270577847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "Discard", 2, {
              Complex[0.20632093432967819`, -1.3095468114663624`], 
              Complex[1.2625366270577847`, -2.7818631837665064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0010727532690869516`, -0.013832610418171147`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345916637483683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.314607738651282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2597556842695194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.786666194080565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "Discard", 1, {
              Complex[3.345916637483683, -1.314607738651282], 
              Complex[1.2597556842695194`, -2.786666194080565]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0007585940037279607, -0.013832610418171114`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20432398389389064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3146077386512802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2597556842695206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7866661940805635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "Discard", 2, {
              Complex[0.20432398389389064`, -1.3146077386512802`], 
              Complex[1.2597556842695206`, -2.7866661940805635`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0011067956842600898`, -0.013927558137525544`}],
            RowBox[{"{", 
              
              RowBox[{"21.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.343961989965874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.31960343834836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2570198078392791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "Discard", 1, {
              Complex[3.343961989965874, -1.31960343834836], 
              Complex[1.2570198078392791`, -2.7914097464142906`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000792636418901126, -0.013927558137525536`}],
            RowBox[{"{", 
              
              RowBox[{"21.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2023693363760805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3196034383483597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.257019807839279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "Discard", 2, {
              Complex[0.2023693363760805, -1.3196034383483597`], 
              Complex[1.257019807839279, -2.7914097464142906`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0011407509163772365`, -0.014021568526281933`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.342048169184744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2543275205461564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "Discard", 1, {
              Complex[3.342048169184744, -1.3245357428128088`], 
              Complex[1.2543275205461564`, -2.796095546707045]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0008265916510182541, -0.014021568526281954`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20045551559495106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2543275205461566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707046`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "Discard", 2, {
              Complex[0.20045551559495106`, -1.3245357428128093`], 
              Complex[1.2543275205461566`, -2.796095546707046]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0011746192511581034`, -0.014114669937564734`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.340173772683676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3294064022937957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2516774178194212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597475`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "Discard", 1, {
              Complex[3.340173772683676, -1.3294064022937957`], 
              Complex[1.2516774178194212`, -2.8007252229597475`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0008604599857990841, -0.014114669937564727`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1985811190938835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.329406402293795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2516774178194228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "Discard", 2, {
              Complex[0.1985811190938835, -1.329406402293795], 
              Complex[1.2516774178194228`, -2.8007252229597466`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012084010223623702`, -0.014206889343195233`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.338337466890455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2490681629814273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "Discard", 1, {
              Complex[3.338337466890455, -1.3342170901139807`], 
              Complex[1.2490681629814273`, -2.805300330131515]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0008942417570033781, -0.014206889343195236`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19674481330066165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2490681629814275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "Discard", 2, {
              Complex[0.19674481330066165`, -1.3342170901139803`], 
              Complex[1.2490681629814275`, -2.805300330131515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012420966061049705`, -0.014298252425118244`}],
            RowBox[{"{", 
              
              RowBox[{"21.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.336537982671677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33896940734793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.246498482878781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.809822354646045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "Discard", 1, {
              Complex[3.336537982671677, -1.33896940734793], 
              Complex[1.246498482878781, -2.809822354646045]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000927937340745983, -0.014298252425118268`}],
            RowBox[{"{", 
              
              RowBox[{"21.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19494532908188417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3389694073479312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2464984828787806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.809822354646047`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "Discard", 2, {
              Complex[0.19494532908188417`, -1.3389694073479312`], 
              Complex[1.2464984828787806`, -2.809822354646047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012757064157781174`, -0.014388783659254776`}],
            RowBox[{"{", 
              
              RowBox[{"21.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.334774111243452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.343664887137726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2439671638639436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "Discard", 1, {
              Complex[3.334774111243452, -1.343664887137726], 
              Complex[1.2439671638639436`, -2.814292718545235]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0009615471504191562, -0.014388783659254747`}],
            RowBox[{"{", 
              
              RowBox[{"21.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19318145765365854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3436648871377261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.243967163863943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "Discard", 2, {
              Complex[0.19318145765365854`, -1.3436648871377261`], 
              Complex[1.243967163863943, -2.814292718545235]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0013092308975115037`, -0.014478506392528694`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.333044700404312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2414730480936764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323322`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "Discard", 1, {
              Complex[3.333044700404312, -1.348304998679792], 
              Complex[1.2414730480936764`, -2.818712783323322]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0009950716321524982, -0.014478506392528718`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19145204681451947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2414730480936766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323323`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "Discard", 2, {
              Complex[0.19145204681451947`, -1.348304998679793], 
              Complex[1.2414730480936766`, -2.818712783323323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0013426705261091422`, -0.014567442913731583`}],
            RowBox[{"{", 
              
              RowBox[{"21.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.331348651060044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3528911509132835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "Discard", 1, {
              Complex[3.331348651060044, -1.3528911509132835`], 
              Complex[1.2390150301144984`, -2.8230838534712275`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001028511260750182, -0.014567442913731585`}],
            RowBox[{"{", 
              
              RowBox[{"21.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18975599747025035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.352891150913283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "Discard", 2, {
              Complex[0.18975599747025035`, -1.352891150913283], 
              Complex[1.2390150301144984`, -2.8230838534712266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0013760258014105706`, -0.014655614518812506`}],
            RowBox[{"{", 
              
              RowBox[{"21.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3296849140134457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3574246959370493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2365920537085775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8274071797574867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "Discard", 1, {
              Complex[3.3296849140134457`, -1.3574246959370493`], 
              Complex[1.2365920537085775`, -2.8274071797574867`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00106186653605159, -0.014655614518812513`}],
            RowBox[{"{", 
              
              RowBox[{"21.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18809226042365237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3574246959370482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2365920537085782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.827407179757486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "Discard", 2, {
              Complex[0.18809226042365237`, -1.3574246959370482`], 
              Complex[1.2365920537085782`, -2.827407179757486]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0014092972450287077`, -0.014743041571117806`}],
            RowBox[{"{", 
              
              RowBox[{"21.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.328052486994904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.36190693217938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.234203108976306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.831683962269427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "Discard", 1, {
              Complex[3.328052486994904, -1.36190693217938], 
              Complex[1.234203108976306, -2.831683962269427]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0010951379796697235`, -0.014743041571117837`}],
            RowBox[{"{", 
              
              RowBox[{"21.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1864598334051111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3619069321793806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2342031089763061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8316839622694276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "Discard", 2, {
              Complex[0.1864598334051111, -1.3619069321793806`], 
              Complex[1.2342031089763061`, -2.8316839622694276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0014424853974241638`, -0.014829743557046794`}],
            RowBox[{"{", 
              
              RowBox[{"22.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.326450411912238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "Discard", 1, {
              Complex[3.326450411912238, -1.3663391073422075`], 
              Complex[1.2318472296343572`, -2.8359153532357357`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001128326132065191, -0.014829743557046757`}],
            RowBox[{"{", 
              
              RowBox[{"22.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18485775832244397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "Discard", 2, {
              Complex[0.18485775832244397`, -1.3663391073422058`], 
              Complex[1.2318472296343572`, -2.8359153532357344`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0014755908152793889`, -0.014915739137539854`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.324877772300485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2295234905102046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "Discard", 1, {
              Complex[3.324877772300485, -1.3707224211391649`], 
              Complex[1.2295234905102046`, -2.8401024596493727`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0011614315499204157`, -0.014915739137539881`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18328511871069184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2295234905102042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "Discard", 2, {
              Complex[0.18328511871069184`, -1.3707224211391664`], 
              Complex[1.2295234905102042`, -2.8401024596493754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0015086140691408065`, -0.015001046195773086`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3233336909542834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3750580278450637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2272310052160105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "Discard", 1, {
              Complex[3.3233336909542834`, -1.3750580278450637`], 
              Complex[1.2272310052160105`, -2.8442463457079334`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0011944548037818126`, -0.015001046195773087`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18174103736449077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3750580278450635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2272310052160111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "Discard", 2, {
              Complex[0.18174103736449077`, -1.3750580278450635`], 
              Complex[1.2272310052160111`, -2.8442463457079334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0015415557413008532`, -0.015085681881391966`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.321817327727244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2249689239865722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8483480350867407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "Discard", 1, {
              Complex[3.321817327727244, -1.3793470386724547`], 
              Complex[1.2249689239865722`, -2.8483480350867407`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012273964759418551`, -0.01508568188139198}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18022467413745052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.224968923986572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8483480350867416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "Discard", 2, {
              Complex[0.18022467413745052`, -1.3793470386724553`], 
              Complex[1.224968923986572, -2.8483480350867416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001574416423894492, -0.015169662651586036`}],
            RowBox[{"{", 
              
              RowBox[{"22.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3203278774842637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.383590523989566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2227364316674654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "Discard", 1, {
              Complex[3.3203278774842637`, -1.383590523989566], 
              Complex[1.2227364316674654`, -2.8524085130586]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012602571585355314`, -0.015169662651586084`}],
            RowBox[{"{", 
              
              RowBox[{"22.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17873522389447033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3835905239895683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2227364316674634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "Discard", 2, {
              Complex[0.17873522389447033`, -1.3835905239895683`], 
              Complex[1.2227364316674634`, -2.8524085130586028`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0016071967171888304`, -0.015253004309273212`}],
            RowBox[{"{", 
              
              RowBox[{"22.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3188645681940967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3877895153923996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.220532745840933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8564287284726504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "Discard", 1, {
              Complex[3.3188645681940967`, -1.3877895153923996`], 
              Complex[1.220532745840933, -2.8564287284726504`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0012930374518298536`, -0.015253004309273234`}],
            RowBox[{"{", 
              
              RowBox[{"22.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17727191460430375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3877895153924003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2205327458409323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8564287284726513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "Discard", 2, {
              Complex[0.17727191460430375`, -1.3877895153924003`], 
              Complex[1.2205327458409323`, -2.8564287284726513`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0016398972280450815`, -0.015335722038637872`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3174266591507107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3919450076426472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2183571150782422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "Discard", 1, {
              Complex[3.3174266591507107`, -1.3919450076426472`], 
              Complex[1.2183571150782422`, -2.860409595603666]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0013257379626860678`, -0.015335722038637868`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1758340055609178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.391945007642646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.218357115078243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "Discard", 2, {
              Complex[0.1758340055609178, -1.391945007642646], 
              Complex[1.218357115078243, -2.860409595603666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001672518568536205, -0.015417830438241732`}],
            RowBox[{"{", 
              
              RowBox[{"22.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3160134393130587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.396057960481959`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2162088173083034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.864351995882056`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "Discard", 1, {
              Complex[3.3160134393130587`, -1.396057960481959], 
              Complex[1.2162088173083034`, -2.864351995882056]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[
            PointBox[{-0.0013583593031772016`, -0.015417830438241704`}],
            RowBox[{"{", 
              
              RowBox[{"22.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17442078572326566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3960579604819585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2162088173083037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8643519958820556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "Discard", 2, {
              Complex[0.17442078572326566`, -1.3960579604819585`], 
              Complex[1.2162088173083037`, -2.8643519958820556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0017050613547043964`, -0.01549934355190653}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3146242257538696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4001293003321456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.214087158293307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "Discard", 1, {
              Complex[3.3146242257538696`, -1.4001293003321456`], 
              Complex[1.214087158293307, -2.8682567795138803`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0013909020893454083`, -0.015499343551906526`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17303157216407558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4001293003321469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2140871582933066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "Discard", 2, {
              Complex[0.17303157216407558`, -1.4001293003321469`], 
              Complex[1.2140871582933066`, -2.8682567795138803`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001737526205444115, -0.015580274897547545`}],
            RowBox[{"{", 
              
              RowBox[{"22.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.313258362208889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2119914702029877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "Discard", 1, {
              Complex[3.313258362208889, -1.4041599218900036`], 
              Complex[1.2119914702029877`, -2.8721247669993084`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001423366940085132, -0.015580274897547566`}],
            RowBox[{"{", 
              RowBox[{
               "22.999999999999996`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17166570861909555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2119914702029881`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "Discard", 2, {
              Complex[0.17166570861909555`, -1.4041599218900036`], 
              Complex[1.2119914702029881`, -2.8721247669993084`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.001769913741498774, -0.01566063749412107}],
            
            RowBox[{"{", 
              
              RowBox[{"23.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.311915217718847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.408150689624686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.209921110279896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.875956750557249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "Discard", 1, {
              Complex[3.311915217718847, -1.408150689624686], 
              Complex[1.209921110279896, -2.875956750557249]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0014557544761397692`, -0.015660637494121023`}],
            RowBox[{"{", 
              RowBox[{
               "23.099999999999998`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17032256412905356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4081506896246843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2099211102798964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.875956750557247`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "Discard", 2, {
              Complex[0.17032256412905356`, -1.4081506896246843`], 
              Complex[1.2099211102798964`, -2.875956750557247]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018022245845594237`, -0.01574044388683347}],
            RowBox[{"{", 
              
              RowBox[{"23.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.310594185357048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.41210243918487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2078754595887096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8797534954631456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "Discard", 1, {
              Complex[3.310594185357048, -1.41210243918487], 
              Complex[1.2078754595887096`, -2.8797534954631456`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0014880653192004705`, -0.01574044388683346}],
            RowBox[{"{", 
              RowBox[{
               "23.199999999999996`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16900153176725363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4121024391848713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2078754595887078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.879753495463146`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "Discard", 2, {
              Complex[0.16900153176725363`, -1.4121024391848713`], 
              Complex[1.2078754595887078`, -2.879753495463146]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018344593564559868`, -0.01581970617074694}],
            RowBox[{"{", 
              
              RowBox[{"23.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3092946810361643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.205853921843281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.883515741306371`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "Discard", 1, {
              Complex[3.3092946810361643`, -1.4160159787223123`], 
              Complex[1.205853921843281, -2.883515741306371]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001520300091097007, -0.015819706170746926`}],
            RowBox[{"{", 
              RowBox[{
               "23.299999999999997`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1677020274463709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.205853921843282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8835157413063706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "Discard", 2, {
              Complex[0.1677020274463709, -1.4160159787223117`], 
              Complex[1.205853921843282, -2.8835157413063706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018666186784317682`, -0.015898436012903153`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3080161423883445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "Discard", 1, {
              Complex[3.3080161423883445`, -1.419892090137794], 
              Complex[1.203855922305636, -2.8872442031730206`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0015524594130727986`, -0.01589843601290317}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1664234887985512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "Discard", 2, {
              Complex[0.1664234887985512, -1.419892090137794], 
              Complex[1.203855922305636, -2.8872442031730206`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001898703170493119, -0.015976644673077044`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.306758027713268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4237315302550264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2018809067516425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.890939572759507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "Discard", 1, {
              Complex[3.306758027713268, -1.4237315302550264`], 
              Complex[1.2018809067516425`, -2.890939572759507]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0015845439051341526`, -0.015976644673077044`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1651653741234745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4237315302550273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2018809067516416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8909395727595073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "Discard", 2, {
              Complex[0.1651653741234745, -1.4237315302550273`], 
              Complex[1.2018809067516416`, -2.8909395727595073`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0019307134508275378`, -0.016054343023262373`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3055198149892218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1999283404985257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "Discard", 1, {
              Complex[3.3055198149892218`, -1.4275350319275477`], 
              Complex[1.1999283404985257`, -2.8946025194218263`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0016165541854685885`, -0.016054343023262415`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1639271613994279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1999283404985253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "Discard", 2, {
              Complex[0.1639271613994279, -1.4275350319275484`], 
              Complex[1.1999283404985253`, -2.8946025194218263`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001962650135283316, -0.016131541565982014`}],
            RowBox[{"{", 
              
              RowBox[{"23.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.304301000942701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650046`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "Discard", 1, {
              Complex[3.304301000942701, -1.4313033050832549`], 
              Complex[1.1979977074898187`, -2.8982336911650046`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001648490869924329, -0.016131541565981983`}],
            RowBox[{"{", 
              
              RowBox[{"23.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16270834735290776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650033`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "Discard", 2, {
              Complex[0.16270834735290776`, -1.4313033050832542`], 
              Complex[1.1979977074898187`, -2.8982336911650033`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001994513836904741, -0.016208250451507842`}],
            RowBox[{"{", 
              
              RowBox[{"23.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3031011001724133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4350370377108632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.196088509433674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.901833715576858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "Discard", 1, {
              Complex[3.3031011001724133`, -1.4350370377108632`], 
              Complex[1.196088509433674, -2.901833715576858]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.001680354571545746, -0.01620825045150787}],
            
            RowBox[{"{", 
              
              RowBox[{"23.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16150844658262048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4350370377108643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1960885094336744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9018337155768594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "Discard", 2, {
              Complex[0.16150844658262048`, -1.4350370377108643`], 
              Complex[1.1960885094336744`, -2.9018337155768594`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0020263051655183975`, -0.016284479494068554`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3019196443238705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.194200264990824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.905403200709853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "Discard", 1, {
              Complex[3.3019196443238705`, -1.438736896792191], 
              Complex[1.194200264990824, -2.905403200709853]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001712145900159428, -0.016284479494068548`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16032699073407702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1942002649908234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9054032007098534`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "Discard", 2, {
              Complex[0.16032699073407702`, -1.438736896792191], 
              Complex[1.1942002649908234`, -2.9054032007098534`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0020580247273647816`, -0.016360238187116228`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3007561813111055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4424035291838815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.908942735914548`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "Discard", 1, {
              Complex[3.3007561813111055`, -1.4424035291838815`], 
              Complex[1.192332509008784, -2.908942735914548]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0017438654620057991`, -0.016360238187116263`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15916352772131243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.442403529183883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9089427359145503`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "Discard", 2, {
              Complex[0.15916352772131243`, -1.442403529183883], 
              Complex[1.192332509008784, -2.9089427359145503`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002089673124771745, -0.016435535717718032`}],
            RowBox[{"{", 
              
              RowBox[{"24.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2996102745823035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.446037562451929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.190484791799119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "Discard", 1, {
              Complex[3.2996102745823035`, -1.446037562451929], 
              Complex[1.190484791799119, -2.912452892627875]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0017755138594127767`, -0.01643553571771804}],
            RowBox[{"{", 
              
              RowBox[{"24.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15801762099250957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4460375624519293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1904847917991184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "Discard", 2, {
              Complex[0.15801762099250957`, -1.4460375624519293`], 
              Complex[1.1904847917991184`, -2.912452892627875]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0021212509558655303`, -0.016510380980132532`}],
            RowBox[{"{", 
              
              RowBox[{"24.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.298481502426376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1886566784549102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9159342251191687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "Discard", 1, {
              Complex[3.298481502426376, -1.4496396056620289`], 
              Complex[1.1886566784549102`, -2.9159342251191687`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018070916905065352`, -0.016510380980132487`}],
            RowBox[{"{", 
              
              RowBox[{"24.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15688884883658272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.188656678454911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.915934225119166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "Discard", 2, {
              Complex[0.15688884883658272`, -1.4496396056620269`], 
              Complex[1.188656678454911, -2.915934225119166]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0021527588143158464`, -0.016584782588626574`}],
            RowBox[{"{", 
              
              RowBox[{"24.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2973694573177923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4532102501286348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1868477482057302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "Discard", 1, {
              Complex[3.2973694573177923`, -1.4532102501286348`], 
              Complex[1.1868477482057302`, -2.919387271196738]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018385995489568817`, -0.016584782588626595`}],
            RowBox[{"{", 
              
              RowBox[{"24.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15577680372799887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4532102501286346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1868477482057311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "Discard", 2, {
              Complex[0.15577680372799887`, -1.4532102501286346`], 
              Complex[1.1868477482057311`, -2.919387271196738]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0021841972891121944`, -0.01665874888958386}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.296273745297108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4567500701253233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1850575938076657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9228125528774775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "Discard", 1, {
              Complex[3.296273745297108, -1.4567500701253233`], 
              Complex[1.1850575938076657`, -2.9228125528774775`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0018700380237532135`, -0.01665874888958386}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1546810917073148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.456750070125323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1850575938076662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.922812552877478`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "Discard", 2, {
              Complex[0.1546810917073148, -1.456750070125323], 
              Complex[1.1850575938076662`, -2.922812552877478]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002215566964368169, -0.016732287972951485`}],
            RowBox[{"{", 
              
              RowBox[{"24.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2951939853849117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1832858209661052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.926210577021858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "Discard", 1, {
              Complex[3.2951939853849117`, -1.4602596235588936`], 
              Complex[1.1832858209661052`, -2.926210577021858]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0019014076990091894`, -0.016732287972951513`}],
            RowBox[{"{", 
              
              RowBox[{"24.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1536013317951177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1832858209661048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.92621057702186`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "Discard", 2, {
              Complex[0.1536013317951177, -1.4602596235588952`], 
              Complex[1.1832858209661048`, -2.92621057702186]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002246868419151228, -0.01680540768306919}],
            
            RowBox[{"{", 
              
              RowBox[{"24.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2941298090270217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4637394526094694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1815320477892093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "Discard", 1, {
              Complex[3.2941298090270217`, -1.4637394526094694`], 
              Complex[1.1815320477892093`, -2.9295818359364927`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001932709153792285, -0.016805407683069193`}],
            RowBox[{"{", 
              
              RowBox[{"24.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15253715543722762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4637394526094687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.181532047789208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "Discard", 2, {
              Complex[0.15253715543722762`, -1.4637394526094687`], 
              Complex[1.181532047789208, -2.9295818359364927`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002278102227335843, -0.01687811562891998}],
            
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2930808595689487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4671900843386574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1797959042700832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9329268079462416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "Discard", 1, {
              Complex[3.2930808595689487`, -1.4671900843386574`], 
              Complex[1.1797959042700832`, -2.9329268079462416`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.001963942961976872, -0.016878115628919967`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15148820597915524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4671900843386563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.179795904270083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.932926807946241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "Discard", 2, {
              Complex[0.15148820597915524`, -1.4671900843386563`], 
              Complex[1.179795904270083, -2.932926807946241]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0023092689574773844`, -0.01695041919384058}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2920467917577914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.178077031795879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.936245957937766`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "Discard", 1, {
              Complex[3.2920467917577914`, -1.470612031267736], 
              Complex[1.178077031795879, -2.936245957937766]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.001995109692118418, -0.01695041919384056}],
            
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1504541381679981`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1780770317958789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.936245957937765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "Discard", 2, {
              Complex[0.1504541381679981, -1.470612031267735], 
              Complex[1.1780770317958789`, -2.936245957937765]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0023403691727053523`, -0.017022325544724905`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.291027271269856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.474005791927643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "Discard", 1, {
              Complex[3.291027271269856, -1.474005791927643], 
              Complex[1.1763750826821242`, -2.9395397378762267`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002026209907346351, -0.017022325544724888`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1494346176800629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4740057919276426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "Discard", 2, {
              Complex[0.1494346176800629, -1.4740057919276426`], 
              Complex[1.1763750826821242`, -2.9395397378762262`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0023714034306338374`, -0.01709384164075301}],
            RowBox[{"{", 
              
              RowBox[{"24.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2900219742624115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4773718513824372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1746897197307482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9428085872967427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "Discard", 1, {
              Complex[3.2900219742624115`, -1.4773718513824372`], 
              Complex[1.1746897197307482`, -2.9428085872967427`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0020572441652748617`, -0.017093841640753}],
            
            RowBox[{"{", 
              
              RowBox[{"24.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1484293206726183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.477371851382437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1746897197307484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.942808587296742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "Discard", 2, {
              Complex[0.1484293206726183, -1.477371851382437], 
              Complex[1.1746897197307484`, -2.942808587296742]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0024023722832877815`, -0.017164974241674985`}],
            RowBox[{"{", 
              
              RowBox[{"25.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2890305869481264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "Discard", 1, {
              Complex[3.2890305869481264`, -1.4807106817278028`], 
              Complex[1.1730206158103629`, -2.946052933772111]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002088213017928795, -0.017164974241675002`}],
            RowBox[{"{", 
              
              RowBox[{"25.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1474379333583333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "Discard", 2, {
              Complex[0.1474379333583333, -1.4807106817278035`], 
              Complex[1.1730206158103629`, -2.946052933772111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0024332762770429956`, -0.017235729915676196`}],
            RowBox[{"{", 
              
              RowBox[{"25.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.288052805190806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4840227425660197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1713674534574503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "Discard", 1, {
              Complex[3.288052805190806, -1.4840227425660197`], 
              Complex[1.1713674534574503`, -2.9492731933581573`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002119117011683995, -0.017235729915676196`}],
            RowBox[{"{", 
              
              RowBox[{"25.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14646015160101253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.48402274256602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1713674534574505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "Discard", 2, {
              Complex[0.14646015160101253`, -1.48402274256602], 
              Complex[1.1713674534574505`, -2.9492731933581573`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002464115952579975, -0.01730611504685094}],
            
            RowBox[{"{", 
              
              RowBox[{"25.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2870883341211625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4873084814587765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1697299244972095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9524697710180425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "Discard", 1, {
              Complex[3.2870883341211625`, -1.4873084814587765`], 
              Complex[1.1697299244972095`, -2.9524697710180425`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0021499566872209778`, -0.017306115046850937`}],
            RowBox[{"{", 
              
              RowBox[{"25.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14549568053136955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.487308481458776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.16972992449721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9524697710180416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "Discard", 2, {
              Complex[0.14549568053136955`, -1.487308481458776], 
              Complex[1.16972992449721, -2.9524697710180416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002494891844848537, -0.017376135842306305`}],
            RowBox[{"{", 
              
              RowBox[{"25.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.28613688777145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4905683343590643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1681077296829168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9556430610267057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "Discard", 1, {
              Complex[3.28613688777145, -1.4905683343590643`], 
              Complex[1.1681077296829168`, -2.9556430610267057`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002180732579489568, -0.01737613584230626}],
            
            RowBox[{"{", 
              
              RowBox[{"25.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1445442341816557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.490568334359063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.168107729682917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.955643061026704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "Discard", 2, {
              Complex[0.1445442341816557, -1.490568334359063], 
              Complex[1.168107729682917, -2.955643061026704]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0025256044830437646`, -0.017445798338919506`}],
            RowBox[{"{", 
              
              RowBox[{"25.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.285198188727837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1665005783527111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9587934473565816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "Discard", 1, {
              Complex[3.285198188727837, -1.4938027260233295`], 
              Complex[1.1665005783527111`, -2.9587934473565816`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002211445217684758, -0.017445798338919533`}],
            RowBox[{"{", 
              
              RowBox[{"25.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14360553513804464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1665005783527118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.958793447356582`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "Discard", 2, {
              Complex[0.14360553513804464`, -1.4938027260233295`], 
              Complex[1.1665005783527118`, -2.958793447356582]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0025562543905908617`, -0.017515108409768443`}],
            RowBox[{"{", 
              
              RowBox[{"25.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.284271967799523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4970120704049878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1649081881027983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "Discard", 1, {
              Complex[3.284271967799523, -1.4970120704049878`], 
              Complex[1.1649081881027983`, -2.9619213040456414`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0022420951252318647`, -0.017515108409768443`}],
            RowBox[{"{", 
              
              RowBox[{"25.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1426793142097304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4970120704049876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1649081881027992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "Discard", 2, {
              Complex[0.1426793142097304, -1.4970120704049876`], 
              Complex[1.1649081881027992`, -2.9619213040456414`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0025868420851393454`, -0.01758407177025441}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.283357963703603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.500196771030314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1633302844761357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "Discard", 1, {
              Complex[3.283357963703603, -1.500196771030314], 
              Complex[1.1633302844761357`, -2.965026995548729]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002272682819780332, -0.017584071770254388`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14176531011381055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5001967710303135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1633302844761368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "Discard", 2, {
              Complex[0.14176531011381055`, -1.5001967710303135`], 
              Complex[1.1633302844761368`, -2.965026995548729]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0026173680785646224`, -0.017652693983935347`}],
            RowBox[{"{", 
              
              RowBox[{"25.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2824559227648207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1617666006657197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.968110877073136`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "Discard", 1, {
              Complex[3.2824559227648207`, -1.5033572213576796`], 
              Complex[1.1617666006657197`, -2.968110877073136]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0023032088132055955`, -0.017652693983935354`}],
            RowBox[{"{", 
              
              RowBox[{"25.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14086326917502792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.161766600665721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9681108770731357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "Discard", 2, {
              Complex[0.14086326917502792`, -1.5033572213576796`], 
              Complex[1.161766600665721, -2.9681108770731357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0026478328769767617`, -0.017720980468085384`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2815655986293515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5064938051210213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1602168772316634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9711732948992347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "Discard", 1, {
              Complex[3.2815655986293515`, -1.5064938051210213`], 
              Complex[1.1602168772316634`, -2.9711732948992347`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0023336736116177847`, -0.01772098046808537}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13997294503955765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5064938051210208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.160216877231663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9711732948992333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "Discard", 2, {
              Complex[0.13997294503955765`, -1.5064938051210208`], 
              Complex[1.160216877231663, -2.9711732948992333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0026782369807358797`, -0.01778893649899673}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.280686751991847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1586808618312865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "Discard", 1, {
              Complex[3.280686751991847, -1.5096068966583966`], 
              Complex[1.1586808618312865`, -2.974214586687023]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002364077715376918, -0.01778893649899674}],
            
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13909409840205325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.158680861831286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "Discard", 2, {
              Complex[0.13909409840205325`, -1.5096068966583966`], 
              Complex[1.158680861831286, -2.974214586687023]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002708580884472762, -0.017856567217037836`}],
            RowBox[{"{", 
              
              RowBox[{"26.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.279819150335005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.512696861226397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1571583089615178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "Discard", 1, {
              Complex[3.279819150335005, -1.512696861226397], 
              Complex[1.1571583089615178`, -2.9772350817692788`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002394421619113789, -0.017856567217037836`}],
            RowBox[{"{", 
              
              RowBox[{"26.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13822649674521148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5126968612263973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1571583089615174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "Discard", 2, {
              Complex[0.13822649674521148`, -1.5126968612263973`], 
              Complex[1.1571583089615174`, -2.9772350817692788`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0027388650771151173`, -0.017923877631481656`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2789625676809804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5157640553011698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1556489797129244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.980235101432074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "Discard", 1, {
              Complex[3.2789625676809804`, -1.5157640553011698`], 
              Complex[1.1556489797129244`, -2.980235101432074]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0024247058117561108`, -0.01792387763148165}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13736991409118712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.515764055301169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1556489797129252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9802351014320725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "Discard", 2, {
              Complex[0.13736991409118712`, -1.515764055301169], 
              Complex[1.1556489797129252`, -2.9802351014320725`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0027690900419181964`, -0.017990872625116557`}],
            RowBox[{"{", 
              
              RowBox[{"26.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.278116784354001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.518808826866739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1541526415347505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9832149591832895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "Discard", 1, {
              Complex[3.278116784354001, -1.518808826866739], 
              Complex[1.1541526415347505`, -2.9832149591832895`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002454930776559216, -0.017990872625116564`}],
            RowBox[{"{", 
              
              RowBox[{"26.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13652413076420825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5188088268667397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.15415264153475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.98321495918329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "Discard", 2, {
              Complex[0.13652413076420825`, -1.5188088268667397`], 
              Complex[1.15415264153475, -2.98321495918329]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002799256256499719, -0.018057556958651483`}],
            RowBox[{"{", 
              
              RowBox[{"26.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.277281586753582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.152669068010364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "Discard", 1, {
              Complex[3.277281586753582, -1.5218315156912805`], 
              Complex[1.152669068010364, -2.9861749610097594`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0024850969911407368`, -0.0180575569586515}],
            RowBox[{"{", 
              
              RowBox[{"26.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13568893316378858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1526690680103642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "Discard", 2, {
              Complex[0.13568893316378858`, -1.5218315156912807`], 
              Complex[1.1526690680103642`, -2.9861749610097594`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0028293641928783253`, -0.018123935274926745`}],
            RowBox[{"{", 
              
              RowBox[{"26.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2764567671377804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "Discard", 1, {
              Complex[3.2764567671377804`, -1.5248324535919475`], 
              Complex[1.1511980386425853`, -2.9891154056236187`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0025152049275193643`, -0.018123935274926766`}],
            RowBox[{"{", 
              
              RowBox[{"26.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13486411354798725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "Discard", 2, {
              Complex[0.13486411354798725`, -1.5248324535919475`], 
              Complex[1.1511980386425853`, -2.9891154056236187`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0028594143175154317`, -0.01819001210294039}],
            RowBox[{"{", 
              
              RowBox[{"26.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2756421234159636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5278119646888435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1497393386483465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.992036584698415`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "Discard", 1, {
              Complex[3.2756421234159636`, -1.5278119646888435`], 
              Complex[1.1497393386483465`, -2.992036584698415]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002545255052156498, -0.018190012102940394`}],
            RowBox[{"{", 
              
              RowBox[{"26.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13404946982617044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5278119646888442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1497393386483457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9920365846984165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "Discard", 2, {
              Complex[0.13404946982617044`, -1.5278119646888442`], 
              Complex[1.1497393386483457`, -2.9920365846984165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0028894070913600615`, -0.01825579186170027}],
            RowBox[{"{", 
              
              RowBox[{"26.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.274837458950583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5307703656486717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1482927587622176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830954994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "Discard", 1, {
              Complex[3.274837458950583, -1.5307703656486717`], 
              Complex[1.1482927587622176`, -2.9949387830954994`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002575247826001098, -0.018255791861700267`}],
            RowBox[{"{", 
              
              RowBox[{"26.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1332448053607902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.530770365648672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1482927587622171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830955003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "Discard", 2, {
              Complex[0.1332448053607902, -1.530770365648672], 
              Complex[1.1482927587622171`, -2.9949387830955003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0029193429698960846`, -0.018321278863910752`}],
            RowBox[{"{", 
              
              RowBox[{"26.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.274042582367506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5337079659185715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1468580950483382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "Discard", 1, {
              Complex[3.274042582367506, -1.5337079659185715`], 
              Complex[1.1468580950483382`, -2.997822279081166]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0026051837045371075`, -0.01832127886391077}],
            RowBox[{"{", 
              
              RowBox[{"26.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13244992877771303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.533707965918572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1468580950483385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "Discard", 2, {
              Complex[0.13244992877771303`, -1.533707965918572], 
              Complex[1.1468580950483385`, -2.997822279081167]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0029492224031918437`, -0.018386477319502693`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.273257307374448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1454351487203243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0006873445350215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "Discard", 1, {
              Complex[3.273257307374448, -1.5366250679506237`], 
              Complex[1.1454351487203243`, -3.0006873445350215`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002635063137832867, -0.018386477319502693`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13166465378465506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1454351487203238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.000687344535021`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "Discard", 2, {
              Complex[0.13166465378465506`, -1.5366250679506237`], 
              Complex[1.1454351487203238`, -3.000687344535021]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.002979045835951909, -0.01845139133901432}],
            
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.272481452587111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1440237259687367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.003534245149988`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "Discard", 1, {
              Complex[3.272481452587111, -1.5395219674174738`], 
              Complex[1.1440237259687367`, -3.003534245149988]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.002664886570592925, -0.0184513913390143}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13088879899731687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.144023725968737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0035342451499867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "Discard", 2, {
              Complex[0.13088879899731687`, -1.5395219674174727`], 
              Complex[1.144023725968737, -3.0035342451499867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003008813707570377, -0.01851602493683158}],
            
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.271714841362621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.542398953419513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1426236377957488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "Discard", 1, {
              Complex[3.271714841362621, -1.542398953419513], 
              Complex[1.1426236377957488`, -3.0063632406243794`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0026946544422113998`, -0.018516024936831566`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13012218777282775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5423989534195135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1426236377957477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "Discard", 2, {
              Complex[0.13012218777282775`, -1.5423989534195135`], 
              Complex[1.1426236377957477`, -3.0063632406243785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003038526452185549, -0.01858038203429369}],
            
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2709573016399287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5452563086839952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1412346998566438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846389`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "Discard", 1, {
              Complex[3.2709573016399287`, -1.5452563086839952`], 
              Complex[1.1412346998566438`, -3.009174584846389]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0027243671868266077`, -0.01858038203429371}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12936464805013348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545256308683994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1412346998566436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "Discard", 2, {
              Complex[0.12936464805013348`, -1.545256308683994], 
              Complex[1.1412346998566436`, -3.009174584846388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00306818449873657, -0.018644466462672028`}],
            RowBox[{"{", 
              
              RowBox[{"27.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270208665786776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.548094309756492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1398567323078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0119685260713935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "Discard", 1, {
              Complex[3.270208665786776, -1.548094309756492], 
              Complex[1.1398567323078, -3.0119685260713935`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0027540252333775653`, -0.018644466462672}],
            
            RowBox[{"{", 
              
              RowBox[{"27.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12861601219698304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5480943097564914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1398567323078006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0119685260713926`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "Discard", 2, {
              Complex[0.12861601219698304`, -1.5480943097564914`], 
              Complex[1.1398567323078006`, -3.0119685260713926`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0030977882710199554`, -0.018708281966027293`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2694687704529923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5509132271850388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1384895596608702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.014745307092387`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "Discard", 1, {
              Complex[3.2694687704529923`, -1.5509132271850388`], 
              Complex[1.1384895596608702`, -3.014745307092387]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0027836290056610074`, -0.018708281966027293`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12787611686319877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5509132271850385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1384895596608695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0147453070923866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "Discard", 2, {
              Complex[0.12787611686319877`, -1.5509132271850385`], 
              Complex[1.1384895596608695`, -3.0147453070923866`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0031273381877484985`, -0.018771832203952107`}],
            RowBox[{"{", 
              
              RowBox[{"27.499999999999993`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.268737456429699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1371330106428055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0175051654038723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "Discard", 1, {
              Complex[3.268737456429699, -1.5537133256973044`], 
              Complex[1.1371330106428055`, -3.0175051654038723`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0028131789223896325`, -0.018771832203952152`}],
            RowBox[{"{", 
              
              RowBox[{"27.499999999999993`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12714480283990298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1371330106428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.017505165403874`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "Discard", 2, {
              Complex[0.12714480283990298`, -1.5537133256973077`], 
              Complex[1.1371330106428, -3.017505165403874]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0031568346626097165`, -0.018835120754203866`}],
            RowBox[{"{", 
              
              RowBox[{"27.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.268014568514247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.55649486437111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1357869180615132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.020248333359523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "Discard", 1, {
              Complex[3.268014568514247, -1.55649486437111], 
              Complex[1.1357869180615132`, -3.020248333359523]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0028426753972507586`, -0.018835120754203842`}],
            RowBox[{"{", 
              
              RowBox[{"27.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12642191492445268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5564948643711098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1357869180615123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0202483333595227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "Discard", 2, {
              Complex[0.12642191492445268`, -1.5564948643711098`], 
              Complex[1.1357869180615123`, -3.0202483333595227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00318627810432549, -0.018898151115233127`}],
            RowBox[{"{", 
              
              RowBox[{"27.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.267299955380531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1344511186768103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0229750383238807`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "Discard", 1, {
              Complex[3.267299955380531, -1.559258096798595], 
              Complex[1.1344511186768103`, -3.0229750383238807`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00287211883896649, -0.018898151115233096`}],
            RowBox[{"{", 
              
              RowBox[{"27.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12570730179073827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1344511186768111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.02297503832388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "Discard", 2, {
              Complex[0.12570730179073827`, -1.559258096798594], 
              Complex[1.1344511186768111`, -3.02297503832388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0032156689167121082`, -0.018960926708613303`}],
            RowBox[{"{", 
              
              RowBox[{"27.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2665934694544774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5620032712443408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1331254530764636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "Discard", 1, {
              Complex[3.2665934694544774`, -1.5620032712443408`], 
              Complex[1.1331254530764636`, -3.0256855028184027`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00290150965135311, -0.01896092670861327}],
            RowBox[{"{", 
              
              RowBox[{"27.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12500081586468456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5620032712443406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1331254530764638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "Discard", 2, {
              Complex[0.12500081586468456`, -1.5620032712443406`], 
              Complex[1.1331254530764638`, -3.0256855028184018`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003245007498740545, -0.01902345088137513}],
            
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.265894966794422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1318097655570643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "Discard", 1, {
              Complex[3.265894966794422, -1.5647306307976763`], 
              Complex[1.1318097655570643`, -3.028379944662053]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0029308482333815773`, -0.019023450881375133`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12430231320462909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.131809765557065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "Discard", 2, {
              Complex[0.12430231320462909`, -1.5647306307976756`], 
              Complex[1.131809765557065, -3.028379944662053]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003274294244597022, -0.01908572690825176}],
            
            RowBox[{"{", 
              
              RowBox[{"27.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2652043069761856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1305039040095175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "Discard", 1, {
              Complex[3.2652043069761856`, -1.5674404135194786`], 
              Complex[1.1305039040095175`, -3.0310585771067586`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0029601349792378567`, -0.019085726908251603`}],
            RowBox[{"{", 
              RowBox[{
               "27.999999999999996`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1236116533863979`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1305039040095248`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "Discard", 2, {
              Complex[0.1236116533863979, -1.5674404135194724`], 
              Complex[1.1305039040095248`, -3.0310585771067524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0033035295437438775`, -0.019147757993837337`}],
            RowBox[{"{", 
              
              RowBox[{"28.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2645213529825936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1292077198089117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.03372160896789`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "Discard", 1, {
              Complex[3.2645213529825936`, -1.5701328525836726`], 
              Complex[1.1292077198089117`, -3.03372160896789]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.002989370278384846, -0.019147757993837437`}],
            RowBox[{"{", 
              RowBox[{
               "28.099999999999998`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12292869939280154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1292077198089157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0337216089678942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "Discard", 2, {
              Complex[0.12292869939280154`, -1.5701328525836726`], 
              Complex[1.1292077198089157`, -3.0337216089678942`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003332713780979884, -0.019209547274663886`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2638459710972687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5728081764136679`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1279210677086156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.036369244750015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "Discard", 1, {
              Complex[3.2638459710972687`, -1.5728081764136679`], 
              Complex[1.1279210677086156`, -3.036369244750015]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0030185545156209445`, -0.019209547274663875`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12225331750747458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5728081764136674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1279210677086149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0363692447500137`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "Discard", 2, {
              Complex[0.12225331750747458`, -1.5728081764136674`], 
              Complex[1.1279210677086149`, -3.0363692447500137`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0033618473365014836`, -0.01927109782120015}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2631780308024685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.575466608813974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.126643805738343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.03900168476816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "Discard", 1, {
              Complex[3.2631780308024685`, -1.575466608813974], 
              Complex[1.126643805738343, -3.03900168476816]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003047688071142509, -0.019271097821200175`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12158537721267502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754666088139742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1266438057383434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.039001684768161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "Discard", 2, {
              Complex[0.12158537721267502`, -1.5754666088139742`], 
              Complex[1.1266438057383434`, -3.039001684768161]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0033909305859629764`, -0.01933241263977583}],
            RowBox[{"{", 
              
              RowBox[{"28.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2625174046808185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5781083690971809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1253757951060703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.041619125264729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "Discard", 1, {
              Complex[3.2625174046808185`, -1.5781083690971809`], 
              Complex[1.1253757951060703`, -3.041619125264729]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0030767713206040037`, -0.01933241263977585}],
            RowBox[{"{", 
              
              RowBox[{"28.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12092475109102498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5781083690971813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1253757951060699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.04161912526473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "Discard", 2, {
              Complex[0.12092475109102498`, -1.5781083690971813`], 
              Complex[1.1253757951060699`, -3.04161912526473]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003419963900537017, -0.019393494674434086`}],
            RowBox[{"{", 
              
              RowBox[{"28.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2618639683207284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5807336722064977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1241169001035878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0442217585222795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "Discard", 1, {
              Complex[3.2618639683207284`, -1.5807336722064977`], 
              Complex[1.1241169001035878`, -3.0442217585222795`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0031058046351780384`, -0.01939349467443406}],
            RowBox[{"{", 
              
              RowBox[{"28.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12027131473093523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.580733672206497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.124116900103588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0442217585222786`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "Discard", 2, {
              Complex[0.12027131473093523`, -1.580733672206497], 
              Complex[1.124116900103588, -3.0442217585222786`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003448947646974741, -0.019454346808716612`}],
            RowBox[{"{", 
              
              RowBox[{"28.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2612176002253626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1228669880155548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "Discard", 1, {
              Complex[3.2612176002253626`, -1.5833427288340611`], 
              Complex[1.1228669880155548`, -3.0468097729723587`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003134788381615789, -0.019454346808716626`}],
            RowBox[{"{", 
              
              RowBox[{"28.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11962494663556839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1228669880155542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "Discard", 2, {
              Complex[0.11962494663556839`, -1.5833427288340611`], 
              Complex[1.1228669880155542`, -3.0468097729723587`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003477882187665654, -0.019514971867383504`}],
            RowBox[{"{", 
              
              RowBox[{"28.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.260578181724976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1216259290318786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.049383353300541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "Discard", 1, {
              Complex[3.260578181724976, -1.5859357455351744`], 
              Complex[1.1216259290318786`, -3.049383353300541]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003163722922306689, -0.01951497186738351}],
            
            RowBox[{"{", 
              
              RowBox[{"28.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11898552813518211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1216259290318777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0493833533005414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "Discard", 2, {
              Complex[0.11898552813518211`, -1.5859357455351755`], 
              Complex[1.1216259290318777`, -3.0493833533005414`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0035067678806969304`, -0.0195753726180706}],
            RowBox[{"{", 
              
              RowBox[{"28.799999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.259945596892496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58851292483865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1203935961632925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "Discard", 1, {
              Complex[3.259945596892496, -1.58851292483865], 
              Complex[1.1203935961632925`, -3.051942680547835]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003192608615337973, -0.01957537261807059}],
            
            RowBox[{"{", 
              
              RowBox[{"28.799999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11835294330270157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5885129248386511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1203935961632907`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "Discard", 2, {
              Complex[0.11835294330270157`, -1.5885129248386511`], 
              Complex[1.1203935961632907`, -3.051942680547835]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0035356050799127355`, -0.019635551772887814`}],
            RowBox[{"{", 
              
              RowBox[{"28.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2593197324621768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5910744653534166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.119169865159973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.054487932208608`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "Discard", 1, {
              Complex[3.2593197324621768`, -1.5910744653534166`], 
              Complex[1.119169865159973, -3.054487932208608]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0032214458145537824`, -0.019635551772887838`}],
            RowBox[{"{", 
              
              RowBox[{"28.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11772707887238294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5910744653534168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1191698651599729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0544879322086085`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "Discard", 2, {
              Complex[0.11772707887238294`, -1.5910744653534168`], 
              Complex[1.1191698651599729`, -3.0544879322086085`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0035643941349726128`, -0.01969551198996052}],
            RowBox[{"{", 
              
              RowBox[{"28.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.258700477751228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5936205618715453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1179546144330978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.057019282325188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "Discard", 1, {
              Complex[3.258700477751228, -1.5936205618715453`], 
              Complex[1.1179546144330978`, -3.057019282325188]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0032502348696137277`, -0.019695511989960578`}],
            RowBox[{"{", 
              
              RowBox[{"28.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11710782416143134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.593620561871549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1179546144330925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0570192823251907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "Discard", 2, {
              Complex[0.11710782416143134`, -1.593620561871549], 
              Complex[1.1179546144330925`, -3.0570192823251907`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0035931353914096568`, -0.01975525587491612}],
            RowBox[{"{", 
              
              RowBox[{"29.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.258087724584257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5961514054678452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1167477249791709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "Discard", 1, {
              Complex[3.258087724584257, -1.5961514054678452`], 
              Complex[1.1167477249791709`, -3.0595369015792553`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0032789761260506815`, -0.01975525587491612}],
            RowBox[{"{", 
              
              RowBox[{"29.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1164950709944641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.596151405467845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1167477249791702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "Discard", 2, {
              Complex[0.1164950709944641, -1.596151405467845], 
              Complex[1.1167477249791702`, -3.0595369015792553`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0036218291906882864`, -0.01981478598231915}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.257481367220427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.115549080307043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.062040957380181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "Discard", 1, {
              Complex[3.257481367220427, -1.5986671835961581`], 
              Complex[1.115549080307043, -3.062040957380181]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003307669925329332, -0.019814785982319064`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11588871363063293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.115549080307041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0620409573801792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "Discard", 2, {
              Complex[0.11588871363063293`, -1.5986671835961561`], 
              Complex[1.115549080307041, -3.0620409573801792`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003650475870261215, -0.019874104817055847`}],
            RowBox[{"{", 
              
              RowBox[{"29.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.256881302283198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60116808018249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1143585663674842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.064531613950414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "Discard", 1, {
              Complex[3.256881302283198, -1.60116808018249], 
              Complex[1.1143585663674842`, -3.064531613950414]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003336316604902235, -0.019874104817055843`}],
            RowBox[{"{", 
              
              RowBox[{"29.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11528864869340531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6011680801824892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.114358566367485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0645316139504137`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "Discard", 2, {
              Complex[0.11528864869340531`, -1.6011680801824892`], 
              Complex[1.114358566367485, -3.0645316139504137`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003679075763625993, -0.01993321483567152}],
            
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2562874286925667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.603654275715105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1131760714852224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "Discard", 1, {
              Complex[3.2562874286925667`, -1.603654275715105], 
              Complex[1.1131760714852224`, -3.067009032408053]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0033649164982671132`, -0.01993321483567158}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11469477510277208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.603654275715108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1131760714852184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408055`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "Discard", 2, {
              Complex[0.11469477510277208`, -1.603654275715108], 
              Complex[1.1131760714852184`, -3.067009032408055]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003707629200381017, -0.019992118447661786`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.255699647599667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.606125947331712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1120014862933134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "Discard", 1, {
              Complex[3.255699647599667, -1.606125947331712], 
              Complex[1.1120014862933134`, -3.06947337084671]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00339346993502201, -0.019992118447661782`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11410699400987415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6061259473317113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.112001486293314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "Discard", 2, {
              Complex[0.11410699400987415`, -1.6061259473317113`], 
              Complex[1.112001486293314, -3.06947337084671]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0037361365062807, -0.020050818016719575`}],
            
            RowBox[{"{", 
              
              RowBox[{"29.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2551178623236616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6085832689038237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1108347036697925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "Discard", 1, {
              Complex[3.2551178623236616`, -1.6085832689038237`], 
              Complex[1.1108347036697925`, -3.0719247844127553`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003421977240921754, -0.020050818016719645`}],
            RowBox[{"{", 
              
              RowBox[{"29.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11352520873386833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.608583268903826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1108347036697903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "Discard", 2, {
              Complex[0.11352520873386833`, -1.608583268903826], 
              Complex[1.1108347036697903`, -3.0719247844127584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003764598003290311, -0.020109315861941132`}],
            RowBox[{"{", 
              
              RowBox[{"29.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.254541978290817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1096756186764698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "Discard", 1, {
              Complex[3.254541978290817, -1.611026411118455], 
              Complex[1.1096756186764698`, -3.0743634253800933`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0034504387379313793`, -0.020109315861941143`}],
            RowBox[{"{", 
              
              RowBox[{"29.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1129493247010233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1096756186764682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "Discard", 2, {
              Complex[0.1129493247010233, -1.611026411118455], 
              Complex[1.1096756186764682`, -3.0743634253800933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0037930140096401697`, -0.020167614258990278`}],
            RowBox[{"{", 
              
              RowBox[{"29.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.253971902975671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1085241284998075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.076789443222504`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "Discard", 1, {
              Complex[3.253971902975671, -1.6134555415571998`], 
              Complex[1.1085241284998075`, -3.076789443222504]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0034788547442812026`, -0.020167614258990267`}],
            RowBox[{"{", 
              
              RowBox[{"29.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11237924938587697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.108524128499807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0767894432225034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "Discard", 2, {
              Complex[0.11237924938587697`, -1.6134555415571996`], 
              Complex[1.108524128499807, -3.0767894432225034`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003821384839878698, -0.020225715441224985`}],
            RowBox[{"{", 
              
              RowBox[{"29.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2534075458442144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "Discard", 1, {
              Complex[3.2534075458442144`, -1.6158708247728455`], 
              Complex[1.1073801323937882`, -3.0792029846837012`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003507225574519718, -0.02022571544122498}],
            
            RowBox[{"{", 
              
              RowBox[{"29.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1118148922544208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "Discard", 2, {
              Complex[0.1118148922544208, -1.6158708247728453`], 
              Complex[1.1073801323937882`, -3.0792029846837004`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003849710804925588, -0.02028362160078633}],
            
            RowBox[{"{", 
              
              RowBox[{"29.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2528488182990007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6182724223635778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1062435316246895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "Discard", 1, {
              Complex[3.2528488182990007`, -1.6182724223635778`], 
              Complex[1.1062435316246895`, -3.0816041938451617`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0035355515395665785`, -0.020283621600786325`}],
            RowBox[{"{", 
              
              RowBox[{"29.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11125616470920796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6182724223635776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1062435316246904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "Discard", 2, {
              Complex[0.11125616470920796`, -1.6182724223635776`], 
              Complex[1.1062435316246904`, -3.0816041938451617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003877992212123589, -0.020341334889651765`}],
            RowBox[{"{", 
              
              RowBox[{"30.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.252295633626107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.620660493044881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.105114229417701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "Discard", 1, {
              Complex[3.252295633626107, -1.620660493044881], 
              Complex[1.105114229417701, -3.0839932121918214`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003563832946764614, -0.020341334889651768`}],
            RowBox[{"{", 
              
              RowBox[{"30.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.110702980036313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6206604930448811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1051142294177012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "Discard", 2, {
              Complex[0.110702980036313, -1.6206604930448811`], 
              Complex[1.1051142294177012`, -3.0839932121918214`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0039062293652901824`, -0.020398857420654174`}],
            RowBox[{"{", 
              
              RowBox[{"30.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.251747906943866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.10399213090529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.086370178675715`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "Discard", 1, {
              Complex[3.251747906943866, -1.6230351927192315`], 
              Complex[1.10399213090529, -3.086370178675715]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0035920700999312184`, -0.02039885742065416}],
            RowBox[{"{", 
              
              RowBox[{"30.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11015525335407254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1039921309052896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0863701786757147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "Discard", 2, {
              Complex[0.11015525335407254`, -1.6230351927192315`], 
              Complex[1.1039921309052896`, -3.0863701786757147`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003934422564768166, -0.02045619126846798}],
            
            RowBox[{"{", 
              
              RowBox[{"30.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.25120555515332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6253966745436454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1028771430772724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0887352297776514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "Discard", 1, {
              Complex[3.25120555515332, -1.6253966745436454`], 
              Complex[1.1028771430772724`, -3.0887352297776514`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.003620263299409205, -0.020456191268468}],
            RowBox[{"{", 
              
              RowBox[{"30.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1096129015635269`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6253966745436466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.102877143077272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0887352297776527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "Discard", 2, {
              Complex[0.1096129015635269, -1.6253966745436466`], 
              Complex[1.102877143077272, -3.0887352297776527`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003962572107475744, -0.02051333847056381}],
            
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.250668496890299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0910884995669843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "Discard", 1, {
              Complex[3.250668496890299, -1.6277450889951866`], 
              Complex[1.1017691747325018`, -3.0910884995669843`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00364841284211679, -0.02051333847056381}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10907584330050497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.091088499566983`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "Discard", 2, {
              Complex[0.10907584330050497`, -1.6277450889951857`], 
              Complex[1.1017691747325018`, -3.091088499566983]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003990678286955965, -0.02057030102813225}],
            
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2501366524790782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6300805839344696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1006681364321238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.093430119759536`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "Discard", 1, {
              Complex[3.2501366524790782`, -1.6300805839344696`], 
              Complex[1.1006681364321238`, -3.093430119759536]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003676519021596945, -0.020570301028132284`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10854399888928548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6300805839344692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1006681364321256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0934301197595353`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "Discard", 2, {
              Complex[0.10854399888928548`, -1.6300805839344692`], 
              Complex[1.1006681364321256`, -3.0934301197595353`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004018741393425304, -0.020627080906979078`}],
            RowBox[{"{", 
              
              RowBox[{"30.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2496099438875583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6324033046672912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0995739404543334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "Discard", 1, {
              Complex[3.2496099438875583`, -1.6324033046672912`], 
              Complex[1.0995739404543334`, -3.095760219773794]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0037045821280663345`, -0.02062708090697909}],
            RowBox[{"{", 
              
              RowBox[{"30.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10801729029776416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6324033046672906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0995739404543337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "Discard", 2, {
              Complex[0.10801729029776416`, -1.6324033046672906`], 
              Complex[1.0995739404543337`, -3.095760219773794]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0040467617138218595`, -0.020683680038391716`}],
            RowBox[{"{", 
              
              RowBox[{"30.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2490882946838866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6347133940043952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0984865007505693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.098078926785381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "Discard", 1, {
              Complex[3.2490882946838866`, -1.6347133940043952`], 
              Complex[1.0984865007505693`, -3.098078926785381]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0037326024484628634`, -0.02068368003839169}],
            RowBox[{"{", 
              
              RowBox[{"30.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10749564109409336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6347133940043936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.09848650075057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.09807892678538`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "Discard", 2, {
              Complex[0.10749564109409336`, -1.6347133940043936`], 
              Complex[1.09848650075057, -3.09807892678538]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00407473953185248, -0.02074010031997901}],
            RowBox[{"{", 
              
              RowBox[{"30.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2485716299944873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0974057329031106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1003863657798956`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "Discard", 1, {
              Complex[3.2485716299944873`, -1.6370109923194756`], 
              Complex[1.0974057329031106`, -3.1003863657798956`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00376058026649348, -0.020740100319979}],
            RowBox[{"{", 
              
              RowBox[{"30.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10697897640469432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0974057329031108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.100386365779895`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "Discard", 2, {
              Complex[0.10697897640469432`, -1.6370109923194756`], 
              Complex[1.0974057329031108`, -3.100386365779895]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004102675128039459, -0.020796343616485}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.248059876463437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6392962376054834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041888`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "Discard", 1, {
              Complex[3.248059876463437, -1.6392962376054834`], 
              Complex[1.0963315540840044`, -3.1026826596041888`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0037885158626804927`, -0.020796343616484973`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1064672228736436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6392962376054825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "Discard", 2, {
              Complex[0.1064672228736436, -1.6392962376054825`], 
              Complex[1.0963315540840044`, -3.1026826596041883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004130568779766602, -0.020852411760577363`}],
            RowBox[{"{", 
              
              RowBox[{"30.999999999999993`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2475529622131285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.09526388301527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.104967929016112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "Discard", 1, {
              Complex[3.2475529622131285`, -1.64156926552927], 
              Complex[1.09526388301527, -3.104967929016112]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0038164095144076165`, -0.02085241176057735}],
            RowBox[{"{", 
              
              RowBox[{"30.999999999999993`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10596030862333504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0952638830152697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.104967929016111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "Discard", 2, {
              Complex[0.10596030862333504`, -1.64156926552927], 
              Complex[1.0952638830152697`, -3.104967929016111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004158420761324276, -0.020908306553612088`}],
            RowBox[{"{", 
              
              RowBox[{"31.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2470508168061887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6438302094846542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0942026399303626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.107242292732799`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "Discard", 1, {
              Complex[3.2470508168061887`, -1.6438302094846542`], 
              Complex[1.0942026399303626`, -3.107242292732799]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003844261495965338, -0.020908306553612106`}],
            RowBox[{"{", 
              
              RowBox[{"31.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10545816321639523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.643830209484655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0942026399303617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1072422927328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "Discard", 2, {
              Complex[0.10545816321639523`, -1.643830209484655], 
              Complex[1.0942026399303617`, -3.1072422927328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004186231343954349, -0.0209640297663748}],
            RowBox[{"{", 
              
              RowBox[{"31.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2465533712085897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6460792006439566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0931477465368076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.109505867477551`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "Discard", 1, {
              Complex[3.2465533712085897`, -1.6460792006439566`], 
              Complex[1.0931477465368076`, -3.109505867477551]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.003872072078595358, -0.0209640297663748}],
            RowBox[{"{", 
              
              RowBox[{"31.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10496071761879634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.646079200643956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.093147746536808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.10950586747755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "Discard", 2, {
              Complex[0.10496071761879634`, -1.646079200643956], 
              Complex[1.093147746536808, -3.10950586747755]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004214000795893677, -0.021019583139799448`}],
            RowBox[{"{", 
              
              RowBox[{"31.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2460605577539177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648316368008041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0920991259800008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.111758768025328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "Discard", 1, {
              Complex[3.2460605577539177`, -1.648316368008041], 
              Complex[1.0920991259800008`, -3.111758768025328]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0038998415305347245`, -0.02101958313979945}],
            RowBox[{"{", 
              
              RowBox[{"31.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10446790416412378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6483163680080417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0920991259799997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1117587680253287`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "Discard", 2, {
              Complex[0.10446790416412378`, -1.6483163680080417`], 
              Complex[1.0920991259799997`, -3.1117587680253287`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004241729382417897, -0.0210749683856661}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2455723101087495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6505418384549597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0910567028080993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "Discard", 1, {
              Complex[3.2455723101087495`, -1.6505418384549597`], 
              Complex[1.0910567028080993`, -3.114001107246972]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003927570117058932, -0.02107496838566609}],
            
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10397965651895658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.65054183845496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0910567028080986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "Discard", 2, {
              Complex[0.10397965651895658`, -1.65054183845496], 
              Complex[1.0910567028080986`, -3.114001107246972]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004269417365883537, -0.021130187187277088`}],
            RowBox[{"{", 
              
              RowBox[{"31.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2450885632391073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6527557367871826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0900204029379934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "Discard", 1, {
              Complex[3.2450885632391073`, -1.6527557367871826`], 
              Complex[1.0900204029379934`, -3.116232996152112]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003955258100524528, -0.021130187187277077`}],
            RowBox[{"{", 
              
              RowBox[{"31.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10349590964931504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.652755736787182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0900204029379945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "Discard", 2, {
              Complex[0.10349590964931504`, -1.652755736787182], 
              Complex[1.0900204029379945`, -3.116232996152111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0042970650057702195`, -0.021185241200114}],
            
            RowBox[{"{", 
              
              RowBox[{"31.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2446092533779374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6549581857775257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.088990153622295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1184545439308806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "Discard", 1, {
              Complex[3.2446092533779374`, -1.6549581857775257`], 
              Complex[1.088990153622295, -3.1184545439308806`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.003982905740411263, -0.021185241200114023`}],
            RowBox[{"{", 
              
              RowBox[{"31.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10301659978814422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6549581857775262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0889901536222948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.118454543930881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "Discard", 2, {
              Complex[0.10301659978814422`, -1.6549581857775262`], 
              Complex[1.0889901536222948`, -3.118454543930881]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004324672558722068, -0.021240132052474974`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2441343179935824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0879658834173163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944384`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "Discard", 1, {
              Complex[3.2441343179935824`, -1.6571493062137856`], 
              Complex[1.0879658834173163`, -3.1206658579944384`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0040105132933631014`, -0.021240132052474995`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1025416644037889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0879658834173156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944393`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "Discard", 2, {
              Complex[0.1025416644037889, -1.6571493062137859`], 
              Complex[1.0879658834173156`, -3.1206658579944393`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004352240278588184, -0.021294861346093152`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2436636957592206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1228670440143484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "Discard", 1, {
              Complex[3.2436636957592206`, -1.6593292169421239`], 
              Complex[1.0869475221520086`, -3.1228670440143484`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004038081013229186, -0.02129486134609312}],
            
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10207104216942726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.122867044014348`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "Discard", 2, {
              Complex[0.10207104216942726`, -1.6593292169421239`], 
              Complex[1.0869475221520086`, -3.122867044014348]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004379768416462682, -0.021349430656737684`}],
            RowBox[{"{", 
              
              RowBox[{"31.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2431973265232212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6614980349092643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0859350008978244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "Discard", 1, {
              Complex[3.2431973265232212`, -1.6614980349092643`], 
              Complex[1.0859350008978244`, -3.1250582059608574`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004065609151103688, -0.02134943065673767}],
            
            RowBox[{"{", 
              
              RowBox[{"31.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10160467293342826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6614980349092632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0859350008978255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "Discard", 2, {
              Complex[0.10160467293342826`, -1.6614980349092632`], 
              Complex[1.0859350008978255`, -3.1250582059608565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004407257220724144, -0.02140384153479705}],
            
            RowBox[{"{", 
              
              RowBox[{"31.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.242735151280391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.084928251939455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.127239446140108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "Discard", 1, {
              Complex[3.242735151280391, -1.6636558752035226`], 
              Complex[1.084928251939455, -3.127239446140108]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0040930979553651945`, -0.021403841534797075`}],
            RowBox[{"{", 
              
              RowBox[{"31.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10114249769059809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0849282519394552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1272394461401083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "Discard", 2, {
              Complex[0.10114249769059809`, -1.6636558752035224`], 
              Complex[1.0849282519394552`, -3.1272394461401083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004434706937074476, -0.021458095505845896`}],
            RowBox[{"{", 
              
              RowBox[{"32.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2422771121440808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6658028510947214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303243`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "Discard", 1, {
              Complex[3.2422771121440808`, -1.6658028510947214`], 
              Complex[1.083927208746434, -3.1294108652303243`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004120547671715526, -0.02145809550584592}],
            
            RowBox[{"{", 
              
              RowBox[{"32.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10068445855428786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6658028510947218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "Discard", 2, {
              Complex[0.10068445855428786`, -1.6658028510947218`], 
              Complex[1.083927208746434, -3.1294108652303256`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004462117808576994, -0.021512194071195513`}],
            RowBox[{"{", 
              
              RowBox[{"32.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2418231523191214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6679390740730151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "Discard", 1, {
              Complex[3.2418231523191214`, -1.6679390740730151`], 
              Complex[1.082931805945569, -3.1315725623170003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004147958543217995, -0.021512194071195492`}],
            RowBox[{"{", 
              
              RowBox[{"32.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10023049872932865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6679390740730153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "Discard", 2, {
              Complex[0.10023049872932865`, -1.6679390740730153`], 
              Complex[1.082931805945569, -3.1315725623170003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004489490075693837, -0.02156613870842883}],
            
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.241373216075559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927122`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "Discard", 1, {
              Complex[3.241373216075559, -1.6700646538866692`], 
              Complex[1.0819419792941676`, -3.133724634927122]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004175330810334848, -0.0215661387084288}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09978056248576549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "Discard", 2, {
              Complex[0.09978056248576549, -1.6700646538866686`], 
              Complex[1.0819419792941676`, -3.133724634927121]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004516823976323265, -0.02161993087192057}],
            
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.240927248723158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624704`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "Discard", 1, {
              Complex[3.240927248723158, -1.6721796985788306`], 
              Complex[1.0809576656540323`, -3.1358671790624704`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0042026647109642675`, -0.021619930871920517`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09933459513336479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "Discard", 2, {
              Complex[0.09933459513336479, -1.6721796985788298`], 
              Complex[1.0809576656540323`, -3.1358671790624695`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00454411974583578, -0.0216735719933425}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.240485196586656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6742843145233057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0799788029662047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138000289232015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "Discard", 1, {
              Complex[3.240485196586656, -1.6742843145233057`], 
              Complex[1.0799788029662047`, -3.138000289232015]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004229960480476803, -0.021673571993342532`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0988925429968627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6742843145233064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.079978802966205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.138000289232016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "Discard", 2, {
              Complex[0.0988925429968627, -1.6742843145233064`], 
              Complex[1.079978802966205, -3.138000289232016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00457137761711002, -0.021727063482155078`}],
            RowBox[{"{", 
              
              RowBox[{"32.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2400470069817295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6763786064594062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.079005330226425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.140124058483446`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "Discard", 1, {
              Complex[3.2400470069817295`, -1.6763786064594062`], 
              Complex[1.079005330226425, -3.140124058483446]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004257218351751027, -0.02172706348215509}],
            
            RowBox[{"{", 
              
              RowBox[{"32.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09845435339193638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6763786064594066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0790053302264244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1401240584834467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "Discard", 2, {
              Complex[0.09845435339193638, -1.6763786064594066`], 
              Complex[1.0790053302264244`, -3.1401240584834467`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004598597820567857, -0.021780406726085052`}],
            RowBox[{"{", 
              
              RowBox[{"32.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2396126281916615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6784626775258558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0780371874612853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "Discard", 1, {
              Complex[3.2396126281916615`, -1.6784626775258558`], 
              Complex[1.0780371874612853`, -3.1422385784338522`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004284438555208863, -0.021780406726085024`}],
            RowBox[{"{", 
              
              RowBox[{"32.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09801997460186761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6784626775258555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0780371874612855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "Discard", 2, {
              Complex[0.09801997460186761, -1.6784626775258555`], 
              Complex[1.0780371874612855`, -3.1422385784338505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0046257805842091805`, -0.02183360309159023}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2391820094446726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6805366292938222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0770743157050588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.144343939299593`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "Discard", 1, {
              Complex[3.2391820094446726`, -1.6805366292938222`], 
              Complex[1.0770743157050588`, -3.144343939299593]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004311621318850196, -0.021833603091590183`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09758935585487952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6805366292938224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0770743157050577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1443439392995933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "Discard", 2, {
              Complex[0.09758935585487952, -1.6805366292938224`], 
              Complex[1.0770743157050577`, -3.1443439392995933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004652926133645969, -0.021886653924311696`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2387551008919058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6826005617990878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.076116656977162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1464402299253895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "Discard", 1, {
              Complex[3.2387551008919058`, -1.6826005617990878`], 
              Complex[1.076116656977162, -3.1464402299253895`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004338766868286963, -0.02188665392431169}],
            
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09716244730211258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.682600561799087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0761166569771627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1464402299253886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "Discard", 2, {
              Complex[0.09716244730211258, -1.682600561799087], 
              Complex[1.0761166569771627`, -3.1464402299253886`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004680034692135726, -0.021939560549513598`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.238331853586033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6846545735733742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.075164154260271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.148527537812633`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "Discard", 1, {
              Complex[3.238331853586033, -1.6846545735733742`], 
              Complex[1.075164154260271, -3.148527537812633]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004365875426776753, -0.021939560549513577`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09673919999623987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.684654573573374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0751641542602708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1485275378126323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "Discard", 2, {
              Complex[0.09673919999623987, -1.684654573573374], 
              Complex[1.0751641542602708`, -3.1485275378126323`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004707106480614677, -0.0219923242725109}],
            RowBox[{"{", 
              
              RowBox[{"33.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237912219460468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.686698761674875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.15060594914697`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "Discard", 1, {
              Complex[3.237912219460468, -1.686698761674875], 
              Complex[1.0742167514790106`, -3.15060594914697]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0043929472152556765`, -0.02199232427251086}],
            RowBox[{"{", 
              
              RowBox[{"33.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0963195658706748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6866987616748745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1506059491469687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "Discard", 2, {
              Complex[0.0963195658706748, -1.6866987616748745`], 
              Complex[1.0742167514790106`, -3.1506059491469687`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004734141717729958, -0.022044946379086182`}],
            RowBox[{"{", 
              
              RowBox[{"33.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237496151309166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6887332217179927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0732743934792588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.152675548825165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "Discard", 1, {
              Complex[3.237496151309166, -1.6887332217179927`], 
              Complex[1.0732743934792588`, -3.152675548825165]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0044199824523709795`, -0.022044946379086168`}],
            RowBox[{"{", 
              
              RowBox[{"33.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09590349771937258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.688733221717992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0732743934792583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1526755488251643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "Discard", 2, {
              Complex[0.09590349771937258, -1.688733221717992], 
              Complex[1.0732743934792583`, -3.1526755488251643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0047611406198719, -0.022097428135894787`}],
            
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237083602766982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0723370260079925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.154736420481273`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "Discard", 1, {
              Complex[3.237083602766982, -1.6907580479023252`], 
              Complex[1.0723370260079925`, -3.154736420481273]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004446981354512908, -0.022097428135894784`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09549094917718823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.072337026007993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1547364204812727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "Discard", 2, {
              Complex[0.09549094917718823, -1.6907580479023245`], 
              Complex[1.072337026007993, -3.1547364204812727`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004788103401205012, -0.022149770790859544`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2366745282905844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6927733330409118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.071404595693708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "Discard", 1, {
              Complex[3.2366745282905844`, -1.6927733330409118`], 
              Complex[1.071404595693708, -3.156788646512134]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004473944135846044, -0.022149770790859547`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09508187470079153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6927733330409114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0714045956937088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "Discard", 2, {
              Complex[0.09508187470079153, -1.6927733330409114`], 
              Complex[1.0714045956937088`, -3.156788646512134]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004815030273699424, -0.02220197557355523}],
            
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2362688831398905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.694779168587776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0704770500273408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.158832308102228`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "Discard", 1, {
              Complex[3.2362688831398905`, -1.694779168587776], 
              Complex[1.0704770500273408`, -3.158832308102228]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004500871008340418, -0.022201975573555216`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09467622955009732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6947791685877762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0704770500273406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1588323081022285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "Discard", 2, {
              Complex[0.09467622955009732, -1.6947791685877762`], 
              Complex[1.0704770500273406`, -3.1588323081022285`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004841921447160744, -0.022254043695582523`}],
            RowBox[{"{", 
              
              RowBox[{"33.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.235866623360016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6967756446647662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0695543373437264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1608674852478886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "Discard", 1, {
              Complex[3.235866623360016, -1.6967756446647662`], 
              Complex[1.0695543373437264`, -3.1608674852478886`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004527762181801761, -0.02225404369558251}],
            
            RowBox[{"{", 
              
              RowBox[{"33.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0942739697702223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6967756446647657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.069554337343726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1608674852478877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "Discard", 2, {
              Complex[0.0942739697702223, -1.6967756446647657`], 
              Complex[1.069554337343726, -3.1608674852478877`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004868777129260548, -0.022305976350932684`}],
            RowBox[{"{", 
              
              RowBox[{"33.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2354677057637162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6987628500877325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.068636406803538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.162894256780908`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "Discard", 1, {
              Complex[3.2354677057637162`, -1.6987628500877325`], 
              Complex[1.068636406803538, -3.162894256780908]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004554617863901558, -0.02230597635093271}],
            
            RowBox[{"{", 
              
              RowBox[{"33.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09387505217392343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6987628500877328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0686364068035386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1628942567809086`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "Discard", 2, {
              Complex[0.09387505217392343, -1.6987628500877328`], 
              Complex[1.0686364068035386`, -3.1628942567809086`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004895597525565213, -0.02235777471634256}],
            
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2350720879143124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7007408723920572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0677232083757224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "Discard", 1, {
              Complex[3.2350720879143124`, -1.7007408723920572`], 
              Complex[1.0677232083757224`, -3.1649127003915547`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004581438260206269, -0.022357774716342614`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09347943432451934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.700740872392058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0677232083757218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "Discard", 2, {
              Complex[0.09347943432451934, -1.700740872392058], 
              Complex[1.0677232083757218`, -3.1649127003915565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0049223828395654565`, -0.02240943995164054}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.234679728109072`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7027097978575507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0668146928203772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1669228926510127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "Discard", 1, {
              Complex[3.234679728109072, -1.7027097978575507`], 
              Complex[1.0668146928203772`, -3.1669228926510127`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004608223574206441, -0.022409439951640513`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0930870745192786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7027097978575496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0668146928203786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.166922892651011`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "Discard", 2, {
              Complex[0.0930870745192786, -1.7027097978575496`], 
              Complex[1.0668146928203786`, -3.166922892651011]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004949133272704226, -0.022460973200083424`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2342905853630466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.065910811672111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1689249090332523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "Discard", 1, {
              Complex[3.2342905853630466`, -1.7046697115327338`], 
              Complex[1.065910811672111, -3.1689249090332523`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00463497400734532, -0.022460973200083386`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0926979317732518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0659108116721088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.168924909033252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "Discard", 2, {
              Complex[0.0926979317732518, -1.7046697115327327`], 
              Complex[1.0659108116721088`, -3.168924909033252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00497584902440536, -0.022512375588685248`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2339046193933325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0650115172238024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "Discard", 1, {
              Complex[3.2339046193933325`, -1.7066206972585347`], 
              Complex[1.0650115172238024`, -3.170918823936388]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004661689759046362, -0.022512375588685237`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09231196580353926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0650115172238028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "Discard", 2, {
              Complex[0.09231196580353926, -1.7066206972585347`], 
              Complex[1.0650115172238028`, -3.170918823936388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005002530292100557, -0.02256364822853732}],
            
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2335217906037683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7085628376914088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0641167625108199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "Discard", 1, {
              Complex[3.2335217906037683`, -1.7085628376914088`], 
              Complex[1.0641167625108199`, -3.1729047107034827`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004688371026741571, -0.022563648228537323`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09192913701397513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7085628376914086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.06411676251082`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "Discard", 2, {
              Complex[0.09192913701397513, -1.7085628376914086`], 
              Complex[1.06411676251082, -3.1729047107034827`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0050291772712568695`, -0.022614792215120263`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2331420600700214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7104962143258888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0632265012956237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1748826416428573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "Discard", 1, {
              Complex[3.2331420600700214`, -1.7104962143258888`], 
              Complex[1.0632265012956237`, -3.1748826416428573`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00471501800589791, -0.022614792215120288`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09154940648022836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7104962143258893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.063226501295623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.174882641642858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "Discard", 2, {
              Complex[0.09154940648022836, -1.7104962143258893`], 
              Complex[1.063226501295623, -3.174882641642858]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0050557901554033275`, -0.02266580862860849}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2327653895250794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.712420907516613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0623406880527706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1768526880479087`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "Discard", 1, {
              Complex[3.2327653895250794`, -1.712420907516613], 
              Complex[1.0623406880527706`, -3.1768526880479087`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0047416308900443595`, -0.022665808628608498`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0911727359352858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7124209075166128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.06234068805277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.176852688047909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "Discard", 2, {
              Complex[0.0911727359352858, -1.7124209075166128`], 
              Complex[1.06234068805277, -3.176852688047909]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00508236913615712, -0.02271669853416705}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23239174134512`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7143369964998079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0614592779543162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "Discard", 1, {
              Complex[3.23239174134512, -1.7143369964998079`], 
              Complex[1.0614592779543162`, -3.1788149202164426`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.004768209870798141, -0.02271669853416704}],
            
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09079908775532702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.714336996499808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0614592779543155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "Discard", 2, {
              Complex[0.09079908775532702, -1.714336996499808], 
              Complex[1.0614592779543155`, -3.1788149202164435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0051089144032493445`, -0.02276746298224061}],
            RowBox[{"{", 
              
              RowBox[{"34.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2320210785357544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7162445594142668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0605822268555747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.180769407469538`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "Discard", 1, {
              Complex[3.2320210785357544`, -1.7162445594142668`], 
              Complex[1.0605822268555747`, -3.180769407469538]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0047947551378903835`, -0.02276746298224063}],
            RowBox[{"{", 
              
              RowBox[{"34.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09042842494596093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7162445594142677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.060582226855574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1807694074695387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "Discard", 2, {
              Complex[0.09042842494596093, -1.7162445594142677`], 
              Complex[1.060582226855574, -3.1807694074695387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005135426144550579, -0.022818103008836306`}],
            RowBox[{"{", 
              
              RowBox[{"34.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.231653364718622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0597094912812492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1827162181699684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "Discard", 1, {
              Complex[3.231653364718622, -1.7181436733218398`], 
              Complex[1.0597094912812492`, -3.1827162181699684`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00482126687919163, -0.022818103008836715`}],
            RowBox[{"{", 
              
              RowBox[{"34.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.090060711128834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.05970949128125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1827162181699844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "Discard", 2, {
              Complex[0.090060711128834, -1.7181436733218531`], 
              Complex[1.05970949128125, -3.1827162181699844`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005161904546095823, -0.022868619635798774`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.231288564118341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0588410284119094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.184655419740182`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "Discard", 1, {
              Complex[3.231288564118341, -1.7200344142274249`], 
              Complex[1.0588410284119094`, -3.184655419740182]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0048477452807368605`, -0.022868619635798747`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08969591052854747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.058841028411909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.18465541974018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "Discard", 2, {
              Complex[0.08969591052854747, -1.7200344142274246`], 
              Complex[1.058841028411909, -3.18465541974018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005188349792109026, -0.022919013871078916`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.230926641549791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7219168570985053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0579767960708073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1865870786798474`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "Discard", 1, {
              Complex[3.230926641549791, -1.7219168570985053`], 
              Complex[1.0579767960708073`, -3.1865870786798474`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004874190526750031, -0.0229190138710789}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0893339879599975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.721916857098505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0579767960708075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.186587078679847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "Discard", 2, {
              Complex[0.0893339879599975, -1.721916857098505], 
              Complex[1.0579767960708075`, -3.186587078679847]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005214762065027326, -0.02296928670899607}],
            
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2305675624057217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7237910758842263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.057116752711029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.188511260583004`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "Discard", 1, {
              Complex[3.2305675624057217`, -1.7237910758842263`], 
              Complex[1.057116752711029, -3.188511260583004]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.004900602799668382, -0.0229692867089961}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08897490881592815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7237910758842274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0571167527110277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1885112605830046`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "Discard", 2, {
              Complex[0.08897490881592815, -1.7237910758842274`], 
              Complex[1.0571167527110277`, -3.1885112605830046`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005241141545524946, -0.023019439130494007`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.230211292644681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7256571435340284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.056260857402957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.190428030154787`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "Discard", 1, {
              Complex[3.230211292644681, -1.7256571435340284`], 
              Complex[1.056260857402957, -3.190428030154787]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0049269822801659355`, -0.023019439130494007`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08861863905488769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.725657143534028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0562608574029573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.190428030154786`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "Discard", 2, {
              Complex[0.08861863905488769, -1.725657143534028], 
              Complex[1.0562608574029573`, -3.190428030154786]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005267488412536321, -0.023069472103390394`}],
            RowBox[{"{", 
              
              RowBox[{"35.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2298577987792507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.727515132015845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0554090698220604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1923374512277776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "Discard", 1, {
              Complex[3.2298577987792507`, -1.727515132015845], 
              Complex[1.0554090698220604`, -3.1923374512277776`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00495332914717738, -0.023069472103390404`}],
            RowBox[{"{", 
              
              RowBox[{"35.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08826514518945743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.727515132015846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.055409069822059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1923374512277785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "Discard", 2, {
              Complex[0.08826514518945743, -1.727515132015846], 
              Complex[1.055409069822059, -3.1923374512277785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005293802843279591, -0.023119386582620888`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2295070478645758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0545613502369586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "Discard", 1, {
              Complex[3.2295070478645758`, -1.7293651123339018`], 
              Complex[1.0545613502369586`, -3.1942395867779743`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.004979643577920611, -0.023119386582620895`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08791439427478234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0545613502369584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "Discard", 2, {
              Complex[0.08791439427478234, -1.7293651123339018`], 
              Complex[1.0545613502369584`, -3.1942395867779743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005320085013278856, -0.023169183510476754`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.229159007487185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7312071545460794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0537176594978062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.196134498940377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "Discard", 1, {
              Complex[3.229159007487185, -1.7312071545460794`], 
              Complex[1.0537176594978062`, -3.196134498940377]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005005925747919894, -0.023169183510476803`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08756635389739194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.73120715454608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0537176594978057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1961344989403777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "Discard", 2, {
              Complex[0.08756635389739194, -1.73120715454608], 
              Complex[1.0537176594978057`, -3.1961344989403777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005346335096386782, -0.023218863816837763`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.228813645754096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7330413277809138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.052877959024942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1980222490242434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "Discard", 1, {
              Complex[3.228813645754096, -1.7330413277809138`], 
              Complex[1.052877959024942, -3.1980222490242434`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0050321758310278, -0.02321886381683772}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08722099216430315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.733041327780913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0528779590249415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1980222490242425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "Discard", 2, {
              Complex[0.08722099216430315, -1.733041327780913], 
              Complex[1.0528779590249415`, -3.1980222490242425`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00537255326480634, -0.023268428419398475`}],
            RowBox[{"{", 
              
              RowBox[{"35.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.228470931282186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.052042210797825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1999028975279598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "Discard", 1, {
              Complex[3.228470931282186, -1.7348677002541815`], 
              Complex[1.052042210797825, -3.1999028975279598`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005058393999447379, -0.023268428419398485`}],
            RowBox[{"{", 
              
              RowBox[{"35.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.086878277692393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0520422107978245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.199902897527961`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "Discard", 2, {
              Complex[0.086878277692393, -1.7348677002541821`], 
              Complex[1.0520422107978245`, -3.199902897527961]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.005398739689112632, -0.02331787822389054}],
            
            RowBox[{"{", 
              
              RowBox[{"35.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2281308331878296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.736686339285139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0512103773442272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153611`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "Discard", 1, {
              Complex[3.2281308331878296`, -1.736686339285139], 
              Complex[1.0512103773442272`, -3.201776504153611]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005084580423753661, -0.023317878223890646`}],
            RowBox[{"{", 
              
              RowBox[{"35.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08653817959803752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7366863392851428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0512103773442263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153616`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "Discard", 2, {
              Complex[0.08653817959803752, -1.7366863392851428`], 
              Complex[1.0512103773442263`, -3.201776504153616]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.005424894538273949, -0.02336721412429885}],
            
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227793321076793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0503824217296989`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211888`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "Discard", 1, {
              Complex[3.227793321076793, -1.7384973113123774`], 
              Complex[1.0503824217296989`, -3.2036431278211888`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005110735272914953, -0.02336721412429885}],
            
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08620066748699956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0503824217296986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "Discard", 2, {
              Complex[0.08620066748699956, -1.7384973113123776`], 
              Complex[1.0503824217296986`, -3.2036431278211883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005451017979672755, -0.023416437003072908`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227458365034377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0495583075472772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.20550282668249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "Discard", 1, {
              Complex[3.227458365034377, -1.7403006819093283`], 
              Complex[1.0495583075472772`, -3.20550282668249]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0051368587143137455`, -0.023416437003072863`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08586571144458416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0495583075472783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2055028266824883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "Discard", 2, {
              Complex[0.08586571144458416, -1.7403006819093272`], 
              Complex[1.0495583075472783`, -3.2055028266824883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005477110179126379, -0.023465547731333733`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227125935615802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7420965157994346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134717`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "Discard", 1, {
              Complex[3.227125935615802, -1.7420965157994346`], 
              Complex[1.0487379989074426`, -3.207355658134717]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005162950913767382, -0.023465547731333705`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08553328202600917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.742096515799434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134716`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "Discard", 2, {
              Complex[0.08553328202600917, -1.742096515799434], 
              Complex[1.0487379989074426`, -3.207355658134716]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005503171300907135, -0.023514547169075615`}],
            RowBox[{"{", 
              
              RowBox[{"36.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2267960038368266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7438848768709785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0479214604283111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "Discard", 1, {
              Complex[3.2267960038368266`, -1.7438848768709785`], 
              Complex[1.0479214604283111`, -3.209201678833752]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005189012035548136, -0.023514547169075604`}],
            RowBox[{"{", 
              
              RowBox[{"36.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08520335024703361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7438848768709778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0479214604283116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "Discard", 2, {
              Complex[0.08520335024703361, -1.7438848768709778`], 
              Complex[1.0479214604283116`, -3.209201678833752]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005529201507762366, -0.02356343616536352}],
            
            RowBox[{"{", 
              
              RowBox[{"36.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2264685411645937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7456658281915811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0471086572260642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "Discard", 1, {
              Complex[3.2264685411645937`, -1.7456658281915811`], 
              Complex[1.0471086572260642`, -3.2110409447071544`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005215042242403387, -0.02356343616536352}],
            
            RowBox[{"{", 
              
              RowBox[{"36.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08487588757480041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7456658281915818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.047108657226064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "Discard", 2, {
              Complex[0.08487588757480041, -1.7456658281915818`], 
              Complex[1.047108657226064, -3.2110409447071544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005555200960934033, -0.023612215558525832`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.226143519508699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747439432022393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0462995549055958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.212873510966856`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "Discard", 1, {
              Complex[3.226143519508699, -1.747439432022393], 
              Complex[1.0462995549055958`, -3.212873510966856]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005241041695575025, -0.02361221555852582}],
            
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08455086591890591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474394320223927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.046299554905596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2128735109668556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "Discard", 2, {
              Complex[0.08455086591890591, -1.7474394320223927`], 
              Complex[1.046299554905596, -3.2128735109668556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005581169820177937, -0.023660886176342794`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.225820911212475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7492057498319644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.045494119551384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2146994321215847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "Discard", 1, {
              Complex[3.225820911212475, -1.7492057498319644`], 
              Complex[1.045494119551384, -3.2146994321215847`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0052670105548189745`, -0.023660886176342797`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0842282576226818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7492057498319649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0454941195513836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2146994321215856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "Discard", 2, {
              Complex[0.0842282576226818, -1.7492057498319649`], 
              Complex[1.0454941195513836`, -3.2146994321215856`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005607108243783008, -0.023709448836231137`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.225500689044484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.750964842309831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0446923177185734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "Discard", 1, {
              Complex[3.225500689044484, -1.750964842309831], 
              Complex[1.0446923177185734`, -3.2165187619890245`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005292948978424031, -0.023709448836231117`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08390803545469033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7509648423098307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0446923177185725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "Discard", 2, {
              Complex[0.08390803545469033, -1.7509648423098307`], 
              Complex[1.0446923177185725`, -3.2165187619890236`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005633016388589556, -0.023757904345423575`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2251828261902116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7527167693797805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0438941164242628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2183315537076793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "Discard", 1, {
              Complex[3.2251828261902116`, -1.7527167693797805`], 
              Complex[1.0438941164242628`, -3.2183315537076793`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0053188571232305965`, -0.023757904345423558`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0835901726004175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.752716769379781`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0438941164242617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.218331553707678`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "Discard", 2, {
              Complex[0.0835901726004175, -1.752716769379781], 
              Complex[1.0438941164242617`, -3.218331553707678]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005658894410008299, -0.02380625350114576}],
            
            RowBox[{"{", 
              
              RowBox[{"36.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.224867296243958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0430994831389901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2201378597485246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "Discard", 1, {
              Complex[3.224867296243958, -1.7544615902128715`], 
              Complex[1.0430994831389901`, -3.2201378597485246`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00534473514464931, -0.023806253501145777`}],
            RowBox[{"{", 
              
              RowBox[{"36.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08327464265416494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.04309948313899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2201378597485255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "Discard", 2, {
              Complex[0.08327464265416494, -1.7544615902128715`], 
              Complex[1.04309948313899, -3.2201378597485255`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005684742462037843, -0.023854497090787973`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2245540732009284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561993632401343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0423083857784268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "Discard", 1, {
              Complex[3.2245540732009284`, -1.7561993632401343`], 
              Complex[1.0423083857784268`, -3.2219377319263685`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005370583196678815, -0.02385449709078799}],
            
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08296141961113473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561993632401347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0423083857784274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "Discard", 2, {
              Complex[0.08296141961113473, -1.7561993632401347`], 
              Complex[1.0423083857784274`, -3.2219377319263676`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005710560697283048, -0.023902635892073896`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2242431314494953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7579301461650294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0415207926952428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2237312214109846`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "Discard", 1, {
              Complex[3.2242431314494953`, -1.7579301461650294`], 
              Complex[1.0415207926952428`, -3.2237312214109846`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0053964014319240914`, -0.023902635892073924`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08265047785970185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7579301461650303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0415207926952421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.223731221410986`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "Discard", 2, {
              Complex[0.08265047785970185, -1.7579301461650303`], 
              Complex[1.0415207926952421`, -3.223731221410986]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005736349266972364, -0.023950670673225226`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.223934445763656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7596539959756308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0407366726711693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "Discard", 1, {
              Complex[3.223934445763656, -1.7596539959756308`], 
              Complex[1.0407366726711693`, -3.225518378738008]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005422190001613454, -0.023950670673225084`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08234179217386196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.759653995975626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0407366726711678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "Discard", 2, {
              Complex[0.08234179217386196, -1.759653995975626], 
              Complex[1.0407366726711678`, -3.225518378738005]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005762108320975105, -0.023998602193122984`}],
            RowBox[{"{", 
              
              RowBox[{"37.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2236279912956602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7613709689565495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0399559949092407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "Discard", 1, {
              Complex[3.2236279912956602`, -1.7613709689565495`], 
              Complex[1.0399559949092407`, -3.227299253819592]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0054479490556161156`, -0.023998602193122977`}],
            RowBox[{"{", 
              
              RowBox[{"37.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08203533770586706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7613709689565493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0399559949092405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "Discard", 2, {
              Complex[0.08203533770586706, -1.7613709689565493`], 
              Complex[1.0399559949092405`, -3.227299253819592]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.005787838007818584, -0.0240464312014653}],
            RowBox[{"{", 
              
              RowBox[{"37.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.223323743568807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7630811207006185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.229073895954844`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "Discard", 1, {
              Complex[3.223323743568807, -1.7630811207006185`], 
              Complex[1.039178729026203, -3.229073895954844]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.0054736787424596, -0.02404643120146529}],
            RowBox[{"{", 
              
              RowBox[{"37.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0817310899790139`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.763081120700618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2290738959548437`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "Discard", 2, {
              Complex[0.0817310899790139, -1.763081120700618], 
              Complex[1.039178729026203, -3.2290738959548437`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005813538474704664, -0.02409415843892158}],
            
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2230216784704147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7647845061203178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0384048450451053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "Discard", 1, {
              Complex[3.2230216784704147`, -1.7647845061203178`], 
              Complex[1.0384048450451053`, -3.230842353840041]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005499379209345677, -0.024094158438921546`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08142902488062087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7647845061203167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0384048450451058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840039`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "Discard", 2, {
              Complex[0.08142902488062087, -1.7647845061203167`], 
              Complex[1.0384048450451058`, -3.230842353840039]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005839209867526702, -0.02414178463728365}],
            
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.222721772244943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0376343133880408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "Discard", 1, {
              Complex[3.222721772244943, -1.7664811794589748`], 
              Complex[1.0376343133880408`, -3.2326046755786235`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0055250506021675815`, -0.02414178463728355}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08112911865515363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0376343133880443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "Discard", 2, {
              Complex[0.08112911865515363, -1.7664811794589725`], 
              Complex[1.0376343133880443`, -3.2326046755786213`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005864852330885238, -0.024189310519613413`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.222424001487289`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0368671048690654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.234360908690994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "Discard", 1, {
              Complex[3.222424001487289, -1.7681711943017286`], 
              Complex[1.0368671048690654`, -3.234360908690994]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005550693065526279, -0.024189310519613403`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08083134789749542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0368671048690645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2343609086909946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "Discard", 2, {
              Complex[0.08083134789749542, -1.7681711943017286`], 
              Complex[1.0368671048690645`, -3.2343609086909946`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005890466008104506, -0.024236736800387636`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2221283431362147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.769854603586262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0361031906872582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "Discard", 1, {
              Complex[3.2221283431362147`, -1.769854603586262], 
              Complex[1.0361031906872582`, -3.2361111001240945`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005576306742745539, -0.02423673680038762}],
            
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08053568954642111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7698546035862615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0361031906872573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "Discard", 2, {
              Complex[0.08053568954642111, -1.7698546035862615`], 
              Complex[1.0361031906872573`, -3.2361111001240945`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005916051041247707, -0.02428406418563939}],
            
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.221834774467946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0353425424199543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "Discard", 1, {
              Complex[3.221834774467946, -1.7715314596133196`], 
              Complex[1.0353425424199543`, -3.2378552962607934`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005601891775888734, -0.024284064185639376`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08024212087815223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0353425424199532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "Discard", 2, {
              Complex[0.08024212087815223, -1.7715314596133194`], 
              Complex[1.0353425424199532`, -3.2378552962607934`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005941607571133032, -0.024331293373096627`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2215432730898983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7732018140570123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0345851320160955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2395935429290827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "Discard", 1, {
              Complex[3.2215432730898983`, -1.7732018140570123`], 
              Complex[1.0345851320160955`, -3.2395935429290827`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0056274483057740365`, -0.02433129337309661}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07995061950010503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.773201814057012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.034585132016095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.239593542929082`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "Discard", 2, {
              Complex[0.07995061950010503, -1.773201814057012], 
              Complex[1.034585132016095, -3.239593542929082]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005967135737348306, -0.024378425052318083`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2212538169345617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0338309317897683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.24132588541108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "Discard", 1, {
              Complex[3.2212538169345617`, -1.7748657179749052`], 
              Complex[1.0338309317897683`, -3.24132588541108]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0056529764719893206`, -0.024378425052318083`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0796611633447683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0338309317897687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2413258854110794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "Discard", 2, {
              Complex[0.0796611633447683, -1.7748657179749043`], 
              Complex[1.0338309317897687`, -3.2413258854110794`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00599263567826675, -0.024425459904825864`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.220966384253502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7765232218179048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0330799144138363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2430523684518433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "Discard", 1, {
              Complex[3.220966384253502, -1.7765232218179048`], 
              Complex[1.0330799144138363`, -3.2430523684518433`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005678476412907793, -0.024425459904825902`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07937373066370935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.776523221817905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0330799144138367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.243052368451844`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "Discard", 2, {
              Complex[0.07937373066370935, -1.776523221817905], 
              Complex[1.0330799144138367`, -3.243052368451844]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006018107531061268, -0.02447239860423578}],
            
            RowBox[{"{", 
              
              RowBox[{"38.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2206809536115193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7781743754399488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "Discard", 1, {
              Complex[3.2206809536115193`, -1.7781743754399488`], 
              Complex[1.0323320529137487`, -3.2447730362680187`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005703948265702334, -0.024472398604235807`}],
            RowBox[{"{", 
              
              RowBox[{"38.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07908830002172706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7781743754399495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "Discard", 2, {
              Complex[0.07908830002172706, -1.7781743754399495`], 
              Complex[1.0323320529137487`, -3.2447730362680205`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0060435514317192145`, -0.024519241816384606`}],
            RowBox[{"{", 
              
              RowBox[{"38.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2203975038809194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325563003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "Discard", 1, {
              Complex[3.2203975038809194`, -1.7798192281074985`], 
              Complex[1.0315873206614592`, -3.2464879325563003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.005729392166360235, -0.0245192418163846}],
            RowBox[{"{", 
              
              RowBox[{"38.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07880485029112587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325562994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "Discard", 2, {
              Complex[0.07880485029112587, -1.7798192281074985`], 
              Complex[1.0315873206614592`, -3.2464879325562994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006068967515056689, -0.02456599019945488}],
            
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2201160142359173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7814578285088363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.030845691369485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.248197100501716`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "Discard", 1, {
              Complex[3.2201160142359173`, -1.7814578285088363`], 
              Complex[1.030845691369485, -3.248197100501716]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0057548082496975276`, -0.02456599019945487}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07852336064612488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.781457828508837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0308456913694903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2481971005017125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "Discard", 2, {
              Complex[0.07852336064612488, -1.781457828508837], 
              Complex[1.0308456913694903`, -3.2481971005017125`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006094355914732865, -0.024612644404097175`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.219836464147169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.78309022476319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0301071390850915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.249900582785768`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "Discard", 1, {
              Complex[3.219836464147169, -1.78309022476319], 
              Complex[1.0301071390850915`, -3.249900582785768]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005780196649373832, -0.024612644404097158`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07824381055737564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7830902247631892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.030107139085092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.249900582785767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "Discard", 2, {
              Complex[0.07824381055737564, -1.7830902247631892`], 
              Complex[1.030107139085092, -3.249900582785767]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006119716763263656, -0.02465920507354987}],
            
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2195588333764196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7847164644296638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0293716381846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.251598421594382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "Discard", 1, {
              Complex[3.2195588333764196`, -1.7847164644296638`], 
              Complex[1.0293716381846, -3.251598421594382]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005805557497904721, -0.024659205073549736`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07796617978662179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7847164644296631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0293716381845965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2515984215943754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "Discard", 2, {
              Complex[0.07796617978662179, -1.7847164644296631`], 
              Complex[1.0293716381845965`, -3.2515984215943754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006145050192035647, -0.024705672843756334`}],
            RowBox[{"{", 
              
              RowBox[{"38.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.21928310197127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7863365945159997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0286391633678167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625719`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "Discard", 1, {
              Complex[3.21928310197127, -1.7863365945159997`], 
              Complex[1.0286391633678167`, -3.253290658625719]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005830890926676676, -0.024705672843756403`}],
            RowBox[{"{", 
              
              RowBox[{"38.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0776904483814771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7863365945160001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0286391633678178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625721`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "Discard", 2, {
              Complex[0.0776904483814771, -1.7863365945160001`], 
              Complex[1.0286391633678178`, -3.253290658625721]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006170356331319604, -0.024752048343480115`}],
            RowBox[{"{", 
              
              RowBox[{"38.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2190092502600542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7879506614871665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0279096896525775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2549773350978284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "Discard", 1, {
              Complex[3.2190092502600542`, -1.7879506614871665`], 
              Complex[1.0279096896525775`, -3.2549773350978284`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0058561970659605726`, -0.02475204834348003}],
            RowBox[{"{", 
              
              RowBox[{"38.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.077416596670261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7879506614871654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.027909689652578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.254977335097826`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "Discard", 2, {
              Complex[0.077416596670261, -1.7879506614871654`], 
              Complex[1.027909689652578, -3.254977335097826]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006195635310283585, -0.024798332194417017`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2187372588468346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895587112737734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0271831923694072`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.256658491756127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "Discard", 1, {
              Complex[3.2187372588468346`, -1.7895587112737734`], 
              Complex[1.0271831923694072`, -3.256658491756127]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005881476044924766, -0.024798332194416857`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07714460525703772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.789558711273773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0271831923693993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2566584917561223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "Discard", 2, {
              Complex[0.07714460525703772, -1.789558711273773], 
              Complex[1.0271831923693993`, -3.2566584917561223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006220887257006386, -0.024844525011306257`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2184671086065006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.791160789280331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2583341688807756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "Discard", 1, {
              Complex[3.2184671086065006`, -1.791160789280331], 
              Complex[1.0264596471562961`, -3.2583341688807756`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005906727991647453, -0.024844525011306257`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07687445501670612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7911607892803307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.258334168880775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "Discard", 2, {
              Complex[0.07687445501670612, -1.7911607892803307`], 
              Complex[1.0264596471562961`, -3.258334168880775]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006246112298490259, -0.02489062740203789}],
            
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2181987806799732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.79275694039334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.025739029953579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "Discard", 1, {
              Complex[3.2181987806799732`, -1.79275694039334], 
              Complex[1.025739029953579, -3.2600044062938625`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.005931953033131266, -0.0248906274020379}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07660612709017996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7927569403933397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0257390299535794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "Discard", 2, {
              Complex[0.07660612709017996, -1.7927569403933397`], 
              Complex[1.0257390299535794`, -3.2600044062938625`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006271310560673468, -0.024936639967759244`}],
            RowBox[{"{", 
              
              RowBox[{"39.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2179322564695223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794347208989231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.025021316998925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2616692433664776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "Discard", 1, {
              Complex[3.2179322564695223`, -1.794347208989231], 
              Complex[1.025021316998925, -3.2616692433664776`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.005957151295314272, -0.024936639967759328`}],
            RowBox[{"{", 
              
              RowBox[{"39.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07633960287973203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7943472089892278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0250213169989348`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2616692433664767`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "Discard", 2, {
              Complex[0.07633960287973203, -1.7943472089892278`], 
              Complex[1.0250213169989348`, -3.2616692433664767`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006296482168443321, -0.024982563302978777`}],
            RowBox[{"{", 
              
              RowBox[{"39.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2176675176341636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0243064848224217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "Discard", 1, {
              Complex[3.2176675176341636`, -1.7959316389421525`], 
              Complex[1.0243064848224217`, -3.2633287190256435`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.005982322903084337, -0.02498256330297877}],
            
            RowBox[{"{", 
              
              RowBox[{"39.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07607486404437007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.024306484822421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "Discard", 2, {
              Complex[0.07607486404437007, -1.7959316389421525`], 
              Complex[1.024306484822421, -3.2633287190256435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006321627245648027, -0.025028397995667712`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2174045460851777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7975102736315947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0235945102417783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2649828717610987`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "Discard", 1, {
              Complex[3.2174045460851777`, -1.7975102736315947`], 
              Complex[1.0235945102417783`, -3.2649828717610987`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-0.00600746798028903, -0.02502839799566777}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07581189249538411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.797510273631595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0235945102417785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.264982871761099`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "Discard", 2, {
              Complex[0.07581189249538411, -1.797510273631595], 
              Complex[1.0235945102417785`, -3.264982871761099]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006346745915109144, -0.025074144627360368`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.217143323981706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0228853703576102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.266631739631969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "Discard", 1, {
              Complex[3.217143323981706, -1.7990831559498917`], 
              Complex[1.0228853703576102`, -3.266631739631969]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006032586649750142, -0.025074144627360382`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07555067039191275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0228853703576115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2666317396319684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "Discard", 2, {
              Complex[0.07555067039191275, -1.7990831559498914`], 
              Complex[1.0228853703576115`, -3.2666317396319684`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006371838298633483, -0.02511980377325158}],
            
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2168838337264507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8006503283095574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.022179042548827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.268275360273292`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "Discard", 1, {
              Complex[3.2168838337264507`, -1.8006503283095574`], 
              Complex[1.022179042548827, -3.268275360273292]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006057679033274718, -0.02511980377325137}],
            
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07529118013665538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8006503283095583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0221790425488162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.26827536027329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "Discard", 2, {
              Complex[0.07529118013665538, -1.8006503283095583`], 
              Complex[1.0221790425488162`, -3.26827536027329]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006396904517025045, -0.025165376002293013`}],
            RowBox[{"{", 
              
              RowBox[{"39.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2166260579614594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8022118326504983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0214755044681103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.269913770902438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "Discard", 1, {
              Complex[3.2166260579614594`, -1.8022118326504983`], 
              Complex[1.0214755044681103`, -3.269913770902438]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006082745251666091, -0.025165376002292978`}],
            RowBox[{"{", 
              
              RowBox[{"39.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07503340437166661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.802211832650498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0214755044681099`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2699137709024373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "Discard", 2, {
              Complex[0.07503340437166661, -1.802211832650498], 
              Complex[1.0214755044681099`, -3.2699137709024373`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006421944690096516, -0.025210861877287282`}],
            RowBox[{"{", 
              
              RowBox[{"39.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2163699795640026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.020774734037491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2715470083253844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "Discard", 1, {
              Complex[3.2163699795640026`, -1.8037677104470822`], 
              Complex[1.020774734037491, -3.2715470083253844`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006107785424737416, -0.025210861877287254`}],
            RowBox[{"{", 
              
              RowBox[{"39.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0747773259742065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0207747340374922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2715470083253804`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "Discard", 2, {
              Complex[0.0747773259742065, -1.8037677104470848`], 
              Complex[1.0207747340374922`, -3.2715470083253804`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006446958936680724, -0.025256261954980336`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.216115581642531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.27317510894289`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "Discard", 1, {
              Complex[3.216115581642531, -1.805318002715075], 
              Complex[1.0200767094440117`, -3.27317510894289]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{-0.006132799671321743, -0.02525626195498035}],
            
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0745229280527381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.273175108942891`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "Discard", 2, {
              Complex[0.0745229280527381, -1.805318002715075], 
              Complex[1.0200767094440117`, -3.273175108942891]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[
            PointBox[{-0.006471947374642155, -0.025301576786151907`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2158628475327276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8068627500184498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0193814091354683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "Discard", 1, {
              Complex[3.2158628475327276`, -1.8068627500184498`], 
              Complex[1.0193814091354683`, -3.2747981087565443`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006157788109282877, -0.025301576786151667`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07427019394292937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8068627500184438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0193814091354747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565288`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "Discard", 2, {
              Complex[0.07427019394292937, -1.8068627500184438`], 
              Complex[1.0193814091354747`, -3.2747981087565288`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0064969101208878655`, -0.025346806915704435`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2156117607936308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0186888118162514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.276416043374702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "Discard", 1, {
              Complex[3.2156117607936308`, -1.8084019924760657`], 
              Complex[1.0186888118162514`, -3.276416043374702]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.006182750855528871, -0.025346806915704494`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0740191072038374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0186888118162511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2764160433747036`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "Discard", 2, {
              Complex[0.0740191072038374, -1.8084019924760677`], 
              Complex[1.0186888118162511`, -3.2764160433747036`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004404158687741578, 0.0012417012646909972`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375882, -0.6433017314670934], 
              Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.003429735502141718, -0.0031850963061037327`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.006645071137818129], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00495553668709291, 0.0014832446226693983`}],
            
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665036, -0.6165221792948049], 
              Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.003913452821412689, -0.0036307888689586037`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.006712510785854934], 
              Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005345125040192467, 0.0016755034167271405`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127986, -0.5952855745698065], 
              Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.004266871045765303, -0.003955879663560591}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047798], 
              Complex[6.122517060306257, -1.163371113059422]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005649230128751669, 0.001840100157706035}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234371, -0.5773156862277916], 
              Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.004550093789084668, -0.004216110953577868}],
            
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850742, 0.0068633365731448895`], 
              Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005899568784387168, 0.0019863958589716652`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.813020240902394, -0.5615718710865851], 
              Complex[1.908828689419144, -2.052868131119601]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.004788429173470064, -0.004434927621300826}],
            
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.569036631840206, 0.006943461497604872], 
              Complex[6.068475300453683, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006112620332002091, 0.002119422772886288}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.835170145892391, -0.5474736791133877], 
              Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0049951745978965316`, -0.004624635864647477}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871681], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006298126795255094, 0.002242246514157109}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628703, -0.5346576120369388], 
              Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005178270760382972, -0.004792577822677373}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.5253142371097725`, 0.007110298008162873], 
              Complex[6.023558855884933, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006462360198022832, 0.0023568952733081165`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593927, -0.52287788641464], 
              Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005342877807681538, -0.004943520631640478}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880139], 
              Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0066096121868015395`, 0.0024647921860425823`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906652, -0.5119589442981493], 
              Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00549255749557479, -0.005080752115186903}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243672], 
              Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006742956998184478, 0.002566980917650639}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522108, -0.5017701062164057], 
              Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005629882319462848, -0.005206645067078281}],
            
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884141, 0.007373913179256361], 
              Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0068646769847945715`, 0.002664253640354263}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.9300797102089358, -0.4922109148816913], 
              Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005756777157873431, -0.005322973587083283}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155936, 0.007464952252033912], 
              Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006976515964972332, 0.002757228451389892}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089921, -0.48320212310888055`], 
              Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005874723767137344, -0.005431102340322862}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.436690887655669, 0.007557496991163237], 
              Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00707983808841015, 0.002846398652680905}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078037, -0.47467987499817715`], 
              Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0059848896658278245`, -0.005532105787082018}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937318, 0.0076515243225991425`], 
              Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007175731749576803, 0.0029321654465840116`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460469, -0.46659179640833603`], 
              Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006088212850069383, -0.0056268465190673495`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063904, 0.007747021157202576], 
              Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007265079983412461, 0.003014860388272753}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926878, -0.45889427989730874`], 
              Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006185459454151991, -0.005716028556444167}],
            
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143664, 0.007843982012263403], 
              Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007348609588752034, 0.0030947612585898905`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806893, -0.45155054573492875`], 
              Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006277264170648885, -0.0058002346943138786`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837108, 0.007942407351021055], 
              Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007426926288546381, 0.0031721035681206494`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.024534313536096, -0.4445292235923795], 
              Complex[2.119679474265541, -1.918057531021162]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00636415930916664, -0.005879953341435034}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.00804230239670521], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007500540455283164, 0.003247089076509916}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885552`, -0.43780329333443724`], 
              Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006446596148962164, -0.0059555982341294}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233574], 
              Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007569886298907055, 0.003319892221433289}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791161`, -0.43134927949335167`], 
              Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006524960932018823, -0.006027523196522197}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353644, 0.008246541346654037], 
              Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007635336423644113, 0.0033906650514465416`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468007`, -0.42514662876555165`], 
              Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006599587045726984, -0.006096033380034283}],
            
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.325414662407916, 0.008350912786611275], 
              Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007697213039453826, 0.0034595410672268053`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495686`, -0.4191772220375579], 
              Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0066707644433131345`, -0.0061613939513628395`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.00845680816400054], 
              Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007755796714405676, 0.0035266382525856836`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739518`, -0.41342498695323976`], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0067387470268127385`, -0.006223836898999584}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411541], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007811333290992855, 0.003592061494789895}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145414, -0.4078755867501416], 
              Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00680375850363871, -0.006283566430613609}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.289108069365748, 0.008673251522090971], 
              Complex[5.777450742552286, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007864039412081664, 0.003655904538161073}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.1204149466885311`, -0.40251616773611126`], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006865997083448382, -0.006340763300125244}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995735], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00791410698044825, 0.003718251576471847}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568057`, -0.39733515240586337`], 
              Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006925639282628289, -0.006395588311407795}],
            
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349858974], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007961706790783611, 0.003779178562581557}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326737`, -0.3923220684765709], 
              Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006982843034088065, -0.006448185181188484}],
            
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.254797798340199, 0.009009898497034034], 
              Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008006991512650607, 0.0038387542943868363`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396105`, -0.38746740648134814`], 
              Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007037750250490757, -0.006498682897913373}],
            
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990397], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00805009815936721, 0.0038970413221104767`}],
            
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155862`, -0.382762500281366], 
              Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007090488953250797, -0.006547197680265658}],
            
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694921, 0.009242627557842213], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008091150146026042, 0.0039540967116175685`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728408`, -0.378199426130277], 
              Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007141175053431162, -0.006593834614823331}],
            
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391626], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00813025901638264, 0.004009972690758072}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791763`, -0.3737709168766501], 
              Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007189913851258958, -0.006638689034413157}],
            
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555506, 0.009482273153986658], 
              Complex[5.695312895009785, -1.162653682569165]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008167525900794611, 0.004064717199945559}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.369470288610321], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007236801306431158, -0.006681847685284781}],
            
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122505], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008203042754134861, 0.004118374363780131}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862845`], 
              Complex[2.317691837968342, -1.816262829010749]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007281925120366454, -0.006723389721058039}],
            
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121772], 
              Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008236893412486792, 0.004170984897141971}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418311`, -0.3612284858628565], 
              Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007325365663134038, -0.0067633875536211256`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.180597939390085, 0.00985529184370446], 
              Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00826915449964213, 0.0042225864565628825`}],
            
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.3572763337954378], 
              Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0073671967712899905`, -0.006801907585156863}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384763], 
              Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008299896208374733, 0.004273213945635447}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.253144354246581, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00740748643779154, -0.006839010840806824}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967319`], 
              Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00832918297673087, 0.004322899781607646}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377363`, -0.34968498034029766`], 
              Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007446297411190964, -0.006874753517820827}],
            
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.1507374166916415`, 0.010245449802525813`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0083570740758438, 0.004371674129031273}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.275657357109484, -0.34603696586050564`], 
              Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007483687718173334, -0.006909187464146079}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040012], 
              Complex[5.620051946974447, -1.162340058391703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008383624122816765, 0.004419565105310152}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.286765557155954, -0.34248200518323674`], 
              Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007519711121005676, -0.006942360597107582}],
            
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854463`], 
              Complex[5.609715869645587, -1.162290029994955]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008408883529848206, 0.004466598962172435}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.297780579877745, -0.33901638456087957`], 
              Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007554417519464385, -0.006974317270986913}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.010653838531129443`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008432898898867003, 0.004512800246426184}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214082`, -0.33563662492447366`], 
              Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007587853305195075, -0.007005098600819411}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694102`], 
              Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008455713369402621, 0.004558191942815539}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.319546769980594, -0.3323394622978922], 
              Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007620061675150899, -0.007034742748524406}],
            
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194785, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008477366926159403, 0.004602795601352132}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014382], 
              Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007651082909688808, -0.007063285176499912}],
            
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.011081667776607964`], 
              Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008497896671737143, 0.004646631451131622}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.3409852666152733`, -0.32598084447903347`], 
              Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007680954620028539, -0.007090758873007218}],
            
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798519`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008517337069095464, 0.004689718502343862}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.351590003278767, -0.32291378822242217`], 
              Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.0077097119690587475`, -0.00711719455300705}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.01137834253242333], 
              Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008535720157661266, 0.004732074637934741}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573207, -0.319918100098616], 
              Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007737387868877961, -0.007142620837559066}],
            
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525727997], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00855307574639957, 0.004773716696168788}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799593`, -0.31699136241415216`], 
              Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007764013157962033, -0.007167064414439554}],
            
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931263`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008569431586684736, 0.00481466054516643}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.382982671230815, -0.31413129087274266`], 
              Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007789616760435111, -0.007190550182250233}],
            
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115778`], 
              Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008584813527404924, 0.004854921150342578}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.3933157460094145`, -0.3113357252023996], 
              Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007814225829573923, -0.007213101379970794}],
            
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428713, 0.012001139360437396`], 
              Complex[5.510503169822832, -1.161705165156914]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008599245654392604, 0.004894512635548559}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924137`, -0.3086026206444544], 
              Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007837865877381951, -0.007234739703638055}],
            
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485264`], 
              Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008612750415987143, 0.004933448338613789}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261344`, -0.3059300402110024], 
              Complex[2.522758307852828, -1.730511398029892]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007860560891823168, -0.007255485411606813}],
            
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552492`], 
              Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00862534873629282, 0.004971740861894081}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222573`, -0.3033161476291157], 
              Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00788233344309483, -0.00727535741965364}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164358`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008637060117488575, 0.005009402118356288}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.434060524745711, -0.30075920090048514`], 
              Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007903204780140312, -0.0072943733870202525`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376173, 0.012666429816627254`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008647902732370608, 0.005046443373663731}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589816`, -0.29825754641387064`], 
              Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007923194918450203, -0.007312549794352661}],
            
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854708`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008657893508157289, 0.005082875284669862}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.454112902979397, -0.29580961355530405`], 
              Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007942322720069457, -0.007329902014370802}],
            
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742245`], 
              Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008667048202457358, 0.005118707934679886}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993398`, -0.29341390976756415`], 
              Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007960605966615835, -0.007346444376000313}],
            
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391367`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008675381472190392, 0.005153950865796572}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135785`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.70709401390507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007978061426018007, -0.007362190222608046}],
            
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.9697564531622382`, 0.01337858327951261], 
              Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008682906936152581, 0.005188613108631598}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.0079947049135982, -0.007377151964905557}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.961261553838926, 0.013564516504362838`], 
              Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00868963723183728, 0.005222703209630888}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395204`, -0.28652632543776696`], 
              Complex[2.608435730175939, -1.699727637683005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00801055134805157, -0.007391341129017275}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612012, 0.013753774271608805`], 
              Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008695584067047747, 0.005256229256235377}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.503444825853813, -0.28432602230905957`], 
              Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008025614802811465, -0.007404768400151738}],
            
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.01394644523553293], 
              Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008700758266775672, 0.005289198900074668}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.513189476842979, -0.2821715098398555], 
              Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00803990855323502, -0.007417443662262582}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.01414262133304412], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008705169815764606, 0.005321619378369368}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939458`, -0.280061680393945], 
              Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008053445119995306, -0.007429376034041503}],
            
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008708827897128214, 0.005353497533700142}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.5325712660346489`, -0.2779954793374565], 
              Complex[2.650557449990277, -1.685592253447088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00806623630902461, -0.00744057390154557}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250778`], 
              Complex[5.379881023870964, -1.160554068514124]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008711740927351554, 0.005384839832284777}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034572`, -0.2759719024950626], 
              Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00807829324831641, -0.007451044947726767}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367222`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008713916587965097, 0.005415652380890607}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451707`, -0.27398999380419353`], 
              Complex[2.671487342062719, -1.678805872976879]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.008089626421861385, -0.007460796179100536}],
            
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.014964339414034983`], 
              Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00871536185414877, 0.00544594094249673}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502447`, -0.27204884315225314`], 
              Complex[2.68192509329917, -1.675479597139089]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008100245700964412, -0.007469833949762834}],
            
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436329`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008716083020493136, 0.005475710950809699}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335246`], 
              Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008110160373164182, -0.007478163982941035}],
            
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965335`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008716085724118831, 0.005504967523726411}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.26828539346253044`], 
              Complex[2.702753826320577, -1.668956496466899]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00811937916895513, -0.007485791390241794}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198204`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008715374965331748, 0.005533715475829326}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028523`, -0.26646148678673565`], 
              Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008127910286491544, -0.007492720688739601}],
            
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.8697451279879247`, 0.015850459092959818`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008713955125970244, 0.0055619593299912765`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.5994496576990789`, -0.26467511963294016`], 
              Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008135761414436601, -0.007498955816032125}],
            
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.861557349529051, 0.01608294265041592], 
              Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008711829985581405, 0.005589703328160981}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348713], 
              Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008142939753103227, -0.007504500143372176}],
            
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.0163200694182023], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00870900273554655, 0.005616951441393562}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620054`, -0.2612122109807513], 
              Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008149452034020609, -0.007509356486971433}],
            
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759486`, 0.01656197969868379], 
              Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008705475991259594, 0.005643707379185995}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.6277476075095596`, -0.2595343622253301], 
              Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.008155304538047352, -0.007513527117558}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533064`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00870125180244815, 0.005669974598172302}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.637142374648998, -0.2578914362102892], 
              Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008160503112142106, -0.007517013768256857}],
            
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761326`, 0.017060741491919426`], 
              Complex[5.280454632721417, -1.159256290802515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008696331661713444, 0.005695756310229384}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595256`, -0.2562828635878306], 
              Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008165053184892518, -0.0075198176408511576`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.01731790403871422], 
              Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008690716511352602, 0.0057210554900410625`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210377`, -0.25470810704296915`], 
              Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008168959780895022, -0.007521939410471355}],
            
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.0175804728442376], 
              Complex[5.262480372776144, -1.158970392486303]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008684406748515667, 0.005745874882164998}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106765], 
              Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008172227534070535, -0.007523379228748609}],
            
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213583`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008677402228738203, 0.005770217007644083}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.251658048484637], 
              Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008174860699994438, -0.007524136725459663}],
            
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.796488032915171, 0.018122527898744724`], 
              Complex[5.244507580447731, -1.158666193825158]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008669702267880256, 0.005794084170202837}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.6838947753228468`, -0.25018182541497563`], 
              Complex[2.816682213625116, -1.635923116971627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00817686316731335, -0.007524211008680442}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287773`], 
              Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008661305642492022, 0.005817478462066625}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745874`, -0.2487375751928472], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008178238468316487, -0.007523600663456755}],
            
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008652210588617072, 0.005840401769440973}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.7025179328539397`, -0.2473249107203387], 
              Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008178989788724543, -0.007522303748991369}],
            
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336802`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00864241479903439, 0.005862855777687183}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.711818266170711, -0.24594347356467736`], 
              Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008179119976755828, -0.007520317794337885}],
            
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.7640993290778377`, 0.019279648259930993`], 
              Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008631915418930425, 0.0058848419762301835`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258053`, -0.2445929336962447], 
              Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008178631551526028, -0.0075176397925826085`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954856`, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008620709039983855, 0.005906361663234049}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041993`], 
              Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008177526710835575, -0.007514266193487038}],
            
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995082, 0.01989808875998759], 
              Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008608791692835096, 0.005927415950081697}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.739690532733481, -0.24198336673385532`], 
              Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008175807338396835, -0.007510192894553618}],
            
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.020218096688815523`], 
              Complex[5.181444746812216, -1.157435637212811]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008596158837903344, 0.005948005765695671}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071482`, -0.24072382041628856`], 
              Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008173475010551929, -0.007505415230468578}],
            
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985933], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008582805354503772, 0.0059681318607386425`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.758261707755823, -0.23949413300958816`], 
              Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008170531002531461, -0.0074999279608649605`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.723580109977185, 0.020880984524095002`], 
              Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008568725528206587, 0.0059877948117333666`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947163`, -0.2382941155363085], 
              Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008166976294304299, -0.007493725256339128}],
            
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603414`, 0.021224421666976207`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008553913036369275, 0.00600699502514559}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.776837442159661, -0.23712360765068694`], 
              Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008162811576069325, -0.007486800682642354}],
            
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008538360931760792, 0.006025732741475122}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022496`, -0.23598247799562685`], 
              Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008158037253441166, -0.007479147182957843}],
            
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.021936781873947247`], 
              Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008522061624184939, 0.006044008039404875}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267061`, -0.23487062465998598`], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008152653452384384, -0.0074707570581604744`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795406`, 0.022306351154756415`], 
              Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00850500685999612, 0.006061820840062292}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.8047341113748927`, -0.23378797574120985`], 
              Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.008146660023953119, -0.00746162194494311}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684448`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008487187699386955, 0.006079170911452554}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.814047540666005, -0.23273449001922963`], 
              Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00814005654889752, -0.007451732791678582}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.6746872967000694`, 0.0230740120998302], 
              Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00846859449131116, 0.006096057873130165}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.8233706764978728`, -0.2317101577484136], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008132842342202703, -0.007441079831870331}],
            
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944835`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008449216845888823, 0.006112481201182791}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169915`, -0.23071500157543248`], 
              Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008125016457632719, -0.007429652555027285}],
            
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.023882250111808095`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008429043604122305, 0.006128440233610584}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.8420520682648396`, -0.22974907759194238`], 
              Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008116577692358826, -0.007417439674779186}],
            
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.6500433079634345`, 0.02430261999177399], 
              Complex[5.080861117956597, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008408062804731536, 0.00614393417619482}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.22881247653229805`], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.008107524591760961, -0.00740442909402782}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.64178970149396, 0.024734421969833987`], 
              Complex[5.071567299655017, -1.154523602824754]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008386261647894355, 0.006158962108962414}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.860790544062835, -0.2279053251278246], 
              Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008097855454501795, -0.007390607866905816}],
            
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.633514093134369, 0.025178136640842893`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008363626455654532, 0.006173522993367398}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162653`, -0.22702778763077072`], 
              Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008087568337985799, -0.007375962157289813}],
            
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.625214919738834, 0.025634272402031196`], 
              Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008340142628732183, 0.006187615680327746}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.22618006752276323`], 
              Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008076661064331192, -0.007360477193585588}],
            
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.6168905845521655`, 0.0261033675095845], 
              Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008315794599441966, 0.006201238919276255}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454516`], 
              Complex[3.047400635096297, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008065131227000756, -0.007344137219471722}],
            
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.6085394545164045`, 0.026585992320965875`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008290565780391746, 0.0062143913684074995`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.8984901687203608`, -0.2245751012259816], 
              Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008052976198259041, -0.007326925440253222}],
            
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796535`], 
              Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008264438508597441, 0.006227071606330892}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.22381847645779898`], 
              Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008040193137649171, -0.0073088239644377665`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840515`, 0.02759428790654434], 
              Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008237393984609582, 0.006239278145372174}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.9174784699871426`, -0.22309291692935715`], 
              Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008026779001712484, -0.007289813740103193}],
            
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.583308359957026, 0.02812128309705336], 
              Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008209412206201484, 0.00625100944680385}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.927013515572947, -0.22239885565995451`], 
              Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008012730555210006, -0.0072698744855775885`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.5748328921336294`, 0.02866446296210389], 
              Complex[4.99589327476625, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008180471896119106, 0.006262263938329816}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386594`, -0.22173678013483558`], 
              Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007998044384146783, -0.007248984613897986}],
            
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.566321815756732, 0.029224600034819154`], 
              Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008150550423336005, 0.0062730400342027055`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.22110723592124693`], 
              Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007982716910950542, -0.007227121150454269}],
            
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.029802517604874564`], 
              Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00811962371719467, 0.00628333615841389}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.9558052382062334`, -0.22051083068468325`], 
              Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007966744412214734, -0.007204259643156884}],
            
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211273`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008087666173745534, 0.006293150771470545}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092936`], 
              Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007950123039487132, -0.0071803740643914165`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413904`], 
              Complex[4.956961006232221, -1.149994992121425]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008054650553517104, 0.006302482401360859}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269593`, -0.21942020556585135`], 
              Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007932848843668034, -0.007155436703938763}],
            
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.531882200536309, 0.031652040121196476`], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.008020547869863951, 0.006311329679411392}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.984919912288591, -0.2189275542121152], 
              Complex[3.157220421076432, -1.563457815486074]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007914917803682234, -0.007129418051944901}],
            
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.5231630995005294`, 0.03231048635665899], 
              Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007985327266942522, 0.006319691381863856}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505623`, -0.21847119055042036`], 
              Complex[3.168494941546649, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007896325860207273, -0.007102286670918531}],
            
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234993], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00794895588625733, 0.006327566478144063}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.004538523616137, -0.21805211056251306`], 
              Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00787706895538238, -0.00707400905561712}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.03369708483581626], 
              Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00791139872060026, 0.006334954186969899}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.014417623368864, -0.21767140788446343`], 
              Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007857143079592082, -0.007044549479549446}],
            
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.4967078949018573`, 0.03442779801852968], 
              Complex[4.9069682642347, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00787261845407403, 0.006341854041653285}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667068`, -0.21733028233169743`], 
              Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007836544326622214, -0.007013869826676869}],
            
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.035185322904060734`], 
              Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00783257528674398, 0.00634826596620041}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.2170300494324249], 
              Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007815268958730128, -0.0069819294067319055`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.478798332845711, 0.03597119669747849], 
              Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007791226742302731, 0.006354190364113076}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.0443651392587743`, -0.2167721511036576], 
              Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.0077933134834657, -0.006948684752393079}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.469753862175173, 0.036787077710537186`], 
              Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007748527456956524, 0.006359628222154504}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.2165581676245985], 
              Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007770674744434443, -0.006914089396356243}],
            
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.460645854137856, 0.03763475749771081], 
              Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007704428947552947, 0.0063645812317760795`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.21638983108607387`], 
              Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007747350028624069, -0.0068780936261257485`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.4514713529124292`, 0.03851617446207811], 
              Complex[4.855165682495277, -1.144029106365958]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007658879356766961, 0.006369051931425952}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380015`, -0.2162690405227275], 
              Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007723337193435619, -0.006840644214114218}],
            
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804209], 
              Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00761182317294891, 0.006373043873595141}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.21619787896744103`], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007698634817192792, -0.006801684120387289}],
            
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302233`, 0.04038880139063529], 
              Complex[4.833843395364207, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007563200922019414, 0.00637656182122713}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584692`], 
              Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007673242377671868, -0.006761152165126613}],
            
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.04138476980950441], 
              Complex[4.823037890424123, -1.141619564099015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007512948828578435, 0.00637961197905339}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.1059186388242215`, -0.21621381305374038`], 
              Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007647160464132361, -0.006718982667611797}],
            
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.042424033620649226`], 
              Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007460998443193171, 0.0063822022665591125`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.116430696743796, -0.21630618103294583`], 
              Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007620391029474688, -0.006675105048256308}],
            
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.4044886731783923`, 0.043509537491681564`], 
              Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007407276232658427, 0.006384342640676635}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.127024883972908, -0.21645877538292152`], 
              Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[
            PointBox[{0.007592937690553459, -0.0066294433899841895`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114825`], 
              Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007351703129912377, 0.006386045478008063}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.137705253425444, -0.21667494441768215`], 
              Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007564806086394836, -0.006581915955033589}],
            
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.045832443950466685`], 
              Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0072941940402811095`, 0.006387326028465105}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209172`], 
              Complex[3.347142736911111, -1.54216837655994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007536004306178482, -0.006532434653154709}],
            
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.3752813400511936`, 0.04707723610641603], 
              Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007234657300874908, 0.00638820295477122}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992383`], 
              Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007506543401440071, -0.006480904457190356}],
            
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.04838312541060397], 
              Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007172994090354923, 0.00638869897540821}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.170306785665302, -0.21774382534019746`], 
              Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007476438000143802, -0.006427222762268837}],
            
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.3553179107369844`, 0.049754792118764775`], 
              Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.007109097787053145, 0.006388841632435505}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.2182553516597405], 
              Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00744570704420266, -0.006371278685419202}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.345174865313174, 0.0511974018142957], 
              Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00704285327473736, 0.006388664210324636}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.1925549397581063`, -0.21885330570991673`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007414374676853822, -0.006312952303510327}],
            
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.052716667715368405`], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00697413619741904, 0.006388206837715203}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.2195438662043097], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007382471312224028, -0.006252113829262181}],
            
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952697], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006902812167861783, 0.006387517811024752}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.2152615870464745`, -0.2203339164903331], 
              Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007350034926673185, -0.0061886227280340475`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.314039845823023, 0.05601119898888117], 
              Complex[4.696326724353138, -1.12850882102276]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0068287359393694, 0.006386655187360315}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.2268005544144556`, -0.22123113894674887`], 
              Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00731711262033514, -0.006122326782660048}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375003`, 0.05780132763801396], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006751750557731126, 0.006385688704414603}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.23847095502768, -0.2222441235311438], 
              Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007283762507945374, -0.006053061120491605}],
            
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180628, 0.059698042168788046`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0066716865208833916`, 0.0063847020971771855`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.250278721787946, -0.22338249250843553`], 
              Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007250056010790458, -0.005980647227024181}],
            
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.2817307812779952`, 0.061711105883242925`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0065883609893169085`, 0.00638379589543476}],
            
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838817`, -0.2246570435317342], 
              Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007216080636576062, -0.005904891985445049}],
            
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.06385145452602974], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006501577112461895, 0.006383090802020721}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007181943351111834, -0.005825586803105942}],
            
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.2594613930506555`, 0.06613136000835836], 
              Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00641112356787924, 0.006382731768988801}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.2865864863773204`, -0.2276647637711871], 
              Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007147774664437881, -0.0057425069170002445`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672782`, 0.06856461676025145], 
              Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006316774454646265, 0.00638289290587535}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.2990036923040837`, -0.2294269927942462], 
              Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007113733573044816, -0.005655411014460322}],
            
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.23655245953774, 0.07116675231062944], 
              Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006218289744511853, 0.006383783368069812}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.311587489979285, -0.23138396931833907`], 
              Complex[3.539668711719687, -1.54125837029078]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007080013516417134, -0.005564041367288539}],
            
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.2248441119132174`, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006115416580043515, 0.006385654378679621}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.324342656755631, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.007046849515090983, -0.00546812476346128}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.212959979911501, 0.07694987142173919], 
              Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.006007891824868904, 0.006388807524833571}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.2359630690132302], 
              Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007014526649644761, -0.005367374637547927}],
            
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.20089626382986, 0.0801728075757009], 
              Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005895446424012056, 0.006393604423603219}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577226`, -0.23863220192231419`], 
              Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0069833900001905645`, -0.005261494956441067}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.18865053484601, 0.08364909334179278], 
              Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005777812326681393, 0.006400477748880245}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.3636672947096224`, -0.24159066834690415`], 
              Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006953856069310419, -0.005150186616235836}],
            
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.176222295931689, 0.08740682313953917], 
              Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005654732956759758, 0.006409943411022604}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517165`, -0.24486976056502352`], 
              Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006926425520139373, -0.005033157347494877}],
            
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034565`, 0.09147740408549974], 
              Complex[4.519597775965093, -1.093160763626926]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005525978467786626, 0.006422613332318775}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358295`, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006901696721048573, -0.004910136391563498}],
            
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.1508305149179034`, 0.09589570953158899], 
              Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005391367235954809, 0.006439207694310066}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889628, -0.25253232740394693`], 
              Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006880379028171625, -0.004780895448773834}],
            
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.137883196665494, 0.10070007254234226`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005250795114131151, 0.006460564674100581}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.66780561916792, -1.560366273382241]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006863303879392213, -0.004645277500061487}],
            
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.124788364875778, 0.1059320141880026], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.005104273688764279, 0.006487644491183855}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.26193749411720374`], 
              Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006851430567034495, -0.004503234864527086}],
            
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320068`, 0.11163556486001101`], 
              Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004951977831109566, 0.00652152311236422}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059935], 
              Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0068458420497782245`, -0.004354876956186376}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.098263114072366, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004794300803072048, 0.006563369501820835}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.4608658796691665`, -0.2734383645589258], 
              Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006847724636377115, -0.0042005262233381635`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981808, 0.1246378257982292], 
              Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004631911706723562, 0.006614399551845331}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.4750284976365355`, -0.28008223230347307`], 
              Complex[3.736478521301466, -1.58190695616248]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006858324508749422, -0.004040777313780254}],
            
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918281, 0.1320217921353984], 
              Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004465805208462557, 0.006675800992047585}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.4891027727434665`, -0.2873682998621285], 
              Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006878875054138919, -0.003876549626473281}],
            
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.0583200745943513`, 0.1400410254670661], 
              Complex[4.393335070431694, -1.040700701679103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004297328275980587, 0.00674862815068923}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697787`, -0.29531732776612113`], 
              Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006910493371365069, -0.003709118091739843}],
            
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009868`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.004128165705431827, 0.0068336743500188755`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.5166444532991594`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006954053092089783, -0.0035401038000339967`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.1580516738214428], 
              Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.003960269231094745, 0.006931341719867766}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509884`, -0.31319809514055186`], 
              Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007010052684019198, -0.0033714087352561053`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132126`, 0.16802967600526134`], 
              Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0037957268363363232`, 0.007041538600702441}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771702`, -0.3230721172560292], 
              Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007078509069618433, -0.003205090309948305}],
            
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.17861007860412123`], 
              Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.003636587994640706, 0.007163636312426374}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.5550227978429705`, -0.33349241406049857`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007158908538289072, -0.003043190315438011}],
            
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.1897302873440814], 
              Complex[4.317427040750872, -0.984655324990569]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.003484679169905803, 0.00729650487957195}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.5666918389490667`, -0.3443779449095298], 
              Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00725023537805525, -0.0028875516804539713`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859258`, 0.20130934934494918`], 
              Complex[4.303885430470007, -0.971377104797334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0033414513010578393`, 0.007438624038399555}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946193`], 
              Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007351075824860772, -0.0027396643987192496`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474694`, 0.21325435309295854`], 
              Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.003207891482901415, 0.007588242419902652}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.588031851130083, -0.3671682712416466], 
              Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007459771498093976, -0.002600573216291703}],
            
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.965814938226205, 0.22546793870233256`], 
              Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.003084509282164351, 0.0077435461674729795`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.3788808057418005], 
              Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007574584416789845, -0.0024708584754158333`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.2378553727309031], 
              Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00297138582765619, 0.007902802649640469}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.606650933262854, -0.3906866010723904], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007693839446646163, -0.0023506793966429993`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771455`], 
              Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0028682609375344902`, 0.008064459970332229}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.6149863657999486`, -0.40251041678372024`], 
              Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007816024515374382, -0.0022398560042644045`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.9412066320031385`, 0.2628167267283543], 
              Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.002774632471938955, 0.008227199341706414}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.6227207308158538`, -0.41428986426444875`], 
              Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007939845009034484, -0.002137964423894443}],
            
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.27525317641875774`], 
              Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0026898488335129183`, 0.00838994849504478}],
            
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.629897485254924, -0.42597525546826037`], 
              Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008064239852775192, -0.002044426619245031}],
            
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.28758976049421764`], 
              Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0026131844613098225`, 0.008551868635054331}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.636561822697944, -0.4375284851167467], 
              Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008188371253437595, -0.0019585842864226067`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.921944339934747, 0.2997884495937316], 
              Complex[4.222645506003507, -0.856274787217682]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0025438954873642713`, 0.008712326831595157}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826854`, -0.4489214364481581], 
              Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008311599663929067, -0.0018797538202556447`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934106`], 
              Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0024812571835082326`, 0.008870862832774783}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.648529805818011, -0.4601342612759221], 
              Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008433452789374105, -0.0018072637050421906`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.323668241424401], 
              Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.002424586767977247, 0.009027156022397244}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.653915808537619, -0.4711537472500261], 
              Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.008553594313034117, -0.001740477661679793}],
            
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.90687121326868, 0.33531642890390234`], 
              Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0023732554616437735`, 0.009180995586133592}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500918, -0.48197187877303665`], 
              Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008671795430373866, -0.0016788072610980091`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669044`, 0.3467578191386486], 
              Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0023266931982218395`, 0.009332255135689173}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.6636739953559614`, -0.49258462786579826`], 
              Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008787910496531322, -0.0016217172844490678`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.3579884536883491], 
              Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.002284388639649425, 0.009480871960923332}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751523, -0.50299097090211], 
              Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008901857022019496, -0.0015687264027154496`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.8949272831009005`, 0.36900737727295585`], 
              Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.002245886409758799, 0.009626830525436744}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.6722845561748567`, -0.5131921073476409], 
              Complex[3.989240598169983, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009013599693651937, -0.0015194050432655207`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485174`, 0.37981585653752775`], 
              Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.002210782849937826, 0.009770149595409968}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724435], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00912313786325928, -0.0014733717236971387`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379943`, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0021787211424178945`, 0.009910872349984133}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598123], 
              Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009230495895245725, -0.0014302886892903174`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346624], 
              Complex[4.173308062162179, -0.735357851265334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.002149386322919942, 0.010049058870922592`}],
            
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885688], 
              Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009335715804080208, -0.0013898573748195252`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.8825075055343556`, 0.41101275787833075`], 
              Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.00212250048542325, 0.010184780494988001`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.6868312180069145`, -0.5520158986267104], 
              Complex[4.009806376364359, -1.880054831501801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00943885169051318, -0.0013518139970725563`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.42101794594737985`], 
              Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0020978183392252573`, 0.010318115605164225`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399855`, -0.5612511491377956], 
              Complex[4.01438190088909, -1.890520862682429]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.009539965571567399, -0.001315925444021571}],
            
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148396`, 0.4308353192168015], 
              Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0020751231888623167`, 0.010449146522606227`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.693056602464925, -0.5703092165540393], 
              Complex[4.018766629721939, -1.900792375423005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.009639124280104746, -0.001281985537768693}],
            
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.4404706516054349], 
              Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0020542233533778678`, 0.010577957234622614`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.695956129918709, -0.5791958590266285], 
              Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.009736397179397, -0.001249811694279275}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.8729290323659913`, 0.4499297609478434], 
              Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.002034949010471003, 0.010704631754098701`}],
            
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.698728344803272, -0.5879167986060275], 
              Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009831854495397944, -0.0012192419715179883`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.8708731122295896`, 0.4592184279956057], 
              Complex[4.152955626516613, -0.664447166754532]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0020171494347764073`, 0.010829252953603005`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911527], 
              Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[
            PointBox[{0.009925566115159223, -0.0011901324806878565`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370305`, 0.4683423384869718], 
              Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0020006905922883788`, 0.010951901754798534`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011073], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.010017600735679777`, -0.001162355127350909}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.477307042638535], 
              Complex[4.147506625196923, -0.642348121441579]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0019854530510928117`, 0.011072656582629483`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.613140979653751], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.010108025275217815`, -0.001135795646693211}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.48611792774323803`], 
              Complex[4.144979724610491, -0.631560836108617]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001971330169774979, 0.011191593015839421`}],
            
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.708723978803601, -0.6212539145605391], 
              Complex[4.041793889306879, -1.958660288701135]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010196904480376811`, -0.0011103518977908077`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426793`, 0.49478020058417876`], 
              Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.0019582265276733833`, 0.0113087835821911}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 1, {
              Complex[2.710987197779323, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010284300678514761`, -0.0010859323839952965`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 2, {
              Complex[2.8621480115494466`, 0.503298877159704], 
              Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0019460565646611762`, 0.011424297659514547`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 1, {
              Complex[2.7131687671511795`, -0.6370671424983351], 
              Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010370273637370753`, -0.0010624549695995452`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 2, {
              Complex[2.860663808423174, 0.5116787778163023], 
              Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001934743401831926, 0.011538201453363713`}],
            
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 1, {
              Complex[2.71527400291423, -0.6447767740762022], 
              Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.01045488050316592, -0.0010398457662402544`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 2, {
              Complex[2.8592528632013723`, 0.5199245263444046], 
              Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0019242178180515952`, 0.011650558029361997`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 1, {
              Complex[2.717307750554921, -0.6523609855265123], 
              Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010538175795529252`, -0.0010180381657406143`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 2, {
              Complex[2.857910352423154, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001914417360658839, 0.011761427383827874`}],
            
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 1, {
              Complex[2.7192744356306133`, -0.6598239647344449], 
              Complex[4.057727034812088, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01062021144296853, -0.0009969719991328267}],
            
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 2, {
              Complex[2.8566318723517807`, 0.5360310932164641], 
              Complex[4.132077284632824, -0.570171279993703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0019052855715839413`, 0.011870866540435367`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 1, {
              Complex[2.7211781081510784`, -0.6671697152100743], 
              Complex[4.060641656654434, -2.01093044740819]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010701036846671405`, -0.0009765928043511218}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 2, {
              Complex[2.8554133945952374`, 0.543900203601609], 
              Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.001896771312796193, 0.01197892966380501}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 1, {
              Complex[2.7230224815870465`, -0.6744020624307276], 
              Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010780698963497292`, -0.0009568511875271273}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 2, {
              Complex[2.854251227099731, 0.5516517577146821], 
              Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001888828177290202, 0.012085668183291496`}],
            
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 1, {
              Complex[2.724810967217476, -0.6815246607732999], 
              Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010859242401349842`, -0.0009377022649557592}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 2, {
              Complex[2.8531419798044717`, 0.5592894583048513], 
              Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018814139738110153`, 0.012191130922023412`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 1, {
              Complex[2.7265467044285883`, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010936709521880634`, -0.0009191051746510174}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 2, {
              Complex[2.852082534344649, 0.5668168435275388], 
              Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018744902752250128`, 0.012295364227597553`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 1, {
              Complex[2.7282325874925664`, -0.6954544165180527], 
              Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011013140546808988`, -0.0009010226480053244}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 2, {
              Complex[2.8510700172747567`, 0.5742372943510567], 
              Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018680220219057337`, 0.012398412101845478`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 1, {
              Complex[2.729871289280439, -0.7022680930260651], 
              Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011088573665149766`, -0.0008834206334314602}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 2, {
              Complex[2.850101776357696, 0.5815540419531228], 
              Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018619771727493672`, 0.012500316327852692`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 1, {
              Complex[2.7314652823007664`, -0.7089850735194753], 
              Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011163045139402937`, -0.0008662679650336009}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 2, {
              Complex[2.8491753595280755`, 0.5887701750046822], 
              Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001856326397496573, 0.012601116592982171`}],
            
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 1, {
              Complex[2.733016857401756, -0.7156082665076033], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011236589409331903`, -0.0008495360703489109}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 2, {
              Complex[2.848288496192057, 0.5958886467685786], 
              Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018510428049402878`, 0.012700850607081322`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 1, {
              Complex[2.734528140428245, -0.7221404526376912], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011309239192389851`, -0.0008331987120488206}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 2, {
              Complex[2.847439080572326, 0.6029122819634529], 
              Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018461017023672418`, 0.01279955421536846}],
            
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 1, {
              Complex[2.736001107085408, -0.7285842912785057], 
              Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011381025580175586`, -0.0008172317592111786}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 2, {
              Complex[2.8466251568463186`, 0.6098437833604624], 
              Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001841480382235287, 0.012897261505728702`}],
            
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 1, {
              Complex[2.7374375962271382`, -0.7349423268176083], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01145197813054234, -0.0008016129843888049}],
            
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 2, {
              Complex[2.845844905859744, 0.6166857380933649], 
              Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018371579326437956`, 0.012994004910321206`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 1, {
              Complex[2.7388393217580846`, -0.7412169946624545], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011522124955160513`, -0.0007863218832241038}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001833115068630639, 0.013089815301522034`}],
            
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 1, {
              Complex[2.7402078833132797`, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011591492802466567`, -0.0007713395138053449}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 2, {
              Complex[2.8443787586507785`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018293339817313952`, 0.013184722082315633`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 1, {
              Complex[2.7415447758580713`, -0.7535254579157126], 
              Complex[4.092654956897793, -2.109452014313655]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.01166010713602466, -0.00075664835334214}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 2, {
              Complex[2.843689806329271, 0.6366985832782687], 
              Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018257982055838121`, 0.01327875327130758}],
            
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 1, {
              Complex[2.742851398332544, -0.7595636290829759], 
              Complex[4.094763792064631, -2.11634961995984]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011727992208395172`, -0.0007422321700625554}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 2, {
              Complex[2.8430283963083336`, 0.6432061141597183], 
              Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018224924956549006`, 0.013371935582571827`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 1, {
              Complex[2.744129061448893, -0.7655271940238008], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011795171130650504`, -0.0007280759085136072}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 2, {
              Complex[2.842393236688587, 0.6496354995683534], 
              Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.001819402721421859, 0.0134642945005705}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 1, {
              Complex[2.745378994736478, -0.7714181229593412], 
              Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.011861665937710025`, -0.000714165586685547}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 2, {
              Complex[2.8417831165816425`, 0.6559887487872518], 
              Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018165157695544572`, 0.01355585435039815}],
            
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 1, {
              Complex[2.746602352917594, -0.7772383070571701], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011927497649685086`, -0.0007004882035852938}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 2, {
              Complex[2.8411968997361448`, 0.6622677914714884], 
              Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018138194568339328`, 0.01364663836360766}],
            
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 1, {
              Complex[2.7478002216867257`, -0.7829895624892164], 
              Complex[4.102814974771636, -2.143119636338954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011992686329435643`, -0.0006870316560606285}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 2, {
              Complex[2.8406335187602902`, 0.6684744817167128], 
              Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018113024517035156`, 0.013736668739874855`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 1, {
              Complex[2.748973622957287, -0.7886736342555815], 
              Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01205725113654469, -0.0006737846638289309}],
            
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 2, {
              Complex[2.8400919698768647`, 0.6746106018933697], 
              Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018089542034844118`, 0.013825966704753473`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409572, -2.156041173845927]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01212121037791597, -0.0006607367017944123}],
            
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 2, {
              Complex[2.8395713081544542`, 0.6806778662591643], 
              Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001806764878410631, 0.013914552563765104`}],
            
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 1, {
              Complex[2.751250819947598, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01218458155519666, -0.0006478779388520372}],
            
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 2, {
              Complex[2.839070643165216, 0.6866779243621389], 
              Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001804725301739955, 0.014002445753058554`}],
            
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 1, {
              Complex[2.7523563814347085`, -0.8053392041803537], 
              Complex[4.11031899238399, -2.168673807450607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012247381409221257`, -0.0006351991824726737}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 2, {
              Complex[2.838589135025258, 0.6926123642464805], 
              Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018028269052875155`, 0.01408966488686202}],
            
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 1, {
              Complex[2.7534410145367234`, -0.8107706896206492], 
              Complex[4.112118632879193, -2.174886099543967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012309625961664432`, -0.0006226918284508866}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 2, {
              Complex[2.8381259907789103`, 0.6984827154726537], 
              Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0018010616798068274`, 0.014176227801940307`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 1, {
              Complex[2.7545054859170786`, -0.8161427678288303], 
              Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012371330554082531`, -0.0006103478152686843}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 2, {
              Complex[2.8376804610924062`, 0.7042904519630285], 
              Complex[4.102309515593154, -0.359742624540917]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.001799422131710598, 0.01426215159925674}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012432509884514156`, -0.0005981595825939373}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 2, {
              Complex[2.8372518372264883`, 0.710036994683633], 
              Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017979012436829724`, 0.01434745268302758}],
            
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 1, {
              Complex[2.7565768091900997`, -0.8267141994476596], 
              Complex[4.117350770809639, -2.193126103819013]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012493178041800664`, -0.0005861200334874983}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 2, {
              Complex[2.836839448260752, 0.7157237141721116], 
              Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017964924387861927`, 0.014432146797345766`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 1, {
              Complex[2.7575850015374925`, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012553348537778036`, -0.0005742224999420994}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 2, {
              Complex[2.8364426585455744`, 0.7213519329214126], 
              Complex[4.100239116839224, -0.338101803538321]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017951895477098002`, 0.014516249060537835`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 1, {
              Complex[2.7585757179660733`, -0.8370640075328957], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.012613034337482199`, -0.000562460711418759}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 2, {
              Complex[2.836060865360036, 0.7269229276281965], 
              Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017939867788498542`, 0.014599773997408633`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 1, {
              Complex[2.759549546988155, -0.8421588862221198], 
              Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012672247887500985`, -0.0005508287660837449}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 2, {
              Complex[2.8356934967565883`, 0.732437931314428], 
              Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017928786909405363`, 0.014682735569516672`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 1, {
              Complex[2.760507048180339, -0.8472019743388879], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012731001142596851`, -0.0005393211044820282}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 2, {
              Complex[2.8353400095752215`, 0.7378981353300624], 
              Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017918601679905108`, 0.01476514720361386}],
            
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 1, {
              Complex[2.7614487540168455`, -0.8521943919901349], 
              Complex[4.12556733480281, -2.222290341327314]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012789305590716761`, -0.0005279324854120356}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 2, {
              Complex[2.8349998876116986`, 0.7433046912443027], 
              Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017909263963034898`, 0.014847021818373747`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 1, {
              Complex[2.762375171562624, -0.8571372217260823], 
              Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012847172276496946`, -0.0005166579637915852}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 2, {
              Complex[2.8346726399259916`, 0.7486587126323618], 
              Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017900728433858145`, 0.014928371849523626`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 1, {
              Complex[2.7632867840386814`, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012904611823363743`, -0.0005054928703278456}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 2, {
              Complex[2.8343577992784867`, 0.7539612767642822], 
              Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.001789295238564948, 0.01500920927348791}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 1, {
              Complex[2.764184052270831, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.012961634454323873`, -0.000494432792823041}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 2, {
              Complex[2.8340549206827474`, 0.7592134262018864], 
              Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.001788589555160745, 0.01508954562964213}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 1, {
              Complex[2.765067416031943, -0.8716784802620265], 
              Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013018250011531519`, -0.00048347355896615667`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 2, {
              Complex[2.8337635800647583`, 0.764416170309563], 
              Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017879519940678934`, 0.015169392041270421`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 1, {
              Complex[2.7659372952868275`, -0.8764330896595155], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013074467974713136`, -0.0004726112204751955}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017873789686225728`, 0.01524875923531208}],
            
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 1, {
              Complex[2.7667940913479225`, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01313029747852557, -0.0004618420384692269}],
            
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 2, {
              Complex[2.8332139136568895`, 0.7746773225093263], 
              Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017868670906388568`, 0.015327657560976886`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 1, {
              Complex[2.7676381879492564`, -0.8858091496519156], 
              Complex[4.136164053701611, -2.260791305494017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013185747328917127`, -0.0004511624699611084}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 2, {
              Complex[2.83295483352893, 0.7797375958378118], 
              Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017864131575116122`, 0.015406097007303695`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 1, {
              Complex[2.768469952245414, -0.8904323517124777], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013240826018556962`, -0.0004405691553726185}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 2, {
              Complex[2.8327057806325184`, 0.7847521968079433], 
              Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017860141402935921`, 0.015484087219730464`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 1, {
              Complex[2.7692897357415935`, -0.8950134580602265], 
              Complex[4.139022292544098, -2.271338727751554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01329554174139317, -0.0004300589069836655}],
            
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017856671726623166`, 0.015561637515739867`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 1, {
              Complex[2.770097875160309, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013349902406395575`, -0.00041962869823538023`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 2, {
              Complex[2.83223642523709, 0.7946478095124515], 
              Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001785369540701635, 0.015638756899639956`}],
            
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 1, {
              Complex[2.770894693249766, -0.9040526005333875], 
              Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013403915650535865`, -0.00040927565381514093`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 2, {
              Complex[2.832015492909507, 0.7995304720360317], 
              Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017851186734288344`, 0.015715454076534595`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 1, {
              Complex[2.771680499538499, -0.9085121854432784], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013457588851053191`, -0.00039899704045785696`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 2, {
              Complex[2.8318033265960922`, 0.8043707658042935], 
              Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017849121340058878`, 0.015791737465535294`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 1, {
              Complex[2.772455591040422, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01351092913705073, -0.0003887902584044077}],
            
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 2, {
              Complex[2.8315996437819138`, 0.8091694575484238], 
              Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017847476115780093`, 0.015867615212261897`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 1, {
              Complex[2.773220252914124, -0.9173150854995425], 
              Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013563943400465088`, -0.00037865283346336976`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 2, {
              Complex[2.8314041736809603`, 0.8139272921843714], 
              Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017846229136886163`, 0.01594309520067657}],
            
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 1, {
              Complex[2.7739747590798687`, -0.9216598178919512], 
              Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013616638306447555`, -0.00036858240962739467`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 2, {
              Complex[2.8312166566204735`, 0.8186449936599106], 
              Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017845359592247052`, 0.016018185064291902`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 1, {
              Complex[2.774719372797445, -0.9259676497839711], 
              Complex[4.148512526970578, -2.306826396101705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013669020303193842`, -0.00035857674219958753`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 2, {
              Complex[2.8310368434643864`, 0.8233232657606014], 
              Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017844847718495517`, 0.01609289219679253}],
            
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 1, {
              Complex[2.775454347207829, -0.9302392405994732], 
              Complex[4.149808341378721, -2.311725622493254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013721095631256024`, -0.00034863369138975203`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 2, {
              Complex[2.8308644950729818`, 0.8279627928769887], 
              Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017844674738848765`, 0.016167223762104502`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 1, {
              Complex[2.776179925841262, -0.9344752314248258], 
              Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013772870332368289`, -0.0003387512163435377}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 2, {
              Complex[2.8306993817960873`, 0.8325642407352367], 
              Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004089999422382611, 0.0012417012646909612`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 1, {
              Complex[3.8395927484273833`, -0.6433017314670934], 
              Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0031155762367827294`, -0.0031850963061037262`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 2, {
              Complex[7.8360190079650485`, 0.006645071137818026], 
              Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004641377421733957, 0.0014832446226694022`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 1, {
              Complex[3.8749809118562997`, -0.6165221792948034], 
              Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0035992935560537134`, -0.0036307888689586015`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 2, {
              Complex[7.795901779221279, 0.006712510785854963], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005030965774833473, 0.0016755034167271288`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 1, {
              Complex[3.9045700992025902`, -0.5952855745698094], 
              Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.003952711780406265, -0.003955879663560543}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 2, {
              Complex[7.763484521798694, 0.006786025025048383], 
              Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005335070863392686, 0.0018401001577060244`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 1, {
              Complex[3.93075079131323, -0.5773156862277917], 
              Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.004235934523725686, -0.00421611095357787}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 2, {
              Complex[7.735547972440535, 0.006863336573144897], 
              Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005585409519028197, 0.0019863958589716848`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 1, {
              Complex[3.9546128944921874`, -0.5615718710865847], 
              Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.004474269908111086, -0.004434927621300828}],
            
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 2, {
              Complex[7.710629285429999, 0.00694346149760476], 
              Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005798461066643097, 0.0021194227728862846`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 1, {
              Complex[3.976762799482182, -0.5474736791133854], 
              Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0046810153325375576`, -0.0046246358646474745`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 2, {
              Complex[7.687917286732913, 0.007025882918871702], 
              Complex[6.045167287063117, -1.163332885610651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0059839675298961285`, 0.0022422465141571117`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 1, {
              Complex[3.997579366252664, -0.5346576120369394], 
              Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.004864111495023978, -0.004792577822677356}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 2, {
              Complex[7.666906890699567, 0.007110298008162871], 
              Complex[6.023558855884935, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00614820093266385, 0.0023568952733081295`}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 1, {
              Complex[4.017318225749185, -0.5228778864146391], 
              Complex[1.970954950697273, -2.009827028796297]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005028718542322557, -0.004943520631640469}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 2, {
              Complex[7.6472584862388935`, 0.007196517077880152], 
              Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006295452921442564, 0.0024647921860425936`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 1, {
              Complex[4.036161628380458, -0.5119589442981466], 
              Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005178398230215783, -0.005080752115186951}],
            
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 2, {
              Complex[7.628730822140306, 0.0072844163322486775`], 
              Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006428797732825525, 0.0025669809176506134`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 1, {
              Complex[4.054245015542006, -0.5017701062164085], 
              Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.005315723054103852, -0.0052066450670782746`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 2, {
              Complex[7.611145277473936, 0.007373913179256576], 
              Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0065505177194355845`, 0.002664253640354264}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 1, {
              Complex[4.071672363798729, -0.49221091488169333`], 
              Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0054426178925144715`, -0.005322973587083304}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 2, {
              Complex[7.5943652547457265`, 0.0074649522520338], 
              Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00666235669961335, 0.0027572284513898834`}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 1, {
              Complex[4.088525607498785, -0.4832021231088809], 
              Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005560564501778379, -0.005431102340322847}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 2, {
              Complex[7.5782835412454626`, 0.0075574969911607935`], 
              Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006765678823051175, 0.002846398652680939}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 1, {
              Complex[4.104870714597597, -0.4746798749981737], 
              Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.005670730400468822, -0.005532105787082}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 2, {
              Complex[7.5628141695271145`, 0.007651524322598731], 
              Complex[5.915830554816423, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006861572484217842, 0.0029321654465840103`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 1, {
              Complex[4.12076176343584, -0.46659179640833626`], 
              Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.0057740535847104115`, -0.00562684651906732}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 2, {
              Complex[7.547886962653699, 0.00774702115719995], 
              Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00695092071805349, 0.003014860388272755}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 1, {
              Complex[4.13624377018248, -0.4588942798973108], 
              Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005871300188792999, -0.005716028556444156}],
            
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 2, {
              Complex[7.533443755733459, 0.007843982012263152], 
              Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007034450323393035, 0.003094761258589867}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 1, {
              Complex[4.151354705396683, -0.4515505457349306], 
              Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.005963104905289921, -0.005800234694313881}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 2, {
              Complex[7.5194357044269005`, 0.007942407351021058], 
              Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007112767023187392, 0.0031721035681206763`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 1, {
              Complex[4.166126967125889, -0.44452922359237873`], 
              Complex[2.119679474265542, -1.918057531021161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006050000043807653, -0.005879953341435031}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 2, {
              Complex[7.5058213212730225`, 0.008042302396705316], 
              Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007186381189924173, 0.003247089076509907}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 1, {
              Complex[4.180588479578346, -0.43780329333443724`], 
              Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006132436883603195, -0.0059555982341293985`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 2, {
              Complex[7.492565012985164, 0.008143676269233487], 
              Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007255727033548082, 0.003319892221433293}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 1, {
              Complex[4.194763527568909, -0.43134927949335283`], 
              Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0062108016666598456`, -0.0060275231965221995`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 2, {
              Complex[7.479635970943437, 0.008246541346654087], 
              Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007321177158285124, 0.0033906650514465286`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 1, {
              Complex[4.208673400536594, -0.42514662876555215`], 
              Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0062854277803679835`, -0.006096033380034313}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 2, {
              Complex[7.4670073159977095`, 0.008350912786614366], 
              Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00738305377409484, 0.0034595410672268213`}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 1, {
              Complex[4.222336896739361, -0.41917722203755803`], 
              Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0063566051779541536`, -0.006161393951362845}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 2, {
              Complex[7.454655429824251, 0.008456808164000526], 
              Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007441637449046705, 0.003526638252585695}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 1, {
              Complex[4.2357707230637445`, -0.41342498695324215`], 
              Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006424587761453763, -0.00622383689899958}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 2, {
              Complex[7.442559425423676, 0.008564247194411552], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007497174025633891, 0.00359206149478991}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 1, {
              Complex[4.248989815735208, -0.4078755867501412], 
              Complex[2.203596585722578, -1.872357412196735]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006489599238279732, -0.006283566430613615}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 2, {
              Complex[7.430700722955541, 0.008673251522090992], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007549880146722695, 0.0036559045381610593`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 1, {
              Complex[4.262007600278324, -0.4025161677361105], 
              Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006551837818089398, -0.006340763300125241}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 2, {
              Complex[7.419062706397297, 0.008783844556995738], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007599947715089268, 0.0037182515764718513`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 1, {
              Complex[4.274836204246599, -0.39733515240586165`], 
              Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006611480017269311, -0.006395588311407797}],
            
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 2, {
              Complex[7.4076304429802775`, 0.00889605134985899], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0076475475254246215`, 0.003779178562581551}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 1, {
              Complex[4.287486632822467, -0.39232206847656975`], 
              Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006668683768729073, -0.006448185181188466}],
            
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 2, {
              Complex[7.396390451929997, 0.009009898497033932], 
              Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007692832247291635, 0.0038387542943868376`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 1, {
              Complex[4.299968914929404, -0.38746740648134725`], 
              Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006723590985131776, -0.006498682897913378}],
            
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 2, {
              Complex[7.3853305123250825`, 0.009125414068990404], 
              Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007735938894008249, 0.003897041322110457}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 1, {
              Complex[4.31229222570538, -0.3827625002813669], 
              Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0067763296878918045`, -0.006547197680265639}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 2, {
              Complex[7.374439502284718, 0.00924262755784085], 
              Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007776990880667084, 0.003954096711617569}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 1, {
              Complex[4.324464989862636, -0.3781994261302779], 
              Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00682701578807218, -0.006593834614823333}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 2, {
              Complex[7.363707263462426, 0.009361569840391621], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007816099751023656, 0.004009972690758083}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 1, {
              Complex[4.336494969468971, -0.3737709168766498], 
              Complex[2.293253543143011, -1.82773180818695]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006875754585899968, -0.006638689034413165}],
            
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 2, {
              Complex[7.3531244861453, 0.009482273153988793], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007853366635435642, 0.004064717199945549}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 1, {
              Complex[4.348389338937685, -0.36947028861032294`], 
              Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006922642041072183, -0.006681847685284773}],
            
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007888883488775894, 0.004118374363780124}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 1, {
              Complex[4.3601547494422475`, -0.3652913776086266], 
              Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006967765855007473, -0.006723389721058038}],
            
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 2, {
              Complex[7.332373746308075, 0.009729098555121761], 
              Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007922734147127818, 0.004170984897141967}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 1, {
              Complex[4.3717973845316225`, -0.36122848586285683`], 
              Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007011206397775067, -0.0067633875536211256`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 2, {
              Complex[7.322190592979878, 0.009855291843704485], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007954995234283144, 0.0042225864565628825`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 1, {
              Complex[4.38332300838, -0.35727633379543705`], 
              Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00705303750593101, -0.006801907585156858}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 2, {
              Complex[7.312126384370602, 0.009983388579384756], 
              Complex[5.651636660481892, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007985736943015754, 0.004273213945635445}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 1, {
              Complex[4.394737007836374, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00709332717243256, -0.006839010840806826}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 2, {
              Complex[7.302174830430454, 0.010113427765967268`], 
              Complex[5.641006995243322, -1.162436027385382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008015023711371898, 0.004322899781607653}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 1, {
              Complex[4.40604442922753, -0.3496849803402998], 
              Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007132138145831981, -0.0068747535178208296`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 2, {
              Complex[7.292330070281435, 0.010245449802525817`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00804291481048482, 0.004371674129031278}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 1, {
              Complex[4.417250010699276, -0.3460369658605059], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007169528452814355, -0.006909187464146067}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 2, {
              Complex[7.282586630397876, 0.010379496510400103`], 
              Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00806946485745778, 0.00441956510531015}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 1, {
              Complex[4.428358210745746, -0.34248200518323846`], 
              Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007205551855646692, -0.006942360597107584}],
            
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 2, {
              Complex[7.272939387787106, 0.010515611164854442`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00809472426448922, 0.004466598962172421}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 1, {
              Complex[4.439373233467538, -0.3390163845608803], 
              Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007240258254105407, -0.006974317270986914}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 2, {
              Complex[7.263383537456196, 0.010653838531129386`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008118739633508022, 0.004512800246426183}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 1, {
              Complex[4.450299051011202, -0.3356366249244736], 
              Complex[2.411607470734253, -1.774754506235453]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00727369403983609, -0.00700509860081941}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 2, {
              Complex[7.253914563567924, 0.010794224904694137`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008141554104043647, 0.004558191942815528}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 1, {
              Complex[4.461139423570387, -0.33233946229789096`], 
              Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0073059024097919265`, -0.007034742748524402}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 2, {
              Complex[7.244528213784578, 0.010936818155564378`], 
              Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008163207660800415, 0.004602795601352126}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 1, {
              Complex[4.471897917269896, -0.3291218303014387], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007336923644329837, -0.007063285176499909}],
            
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 2, {
              Complex[7.235220476376673, 0.01108166777660797], 
              Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008183737406378159, 0.004646631451131616}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 1, {
              Complex[4.482577920205066, -0.3259808444790341], 
              Complex[2.445554179476747, -1.760702890657421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00736679535466956, -0.007090758873007219}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 2, {
              Complex[7.225987559738016, 0.011228824935798491`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008203177803736474, 0.004689718502343838}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 1, {
              Complex[4.4931826568685596`, -0.32291378822242134`], 
              Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0073955527036997665`, -0.007117194553007051}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 2, {
              Complex[7.216825874002135, 0.011378342532423407`], 
              Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00822156089230229, 0.004732074637934731}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 1, {
              Complex[4.503715201163001, -0.3199181000986165], 
              Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007423228603518985, -0.007142620837559069}],
            
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 2, {
              Complex[7.207732014499435, 0.011530275257279964`], 
              Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00823891648104059, 0.004773716696168795}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 1, {
              Complex[4.514178488169753, -0.31699136241415254`], 
              Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0074498538926030524`, -0.007167064414439555}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 2, {
              Complex[7.198702746831605, 0.011684679656931228`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00825527232132576, 0.004814660545166428}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 1, {
              Complex[4.524575324820607, -0.31413129087274355`], 
              Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00747545749507613, -0.007190550182250234}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 2, {
              Complex[7.189734993370944, 0.011841614202115805`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008270654262045946, 0.004854921150342591}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 1, {
              Complex[4.534908399599208, -0.3113357252023988], 
              Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007500066564214945, -0.007213101379970787}],
            
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 2, {
              Complex[7.180825821018505, 0.012001139360437759`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008285086389033603, 0.004894512635548563}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 1, {
              Complex[4.545180291382208, -0.3086026206444535], 
              Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007523706612022965, -0.007234739703638057}],
            
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 2, {
              Complex[7.171972430077165, 0.012163317673485156`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008298591150628162, 0.004933448338613792}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 1, {
              Complex[4.555393477515928, -0.3059300402110033], 
              Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0075464016264641855`, -0.0072554854116068206`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 2, {
              Complex[7.163172144114486, 0.012328213838552503`], 
              Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00831118947093384, 0.004971740861894076}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 1, {
              Complex[4.565550341212051, -0.3033161476291155], 
              Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0075681741777358594`, -0.007275357419653635}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 2, {
              Complex[7.154422400706351, 0.012495894795164308`], 
              Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008322900852129597, 0.005009402118356301}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 1, {
              Complex[4.5756531783355054`, -0.30075920090048514`], 
              Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00758904551478134, -0.007294373387020248}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 2, {
              Complex[7.145720742965965, 0.012666429816627278`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008333743467011632, 0.005046443373663722}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 1, {
              Complex[4.585704203648775, -0.2982575464138705], 
              Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007609035653091222, -0.0073125497943526616`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 2, {
              Complex[7.137064811774602, 0.012839890606854724`], 
              Complex[5.463037520285709, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008343734242798303, 0.0050828752846698655`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 1, {
              Complex[4.59570555656919, -0.2958096135553045], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007628163454710481, -0.007329902014370801}],
            
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 2, {
              Complex[7.128452338640535, 0.013016351402742217`], 
              Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008352888937098376, 0.005118707934679879}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 1, {
              Complex[4.605659306489133, -0.2934139097675642], 
              Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.007646446701256861, -0.00734644437600031}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 2, {
              Complex[7.119881139121318, 0.01319588908239133], 
              Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008361222206831427, 0.00515395086579657}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 1, {
              Complex[4.615567457703371, -0.2910690160160602], 
              Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007663902160659028, -0.007362190222608051}],
            
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 2, {
              Complex[7.111349106752032, 0.013378583279512458`], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008368747670793604, 0.005188613108631587}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 1, {
              Complex[4.62543195398277, -0.2887735826232172], 
              Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007680545648239218, -0.007377151964905557}],
            
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 2, {
              Complex[7.102854207428718, 0.013564516504362785`], 
              Complex[5.425781575481577, -1.161018749909008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00837547796647829, 0.00522270320963088}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 1, {
              Complex[4.635254682829313, -0.286526325437767], 
              Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007696392082692585, -0.007391341129017275}],
            
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 2, {
              Complex[7.094394474201807, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008381424801688759, 0.005256229256235381}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 1, {
              Complex[4.645037479443608, -0.2843260223090588], 
              Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007711455537452484, -0.0074047684001517415`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 2, {
              Complex[7.085968002439294, 0.013946445235532949`], 
              Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008386599001416698, 0.005289198900074675}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 1, {
              Complex[4.654782130432774, -0.2821715098398547], 
              Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007725749287876043, -0.007417443662262586}],
            
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 2, {
              Complex[7.077572945323753, 0.014142621333044114`], 
              Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00839101055040562, 0.005321619378369374}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 1, {
              Complex[4.664490377283739, -0.28006168039394375`], 
              Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007739285854636329, -0.007429376034041497}],
            
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 2, {
              Complex[7.069207509650976, 0.014342397934981436`], 
              Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008394668631769232, 0.005353497533700135}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 1, {
              Complex[4.674163919624442, -0.2779954793374564], 
              Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007752077043665635, -0.007440573901545564}],
            
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 2, {
              Complex[7.060869951901384, 0.014545874006250832`], 
              Complex[5.379881023870965, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008397581661992578, 0.005384839832284777}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 1, {
              Complex[4.683804418293251, -0.2759719024950625], 
              Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007764133982957427, -0.007451044947726767}],
            
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 2, {
              Complex[7.052558574558201, 0.014753152275367028`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008399757322606127, 0.005415652380890613}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 1, {
              Complex[4.693413498234962, -0.2739899938041945], 
              Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007775467156502406, -0.007460796179100532}],
            
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 2, {
              Complex[7.044271722648962, 0.014964339414035013`], 
              Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008401202588789805, 0.005445940942496733}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 1, {
              Complex[4.702992751240038, -0.27204884315225375`], 
              Complex[2.68192509329917, -1.67547959713909]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007786086435605438, -0.007469833949762824}],
            
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 2, {
              Complex[7.036007780489124, 0.015179546227436098`], 
              Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008401923755134152, 0.005475710950809701}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 1, {
              Complex[4.712543738542191, -0.2701475843833519], 
              Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007796001107805199, -0.007478163982941036}],
            
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 2, {
              Complex[7.027765168608572, 0.01539888785596537], 
              Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008401926458759852, 0.0055049675237264254`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 1, {
              Complex[4.722067993288219, -0.2682853934625311], 
              Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007805219903596141, -0.007485791390241792}],
            
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 2, {
              Complex[7.019542340843495, 0.015622483989198223`], 
              Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008401215699972776, 0.005533715475829326}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 1, {
              Complex[4.731567022892644, -0.26646148678673676`], 
              Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007813751021132567, -0.007492720688739603}],
            
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 2, {
              Complex[7.011337781577717, 0.015850459092959842`], 
              Complex[5.325475035055747, -1.159899171471262]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008399795860611268, 0.005561959329991287}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 1, {
              Complex[4.741042311288872, -0.26467511963294066`], 
              Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.007821602149077619, -0.00749895581603213}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 2, {
              Complex[7.003150003118844, 0.016082942650415873`], 
              Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008397670720222428, 0.005589703328160982}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 1, {
              Complex[4.75049532108751, -0.26292558473487176`], 
              Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007828780487744252, -0.0075045001433721795`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 2, {
              Complex[6.994977543195845, 0.016320069418202337`], 
              Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008394843470187563, 0.005616951441393559}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 1, {
              Complex[4.7599274956518, -0.2612122109807508], 
              Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007835292768661625, -0.007509356486971438}],
            
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 2, {
              Complex[6.986818962565743, 0.016561979698683896`], 
              Complex[5.298442228350345, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008391316725900601, 0.005643707379185995}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 1, {
              Complex[4.769340261099353, -0.2595343622253304], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007841145272688367, -0.007513527117558006}],
            
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 2, {
              Complex[6.978672842717983, 0.01680881962953298], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008387092537089176, 0.005669974598172299}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 1, {
              Complex[4.778735028238791, -0.25789143621028987`], 
              Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007846343846783127, -0.0075170137682568595`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 2, {
              Complex[6.970537783665925, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00838217239635447, 0.005695756310229377}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 1, {
              Complex[4.788113194449318, -0.256282863587831], 
              Complex[2.775317254506115, -1.647405199653864]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00785089391953354, -0.0075198176408511576`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 2, {
              Complex[6.962412401815591, 0.017317904038714253`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008376557245993618, 0.005721055490041078}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 1, {
              Complex[4.79747614551083, -0.2547081070429694], 
              Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007854800515536041, -0.007521939410471356}],
            
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 2, {
              Complex[6.954295327902444, 0.01758047284423772], 
              Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008370247483156682, 0.005745874882165003}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 1, {
              Complex[4.806825257391718, -0.2531666605106761], 
              Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007858068268711563, -0.007523379228748607}],
            
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 2, {
              Complex[6.946185204987557, 0.017848620677213628`], 
              Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008363242963379227, 0.005770217007644078}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 1, {
              Complex[4.8161618980011855`, -0.2516580484846366], 
              Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00786070143463546, -0.007524136725459666}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 2, {
              Complex[6.938080686504964, 0.018122527898744748`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008355543002521277, 0.005794084170202853}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 1, {
              Complex[4.825487428912641, -0.2501818254149765], 
              Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007862703901954376, -0.007524211008680437}],
            
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 2, {
              Complex[6.929980434352448, 0.01840238288728782], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008347146377133036, 0.005817478462066624}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007864079202957504, -0.0075236006634567575`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 2, {
              Complex[6.921883117018336, 0.018688382492788213`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008338051323258103, 0.005840401769440959}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 1, {
              Complex[4.844110586443732, -0.24732491072033783`], 
              Complex[2.837373837167927, -1.630395790115732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00786483052336556, -0.00752230374899137}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 2, {
              Complex[6.913787407737206, 0.018980732522336733`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008328255533675414, 0.005862855777687181}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 1, {
              Complex[4.853410919760504, -0.24594347356467788`], 
              Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007864960711396845, -0.007520317794337888}],
            
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 2, {
              Complex[6.90569198266763, 0.01927964825993098], 
              Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008317756153571446, 0.005884841976230185}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 1, {
              Complex[4.862705560115598, -0.24459293369624477`], 
              Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00786447228616705, -0.0075176397925826085`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 2, {
              Complex[6.897595519085279, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008306549774624875, 0.005906361663234057}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 1, {
              Complex[4.871995862670491, -0.24327298931041968`], 
              Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007863367445476596, -0.007514266193487041}],
            
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 2, {
              Complex[6.889496693584875, 0.019898088759987553`], 
              Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008294632427476115, 0.005927415950081693}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 1, {
              Complex[4.881283186323276, -0.24198336673385487`], 
              Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007861648073037854, -0.007510192894553621}],
            
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 2, {
              Complex[6.881394180284589, 0.020218096688815555`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008281999572544371, 0.005948005765695678}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 1, {
              Complex[4.8905688953969415`, -0.24072382041628823`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007859315745192955, -0.007505415230468572}],
            
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 2, {
              Complex[6.873286649026525, 0.020545637985932938`], 
              Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008268646089144792, 0.005968131860738634}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 1, {
              Complex[4.899854361345616, -0.23949413300958752`], 
              Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007856371737172478, -0.007499927960864964}],
            
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 2, {
              Complex[6.865172763566979, 0.020880984524095033`], 
              Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008254566262847608, 0.005987794811733353}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 1, {
              Complex[4.90914096448451, -0.23829411553630825`], 
              Complex[2.910034828740951, -1.612121547840817]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007852817028945318, -0.007493725256339126}],
            
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 2, {
              Complex[6.857051179750135, 0.021224421666976113`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008239753771010296, 0.0060069950251455916`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 1, {
              Complex[4.918430095749453, -0.2371236076506873], 
              Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007848652310710346, -0.007486800682642352}],
            
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 2, {
              Complex[6.848920543658824, 0.02157624912441265], 
              Complex[5.145157618862018, -1.156595047683686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008224201666401811, 0.006025732741475122}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 1, {
              Complex[4.927723158492043, -0.23598247799562702`], 
              Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007843877988082186, -0.007479147182957847}],
            
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 2, {
              Complex[6.840779489735858, 0.021936781873947195`], 
              Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00820790235882596, 0.006044008039404884}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 1, {
              Complex[4.9370215703165, -0.23487062465998587`], 
              Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007838494187025405, -0.007470757058160485}],
            
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 2, {
              Complex[6.832626638869334, 0.022306351154756456`], 
              Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008190847594637143, 0.006061820840062292}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 1, {
              Complex[4.946326764964685, -0.2337879757412101], 
              Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007832500758594136, -0.007461621944943119}],
            
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 2, {
              Complex[6.824460596435171, 0.022685305540684226`], 
              Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008173028434027976, 0.006079170911452548}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 1, {
              Complex[4.955640194255799, -0.2327344900192291], 
              Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007825897283538542, -0.007451732791678584}],
            
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 2, {
              Complex[6.816279950289862, 0.023074012099830184`], 
              Complex[5.108566172536498, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008154435225952173, 0.00609605787313016}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 1, {
              Complex[4.9649633300876665`, -0.23171015774841372`], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00781868307684372, -0.007441079831870327}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 2, {
              Complex[6.808083268706271, 0.02347285764894464], 
              Complex[5.099358827456356, -1.155369598409927]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00813505758052983, 0.006112481201182797}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 1, {
              Complex[4.974297666506786, -0.2307150015754329], 
              Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007810857192273741, -0.007429652555027278}],
            
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 2, {
              Complex[6.799869098244956, 0.023882250111808064`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.00811488433876334, 0.0061284402336105855`}],
            
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 1, {
              Complex[4.983644721854632, -0.22974907759194269`], 
              Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007802418426999845, -0.007417439674779191}],
            
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 2, {
              Complex[6.7916359615532285`, 0.024302619991773983`], 
              Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008093903539372551, 0.006143934176194824}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 1, {
              Complex[4.993006040998135, -0.22881247653229808`], 
              Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007793365326401984, -0.007404429094027811}],
            
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 2, {
              Complex[6.783382355083752, 0.024734421969834053`], 
              Complex[5.071567299655017, -1.154523602824754]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00807210238253537, 0.006158962108962401}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 1, {
              Complex[5.0023831976526285`, -0.22790532512782422`], 
              Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007783696189142816, -0.007390607866905814}],
            
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 2, {
              Complex[6.775106746724161, 0.02517813664084302], 
              Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008049467190295548, 0.00617352299336739}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.025955129189635, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00777340907262682, -0.0073759621572898155`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 2, {
              Complex[6.766807573328626, 0.02563427240203126], 
              Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008025983363373198, 0.006187615680327742}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 1, {
              Complex[5.021191477253695, -0.2261800675227632], 
              Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007762501798972206, -0.007360477193585598}],
            
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 2, {
              Complex[6.7584832381419595`, 0.02610336750958422], 
              Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.008001635334082985, 0.0062012389192762545`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 1, {
              Complex[5.030625914253164, -0.22536240942454472`], 
              Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007750971961641789, -0.0073441372194717105`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 2, {
              Complex[6.750132108106198, 0.026585992320966013`], 
              Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007976406515032767, 0.0062143913684074995`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 1, {
              Complex[5.040082822310154, -0.22457510122598082`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00773881693290006, -0.007326925440253233}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 2, {
              Complex[6.7417525110391665`, 0.02708275174279656], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007950279243238472, 0.006227071606330899}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 1, {
              Complex[5.049563958105735, -0.22381847645779873`], 
              Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0077260338722901865`, -0.007308823964437751}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 2, {
              Complex[6.733342732673844, 0.027594287906544456`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007923234719250601, 0.0062392781453721805`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 1, {
              Complex[5.059071123576937, -0.22309291692935682`], 
              Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007712619736353491, -0.007289813740103197}],
            
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 2, {
              Complex[6.724901013546819, 0.02812128309705345], 
              Complex[5.005499610747705, -1.15214256927739]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0078952529408425, 0.006251009446803837}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 1, {
              Complex[5.068606169162741, -0.22239885565995454`], 
              Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007698571289851014, -0.007269874485577586}],
            
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 2, {
              Complex[6.716425545723422, 0.02866446296210377], 
              Complex[4.995893274766249, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007866312630760123, 0.006262263938329819}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 1, {
              Complex[5.078170997228454, -0.22173678013483544`], 
              Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0076838851187878005`, -0.007248984613897991}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 2, {
              Complex[6.707914469346525, 0.029224600034819193`], 
              Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007836391157977024, 0.0062730400342027055`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 1, {
              Complex[5.087767565681953, -0.22110723592124715`], 
              Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007668557645591559, -0.007227121150454276}],
            
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 2, {
              Complex[6.699365868995314, 0.02980251760487493], 
              Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00780546445183569, 0.006283336158413888}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 1, {
              Complex[5.097397891796026, -0.2205108306846836], 
              Complex[3.123750747268463, -1.568770237634814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007652585146855755, -0.007204259643156891}],
            
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 2, {
              Complex[6.6907777698397455`, 0.030399093979211252`], 
              Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007773506908386558, 0.00629315077147057}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 1, {
              Complex[5.107064056251541, -0.21994823865093072`], 
              Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007635963774128155, -0.007180374064391415}],
            
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 2, {
              Complex[6.682148133575791, 0.03101526717841391], 
              Complex[4.956961006232221, -1.149994992121425]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007740491288158137, 0.006302482401360865}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 1, {
              Complex[5.116768207416752, -0.21942020556585193`], 
              Complex[3.146006672598035, -1.565190320272424]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007618689578309046, -0.0071554367039387634`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 2, {
              Complex[6.673474854126102, 0.031652040121196295`], 
              Complex[4.947089201235956, -1.149509834990993]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007706388604504967, 0.006311329679411389}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 1, {
              Complex[5.126512565878383, -0.21892755421211518`], 
              Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007600758538323253, -0.007129418051944888}],
            
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 2, {
              Complex[6.664755753090322, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007671168001583552, 0.00631969138186385}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 1, {
              Complex[5.1362994292403545`, -0.21847119055042014`], 
              Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007582166594848297, -0.007102286670918537}],
            
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 2, {
              Complex[6.655988574929111, 0.03299175641235], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007634796620898348, 0.006327566478144064}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 1, {
              Complex[5.1461311772059295`, -0.21805211056251345`], 
              Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007562909690023397, -0.007074009055617112}],
            
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 2, {
              Complex[6.647170981866, 0.03369708483581625], 
              Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007597239455241286, 0.0063349541869699}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 1, {
              Complex[5.156010276958656, -0.21767140788446362`], 
              Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0075429838142331024`, -0.007044549479549446}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 2, {
              Complex[6.6383005484916495`, 0.03442779801852971], 
              Complex[4.906968264234699, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007558459188715045, 0.0063418540416532955`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 1, {
              Complex[5.1659392888564994`, -0.2173302823316979], 
              Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007522385061263232, -0.007013869826676859}],
            
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 2, {
              Complex[6.629374756056008, 0.03518532290406068], 
              Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007518416021385005, 0.006348265966200399}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 1, {
              Complex[5.175920872451979, -0.21703004943242454`], 
              Complex[3.214258836551336, -1.555411285239044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007501109693371156, -0.006981929406731903}],
            
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 2, {
              Complex[6.620390986435504, 0.03597119669747851], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007477067476943751, 0.006354190364113072}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 1, {
              Complex[5.185957792848567, -0.21677215110365716`], 
              Complex[3.225881858451649, -1.553934201044293]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007479154218106721, -0.006948684752393087}],
            
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 2, {
              Complex[6.611346515764966, 0.03678707771053715], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007434368191597546, 0.006359628222154506}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 1, {
              Complex[5.196052927399868, -0.21655816762459845`], 
              Complex[3.237584411566567, -1.552504823512188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007456515479075474, -0.006914089396356238}],
            
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 2, {
              Complex[6.60223850772765, 0.037634757497710766`], 
              Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007390269682193976, 0.006364581231776089}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 1, {
              Complex[5.206209272752708, -0.2163898310860751], 
              Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007433190763265095, -0.006878093626125749}],
            
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 2, {
              Complex[6.593064006502223, 0.038516174462077585`], 
              Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0073447200914079705`, 0.0063690519314259526`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 1, {
              Complex[5.216429952227797, -0.21626904052272788`], 
              Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007409177928076638, -0.006840644214114209}],
            
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 2, {
              Complex[6.58381992937299, 0.03943342913804175], 
              Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007297663907589933, 0.006373043873595153}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 1, {
              Complex[5.226718223521198, -0.2161978789674424], 
              Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007384475551833816, -0.006801684120387292}],
            
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 2, {
              Complex[6.574503059020016, 0.040388801390635574`], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007249041656660428, 0.006376561821227117}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 1, {
              Complex[5.237077486695947, -0.21617863270584659`], 
              Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007359083112312885, -0.006761152165126606}],
            
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 2, {
              Complex[6.565110035519868, 0.04138476980950452], 
              Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007198789563219448, 0.006379611979053384}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 1, {
              Complex[5.247511292414014, -0.21621381305374007`], 
              Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007333001198773378, -0.006718982667611793}],
            
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 2, {
              Complex[6.555637348106621, 0.04242403362064838], 
              Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007146839177834192, 0.006382202266559109}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 1, {
              Complex[5.258023350333589, -0.21630618103294588`], 
              Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007306231764115724, -0.006675105048256313}],
            
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 2, {
              Complex[6.546081326768186, 0.04350953749168187], 
              Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007093116967299448, 0.006384342640676628}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 1, {
              Complex[5.268617537562701, -0.21645877538292138`], 
              Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00727877842519447, -0.006629443389984197}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 2, {
              Complex[6.536438133786874, 0.04464449966811444], 
              Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.007037543864553398, 0.006386045478008066}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 1, {
              Complex[5.279297907015237, -0.2166749444176823], 
              Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007250646821035854, -0.006581915955033595}],
            
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 2, {
              Complex[6.526703755378124, 0.045832443950467455`], 
              Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006980034774922136, 0.006387326028465091}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 1, {
              Complex[5.29006869545568, -0.21695838232209166`], 
              Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007221845040819502, -0.006532434653154706}],
            
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 2, {
              Complex[6.516873993640987, 0.047077236106415926`], 
              Complex[4.767386408695089, -1.136665739909799]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006920498035515926, 0.00638820295477123}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 1, {
              Complex[5.300934330939945, -0.21731317057992383`], 
              Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0071923841360811034`, -0.006480904457190351}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 2, {
              Complex[6.50694445911303, 0.04838312541060556], 
              Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006858834824995931, 0.00638869897540821}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 1, {
              Complex[5.311899439255096, -0.21774382534019754`], 
              Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007162278734784824, -0.006427222762268842}],
            
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 2, {
              Complex[6.496910564326778, 0.04975479211876483], 
              Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006794938521694168, 0.006388841632435513}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 1, {
              Complex[5.322968848822688, -0.21825535165974055`], 
              Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007131547778843696, -0.0063712786854191765`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 2, {
              Complex[6.486767518902965, 0.0511974018142995], 
              Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0067286940093783795`, 0.006388664210324639}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 1, {
              Complex[5.334147593347899, -0.21885330570991693`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007100215411494839, -0.006312952303510322}],
            
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 2, {
              Complex[6.476510326898408, 0.05271666771536847], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0066599769320600626`, 0.006388206837715196}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 1, {
              Complex[5.34544091125561, -0.21954386620430968`], 
              Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007068312046865052, -0.006252113829262171}],
            
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 2, {
              Complex[6.466133787367247, 0.05431892219952709], 
              Complex[4.70854473004717, -1.130085166709498]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006588652902502804, 0.006387517811024755}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 1, {
              Complex[5.356854240636268, -0.2203339164903332], 
              Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007035875661314212, -0.006188622728034052}],
            
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 2, {
              Complex[6.4556324994128165`, 0.05601119898888104], 
              Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006514576674010414, 0.00638665518736032}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 1, {
              Complex[5.36839320800425, -0.2212311389467491], 
              Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0070029533549761545`, -0.0061223267826600505`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 2, {
              Complex[6.445000873427293, 0.05780132763801389], 
              Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006437591292372158, 0.006385688704414603}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 1, {
              Complex[5.380063608617472, -0.22224412353114406`], 
              Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006969603242586393, -0.00605306112049161}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 2, {
              Complex[6.434233150770422, 0.05969804216878785], 
              Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006357527255524417, 0.006384702097177179}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 1, {
              Complex[5.39187137537774, -0.22338249250843517`], 
              Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0069358967454314704`, -0.005980647227024183}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 2, {
              Complex[6.423323434867788, 0.061711105883242766`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0062742017239579406`, 0.006383795895434758}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 1, {
              Complex[5.403822532373675, -0.2246570435317341], 
              Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006901921371217077, -0.005904891985445036}],
            
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 2, {
              Complex[6.412265737666768, 0.06385145452602968], 
              Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00618741784710291, 0.006383090802020718}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 1, {
              Complex[5.415923127875931, -0.22607991328743238`], 
              Complex[3.49540764739327, -1.538992497237254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00686778408575286, -0.005825586803105945}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 2, {
              Complex[6.401054046640449, 0.06613136000835822], 
              Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0060969643025202466`, 0.006382731768988811}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 1, {
              Complex[5.428179139967114, -0.22766476377118722`], 
              Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006833615399078896, -0.00574250691700024}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 2, {
              Complex[6.389682419157071, 0.06856461676025156], 
              Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.006002615189287274, 0.00638289290587535}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 1, {
              Complex[5.440596345893878, -0.22942699279424578`], 
              Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006799574307685834, -0.005655411014460322}],
            
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 2, {
              Complex[6.378145113127533, 0.07116675231062962], 
              Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005904130479152862, 0.006383783368069814}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 1, {
              Complex[5.453180143569079, -0.23138396931833927`], 
              Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006765854251058153, -0.005564041367288539}],
            
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 2, {
              Complex[6.3664367655030105`, 0.07395526269357508], 
              Complex[4.591951242060748, -1.111090937656241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0058012573146845325`, 0.006385654378679626}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 1, {
              Complex[5.465935310345424, -0.23355529236003053`], 
              Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006732690249732016, -0.005468124763461265}],
            
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 2, {
              Complex[6.354552633501294, 0.07694987142174026], 
              Complex[4.577957240848536, -1.108080936651698]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0056937325595099045`, 0.006388807524833584}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 1, {
              Complex[5.478865680202783, -0.23596306901323125`], 
              Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006700367384285774, -0.0053673746375479175`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 2, {
              Complex[6.342488917419652, 0.08017280757570108], 
              Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005581287158653058, 0.006393604423603212}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 1, {
              Complex[5.491973715947518, -0.2386322019223144], 
              Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006669230734831589, -0.0052614949564410585`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 2, {
              Complex[6.330243188435803, 0.08364909334179328], 
              Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005463653061322401, 0.006400477748880246}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 1, {
              Complex[5.5052599482994165`, -0.2415906683469046], 
              Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006639696803951442, -0.005150186616235833}],
            
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 2, {
              Complex[6.317814949521482, 0.08740682313953926], 
              Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0053405736914007625`, 0.006409943411022606}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 1, {
              Complex[5.518722249741511, -0.24486976056502427`], 
              Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006612266254780399, -0.0050331573474948705`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 2, {
              Complex[6.30520636159325, 0.09147740408549994], 
              Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00521181920242765, 0.006422613332318775}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 1, {
              Complex[5.532354909525623, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006587537455689593, -0.004910136391563499}],
            
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 2, {
              Complex[6.292423168507697, 0.09589570953158878], 
              Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.005077207970595827, 0.006439207694310073}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 1, {
              Complex[5.546147480479421, -0.25253232740394727`], 
              Complex[3.650990035081118, -1.556521435684903]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006566219762812653, -0.004780895448773832}],
            
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 2, {
              Complex[6.279475850255287, 0.10070007254234241`], 
              Complex[4.488987856730723, -1.083460700125328]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004936635848772158, 0.006460564674100581}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 1, {
              Complex[5.560083383502212, -0.2569954375693105], 
              Complex[3.667805619167921, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006549144614033234, -0.004645277500061477}],
            
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 2, {
              Complex[6.266381018465571, 0.10593201418800262`], 
              Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0047901144234052985`, 0.006487644491183846}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 1, {
              Complex[5.5741382895514295`, -0.26193749411720274`], 
              Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006537271301675521, -0.00450323486452709}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 2, {
              Complex[6.2531630344218, 0.11163556486001082`], 
              Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0046378185657506, 0.0065215231123642}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 1, {
              Complex[5.5882783610426285`, -0.267403671805992], 
              Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0065316827844192436`, -0.004354876956186388}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 2, {
              Complex[6.23985576766216, 0.11785600339462998`], 
              Complex[4.44156860245767, -1.065050990167949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004480141537713098, 0.006563369501820837}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 1, {
              Complex[5.602458533258957, -0.2734383645589251], 
              Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0065335653710181275`, -0.0042005262233381765`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 2, {
              Complex[6.226504314571602, 0.12463782579822859`], 
              Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004317752441364595, 0.00661439955184534}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 1, {
              Complex[5.616621151226328, -0.2800822323034732], 
              Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00654416524339044, -0.004040777313780263}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 2, {
              Complex[6.213166361508075, 0.13202179213539816`], 
              Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004151645943103562, 0.006675800992047596}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 1, {
              Complex[5.6306954263332605`, -0.2873682998621296], 
              Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006564715788779914, -0.0038765496264732487`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 2, {
              Complex[6.199912728184141, 0.14004102546706554`], 
              Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.003983169010621589, 0.006748628150689235}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 1, {
              Complex[5.644598280659573, -0.29531732776612096`], 
              Complex[3.770794613325991, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006596334106006096, -0.0037091180917398297`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0038140064400728505`, 0.006833674350018879}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 1, {
              Complex[5.6582371068889525`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006639893826730822, -0.003540103800033951}],
            
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 2, {
              Complex[6.1740003848318254`, 0.15805167382144575`], 
              Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0036461099657357403`, 0.006931341719867771}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 1, {
              Complex[5.671514683640783, -0.31319809514055214`], 
              Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006695893418660231, -0.0033714087352560923`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 2, {
              Complex[6.161531564303005, 0.16802967600526247`], 
              Complex[4.34645857273412, -1.009339964026806]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0034815675709773783`, 0.007041538600702415}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 1, {
              Complex[5.684335924466961, -0.3230721172560274], 
              Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006764349804259442, -0.003205090309948309}],
            
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 2, {
              Complex[6.1495151781876825`, 0.1786100786041201], 
              Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.003322428729281727, 0.0071636363124263774`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 1, {
              Complex[5.696615451432764, -0.33349241406049873`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.006844749272930102, -0.003043190315438006}],
            
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 2, {
              Complex[6.138036634132392, 0.18973028734408198`], 
              Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0031705199045468035`, 0.007296504879571945}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 1, {
              Complex[5.708284492538861, -0.3443779449095292], 
              Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.006936076112696294, -0.00288755168045396}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 2, {
              Complex[6.127164733575719, 0.20130934934495107`], 
              Complex[4.303885430470007, -0.971377104797332]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0030272920356988276`, 0.007438624038399569}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 1, {
              Complex[5.719295626734264, -0.3556357121294631], 
              Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.007036916559501793, -0.00273966439871925}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 2, {
              Complex[6.1169469267372625`, 0.21325435309295884`], 
              Complex[4.291086318485069, -0.957611110502011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002893732217542453, 0.007588242419902645}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 1, {
              Complex[5.729624504719875, -0.3671682712416461], 
              Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007145612232735001, -0.0026005732162917095`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 2, {
              Complex[6.107407591815999, 0.22546793870233275`], 
              Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0027703500168053713`, 0.007743546167472999}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 1, {
              Complex[5.7392685732062425`, -0.37888080574180155`], 
              Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007260425151430866, -0.002470858475415818}],
            
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 2, {
              Complex[6.098549310734496, 0.2378553727309036], 
              Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0026572265622972187`, 0.007902802649640486}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 1, {
              Complex[5.748243586852646, -0.3906866010723917], 
              Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007379680181287162, -0.002350679396643019}],
            
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 2, {
              Complex[6.0903563572018244`, 0.2503300221877129], 
              Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002554101672175527, 0.008064459970332213}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 1, {
              Complex[5.75657901938974, -0.4025104167837189], 
              Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007501865250015435, -0.002239856004264381}],
            
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 2, {
              Complex[6.08279928559293, 0.26281672672835754`], 
              Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002460473206579992, 0.008227199341706404}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 1, {
              Complex[5.7643133844056464`, -0.4142898642644478], 
              Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007625685743675505, -0.0021379644238944486`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 2, {
              Complex[6.075839610164613, 0.27525317641875785`], 
              Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002375689568153946, 0.008389948495044772}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 1, {
              Complex[5.771490138844717, -0.42597525546826004`], 
              Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.007750080587416216, -0.002044426619245038}],
            
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 2, {
              Complex[6.069433901558818, 0.2875897604942178], 
              Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002299025195950836, 0.00855186863505433}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 1, {
              Complex[5.778154476287738, -0.43752848511674675`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007874211988078614, -0.0019585842864226206`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 2, {
              Complex[6.063536993524541, 0.2997884495937313], 
              Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00222973622200529, 0.008712326831595141}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 1, {
              Complex[5.784351043372479, -0.448921436448157], 
              Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007997440398570081, -0.0018797538202556447`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 2, {
              Complex[6.058104266499389, 0.311821201539341], 
              Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002167097918149241, 0.008870862832774792}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 1, {
              Complex[5.790122459407805, -0.4601342612759226], 
              Complex[3.95661157787795, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00811929352401512, -0.0018072637050422001`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 2, {
              Complex[6.053093127997606, 0.32366824142440104`], 
              Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002110427502618269, 0.009027156022397249}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 1, {
              Complex[5.795508462127413, -0.4711537472500259], 
              Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00823943504767514, -0.0017404776616797885`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 2, {
              Complex[6.048463866858473, 0.3353164289039027], 
              Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002059096196284817, 0.009180995586133587}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 1, {
              Complex[5.800545503681592, -0.4819718787730359], 
              Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00835763616501488, -0.0016788072610979953`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 2, {
              Complex[6.044180057256696, 0.34675781913864817`], 
              Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.002012533932862971, 0.009332255135689117}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 1, {
              Complex[5.805266648945746, -0.4925846278657947], 
              Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00847375123117236, -0.0016217172844490695`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 2, {
              Complex[6.04020866039606, 0.3579884536883503], 
              Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0019702293742904697`, 0.009480871960923305}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 1, {
              Complex[5.809701663341314, -0.5029909709021079], 
              Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008587697756660519, -0.0015687264027154624`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 2, {
              Complex[6.036519936690694, 0.36900737727295657`], 
              Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0019317271443998248`, 0.009626830525436749}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 1, {
              Complex[5.81387720976465, -0.5131921073476412], 
              Complex[3.989240598169983, -1.836139309119696]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00869944042829296, -0.0015194050432655254`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 2, {
              Complex[6.033087248838311, 0.3798158565375278], 
              Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0018966235845788424`, 0.009770149595409965}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 1, {
              Complex[5.817817100281683, -0.5231908494724428], 
              Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008808978597900296, -0.0014733717236971363`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 2, {
              Complex[6.029886810127787, 0.39041676979000506`], 
              Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018645618770589036`, 0.00991087234998414}],
            
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 1, {
              Complex[5.821542567589421, -0.5329911517598128], 
              Complex[4.000015848490729, -1.858517093091784]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008916336629886744, -0.0014302886892903284`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001835227057560972, 0.010049058870922585`}],
            
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 1, {
              Complex[5.8250725348409, -0.5425977517885678], 
              Complex[4.00502375333401, -1.869388672925242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009021556538721243, -0.0013898573748195176`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 2, {
              Complex[6.024100159124149, 0.4110127578783314], 
              Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0018083412200642622`, 0.01018478049498801}],
            
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 1, {
              Complex[5.8284238715967085`, -0.5520158986267112], 
              Complex[4.009806376364359, -1.880054831501802]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009124692425154199, -0.0013518139970725624`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 2, {
              Complex[6.021478203650236, 0.4210179459473799], 
              Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017836590738662763`, 0.010318115605164234`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 1, {
              Complex[5.831611629629778, -0.5612511491377962], 
              Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009225806306208416, -0.0013159254440215824`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 2, {
              Complex[6.019016519204634, 0.4308353192168009], 
              Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017609639235033388`, 0.010449146522606286`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 1, {
              Complex[5.834649256054719, -0.5703092165540443], 
              Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009324965014745779, -0.0012819855377686961`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 2, {
              Complex[6.016701682863842, 0.4404706516054355], 
              Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0017400640880188968`, 0.01057795723462261}],
            
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 1, {
              Complex[5.837548783508502, -0.5791958590266288], 
              Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00942223791403803, -0.001249811694279279}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 2, {
              Complex[6.014521685955785, 0.4499297609478434], 
              Complex[4.155898108440934, -0.675770415493782]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017207897451120267`, 0.010704631754098694`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 1, {
              Complex[5.840320998393064, -0.5879167986060267], 
              Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009517695230038975, -0.0012192419715179887`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 2, {
              Complex[6.012465765819384, 0.4592184279956062], 
              Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0017029901694173917`, 0.010829252953603027`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 1, {
              Complex[5.842975588855198, -0.5964776632911535], 
              Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.009611406849800237, -0.001190132480687928}],
            
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 2, {
              Complex[6.010524257826831, 0.4683423384869708], 
              Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016865313269293996`, 0.010951901754798541`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 1, {
              Complex[5.8455212744613, -0.6048839465011082], 
              Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009703441470320793, -0.0011623551273509238`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 2, {
              Complex[6.008688465710948, 0.47730704263853474`], 
              Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.001671293785733845, 0.0110726565826295}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 1, {
              Complex[5.84796591957802, -0.6131409796537515], 
              Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009793866009858833, -0.0011357956466932174`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016571709044159947`, 0.011191593015839423`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 1, {
              Complex[5.850316632393395, -0.6212539145605389], 
              Complex[4.04179388930688, -1.958660288701135]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.00988274521501784, -0.001110351897790786}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 2, {
              Complex[6.0053034199324715`, 0.4947802005841794], 
              Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016440672623144097`, 0.011308783582191092`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 1, {
              Complex[5.852579851369116, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009970141413155775, -0.0010859323839952852`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 2, {
              Complex[6.003740665139239, 0.5032988771597035], 
              Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00163189729930221, 0.011424297659514531`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.010056114372011782`, -0.001062454969599548}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 2, {
              Complex[6.0022564620129675`, 0.5116787778163029], 
              Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016205841364729493`, 0.011538201453363707`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 1, {
              Complex[5.856866656504023, -0.6447767740762016], 
              Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010140721237806946`, -0.0010398457662403099`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 2, {
              Complex[6.000845516791171, 0.519924526344405], 
              Complex[4.135993261432002, -0.5900329694879913]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016100585526926197`, 0.011650558029362004`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 1, {
              Complex[5.8589004041447135`, -0.6523609855265128], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.010224016530170268`, -0.00101803816574061}],
            
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 2, {
              Complex[5.999503006012947, 0.528040551941874], 
              Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0016002580952998733`, 0.011761427383827851`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 1, {
              Complex[5.860867089220406, -0.6598239647344442], 
              Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010306052177609564`, -0.0009969719991328309}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 2, {
              Complex[5.998224525941575, 0.5360310932164654], 
              Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015911263062249855`, 0.011870866540435367`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 1, {
              Complex[5.862770761740871, -0.6671697152100744], 
              Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010386877581312416`, -0.0009765928043511123}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 2, {
              Complex[5.99700604818503, 0.5439002036016083], 
              Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.001582612047437214, 0.01197892966380501}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 1, {
              Complex[5.86461513517684, -0.6744020624307271], 
              Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010466539698138313`, -0.0009568511875271375}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 2, {
              Complex[5.995843880689525, 0.5516517577146818], 
              Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015746689119312185`, 0.012085668183291487`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 1, {
              Complex[5.86640362080727, -0.6815246607732995], 
              Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010545083135990885`, -0.0009377022649557882}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 2, {
              Complex[5.994734633394268, 0.5592894583048527], 
              Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015672547084520341`, 0.012191130922023402`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 1, {
              Complex[5.868139358018381, -0.6885410007735715], 
              Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01062255025652166, -0.0009191051746510194}],
            
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 2, {
              Complex[5.993675187934443, 0.5668168435275391], 
              Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015603310098660436`, 0.012295364227597541`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 1, {
              Complex[5.869825241082359, -0.6954544165180526], 
              Complex[4.071554204602269, -2.043172220042138]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.010698981281450005`, -0.000901022648005342}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 2, {
              Complex[5.992662670864552, 0.5742372943510564], 
              Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015538627565467632`, 0.012398412101845474`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 1, {
              Complex[5.871463942870232, -0.7022680930260652], 
              Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01077441439979079, -0.0008834206334314544}],
            
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 2, {
              Complex[5.991694429947489, 0.5815540419531224], 
              Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015478179073903772`, 0.012500316327852687`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 1, {
              Complex[5.87305793589056, -0.7089850735194753], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010848885874043944`, -0.0008662679650336074}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 2, {
              Complex[5.990768013117869, 0.588770175004682], 
              Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015421671321375974`, 0.012601116592982171`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 1, {
              Complex[5.874609510991549, -0.7156082665076038], 
              Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01092243014397293, -0.0008495360703488965}],
            
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 2, {
              Complex[5.98988114978185, 0.5958886467685789], 
              Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015368835395813303`, 0.012700850607081314`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 1, {
              Complex[5.876120794018037, -0.7221404526376908], 
              Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01099507992703088, -0.0008331987120488089}],
            
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 2, {
              Complex[5.989031734162119, 0.6029122819634535], 
              Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015319424370082968`, 0.012799554215368453`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.011066866314816614`, -0.000817231759211166}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 2, {
              Complex[5.988217810436113, 0.6098437833604634], 
              Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0015273211168763089`, 0.01289726150572869}],
            
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 1, {
              Complex[5.879030249816931, -0.7349423268176076], 
              Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.011137818865183368`, -0.000801612984388799}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 2, {
              Complex[5.987437559449537, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001522998667284831, 0.012994004910321209`}],
            
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 1, {
              Complex[5.880431975347877, -0.7412169946624547], 
              Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011207965689801534`, -0.0007863218832241057}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 2, {
              Complex[5.986689286816269, 0.6234406236721282], 
              Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015189558032716434`, 0.013089815301522041`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 1, {
              Complex[5.881800536903074, -0.7474106269426314], 
              Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011277333537107604`, -0.0007713395138053623}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 2, {
              Complex[5.985971412240573, 0.6301108136973947], 
              Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015151747163724121`, 0.013184722082315631`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 1, {
              Complex[5.883137429447864, -0.7535254579157123], 
              Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011345947870665694`, -0.0007566483533421432}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 2, {
              Complex[5.985282459919064, 0.6366985832782691], 
              Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0015116389402248217`, 0.013278753271307573`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 1, {
              Complex[5.884444051922338, -0.7595636290829754], 
              Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011413832943036195`, -0.0007422321700625625}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 2, {
              Complex[5.984621049898127, 0.643206114159718], 
              Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0015083332302959288`, 0.01337193558257183}],
            
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 1, {
              Complex[5.885721715038686, -0.7655271940238007], 
              Complex[4.096832656761998, -2.123163026694792]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011481011865291517`, -0.0007280759085135799}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 2, {
              Complex[5.983985890278379, 0.6496354995683528], 
              Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0015052434560628978`, 0.01346429450057054}],
            
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 1, {
              Complex[5.886971648326271, -0.7714181229593432], 
              Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011547506672351035`, -0.0007141655866855505}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 2, {
              Complex[5.983375770171436, 0.655988748787251], 
              Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00150235650419547, 0.01355585435039814}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 1, {
              Complex[5.888195006507387, -0.7772383070571703], 
              Complex[4.100856784915978, -2.136545961543077]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.0116133383843261, -0.0007004882035852962}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 2, {
              Complex[5.982789553325939, 0.6622677914714878], 
              Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001499660191474949, 0.013646638363607676`}],
            
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 1, {
              Complex[5.88939287527652, -0.782989562489217], 
              Complex[4.102814974771636, -2.143119636338955]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011678527064076662`, -0.0006870316560606311}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 2, {
              Complex[5.982226172350083, 0.6684744817167128], 
              Complex[4.1071667491158, -0.4049877179062303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014971431863445386`, 0.013736668739874865`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 1, {
              Complex[5.89056627654708, -0.7886736342555825], 
              Complex[4.104739060573037, -2.149617413966407]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011743091871185725`, -0.0006737846638289037}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 2, {
              Complex[5.981684623466656, 0.6746106018933713], 
              Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00149479493812545, 0.013825966704753478`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 1, {
              Complex[5.891716173221934, -0.7942921997868306], 
              Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011807051112556978`, -0.0006607367017944233}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 2, {
              Complex[5.981163961744247, 0.6806778662591632], 
              Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014926056130516335`, 0.013914552563765094`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 1, {
              Complex[5.892843473537392, -0.7998468723371351], 
              Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011870422289837675`, -0.0006478779388520229}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 2, {
              Complex[5.980663296755008, 0.6866779243621381], 
              Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014905660363809634`, 0.014002445753058552`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 1, {
              Complex[5.893949035024502, -0.8053392041803533], 
              Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011933222143862275`, -0.0006351991824726659}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 2, {
              Complex[5.980181788615051, 0.6926123642464803], 
              Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001488667639928552, 0.014089664886862011`}],
            
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 1, {
              Complex[5.8950336681265165`, -0.8107706896206487], 
              Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011995466696305456`, -0.0006226918284508949}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 2, {
              Complex[5.979718644368703, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014869024144478515`, 0.014176227801940333`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 1, {
              Complex[5.896098139506871, -0.8161427678288314], 
              Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012057171288723594`, -0.0006103478152687616}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 2, {
              Complex[5.979273114682207, 0.7042904519630309], 
              Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001485262866351616, 0.014262151599256737`}],
            
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 1, {
              Complex[5.897143175078252, -0.8214568255150104], 
              Complex[4.115633584193734, -2.187110717536775]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01211835061915518, -0.0005981595825939426}],
            
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 2, {
              Complex[5.978844490816281, 0.7100369946836335], 
              Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001483741978323982, 0.014347452683027579`}],
            
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012179018776441676`, -0.0005861200334875016}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 2, {
              Complex[5.9784321018505455`, 0.7157237141721113], 
              Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001482333173427209, 0.014432146797345745`}],
            
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 1, {
              Complex[5.899177655127286, -0.8319161788285983], 
              Complex[4.119042270745964, -2.199078825420971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01223918927241906, -0.0005742224999420956}],
            
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 2, {
              Complex[5.978035312135368, 0.7213519329214122], 
              Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014810302823508163`, 0.014516249060537839`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 1, {
              Complex[5.900168371555867, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012298875072123223`, -0.0005624607114187498}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 2, {
              Complex[5.977653518949829, 0.7269229276281969], 
              Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014798275134908644`, 0.014599773997408642`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 1, {
              Complex[5.901142200577949, -0.8421588862221203], 
              Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012358088622141996`, -0.0005508287660837141}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 2, {
              Complex[5.97728615034638, 0.7324379313144281], 
              Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001478719425581553, 0.014682735569516683`}],
            
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 1, {
              Complex[5.9020997017701315`, -0.8472019743388882], 
              Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012416841877237884`, -0.0005393211044820383}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 2, {
              Complex[5.976932663165016, 0.7378981353300635], 
              Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014777009026315348`, 0.014765147203613856`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01247514632535779, -0.0005279324854120264}],
            
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 2, {
              Complex[5.976592541201492, 0.7433046912443029], 
              Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014767671309444943`, 0.014847021818373737`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 1, {
              Complex[5.903967825152418, -0.8571372217260815], 
              Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01253301301113797, -0.0005166579637915913}],
            
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 2, {
              Complex[5.976265293515786, 0.7486587126323617], 
              Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014759135780268357`, 0.01492837184952363}],
            
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 1, {
              Complex[5.904879437628475, -0.8620315102214064], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01259045255800477, -0.0005054928703278198}],
            
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 2, {
              Complex[5.975950452868279, 0.7539612767642825], 
              Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014751359732059922`, 0.01500920927348791}],
            
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 1, {
              Complex[5.905776705860623, -0.8668782698647188], 
              Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012647475188964911`, -0.0004944327928230379}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 2, {
              Complex[5.975647574272541, 0.7592134262018878], 
              Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014744302898017634`, 0.015089545629642126`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 1, {
              Complex[5.9066600696217355`, -0.8716784802620264], 
              Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012704090746172538`, -0.0004834735589661503}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 2, {
              Complex[5.975356233654551, 0.7644161703095629], 
              Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014737927287089107`, 0.015169392041270437`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 1, {
              Complex[5.907529948876621, -0.8764330896595154], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012760308709354157`, -0.00047261122047518407`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 2, {
              Complex[5.975076026609326, 0.7695704866842142], 
              Complex[4.095188685529604, -0.27663159198783]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001473219703263578, 0.015248759235312076`}],
            
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 1, {
              Complex[5.908386744937716, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012816138213166595`, -0.00046184203846923226`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 2, {
              Complex[5.974806567246683, 0.7746773225093266], 
              Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014727078252798724`, 0.015327657560976876`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 1, {
              Complex[5.909230841539049, -0.8858091496519155], 
              Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012871588063558148`, -0.00045116246996111724`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 2, {
              Complex[5.974547487118723, 0.779737595837812], 
              Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001472253892152635, 0.015406097007303698`}],
            
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 1, {
              Complex[5.910062605835208, -0.8904323517124778], 
              Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01292666675319798, -0.0004405691553726346}],
            
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 2, {
              Complex[5.974298434222312, 0.7847521968079424], 
              Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014718548749345982`, 0.01548408721973047}],
            
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 1, {
              Complex[5.910882389331387, -0.8950134580602268], 
              Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012981382476034201`, -0.0004300589069836661}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 2, {
              Complex[5.974059072070432, 0.7897219887964377], 
              Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014715079073033465`, 0.01556163751573987}],
            
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 1, {
              Complex[5.911690528750102, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013035743141036601`, -0.00041962869823537383`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014712102753426334`, 0.015638756899639953`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 1, {
              Complex[5.912487346839559, -0.904052600533387], 
              Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013089756385176893`, -0.0004092756538151445}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 2, {
              Complex[5.973608146499301, 0.7995304720360318], 
              Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014709594080698479`, 0.01571545407653459}],
            
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 1, {
              Complex[5.913273153128292, -0.9085121854432785], 
              Complex[4.143183206373633, -2.286811288665357]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013143429585694212`, -0.00039899704045784785`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.001470752868646908, 0.015791737465535312`}],
            
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 1, {
              Complex[5.914048244630215, -0.9129327741202411], 
              Complex[4.1445381709548, -2.291879330010546]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.013196769871691761`, -0.000388790258404395}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 2, {
              Complex[5.973192297371707, 0.8091694575484238], 
              Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014705883462189885`, 0.015867615212261918`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 1, {
              Complex[5.914812906503919, -0.9173150854995431], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013249784135106114`, -0.00037865283346338006`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 2, {
              Complex[5.972996827270754, 0.8139272921843711], 
              Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014704636483296681`, 0.015943095200676587`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 1, {
              Complex[5.9155674126696605`, -0.9216598178919517], 
              Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013302479041088548`, -0.00036858240962739066`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014703766938657394`, 0.016018185064291944`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 1, {
              Complex[5.916312026387238, -0.925967649783973], 
              Complex[4.148512526970577, -2.306826396101707]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013354861037834861`, -0.00035857674219958997`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 2, {
              Complex[5.9726294970541804`, 0.8233232657606012], 
              Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0014703255064906391`, 0.01609289219679252}],
            
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 1, {
              Complex[5.917047000797618, -0.9302392405994727], 
              Complex[4.149808341378717, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013406936365897045`, -0.0003486336913897392}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 2, {
              Complex[5.972457148662774, 0.8279627928769886], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0014703082085259149`, 0.016167223762104502`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 1, {
              Complex[5.9177725794310545`, -0.9344752314248252], 
              Complex[4.15109024131099, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.01345871106700931, -0.0003387512163435475}],
            
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 2, {
              Complex[5.97229203538588, 0.8325642407352367], 
              Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.003078626261514869, 0.003282094578540987}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 1, {
              Complex[4.976967927486167, 0.006887727487396918], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0030544398003150893`, -0.0032301799803081048`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 2, {
              Complex[7.398301539299036, -0.01324317030169907], 
              Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0034721047210118515`, 0.0036938076965496946`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 1, {
              Complex[5.020988084142068, 0.007042959985368871], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0034446280794981025`, -0.0036418491663942664`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 2, {
              Complex[7.352914113679207, -0.013509876715323901`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.003748798082170925, 0.003980757503062971}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 1, {
              Complex[5.05739532427709, 0.007197843246654808], 
              Complex[6.557943371421671, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0037185709665267003`, -0.003930469352910901}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 2, {
              Complex[7.315449803449272, -0.01375104485251276], 
              Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.003962736168324393, 0.004200656208179246}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 1, {
              Complex[5.089412494295966, 0.007354951961001998], 
              Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.003929954191645486, -0.004152874368641221}],
            
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 2, {
              Complex[7.282554763488937, -0.01397986959845826], 
              Complex[8.685690080337723, -1.196609721074035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00413651138471871, 0.004377621601496383}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 1, {
              Complex[5.118506250669166, 0.007515591774090762], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004101236036966588, -0.004332848084272667}],
            
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 2, {
              Complex[7.252703058118813, -0.014202465960727835`], 
              Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004281918361441319, 0.00452423770911296}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 1, {
              Complex[5.145491825926181, 0.007680628289980853], 
              Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004244144110928266, -0.004482816245786672}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 2, {
              Complex[7.225046713694154, -0.01442235766034999], 
              Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0044059547974274705`, 0.004647966131884336}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 1, {
              Complex[5.170878634413056, 0.007850743160533592], 
              Complex[6.668857252414806, -1.162622520798364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004365636732238502, -0.004610156140773216}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 2, {
              Complex[7.199056007873823, -0.014641876121436175`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004513136162729351, 0.004753618262495803}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 1, {
              Complex[5.19501091123548, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004470203086898994, -0.004719631428135566}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 2, {
              Complex[7.174373102447971, -0.014862729232274653`], 
              Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004606554387817914, 0.00484448567902332}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 1, {
              Complex[5.2181348551047995`, 0.008208588338762854], 
              Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004560915520695647, -0.004814506201618239}],
            
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 2, {
              Complex[7.1507421714555965`, -0.015086273942248003`], 
              Complex[8.556435217312076, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004688421684426538, 0.0049229206229811796`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 1, {
              Complex[5.240434389619399, 0.00839746770183686], 
              Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.004639970169684498, -0.00489711746689961}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 2, {
              Complex[7.127972189674163, -0.015313663264596189`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00476037462101751, 0.004990660459127281}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 1, {
              Complex[5.262051805853028, 0.008593772293729816], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0047089892743440226`, -0.004969195355511949}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 2, {
              Complex[7.1059154551031405`, -0.015545933419028879`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004823655538752401, 0.005049021165624798}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 1, {
              Complex[5.283100441464033, 0.008798133065178963], 
              Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004769201528373142, -0.005032054237418022}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 2, {
              Complex[7.084454398670628, -0.015784060035230123`], 
              Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004879226467889984, 0.005099018753068593}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 1, {
              Complex[5.303672866164795, 0.009011228909084937], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004821555284070706, -0.005086712769401545}],
            
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 2, {
              Complex[7.063493070122277, -0.01602899750358731], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004927843666635216, 0.005141448633075179}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 1, {
              Complex[5.323846388854408, 0.00923379877093513], 
              Complex[6.816993839756789, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004866792566440758, -0.0051339724755390176`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 2, {
              Complex[7.042951411025012, -0.016281708942805718`], 
              Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004970108056839635, 0.0051769392367014624`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 1, {
              Complex[5.343686896016404, 0.009466654168547547], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004905499077605006, -0.0051744709388233685`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 2, {
              Complex[7.022761264330782, -0.01654319107188898], 
              Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005006500294518998, 0.0052059892026174144`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 1, {
              Complex[5.363251612071681, 0.009710692858210855], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004938138873947737, -0.005208718804493312}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 2, {
              Complex[7.002863505905769, -0.016814496662831985`], 
              Complex[8.412563676597296, -1.198158678433355]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005037405694187044, 0.005228993696435956}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 1, {
              Complex[5.382591142510598, 0.009966914310096187], 
              Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0049650788978496075`, -0.005237126091758705}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 2, {
              Complex[6.983205922649462, -0.017096756417673678`], 
              Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005063132238717452, 0.005246263298924661}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 1, {
              Complex[5.401751028707841, 0.010236437677199473`], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0049866065672278925`, -0.005260021218522329}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 2, {
              Complex[6.963741599119119, -0.017391201699304113`], 
              Complex[8.374692817528384, -1.198488112788141]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005083923736765995, 0.005258037649238627}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 1, {
              Complex[5.4207729647332625`, 0.010520523036427932`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.005002942459470492, -0.005277664912132277}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 2, {
              Complex[6.944427656372562, -0.01769918937958054], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005099969475562647, 0.005264495262837773}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 1, {
              Complex[5.439695778207934, 0.010820596844492497`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.005014249411441244, -0.005290260427094865}],
            
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 2, {
              Complex[6.925224236986869, -0.01802223007164421], 
              Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005111411265695192, 0.005265760456517568}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 1, {
              Complex[5.458556246931596, 0.011138282794836883`], 
              Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.005020638902306356, -0.005297961015531964}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 2, {
              Complex[6.906093661793765, -0.01836202115462416], 
              Complex[8.319026572634915, -1.199065136952576]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005118348479796317, 0.00526190799061428}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 1, {
              Complex[5.47738980371477, 0.011475439606775242`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0050221752843972005`, -0.0053008752858284955`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 2, {
              Complex[6.886999703988066, -0.01872048627707082], 
              Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0051208414875081555`, 0.005252965814582592}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 1, {
              Complex[5.496231169626781, 0.011834207760463395`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.005018878217270038, -0.005299070874855114}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 2, {
              Complex[6.867906939037359, -0.019099823463292427`], 
              Complex[8.28224016277643, -1.199522741096495]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005118913748089901, 0.005238916136301558}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 1, {
              Complex[5.515114948423251, 0.012217067867222332`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.005010723503691073, -0.005292576710797902}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 2, {
              Complex[6.8487801366438275`, -0.019502564592186727`], 
              Complex[8.263840153003091, -1.199779292073964]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005112552716693771, 0.005219694901154446}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 1, {
              Complex[5.5340762109349875`, 0.012626914319474934`], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004997642398576608, -0.005281384032922564}],
            
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 2, {
              Complex[6.829583665251546, -0.019931649951741116`], 
              Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00510170963557318, 0.005195189644821376}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 1, {
              Complex[5.553151097008939, 0.013067149229433903`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004979519344634088, -0.005265446245670747}],
            
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 2, {
              Complex[6.810280880968052, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.200360975725519]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005086298206498655, 0.005165235557212004}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 1, {
              Complex[5.57237746397503, 0.013541803645186435`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004956187965632991, -0.005244677605968373}],
            
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 2, {
              Complex[6.790833471518203, -0.020883251810279654`], 
              Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005066192066729869, 0.005129609446607661}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 1, {
              Complex[5.591795614755318, 0.014055695951277704`], 
              Complex[7.073421269042283, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0049274250029046505`, -0.0052189506653636}],
            
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 2, {
              Complex[6.771200721802021, -0.021414688765245018`], 
              Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005041220909882846, 0.0050880211008260635`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 1, {
              Complex[5.611449146258794, 0.014614641743299664`], 
              Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004892941691119874, -0.005188092304037024}],
            
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 2, {
              Complex[6.751338660172414, -0.021990680088691934`], 
              Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.005011164996117481, 0.005040101274207626}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 1, {
              Complex[5.631385970822487, 0.015225736181981623`], 
              Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004852371804063076, -0.005151878092525793}],
            
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 2, {
              Complex[6.731199032484283, -0.022618348956057268`], 
              Complex[8.151078988162068, -1.201907179567137]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0049757476726064835`, 0.004985385135372681}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 1, {
              Complex[5.651659582251507, 0.0158977403597609], 
              Complex[7.130299515097565, -1.157225283537514]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004805255210224293, -0.005110024587863938}],
            
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 2, {
              Complex[6.7107280322146305`, -0.02330648209651286], 
              Complex[8.13150550216652, -1.202406603890853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004934625361714214, 0.004923289407826917}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 1, {
              Complex[5.6723306669868805`, 0.016641620135819466`], 
              Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004751015178719481, -0.0050621789992264295`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 2, {
              Complex[6.689864686007544, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0048873742538466085`, 0.004853080479426099}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 1, {
              Complex[5.693469206036438, 0.01747131387776226], 
              Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00468892672457839, -0.005007905425537444}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 2, {
              Complex[6.668538748914897, -0.024911069370827682`], 
              Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0048334726461947254`, 0.004773829187748988}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 1, {
              Complex[5.715157284805061, 0.018404853311322064`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004618071719679089, -0.004946666552631296}],
            
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 2, {
              Complex[6.646667892120967, -0.025859535214795407`], 
              Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004772277487853156, 0.00468434531989016}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 1, {
              Complex[5.737492944039841, 0.019466046203823834`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004537273835621523, -0.004877799285458539}],
            
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 2, {
              Complex[6.624153849873985, -0.02693529265819097], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004702993261719724, 0.004583080144981422}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 1, {
              Complex[5.76059559895939, 0.020687085496539206`], 
              Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0044450016763726286`, -0.00480048230723085}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 2, {
              Complex[6.600876998505349, -0.028170551750252844`], 
              Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0046246310586854494`, 0.004467976571680443}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 1, {
              Complex[5.78461388785291, 0.022112751073540098`], 
              Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004339219747779267, -0.004713693187028435}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 2, {
              Complex[6.5766885062096785`, -0.02961010826063084], 
              Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004535956365896426, 0.004336229555932165}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 1, {
              Complex[5.809737407862617, 0.023807487220115758`], 
              Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004217149960768496, -0.0046161531447570965`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 2, {
              Complex[6.5513985958381715`, -0.03131842125415489], 
              Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004435428498302454, 0.004183884416000054}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 1, {
              Complex[5.836214897718771, 0.02586798658403449], 
              Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.004074871401224411, -0.004506261634936063}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 2, {
              Complex[6.5247583609077076`, -0.03339219715471046], 
              Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004321152889923094, 0.004005123641014843}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 1, {
              Complex[5.864383522178553, 0.028447097632704994`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.003906608963156504, -0.004382040446265364}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 2, {
              Complex[6.496430480050892, -0.03598429729320658], 
              Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0041909389161618295`, 0.0037909095603275477`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 1, {
              Complex[5.894717893374835, 0.031803157852374093`], 
              Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0037033778469775895`, -0.004241176749810795}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 2, {
              Complex[6.465940194681216, -0.03935307118737327], 
              Complex[7.898547952604841, -1.215606555382372]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0040428505189618455`, 0.003526179665223625}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 1, {
              Complex[5.927914095850698, 0.036413030935491676`], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0034501786035887614`, -0.004081544851982941}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 2, {
              Complex[6.432591283080759, -0.043975393800888975`], 
              Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0038780091221184247`, 0.0031835351834102526`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 1, {
              Complex[5.96502471876488, 0.0432677226664523], 
              Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.003119672804682169, -0.003903947182607059}],
            
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 2, {
              Complex[6.395331027411176, -0.05084228149319564], 
              Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0037149049682381518`, 0.0027089550876112072`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 1, {
              Complex[6.007534506136697, 0.054768081877322586`], 
              Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0026578148406155764`, -0.0037262834622664885`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 2, {
              Complex[6.352674562767395, -0.062354593032590215`], 
              Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0036635736053834684`, 0.002015362915706273}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 1, {
              Complex[6.055705576569384, 0.07734359441247692], 
              Complex[7.512359287571745, -1.102232298445035]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.001976945016143217, -0.0036574985680716816`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 2, {
              Complex[6.304359656824848, -0.08494182361233121], 
              Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.004016816495502117, 0.0012402254251815403`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 1, {
              Complex[6.097972756057953, 0.11902724764148631`], 
              Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.001212043301138069, -0.003989925381101783}],
            
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 2, {
              Complex[6.261951376465343, -0.12663696940989244`], 
              Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.004609162170820417, 0.0008000170701272508}],
            
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 1, {
              Complex[6.120724694194671, 0.16611165996512534`], 
              Complex[7.574268139734727, -1.019141232917107]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0007780047144320268, -0.004561091607820349}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 2, {
              Complex[6.239060971061035, -0.17373265713468317`], 
              Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.005132767342241193, 0.0005925265977318417}],
            
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 1, {
              Complex[6.132202365530885, 0.2069539217818524], 
              Complex[7.58536879774568, -0.980787258766948]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0005744121613809151, -0.0050649283439783924`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 2, {
              Complex[6.22744737065107, -0.21458598503237494`], 
              Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.005568954405508589, 0.0004785288764246514}],
            
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 1, {
              Complex[6.138977875500199, 0.24191392575349213`], 
              Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000463255084476625, -0.005482609946952926}],
            
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 2, {
              Complex[6.22053837960052, -0.24955685318475593`], 
              Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.005942142675783732, 0.00040682046436309465`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 1, {
              Complex[6.143492571886664, 0.27256109297706693`], 
              Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0003938145905240093, -0.005838241280215913}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 2, {
              Complex[6.215892564752824, -0.2802146897125671], 
              Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006270511958580286, 0.00035739250353816765`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 1, {
              Complex[6.146749395916181, 0.30000093008350615`], 
              Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00034629907222898576`, -0.006149775657157543}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 2, {
              Complex[6.212506903993471, -0.30766500790256135`], 
              Complex[7.656512931924062, -1.465936381216481]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.006565795898314957, 0.0003211012512384868}],
            
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 1, {
              Complex[6.149229270200796, 0.3249638924276399], 
              Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00031167758183572864`, -0.006428791877510258}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 2, {
              Complex[6.209900397991501, -0.3326382694231228], 
              Complex[7.653771155925207, -1.489346210521607]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.006835722375393537, 0.0002932109534163257}],
            
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 1, {
              Complex[6.151192034362995, 0.34794816918875576`], 
              Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00028527981662846937`, -0.0066829090474908375`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 2, {
              Complex[6.207813134288261, -0.3556326694484139], 
              Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007085588228158005, 0.00027102734186411717`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 1, {
              Complex[6.152791090696166, 0.3693076970042951], 
              Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00026445274616933165`, -0.0069173448563985985`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 2, {
              Complex[6.2060916413747425`, -0.3770021503134528], 
              Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.007319165806763524, 0.0002529039426031884}],
            
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 1, {
              Complex[6.154123300626686, 0.38930335076908473`], 
              Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00024757755121476, -0.007135812193831504}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 2, {
              Complex[6.204638991989324, -0.3970075923331428], 
              Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007539232479592497, 0.00023777679638673817`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 1, {
              Complex[6.155253112689077, 0.4081334915298177], 
              Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00023360974253384037`, -0.007341042529493789}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 2, {
              Complex[6.203390674922197, -0.41584736171471254`], 
              Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0077478915025915585`, 0.00022492696264479777`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 1, {
              Complex[6.156225240135477, 0.4259529280523631], 
              Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0002218446304955057, -0.007535102871599498}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 2, {
              Complex[6.202301917203499, -0.4336762721416338], 
              Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00794677414056158, 0.000213850594364857}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 1, {
              Complex[6.1570717804683675`, 0.44288515307919946`], 
              Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0002117891351854532, -0.007719595302556021}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 2, {
              Complex[6.201340564384264, -0.4506178210463805], 
              Complex[7.644243187304668, -1.599732810883159]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008137171627162118, 0.00020418372109818356`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 1, {
              Complex[6.15781643675441, 0.45903052180506065`], 
              Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00020308763835436258`, -0.007895787174045757}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 2, {
              Complex[6.2004828590509335`, -0.46677236810008377`], 
              Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008320124107802841, 0.00019565660754998157`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0001954770292575028, -0.00806469881062016}],
            
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 2, {
              Complex[6.199710822382092, -0.4822227732417416], 
              Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00849648229456928, 0.0001880649389226689}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 1, {
              Complex[6.1590677155468105`, 0.48927860682774], 
              Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00018875834805917276`, -0.008227164272522897}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 2, {
              Complex[6.199010567153125, -0.49703839004290984`], 
              Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.008666951273555514, 0.0001812510033996047}],
            
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 1, {
              Complex[6.159599046539053, 0.5035094122855176], 
              Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001827782831609318, -0.008383874506682631}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 2, {
              Complex[6.198371175040328, -0.5112779620899686], 
              Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008832122316531563, 0.00017509103900316072`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 1, {
              Complex[6.160079801248174, 0.5172145811965714], 
              Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001774167402940457, -0.008535408666125609}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008992496432004095, 0.00016948650595591234`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 1, {
              Complex[6.160516992248921, 0.5304375419992584], 
              Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001725782754224628, -0.008682257285507172}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 2, {
              Complex[6.197241770749233, -0.538223239963063], 
              Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.009148502103123854, 0.0001643579303115806}],
            
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 1, {
              Complex[6.160916358296958, 0.5432161176861712], 
              Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.000168186056741713, -0.008824839728169455}],
            
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 2, {
              Complex[6.1967389220498434`, -0.5510102042411117], 
              Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.009300508854566132, 0.0001596404742500931}],
            
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 1, {
              Complex[6.161282646160605, 0.5555834916479535], 
              Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00016417752383511116`, -0.008963517524681342}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 2, {
              Complex[6.1962705954158785`, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.00944883777390483, 0.0001552806917892353}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 1, {
              Complex[6.1616198199314836`, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00016050121118446172`, -0.009098604712754553}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 2, {
              Complex[6.195832788389601, -0.5753794785718529], 
              Complex[7.637270060814722, -1.715957196142648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009593769773936337, 0.00015123411459559217`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 1, {
              Complex[6.161931218858729, 0.5791985860418423], 
              Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001571143864637731, -0.009230375953770095}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 2, {
              Complex[6.1954221248841135`, -0.5870171355873215], 
              Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009735552155171157, 0.00014746342952226242`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 1, {
              Complex[6.162219678012526, 0.5904955973399484], 
              Complex[7.615928222964841, -0.621726996632902]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00015398126923943687`, -0.009359072976951278}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 2, {
              Complex[6.195035734438572, -0.5983220770848242], 
              Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009874403872509138, 0.00014393708480225673`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 1, {
              Complex[6.162487621687207, 0.6014808784641323], 
              Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00015107166983349945`, -0.009484909749142928}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 2, {
              Complex[6.194671158739189, -0.6093151811133911], 
              Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.010010519802253664`, 0.000140628211346308}],
            
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 1, {
              Complex[6.162737136528052, 0.6121732527479822], 
              Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001483599368338094, -0.009608076661812319}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 2, {
              Complex[6.194326278421569, -0.6200152737048314], 
              Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.010144074229468043`, 0.0001375137787922375}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 1, {
              Complex[6.162970029380981, 0.6225897638061394], 
              Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00014582413438334925`, -0.00972874395182638}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 2, {
              Complex[6.193999255154619, -0.63043940107047], 
              Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010275223721115301`, 0.00013457392859688613`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 1, {
              Complex[6.1631878734954, 0.6327459028649584], 
              Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00014344539264207157`, -0.009847064518800526}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010404109510805146`, 0.00013179144216395999`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 1, {
              Complex[6.163392045750655, 0.6426557999628854], 
              Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0001412073902384817, -0.009963176262791015}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 2, {
              Complex[6.193392563005682, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010530859491846628`, 0.00012915131304360873`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 1, {
              Complex[6.163583756894771, 0.6523323858111204], 
              Complex[7.617513055986503, -0.564265877881112]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00013909593837386922`, -0.010077204037420625`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 2, {
              Complex[6.193110249156134, -0.660204284545775], 
              Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.01065558989364174, 0.00012664040011683552`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 1, {
              Complex[6.163764076292796, 0.6617875296457958], 
              Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[
            PointBox[{0.00013709864397188666`, -0.010189261292204219`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 2, {
              Complex[6.192840447329175, -0.6696666607954201], 
              Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010778406700173482`, 0.00012424714436346613`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 1, {
              Complex[6.16393395232409, 0.671032157293945], 
              Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00013520463484573844`, -0.010299451461815896`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 2, {
              Complex[6.192582182972333, -0.6789184304865281], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.01089940685697981, 0.00012196133597252762`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 1, {
              Complex[6.164094229303429, 0.680076352824419], 
              Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0001334043339304999, -0.01040786914787711}],
            
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 2, {
              Complex[6.192334586512061, -0.6879696797720971], 
              Complex[7.632109194769857, -1.820245960840084]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011018679303531823`, 0.00011977392161764537`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 1, {
              Complex[6.164245661604394, 0.6889294464957759], 
              Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00013168927263437736`, -0.010514601129528218`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 2, {
              Complex[6.192096879187743, -0.6968297409230599], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011136305860612636`, 0.00011767684401498139`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 1, {
              Complex[6.164388925515004, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00013005193560794431`, -0.010619727231844997`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 2, {
              Complex[6.191868361155921, -0.7055072687737808], 
              Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011252361996587017`, 0.00011566290760358118`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 1, {
              Complex[6.164524629243228, 0.7060963291837459], 
              Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012848563091733908`, -0.010723321075553805`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 2, {
              Complex[6.191648401446948, -0.7140103074539127], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011366917491971376`, 0.00011372566549969276`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 1, {
              Complex[6.164653321403731, 0.7144256505494253], 
              Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012698438089105512`, -0.01082545072709355}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 2, {
              Complex[6.191436429442565, -0.7223463488774431], 
              Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.01148003701816932, 0.0001118593238813853}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 1, {
              Complex[6.164775498250602, 0.7225950446980839], 
              Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012554282989216437`, -0.010926179264591822`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 2, {
              Complex[6.191231927609488, -0.7305223842033104], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.011591780643416129`, 0.0001100586607354298}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 1, {
              Complex[6.164891609869033, 0.7306110457745064], 
              Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012415616602594123`, -0.011025565272549586`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011702204276713793`, 0.00010831895650162754`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 1, {
              Complex[6.165002065498246, 0.738479772924393], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012282005438302707`, -0.01112366327580788}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 2, {
              Complex[6.190843493278558, -0.7464201648848559], 
              Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[
            PointBox[{0.011811360058713392`, 0.00010663593462405164`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 1, {
              Complex[6.1651072381259, 0.7462069660795196], 
              Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012153057987975448`, -0.011220524121579372`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 2, {
              Complex[6.190658739339742, -0.7541537725552644], 
              Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.01191929670702589, 0.00010500571038975908`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 1, {
              Complex[6.165207468468805, 0.7537980178639989], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00012028419812139092`, -0.011316195316876127`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 2, {
              Complex[6.190479804059834, -0.761751166453437], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012026059822232198`, 0.00010342474673363855`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 1, {
              Complex[6.165303068434313, 0.761258002124613], 
              Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011907769300318255`, -0.01141072132748129}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012131692159879295`, 0.00010188981592308498`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 1, {
              Complex[6.165394324140473, 0.7685916995129604], 
              Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011790813999382256`, -0.011504143843643417`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 2, {
              Complex[6.190138095789615, -0.7765573210571961], 
              Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012236233872932765`, 0.00010039796622609919`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 1, {
              Complex[6.1654814985597985`, 0.7758036204842987], 
              Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011677287423178057`, -0.011596502016872975`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 2, {
              Complex[6.18997473915616, -0.7837753757227331], 
              Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.012339722728483696`, 0.0000989464928204659}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 1, {
              Complex[6.1655648338407385`, 0.7828980260257037], 
              Complex[7.619946700555888, -0.443528162616499]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011566946271330451`, -0.01168783267156088}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 2, {
              Complex[6.189816028885474, -0.7908758482666055], 
              Complex[7.627776768560513, -1.914949385030405]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012442194301947937`, 0.00009753291232477221}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 1, {
              Complex[6.165644553352178, 0.7898789463823163], 
              Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011459567997249234`, -0.011778170494589759`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012543682151528493`, 0.00009615494043446911}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 1, {
              Complex[6.165720863489107, 0.7967501980135657], 
              Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011354948675169431`, -0.011867548205650127`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 2, {
              Complex[6.189511607388403, -0.804739959431843], 
              Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01264421797532069, 0.00009481047222760578}],
            
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 1, {
              Complex[6.165793955271714, 0.8035153989801244], 
              Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0001125290112421401, -0.011955996710591164`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 2, {
              Complex[6.189365468138804, -0.8115110351012247], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012743831753109091`, 0.00009349756477591084}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 1, {
              Complex[6.1658640057650915`, 0.8101779829358522], 
              Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011153253254058279`, -0.012043545239811321`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 2, {
              Complex[6.189223116150438, -0.8181794321268676], 
              Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012842551874628965`, 0.00009221442174935818}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 1, {
              Complex[6.165931179342954, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00011055846602155672`, -0.012130221473423056`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 2, {
              Complex[6.18908437282858, -0.8247484136793249], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012940405255827271`, 0.00009095937975340682}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 1, {
              Complex[6.165995628815023, 0.823208187778776], 
              Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010960535037244295`, -0.01221605165469362}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 2, {
              Complex[6.188949071546019, -0.8312210828762437], 
              Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013037417444459241`, 0.00008973089617359305}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 1, {
              Complex[6.166057496435186, 0.8295818632429409], 
              Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010867183607447517`, -0.012301060693068636`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 2, {
              Complex[6.188817056619653, -0.8376003934276774], 
              Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01313361271618432, 0.00008852753833644915}],
            
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 1, {
              Complex[6.1661169148049755`, 0.8358650512460941], 
              Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010775667514492531`, -0.012385272257916677`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 2, {
              Complex[6.188688182392475, -0.8438891593891127], 
              Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01322901416218017, 0.00008734797382354233}],
            
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010685871198251109`, -0.012468708863990798`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 2, {
              Complex[6.188562312408357, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013323643769166442`, 0.00008619096179644857}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 1, {
              Complex[6.166228890724623, 0.8481705716325338], 
              Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010597687518041471`, -0.012551391949478892`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 2, {
              Complex[6.1884393186687205`, -0.8562056684719376], 
              Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013417522492622585`, 0.00008505534521182583}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 1, {
              Complex[6.166281672121116, 0.8541979088518953], 
              Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010511017018919085`, -0.012633341947409595`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 2, {
              Complex[6.188319080961654, -0.8622384184423437], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01351067032389068, 0.00008394004382154596}],
            
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 1, {
              Complex[6.166332453213396, 0.8601447828394871], 
              Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010425767272893734`, -0.012714578351088784`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013603106351772557`, 0.00008284404786608799}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 1, {
              Complex[6.166381329020564, 0.8660134292433507], 
              Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010341852286310091`, -0.012795119774162476`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 2, {
              Complex[6.188086428148008, -0.8740646059731705], 
              Complex[7.6243541862563, -1.990999855207028]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013694848819161503`, 0.00008176641238284863}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 1, {
              Complex[6.166428388729593, 0.8718059882315833], 
              Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0001025919196573027, -0.01287498400583351}],
            
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 2, {
              Complex[6.187973806370098, -0.8798624212060279], 
              Complex[7.624115410024538, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013785915175186384`, 0.00008070625205980755}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 1, {
              Complex[6.166473716138243, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0001017771163577503, -0.012954188061699375`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 2, {
              Complex[6.187863526329917, -0.8855861488792874], 
              Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013876322123293993`, 0.00007966273657437125}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 1, {
              Complex[6.166517390057898, 0.8831709599557609], 
              Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010097341603057255`, -0.013032748230626817`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 2, {
              Complex[6.187755498701229, -0.8912377552298747], 
              Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01396608566564808, 0.00007863508636490288}],
            
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00010018016761189808`, -0.013110680118032623`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 2, {
              Complex[6.187649639046593, -0.8968191263829133], 
              Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01405522114418286, 0.00007762256878835724}],
            
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 1, {
              Complex[6.166600069913391, 0.8942551097650246], 
              Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009939676232514403, -0.013187998685901361`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 2, {
              Complex[6.187545867473453, -0.9023320727684235], 
              Complex[7.623188002862294, -2.016726496581311]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014143743278613091`, 0.00007662449462348654}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 1, {
              Complex[6.166639211685018, 0.8996963572765853], 
              Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009862263042435435, -0.013264718289833752`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 2, {
              Complex[6.187444108319425, -0.9077783332310714], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014231666201671236`, 0.00007564021488382192}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 1, {
              Complex[6.166676972224923, 0.9050726361762731], 
              Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009785723823190668, -0.013340852713390899`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 2, {
              Complex[6.187344289864064, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014319003491814116`, 0.00007466911790844169}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 1, {
              Complex[6.166713410320053, 0.9103855526005633], 
              Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[
            PointBox[{0.00009710008543867353, -0.013416415199970614`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014405768203617343`, 0.00007371062670320211}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0000963507026402522, -0.01349141848242857}],
            
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 2, {
              Complex[6.187150206311988, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014491972896053638`, 0.00007276419650681735}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 1, {
              Complex[6.166782538502952, 0.9208274215121246], 
              Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00009560864908603295, -0.01356587481063642}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 2, {
              Complex[6.1870558152094315`, -0.9289289945966069], 
              Complex[7.622084507976148, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014577629658832063`, 0.00007182931256029867}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 1, {
              Complex[6.166815330974628, 0.9259592943584081], 
              Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009487351061938843, -0.013639795977148893`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 2, {
              Complex[6.186963112364547, -0.9340656567439883], 
              Complex[7.621870484005858, -2.045532964655917]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.014662750136957779`, 0.0000709054880600767}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 1, {
              Complex[6.166847006151044, 0.9310336510892632], 
              Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000941448977912444, -0.013713193341136201`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 2, {
              Complex[6.186872042200558, -0.9391447601963707], 
              Complex[7.621658530284452, -2.050135996258457]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014747345553657273`, 0.00006999226227721734}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 1, {
              Complex[6.166877608777316, 0.9360518228828759], 
              Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009342244412879136, -0.013786077850722969`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.014831426731799413`, 0.0000690891988270076}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 1, {
              Complex[6.166907181313368, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00009270580454751821, -0.01385846006386034}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 2, {
              Complex[6.186694590646789, -0.9491355712999217], 
              Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014915004113931509`, 0.00006819588407562315}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 1, {
              Complex[6.166935764077781, 0.9459247030157971], 
              Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.000091994653888992, -0.013930350167849163`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014998087781037882`, 0.00006731192567049408}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 1, {
              Complex[6.166963395380894, 0.9507818469782096], 
              Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00009128868557698899, -0.01400175799761618}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 2, {
              Complex[6.186523065904121, -0.9589115304824511], 
              Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[
            PointBox[{0.015080687470119295`, 0.00006643695118409165}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 1, {
              Complex[6.166990111648028, 0.9555876813576081], 
              Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00009058761037848554, -0.014072693052843293`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 2, {
              Complex[6.186439412474038, -0.9637219085313011], 
              Complex[7.620627795708716, -2.072379088667851]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01516281259068242, 0.00006557060686018385}],
            
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008989115526037919, -0.014143164514032119`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 2, {
              Complex[6.1863571084384, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015244472240220857`, 0.00006471255645457658}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 1, {
              Complex[6.1670409360276865`, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000891990623349875, -0.014213181257587755`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 2, {
              Complex[6.186276113687406, -0.9731930502608692], 
              Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01532567521876204, 0.00006386248016099081}],
            
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008851108788484859, -0.014282751869990923`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 2, {
              Complex[6.186196389837632, -0.977855938983316], 
              Complex[7.620030720208938, -2.085147528272351]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015406430042548195`, 0.00006302007361589074}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 1, {
              Complex[6.1670884950589855`, 0.974319711882344], 
              Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008782700146016083, -0.014351884661126964`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 2, {
              Complex[6.186117900135718, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01548674495691325, 0.00006218504697482604}],
            
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 1, {
              Complex[6.167111124103515, 0.9788850321593934], 
              Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008714658504386102, -0.014420587676831135`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 2, {
              Complex[6.186040609368656, -0.9870414080668142], 
              Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015566627948413207`, 0.00006135712405477904}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 1, {
              Complex[6.167133022935145, 0.9834052186894809], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00008646963227719805, -0.01448886871070637}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 2, {
              Complex[6.18596448378006, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015646086756261772`, 0.00006053604153667182}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 1, {
              Complex[6.1671542175655905`, 0.9878811887189864], 
              Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008579594774142247, -0.014556735315264396`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.10155454761218]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015725128883119756`, 0.00005972154822351084}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 1, {
              Complex[6.167174732838952, 0.992313831072267], 
              Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008512534629083598, -0.014624194812436982`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 2, {
              Complex[6.185815599931938, -1.000483060574068], 
              Complex[7.619067332909202, -2.105552017907877]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01580376160528209, 0.000058913404349508835`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 1, {
              Complex[6.167194592496085, 0.9967040073387544], 
              Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00008445765243319725, -0.01469125430350039}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 2, {
              Complex[6.185742780764412, -1.004877451924907], 
              Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015881991982303337`, 0.000058111380936145576`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 1, {
              Complex[6.167213819234735, 1.0010525529976395`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008379269975307172, -0.014757920678452774`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 2, {
              Complex[6.185671004827051, -1.0092301787755908`], 
              Complex[7.618692192411457, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0159598268660989, 0.00005731525919135363}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 1, {
              Complex[6.16723243476579, 1.005360278484099], 
              Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008313033037549841, -0.014824200624880872`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0160372729095568, 0.000056524829948787575`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 1, {
              Complex[6.16725045986591, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000824703944659548, -0.014890100636349692`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 2, {
              Complex[6.185530473503019, -1.017813858605525], 
              Complex[7.618322479547935, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01611433657469164, 0.00005573989314365456}],
            
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 1, {
              Complex[6.167267914426828, 1.013856391477559], 
              Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000818127497645487, -0.014955627020346423`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 2, {
              Complex[6.185461666136161, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016191024140370287`, 0.000054960257323016006`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008115726115113722, -0.015020785905807053`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 2, {
              Complex[6.185393797936859, -1.0262403046082502`], 
              Complex[7.617957948303616, -2.128722917140586]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01626734170963661, 0.00005418573918690953}],
            
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 1, {
              Complex[6.167301187347679, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00008050380023955932, -0.015085583250252324`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 2, {
              Complex[6.185326845280091, -1.030396405990655], 
              Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016343295216660444`, 0.00005341616315920058}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007985224499827608, -0.015150024846557825`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01641889043333397, 0.00005265136098490229}],
            
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 1, {
              Complex[6.167332396649198, 1.0303918810590926`], 
              Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.00007920247939572364, -0.0152141163293805}],
            
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 2, {
              Complex[6.185195596375154, -1.0385978654970505`], 
              Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016494132975537645`, 0.000051891171353054855`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 1, {
              Complex[6.1673472689966875`, 1.0344346539072418`], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007855439306864636, -0.015277863181263422`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 2, {
              Complex[6.185131257036874, -1.0426445649584837`], 
              Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016569028309095204`, 0.00005113543954217889}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007790788101143721, -0.015341270738437237`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 2, {
              Complex[6.185067746985585, -1.0466561075785734`], 
              Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.016643581755436867`, 0.0000503840170878865}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 1, {
              Complex[6.167375626411306, 1.0424154437428594`], 
              Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007726284328499826, -0.01540434419633824}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 2, {
              Complex[6.1850050465299, -1.0506331187508056`], 
              Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016717798496987974`, 0.00004963676147010318}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 1, {
              Complex[6.167389140580846, 1.04635469380724], 
              Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007661918474402527, -0.015467088614858238`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01679168358229922, 0.00004889353581917154}],
            
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 1, {
              Complex[6.167402230179722, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007597681478109437, -0.015529508923342957`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 2, {
              Complex[6.1848819990139186`, -1.0584859643603293`], 
              Complex[7.616547285902736, -2.157643104664951]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01686524193093342, 0.00004815420863914441}],
            
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 1, {
              Complex[6.167414908379169, 1.054133863773935], 
              Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007533564708633251, -0.01559160992535348}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 2, {
              Complex[6.184821615854545, -1.062362967438099], 
              Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01693847833812298, 0.00004741865354734817}],
            
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 1, {
              Complex[6.167427187845094, 1.0579749207033107`], 
              Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007469559942179713, -0.015653396303204177`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 2, {
              Complex[6.184761970036191, -1.0662077774973115`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01701139747921123, 0.00004668674902898109}],
            
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 1, {
              Complex[6.167439080761725, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007405659340957377, -0.01571487262229008}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 2, {
              Complex[6.184703044981658, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017084003913889447`, 0.00004595837820571265}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007341855433218409, -0.01577604333521545}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 2, {
              Complex[6.184644824657079, -1.07380299123558], 
              Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017156302090241434`, 0.00004523342861762625}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 1, {
              Complex[6.167461753408532, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007278141094531802, -0.01583691278573471}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 2, {
              Complex[6.184587293548676, -1.0775544464801792`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017228296348606027`, 0.00004451179201696757}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0000721450953008977, -0.01589748521251611}],
            
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 2, {
              Complex[6.1845304366407206`, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01729999092526745, 0.00004379336417387017}],
            
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 1, {
              Complex[6.1674830149790685`, 1.0767163678318639`], 
              Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{0.0000715095425811302, -0.01595776475273775}],
            
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 2, {
              Complex[6.184474239394659, -1.0849675833073054`], 
              Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01737138995598306, 0.000043078044692507626`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 1, {
              Complex[6.1674931425517565`, 1.08037543065552], 
              Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007087469094152211, -0.016017755445525195`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 2, {
              Complex[6.184418687729288, -1.0886302388755988`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017442497479357076`, 0.00004236573683720925}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 1, {
              Complex[6.167502947734983, 1.0840058730914166`], 
              Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00007024048136329787, -0.01607746123523904}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017513317440068423`, 0.00004165634736835772}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 1, {
              Complex[6.167512439903273, 1.0876081523509995`], 
              Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00006960685751397533, -0.01613688597462048}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 2, {
              Complex[6.1843094669907455`, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01758385369196053, 0.00004094978638658867}],
            
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 1, {
              Complex[6.167521628097823, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000689737656156713, -0.016196033427802275`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 2, {
              Complex[6.18425577187742, -1.0994481489240884`], 
              Complex[7.614715122272779, -2.194233932689377]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017654110001000145`, 0.00004024596718561837}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 1, {
              Complex[6.167530521040912, 1.0947299951246656`], 
              Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006834115432122251, -0.016254907273192263`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 2, {
              Complex[6.184202670231408, -1.1029989218798246`], 
              Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0177240900481118, 0.0000395448061128102}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 1, {
              Complex[6.167539127149569, 1.098250419067797], 
              Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006770897459664065, -0.016313511106235783`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 2, {
              Complex[6.184150149994408, -1.1065228138938465`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01779379743189486, 0.00003884622243672703}],
            
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 1, {
              Complex[6.167547454548559, 1.1017444013712936`], 
              Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006707717961011071, -0.016371848442063488`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 2, {
              Complex[6.184098199465816, -1.1100202402427715`], 
              Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017863235671228186`, 0.000038150138221816275`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 1, {
              Complex[6.167555511082704, 1.1052123472899034`], 
              Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006644572462741514, -0.016429922718030003`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 2, {
              Complex[6.1840468072888495`, -1.1134916064718126`], 
              Complex[7.614075476378116, -2.206739345003816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0179324082077689, 0.00003745647820939419}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006581456691252641, -0.016487737296149288`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 2, {
              Complex[6.183995962437312, -1.1169373087010905`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01800131840835004, 0.000036765169704806913`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 1, {
              Complex[6.16757084160569, 1.1120717041858348`], 
              Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006518366563382324, -0.016545295465431435`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 2, {
              Complex[6.183945654203009, -1.1203577339198187`], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018069969567282268`, 0.000036076142469927747`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 1, {
              Complex[6.167578129986962, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000645529817751768, -0.016602600444126106`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 2, {
              Complex[6.1838958721837285`, -1.1237532602689642`], 
              Complex[7.613604090254429, -2.215864050835693]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018138364908564155`, 0.00003538932862157527}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 1, {
              Complex[6.167585176308896, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006392247805180864, -0.016659655381877015`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 2, {
              Complex[6.1838466062718, -1.1271242573129145`], 
              Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018206507588005745`, 0.00003470466253439348}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 1, {
              Complex[6.167591987181104, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00006329211883050085, -0.01671646336179158}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 2, {
              Complex[6.183797846643169, -1.1304710863006642`], 
              Complex[7.613293610009215, -2.221831501514852]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018274400695269224`, 0.00003402208074890976}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 1, {
              Complex[6.167598568995433, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00006266187005384801, -0.016773027402430623`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 2, {
              Complex[6.183749583746966, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01834204725583087, 0.000033341521883739584`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 1, {
              Complex[6.167604927934658, 1.128791084903274], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00006203169916875142, -0.01682935045971989}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 2, {
              Complex[6.183701808295563, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018409450232867944`, 0.00003266292655252704}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 1, {
              Complex[6.16761106998075, 1.1320642574808064`], 
              Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00006140157505818022, -0.01688543542879032}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 2, {
              Complex[6.183654511255059, -1.1403700578948637`], 
              Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01847661252907392, 0.00003198623728417546}],
            
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00006077146797674543, -0.01694128514574714}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 2, {
              Complex[6.183607683836199, -1.1436236694349755`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018543536988405482`, 0.000031311398447460836`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 1, {
              Complex[6.167622726364391, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000060141349489238485`, -0.016996902389373066`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 2, {
              Complex[6.183561317485685, -1.1468548029005128`], 
              Complex[7.612529927102651, -2.236364734026166]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01861022639776446, 0.000030638356178928305`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 1, {
              Complex[6.1676282517310606`, 1.1417483803738426`], 
              Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000059511192412487005`, -0.017052289882767906`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 2, {
              Complex[6.183515403877874, -1.1500637746045628`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018676683488617524`, 0.00002996705831414972}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 1, {
              Complex[6.167633582276865, 1.1449323435024108`], 
              Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000588809707600112, -0.017107450294927624`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 2, {
              Complex[6.183469934906837, -1.1532508941175408`], 
              Complex[7.612229226993079, -2.242030438093195]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018742910938556453`, 0.00002929745432227452}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 1, {
              Complex[6.167638723091055, 1.1480947778478905`], 
              Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000058250659689389215`, -0.017162386242265702`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 2, {
              Complex[6.183424902678746, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018808911372801884`, 0.000028629495243535627`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 1, {
              Complex[6.167643679104286, 1.1512359798388985`], 
              Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005762023545225092, -0.017217100290078946`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 2, {
              Complex[6.1833802995046, -1.1595607822888863`], 
              Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0188746873656527, 0.00002796313362957265}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 1, {
              Complex[6.167648455094579, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005698967534671561, -0.017271594953960835`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 2, {
              Complex[6.183336117893254, -1.1626841380761952`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018940241441883693`, 0.000027298323486523865`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005635895767219715, -0.017325872701164306`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 2, {
              Complex[6.183292350544735, -1.1657868162826117`], 
              Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[
            PointBox[{0.01900557607809369, 0.000026635020220632116`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 1, {
              Complex[6.16765748538922, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000557280616861039, -0.017379935951915792`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 2, {
              Complex[6.183248990343842, -1.1688690955240477`], 
              Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019070693704006235`, 0.00002597318058627428}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 1, {
              Complex[6.1676617485364815`, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005509696756322031, -0.017433787080684434`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 2, {
              Complex[6.1832060303540155`, -1.171931248732845], 
              Complex[7.611342435457713, -2.258551532233561]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019135596703724965`, 0.000025312762636408104`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 1, {
              Complex[6.167665849356821, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000054465656356212715`, -0.01748742841740504}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 2, {
              Complex[6.183163463811437, -1.1749735433132202`], 
              Complex[7.611196771510031, -2.261238440302506]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019200287416945534`, 0.00002465372567500001}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 1, {
              Complex[6.167669791945717, 1.1696531548443287`], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005383410995866436, -0.017540862248660926`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 2, {
              Complex[6.183121284119393, -1.1779962412914966`], 
              Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019264768140125947`, 0.000023996030211628008`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 1, {
              Complex[6.167673580276672, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005320231106953523, -0.017594090818824216`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 2, {
              Complex[6.1830794848428505`, -1.180999599461101], 
              Complex[7.610907194686489, -2.266557440612444]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01932904112761703, 0.00002333963791806284}],
            
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 1, {
              Complex[6.167677218205581, 1.1756348399245424`], 
              Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005257024315934092, -0.017647116331159233`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01939310859275479, 0.000022684511586734802`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 1, {
              Complex[6.167680709474919, 1.1785973245423345`], 
              Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000051937890437981434`, -0.017699940948886935`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.271804947320256]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.01945697270891603, 0.000022030615090969}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 1, {
              Complex[6.1676840577177385`, 1.1815412277835526`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005130523782384523, -0.017752566796214904`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 2, {
              Complex[6.182956307473314, -1.1898961274694768`], 
              Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01952063561053895, 0.000021377913346616327`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 1, {
              Complex[6.167687266461523, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000050672270914641136`, -0.017804995959332617`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 2, {
              Complex[6.182915968564257, -1.1928245944888065`], 
              Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.019584099394110138`, 0.0000207263722759926}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 1, {
              Complex[6.167690339131856, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00005003897595918243, -0.017857230487373855`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 2, {
              Complex[6.1828759801456865`, -1.1957349319176866`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019647366119118978`, 0.000020075958772468383`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 1, {
              Complex[6.167693279055961, 1.1902637967550591`], 
              Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004940533983086928, -0.017909272393347886`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019710437808981365`, 0.000019426640667146067`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00004877135000202762, -0.01796112365504014}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 2, {
              Complex[6.182797032640057, -1.201502126383065], 
              Complex[7.609911224902995, -2.284622879275391]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01977331645193336, 0.000018778386696722693`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 1, {
              Complex[6.167698773502733, 1.1959901616082875`], 
              Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000048136994519451785`, -0.01801278621588398}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 2, {
              Complex[6.182758062802262, -1.2043594268588764`], 
              Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019836004001896355`, 0.00001813116647256956}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004750226198123595, -0.018064261985804658`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.01989850237931477, 0.00001748495045110146}],
            
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 1, {
              Complex[6.167703774577614, 1.201647620337123], 
              Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000046867141514543706`, -0.01811555284203624}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019960813471967053`, 0.000016839709905642164`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004623162275407236, -0.018166660629913012`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 2, {
              Complex[6.182643106997762, -1.2128287152203816`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020022939135751795`, 0.000016195416898727976`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 1, {
              Complex[6.167708305685528, 1.2072378477042838`], 
              Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004559569582194904, -0.018217587163636015`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 2, {
              Complex[6.182605423099423, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.02008488119544889, 0.00001555204425634748}],
            
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 1, {
              Complex[6.1677104019634195`, 1.210008256181661], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00004495935130812322, -0.01826833422701575}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 2, {
              Complex[6.182568048561961, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02014664144545739, 0.000014909565542578746`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 1, {
              Complex[6.167712388950775, 1.2127624573020033`], 
              Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00004432258025178539, -0.01831890357419205}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020208221650510876`, 0.000014267955035548567`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 1, {
              Complex[6.167714269226694, 1.2155006436945395`], 
              Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004368537412354034, -0.018369296930331794`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 2, {
              Complex[6.1824942091285005`, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020269623546370883`, 0.00001362718770403791}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 1, {
              Complex[6.167716045300302, 1.2182230045272868`], 
              Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000043047724808309545`, -0.018419515992305516`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 2, {
              Complex[6.182457735262816, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020330848840499384`, 0.000012987239185420838`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 1, {
              Complex[6.167717719612997, 1.2209297255903704`], 
              Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000042409624589047915`, -0.018469562429343587`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 2, {
              Complex[6.1824215528129, -1.229323793839144], 
              Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02039189921271109, 0.000012348085764071427`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 1, {
              Complex[6.167719294540649, 1.2236209893768326`], 
              Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.000041771066131126, -0.01851943788367256}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 2, {
              Complex[6.182385657532068, -1.2320177339512255`], 
              Complex[7.608396583634034, -2.31141882849242]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020452776315806796`, 0.000011709704350458222`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 1, {
              Complex[6.167720772395696, 1.2262969751610366`], 
              Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000041132042467216896`, -0.018569143971132823`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 2, {
              Complex[6.182350045264077, -1.2346963807243223`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020513481776186657`, 0.00001107207246201154}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 1, {
              Complex[6.16772215542913, 1.2289578590746735`], 
              Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00004049254698309021, -0.018618682281777772`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 2, {
              Complex[6.182314711940597, -1.2373599104404132`], 
              Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020574017194447177`, 0.000010435168203307134`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 1, {
              Complex[6.167723445832482, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000398525734038745, -0.018668054380455462`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.020634384145959517`, 9.798970248016372*^-6}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 1, {
              Complex[6.167724645739662, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000039212115780692606`, -0.018717261807373355`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 2, {
              Complex[6.182244866278791, -1.242642308546148], 
              Complex[7.607859712684855, -2.320721705723057]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.020694584181431608`, 9.163457821085337*^-6}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 1, {
              Complex[6.167725757228776, 1.2368516153041005`], 
              Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00003857116847820908, -0.018766306078646683`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 2, {
              Complex[6.1822103462217495`, -1.245261514429298], 
              Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.020754618827453365`, 8.52861068180497*^-6}],
            
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 1, {
              Complex[6.16772678232385, 1.2394537927373115`], 
              Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000037929726162553695`, -0.018815188686830867`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 2, {
              Complex[6.182176089667306, -1.2478662783795629`], 
              Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.020814489587027928`, 7.894409107289625*^-6}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 1, {
              Complex[6.167727722996508, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000037287783789436305`, -0.018863911101439007`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.020874197940085628`, 7.260833876695686*^-6}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 1, {
              Complex[6.16772858116758, 1.2446155088257413`], 
              Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000036645336593354655`, -0.01891247476944449}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 2, {
              Complex[6.182108352485272, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02093374534398508, 6.627866255969238*^-6}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 1, {
              Complex[6.167729358708656, 1.247175362316046], 
              Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[
            PointBox[{0.000036002380076657035`, -0.018960881115769376`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 2, {
              Complex[6.182074864751301, -1.2555955212603063`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02099313323399953, 5.995487983124089*^-6}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 1, {
              Complex[6.167730057443585, 1.249721418272031], 
              Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00003535890999936098, -0.019009131543759297`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 2, {
              Complex[6.182041626303249, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.021052363023789794`, 5.363681254299548*^-6}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 1, {
              Complex[6.167730679149904, 1.2522538276170248`], 
              Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000034714922369315136`, -0.019057227435644954`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.021111436105864245`, 4.732428709541781*^-6}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000034070413432834785`, -0.019105170152990944`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 2, {
              Complex[6.181975883820568, -1.2632004444906197`], 
              Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02117035385202574, 4.1017134202401694`*^-6}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0000334253796653949, -0.019152961037132148`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 2, {
              Complex[6.1819433732291715`, -1.2657084915461239`], 
              Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021229117613806796`, 3.4715188762278455`*^-6}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 1, {
              Complex[6.167732099207092, 1.2597706481409663`], 
              Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00003277981776324891, -0.019200601409598388`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 2, {
              Complex[6.181911098806735, -1.2682033164767692`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.021287728722892665`, 2.84182897314011*^-6}],
            
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 1, {
              Complex[6.167732429696165, 1.2622499312165703`], 
              Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000032133724634719964`, -0.019248092572527416`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 2, {
              Complex[6.1818790574326545`, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021346188491533063`, 2.2126280012428766`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000031487097392477253`, -0.0192954358090667}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 2, {
              Complex[6.181847246046556, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021404498212942883`, 1.5839006334069697`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 1, {
              Complex[6.167732885836667, 1.2671698491615644`], 
              Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000030839933345540375`, -0.01934263238376469}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 2, {
              Complex[6.181815661646743, -1.275609861130944], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.021462659161692207`, 9.556319143839625*^-7}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 1, {
              Complex[6.167733014505244, 1.2696107553621172`], 
              Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00003019222999208535, -0.01938968354295141}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 2, {
              Complex[6.1817843012887375`, -1.2780531889506415`], 
              Complex[7.606032678038458, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02152067259408595, 3.2780725002276226`*^-7}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 1, {
              Complex[6.167733078856032, 1.272039137007607], 
              Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000029543985012168502`, -0.019436590515109122`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.353740237720617]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021578539748533528`, -2.9958760296249024`*^-7}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 1, {
              Complex[6.1677330803070305`, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000028895196260943207`, -0.019483354511233213`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021636261845908947`, -9.265665468956587*^-7}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 1, {
              Complex[6.167733020241881, 1.276858845955496], 
              Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000028245861762047984`, -0.019529976725183612`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 2, {
              Complex[6.181691535849006, -1.2853084672867796`], 
              Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021693840089901356`, -1.5531431528529015`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000027595979701056482`, -0.01957645833402711}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 2, {
              Complex[6.181661043308228, -1.2877024197670905`], 
              Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.02175127566735666, -2.179330670005249*^-6}],
            
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 1, {
              Complex[6.167732720931719, 1.2816299944237621`], 
              Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000026945548420090787`, -0.01962280049837084}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 2, {
              Complex[6.181630760896252, -1.2900843444730699`], 
              Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021808569748610337`, -2.805142034521052*^-6}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 1, {
              Complex[6.167732484290831, 1.2839976681063678`], 
              Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000026294566410850872`, -0.01966900436268713}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 2, {
              Complex[6.181600685983191, -1.2924543639191768`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021865723487811704`, -3.430589877818584*^-6}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00002564303231016391, -0.019715071055630296`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 2, {
              Complex[6.181570815987224, -1.2948125987358035`], 
              Complex[7.605146784820535, -2.366194163693253]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021922738023240008`, -4.055686536079513*^-6}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 1, {
              Complex[6.167731843316621, 1.2886978170110817`], 
              Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000024990944893538338`, -0.019761001690344854`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 2, {
              Complex[6.181541148373396, -1.2971591677080394`], 
              Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02197961447761249, -4.68044405725197*^-6}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00002433830307063016, -0.019806797364766773`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 2, {
              Complex[6.18151168065253, -1.2994941878134685`], 
              Complex[7.604896783758138, -2.370257325860909]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022036353958384724`, -5.3048742093371045`*^-6}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00002368510587997159, -0.01985245916191639}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022092957558043486`, -5.928988488271689*^-6}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{0.00002303135248403955, -0.01989798815018453}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 2, {
              Complex[6.18145333515529, -1.3041300405165688`], 
              Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.022149426354392404`, -6.55279812471858*^-6}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 1, {
              Complex[6.167729923927075, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000022377042164773503`, -0.019943385383611262`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 2, {
              Complex[6.181424452619743, -1.3064310983584468`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[PointBox[{0.02220576141083042, -7.176314091665782*^-6}],
            
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00002172217431901649, -0.019988651902157994`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 2, {
              Complex[6.181395760456799, -1.3087210578909678`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.022261963776623494`, -7.79954711115714*^-6}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 1, {
              Complex[6.167728663570656, 1.3025249977626074`], 
              Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000021066748454153544`, -0.020033788731972712`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 2, {
              Complex[6.181367256390402, -1.3110000275879252`], 
              Complex[7.604277546409371, -2.380230742900865]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022318034487169833`, -8.422507660898433*^-6}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 1, {
              Complex[6.167727961973395, 1.304790845205713], 
              Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000020410764184196096`, -0.020078796885648845`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 2, {
              Complex[6.181338938184205, -1.3132681143229286`], 
              Complex[7.604154661093243, -2.382194632873834]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.0223739745642584, -9.045205980819878*^-6}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 1, {
              Complex[6.167727214125249, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000019754221225338074`, -0.020123677362477905`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 2, {
              Complex[6.18131080364063, -1.3155254234009877`], 
              Complex[7.604032089130619, -2.384148493285349]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022429785016321382`, -9.667652079379296*^-6}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 1, {
              Complex[6.167726421018415, 1.3092903447657456`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00001909711939243915, -0.020168431148695966`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 2, {
              Complex[6.181282850600006, -1.3177720585893227`], 
              Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02248546683868063, -0.000010289855739507537`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 1, {
              Complex[6.167725583622502, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000018439458595360363`, -0.020213059217724216`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022541021013788135`, -0.000010911826524612616`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 1, {
              Complex[6.16772470288514, 1.313747600858923], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00001778123883516036, -0.020257562530403932`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 2, {
              Complex[6.181227480573279, -1.32223371485628], 
              Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{0.02259644851146069, -0.00001153357378422923}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 1, {
              Complex[6.167723779732554, 1.3159606384280345`], 
              Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00001712246020064046, -0.020301942035225687`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 2, {
              Complex[6.181200059449696, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02265175028910939, -0.000012155106659415127`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 1, {
              Complex[6.167722815070127, 1.3181634132423612`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00001646312286520559, -0.020346198668553195`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 2, {
              Complex[6.1811728115525035`, -1.3266538836292885`], 
              Complex[7.603423824286758, -2.393770722784648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022706927291963285`, -0.000012776434088523754`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 1, {
              Complex[6.167721809782957, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000015803227083820024`, -0.020390333354842315`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 2, {
              Complex[6.181145734899095, -1.3288486541172821`], 
              Complex[7.603303069891951, -2.395666408981522]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022761980453288193`, -0.000013397564811897367`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 1, {
              Complex[6.167720764736373, 1.322538558935139], 
              Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000015142773189004195`, -0.020434347006853922`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 2, {
              Complex[6.181118827539914, -1.3310333426575782`], 
              Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022816910694600196`, -0.00001401850737713878}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 1, {
              Complex[6.167719680776454, 1.3247111185862182`], 
              Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000014481761589478155`, -0.020478240525863486`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 2, {
              Complex[6.1810920875578015`, -1.3332080430544786`], 
              Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022871718925874352`, -0.000014639270144069595`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000013820192765465221`, -0.02052201480186375}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02292640604574854, -0.000015259861289364797`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000013158067267138311`, -0.020565670713764847`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 2, {
              Complex[6.1810391022135605`, -1.337527848075709], 
              Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0027644669961558966`, 0.0032820945785409965`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[8.118560581075961, 0.0068877274873969585`], 
              Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0027402805349560936`, -0.0032301799803080905`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[10.53989419288883, -0.01324317030169899], 
              Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0031579454556528294`, 0.0036938076965496785`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[8.162580737731858, 0.007042959985370651], 
              Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0031304688141391233`, -0.003641849166394265}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[10.494506767269, -0.013509876715323853`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.003434638816811946, 0.00398075750306297}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[8.198987977866883, 0.007197843246654797], 
              Complex[6.557943371421671, -1.162972548762566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0034044117011677163`, -0.003930469352910891}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[10.457042457039066`, -0.013751044852512806`], 
              Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0036485769029653567`, 0.004200656208179244}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[8.231005147885755, 0.0073549519610065905`], 
              Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.003615794926286512, -0.0041528743686412226`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[10.42414741707873, -0.0139798695984579], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.003822352119359727, 0.004377621601496377}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[8.260098904258959, 0.007515591774090756], 
              Complex[6.61778553109412, -1.162803172863648]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0037870767716075794`, -0.00433284808427266}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[10.39429571170861, -0.014202465960725278`], 
              Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.003967759096082339, 0.004524237709112961}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[8.287084479515974, 0.007680628289981289], 
              Complex[6.644124842294815, -1.162714599075609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.003929984845569303, -0.004482816245786688}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[10.366639367283945`, -0.014422357660350082`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004091795532068503, 0.004647966131884348}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[8.312471288002852, 0.00785074316053409], 
              Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004051477466879513, -0.004610156140773214}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[10.340648661463618`, -0.014641876121436062`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004198976897370379, 0.00475361826249581}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[8.336603564825275, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004156043821540009, -0.004719631428135556}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[10.315965756037766`, -0.014862729232274637`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004292395122458936, 0.004844485679023325}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[8.359727508694593, 0.008208588338762687], 
              Complex[6.714779367617378, -1.162425692393188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0042467562553366684`, -0.004814506201618235}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[10.29233482504539, -0.015086273942248], 
              Complex[8.556435217312078, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0043742624190675605`, 0.004922920622981176}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[8.382027043209192, 0.008397467701836855], 
              Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004325810904325515, -0.00489711746689961}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[10.269564843263957`, -0.01531366326459591], 
              Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004446215355658524, 0.004990660459127274}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[8.40364445944282, 0.008593772293729832], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004394830008985039, -0.004969195355511949}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[10.247508108692935`, -0.01554593341902805], 
              Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0045094962733934225`, 0.005049021165624798}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[8.424693095053826, 0.00879813306517896], 
              Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004455042263014165, -0.005032054237418021}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[10.226047052260421`, -0.01578406003523005], 
              Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0045650672025310075`, 0.005099018753068594}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[8.445265519754589, 0.009011228909084963], 
              Complex[6.797539667322055, -1.161966845801127]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004507396018711729, -0.005086712769401542}],
            
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[10.20508572371207, -0.016028997503587203`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004613684401276235, 0.005141448633075179}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[8.465439042444201, 0.009233798770935121], 
              Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004552633301081784, -0.005133972475539012}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[10.184544064614805`, -0.016281708942805753`], 
              Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004655948791480658, 0.005176939236701458}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[8.485279549606197, 0.009466654168547486], 
              Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0045913398122460255`, -0.00517447093882337}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[10.164353917920575`, -0.016543191071888914`], 
              Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004692341029160016, 0.005205989202617416}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[8.504844265661474, 0.009710692858210806], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004623979608588758, -0.005208718804493308}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[10.144456159495563`, -0.016814496662831836`], 
              Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004723246428828065, 0.005228993696435956}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004650919632490628, -0.0052371260917586995`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[10.124798576239256`, -0.017096756417673668`], 
              Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0047489729733584726`, 0.005246263298924662}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[8.543343682297635, 0.01023643767719948], 
              Complex[6.891907468896068, -1.161220171125207]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004672447301868918, -0.005260021218522327}],
            
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[10.105334252708913`, -0.017391201699304026`], 
              Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004769764471407013, 0.005258037649238629}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[8.562365618323055, 0.010520523036427927`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004688783194111519, -0.005277664912132273}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[10.086020309962356`, -0.017699189379580486`], 
              Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004785810210203662, 0.005264495262837773}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[8.581288431797727, 0.010820596844492403`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004700090146082259, -0.00529026042709487}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[10.06681689057666, -0.018022230071644385`], 
              Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004797252000336214, 0.0052657604565175655`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[8.600148900521386, 0.011138282794836918`], 
              Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004706479636947383, -0.005297961015531958}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[10.047686315383556`, -0.018362021154624195`], 
              Complex[8.319026572634915, -1.199065136952576]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0048041892144373415`, 0.00526190799061428}],
            
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[8.618982457304563, 0.011475439606775252`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004708016019038223, -0.005300875285828494}],
            
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[10.02859235757786, -0.018720486277070698`], 
              Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004806682222149171, 0.005252965814582593}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[8.637823823216573, 0.011834207760463409`], 
              Complex[6.982345361327388, -1.160172170534845]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004704718951911059, -0.005299070874855116}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[10.009499592627153`, -0.019099823463292497`], 
              Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0048047544827309226`, 0.005238916136301563}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[8.656707602013043, 0.012217067867222313`], 
              Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004696564238332095, -0.005292576710797897}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[9.990372790233621, -0.01950256459218661], 
              Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004798393451334791, 0.005219694901154448}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[8.675668864524779, 0.012626914319474911`], 
              Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.00468348313321763, -0.0052813840329225615`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[9.971176318841339, -0.019931649951741043`], 
              Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004787550370214203, 0.005195189644821374}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[8.694743750598732, 0.013067149229433986`], 
              Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004665360079275102, -0.005265446245670743}],
            
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[9.951873534557844, -0.020390522922278387`], 
              Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004772138941139674, 0.005165235557212002}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[8.713970117564823, 0.013541803645186434`], 
              Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004642028700274019, -0.005244677605968366}],
            
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[9.932426125107996, -0.020883251810279745`], 
              Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004752032801370888, 0.005129609446607657}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[8.733388268345113, 0.014055695951277626`], 
              Complex[7.073421269042284, -1.158603006979818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0046132657375456704`, -0.005218950665363601}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[9.912793375391814, -0.02141468876524509], 
              Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004727061644523866, 0.005088021100826067}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[8.753041799848587, 0.014614641743299649`], 
              Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004578782425760901, -0.005188092304037024}],
            
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[9.892931313762208, -0.021990680088691875`], 
              Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004697005730758501, 0.005040101274207624}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[8.77297862441228, 0.015225736181981687`], 
              Complex[7.111050585905176, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0045382125387040855`, -0.005151878092525797}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[9.872791686074075, -0.02261834895605743], 
              Complex[8.151078988162066, -1.201907179567137]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0046615884072475, 0.004985385135372671}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[8.793252235841303, 0.01589774035976148], 
              Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004491095944865312, -0.005110024587863936}],
            
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[9.852320685804424, -0.02330648209651281], 
              Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004620466096355234, 0.00492328940782692}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[8.813923320576674, 0.016641620135819556`], 
              Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0044368559133605, -0.0050621789992264365`}],
            
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[9.831457339597339, -0.02406606889621767], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0045732149884876215`, 0.004853080479426095}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[8.835061859626233, 0.017471313877762306`], 
              Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0043747674592194115`, -0.005007905425537439}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[9.81013140250469, -0.02491106937082747], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004519313380835743, 0.00477382918774899}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.01840485331132207], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.004303912454320107, -0.00494666655263129}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479562], 
              Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004458118222494171, 0.004684345319890161}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629635, 0.019466046203823823`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004223114570262543, -0.004877799285458545}],
            
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.02693529265819088], 
              Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004388833996360742, 0.004583080144981418}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549184, 0.020687085496539234`], 
              Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.004130842411013646, -0.0048004823072308805`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095146, -0.028170551750257837`], 
              Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004310471793326468, 0.004467976571680447}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442703, 0.02211275107353916], 
              Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004025060482420289, -0.004713693187028441}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631186`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.004221797100537448, 0.004336229555932163}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.023807487220115792`], 
              Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.003902990695409533, -0.0046161531447571034`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427967, -0.0313184212541546], 
              Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.00412126923294345, 0.004183884416}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308572, 0.025867986584037196`], 
              Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.003760712135865431, -0.004506261634936061}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.033392197154710215`], 
              Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0040069936245641135`, 0.0040051236410148456`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768346, 0.028447097632704935`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.003592449697797522, -0.004382040446265369}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.035984297293206895`], 
              Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.003876779650802851, 0.0037909095603275603`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964627, 0.031803157852373865`], 
              Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0033892185816186003`, -0.004241176749810794}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187373335`], 
              Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0037286912536028723`, 0.003526179665223781}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.069506749440478, 0.03641303093548226], 
              Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0031360193382297965`, -0.004081544851982944}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670554, -0.04397539380088848], 
              Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0035638498567594464`, 0.0031835351834102513`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645232], 
              Complex[7.426654831776879, -1.133628019546016]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0028055135393229734`, -0.0039039471826070988`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000955, -0.05084228149321134], 
              Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0034007457028791825`, 0.0027089550876112246`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732223], 
              Complex[7.466802670715167, -1.123122290976753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0023436555752566865`, -0.003726283462266374}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.494267216357189, -0.062354593032578], 
              Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0033494143400245, 0.002015362915706276}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.07734359441247762], 
              Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0016627857507839497`, -0.00365749856807173}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414624, -0.08494182361234351], 
              Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.003702657230143189, 0.0012402254251815017`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647748, 0.11902724764149018`], 
              Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0008978840357791428, -0.003989925381101714}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055139, -0.12663696940988678`], 
              Complex[7.704988630788347, -1.296125883577755]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.004295002905461409, 0.0008000170701272545}],
            
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784464, 0.16611165996512323`], 
              Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0004638454490729914, -0.0045610916078202965`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650824, -0.17373265713467972`], 
              Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0048186080768821814`, 0.0005925265977318188}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.20695392178184982`], 
              Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00026025289602246596`, -0.005064928343978455}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240906, -0.21458598503237647`], 
              Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.005254795140149619, 0.0004785288764247043}],
            
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.280570529089989, 0.24191392575349288`], 
              Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{0.0001490958191176632, -0.005482609946952902}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.2495568531847539], 
              Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.005627983410424765, 0.00040682046436308966`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.285085225476458, 0.27256109297706776`], 
              Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.00007965532516493326, -0.005838241280215948}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.2802146897125705], 
              Complex[7.660008665723722, -1.440191789692609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.005956352693221304, 0.0003573925035381723}],
            
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835058], 
              Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.000032139806870076326`, -0.006149775657157451}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.35409955758327, -0.30766500790255313`], 
              Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.006251636632955965, 0.00032110125123850663`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790588, 0.32496389242763857`], 
              Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-2.4816835232778327`*^-6, -0.0064287918775102265`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581292, -0.33263826942312025`], 
              Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.006521563110034608, 0.000293210953416289}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.34794816918876], 
              Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000028879448730619224`, -0.006682909047490768}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.349405787878045, -0.35563266944840766`], 
              Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.006771428962799051, 0.0002710273418641435}],
            
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285957, 0.36930769700429716`], 
              Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00004970651918964923, -0.006917344856398592}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.37700215031345224`], 
              Complex[7.649655116243796, -1.530899113668034]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.00700500654140454, 0.00025290394260318324`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.3893033507690842], 
              Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0000665817141442456, -0.007135812193831508}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579115, -0.3970075923331433], 
              Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.007225073214233594, 0.000237776796386688}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 1, {
              Complex[9.296845766278874, 0.4081334915298239], 
              Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00008054952282515949, -0.007341042529493793}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 2, {
              Complex[9.344983328511988, -0.41584736171471265`], 
              Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.0074337322372323815`, 0.0002249269626450505}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 1, {
              Complex[9.297817893725249, 0.42595292805234636`], 
              Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00009231463486347838, -0.007535102871599487}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 2, {
              Complex[9.343894570793292, -0.4336762721416326], 
              Complex[7.645371333222616, -1.583906400971115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007632614875202597, 0.00021385059436489757`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 1, {
              Complex[9.298664434058157, 0.44288515307919907`], 
              Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001023701301735289, -0.007719595302556026}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 2, {
              Complex[9.342933217974057, -0.45061782104638065`], 
              Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.007823012361803135, 0.00020418372109817155`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 1, {
              Complex[9.299409090344204, 0.45903052180506093`], 
              Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00011107162700461023`, -0.007895787174045737}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 2, {
              Complex[9.342075512640728, -0.4667723681000823], 
              Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008005964842443864, 0.00019565660754998862`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 1, {
              Complex[9.300069789499112, 0.47447188989313444`], 
              Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00011868223610144967`, -0.008064698810620165}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 2, {
              Complex[9.341303475971888, -0.4822227732417421], 
              Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.0081823230292103, 0.00018806493892265658`}],
            
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00012540091729985444`, -0.008227164272522881}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 2, {
              Complex[9.340603220742913, -0.497038390042908], 
              Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008352792008196532, 0.00018125100339960143`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 1, {
              Complex[9.301191700128847, 0.503509412285517], 
              Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001313809821980438, -0.008383874506682586}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 2, {
              Complex[9.339963828630122, -0.5112779620899647], 
              Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008517963051172705, 0.00017509103900329793`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 1, {
              Complex[9.301672454837956, 0.5172145811965813], 
              Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00013674252506491337`, -0.0085354086661256}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 2, {
              Complex[9.339376581853779, -0.5249917680556035], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.008678337166645109, 0.0001694865059558964}],
            
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 1, {
              Complex[9.302109645838716, 0.5304375419992581], 
              Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00014158098993650152`, -0.008682257285507174}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 2, {
              Complex[9.338834424339028, -0.5382232399630629], 
              Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008834342837764877, 0.00016435793031156857`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 1, {
              Complex[9.302509011886752, 0.5432161176861714], 
              Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001459732086172647, -0.008824839728169458}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 2, {
              Complex[9.338331575639637, -0.5510102042411122], 
              Complex[7.638493829265324, -1.693304925020469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.008986349589207193, 0.00015964047425010838`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 1, {
              Complex[9.302875299750397, 0.5555834916479572], 
              Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001499817415238597, -0.008963517524681346}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 2, {
              Complex[9.337863249005673, -0.5633858475760003], 
              Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.00913467850854585, 0.00015528069178925293`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 1, {
              Complex[9.303212473521276, 0.5675689693259758], 
              Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00015365805417452504`, -0.009098604712754556}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009279610508577311, 0.00015123411459557617`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 1, {
              Complex[9.303523872448524, 0.5791985860418385], 
              Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00015704487889522725`, -0.009230375953770084}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 2, {
              Complex[9.337014778473906, -0.5870171355873209], 
              Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009421392889812183, 0.00014746342952227335`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 1, {
              Complex[9.303812331602318, 0.5904955973399487], 
              Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00016017799611955518`, -0.009359072976951278}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 2, {
              Complex[9.336628388028364, -0.5983220770848241], 
              Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009560244607150173, 0.00014393708480221951`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 1, {
              Complex[9.304080275277004, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00016308759552549385`, -0.009484909749142921}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 2, {
              Complex[9.336263812328982, -0.609315181113391], 
              Complex[7.635641241458829, -1.747457014478097]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009696360536894684, 0.00014062821134628784`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 1, {
              Complex[9.304329790117846, 0.612173252747982], 
              Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.000165799328525165, -0.009608076661812324}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 2, {
              Complex[9.335918932011362, -0.6200152737048319], 
              Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.009829914964109092, 0.00013751377879229443`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 1, {
              Complex[9.30456268297077, 0.6225897638061416], 
              Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001683351309756262, -0.009728743951826374}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 2, {
              Complex[9.335591908744412, -0.6304394010704698], 
              Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.009961064455756317, 0.0001345739285968753}],
            
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 1, {
              Complex[9.304780527085194, 0.6327459028649576], 
              Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00017071387271691598`, -0.009847064518800526}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 2, {
              Complex[9.33528113896544, -0.6406030569368892], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.010089950245446165`, 0.00013179144216396}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 1, {
              Complex[9.304984699340448, 0.6426557999628848], 
              Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.000172951875120496, -0.009963176262791017}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 2, {
              Complex[9.334985216595475, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.010216700226487673`, 0.0001291513130436398}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 1, {
              Complex[9.305176410484561, 0.6523323858111223], 
              Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00017506332698509635`, -0.010077204037420637`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 2, {
              Complex[9.334702902745928, -0.6602042845457757], 
              Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.01034143062828276, 0.00012664040011683788`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 1, {
              Complex[9.30535672988259, 0.6617875296457956], 
              Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00017706062138713943`, -0.01018926129220422}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 2, {
              Complex[9.334433100918964, -0.6696666607954201], 
              Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.010464247434814519`, 0.0001242471443634718}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 1, {
              Complex[9.305526605913883, 0.6710321572939462], 
              Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001789546305132338, -0.010299451461815901`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 2, {
              Complex[9.334174836562127, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010585247591620835`, 0.00012196133597251606`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 1, {
              Complex[9.305686882893223, 0.6800763528244194], 
              Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001807549314284846, -0.010407869147877138`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 2, {
              Complex[9.333927240101854, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010704520038172839`, 0.00011977392161766796`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 1, {
              Complex[9.305838315194185, 0.6889294464957751], 
              Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00018246999272462168`, -0.010514601129528227`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 2, {
              Complex[9.333689532777536, -0.6968297409230606], 
              Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.010822146595253658`, 0.0001176768440149816}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 1, {
              Complex[9.305981579104797, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00018410732975103852`, -0.010619727231845006`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 2, {
              Complex[9.333461014745714, -0.705507268773781], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.010938202731228041`, 0.00011566290760360449`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 1, {
              Complex[9.30611728283302, 0.7060963291837463], 
              Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00018567363444164724`, -0.010723321075553812`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 2, {
              Complex[9.33324105503674, -0.7140103074539126], 
              Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011052758226612388`, 0.00011372566549967863`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 1, {
              Complex[9.306245974993525, 0.7144256505494249], 
              Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00018717488446792842`, -0.01082545072709355}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 2, {
              Complex[9.333029083032358, -0.7223463488774439], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011165877752810341`, 0.00011185932388142636`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 1, {
              Complex[9.306368151840394, 0.722595044698084], 
              Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001886164354668252, -0.010926179264591817`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 2, {
              Complex[9.332824581199281, -0.73052238420331], 
              Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011277621378057212`, 0.00011005866073539707`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 1, {
              Complex[9.30648426345883, 0.730611045774511], 
              Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019000309933304182`, -0.011025565272549586`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 2, {
              Complex[9.332627078865713, -0.7385449492756353], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011388045011354767`, 0.00010831895650163334`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 1, {
              Complex[9.30659471908804, 0.7384797729243899], 
              Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019133921097595153`, -0.011123663275807869`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 2, {
              Complex[9.332436146868352, -0.7464201648848554], 
              Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011497200793354414`, 0.00010663593462405104`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 1, {
              Complex[9.306699891715693, 0.7462069660795199], 
              Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019262868547922506`, -0.011220524121579374`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011605137441666911`, 0.00010500571038975745`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 1, {
              Complex[9.306800122058599, 0.7537980178639988], 
              Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001938750672375919, -0.011316195316876117`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 2, {
              Complex[9.332072457649627, -0.7617511664534365], 
              Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011711900556873213`, 0.00010342474673362612`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 1, {
              Complex[9.306895722024107, 0.7612580021246124], 
              Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019508157235576676`, -0.011410721327481306`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 2, {
              Complex[9.33189901102014, -0.7692174219206883], 
              Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011817532894520309`, 0.00010188981592306963`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 1, {
              Complex[9.306986977730267, 0.7685916995129599], 
              Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019625112536514924`, -0.011504143843643413`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 2, {
              Complex[9.331730749379409, -0.7765573210571958], 
              Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.011922074607573782`, 0.00010039796622609922`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 1, {
              Complex[9.30707415214959, 0.7758036204842984], 
              Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0001973863911272026, -0.011596502016872968`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 2, {
              Complex[9.331567392745953, -0.7837753757227326], 
              Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012025563463124717`, 0.00009894649282045308}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 1, {
              Complex[9.307157487430532, 0.7828980260257034], 
              Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019848980264567848`, -0.011687832671560885`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 2, {
              Complex[9.331408682475267, -0.7908758482666055], 
              Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012128035036588932`, 0.00009753291232481732}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 1, {
              Complex[9.307237206941968, 0.7898789463823147], 
              Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00019956358538649092`, -0.011778170494589773`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 2, {
              Complex[9.331254379194702, -0.7978627702556061], 
              Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012229522886169507`, 0.00009615494043447526}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 1, {
              Complex[9.307313517078901, 0.7967501980135657], 
              Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020060977860735654`, -0.011867548205650136`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 2, {
              Complex[9.331104260978192, -0.8047399594318435], 
              Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012330058709961697`, 0.00009481047222765709}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 1, {
              Complex[9.307386608861503, 0.8035153989801238], 
              Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002016302541168561, -0.011955996710591167`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 2, {
              Complex[9.330958121728596, -0.811511035101225], 
              Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.012429672487750123`, 0.0000934975647758773}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 1, {
              Complex[9.307456659354887, 0.8101779829358526], 
              Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020262673281838027`, -0.012043545239811323`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012528392609269986`, 0.00009221442174934741}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 1, {
              Complex[9.307523832932748, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020360079933743643`, -0.012130221473423058`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 2, {
              Complex[9.330677026418373, -0.824748413679325], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.012626245990468386`, 0.0000909593797533704}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 1, {
              Complex[9.307588282404819, 0.8232081877787825], 
              Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020455391498662768`, -0.012216051654693636`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 2, {
              Complex[9.330541725135806, -0.8312210828762443], 
              Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012723258179100312`, 0.00008973089617357653}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 1, {
              Complex[9.30765015002498, 0.8295818632429439], 
              Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020548742928447387`, -0.012301060693068636`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.012819453450825384`, 0.00008852753833642164}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 1, {
              Complex[9.30770956839477, 0.8358650512460974], 
              Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020640259021402978`, -0.012385272257916668`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 2, {
              Complex[9.33028083598227, -0.8438891593891124], 
              Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.012914854896821197`, 0.0000873479738235511}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020730055337644989`, -0.012468708863990801`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 2, {
              Complex[9.330154965998151, -0.8500900641121139], 
              Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013009484503807506`, 0.00008619096179641934}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 1, {
              Complex[9.307821544314418, 0.8481705716325364], 
              Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002081823901785615, -0.012551391949478885`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 2, {
              Complex[9.330031972258514, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013103363227263612`, 0.00008505534521182228}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 1, {
              Complex[9.307874325710909, 0.8541979088518956], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020904909516980508`, -0.012633341947409588`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 2, {
              Complex[9.329911734551446, -0.8622384184423436], 
              Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013196511058531696`, 0.00008394004382154318}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 1, {
              Complex[9.30792510680319, 0.860144782839487], 
              Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00020990159263002418`, -0.012714578351088784`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 2, {
              Complex[9.32979413984504, -0.8681906520799052], 
              Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013288947086413587`, 0.00008284404786611135}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 1, {
              Complex[9.307973982610356, 0.8660134292433511], 
              Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021074074249587967`, -0.01279511977416248}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.990999855207028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013380689553802528`, 0.00008176641238283571}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 1, {
              Complex[9.308021042319387, 0.8718059882315835], 
              Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021156734570166455`, -0.012874984005833506`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 2, {
              Complex[9.329566459959892, -0.8798624212060276], 
              Complex[7.624115410024538, -1.996281512181469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01347175590982739, 0.00008070625205979544}],
            
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 1, {
              Complex[9.308066369728037, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021238214900124212`, -0.01295418806169937}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 2, {
              Complex[9.32945617991971, -0.8855861488792872], 
              Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013562162857934998`, 0.00007966273657436537}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 1, {
              Complex[9.308110043647693, 0.8831709599557607], 
              Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021318584932848348`, -0.013032748230626785`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 2, {
              Complex[9.329348152291017, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013651926400289097`, 0.00007863508636488742}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021397909774706315`, -0.013110680118032613`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 2, {
              Complex[9.329242292636387, -0.8968191263829126], 
              Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01374106187882388, 0.00007762256878834437}],
            
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 1, {
              Complex[9.308192723503184, 0.8942551097650254], 
              Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021476250303383986`, -0.013187998685901356`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 2, {
              Complex[9.329138521063246, -0.9023320727684233], 
              Complex[7.623188002862294, -2.016726496581311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01382958401325411, 0.00007662449462353725}],
            
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 1, {
              Complex[9.30823186527481, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021553663493465393`, -0.013264718289833742`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 2, {
              Complex[9.329036761909217, -0.9077783332310709], 
              Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.013917506936312262`, 0.00007564021488379671}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 1, {
              Complex[9.308269625814717, 0.9050726361762732], 
              Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021630202712706267`, -0.013340852713390897`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 2, {
              Complex[9.328936943453858, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014004844226455124`, 0.00007466911790845404}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 1, {
              Complex[9.308306063909846, 0.9103855526005625], 
              Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021705917992025854`, -0.013416415199970614`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 2, {
              Complex[9.328838997654197, -0.9184774165528234], 
              Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.014091608938258376`, 0.0000737106267032149}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 1, {
              Complex[9.308341235139771, 0.9156366518516708], 
              Complex[7.621537327849359, -0.321751242072515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021780856271871895`, -0.013491418482428573`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01417781363069467, 0.00007276419650680114}],
            
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 1, {
              Complex[9.308375192092747, 0.9208274215121248], 
              Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021855061627295967`, -0.013565874810636421`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 2, {
              Complex[9.328648468799225, -0.9289289945966074], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014263470393473095`, 0.00007182931256032366}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 1, {
              Complex[9.30840798456442, 0.9259592943584085], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00021928575473959417`, -0.013639795977148893`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 2, {
              Complex[9.32855576595434, -0.9340656567439881], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014348590871598812`, 0.00007090548806008083}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 1, {
              Complex[9.308439659740836, 0.931033651089264], 
              Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022001436756784507`, -0.013713193341136238`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 2, {
              Complex[9.328464695790345, -0.9391447601963729], 
              Complex[7.621658530284444, -2.050135996258459]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0144331862882983, 0.00006999226227723978}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 1, {
              Complex[9.30847026236711, 0.9360518228828761], 
              Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022073682123017, -0.013786077850723054`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 2, {
              Complex[9.328375205370595, -0.9441676368090878], 
              Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014517267466440442`, 0.00006908919882701764}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 1, {
              Complex[9.308499834903161, 0.9410150937958542], 
              Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[
            PointBox[{-0.00022145346081148428`, -0.01385846006386044}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 2, {
              Complex[9.32828724423658, -0.9491355712999281], 
              Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014600844848572526`, 0.00006819588407559468}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 1, {
              Complex[9.308528417667576, 0.9459247030157971], 
              Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[
            PointBox[{-0.00022216461146995953`, -0.013930350167849215`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 2, {
              Complex[9.328200764258014, -0.9540498035022821], 
              Complex[7.621034500886904, -2.063631600211478]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014683928515678903`, 0.00006731192567050862}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 1, {
              Complex[9.308556048970686, 0.9507818469782096], 
              Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022287057978193694`, -0.014001757997616257`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 2, {
              Complex[9.328115719493917, -0.9589115304824558], 
              Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014766528204760305`, 0.00006643695118405067}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 1, {
              Complex[9.308582765237823, 0.9555876813576076], 
              Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022357165498058105`, -0.014072693052843253`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 2, {
              Complex[9.328032066063827, -0.9637219085312987], 
              Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014848653325323438`, 0.00006557060686020849}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 1, {
              Complex[9.30860860112351, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022426811009861806`, -0.014143164514032148`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 2, {
              Complex[9.327949762028192, -0.9684820550389235], 
              Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.014930312974861878`, 0.00006471255645459158}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 1, {
              Complex[9.308633589617479, 0.9650498513977598], 
              Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022496020302394137`, -0.014213181257587729`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015011515953403064`, 0.00006386248016098917}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 1, {
              Complex[9.30865776214308, 0.9697083109361536], 
              Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022564817747413137`, -0.014282751869990907`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 2, {
              Complex[9.327789043427426, -0.9778559389833152], 
              Complex[7.620030720208938, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015092270777189215`, 0.00006302007361587205}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 1, {
              Complex[9.30868114864878, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002263322638988258, -0.014351884661126964`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015172585691554292`, 0.00006218504697478035}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 1, {
              Complex[9.308703777693312, 0.9788850321593942], 
              Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022701268031510103`, -0.014420587676831128`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 2, {
              Complex[9.32763326295845, -0.9870414080668136], 
              Complex[7.619640805534105, -2.093436192381357]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015252468683054235`, 0.00006135712405477477}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 1, {
              Complex[9.308725676524938, 0.9834052186894814], 
              Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022768963308176517`, -0.01448886871070637}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015331927490902786`, 0.00006053604153665349}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 1, {
              Complex[9.308746871155384, 0.9878811887189863], 
              Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022836331761758917`, -0.014556735315264394`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 2, {
              Complex[9.327482144581792, -0.9960461687506829], 
              Complex[7.619257020505317, -2.10155454761218]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015410969617760777`, 0.000059721548223492725`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 1, {
              Complex[9.308767386428746, 0.9923138310722672], 
              Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00022903391906817634`, -0.014624194812436962`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 2, {
              Complex[9.32740825352173, -1.000483060574067], 
              Complex[7.6190673329092, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015489602339923119`, 0.00005891340434949168}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 1, {
              Complex[9.30878724608588, 0.9967040073387546], 
              Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002297016129257769, -0.014691254303500498`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 2, {
              Complex[9.327335434354206, -1.0048774519249142`], 
              Complex[7.618879068115525, -2.109509448113651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015567832716944369`, 0.000058111380936153044`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002303665656058989, -0.014757920678452774`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 2, {
              Complex[9.327263658416845, -1.009230178775591], 
              Complex[7.618692192411457, -2.113427630566214]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015645667600739925`, 0.00005731525919138037}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023102893498346759`, -0.014824200624880868`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015723113644197834`, 0.00005652482994878426}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 1, {
              Complex[9.308843113455703, 1.0096279702007276`], 
              Complex[7.622275519945756, -0.236216870343528]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023168887089283806`, -0.014890100636349672`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 2, {
              Complex[9.327123127092824, -1.0178138586055234`], 
              Complex[7.618322479547946, -2.12114930362412]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015800177309332652`, 0.00005573989314366674}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 1, {
              Complex[9.308860568016621, 1.0138563914775585`], 
              Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023234651559441544`, -0.014955627020346416`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 2, {
              Complex[9.327054319725956, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015876864875011307`, 0.00005496025732301223}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 1, {
              Complex[9.308877471091341, 1.0180462834838366`], 
              Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023300200420780685`, -0.015020785905807039`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 2, {
              Complex[9.326986451526654, -1.0262403046082496`], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.015953182444277635`, 0.000054185739186920106`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 1, {
              Complex[9.308893840937472, 1.0221983660944407`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023365546511940394`, -0.015085583250252329`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 2, {
              Complex[9.326919498869884, -1.030396405990655], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016029135951301454`, 0.00005341616315920222}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 1, {
              Complex[9.3089096950579, 1.0263133387136967`], 
              Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023430702036069344`, -0.015150024846557822`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.016104731167975, 0.000052651360984913464`}],
            
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 1, {
              Complex[9.30892505023899, 1.0303918810590929`], 
              Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002349567859632158, -0.015214116329380547`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 2, {
              Complex[9.326788249964949, -1.0385978654970531`], 
              Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01617997371017867, 0.00005189117135305039}],
            
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 1, {
              Complex[9.30893992258648, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023560487229033682`, -0.015277863181263406`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 2, {
              Complex[9.326723910626667, -1.042644564958483], 
              Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016254869043736225`, 0.00005113543954217456}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 1, {
              Complex[9.308954327559254, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023625138434750623`, -0.015341270738437237`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 2, {
              Complex[9.32666040057538, -1.0466561075785734`], 
              Complex[7.617067825366967, -2.147044806353595]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016329422490077877`, 0.00005038401708791467}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023689642207399463`, -0.015404344196338246`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 2, {
              Complex[9.326597700119693, -1.0506331187508058`], 
              Complex[7.616893231354067, -2.150609297664497]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016403639231628995`, 0.00004963676147009754}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 1, {
              Complex[9.30898179417064, 1.04635469380724], 
              Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002375400806149187, -0.01546708861485823}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 2, {
              Complex[9.326535790249194, -1.0545762069524702`], 
              Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016477524316940242`, 0.00004889353581918338}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 1, {
              Complex[9.308994883769515, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002381824505778465, -0.015529508923342957`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 2, {
              Complex[9.326474652603713, -1.058485964360329], 
              Complex[7.616547285902738, -2.157643104664951]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016551082665574434`, 0.00004815420863912564}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023882361827262796`, -0.01559160992535348}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 2, {
              Complex[9.326414269444339, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01662431907276402, 0.00004741865354733193}],
            
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 1, {
              Complex[9.309019841434887, 1.0579749207033116`], 
              Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00023946366593714037`, -0.015653396303204177`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 2, {
              Complex[9.326354623625987, -1.0662077774973113`], 
              Complex[7.616205519626703, -2.164553676487631]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016697238213852255`, 0.00004668674902897788}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 1, {
              Complex[9.309031734351517, 1.0617843589087967`], 
              Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024010267194941962`, -0.015714872622290165`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 2, {
              Complex[9.326295698571451, -1.0700209412330057`], 
              Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016769844648530454`, 0.000045958378205743486`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 1, {
              Complex[9.309043252443763, 1.0655627106244419`], 
              Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024074071102676516`, -0.015776043335215453`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01684214282488246, 0.00004523342861762492}],
            
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 1, {
              Complex[9.309054406998325, 1.069310494475782], 
              Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024137785441371895`, -0.015836912785734812`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 2, {
              Complex[9.326179947138467, -1.077554446480185], 
              Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.016914137083247037`, 0.00004451179201697648}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 1, {
              Complex[9.309065208883657, 1.0730282159476647`], 
              Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024201417005809063`, -0.015897485212516115`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 2, {
              Complex[9.326123090230514, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01698583165990847, 0.00004379336417389815}],
            
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 1, {
              Complex[9.30907566856886, 1.076716367831864], 
              Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002426497227778895, -0.01595776475273777}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 2, {
              Complex[9.32606689298445, -1.0849675833073058`], 
              Complex[7.61536833755189, -2.181317982768311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01705723069062407, 0.00004307804469251957}],
            
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 1, {
              Complex[9.309085796141549, 1.0803754306555196`], 
              Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024328457441744847`, -0.0160177554455252}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 2, {
              Complex[9.32601134131908, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.017128338213998097`, 0.0000423657368372065}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 1, {
              Complex[9.309095601324776, 1.0840058730914168`], 
              Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024391878399569094`, -0.016077461235239055`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 2, {
              Complex[9.325956421591757, -1.0922642484964793`], 
              Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017199158174709454`, 0.000041656347368356006`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 1, {
              Complex[9.309105093493066, 1.0876081523510002`], 
              Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024455240784502065`, -0.01613688597462047}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 2, {
              Complex[9.325902120580537, -1.0958700696995949`], 
              Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01726969442660158, 0.00004094978638658794}],
            
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 1, {
              Complex[9.309114281687616, 1.0911827145610287`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024518549974334185`, -0.016196033427802275`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 2, {
              Complex[9.325848425467212, -1.0994481489240884`], 
              Complex[7.614715122272777, -2.194233932689377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017339950735641162`, 0.00004024596718561487}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 1, {
              Complex[9.309123174630706, 1.0947299951246658`], 
              Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002458181110377548, -0.016254907273192253`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 2, {
              Complex[9.3257953238212, -1.1029989218798244`], 
              Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017409930782752835`, 0.00003954480611280814}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 1, {
              Complex[9.309131780739362, 1.098250419067798], 
              Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002464502907621296, -0.016313511106235933`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 2, {
              Complex[9.325742803584212, -1.1065228138938557`], 
              Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017479638166535895`, 0.00003884622243670962}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002470820857489026, -0.016371848442063495`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 2, {
              Complex[9.325690853055608, -1.1100202402427715`], 
              Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017549076405869207`, 0.000038150138221827266`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 1, {
              Complex[9.309148164672497, 1.1052123472899034`], 
              Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002477135407315571, -0.01642992271803001}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 2, {
              Complex[9.325639460878643, -1.1134916064718128`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01761824894240992, 0.00003745647820940698}],
            
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 1, {
              Complex[9.309155957918382, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00024834469844646376`, -0.01648773729614929}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 2, {
              Complex[9.325588616027105, -1.1169373087010908`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017687159142991064`, 0.00003676516970477312}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 1, {
              Complex[9.309163495195484, 1.112071704185835], 
              Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002489755997251473, -0.01654529546543144}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 2, {
              Complex[9.325538307792803, -1.1203577339198192`], 
              Complex[7.613760450846203, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017755810301923296`, 0.00003607614246992977}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002496062835837902, -0.016602600444126116`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 2, {
              Complex[9.325488525773522, -1.1237532602689644`], 
              Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01782420564320517, 0.00003538932862159465}],
            
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 1, {
              Complex[9.309177829898688, 1.118831548607897], 
              Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002502367873071807, -0.016659655381877022`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 2, {
              Complex[9.325439259861593, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017892348322646773`, 0.000034704662534424545`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002508671465284996, -0.01671646336179168}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 2, {
              Complex[9.325390500232961, -1.1304710863006695`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.017960241429910245`, 0.000034022080748887544`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 1, {
              Complex[9.309191222585227, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025149739530513644`, -0.016773027402430623`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 2, {
              Complex[9.32534223733676, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0180278879904719, 0.000033341521883751524`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 1, {
              Complex[9.309197581524451, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002521275661902365, -0.016829350459719887`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 2, {
              Complex[9.325294461885356, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01809529096750898, 0.000032662926552520926`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 1, {
              Complex[9.309203723570544, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025275769030077286`, -0.01688543542879032}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 2, {
              Complex[9.325247164844853, -1.1403700578948632`], 
              Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018162453263714927`, 0.000031986237284152086`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 1, {
              Complex[9.309209654512566, 1.1353146500669253`], 
              Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025338779738223787`, -0.016941285145747147`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018229377723046503`, 0.000031311398447474856`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 1, {
              Complex[9.309215379954184, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025401791586957163`, -0.01699690238937329}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 2, {
              Complex[9.325153971075487, -1.1468548029005257`], 
              Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.01829606713240549, 0.0000306383561789232}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 1, {
              Complex[9.309220905320853, 1.1417483803738433`], 
              Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0002546480729465241, -0.0170522898827679}],
            
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018362524223258552`, 0.000029967058314129333`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002552782945988679, -0.017107450294927808`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 2, {
              Complex[9.325062588496635, -1.1532508941175512`], 
              Complex[7.612229226993084, -2.242030438093204]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01842875167319747, 0.00002929745432225942}],
            
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 1, {
              Complex[9.30923137668085, 1.1480947778478905`], 
              Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025590860566962557`, -0.0171623862422657}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 2, {
              Complex[9.325017556268538, -1.1564164644600665`], 
              Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0184947521074429, 0.000028629495243546825`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 1, {
              Complex[9.309236332694079, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025653902990674913`, -0.017217100290078943`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 2, {
              Complex[9.324972953094393, -1.159560782288886], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01856052810029372, 0.000027963133629568694`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 1, {
              Complex[9.309241108684372, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002571695900122198, -0.017271594953960787`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 2, {
              Complex[9.32492877148305, -1.1626841380761932`], 
              Complex[7.611783032412532, -2.250378188362658]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018626082176524714`, 0.000027298323486504766`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025780030768680765`, -0.01732587270116422}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 2, {
              Complex[9.324885004134527, -1.165786816282607], 
              Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018691416812734712`, 0.000026635020220630622`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 1, {
              Complex[9.309250138979012, 1.1605350642903134`], 
              Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00025843120367276013`, -0.017379935951915747`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 2, {
              Complex[9.324841643933642, -1.168869095524045], 
              Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01875653443864725, 0.000025973180586269967`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 1, {
              Complex[9.309254402126275, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002590622977957592, -0.01743378708068438}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 2, {
              Complex[9.324798683943808, -1.1719312487328415`], 
              Complex[7.611342435457713, -2.258551532233558]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.018821437438365986`, 0.0000253127626364209}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 1, {
              Complex[9.309258502946614, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002596936090024782, -0.01748742841740503}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 2, {
              Complex[9.324756117401245, -1.1749735433132202`], 
              Complex[7.611196771510045, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.018886128151586558`, 0.000024653725675004092`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 1, {
              Complex[9.30926244553551, 1.1696531548443287`], 
              Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002603251554003108, -0.01754086224866086}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 2, {
              Complex[9.324713937709186, -1.1779962412914933`], 
              Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01895060887476696, 0.000023996030211576315`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 1, {
              Complex[9.309266233866467, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026095695428940717`, -0.017594090818824296`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 2, {
              Complex[9.324672138432646, -1.180999599461105], 
              Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01901488186225806, 0.000023339637918059164`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 1, {
              Complex[9.309269871795374, 1.1756348399245429`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026158902219964566`, -0.01764711633115923}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 2, {
              Complex[9.32463071329305, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019078949327395817`, 0.00002268451158676312}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 1, {
              Complex[9.309273363064712, 1.178597324542335], 
              Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026222137492096356`, -0.017699940948886998`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 2, {
              Complex[9.324589656163337, -1.186949298219872], 
              Complex[7.610619897990326, -2.271804947320259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019142813443557043`, 0.00002203061509093374}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 1, {
              Complex[9.309276711307533, 1.1815412277835524`], 
              Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026285402753512335`, -0.017752566796214966`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 2, {
              Complex[9.324548961063108, -1.18989612746948], 
              Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01920647634517996, 0.000021377913346629283`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 1, {
              Complex[9.309279920051315, 1.18446678667431], 
              Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026348699444436367`, -0.017804995959332607`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 2, {
              Complex[9.324508622154049, -1.1928245944888063`], 
              Complex[7.61033481839468, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019269940128751148`, 0.000020726372275973203`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 1, {
              Complex[9.30928299272165, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002641202893997914, -0.017857230487373865`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.61019309106805, -2.2795461787176903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019333206853759992`, 0.000020075958772468533`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 1, {
              Complex[9.309285932645754, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002647539255280855, -0.017909272393347893`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019396278543622376`, 0.000019426640667120426`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 1, {
              Complex[9.309288743055875, 1.193135699594645], 
              Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026538791535697274`, -0.017961123655040132`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 2, {
              Complex[9.32438968622985, -1.201502126383065], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.01945915718657439, 0.00001877838669672416}],
            
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 1, {
              Complex[9.309291427092525, 1.195990161608288], 
              Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002660222708395175, -0.01801278621588399}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 2, {
              Complex[9.324350716392056, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019521844736537383`, 0.000018131166472528264`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 1, {
              Complex[9.309293987807608, 1.1988273980957402`], 
              Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002666570033777608, -0.01806426198580466}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 2, {
              Complex[9.324312075535536, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.01958434311395578, 0.000017484950451134836`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 1, {
              Complex[9.309296428167405, 1.201647620337122], 
              Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026729212384443593`, -0.01811555284203624}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 2, {
              Complex[9.324273758587013, -1.2100225117840062`], 
              Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019646654206608084`, 0.000016839709905589035`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 1, {
              Complex[9.309298751055461, 1.204451035693495], 
              Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002679276426049, -0.018166660629913012`}],
            
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 2, {
              Complex[9.324235760587555, -1.2128287152203814`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019708779870392833`, 0.000016195416898738618`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026856356953703915`, -0.01821758716363601}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 2, {
              Complex[9.324198076689216, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019770721930089885`, 0.000015552044256378662`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 1, {
              Complex[9.309303055553212, 1.2100082561816605`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026919991405083645`, -0.01826833422701575}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 2, {
              Complex[9.324160702151756, -1.2183914626776438`], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019832482180098403`, 0.00001490956554256297}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 1, {
              Complex[9.309305042540569, 1.212762457302003], 
              Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00026983668510718986`, -0.018318903574192056`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0198940623851519, 0.000014267955035530311`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 1, {
              Complex[9.30930692281649, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002704738912354774, -0.018369296930331798`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 2, {
              Complex[9.324086862718293, -1.2238893126698196`], 
              Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.019955464281011904`, 0.000013627187704034668`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027111154055066243`, -0.018419515992305527`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 2, {
              Complex[9.32405038885261, -1.2266143809612582`], 
              Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02001668957514039, 0.000012987239185416844`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 1, {
              Complex[9.309310373202791, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027174964076991207`, -0.01846956242934358}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 2, {
              Complex[9.324014206402694, -1.2293237938391435`], 
              Complex[7.608531912472354, -2.309057802254565]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.0200777399473522, 0.000012348085763945637`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027238819922785983`, -0.018519437883672593`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 2, {
              Complex[9.323978311121861, -1.232017733951227], 
              Complex[7.608396583634034, -2.311418828492422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020138617050447817`, 0.000011709704350421854`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 1, {
              Complex[9.30931342598549, 1.2262969751610369`], 
              Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002730272228917491, -0.01856914397113282}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020199322510827684`, 0.000011072072462046736`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 1, {
              Complex[9.309314809018922, 1.2289578590746733`], 
              Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0002736667183760311, -0.0186186822817774}],
            
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 2, {
              Complex[9.323907365530383, -1.2373599104403945`], 
              Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.020259857929088198`, 0.000010435168203286749`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 1, {
              Complex[9.309316099422276, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002743066919550955, -0.01866805438045547}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 2, {
              Complex[9.323872307168552, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020320224880600538`, 9.798970247962104*^-6}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 1, {
              Complex[9.309317299329457, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000274947149578287, -0.018717261807373473`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 2, {
              Complex[9.323837519868585, -1.242642308546154], 
              Complex[7.607859712684855, -2.320721705723063]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02038042491607252, 9.163457821074191*^-6}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 1, {
              Complex[9.30931841081857, 1.2368516153040952`], 
              Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002755880968807756, -0.018766306078646672`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 2, {
              Complex[9.323802999811543, -1.2452615144292978`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020440459562094376`, 8.528610681788638*^-6}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 1, {
              Complex[9.309319435913645, 1.2394537927373108`], 
              Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027622953919641637`, -0.01881518868683086}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 2, {
              Complex[9.3237687432571, -1.2478662783795624`], 
              Complex[7.607593869964685, -2.32529066727406]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02050033032166896, 7.894409107305657*^-6}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 1, {
              Complex[9.309320376586301, 1.2420417043271583`], 
              Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002768714815694982, -0.018863911101439004`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 2, {
              Complex[9.323734746541412, -1.2504567620199438`], 
              Complex[7.607461579018771, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020560038674726652`, 7.260833876711702*^-6}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 1, {
              Complex[9.309321234757373, 1.2446155088257416`], 
              Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002775139287656077, -0.018912474769444486`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 2, {
              Complex[9.323701006075066, -1.253033124240515], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020619586078626084`, 6.627866255984147*^-6}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 1, {
              Complex[9.30932201229845, 1.247175362316046], 
              Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00027815688528235935`, -0.01896088111576936}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 2, {
              Complex[9.323667518341093, -1.255595521260306], 
              Complex[7.607198233627162, -2.332044490630609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02067897396864051, 5.995487983232954*^-6}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 1, {
              Complex[9.309322711033374, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0002788003553596273, -0.0190091315437593}],
            
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02073820375843085, 5.36368125418481*^-6}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 1, {
              Complex[9.309323332739702, 1.2522538276170265`], 
              Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002794443429896521, -0.019057227435644974`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 2, {
              Complex[9.323601287353112, -1.2606790315775551`], 
              Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02079727684050525, 4.732428709541617*^-6}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 1, {
              Complex[9.309323879150051, 1.254772738780499], 
              Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028008885192614964`, -0.01910517015299093}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020856194586666835`, 4.101713420142019*^-6}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 1, {
              Complex[9.309324351953519, 1.2572782977532362`], 
              Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028073388569359016`, -0.01915296103713214}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 2, {
              Complex[9.323536026818966, -1.2657084915461236`], 
              Complex[7.606676358179671, -2.340869773551443]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02091495834844789, 3.471518875832964*^-6}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 1, {
              Complex[9.309324752796902, 1.2597706481409692`], 
              Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002813794475956799, -0.019200601409598356`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 2, {
              Complex[9.323503752396531, -1.2682033164767677`], 
              Complex[7.60654686627181, -2.343044919018725]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.020973569457533675`, 2.841828973172093*^-6}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 1, {
              Complex[9.309325083285957, 1.26224993121657], 
              Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000282025540724283, -0.019248092572527412`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 2, {
              Complex[9.323471711022448, -1.2706850606806674`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02103202922617408, 2.212628001257492*^-6}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 1, {
              Complex[9.309325344986703, 1.2647162859707826`], 
              Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-0.0002826721679665156, -0.0192954358090667}],
            
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 2, {
              Complex[9.323439899636348, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02109033894758391, 1.5839006334005154`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 1, {
              Complex[9.30932553942646, 1.2671698491615646`], 
              Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002833193320132972, -0.01934263238376464}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 2, {
              Complex[9.323408315236543, -1.2756098611309419`], 
              Complex[7.60616066644672, -2.349497677693727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.021148499896333245`, 9.556319143826994*^-7}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 1, {
              Complex[9.309325668095038, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028396703536688063`, -0.01938968354295141}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021206513328726972`, 3.2780725000409355`*^-7}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 1, {
              Complex[9.309325732445826, 1.2720391370076072`], 
              Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028461528034679504`, -0.01943659051510913}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 2, {
              Complex[9.323345815673619, -1.2804839792850278`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021264380483174552`, -2.9958760293941606`*^-7}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028526406909807755`, -0.019483354511233213`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02132210258054997, -9.26566546884694*^-7}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002859134035969968, -0.01952997672518363}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 2, {
              Complex[9.323284189438796, -1.2853084672867803`], 
              Complex[7.605650891587858, -2.357936536444798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021379680824542377`, -1.5531431528375596`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002865632856579177, -0.01957645833402711}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 2, {
              Complex[9.323253696898021, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021437116401997663`, -2.1793306699870706`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 1, {
              Complex[9.30932537452151, 1.2816299944237615`], 
              Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028721371693897756`, -0.01962280049837084}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 2, {
              Complex[9.32322341448604, -1.2900843444730699`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02149441048325134, -2.8051420344502076`*^-6}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028786469894815216`, -0.019669004362687155`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 2, {
              Complex[9.323193339572983, -1.292454363919178], 
              Complex[7.605272293102371, -2.364146338317678]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021551564222452718`, -3.430589877936273*^-6}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 1, {
              Complex[9.309324844933629, 1.286353569409846], 
              Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000288516233048826, -0.019715071055630275`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 2, {
              Complex[9.323163469577016, -1.2948125987358026`], 
              Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.02160857875788102, -4.055686536096787*^-6}],
            
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00028916832046542066`, -0.019761001690344875`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 2, {
              Complex[9.323133801963191, -1.2971591677080403`], 
              Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021665455212253493`, -4.680444057293582*^-6}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 1, {
              Complex[9.309324094995942, 1.291030527780833], 
              Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002898209622883669, -0.019806797364766766`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 2, {
              Complex[9.323104334242323, -1.2994941878134678`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021722194693025745`, -5.304874209336857*^-6}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 1, {
              Complex[9.309323640371, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002904741594789466, -0.01985245916191642}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 2, {
              Complex[9.32307506396992, -1.3018177742589656`], 
              Complex[7.604772284075739, -2.372272881425941]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021778798292684497`, -5.928988488356853*^-6}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 1, {
              Complex[9.309323134173042, 1.2956617974980962`], 
              Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00029112791287488643`, -0.019897988150184513`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 2, {
              Complex[9.323045988745086, -1.3041300405165683`], 
              Complex[7.604648113785146, -2.374277896400649]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.02183526708903361, -6.552798124727309*^-6}],
            
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 1, {
              Complex[9.309322577516868, 1.2979605814829327`], 
              Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002917822231940889, -0.01994338538361132}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 2, {
              Complex[9.323017106209543, -1.3064310983584502`], 
              Complex[7.604524269574324, -2.376272476082065]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021891602145471433`, -7.176314091710947*^-6}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 1, {
              Complex[9.309321971491423, 1.300248278779899], 
              Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00029243709103991133`, -0.019988651902158025`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 2, {
              Complex[9.322988414046595, -1.3087210578909694`], 
              Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.021947804511264508`, -7.799547111177517*^-6}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 1, {
              Complex[9.30932131716045, 1.3025249977626072`], 
              Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002930925169047916, -0.020033788731972705`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 2, {
              Complex[9.322959909980197, -1.3110000275879254`], 
              Complex[7.604277546409373, -2.380230742900865]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022003875221810843`, -8.422507660863783*^-6}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 1, {
              Complex[9.309320615563188, 1.3047908452057129`], 
              Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00029374850117483756`, -0.02007879688564883}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 2, {
              Complex[9.322931591773996, -1.3132681143229277`], 
              Complex[7.604154661093239, -2.382194632873833]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{0.02205981529889941, -9.045205980824273*^-6}],
            
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 1, {
              Complex[9.309319867715043, 1.3070459263165168`], 
              Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002944050441337251, -0.02012367736247789}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 2, {
              Complex[9.32290345723042, -1.315525423400987], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022115625750962393`, -9.667652079376151*^-6}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 1, {
              Complex[9.309319074608208, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002950621459666367, -0.020168431148695945`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 2, {
              Complex[9.322875504189794, -1.3177720585893213`], 
              Complex[7.60390982746478, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02217130757332165, -0.00001028985573950551}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 1, {
              Complex[9.309318237212295, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002957198067636001, -0.02021305921772423}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 2, {
              Complex[9.322847730529492, -1.3200081221474065`], 
              Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{0.02222686174842914, -0.00001091182652459474}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 1, {
              Complex[9.309317356474933, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00029637802652399207`, -0.020257562530403922`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 2, {
              Complex[9.322820134163065, -1.322233714856279], 
              Complex[7.603666223034595, -2.389950867251501]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022282289246101723`, -0.000011533573784233225`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 1, {
              Complex[9.309316433322348, 1.3159606384280351`], 
              Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002970368051583252, -0.020301942035225694`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.391865572493939]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022337591023750398`, -0.000012155106659477193`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 1, {
              Complex[9.309315468659923, 1.3181634132423605`], 
              Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002976961424936582, -0.020346198668553247`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022392768026604375`, -0.000012776434088745732`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 1, {
              Complex[9.30931446337276, 1.3203560217257788`], 
              Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002983560382751778, -0.020390333354842347`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 2, {
              Complex[9.322738388488887, -1.3288486541172835`], 
              Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022447821187929193`, -0.000013397564811961599`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 1, {
              Complex[9.30931341832617, 1.3225385589351384`], 
              Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.0002990164921698189, -0.020434347006854}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 2, {
              Complex[9.322711481129714, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022502751429241203`, -0.000014018507377143824`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.04531544750647416]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.0002996775037695167, -0.020478240525863507`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 2, {
              Complex[9.322684741147594, -1.3332080430544797`], 
              Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.022557559660515356`, -0.000014639270144133393`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 1, {
              Complex[9.309311212320324, 1.3268737930790047`], 
              Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.00030033907259346043`, -0.020522014801863747`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 2, {
              Complex[9.322658166657003, -1.3353728477954119`], 
              Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{0.02261224678038956, -0.000015259861289383442`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 1, {
              Complex[9.309310052997454, 1.3290266735224268`], 
              Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.000301001198092089, -0.020565670713764514`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 2, {
              Complex[9.322631755803343, -1.3375278480756927`], 
              Complex[7.602822954346447, -2.40315628519697]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"Re(\\!\\(\\*SqrtBox[\\(\\*SuperscriptBox[\\(\[ImaginaryI]\\), \\(2\
\\)]\\\\ \\*SubsuperscriptBox[\\(\[PartialD]\\), \\({t, tt}\\), \\(2\\)]S\\)]\
\\))\"", TraditionalForm], 
        FormBox[
        "\"Im(\\!\\(\\*SqrtBox[\\(\\*SuperscriptBox[\\(\[ImaginaryI]\\), \\(2\
\\)]\\\\ \\*SubsuperscriptBox[\\(\[PartialD]\\), \\({t, tt}\\), \\(2\\)]S\\)]\
\\))\"", TraditionalForm]},
      ImageSize->{{900}, {900}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.6509955342952014`, -0.8383554163654666}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.632189772884385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8383554163654666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5874585404782884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210239963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 1, {
              Complex[3.632189772884385, -0.8383554163654666], 
              Complex[1.5874585404782884`, -2.3355245210239963`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.4905971192945886, -0.8383554163654704}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4905971192945886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8383554163654704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5874585404782842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3355245210240003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 2, {
              Complex[0.4905971192945886, -0.8383554163654704], 
              Complex[1.5874585404782842`, -2.3355245210240003`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{4.55095068109639, -0.01205573978218699}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.834135988275976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01205573978218699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.094218012734007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 3, {
              Complex[10.834135988275976`, -0.01205573978218699], 
              Complex[9.094218012734007, -1.1949707911251923`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.692543334686185, -0.012055739782186827`}],
            RowBox[{"{", 
              
              RowBox[{"15.999999999999998`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.692543334686185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.012055739782186827`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.09421801273401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1949707911251923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "Discard", 4, {
              Complex[7.692543334686185, -0.012055739782186827`], 
              Complex[9.09421801273401, -1.1949707911251923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.6765630209487825`, -0.8682153108705755}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6066222862308037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8682153108705755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5611274843968312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291787`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 1, {
              Complex[3.6066222862308037`, -0.8682153108705755], 
              Complex[1.5611274843968312`, -2.3644087056291787`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.46502963264100744`, -0.868215310870579}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.46502963264100744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.868215310870579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5611274843968284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3644087056291823`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 2, {
              Complex[0.46502963264100744`, -0.868215310870579], 
              Complex[1.5611274843968284`, -2.3644087056291823`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{4.593250164802303, -0.011949285676122938`}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.876435471981889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011949285676122938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.136933552574833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 3, {
              Complex[10.876435471981889`, -0.011949285676122938`], 
              Complex[9.136933552574833, -1.1947860159220576`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.734842818392103, -0.01194928567613202}],
            RowBox[{"{", 
              
              RowBox[{"16.099999999999998`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.734842818392103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01194928567613202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.13693355257484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1947860159220667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "Discard", 4, {
              Complex[7.734842818392103, -0.01194928567613202], 
              Complex[9.13693355257484, -1.1947860159220667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.6963935909384897`, -0.8925142454403441}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5867917162410965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5405103103336057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.387780403540836`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "Discard", 1, {
              Complex[3.5867917162410965`, -0.8925142454403441], 
              Complex[1.5405103103336057`, -2.387780403540836]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.4451990626513003, -0.8925142454403411}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4451990626513003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8925142454403411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.540510310333603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3877804035408325`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "Discard", 2, {
              Complex[0.4451990626513003, -0.8925142454403411], 
              Complex[1.540510310333603, -2.3877804035408325`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{4.627550714176735, -0.011873440576436094`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.910736021356321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011873440576436094`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.171648224187221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1946325841924512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "Discard", 3, {
              Complex[10.910736021356321`, -0.011873440576436094`], 
              Complex[9.171648224187221, -1.1946325841924512`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.769143367766525, -0.011873440576434954`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"Discard\"", ",", "4", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.769143367766525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011873440576434954`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.17164822418722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.19463258419245`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "Discard", 4, {
              Complex[7.769143367766525, -0.011873440576434954`], 
              Complex[9.17164822418722, -1.19463258419245]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.7128760907895475`, -0.9135287061735095}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5703092163900387`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5232245875485029`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.407908376507515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 1, {
              Complex[3.5703092163900387`, -0.9135287061735095], 
              Complex[1.5232245875485029`, -2.407908376507515]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.4287165628002437, -0.9135287061735121}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4287165628002437`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9135287061735121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.523224587548502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4079083765075175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 2, {
              Complex[0.4287165628002437, -0.9135287061735121], 
              Complex[1.523224587548502, -2.4079083765075175`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{4.6572028361547435`, -0.011815298319208752`}],
            
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.94038814333433`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011815298319208752`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 3, {
              Complex[10.94038814333433, -0.011815298319208752`], 
              Complex[9.20171331881034, -1.194497402564137]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.798795489744536, -0.01181529831920876}],
            RowBox[{"{", 
              
              RowBox[{"16.299999999999997`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.798795489744536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01181529831920876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"9.20171331881034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.194497402564137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "Discard", 4, {
              Complex[7.798795489744536, -0.01181529831920876], 
              Complex[9.20171331881034, -1.194497402564137]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.727098838249182, -0.9322995873452297}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5560864689304044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.5081859946803688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4258284901011873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "Discard", 1, {
              Complex[3.5560864689304044`, -0.9322995873452297], 
              Complex[1.5081859946803688`, -2.4258284901011873`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.4144938153406103, -0.9322995873452282}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.4144938153406103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9322995873452282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.508185994680368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4258284901011864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "Discard", 2, {
              Complex[0.4144938153406103, -0.9322995873452282], 
              Complex[1.508185994680368, -2.4258284901011864`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{4.683728908124898, -0.011769056829642613`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.966914215304485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011769056829642613`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.228651705652085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "Discard", 3, {
              Complex[10.966914215304485`, -0.011769056829642613`], 
              Complex[9.228651705652085, -1.1943745527422884`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.8253215617147, -0.011769056829649287`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"Discard\"", ",", "4", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8253215617147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011769056829649287`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.228651705652094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1943745527422953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "Discard", 4, {
              Complex[7.8253215617147, -0.011769056829649287`], 
              Complex[9.228651705652094, -1.1943745527422953`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.7396666792044524`, -0.9494075862605201}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.543518627975134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4947924622029343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 1, {
              Complex[3.543518627975134, -0.9494075862605201], 
              Complex[1.4947924622029343`, -2.4421177901257014`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.40192597438534255`, -0.9494075862605198}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.40192597438534255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9494075862605198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.494792462202936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4421177901257014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 2, {
              Complex[0.40192597438534255`, -0.9494075862605198], 
              Complex[1.494792462202936, -2.4421177901257014`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           
           TooltipBox[PointBox[{4.7079731054991125`, -0.011731532239331113`}],
            
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "3", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.991158412678699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.011731532239331113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.253307907545267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 3, {
              Complex[10.991158412678699`, -0.011731532239331113`], 
              Complex[9.253307907545267, -1.1942607697912035`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{7.849565759088899, -0.011731532239340082`}],
            RowBox[{"{", 
              
              RowBox[{"16.499999999999996`", ",", "\"Discard\"", ",", "4", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.849565759088899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.011731532239340082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"9.25330790754526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1942607697912124`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "Discard", 4, {
              Complex[7.849565759088899, -0.011731532239340082`], 
              Complex[9.25330790754526, -1.1942607697912124`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.750956970512758, -0.9652164447599713}],
            RowBox[{"{", 
              
              RowBox[{"16.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.532228336666828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4826686902970212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.45713719067949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "Discard", 1, {
              Complex[3.532228336666828, -0.9652164447599713], 
              Complex[1.4826686902970212`, -2.45713719067949]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.39063568307703384`, -0.9652164447599751}],
            RowBox[{"{", 
              
              RowBox[{"16.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.39063568307703384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9652164447599751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4826686902970199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.457137190679493`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "Discard", 2, {
              Complex[0.39063568307703384`, -0.9652164447599751], 
              Complex[1.4826686902970199`, -2.457137190679493]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.761223879893272, -0.9799721862678735}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5219614272863144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9799721862678735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4715621017597873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.471130430093209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "Discard", 1, {
              Complex[3.5219614272863144`, -0.9799721862678735], 
              Complex[1.4715621017597873`, -2.471130430093209]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.38036877369652167`, -0.9799721862678751}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.38036877369652167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9799721862678751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4715621017597882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4711304300932104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "Discard", 2, {
              Complex[0.38036877369652167`, -0.9799721862678751], 
              Complex[1.4715621017597882`, -2.4711304300932104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.7706482326490165`, -0.9938506052393002}],
            RowBox[{"{", 
              
              RowBox[{"16.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5125370745305697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9938506052393002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4612931389803365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.484271399542434`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "Discard", 1, {
              Complex[3.5125370745305697`, -0.9938506052393002], 
              Complex[1.4612931389803365`, -2.484271399542434]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.37094442094077773`, -0.9938506052392997}],
            RowBox[{"{", 
              
              RowBox[{"16.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.37094442094077773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9938506052392997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4612931389803379`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4842713995424335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "Discard", 2, {
              Complex[0.37094442094077773`, -0.9938506052392997], 
              Complex[1.4612931389803379`, -2.4842713995424335`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.779364081512599, -1.006982614287426}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.503821225666987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.006982614287426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4517287827631657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296525`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "Discard", 1, {
              Complex[3.503821225666987, -1.006982614287426], 
              Complex[1.4517287827631657`, -2.4966893902296525`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.3622285720771921, -1.0069826142874234`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3622285720771921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0069826142874234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4517287827631644`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4966893902296494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "Discard", 2, {
              Complex[0.3622285720771921, -1.0069826142874234`], 
              Complex[1.4517287827631644`, -2.4966893902296494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.787474049232328, -1.0194689005855273`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4957112579472582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4427672678721806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5084836837647715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "Discard", 1, {
              Complex[3.4957112579472582`, -1.0194689005855273`], 
              Complex[1.4427672678721806`, -2.5084836837647715`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.3541186043574641, -1.0194689005855264`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3541186043574641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0194689005855264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.44276726787218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.508483683764771`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "Discard", 2, {
              Complex[0.3541186043574641, -1.0194689005855264`], 
              Complex[1.44276726787218, -2.508483683764771]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.795058749665937, -1.0313889380536854`}],
            RowBox[{"{", 
              
              RowBox[{"17.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4881265575136493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0313889380536854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4343287018663806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631915`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "Discard", 1, {
              Complex[3.4881265575136493`, -1.0313889380536854`], 
              Complex[1.4343287018663806`, -2.519732518631915]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.3465339039238557, -1.031388938053689}],
            RowBox[{"{", 
              
              RowBox[{"17.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3465339039238557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.031388938053689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4343287018663795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.519732518631919`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "Discard", 2, {
              Complex[0.3465339039238557, -1.031388938053689], 
              Complex[1.4343287018663795`, -2.519732518631919]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.802182862155966, -1.0428068062799816`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4810024450236203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0428068062799816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4263490191882389`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5304988762356877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "Discard", 1, {
              Complex[3.4810024450236203`, -1.0428068062799816`], 
              Complex[1.4263490191882389`, -2.5304988762356877`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.33940979143382616`, -1.0428068062799807`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.33940979143382616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0428068062799807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4263490191882378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.530498876235687`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "Discard", 2, {
              Complex[0.33940979143382616`, -1.0428068062799807`], 
              Complex[1.4263490191882378`, -2.530498876235687]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8088992069261813`, -1.0537751001493318`}],
            RowBox[{"{", 
              
              RowBox[{"17.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.474286100253405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4187759266798956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5408343661536392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "Discard", 1, {
              Complex[3.474286100253405, -1.0537751001493318`], 
              Complex[1.4187759266798956`, -2.5408343661536392`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.33269344666361156`, -1.0537751001493318`}],
            RowBox[{"{", 
              
              RowBox[{"17.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.33269344666361156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0537751001493318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.418775926679894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5408343661536397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "Discard", 2, {
              Complex[0.33269344666361156`, -1.0537751001493318`], 
              Complex[1.418775926679894, -2.5408343661536397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.815251571205943, -1.06433764500318}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4679337359736433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.06433764500318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4115660932135865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "Discard", 1, {
              Complex[3.4679337359736433`, -1.06433764500318], 
              Complex[1.4115660932135865`, -2.5507819227528166`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.32634108238384935`, -1.0643376450031767`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.32634108238384935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0643376450031767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4115660932135874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5507819227528135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "Discard", 2, {
              Complex[0.32634108238384935`, -1.0643376450031767`], 
              Complex[1.4115660932135874`, -2.5507819227528135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.821276724532485, -1.0745314357254354`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4619085826471014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.404683146512056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.560377729861402`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "Discard", 1, {
              Complex[3.4619085826471014`, -1.0745314357254354`], 
              Complex[1.404683146512056, -2.560377729861402]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.32031592905730694`, -1.0745314357254354`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.32031592905730694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0745314357254354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.4046831465120544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5603777298614023`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "Discard", 2, {
              Complex[0.32031592905730694`, -1.0745314357254354`], 
              Complex[1.4046831465120544`, -2.5603777298614023`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8270058906447626`, -1.0843880551501943`}],
            RowBox[{"{", 
              
              RowBox[{"17.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4561794165348236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501943`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.398096210752566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.5696526277620455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "Discard", 1, {
              Complex[3.4561794165348236`, -1.0843880551501943`], 
              Complex[1.398096210752566, -2.5696526277620455`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.3145867629450303, -1.0843880551501937`}],
            RowBox[{"{", 
              RowBox[{
               "17.599999999999998`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.3145867629450303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0843880551501937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3980962107525663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.569652627762044`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "Discard", 2, {
              Complex[0.3145867629450303, -1.0843880551501937`], 
              Complex[1.3980962107525663`, -2.569652627762044]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8324658450038487`, -1.0939347333651823`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4507194621757376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939347333651823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3917788166049063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "Discard", 1, {
              Complex[3.4507194621757376`, -1.0939347333651823`], 
              Complex[1.3917788166049063`, -2.5786331633102058`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.30912680858594205`, -1.0939347333651805`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.30912680858594205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939347333651805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3917788166049048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5786331633102035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "Discard", 2, {
              Complex[0.30912680858594205`, -1.0939347333651805`], 
              Complex[1.3917788166049048`, -2.5786331633102035`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.837679748135443, -1.1031951533323339`}],
            RowBox[{"{", 
              
              RowBox[{"17.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4455055590441432`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1031951533323339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3857080739861731`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "Discard", 1, {
              Complex[3.4455055590441432`, -1.1031951533323339`], 
              Complex[1.3857080739861731`, -2.587342388059074]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.30391290545435, -1.1031951533323334`}],
            RowBox[{"{", 
              
              RowBox[{"17.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.30391290545435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1031951533323334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.385708073986173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.587342388059074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "Discard", 2, {
              Complex[0.30391290545435, -1.1031951533323334`], 
              Complex[1.385708073986173, -2.587342388059074]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.842667788590103, -1.1121900734843542`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.440517518589483`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3798640340783366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "Discard", 1, {
              Complex[3.440517518589483, -1.1121900734843542`], 
              Complex[1.3798640340783366`, -2.5958004746630317`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.29892486499969306`, -1.1121900734843577`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.29892486499969306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1121900734843577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3798640340783381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5958004746630365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "Discard", 2, {
              Complex[0.29892486499969306`, -1.1121900734843577`], 
              Complex[1.3798640340783381`, -2.5958004746630365`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8474476861238798`, -1.120937815790952}],
            RowBox[{"{", 
              
              RowBox[{"17.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4357376210557065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.120937815790952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6040251997705024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "Discard", 1, {
              Complex[3.4357376210557065`, -1.120937815790952], 
              Complex[1.3742291902547281`, -2.6040251997705024`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2941449674659141, -1.1209378157909546`}],
            RowBox[{"{", 
              
              RowBox[{"17.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2941449674659141`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1209378157909546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3742291902547281`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.604025199770505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "Discard", 2, {
              Complex[0.2941449674659141, -1.1209378157909546`], 
              Complex[1.3742291902547281`, -2.604025199770505]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.852035090534372, -1.129454653282832}],
            RowBox[{"{", 
              
              RowBox[{"18.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4311502166452144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.129454653282832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3687880826648213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6120323271837886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "Discard", 1, {
              Complex[3.4311502166452144`, -1.129454653282832], 
              Complex[1.3687880826648213`, -2.6120323271837886`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2895575630554191, -1.1294546532828313`}],
            RowBox[{"{", 
              
              RowBox[{"18.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2895575630554191`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1294546532828313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3687880826648193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.612032327183787`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "Discard", 2, {
              Complex[0.2895575630554191, -1.1294546532828313`], 
              Complex[1.3687880826648193`, -2.612032327183787]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.856443901435662, -1.1377551213057147`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.426741405743924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377551213057147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3635269813327329`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "Discard", 1, {
              Complex[3.426741405743924, -1.1377551213057147`], 
              Complex[1.3635269813327329`, -2.6198359153990136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2851487521541328, -1.1377551213057142`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2851487521541328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1377551213057142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3635269813327346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6198359153990136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "Discard", 2, {
              Complex[0.2851487521541328, -1.1377551213057142`], 
              Complex[1.3635269813327346`, -2.6198359153990136`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8606865273189097`, -1.1458522701333511`}],
            RowBox[{"{", 
              
              RowBox[{"18.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4224987798606765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3584336295287167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6274485670330767`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "Discard", 1, {
              Complex[3.4224987798606765`, -1.1458522701333511`], 
              Complex[1.3584336295287167`, -2.6274485670330767`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2809061262708882, -1.1458522701333518`}],
            RowBox[{"{", 
              
              RowBox[{"18.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2809061262708882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1458522701333518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3584336295287214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.627448567033079`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "Discard", 2, {
              Complex[0.2809061262708882, -1.1458522701333518`], 
              Complex[1.3584336295287214`, -2.627448567033079]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.864774097416316, -1.1537578719399622`}],
            RowBox[{"{", 
              
              RowBox[{"18.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.41841120976327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1537578719399622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3534970339779715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.634881633043194`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "Discard", 1, {
              Complex[3.41841120976327, -1.1537578719399622`], 
              Complex[1.3534970339779715`, -2.634881633043194]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2768185561734762, -1.1537578719399602`}],
            RowBox[{"{", 
              
              RowBox[{"18.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2768185561734762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1537578719399602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3534970339779717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6348816330431903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "Discard", 2, {
              Complex[0.2768185561734762, -1.1537578719399602`], 
              Complex[1.3534970339779717`, -2.6348816330431903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.868716636466921, -1.1614825918531306`}],
            RowBox[{"{", 
              
              RowBox[{"18.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4144686707126652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.348707291872495`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "Discard", 1, {
              Complex[3.4144686707126652`, -1.1614825918531306`], 
              Complex[1.348707291872495, -2.6421453813855136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2728760171228721, -1.1614825918531306`}],
            RowBox[{"{", 
              
              RowBox[{"18.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2728760171228721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614825918531306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3487072918724958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6421453813855136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "Discard", 2, {
              Complex[0.2728760171228721, -1.1614825918531306`], 
              Complex[1.3487072918724958`, -2.6421453813855136`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.87252321002425, -1.1690361304484036`}],
            RowBox[{"{", 
              
              RowBox[{"18.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.410662097155336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1690361304484036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3440554470967183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6492491374148304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "Discard", 1, {
              Complex[3.410662097155336, -1.1690361304484036`], 
              Complex[1.3440554470967183`, -2.6492491374148304`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2690694435655443, -1.1690361304484052`}],
            RowBox[{"{", 
              
              RowBox[{"18.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2690694435655443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1690361304484052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3440554470967194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.649249137414832`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "Discard", 2, {
              Complex[0.2690694435655443, -1.1690361304484052`], 
              Complex[1.3440554470967194`, -2.649249137414832]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.876202046153266, -1.176427343324966}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4069832610263204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.176427343324966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3395333698600238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "Discard", 1, {
              Complex[3.4069832610263204`, -1.176427343324966], 
              Complex[1.3395333698600238`, -2.656201401617177]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.26539060743652637`, -1.1764273433249663`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.26539060743652637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1764273433249663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.339533369860022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.656201401617177`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "Discard", 2, {
              Complex[0.26539060743652637`, -1.1764273433249663`], 
              Complex[1.339533369860022, -2.656201401617177]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.879760638039886, -1.1836643421288453`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4034246691397003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1836643421288453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3351336552455113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.663009949003302`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "Discard", 1, {
              Complex[3.4034246691397003`, -1.1836643421288453`], 
              Complex[1.3351336552455113`, -2.663009949003302]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2618320155499074, -1.183664342128846}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2618320155499074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.183664342128846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3351336552455122`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6630099490033023`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "Discard", 2, {
              Complex[0.2618320155499074, -1.183664342128846], 
              Complex[1.3351336552455122`, -2.6630099490033023`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8832058310465865`, -1.1907545804380442`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.399979476133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "Discard", 1, {
              Complex[3.399979476133, -1.1907545804380442`], 
              Complex[1.330849537168034, -2.6696819135459715`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.258386822543207, -1.1907545804380446`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.258386822543207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1907545804380446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.330849537168034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6696819135459737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "Discard", 2, {
              Complex[0.258386822543207, -1.1907545804380446`], 
              Complex[1.330849537168034, -2.6696819135459737`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.886543896999773, -1.1977049272038105`}],
            RowBox[{"{", 
              
              RowBox[{"18.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.396641410179813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977049272038105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3266748149775132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.67622386032944`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "Discard", 1, {
              Complex[3.396641410179813, -1.1977049272038105`], 
              Complex[1.3266748149775132`, -2.67622386032944]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2550487565900203, -1.1977049272038123`}],
            RowBox[{"{", 
              
              RowBox[{"18.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2550487565900203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1977049272038123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3266748149775125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.676223860329442`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "Discard", 2, {
              Complex[0.2550487565900203, -1.1977049272038123`], 
              Complex[1.3266748149775125`, -2.676223860329442]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.889780597923466, -1.204521729892243}],
            RowBox[{"{", 
              
              RowBox[{"19.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3934047092561204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3226037905108854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "Discard", 1, {
              Complex[3.3934047092561204`, -1.204521729892243], 
              Complex[1.3226037905108854`, -2.682641847533846]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.25181205566632714`, -1.204521729892243}],
            RowBox[{"{", 
              
              RowBox[{"19.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.25181205566632714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.204521729892243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3226037905108852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.682641847533846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "Discard", 2, {
              Complex[0.25181205566632714`, -1.204521729892243], 
              Complex[1.3226037905108852`, -2.682641847533846]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8929212409938763`, -1.2112108690459429`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.39026406618571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3186312138329304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.688941479956369`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "Discard", 1, {
              Complex[3.39026406618571, -1.2112108690459429`], 
              Complex[1.3186312138329304`, -2.688941479956369]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.248671412595918, -1.2112108690459433`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.248671412595918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2112108690459433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.318631213832932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6889414799563705`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "Discard", 2, {
              Complex[0.248671412595918, -1.2112108690459433`], 
              Complex[1.318631213832932, -2.6889414799563705`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.895970726147296, -1.2177778056554156`}],
            RowBox[{"{", 
              
              RowBox[{"19.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3872145810322905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2177778056554156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3147522362459452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.69512795544381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "Discard", 1, {
              Complex[3.3872145810322905`, -1.2177778056554156`], 
              Complex[1.3147522362459452`, -2.69512795544381]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.24562192744249728`, -1.2177778056554163`}],
            RowBox[{"{", 
              
              RowBox[{"19.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.24562192744249728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2177778056554163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3147522362459447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6951279554438115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "Discard", 2, {
              Complex[0.24562192744249728`, -1.2177778056554163`], 
              Complex[1.3147522362459447`, -2.6951279554438115`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.8989335875054625`, -1.2242276224707729`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3842517196741237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2242276224707729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3109623694144825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.701206105354477`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "Discard", 1, {
              Complex[3.3842517196741237`, -1.2242276224707729`], 
              Complex[1.3109623694144825`, -2.701206105354477]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.24265906608433005`, -1.2242276224707753`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.24265906608433005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2242276224707753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3109623694144812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7012061053544794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "Discard", 2, {
              Complex[0.24265906608433005`, -1.2242276224707753`], 
              Complex[1.3109623694144812`, -2.7012061053544794`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9018140295707604`, -1.230565060179537}],
            RowBox[{"{", 
              
              RowBox[{"19.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.381371277608826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.230565060179537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.307257449661592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7071804299643993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "Discard", 1, {
              Complex[3.381371277608826, -1.230565060179537], 
              Complex[1.307257449661592, -2.7071804299643993`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.23977862401903308`, -1.2305650601795397`}],
            RowBox[{"{", 
              
              RowBox[{"19.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23977862401903308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2305650601795397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3072574496615919`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.707180429964402`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "Discard", 2, {
              Complex[0.23977862401903308`, -1.2305650601795397`], 
              Complex[1.3072574496615919`, -2.707180429964402]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.904615958974951, -1.2367945492132952`}],
            RowBox[{"{", 
              
              RowBox[{"19.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.378569348204635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.30363360666026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7130551295714294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "Discard", 1, {
              Complex[3.378569348204635, -1.2367945492132952`], 
              Complex[1.30363360666026, -2.7130551295714294`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.23697669461484225`, -1.2367945492132955`}],
            RowBox[{"{", 
              
              RowBox[{"19.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23697669461484225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2367945492132955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3036336066602605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.71305512957143`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "Discard", 2, {
              Complex[0.23697669461484225`, -1.2367945492132955`], 
              Complex[1.3036336066602605`, -2.71305512957143]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.90734301243011, -1.2429202378151198`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3758422947494764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.3000872358777424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7188341319212634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "Discard", 1, {
              Complex[3.3758422947494764`, -1.2429202378151198`], 
              Complex[1.3000872358777424`, -2.7188341319212634`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2342496411596838, -1.2429202378151196`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2342496411596838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2429202378151196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.300087235877743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.718834131921264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "Discard", 2, {
              Complex[0.2342496411596838, -1.2429202378151196`], 
              Complex[1.300087235877743, -2.718834131921264]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9099985814215246`, -1.2489460168942261`}],
            RowBox[{"{", 
              
              RowBox[{"19.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3731867257580617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2489460168942261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2966149742384296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7245211164750502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "Discard", 1, {
              Complex[3.3731867257580617`, -1.2489460168942261`], 
              Complex[1.2966149742384296`, -2.7245211164750502`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.23159407216826933`, -1.248946016894224}],
            RowBox[{"{", 
              
              RowBox[{"19.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.23159407216826933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.248946016894224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2966149742384314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.724521116475047`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "Discard", 2, {
              Complex[0.23159407216826933`, -1.248946016894224], 
              Complex[1.2966149742384314`, -2.724521116475047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.912585834093972, -1.254875542108594}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.370599473085614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.254875542108594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.293213678558499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.730119535953448`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "Discard", 1, {
              Complex[3.370599473085614, -1.254875542108594], 
              Complex[1.293213678558499, -2.730119535953448]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.22900681949582008`, -1.2548755421085922`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22900681949582008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2548755421085922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2932136785584984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7301195359534463`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "Discard", 2, {
              Complex[0.22900681949582008`, -1.2548755421085922`], 
              Complex[1.2932136785584984`, -2.7301195359534463`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.915107734710741, -1.2607122535464201`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.368077572468845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2898804063769864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7356326355228924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "Discard", 1, {
              Complex[3.368077572468845, -1.2607122535464201`], 
              Complex[1.2898804063769864`, -2.7356326355228924`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.22648491887905142`, -1.2607122535464206`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22648491887905142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2607122535464206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2898804063769855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.735632635522893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "Discard", 2, {
              Complex[0.22648491887905142`, -1.2607122535464206`], 
              Complex[1.2898804063769855`, -2.735632635522893]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9175670610056375`, -1.2664593933197807`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365618246173949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2866123988665321`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7410634699329792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "Discard", 1, {
              Complex[3.365618246173949, -1.2664593933197807`], 
              Complex[1.2866123988665321`, -2.7410634699329792`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.22402559258415555`, -1.2664593933197807`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22402559258415555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2664593933197807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2866123988665328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.741063469932979`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "Discard", 2, {
              Complex[0.22402559258415555`, -1.2664593933197807`], 
              Complex[1.2866123988665328`, -2.741063469932979]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.919966419699501, -1.2721200213365205`}],
            RowBox[{"{", 
              
              RowBox[{"20.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3632188874800852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2721200213365205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2834070655552816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7464149188671136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "Discard", 1, {
              Complex[3.3632188874800852`, -1.2721200213365205`], 
              Complex[1.2834070655552816`, -2.7464149188671136`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.22162623389028935`, -1.2721200213365198`}],
            RowBox[{"{", 
              
              RowBox[{"20.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.22162623389028935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2721200213365198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2834070655552792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.746414918867112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "Discard", 2, {
              Complex[0.22162623389028935`, -1.2721200213365198`], 
              Complex[1.2834070655552792`, -2.746414918867112]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9223082604123847`, -1.2776970294771413`}],
            RowBox[{"{", 
              
              RowBox[{"20.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3608770467672016`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2776970294771413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2802619706314171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7516897007297403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "Discard", 1, {
              Complex[3.3608770467672016`, -1.2776970294771413`], 
              Complex[1.2802619706314171`, -2.7516897007297403`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.21928439317740805`, -1.2776970294771406`}],
            RowBox[{"{", 
              
              RowBox[{"20.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21928439317740805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2776970294771406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2802619706314173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.75168970072974`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "Discard", 2, {
              Complex[0.21928439317740805`, -1.2776970294771406`], 
              Complex[1.2802619706314173`, -2.75168970072974]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9245948881688952`, -1.2831931543706478`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.358590419010691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2771748206351425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.756890385061134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "Discard", 1, {
              Complex[3.358590419010691, -1.2831931543706478`], 
              Complex[1.2771748206351425`, -2.756890385061134]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.21699776542089913`, -1.2831931543706483`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21699776542089913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2831931543706483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2771748206351434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7568903850611353`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "Discard", 2, {
              Complex[0.21699776542089913`, -1.2831931543706483`], 
              Complex[1.2771748206351434`, -2.7568903850611353`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9268284746662308`, -1.2886109889360127`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3563568325133555`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2886109889360127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.274143453370581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7620194037437003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "Discard", 1, {
              Complex[3.3563568325133555`, -1.2886109889360127`], 
              Complex[1.274143453370581, -2.7620194037437003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.21476417892356292`, -1.288610988936014}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21476417892356292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.288610988936014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2741434533705815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.762019403743701`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "Discard", 2, {
              Complex[0.21476417892356292`, -1.288610988936014], 
              Complex[1.2741434533705815`, -2.762019403743701]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9290110684507082`, -1.2939529928328564`}],
            RowBox[{"{", 
              
              RowBox[{"20.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.354174238728878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2939529928328564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2711658278935796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "Discard", 1, {
              Complex[3.354174238728878, -1.2939529928328564`], 
              Complex[1.2711658278935796`, -2.7670790611410547`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.21258158513908437`, -1.293952992832856}],
            RowBox[{"{", 
              
              RowBox[{"20.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21258158513908437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.293952992832856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2711658278935793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7670790611410534`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "Discard", 2, {
              Complex[0.21258158513908437`, -1.293952992832856], 
              Complex[1.2711658278935793`, -2.7670790611410534`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.931144604128828, -1.2992215019455444`}],
            RowBox[{"{", 
              
              RowBox[{"20.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.352040703050758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2682400154509323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919705`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "Discard", 1, {
              Complex[3.352040703050758, -1.2992215019455444`], 
              Complex[1.2682400154509323`, -2.7720715432919705`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.21044804946096587`, -1.2992215019455449`}],
            RowBox[{"{", 
              
              RowBox[{"20.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.21044804946096587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2992215019455449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2682400154509332`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7720715432919714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "Discard", 2, {
              Complex[0.21044804946096587`, -1.2992215019455449`], 
              Complex[1.2682400154509332`, -2.7720715432919714`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.933230910722037, -1.3044187370084819`}],
            RowBox[{"{", 
              
              RowBox[{"20.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3499543964575493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3044187370084819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2653641912632538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "Discard", 1, {
              Complex[3.3499543964575493`, -1.3044187370084819`], 
              Complex[1.2653641912632538`, -2.776998926265093]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.20836174286775633`, -1.304418737008481}],
            RowBox[{"{", 
              
              RowBox[{"20.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20836174286775633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.304418737008481`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2653641912632545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.776998926265093`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "Discard", 2, {
              Complex[0.20836174286775633`, -1.304418737008481], 
              Complex[1.2653641912632545`, -2.776998926265093]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.935271719260115, -1.3095468114663606`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.347913587919471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2625366270577851`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665047`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "Discard", 1, {
              Complex[3.347913587919471, -1.3095468114663606`], 
              Complex[1.2625366270577851`, -2.7818631837665047`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.20632093432967819`, -1.3095468114663624`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20632093432967819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3095468114663624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2625366270577847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7818631837665064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "Discard", 2, {
              Complex[0.20632093432967819`, -1.3095468114663624`], 
              Complex[1.2625366270577847`, -2.7818631837665064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.937268669695903, -1.314607738651282}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345916637483683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.314607738651282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2597556842695194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.786666194080565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "Discard", 1, {
              Complex[3.345916637483683, -1.314607738651282], 
              Complex[1.2597556842695194`, -2.786666194080565]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.20432398389389064`, -1.3146077386512802`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20432398389389064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3146077386512802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2597556842695206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7866661940805635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "Discard", 2, {
              Complex[0.20432398389389064`, -1.3146077386512802`], 
              Complex[1.2597556842695206`, -2.7866661940805635`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9392233172137123`, -1.31960343834836}],
            RowBox[{"{", 
              
              RowBox[{"21.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.343961989965874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.31960343834836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2570198078392791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "Discard", 1, {
              Complex[3.343961989965874, -1.31960343834836], 
              Complex[1.2570198078392791`, -2.7914097464142906`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.2023693363760805, -1.3196034383483597`}],
            RowBox[{"{", 
              
              RowBox[{"21.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.2023693363760805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3196034383483597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.257019807839279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.7914097464142906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "Discard", 2, {
              Complex[0.2023693363760805, -1.3196034383483597`], 
              Complex[1.257019807839279, -2.7914097464142906`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.941137137994842, -1.3245357428128088`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.342048169184744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2543275205461564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "Discard", 1, {
              Complex[3.342048169184744, -1.3245357428128088`], 
              Complex[1.2543275205461564`, -2.796095546707045]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.20045551559495106`, -1.3245357428128093`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.20045551559495106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3245357428128093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2543275205461566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.796095546707046`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "Discard", 2, {
              Complex[0.20045551559495106`, -1.3245357428128093`], 
              Complex[1.2543275205461566`, -2.796095546707046]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.94301153449591, -1.3294064022937957`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.340173772683676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3294064022937957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2516774178194212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597475`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "Discard", 1, {
              Complex[3.340173772683676, -1.3294064022937957`], 
              Complex[1.2516774178194212`, -2.8007252229597475`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1985811190938835, -1.329406402293795}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1985811190938835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.329406402293795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2516774178194228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8007252229597466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "Discard", 2, {
              Complex[0.1985811190938835, -1.329406402293795], 
              Complex[1.2516774178194228`, -2.8007252229597466`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9448478402891314`, -1.3342170901139807`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.338337466890455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2490681629814273`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "Discard", 1, {
              Complex[3.338337466890455, -1.3342170901139807`], 
              Complex[1.2490681629814273`, -2.805300330131515]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.19674481330066165`, -1.3342170901139803`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19674481330066165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3342170901139803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2490681629814275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.805300330131515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "Discard", 2, {
              Complex[0.19674481330066165`, -1.3342170901139803`], 
              Complex[1.2490681629814275`, -2.805300330131515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9466473245079094`, -1.33896940734793}],
            RowBox[{"{", 
              
              RowBox[{"21.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.336537982671677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.33896940734793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.246498482878781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.809822354646045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "Discard", 1, {
              Complex[3.336537982671677, -1.33896940734793], 
              Complex[1.246498482878781, -2.809822354646045]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.19494532908188417`, -1.3389694073479312`}],
            RowBox[{"{", 
              
              RowBox[{"21.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19494532908188417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3389694073479312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2464984828787806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.809822354646047`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "Discard", 2, {
              Complex[0.19494532908188417`, -1.3389694073479312`], 
              Complex[1.2464984828787806`, -2.809822354646047]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.948411195936134, -1.343664887137726}],
            RowBox[{"{", 
              
              RowBox[{"21.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.334774111243452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.343664887137726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2439671638639436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "Discard", 1, {
              Complex[3.334774111243452, -1.343664887137726], 
              Complex[1.2439671638639436`, -2.814292718545235]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.19318145765365854`, -1.3436648871377261`}],
            RowBox[{"{", 
              
              RowBox[{"21.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19318145765365854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3436648871377261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.243967163863943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.814292718545235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "Discard", 2, {
              Complex[0.19318145765365854`, -1.3436648871377261`], 
              Complex[1.243967163863943, -2.814292718545235]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9501406067752742`, -1.348304998679792}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.333044700404312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2414730480936764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323322`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "Discard", 1, {
              Complex[3.333044700404312, -1.348304998679792], 
              Complex[1.2414730480936764`, -2.818712783323322]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.19145204681451947`, -1.348304998679793}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.19145204681451947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.348304998679793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2414730480936766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.818712783323323`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "Discard", 2, {
              Complex[0.19145204681451947`, -1.348304998679793], 
              Complex[1.2414730480936766`, -2.818712783323323]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9518366561195424`, -1.3528911509132835`}],
            RowBox[{"{", 
              
              RowBox[{"21.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.331348651060044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3528911509132835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "Discard", 1, {
              Complex[3.331348651060044, -1.3528911509132835`], 
              Complex[1.2390150301144984`, -2.8230838534712275`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18975599747025035`, -1.352891150913283}],
            RowBox[{"{", 
              
              RowBox[{"21.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18975599747025035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.352891150913283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2390150301144984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8230838534712266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "Discard", 2, {
              Complex[0.18975599747025035`, -1.352891150913283], 
              Complex[1.2390150301144984`, -2.8230838534712266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9535003931661405`, -1.3574246959370493`}],
            RowBox[{"{", 
              
              RowBox[{"21.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3296849140134457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3574246959370493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2365920537085775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8274071797574867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "Discard", 1, {
              Complex[3.3296849140134457`, -1.3574246959370493`], 
              Complex[1.2365920537085775`, -2.8274071797574867`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18809226042365237`, -1.3574246959370482`}],
            RowBox[{"{", 
              
              RowBox[{"21.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18809226042365237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3574246959370482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2365920537085782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.827407179757486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "Discard", 2, {
              Complex[0.18809226042365237`, -1.3574246959370482`], 
              Complex[1.2365920537085782`, -2.827407179757486]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9551328201846823`, -1.36190693217938}],
            RowBox[{"{", 
              
              RowBox[{"21.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.328052486994904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.36190693217938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.234203108976306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.831683962269427`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "Discard", 1, {
              Complex[3.328052486994904, -1.36190693217938], 
              Complex[1.234203108976306, -2.831683962269427]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1864598334051111, -1.3619069321793806`}],
            RowBox[{"{", 
              
              RowBox[{"21.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1864598334051111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3619069321793806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2342031089763061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8316839622694276`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "Discard", 2, {
              Complex[0.1864598334051111, -1.3619069321793806`], 
              Complex[1.2342031089763061`, -2.8316839622694276`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9567348952673482`, -1.3663391073422075`}],
            RowBox[{"{", 
              
              RowBox[{"22.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.326450411912238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "Discard", 1, {
              Complex[3.326450411912238, -1.3663391073422075`], 
              Complex[1.2318472296343572`, -2.8359153532357357`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18485775832244397`, -1.3663391073422058`}],
            RowBox[{"{", 
              
              RowBox[{"22.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18485775832244397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3663391073422058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2318472296343572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8359153532357344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "Discard", 2, {
              Complex[0.18485775832244397`, -1.3663391073422058`], 
              Complex[1.2318472296343572`, -2.8359153532357344`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.958307534879101, -1.3707224211391649`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.324877772300485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2295234905102046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "Discard", 1, {
              Complex[3.324877772300485, -1.3707224211391649`], 
              Complex[1.2295234905102046`, -2.8401024596493727`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18328511871069184`, -1.3707224211391664`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18328511871069184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3707224211391664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2295234905102042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8401024596493754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "Discard", 2, {
              Complex[0.18328511871069184`, -1.3707224211391664`], 
              Complex[1.2295234905102042`, -2.8401024596493754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.959851616225303, -1.3750580278450637`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3233336909542834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3750580278450637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2272310052160105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "Discard", 1, {
              Complex[3.3233336909542834`, -1.3750580278450637`], 
              Complex[1.2272310052160105`, -2.8442463457079334`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18174103736449077`, -1.3750580278450635`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18174103736449077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3750580278450635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2272310052160111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8442463457079334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "Discard", 2, {
              Complex[0.18174103736449077`, -1.3750580278450635`], 
              Complex[1.2272310052160111`, -2.8442463457079334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9613679794523424`, -1.3793470386724547`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.321817327727244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2249689239865722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8483480350867407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "Discard", 1, {
              Complex[3.321817327727244, -1.3793470386724547`], 
              Complex[1.2249689239865722`, -2.8483480350867407`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.18022467413745052`, -1.3793470386724553`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.18022467413745052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3793470386724553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.224968923986572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8483480350867416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "Discard", 2, {
              Complex[0.18022467413745052`, -1.3793470386724553`], 
              Complex[1.224968923986572, -2.8483480350867416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9628574296953225`, -1.383590523989566}],
            RowBox[{"{", 
              
              RowBox[{"22.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3203278774842637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.383590523989566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2227364316674654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "Discard", 1, {
              Complex[3.3203278774842637`, -1.383590523989566], 
              Complex[1.2227364316674654`, -2.8524085130586]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17873522389447033`, -1.3835905239895683`}],
            RowBox[{"{", 
              
              RowBox[{"22.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17873522389447033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3835905239895683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2227364316674634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8524085130586028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "Discard", 2, {
              Complex[0.17873522389447033`, -1.3835905239895683`], 
              Complex[1.2227364316674634`, -2.8524085130586028`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9643207389854895`, -1.3877895153923996`}],
            RowBox[{"{", 
              
              RowBox[{"22.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3188645681940967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3877895153923996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.220532745840933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8564287284726504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "Discard", 1, {
              Complex[3.3188645681940967`, -1.3877895153923996`], 
              Complex[1.220532745840933, -2.8564287284726504`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17727191460430375`, -1.3877895153924003`}],
            RowBox[{"{", 
              
              RowBox[{"22.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17727191460430375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3877895153924003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2205327458409323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8564287284726513`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "Discard", 2, {
              Complex[0.17727191460430375`, -1.3877895153924003`], 
              Complex[1.2205327458409323`, -2.8564287284726513`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9657586480288756`, -1.3919450076426472`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3174266591507107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3919450076426472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2183571150782422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "Discard", 1, {
              Complex[3.3174266591507107`, -1.3919450076426472`], 
              Complex[1.2183571150782422`, -2.860409595603666]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1758340055609178, -1.391945007642646}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1758340055609178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.391945007642646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.218357115078243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.860409595603666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "Discard", 2, {
              Complex[0.1758340055609178, -1.391945007642646], 
              Complex[1.218357115078243, -2.860409595603666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9671718678665275`, -1.396057960481959}],
            RowBox[{"{", 
              
              RowBox[{"22.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3160134393130587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.396057960481959`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2162088173083034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.864351995882056`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "Discard", 1, {
              Complex[3.3160134393130587`, -1.396057960481959], 
              Complex[1.2162088173083034`, -2.864351995882056]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17442078572326566`, -1.3960579604819585`}],
            RowBox[{"{", 
              
              RowBox[{"22.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17442078572326566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3960579604819585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2162088173083037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8643519958820556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "Discard", 2, {
              Complex[0.17442078572326566`, -1.3960579604819585`], 
              Complex[1.2162088173083037`, -2.8643519958820556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9685610814257166`, -1.4001293003321456`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3146242257538696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4001293003321456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.214087158293307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "Discard", 1, {
              Complex[3.3146242257538696`, -1.4001293003321456`], 
              Complex[1.214087158293307, -2.8682567795138803`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17303157216407558`, -1.4001293003321469`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17303157216407558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4001293003321469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2140871582933066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8682567795138803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "Discard", 2, {
              Complex[0.17303157216407558`, -1.4001293003321469`], 
              Complex[1.2140871582933066`, -2.8682567795138803`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9699269449706973`, -1.4041599218900036`}],
            RowBox[{"{", 
              
              RowBox[{"22.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.313258362208889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2119914702029877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "Discard", 1, {
              Complex[3.313258362208889, -1.4041599218900036`], 
              Complex[1.2119914702029877`, -2.8721247669993084`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17166570861909555`, -1.4041599218900036`}],
            RowBox[{"{", 
              
              RowBox[{"22.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17166570861909555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4041599218900036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2119914702029881`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8721247669993084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "Discard", 2, {
              Complex[0.17166570861909555`, -1.4041599218900036`], 
              Complex[1.2119914702029881`, -2.8721247669993084`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9712700894607393`, -1.408150689624686}],
            RowBox[{"{", 
              
              RowBox[{"23.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.311915217718847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.408150689624686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.209921110279896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.875956750557249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "Discard", 1, {
              Complex[3.311915217718847, -1.408150689624686], 
              Complex[1.209921110279896, -2.875956750557249]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.17032256412905356`, -1.4081506896246843`}],
            RowBox[{"{", 
              
              RowBox[{"23.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.17032256412905356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4081506896246843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2099211102798964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.875956750557247`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "Discard", 2, {
              Complex[0.17032256412905356`, -1.4081506896246843`], 
              Complex[1.2099211102798964`, -2.875956750557247]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9725911218225383`, -1.41210243918487}],
            RowBox[{"{", 
              
              RowBox[{"23.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.310594185357048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.41210243918487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2078754595887096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8797534954631456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "Discard", 1, {
              Complex[3.310594185357048, -1.41210243918487], 
              Complex[1.2078754595887096`, -2.8797534954631456`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.16900153176725363`, -1.4121024391848713`}],
            RowBox[{"{", 
              
              RowBox[{"23.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16900153176725363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4121024391848713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2078754595887078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.879753495463146`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "Discard", 2, {
              Complex[0.16900153176725363`, -1.4121024391848713`], 
              Complex[1.2078754595887078`, -2.879753495463146]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.973890626143422, -1.4160159787223123`}],
            RowBox[{"{", 
              
              RowBox[{"23.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3092946810361643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.205853921843281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.883515741306371`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "Discard", 1, {
              Complex[3.3092946810361643`, -1.4160159787223123`], 
              Complex[1.205853921843281, -2.883515741306371]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1677020274463709, -1.4160159787223117`}],
            RowBox[{"{", 
              
              RowBox[{"23.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1677020274463709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4160159787223117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.205853921843282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8835157413063706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "Discard", 2, {
              Complex[0.1677020274463709, -1.4160159787223117`], 
              Complex[1.205853921843282, -2.8835157413063706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9751691647912417`, -1.419892090137794}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3080161423883445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "Discard", 1, {
              Complex[3.3080161423883445`, -1.419892090137794], 
              Complex[1.203855922305636, -2.8872442031730206`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1664234887985512, -1.419892090137794}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1664234887985512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.419892090137794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.203855922305636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.8872442031730206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "Discard", 2, {
              Complex[0.1664234887985512, -1.419892090137794], 
              Complex[1.203855922305636, -2.8872442031730206`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9764272794663182`, -1.4237315302550264`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.306758027713268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4237315302550264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2018809067516425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.890939572759507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "Discard", 1, {
              Complex[3.306758027713268, -1.4237315302550264`], 
              Complex[1.2018809067516425`, -2.890939572759507]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1651653741234745, -1.4237315302550273`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1651653741234745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4237315302550273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.2018809067516416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8909395727595073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "Discard", 2, {
              Complex[0.1651653741234745, -1.4237315302550273`], 
              Complex[1.2018809067516416`, -2.8909395727595073`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9776654921903645`, -1.4275350319275477`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3055198149892218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1999283404985257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "Discard", 1, {
              Complex[3.3055198149892218`, -1.4275350319275477`], 
              Complex[1.1999283404985257`, -2.8946025194218263`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1639271613994279, -1.4275350319275484`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1639271613994279`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4275350319275484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1999283404985253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8946025194218263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "Discard", 2, {
              Complex[0.1639271613994279, -1.4275350319275484`], 
              Complex[1.1999283404985253`, -2.8946025194218263`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.978884306236885, -1.4313033050832549`}],
            RowBox[{"{", 
              
              RowBox[{"23.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.304301000942701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650046`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "Discard", 1, {
              Complex[3.304301000942701, -1.4313033050832549`], 
              Complex[1.1979977074898187`, -2.8982336911650046`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.16270834735290776`, -1.4313033050832542`}],
            RowBox[{"{", 
              
              RowBox[{"23.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16270834735290776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4313033050832542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1979977074898187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8982336911650033`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "Discard", 2, {
              Complex[0.16270834735290776`, -1.4313033050832542`], 
              Complex[1.1979977074898187`, -2.8982336911650033`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.980084207007173, -1.4350370377108632`}],
            RowBox[{"{", 
              
              RowBox[{"23.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3031011001724133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4350370377108632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.196088509433674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.901833715576858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "Discard", 1, {
              Complex[3.3031011001724133`, -1.4350370377108632`], 
              Complex[1.196088509433674, -2.901833715576858]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.16150844658262048`, -1.4350370377108643`}],
            RowBox[{"{", 
              
              RowBox[{"23.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16150844658262048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4350370377108643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1960885094336744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9018337155768594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "Discard", 2, {
              Complex[0.16150844658262048`, -1.4350370377108643`], 
              Complex[1.1960885094336744`, -2.9018337155768594`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9812656628557157`, -1.438736896792191}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3019196443238705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.194200264990824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.905403200709853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "Discard", 1, {
              Complex[3.3019196443238705`, -1.438736896792191], 
              Complex[1.194200264990824, -2.905403200709853]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.16032699073407702`, -1.438736896792191}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.16032699073407702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.438736896792191`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1942002649908234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9054032007098534`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "Discard", 2, {
              Complex[0.16032699073407702`, -1.438736896792191], 
              Complex[1.1942002649908234`, -2.9054032007098534`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9824291258684807`, -1.4424035291838815`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3007561813111055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4424035291838815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.908942735914548`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "Discard", 1, {
              Complex[3.3007561813111055`, -1.4424035291838815`], 
              Complex[1.192332509008784, -2.908942735914548]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15916352772131243`, -1.442403529183883}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15916352772131243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.442403529183883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.192332509008784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9089427359145503`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "Discard", 2, {
              Complex[0.15916352772131243`, -1.442403529183883], 
              Complex[1.192332509008784, -2.9089427359145503`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9835750325972827`, -1.446037562451929}],
            RowBox[{"{", 
              
              RowBox[{"24.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2996102745823035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.446037562451929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.190484791799119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "Discard", 1, {
              Complex[3.2996102745823035`, -1.446037562451929], 
              Complex[1.190484791799119, -2.912452892627875]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15801762099250957`, -1.4460375624519293`}],
            RowBox[{"{", 
              
              RowBox[{"24.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15801762099250957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4460375624519293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1904847917991184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.912452892627875`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "Discard", 2, {
              Complex[0.15801762099250957`, -1.4460375624519293`], 
              Complex[1.1904847917991184`, -2.912452892627875]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9847038047532104`, -1.4496396056620289`}],
            RowBox[{"{", 
              
              RowBox[{"24.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.298481502426376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1886566784549102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9159342251191687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "Discard", 1, {
              Complex[3.298481502426376, -1.4496396056620289`], 
              Complex[1.1886566784549102`, -2.9159342251191687`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15688884883658272`, -1.4496396056620269`}],
            RowBox[{"{", 
              
              RowBox[{"24.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15688884883658272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4496396056620269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.188656678454911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.915934225119166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "Discard", 2, {
              Complex[0.15688884883658272`, -1.4496396056620269`], 
              Complex[1.188656678454911, -2.915934225119166]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.985815849861794, -1.4532102501286348`}],
            RowBox[{"{", 
              
              RowBox[{"24.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2973694573177923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4532102501286348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1868477482057302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "Discard", 1, {
              Complex[3.2973694573177923`, -1.4532102501286348`], 
              Complex[1.1868477482057302`, -2.919387271196738]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15577680372799887`, -1.4532102501286346`}],
            RowBox[{"{", 
              
              RowBox[{"24.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15577680372799887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4532102501286346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1868477482057311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.919387271196738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "Discard", 2, {
              Complex[0.15577680372799887`, -1.4532102501286346`], 
              Complex[1.1868477482057311`, -2.919387271196738]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9869115618824784`, -1.4567500701253233`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.296273745297108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4567500701253233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1850575938076657`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9228125528774775`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "Discard", 1, {
              Complex[3.296273745297108, -1.4567500701253233`], 
              Complex[1.1850575938076657`, -2.9228125528774775`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1546810917073148, -1.456750070125323}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1546810917073148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.456750070125323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1850575938076662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.922812552877478`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "Discard", 2, {
              Complex[0.1546810917073148, -1.456750070125323], 
              Complex[1.1850575938076662`, -2.922812552877478]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9879913217946745`, -1.4602596235588936`}],
            RowBox[{"{", 
              
              RowBox[{"24.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2951939853849117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1832858209661052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.926210577021858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "Discard", 1, {
              Complex[3.2951939853849117`, -1.4602596235588936`], 
              Complex[1.1832858209661052`, -2.926210577021858]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1536013317951177, -1.4602596235588952`}],
            RowBox[{"{", 
              
              RowBox[{"24.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1536013317951177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4602596235588952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1832858209661048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.92621057702186`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "Discard", 2, {
              Complex[0.1536013317951177, -1.4602596235588952`], 
              Complex[1.1832858209661048`, -2.92621057702186]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9890554981525645`, -1.4637394526094694`}],
            RowBox[{"{", 
              
              RowBox[{"24.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2941298090270217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4637394526094694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1815320477892093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "Discard", 1, {
              Complex[3.2941298090270217`, -1.4637394526094694`], 
              Complex[1.1815320477892093`, -2.9295818359364927`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15253715543722762`, -1.4637394526094687`}],
            RowBox[{"{", 
              
              RowBox[{"24.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15253715543722762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4637394526094687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.181532047789208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9295818359364927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "Discard", 2, {
              Complex[0.15253715543722762`, -1.4637394526094687`], 
              Complex[1.181532047789208, -2.9295818359364927`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9901044476106375`, -1.4671900843386574`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2930808595689487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4671900843386574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1797959042700832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9329268079462416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "Discard", 1, {
              Complex[3.2930808595689487`, -1.4671900843386574`], 
              Complex[1.1797959042700832`, -2.9329268079462416`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.15148820597915524`, -1.4671900843386563`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.15148820597915524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4671900843386563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.179795904270083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.932926807946241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "Discard", 2, {
              Complex[0.15148820597915524`, -1.4671900843386563`], 
              Complex[1.179795904270083, -2.932926807946241]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.991138515421795, -1.470612031267736}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2920467917577914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.178077031795879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.936245957937766`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "Discard", 1, {
              Complex[3.2920467917577914`, -1.470612031267736], 
              Complex[1.178077031795879, -2.936245957937766]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1504541381679981, -1.470612031267735}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1504541381679981`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.470612031267735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1780770317958789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.936245957937765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "Discard", 2, {
              Complex[0.1504541381679981, -1.470612031267735], 
              Complex[1.1780770317958789`, -2.936245957937765]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.99215803590973, -1.474005791927643}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.291027271269856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.474005791927643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "Discard", 1, {
              Complex[3.291027271269856, -1.474005791927643], 
              Complex[1.1763750826821242`, -2.9395397378762267`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1494346176800629, -1.4740057919276426`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1494346176800629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4740057919276426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1763750826821242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9395397378762262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "Discard", 2, {
              Complex[0.1494346176800629, -1.4740057919276426`], 
              Complex[1.1763750826821242`, -2.9395397378762262`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9931633329171747`, -1.4773718513824372`}],
            RowBox[{"{", 
              
              RowBox[{"24.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2900219742624115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4773718513824372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1746897197307482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9428085872967427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "Discard", 1, {
              Complex[3.2900219742624115`, -1.4773718513824372`], 
              Complex[1.1746897197307482`, -2.9428085872967427`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1484293206726183, -1.477371851382437}],
            RowBox[{"{", 
              
              RowBox[{"24.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1484293206726183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.477371851382437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1746897197307484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.942808587296742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "Discard", 2, {
              Complex[0.1484293206726183, -1.477371851382437], 
              Complex[1.1746897197307484`, -2.942808587296742]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.99415472023146, -1.4807106817278028`}],
            RowBox[{"{", 
              
              RowBox[{"25.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2890305869481264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "Discard", 1, {
              Complex[3.2890305869481264`, -1.4807106817278028`], 
              Complex[1.1730206158103629`, -2.946052933772111]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1474379333583333, -1.4807106817278035`}],
            RowBox[{"{", 
              
              RowBox[{"25.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1474379333583333`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4807106817278035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1730206158103629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.946052933772111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "Discard", 2, {
              Complex[0.1474379333583333, -1.4807106817278035`], 
              Complex[1.1730206158103629`, -2.946052933772111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9951325019887802`, -1.4840227425660197`}],
            RowBox[{"{", 
              
              RowBox[{"25.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.288052805190806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4840227425660197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1713674534574503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "Discard", 1, {
              Complex[3.288052805190806, -1.4840227425660197`], 
              Complex[1.1713674534574503`, -2.9492731933581573`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.14646015160101253`, -1.48402274256602}],
            RowBox[{"{", 
              
              RowBox[{"25.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14646015160101253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.48402274256602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1713674534574505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9492731933581573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "Discard", 2, {
              Complex[0.14646015160101253`, -1.48402274256602], 
              Complex[1.1713674534574505`, -2.9492731933581573`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.9960969730584237`, -1.4873084814587765`}],
            RowBox[{"{", 
              
              RowBox[{"25.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2870883341211625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4873084814587765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1697299244972095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9524697710180425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "Discard", 1, {
              Complex[3.2870883341211625`, -1.4873084814587765`], 
              Complex[1.1697299244972095`, -2.9524697710180425`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.14549568053136955`, -1.487308481458776}],
            RowBox[{"{", 
              
              RowBox[{"25.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14549568053136955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.487308481458776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.16972992449721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9524697710180416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "Discard", 2, {
              Complex[0.14549568053136955`, -1.487308481458776], 
              Complex[1.16972992449721, -2.9524697710180416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.997048419408136, -1.4905683343590643`}],
            RowBox[{"{", 
              
              RowBox[{"25.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.28613688777145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4905683343590643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1681077296829168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9556430610267057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "Discard", 1, {
              Complex[3.28613688777145, -1.4905683343590643`], 
              Complex[1.1681077296829168`, -2.9556430610267057`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1445442341816557, -1.490568334359063}],
            RowBox[{"{", 
              
              RowBox[{"25.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1445442341816557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.490568334359063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.168107729682917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.955643061026704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "Discard", 2, {
              Complex[0.1445442341816557, -1.490568334359063], 
              Complex[1.168107729682917, -2.955643061026704]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.997987118451749, -1.4938027260233295`}],
            RowBox[{"{", 
              
              RowBox[{"25.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.285198188727837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1665005783527111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9587934473565816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "Discard", 1, {
              Complex[3.285198188727837, -1.4938027260233295`], 
              Complex[1.1665005783527111`, -2.9587934473565816`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.14360553513804464`, -1.4938027260233295`}],
            RowBox[{"{", 
              
              RowBox[{"25.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14360553513804464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4938027260233295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1665005783527118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.958793447356582`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "Discard", 2, {
              Complex[0.14360553513804464`, -1.4938027260233295`], 
              Complex[1.1665005783527118`, -2.958793447356582]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.998913339380063, -1.4970120704049878`}],
            RowBox[{"{", 
              
              RowBox[{"25.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.284271967799523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4970120704049878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1649081881027983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "Discard", 1, {
              Complex[3.284271967799523, -1.4970120704049878`], 
              Complex[1.1649081881027983`, -2.9619213040456414`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1426793142097304, -1.4970120704049876`}],
            RowBox[{"{", 
              
              RowBox[{"25.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1426793142097304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4970120704049876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1649081881027992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9619213040456414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "Discard", 2, {
              Complex[0.1426793142097304, -1.4970120704049876`], 
              Complex[1.1649081881027992`, -2.9619213040456414`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-2.999827343475983, -1.500196771030314}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.283357963703603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.500196771030314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1633302844761357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "Discard", 1, {
              Complex[3.283357963703603, -1.500196771030314], 
              Complex[1.1633302844761357`, -2.965026995548729]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.14176531011381055`, -1.5001967710303135`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14176531011381055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5001967710303135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1633302844761368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.965026995548729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "Discard", 2, {
              Complex[0.14176531011381055`, -1.5001967710303135`], 
              Complex[1.1633302844761368`, -2.965026995548729]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0007293844147656`, -1.5033572213576796`}],
            RowBox[{"{", 
              
              RowBox[{"25.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2824559227648207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1617666006657197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.968110877073136`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "Discard", 1, {
              Complex[3.2824559227648207`, -1.5033572213576796`], 
              Complex[1.1617666006657197`, -2.968110877073136]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.14086326917502792`, -1.5033572213576796`}],
            RowBox[{"{", 
              
              RowBox[{"25.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.14086326917502792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5033572213576796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.161766600665721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9681108770731357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "Discard", 2, {
              Complex[0.14086326917502792`, -1.5033572213576796`], 
              Complex[1.161766600665721, -2.9681108770731357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0016197085502347`, -1.5064938051210213`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2815655986293515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5064938051210213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1602168772316634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9711732948992347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "Discard", 1, {
              Complex[3.2815655986293515`, -1.5064938051210213`], 
              Complex[1.1602168772316634`, -2.9711732948992347`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13997294503955765`, -1.5064938051210208`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13997294503955765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5064938051210208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.160216877231663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9711732948992333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "Discard", 2, {
              Complex[0.13997294503955765`, -1.5064938051210208`], 
              Complex[1.160216877231663, -2.9711732948992333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0024985551877394`, -1.5096068966583966`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.280686751991847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1586808618312865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "Discard", 1, {
              Complex[3.280686751991847, -1.5096068966583966`], 
              Complex[1.1586808618312865`, -2.974214586687023]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13909409840205325`, -1.5096068966583966`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13909409840205325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5096068966583966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.158680861831286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.974214586687023`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "Discard", 2, {
              Complex[0.13909409840205325`, -1.5096068966583966`], 
              Complex[1.158680861831286, -2.974214586687023]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.003366156844581, -1.512696861226397}],
            RowBox[{"{", 
              
              RowBox[{"26.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.279819150335005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.512696861226397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1571583089615178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "Discard", 1, {
              Complex[3.279819150335005, -1.512696861226397], 
              Complex[1.1571583089615178`, -2.9772350817692788`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13822649674521148`, -1.5126968612263973`}],
            RowBox[{"{", 
              
              RowBox[{"26.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13822649674521148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5126968612263973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1571583089615174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9772350817692788`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "Discard", 2, {
              Complex[0.13822649674521148`, -1.5126968612263973`], 
              Complex[1.1571583089615174`, -2.9772350817692788`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.004222739498606, -1.5157640553011698`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2789625676809804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5157640553011698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1556489797129244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.980235101432074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "Discard", 1, {
              Complex[3.2789625676809804`, -1.5157640553011698`], 
              Complex[1.1556489797129244`, -2.980235101432074]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13736991409118712`, -1.515764055301169}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13736991409118712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.515764055301169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1556489797129252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9802351014320725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "Discard", 2, {
              Complex[0.13736991409118712`, -1.515764055301169], 
              Complex[1.1556489797129252`, -2.9802351014320725`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.005068522825585, -1.518808826866739}],
            RowBox[{"{", 
              
              RowBox[{"26.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.278116784354001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.518808826866739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1541526415347505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9832149591832895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "Discard", 1, {
              Complex[3.278116784354001, -1.518808826866739], 
              Complex[1.1541526415347505`, -2.9832149591832895`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13652413076420825`, -1.5188088268667397`}],
            RowBox[{"{", 
              
              RowBox[{"26.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13652413076420825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5188088268667397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.15415264153475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.98321495918329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "Discard", 2, {
              Complex[0.13652413076420825`, -1.5188088268667397`], 
              Complex[1.15415264153475, -2.98321495918329]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.005903720426004, -1.5218315156912805`}],
            RowBox[{"{", 
              
              RowBox[{"26.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.277281586753582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.152669068010364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "Discard", 1, {
              Complex[3.277281586753582, -1.5218315156912805`], 
              Complex[1.152669068010364, -2.9861749610097594`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13568893316378858`, -1.5218315156912807`}],
            RowBox[{"{", 
              
              RowBox[{"26.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13568893316378858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5218315156912807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1526690680103642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9861749610097594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "Discard", 2, {
              Complex[0.13568893316378858`, -1.5218315156912807`], 
              Complex[1.1526690680103642`, -2.9861749610097594`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.006728540041806, -1.5248324535919475`}],
            RowBox[{"{", 
              
              RowBox[{"26.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2764567671377804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "Discard", 1, {
              Complex[3.2764567671377804`, -1.5248324535919475`], 
              Complex[1.1511980386425853`, -2.9891154056236187`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13486411354798725`, -1.5248324535919475`}],
            RowBox[{"{", 
              
              RowBox[{"26.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13486411354798725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5248324535919475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1511980386425853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9891154056236187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "Discard", 2, {
              Complex[0.13486411354798725`, -1.5248324535919475`], 
              Complex[1.1511980386425853`, -2.9891154056236187`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0075431837636226`, -1.5278119646888435`}],
            RowBox[{"{", 
              
              RowBox[{"26.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2756421234159636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5278119646888435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1497393386483465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.992036584698415`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "Discard", 1, {
              Complex[3.2756421234159636`, -1.5278119646888435`], 
              Complex[1.1497393386483465`, -2.992036584698415]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13404946982617044`, -1.5278119646888442`}],
            RowBox[{"{", 
              
              RowBox[{"26.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13404946982617044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5278119646888442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1497393386483457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9920365846984165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "Discard", 2, {
              Complex[0.13404946982617044`, -1.5278119646888442`], 
              Complex[1.1497393386483457`, -2.9920365846984165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.008347848229003, -1.5307703656486717`}],
            RowBox[{"{", 
              
              RowBox[{"26.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.274837458950583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5307703656486717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1482927587622176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830954994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "Discard", 1, {
              Complex[3.274837458950583, -1.5307703656486717`], 
              Complex[1.1482927587622176`, -2.9949387830954994`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1332448053607902, -1.530770365648672}],
            RowBox[{"{", 
              
              RowBox[{"26.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1332448053607902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.530770365648672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1482927587622171`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9949387830955003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "Discard", 2, {
              Complex[0.1332448053607902, -1.530770365648672], 
              Complex[1.1482927587622171`, -2.9949387830955003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0091427248120803`, -1.5337079659185715`}],
            RowBox[{"{", 
              
              RowBox[{"26.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.274042582367506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5337079659185715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1468580950483382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "Discard", 1, {
              Complex[3.274042582367506, -1.5337079659185715`], 
              Complex[1.1468580950483382`, -2.997822279081166]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13244992877771303`, -1.533707965918572}],
            RowBox[{"{", 
              
              RowBox[{"26.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13244992877771303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.533707965918572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1468580950483385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.997822279081167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "Discard", 2, {
              Complex[0.13244992877771303`, -1.533707965918572], 
              Complex[1.1468580950483385`, -2.997822279081167]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.009927999805138, -1.5366250679506237`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.273257307374448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1454351487203243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0006873445350215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "Discard", 1, {
              Complex[3.273257307374448, -1.5366250679506237`], 
              Complex[1.1454351487203243`, -3.0006873445350215`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13166465378465506`, -1.5366250679506237`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13166465378465506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5366250679506237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1454351487203238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.000687344535021`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "Discard", 2, {
              Complex[0.13166465378465506`, -1.5366250679506237`], 
              Complex[1.1454351487203238`, -3.000687344535021]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0107038545924754`, -1.5395219674174738`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.272481452587111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1440237259687367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.003534245149988`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "Discard", 1, {
              Complex[3.272481452587111, -1.5395219674174738`], 
              Complex[1.1440237259687367`, -3.003534245149988]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13088879899731687`, -1.5395219674174727`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13088879899731687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5395219674174727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.144023725968737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0035342451499867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "Discard", 2, {
              Complex[0.13088879899731687`, -1.5395219674174727`], 
              Complex[1.144023725968737, -3.0035342451499867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.011470465816965, -1.542398953419513}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.271714841362621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.542398953419513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1426236377957488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "Discard", 1, {
              Complex[3.271714841362621, -1.542398953419513], 
              Complex[1.1426236377957488`, -3.0063632406243794`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.13012218777282775`, -1.5423989534195135`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.13012218777282775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5423989534195135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1426236377957477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0063632406243785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "Discard", 2, {
              Complex[0.13012218777282775`, -1.5423989534195135`], 
              Complex[1.1426236377957477`, -3.0063632406243785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0122280055396575`, -1.5452563086839952`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2709573016399287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5452563086839952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1412346998566438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846389`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "Discard", 1, {
              Complex[3.2709573016399287`, -1.5452563086839952`], 
              Complex[1.1412346998566438`, -3.009174584846389]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12936464805013348`, -1.545256308683994}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12936464805013348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.545256308683994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1412346998566436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.009174584846388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "Discard", 2, {
              Complex[0.12936464805013348`, -1.545256308683994], 
              Complex[1.1412346998566436`, -3.009174584846388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.01297664139281, -1.548094309756492}],
            RowBox[{"{", 
              
              RowBox[{"27.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270208665786776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.548094309756492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1398567323078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0119685260713935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "Discard", 1, {
              Complex[3.270208665786776, -1.548094309756492], 
              Complex[1.1398567323078, -3.0119685260713935`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12861601219698304`, -1.5480943097564914`}],
            RowBox[{"{", 
              
              RowBox[{"27.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12861601219698304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5480943097564914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1398567323078006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0119685260713926`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "Discard", 2, {
              Complex[0.12861601219698304`, -1.5480943097564914`], 
              Complex[1.1398567323078006`, -3.0119685260713926`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.013716536726594, -1.5509132271850388`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2694687704529923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5509132271850388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1384895596608702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.014745307092387`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "Discard", 1, {
              Complex[3.2694687704529923`, -1.5509132271850388`], 
              Complex[1.1384895596608702`, -3.014745307092387]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12787611686319877`, -1.5509132271850385`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12787611686319877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5509132271850385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1384895596608695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0147453070923866`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "Discard", 2, {
              Complex[0.12787611686319877`, -1.5509132271850385`], 
              Complex[1.1384895596608695`, -3.0147453070923866`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.014447850749887, -1.5537133256973044`}],
            RowBox[{"{", 
              
              RowBox[{"27.499999999999993`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.268737456429699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1371330106428055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0175051654038723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "Discard", 1, {
              Complex[3.268737456429699, -1.5537133256973044`], 
              Complex[1.1371330106428055`, -3.0175051654038723`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12714480283990298`, -1.5537133256973077`}],
            RowBox[{"{", 
              
              RowBox[{"27.499999999999993`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12714480283990298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5537133256973077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1371330106428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.017505165403874`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "Discard", 2, {
              Complex[0.12714480283990298`, -1.5537133256973077`], 
              Complex[1.1371330106428, -3.017505165403874]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.015170738665339, -1.55649486437111}],
            RowBox[{"{", 
              
              RowBox[{"27.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.268014568514247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.55649486437111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1357869180615132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.020248333359523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "Discard", 1, {
              Complex[3.268014568514247, -1.55649486437111], 
              Complex[1.1357869180615132`, -3.020248333359523]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12642191492445268`, -1.5564948643711098`}],
            RowBox[{"{", 
              
              RowBox[{"27.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12642191492445268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5564948643711098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1357869180615123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0202483333595227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "Discard", 2, {
              Complex[0.12642191492445268`, -1.5564948643711098`], 
              Complex[1.1357869180615123`, -3.0202483333595227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.015885351799055, -1.559258096798595}],
            RowBox[{"{", 
              
              RowBox[{"27.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.267299955380531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1344511186768103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0229750383238807`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "Discard", 1, {
              Complex[3.267299955380531, -1.559258096798595], 
              Complex[1.1344511186768103`, -3.0229750383238807`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12570730179073827`, -1.559258096798594}],
            RowBox[{"{", 
              
              RowBox[{"27.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12570730179073827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.559258096798594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1344511186768111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.02297503832388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "Discard", 2, {
              Complex[0.12570730179073827`, -1.559258096798594], 
              Complex[1.1344511186768111`, -3.02297503832388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.016591837725109, -1.5620032712443408`}],
            RowBox[{"{", 
              
              RowBox[{"27.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2665934694544774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5620032712443408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1331254530764636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "Discard", 1, {
              Complex[3.2665934694544774`, -1.5620032712443408`], 
              Complex[1.1331254530764636`, -3.0256855028184027`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12500081586468456`, -1.5620032712443406`}],
            RowBox[{"{", 
              
              RowBox[{"27.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12500081586468456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5620032712443406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1331254530764638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0256855028184018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "Discard", 2, {
              Complex[0.12500081586468456`, -1.5620032712443406`], 
              Complex[1.1331254530764638`, -3.0256855028184018`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.017290340385164, -1.5647306307976763`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.265894966794422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1318097655570643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "Discard", 1, {
              Complex[3.265894966794422, -1.5647306307976763`], 
              Complex[1.1318097655570643`, -3.028379944662053]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12430231320462909`, -1.5647306307976756`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12430231320462909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5647306307976756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.131809765557065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.028379944662053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "Discard", 2, {
              Complex[0.12430231320462909`, -1.5647306307976756`], 
              Complex[1.131809765557065, -3.028379944662053]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0179810002034007`, -1.5674404135194786`}],
            RowBox[{"{", 
              
              RowBox[{"27.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2652043069761856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1305039040095175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "Discard", 1, {
              Complex[3.2652043069761856`, -1.5674404135194786`], 
              Complex[1.1305039040095175`, -3.0310585771067586`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1236116533863979, -1.5674404135194724`}],
            RowBox[{"{", 
              
              RowBox[{"27.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1236116533863979`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5674404135194724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1305039040095248`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0310585771067524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "Discard", 2, {
              Complex[0.1236116533863979, -1.5674404135194724`], 
              Complex[1.1305039040095248`, -3.0310585771067524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0186639541969926`, -1.5701328525836726`}],
            RowBox[{"{", 
              
              RowBox[{"28.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2645213529825936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1292077198089117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.03372160896789`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "Discard", 1, {
              Complex[3.2645213529825936`, -1.5701328525836726`], 
              Complex[1.1292077198089117`, -3.03372160896789]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12292869939280154`, -1.5701328525836726`}],
            RowBox[{"{", 
              
              RowBox[{"28.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12292869939280154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5701328525836726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1292077198089157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0337216089678942`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "Discard", 2, {
              Complex[0.12292869939280154`, -1.5701328525836726`], 
              Complex[1.1292077198089157`, -3.0337216089678942`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0193393360823175`, -1.5728081764136679`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2638459710972687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5728081764136679`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1279210677086156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.036369244750015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "Discard", 1, {
              Complex[3.2638459710972687`, -1.5728081764136679`], 
              Complex[1.1279210677086156`, -3.036369244750015]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12225331750747458`, -1.5728081764136674`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12225331750747458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5728081764136674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1279210677086149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0363692447500137`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "Discard", 2, {
              Complex[0.12225331750747458`, -1.5728081764136674`], 
              Complex[1.1279210677086149`, -3.0363692447500137`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0200072763771177`, -1.575466608813974}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2631780308024685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.575466608813974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.126643805738343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.03900168476816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "Discard", 1, {
              Complex[3.2631780308024685`, -1.575466608813974], 
              Complex[1.126643805738343, -3.03900168476816]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12158537721267502`, -1.5754666088139742`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12158537721267502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754666088139742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1266438057383434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.039001684768161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "Discard", 2, {
              Complex[0.12158537721267502`, -1.5754666088139742`], 
              Complex[1.1266438057383434`, -3.039001684768161]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0206679024987677`, -1.5781083690971809`}],
            RowBox[{"{", 
              
              RowBox[{"28.399999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2625174046808185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5781083690971809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1253757951060703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.041619125264729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "Discard", 1, {
              Complex[3.2625174046808185`, -1.5781083690971809`], 
              Complex[1.1253757951060703`, -3.041619125264729]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12092475109102498`, -1.5781083690971813`}],
            RowBox[{"{", 
              
              RowBox[{"28.399999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12092475109102498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5781083690971813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1253757951060699`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.04161912526473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "Discard", 2, {
              Complex[0.12092475109102498`, -1.5781083690971813`], 
              Complex[1.1253757951060699`, -3.04161912526473]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.021321338858858, -1.5807336722064977`}],
            RowBox[{"{", 
              
              RowBox[{"28.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2618639683207284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5807336722064977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1241169001035878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0442217585222795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "Discard", 1, {
              Complex[3.2618639683207284`, -1.5807336722064977`], 
              Complex[1.1241169001035878`, -3.0442217585222795`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.12027131473093523`, -1.580733672206497}],
            RowBox[{"{", 
              
              RowBox[{"28.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.12027131473093523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.580733672206497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.124116900103588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0442217585222786`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "Discard", 2, {
              Complex[0.12027131473093523`, -1.580733672206497], 
              Complex[1.124116900103588, -3.0442217585222786`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0219677069542237`, -1.5833427288340611`}],
            RowBox[{"{", 
              
              RowBox[{"28.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2612176002253626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1228669880155548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "Discard", 1, {
              Complex[3.2612176002253626`, -1.5833427288340611`], 
              Complex[1.1228669880155548`, -3.0468097729723587`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11962494663556839`, -1.5833427288340611`}],
            RowBox[{"{", 
              
              RowBox[{"28.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11962494663556839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5833427288340611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1228669880155542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0468097729723587`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "Discard", 2, {
              Complex[0.11962494663556839`, -1.5833427288340611`], 
              Complex[1.1228669880155542`, -3.0468097729723587`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.02260712545461, -1.5859357455351744`}],
            RowBox[{"{", 
              
              RowBox[{"28.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.260578181724976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1216259290318786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.049383353300541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "Discard", 1, {
              Complex[3.260578181724976, -1.5859357455351744`], 
              Complex[1.1216259290318786`, -3.049383353300541]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11898552813518211`, -1.5859357455351755`}],
            RowBox[{"{", 
              
              RowBox[{"28.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11898552813518211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5859357455351755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1216259290318777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0493833533005414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "Discard", 2, {
              Complex[0.11898552813518211`, -1.5859357455351755`], 
              Complex[1.1216259290318777`, -3.0493833533005414`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0232397102870903`, -1.58851292483865}],
            RowBox[{"{", 
              
              RowBox[{"28.799999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.259945596892496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58851292483865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1203935961632925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "Discard", 1, {
              Complex[3.259945596892496, -1.58851292483865], 
              Complex[1.1203935961632925`, -3.051942680547835]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11835294330270157`, -1.5885129248386511`}],
            RowBox[{"{", 
              
              RowBox[{"28.799999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11835294330270157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5885129248386511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1203935961632907`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.051942680547835`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "Discard", 2, {
              Complex[0.11835294330270157`, -1.5885129248386511`], 
              Complex[1.1203935961632907`, -3.051942680547835]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0238655747174095`, -1.5910744653534166`}],
            RowBox[{"{", 
              
              RowBox[{"28.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2593197324621768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5910744653534166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.119169865159973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.054487932208608`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "Discard", 1, {
              Complex[3.2593197324621768`, -1.5910744653534166`], 
              Complex[1.119169865159973, -3.054487932208608]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11772707887238294`, -1.5910744653534168`}],
            RowBox[{"{", 
              
              RowBox[{"28.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11772707887238294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5910744653534168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1191698651599729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0544879322086085`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "Discard", 2, {
              Complex[0.11772707887238294`, -1.5910744653534168`], 
              Complex[1.1191698651599729`, -3.0544879322086085`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.024484829428358, -1.5936205618715453`}],
            RowBox[{"{", 
              
              RowBox[{"28.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.258700477751228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5936205618715453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1179546144330978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.057019282325188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "Discard", 1, {
              Complex[3.258700477751228, -1.5936205618715453`], 
              Complex[1.1179546144330978`, -3.057019282325188]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11710782416143134`, -1.593620561871549}],
            RowBox[{"{", 
              
              RowBox[{"28.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11710782416143134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.593620561871549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1179546144330925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0570192823251907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "Discard", 2, {
              Complex[0.11710782416143134`, -1.593620561871549], 
              Complex[1.1179546144330925`, -3.0570192823251907`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.025097582595329, -1.5961514054678452`}],
            RowBox[{"{", 
              
              RowBox[{"29.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.258087724584257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5961514054678452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1167477249791709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "Discard", 1, {
              Complex[3.258087724584257, -1.5961514054678452`], 
              Complex[1.1167477249791709`, -3.0595369015792553`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1164950709944641, -1.596151405467845}],
            RowBox[{"{", 
              
              RowBox[{"29.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1164950709944641`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.596151405467845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1167477249791702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0595369015792553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "Discard", 2, {
              Complex[0.1164950709944641, -1.596151405467845], 
              Complex[1.1167477249791702`, -3.0595369015792553`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0257039399591594`, -1.5986671835961581`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.257481367220427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.115549080307043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.062040957380181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "Discard", 1, {
              Complex[3.257481367220427, -1.5986671835961581`], 
              Complex[1.115549080307043, -3.062040957380181]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11588871363063293`, -1.5986671835961561`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11588871363063293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5986671835961561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.115549080307041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0620409573801792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "Discard", 2, {
              Complex[0.11588871363063293`, -1.5986671835961561`], 
              Complex[1.115549080307041, -3.0620409573801792`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0263040048963883`, -1.60116808018249}],
            RowBox[{"{", 
              
              RowBox[{"29.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.256881302283198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.60116808018249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1143585663674842`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.064531613950414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "Discard", 1, {
              Complex[3.256881302283198, -1.60116808018249], 
              Complex[1.1143585663674842`, -3.064531613950414]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11528864869340531`, -1.6011680801824892`}],
            RowBox[{"{", 
              
              RowBox[{"29.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11528864869340531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6011680801824892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.114358566367485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0645316139504137`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "Discard", 2, {
              Complex[0.11528864869340531`, -1.6011680801824892`], 
              Complex[1.114358566367485, -3.0645316139504137`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0268978784870195`, -1.603654275715105}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2562874286925667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.603654275715105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1131760714852224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408053`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "Discard", 1, {
              Complex[3.2562874286925667`, -1.603654275715105], 
              Complex[1.1131760714852224`, -3.067009032408053]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11469477510277208`, -1.603654275715108}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11469477510277208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.603654275715108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1131760714852184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.067009032408055`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "Discard", 2, {
              Complex[0.11469477510277208`, -1.603654275715108], 
              Complex[1.1131760714852184`, -3.067009032408055]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.027485659579919, -1.606125947331712}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.255699647599667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.606125947331712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1120014862933134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "Discard", 1, {
              Complex[3.255699647599667, -1.606125947331712], 
              Complex[1.1120014862933134`, -3.06947337084671]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11410699400987415`, -1.6061259473317113`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11410699400987415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6061259473317113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.112001486293314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.06947337084671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "Discard", 2, {
              Complex[0.11410699400987415`, -1.6061259473317113`], 
              Complex[1.112001486293314, -3.06947337084671]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0280674448559246`, -1.6085832689038237`}],
            RowBox[{"{", 
              
              RowBox[{"29.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2551178623236616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6085832689038237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1108347036697925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127553`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "Discard", 1, {
              Complex[3.2551178623236616`, -1.6085832689038237`], 
              Complex[1.1108347036697925`, -3.0719247844127553`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11352520873386833`, -1.608583268903826}],
            RowBox[{"{", 
              
              RowBox[{"29.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11352520873386833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.608583268903826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1108347036697903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0719247844127584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "Discard", 2, {
              Complex[0.11352520873386833`, -1.608583268903826], 
              Complex[1.1108347036697903`, -3.0719247844127584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0286433288887693`, -1.611026411118455}],
            RowBox[{"{", 
              
              RowBox[{"29.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.254541978290817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1096756186764698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "Discard", 1, {
              Complex[3.254541978290817, -1.611026411118455], 
              Complex[1.1096756186764698`, -3.0743634253800933`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1129493247010233, -1.611026411118455}],
            RowBox[{"{", 
              
              RowBox[{"29.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1129493247010233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.611026411118455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1096756186764682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0743634253800933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "Discard", 2, {
              Complex[0.1129493247010233, -1.611026411118455], 
              Complex[1.1096756186764682`, -3.0743634253800933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.029213404203915, -1.6134555415571998`}],
            RowBox[{"{", 
              
              RowBox[{"29.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.253971902975671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1085241284998075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.076789443222504`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "Discard", 1, {
              Complex[3.253971902975671, -1.6134555415571998`], 
              Complex[1.1085241284998075`, -3.076789443222504]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11237924938587697`, -1.6134555415571996`}],
            RowBox[{"{", 
              
              RowBox[{"29.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11237924938587697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6134555415571996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.108524128499807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0767894432225034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "Discard", 2, {
              Complex[0.11237924938587697`, -1.6134555415571996`], 
              Complex[1.108524128499807, -3.0767894432225034`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.029777761335372, -1.6158708247728455`}],
            RowBox[{"{", 
              
              RowBox[{"29.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2534075458442144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "Discard", 1, {
              Complex[3.2534075458442144`, -1.6158708247728455`], 
              Complex[1.1073801323937882`, -3.0792029846837012`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1118148922544208, -1.6158708247728453`}],
            RowBox[{"{", 
              
              RowBox[{"29.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1118148922544208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6158708247728453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1073801323937882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0792029846837004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "Discard", 2, {
              Complex[0.1118148922544208, -1.6158708247728453`], 
              Complex[1.1073801323937882`, -3.0792029846837004`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0303364888805855`, -1.6182724223635778`}],
            RowBox[{"{", 
              
              RowBox[{"29.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2528488182990007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6182724223635778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1062435316246895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "Discard", 1, {
              Complex[3.2528488182990007`, -1.6182724223635778`], 
              Complex[1.1062435316246895`, -3.0816041938451617`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11125616470920796`, -1.6182724223635776`}],
            RowBox[{"{", 
              
              RowBox[{"29.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11125616470920796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6182724223635776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1062435316246904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0816041938451617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "Discard", 2, {
              Complex[0.11125616470920796`, -1.6182724223635776`], 
              Complex[1.1062435316246904`, -3.0816041938451617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0308896735534794`, -1.620660493044881}],
            RowBox[{"{", 
              
              RowBox[{"30.099999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.252295633626107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.620660493044881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.105114229417701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "Discard", 1, {
              Complex[3.252295633626107, -1.620660493044881], 
              Complex[1.105114229417701, -3.0839932121918214`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.110702980036313, -1.6206604930448811`}],
            RowBox[{"{", 
              
              RowBox[{"30.099999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.110702980036313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6206604930448811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1051142294177012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0839932121918214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "Discard", 2, {
              Complex[0.110702980036313, -1.6206604930448811`], 
              Complex[1.1051142294177012`, -3.0839932121918214`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.03143740023572, -1.6230351927192315`}],
            RowBox[{"{", 
              
              RowBox[{"30.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.251747906943866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.10399213090529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.086370178675715`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "Discard", 1, {
              Complex[3.251747906943866, -1.6230351927192315`], 
              Complex[1.10399213090529, -3.086370178675715]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.11015525335407254`, -1.6230351927192315`}],
            RowBox[{"{", 
              
              RowBox[{"30.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.11015525335407254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6230351927192315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1039921309052896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0863701786757147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "Discard", 2, {
              Complex[0.11015525335407254`, -1.6230351927192315`], 
              Complex[1.1039921309052896`, -3.0863701786757147`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0319797520262664`, -1.6253966745436454`}],
            RowBox[{"{", 
              
              RowBox[{"30.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.25120555515332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6253966745436454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1028771430772724`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0887352297776514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "Discard", 1, {
              Complex[3.25120555515332, -1.6253966745436454`], 
              Complex[1.1028771430772724`, -3.0887352297776514`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1096129015635269, -1.6253966745436466`}],
            RowBox[{"{", 
              
              RowBox[{"30.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1096129015635269`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6253966745436466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.102877143077272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0887352297776527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "Discard", 2, {
              Complex[0.1096129015635269, -1.6253966745436466`], 
              Complex[1.102877143077272, -3.0887352297776527`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0325168102892874`, -1.6277450889951866`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.250668496890299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0910884995669843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "Discard", 1, {
              Complex[3.250668496890299, -1.6277450889951866`], 
              Complex[1.1017691747325018`, -3.0910884995669843`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10907584330050497`, -1.6277450889951857`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10907584330050497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6277450889951857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1017691747325018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.091088499566983`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "Discard", 2, {
              Complex[0.10907584330050497`, -1.6277450889951857`], 
              Complex[1.1017691747325018`, -3.091088499566983]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.033048654700508, -1.6300805839344696`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2501366524790782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6300805839344696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1006681364321238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.093430119759536`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "Discard", 1, {
              Complex[3.2501366524790782`, -1.6300805839344696`], 
              Complex[1.1006681364321238`, -3.093430119759536]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10854399888928548`, -1.6300805839344692`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10854399888928548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6300805839344692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.1006681364321256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0934301197595353`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "Discard", 2, {
              Complex[0.10854399888928548`, -1.6300805839344692`], 
              Complex[1.1006681364321256`, -3.0934301197595353`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.033575363292028, -1.6324033046672912`}],
            RowBox[{"{", 
              
              RowBox[{"30.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2496099438875583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6324033046672912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0995739404543334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "Discard", 1, {
              Complex[3.2496099438875583`, -1.6324033046672912`], 
              Complex[1.0995739404543334`, -3.095760219773794]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10801729029776416`, -1.6324033046672906`}],
            RowBox[{"{", 
              
              RowBox[{"30.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10801729029776416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6324033046672906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0995739404543337`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.095760219773794`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "Discard", 2, {
              Complex[0.10801729029776416`, -1.6324033046672906`], 
              Complex[1.0995739404543337`, -3.095760219773794]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0340970124956996`, -1.6347133940043952`}],
            RowBox[{"{", 
              
              RowBox[{"30.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2490882946838866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6347133940043952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0984865007505693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.098078926785381`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "Discard", 1, {
              Complex[3.2490882946838866`, -1.6347133940043952`], 
              Complex[1.0984865007505693`, -3.098078926785381]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10749564109409336`, -1.6347133940043936`}],
            RowBox[{"{", 
              
              RowBox[{"30.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10749564109409336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6347133940043936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.09848650075057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.09807892678538`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "Discard", 2, {
              Complex[0.10749564109409336`, -1.6347133940043936`], 
              Complex[1.09848650075057, -3.09807892678538]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.034613677185099, -1.6370109923194756`}],
            RowBox[{"{", 
              
              RowBox[{"30.799999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2485716299944873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0974057329031106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1003863657798956`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "Discard", 1, {
              Complex[3.2485716299944873`, -1.6370109923194756`], 
              Complex[1.0974057329031106`, -3.1003863657798956`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10697897640469432`, -1.6370109923194756`}],
            RowBox[{"{", 
              
              RowBox[{"30.799999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10697897640469432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6370109923194756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0974057329031108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.100386365779895`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "Discard", 2, {
              Complex[0.10697897640469432`, -1.6370109923194756`], 
              Complex[1.0974057329031108`, -3.100386365779895]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0351254307161493`, -1.6392962376054834`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.248059876463437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6392962376054834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041888`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "Discard", 1, {
              Complex[3.248059876463437, -1.6392962376054834`], 
              Complex[1.0963315540840044`, -3.1026826596041888`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1064672228736436, -1.6392962376054825`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1064672228736436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6392962376054825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0963315540840044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1026826596041883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "Discard", 2, {
              Complex[0.1064672228736436, -1.6392962376054825`], 
              Complex[1.0963315540840044`, -3.1026826596041883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0356323449664577`, -1.64156926552927}],
            RowBox[{"{", 
              
              RowBox[{"30.999999999999993`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2475529622131285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.09526388301527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.104967929016112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "Discard", 1, {
              Complex[3.2475529622131285`, -1.64156926552927], 
              Complex[1.09526388301527, -3.104967929016112]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10596030862333504`, -1.64156926552927}],
            RowBox[{"{", 
              
              RowBox[{"30.999999999999993`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10596030862333504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.64156926552927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0952638830152697`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.104967929016111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "Discard", 2, {
              Complex[0.10596030862333504`, -1.64156926552927], 
              Complex[1.0952638830152697`, -3.104967929016111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0361344903733976`, -1.6438302094846542`}],
            RowBox[{"{", 
              
              RowBox[{"31.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2470508168061887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6438302094846542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0942026399303626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.107242292732799`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "Discard", 1, {
              Complex[3.2470508168061887`, -1.6438302094846542`], 
              Complex[1.0942026399303626`, -3.107242292732799]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10545816321639523`, -1.643830209484655}],
            RowBox[{"{", 
              
              RowBox[{"31.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10545816321639523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.643830209484655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0942026399303617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1072422927328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "Discard", 2, {
              Complex[0.10545816321639523`, -1.643830209484655], 
              Complex[1.0942026399303617`, -3.1072422927328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0366319359709966`, -1.6460792006439566`}],
            RowBox[{"{", 
              
              RowBox[{"31.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2465533712085897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6460792006439566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0931477465368076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.109505867477551`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "Discard", 1, {
              Complex[3.2465533712085897`, -1.6460792006439566`], 
              Complex[1.0931477465368076`, -3.109505867477551]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10496071761879634`, -1.646079200643956}],
            RowBox[{"{", 
              
              RowBox[{"31.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10496071761879634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.646079200643956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.093147746536808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.10950586747755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "Discard", 2, {
              Complex[0.10496071761879634`, -1.646079200643956], 
              Complex[1.093147746536808, -3.10950586747755]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0371247494256686`, -1.648316368008041}],
            RowBox[{"{", 
              
              RowBox[{"31.299999999999997`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2460605577539177`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648316368008041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0920991259800008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.111758768025328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "Discard", 1, {
              Complex[3.2460605577539177`, -1.648316368008041], 
              Complex[1.0920991259800008`, -3.111758768025328]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10446790416412378`, -1.6483163680080417`}],
            RowBox[{"{", 
              
              RowBox[{"31.299999999999997`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10446790416412378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6483163680080417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0920991259799997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1117587680253287`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "Discard", 2, {
              Complex[0.10446790416412378`, -1.6483163680080417`], 
              Complex[1.0920991259799997`, -3.1117587680253287`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0376129970708368`, -1.6505418384549597`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2455723101087495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6505418384549597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0910567028080993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "Discard", 1, {
              Complex[3.2455723101087495`, -1.6505418384549597`], 
              Complex[1.0910567028080993`, -3.114001107246972]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10397965651895658`, -1.65054183845496}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10397965651895658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.65054183845496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0910567028080986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.114001107246972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "Discard", 2, {
              Complex[0.10397965651895658`, -1.65054183845496], 
              Complex[1.0910567028080986`, -3.114001107246972]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.038096743940479, -1.6527557367871826`}],
            RowBox[{"{", 
              
              RowBox[{"31.499999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2450885632391073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6527557367871826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0900204029379934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "Discard", 1, {
              Complex[3.2450885632391073`, -1.6527557367871826`], 
              Complex[1.0900204029379934`, -3.116232996152112]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10349590964931504`, -1.652755736787182}],
            RowBox[{"{", 
              
              RowBox[{"31.499999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10349590964931504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.652755736787182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0900204029379945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.116232996152111`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "Discard", 2, {
              Complex[0.10349590964931504`, -1.652755736787182], 
              Complex[1.0900204029379945`, -3.116232996152111]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.038576053801649, -1.6549581857775257`}],
            RowBox[{"{", 
              
              RowBox[{"31.599999999999998`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2446092533779374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6549581857775257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.088990153622295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1184545439308806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "Discard", 1, {
              Complex[3.2446092533779374`, -1.6549581857775257`], 
              Complex[1.088990153622295, -3.1184545439308806`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10301659978814422`, -1.6549581857775262`}],
            RowBox[{"{", 
              
              RowBox[{"31.599999999999998`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10301659978814422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6549581857775262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0889901536222948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.118454543930881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "Discard", 2, {
              Complex[0.10301659978814422`, -1.6549581857775262`], 
              Complex[1.0889901536222948`, -3.118454543930881]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.039050989186004, -1.6571493062137856`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2441343179935824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0879658834173163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944384`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "Discard", 1, {
              Complex[3.2441343179935824`, -1.6571493062137856`], 
              Complex[1.0879658834173163`, -3.1206658579944384`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.1025416644037889, -1.6571493062137859`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.1025416644037889`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6571493062137859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0879658834173156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1206658579944393`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "Discard", 2, {
              Complex[0.1025416644037889, -1.6571493062137859`], 
              Complex[1.0879658834173156`, -3.1206658579944393`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0395216114203656`, -1.6593292169421239`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2436636957592206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1228670440143484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "Discard", 1, {
              Complex[3.2436636957592206`, -1.6593292169421239`], 
              Complex[1.0869475221520086`, -3.1228670440143484`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10207104216942726`, -1.6593292169421239`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10207104216942726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6593292169421239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0869475221520086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.122867044014348`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "Discard", 2, {
              Complex[0.10207104216942726`, -1.6593292169421239`], 
              Complex[1.0869475221520086`, -3.122867044014348]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.039987980656365, -1.6614980349092643`}],
            RowBox[{"{", 
              
              RowBox[{"31.899999999999995`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2431973265232212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6614980349092643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0859350008978244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "Discard", 1, {
              Complex[3.2431973265232212`, -1.6614980349092643`], 
              Complex[1.0859350008978244`, -3.1250582059608574`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10160467293342826`, -1.6614980349092632`}],
            RowBox[{"{", 
              
              RowBox[{"31.899999999999995`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10160467293342826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6614980349092632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0859350008978255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1250582059608565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "Discard", 2, {
              Complex[0.10160467293342826`, -1.6614980349092632`], 
              Complex[1.0859350008978255`, -3.1250582059608565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.040450155899195, -1.6636558752035226`}],
            RowBox[{"{", 
              
              RowBox[{"31.999999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.242735151280391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.084928251939455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.127239446140108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "Discard", 1, {
              Complex[3.242735151280391, -1.6636558752035226`], 
              Complex[1.084928251939455, -3.127239446140108]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10114249769059809`, -1.6636558752035224`}],
            RowBox[{"{", 
              
              RowBox[{"31.999999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10114249769059809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6636558752035224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0849282519394552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1272394461401083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "Discard", 2, {
              Complex[0.10114249769059809`, -1.6636558752035224`], 
              Complex[1.0849282519394552`, -3.1272394461401083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0409081950355055`, -1.6658028510947214`}],
            RowBox[{"{", 
              
              RowBox[{"32.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2422771121440808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6658028510947214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303243`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "Discard", 1, {
              Complex[3.2422771121440808`, -1.6658028510947214`], 
              Complex[1.083927208746434, -3.1294108652303243`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10068445855428786`, -1.6658028510947218`}],
            RowBox[{"{", 
              
              RowBox[{"32.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10068445855428786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6658028510947218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.083927208746434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1294108652303256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "Discard", 2, {
              Complex[0.10068445855428786`, -1.6658028510947218`], 
              Complex[1.083927208746434, -3.1294108652303256`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.041362154860465, -1.6679390740730151`}],
            RowBox[{"{", 
              
              RowBox[{"32.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2418231523191214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6679390740730151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "Discard", 1, {
              Complex[3.2418231523191214`, -1.6679390740730151`], 
              Complex[1.082931805945569, -3.1315725623170003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.10023049872932865`, -1.6679390740730153`}],
            RowBox[{"{", 
              
              RowBox[{"32.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.10023049872932865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6679390740730153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.082931805945569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1315725623170003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "Discard", 2, {
              Complex[0.10023049872932865`, -1.6679390740730153`], 
              Complex[1.082931805945569, -3.1315725623170003`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.041812091104027, -1.6700646538866692`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.241373216075559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927122`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "Discard", 1, {
              Complex[3.241373216075559, -1.6700646538866692`], 
              Complex[1.0819419792941676`, -3.133724634927122]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09978056248576549, -1.6700646538866686`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09978056248576549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6700646538866686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0819419792941676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.133724634927121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "Discard", 2, {
              Complex[0.09978056248576549, -1.6700646538866686`], 
              Complex[1.0819419792941676`, -3.133724634927121]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.042258058456428, -1.6721796985788306`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.240927248723158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624704`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "Discard", 1, {
              Complex[3.240927248723158, -1.6721796985788306`], 
              Complex[1.0809576656540323`, -3.1358671790624704`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09933459513336479, -1.6721796985788298`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09933459513336479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721796985788298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0809576656540323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1358671790624695`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "Discard", 2, {
              Complex[0.09933459513336479, -1.6721796985788298`], 
              Complex[1.0809576656540323`, -3.1358671790624695`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0427001105929303`, -1.6742843145233057`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.240485196586656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6742843145233057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0799788029662047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138000289232015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "Discard", 1, {
              Complex[3.240485196586656, -1.6742843145233057`], 
              Complex[1.0799788029662047`, -3.138000289232015]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0988925429968627, -1.6742843145233064`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0988925429968627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6742843145233064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.079978802966205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.138000289232016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "Discard", 2, {
              Complex[0.0988925429968627, -1.6742843145233064`], 
              Complex[1.079978802966205, -3.138000289232016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0431383001978567`, -1.6763786064594062`}],
            RowBox[{"{", 
              
              RowBox[{"32.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2400470069817295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6763786064594062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.079005330226425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.140124058483446`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "Discard", 1, {
              Complex[3.2400470069817295`, -1.6763786064594062`], 
              Complex[1.079005330226425, -3.140124058483446]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09845435339193638, -1.6763786064594066`}],
            RowBox[{"{", 
              
              RowBox[{"32.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09845435339193638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6763786064594066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0790053302264244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1401240584834467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "Discard", 2, {
              Complex[0.09845435339193638, -1.6763786064594066`], 
              Complex[1.0790053302264244`, -3.1401240584834467`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0435726789879247`, -1.6784626775258558`}],
            RowBox[{"{", 
              
              RowBox[{"32.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2396126281916615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6784626775258558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0780371874612853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "Discard", 1, {
              Complex[3.2396126281916615`, -1.6784626775258558`], 
              Complex[1.0780371874612853`, -3.1422385784338522`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09801997460186761, -1.6784626775258555`}],
            RowBox[{"{", 
              
              RowBox[{"32.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09801997460186761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6784626775258555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0780371874612855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1422385784338505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "Discard", 2, {
              Complex[0.09801997460186761, -1.6784626775258555`], 
              Complex[1.0780371874612855`, -3.1422385784338505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0440032977349136`, -1.6805366292938222`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2391820094446726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6805366292938222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0770743157050588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.144343939299593`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "Discard", 1, {
              Complex[3.2391820094446726`, -1.6805366292938222`], 
              Complex[1.0770743157050588`, -3.144343939299593]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09758935585487952, -1.6805366292938224`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09758935585487952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6805366292938224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0770743157050577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1443439392995933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "Discard", 2, {
              Complex[0.09758935585487952, -1.6805366292938224`], 
              Complex[1.0770743157050577`, -3.1443439392995933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0444302062876805`, -1.6826005617990878`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2387551008919058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6826005617990878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.076116656977162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1464402299253895`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "Discard", 1, {
              Complex[3.2387551008919058`, -1.6826005617990878`], 
              Complex[1.076116656977162, -3.1464402299253895`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09716244730211258, -1.682600561799087}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09716244730211258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.682600561799087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0761166569771627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1464402299253886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "Discard", 2, {
              Complex[0.09716244730211258, -1.682600561799087], 
              Complex[1.0761166569771627`, -3.1464402299253886`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.044853453593553, -1.6846545735733742`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.238331853586033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6846545735733742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.075164154260271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.148527537812633`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "Discard", 1, {
              Complex[3.238331853586033, -1.6846545735733742`], 
              Complex[1.075164154260271, -3.148527537812633]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09673919999623987, -1.684654573573374}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09673919999623987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.684654573573374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0751641542602708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1485275378126323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "Discard", 2, {
              Complex[0.09673919999623987, -1.684654573573374], 
              Complex[1.0751641542602708`, -3.1485275378126323`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.045273087719118, -1.686698761674875}],
            RowBox[{"{", 
              
              RowBox[{"33.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237912219460468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.686698761674875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.15060594914697`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "Discard", 1, {
              Complex[3.237912219460468, -1.686698761674875], 
              Complex[1.0742167514790106`, -3.15060594914697]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0963195658706748, -1.6866987616748745`}],
            RowBox[{"{", 
              
              RowBox[{"33.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0963195658706748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6866987616748745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0742167514790106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1506059491469687`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "Discard", 2, {
              Complex[0.0963195658706748, -1.6866987616748745`], 
              Complex[1.0742167514790106`, -3.1506059491469687`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0456891558704204`, -1.6887332217179927`}],
            RowBox[{"{", 
              
              RowBox[{"33.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237496151309166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6887332217179927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0732743934792588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.152675548825165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "Discard", 1, {
              Complex[3.237496151309166, -1.6887332217179927`], 
              Complex[1.0732743934792588`, -3.152675548825165]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09590349771937258, -1.688733221717992}],
            RowBox[{"{", 
              
              RowBox[{"33.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09590349771937258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.688733221717992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0732743934792583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1526755488251643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "Discard", 2, {
              Complex[0.09590349771937258, -1.688733221717992], 
              Complex[1.0732743934792583`, -3.1526755488251643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0461017044126044`, -1.6907580479023252`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.237083602766982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0723370260079925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.154736420481273`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "Discard", 1, {
              Complex[3.237083602766982, -1.6907580479023252`], 
              Complex[1.0723370260079925`, -3.154736420481273]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09549094917718823, -1.6907580479023245`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09549094917718823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6907580479023245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.072337026007993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1547364204812727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "Discard", 2, {
              Complex[0.09549094917718823, -1.6907580479023245`], 
              Complex[1.072337026007993, -3.1547364204812727`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.046510778889002, -1.6927733330409118`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2366745282905844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6927733330409118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.071404595693708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "Discard", 1, {
              Complex[3.2366745282905844`, -1.6927733330409118`], 
              Complex[1.071404595693708, -3.156788646512134]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09508187470079153, -1.6927733330409114`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09508187470079153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6927733330409114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0714045956937088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.156788646512134`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "Discard", 2, {
              Complex[0.09508187470079153, -1.6927733330409114`], 
              Complex[1.0714045956937088`, -3.156788646512134]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0469164240396958`, -1.694779168587776}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2362688831398905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.694779168587776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0704770500273408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.158832308102228`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "Discard", 1, {
              Complex[3.2362688831398905`, -1.694779168587776], 
              Complex[1.0704770500273408`, -3.158832308102228]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09467622955009732, -1.6947791685877762`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09467622955009732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6947791685877762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0704770500273406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1588323081022285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "Discard", 2, {
              Complex[0.09467622955009732, -1.6947791685877762`], 
              Complex[1.0704770500273406`, -3.1588323081022285`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.04731868381957, -1.6967756446647662`}],
            RowBox[{"{", 
              
              RowBox[{"33.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.235866623360016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6967756446647662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0695543373437264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1608674852478886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "Discard", 1, {
              Complex[3.235866623360016, -1.6967756446647662`], 
              Complex[1.0695543373437264`, -3.1608674852478886`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0942739697702223, -1.6967756446647657`}],
            RowBox[{"{", 
              
              RowBox[{"33.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0942739697702223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6967756446647657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.069554337343726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1608674852478877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "Discard", 2, {
              Complex[0.0942739697702223, -1.6967756446647657`], 
              Complex[1.069554337343726, -3.1608674852478877`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.04771760141587, -1.6987628500877325`}],
            RowBox[{"{", 
              
              RowBox[{"33.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2354677057637162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6987628500877325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.068636406803538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.162894256780908`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "Discard", 1, {
              Complex[3.2354677057637162`, -1.6987628500877325`], 
              Complex[1.068636406803538, -3.162894256780908]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09387505217392343, -1.6987628500877328`}],
            RowBox[{"{", 
              
              RowBox[{"33.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09387505217392343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6987628500877328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0686364068035386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1628942567809086`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "Discard", 2, {
              Complex[0.09387505217392343, -1.6987628500877328`], 
              Complex[1.0686364068035386`, -3.1628942567809086`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.048113219265274, -1.7007408723920572`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2350720879143124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7007408723920572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0677232083757224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "Discard", 1, {
              Complex[3.2350720879143124`, -1.7007408723920572`], 
              Complex[1.0677232083757224`, -3.1649127003915547`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09347943432451934, -1.700740872392058}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09347943432451934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.700740872392058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0677232083757218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1649127003915565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "Discard", 2, {
              Complex[0.09347943432451934, -1.700740872392058], 
              Complex[1.0677232083757218`, -3.1649127003915565`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0485055790705142`, -1.7027097978575507`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.234679728109072`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7027097978575507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0668146928203772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1669228926510127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "Discard", 1, {
              Complex[3.234679728109072, -1.7027097978575507`], 
              Complex[1.0668146928203772`, -3.1669228926510127`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0930870745192786, -1.7027097978575496`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0930870745192786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7027097978575496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0668146928203786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.166922892651011`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "Discard", 2, {
              Complex[0.0930870745192786, -1.7027097978575496`], 
              Complex[1.0668146928203786`, -3.166922892651011]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0488947218165396`, -1.7046697115327338`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2342905853630466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.065910811672111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1689249090332523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "Discard", 1, {
              Complex[3.2342905853630466`, -1.7046697115327338`], 
              Complex[1.065910811672111, -3.1689249090332523`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0926979317732518, -1.7046697115327327`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0926979317732518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7046697115327327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0659108116721088`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.168924909033252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "Discard", 2, {
              Complex[0.0926979317732518, -1.7046697115327327`], 
              Complex[1.0659108116721088`, -3.168924909033252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0492806877862537`, -1.7066206972585347`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2339046193933325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0650115172238024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "Discard", 1, {
              Complex[3.2339046193933325`, -1.7066206972585347`], 
              Complex[1.0650115172238024`, -3.170918823936388]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09231196580353926, -1.7066206972585347`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09231196580353926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7066206972585347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0650115172238028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.170918823936388`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "Discard", 2, {
              Complex[0.09231196580353926, -1.7066206972585347`], 
              Complex[1.0650115172238028`, -3.170918823936388]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.049663516575818, -1.7085628376914088`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2335217906037683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7085628376914088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0641167625108199`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "Discard", 1, {
              Complex[3.2335217906037683`, -1.7085628376914088`], 
              Complex[1.0641167625108199`, -3.1729047107034827`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09192913701397513, -1.7085628376914086`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09192913701397513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7085628376914086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.06411676251082`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1729047107034827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "Discard", 2, {
              Complex[0.09192913701397513, -1.7085628376914086`], 
              Complex[1.06411676251082, -3.1729047107034827`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.050043247109565, -1.7104962143258888`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2331420600700214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7104962143258888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0632265012956237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1748826416428573`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "Discard", 1, {
              Complex[3.2331420600700214`, -1.7104962143258888`], 
              Complex[1.0632265012956237`, -3.1748826416428573`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09154940648022836, -1.7104962143258893`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09154940648022836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7104962143258893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.063226501295623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.174882641642858`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "Discard", 2, {
              Complex[0.09154940648022836, -1.7104962143258893`], 
              Complex[1.063226501295623, -3.174882641642858]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.050419917654507, -1.712420907516613}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2327653895250794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.712420907516613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0623406880527706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1768526880479087`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "Discard", 1, {
              Complex[3.2327653895250794`, -1.712420907516613], 
              Complex[1.0623406880527706`, -3.1768526880479087`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0911727359352858, -1.7124209075166128`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0911727359352858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7124209075166128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.06234068805277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.176852688047909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "Discard", 2, {
              Complex[0.0911727359352858, -1.7124209075166128`], 
              Complex[1.06234068805277, -3.176852688047909]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.050793565834466, -1.7143369964998079`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23239174134512`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7143369964998079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0614592779543162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "Discard", 1, {
              Complex[3.23239174134512, -1.7143369964998079`], 
              Complex[1.0614592779543162`, -3.1788149202164426`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09079908775532702, -1.714336996499808}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09079908775532702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.714336996499808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0614592779543155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1788149202164435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "Discard", 2, {
              Complex[0.09079908775532702, -1.714336996499808], 
              Complex[1.0614592779543155`, -3.1788149202164435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.051164228643832, -1.7162445594142668`}],
            RowBox[{"{", 
              
              RowBox[{"34.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2320210785357544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7162445594142668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0605822268555747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.180769407469538`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "Discard", 1, {
              Complex[3.2320210785357544`, -1.7162445594142668`], 
              Complex[1.0605822268555747`, -3.180769407469538]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.09042842494596093, -1.7162445594142677`}],
            RowBox[{"{", 
              
              RowBox[{"34.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.09042842494596093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7162445594142677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.060582226855574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1807694074695387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "Discard", 2, {
              Complex[0.09042842494596093, -1.7162445594142677`], 
              Complex[1.060582226855574, -3.1807694074695387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.051531942460964, -1.7181436733218398`}],
            RowBox[{"{", 
              
              RowBox[{"34.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.231653364718622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0597094912812492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1827162181699684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "Discard", 1, {
              Complex[3.231653364718622, -1.7181436733218398`], 
              Complex[1.0597094912812492`, -3.1827162181699684`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.090060711128834, -1.7181436733218531`}],
            RowBox[{"{", 
              
              RowBox[{"34.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.090060711128834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7181436733218531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.05970949128125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1827162181699844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "Discard", 2, {
              Complex[0.090060711128834, -1.7181436733218531`], 
              Complex[1.05970949128125, -3.1827162181699844`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.051896743061245, -1.7200344142274249`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.231288564118341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0588410284119094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.184655419740182`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "Discard", 1, {
              Complex[3.231288564118341, -1.7200344142274249`], 
              Complex[1.0588410284119094`, -3.184655419740182]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08969591052854747, -1.7200344142274246`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08969591052854747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7200344142274246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.058841028411909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.18465541974018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "Discard", 2, {
              Complex[0.08969591052854747, -1.7200344142274246`], 
              Complex[1.058841028411909, -3.18465541974018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0522586656297954`, -1.7219168570985053`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.230926641549791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7219168570985053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0579767960708073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1865870786798474`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "Discard", 1, {
              Complex[3.230926641549791, -1.7219168570985053`], 
              Complex[1.0579767960708073`, -3.1865870786798474`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0893339879599975, -1.721916857098505}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0893339879599975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.721916857098505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0579767960708075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.186587078679847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "Discard", 2, {
              Complex[0.0893339879599975, -1.721916857098505], 
              Complex[1.0579767960708075`, -3.186587078679847]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0526177447738645`, -1.7237910758842263`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2305675624057217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7237910758842263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.057116752711029`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.188511260583004`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "Discard", 1, {
              Complex[3.2305675624057217`, -1.7237910758842263`], 
              Complex[1.057116752711029, -3.188511260583004]}, 0}, "Tooltip"]& ]\
}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08897490881592815, -1.7237910758842274`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08897490881592815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7237910758842274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0571167527110277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1885112605830046`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "Discard", 2, {
              Complex[0.08897490881592815, -1.7237910758842274`], 
              Complex[1.0571167527110277`, -3.1885112605830046`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.052974014534905, -1.7256571435340284`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.230211292644681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7256571435340284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.056260857402957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.190428030154787`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "Discard", 1, {
              Complex[3.230211292644681, -1.7256571435340284`], 
              Complex[1.056260857402957, -3.190428030154787]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08861863905488769, -1.725657143534028}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08861863905488769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.725657143534028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0562608574029573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.190428030154786`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "Discard", 2, {
              Complex[0.08861863905488769, -1.725657143534028], 
              Complex[1.0562608574029573`, -3.190428030154786]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0533275084003355`, -1.727515132015845}],
            RowBox[{"{", 
              
              RowBox[{"35.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2298577987792507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.727515132015845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0554090698220604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1923374512277776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "Discard", 1, {
              Complex[3.2298577987792507`, -1.727515132015845], 
              Complex[1.0554090698220604`, -3.1923374512277776`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08826514518945743, -1.727515132015846}],
            RowBox[{"{", 
              
              RowBox[{"35.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08826514518945743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.727515132015846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.055409069822059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1923374512277785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "Discard", 2, {
              Complex[0.08826514518945743, -1.727515132015846], 
              Complex[1.055409069822059, -3.1923374512277785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0536782593150105`, -1.7293651123339018`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2295070478645758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0545613502369586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "Discard", 1, {
              Complex[3.2295070478645758`, -1.7293651123339018`], 
              Complex[1.0545613502369586`, -3.1942395867779743`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08791439427478234, -1.7293651123339018`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08791439427478234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7293651123339018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0545613502369584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1942395867779743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "Discard", 2, {
              Complex[0.08791439427478234, -1.7293651123339018`], 
              Complex[1.0545613502369584`, -3.1942395867779743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.054026299692401, -1.7312071545460794`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.229159007487185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7312071545460794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0537176594978062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.196134498940377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "Discard", 1, {
              Complex[3.229159007487185, -1.7312071545460794`], 
              Complex[1.0537176594978062`, -3.196134498940377]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08756635389739194, -1.73120715454608}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08756635389739194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.73120715454608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0537176594978057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1961344989403777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "Discard", 2, {
              Complex[0.08756635389739194, -1.73120715454608], 
              Complex[1.0537176594978057`, -3.1961344989403777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.05437166142549, -1.7330413277809138`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.228813645754096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7330413277809138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.052877959024942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1980222490242434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "Discard", 1, {
              Complex[3.228813645754096, -1.7330413277809138`], 
              Complex[1.052877959024942, -3.1980222490242434`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08722099216430315, -1.733041327780913}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08722099216430315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.733041327780913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0528779590249415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1980222490242425`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "Discard", 2, {
              Complex[0.08722099216430315, -1.733041327780913], 
              Complex[1.0528779590249415`, -3.1980222490242425`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0547143758974, -1.7348677002541815`}],
            RowBox[{"{", 
              
              RowBox[{"35.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.228470931282186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.052042210797825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.1999028975279598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "Discard", 1, {
              Complex[3.228470931282186, -1.7348677002541815`], 
              Complex[1.052042210797825, -3.1999028975279598`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.086878277692393, -1.7348677002541821`}],
            RowBox[{"{", 
              
              RowBox[{"35.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.086878277692393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7348677002541821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0520422107978245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.199902897527961`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "Discard", 2, {
              Complex[0.086878277692393, -1.7348677002541821`], 
              Complex[1.0520422107978245`, -3.199902897527961]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0550544739917567`, -1.736686339285139}],
            RowBox[{"{", 
              
              RowBox[{"35.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2281308331878296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.736686339285139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0512103773442272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153611`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "Discard", 1, {
              Complex[3.2281308331878296`, -1.736686339285139], 
              Complex[1.0512103773442272`, -3.201776504153611]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08653817959803752, -1.7366863392851428`}],
            RowBox[{"{", 
              
              RowBox[{"35.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08653817959803752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7366863392851428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0512103773442263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.201776504153616`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "Discard", 2, {
              Complex[0.08653817959803752, -1.7366863392851428`], 
              Complex[1.0512103773442263`, -3.201776504153616]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0553919861027934`, -1.7384973113123774`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227793321076793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0503824217296989`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211888`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "Discard", 1, {
              Complex[3.227793321076793, -1.7384973113123774`], 
              Complex[1.0503824217296989`, -3.2036431278211888`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08620066748699956, -1.7384973113123776`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08620066748699956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7384973113123776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0503824217296986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2036431278211883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "Discard", 2, {
              Complex[0.08620066748699956, -1.7384973113123776`], 
              Complex[1.0503824217296986`, -3.2036431278211883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0557269421452093`, -1.7403006819093283`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227458365034377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0495583075472772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.20550282668249`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "Discard", 1, {
              Complex[3.227458365034377, -1.7403006819093283`], 
              Complex[1.0495583075472772`, -3.20550282668249]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08586571144458416, -1.7403006819093272`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08586571144458416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7403006819093272`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0495583075472783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2055028266824883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "Discard", 2, {
              Complex[0.08586571144458416, -1.7403006819093272`], 
              Complex[1.0495583075472783`, -3.2055028266824883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.056059371563784, -1.7420965157994346`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.227125935615802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7420965157994346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134717`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "Discard", 1, {
              Complex[3.227125935615802, -1.7420965157994346`], 
              Complex[1.0487379989074426`, -3.207355658134717]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08553328202600917, -1.742096515799434}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08553328202600917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.742096515799434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0487379989074426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.207355658134716`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "Discard", 2, {
              Complex[0.08553328202600917, -1.742096515799434], 
              Complex[1.0487379989074426`, -3.207355658134716]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0563893033427596`, -1.7438848768709785`}],
            RowBox[{"{", 
              
              RowBox[{"36.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2267960038368266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7438848768709785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0479214604283111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "Discard", 1, {
              Complex[3.2267960038368266`, -1.7438848768709785`], 
              Complex[1.0479214604283111`, -3.209201678833752]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08520335024703361, -1.7438848768709778`}],
            RowBox[{"{", 
              
              RowBox[{"36.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08520335024703361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7438848768709778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0479214604283116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.209201678833752`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "Discard", 2, {
              Complex[0.08520335024703361, -1.7438848768709778`], 
              Complex[1.0479214604283116`, -3.209201678833752]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0567167660149925`, -1.7456658281915811`}],
            RowBox[{"{", 
              
              RowBox[{"36.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2264685411645937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7456658281915811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0471086572260642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "Discard", 1, {
              Complex[3.2264685411645937`, -1.7456658281915811`], 
              Complex[1.0471086572260642`, -3.2110409447071544`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08487588757480041, -1.7456658281915818`}],
            RowBox[{"{", 
              
              RowBox[{"36.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08487588757480041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7456658281915818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.047108657226064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2110409447071544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "Discard", 2, {
              Complex[0.08487588757480041, -1.7456658281915818`], 
              Complex[1.047108657226064, -3.2110409447071544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.057041787670887, -1.747439432022393}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.226143519508699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747439432022393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0462995549055958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.212873510966856`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "Discard", 1, {
              Complex[3.226143519508699, -1.747439432022393], 
              Complex[1.0462995549055958`, -3.212873510966856]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08455086591890591, -1.7474394320223927`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08455086591890591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474394320223927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.046299554905596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2128735109668556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "Discard", 2, {
              Complex[0.08455086591890591, -1.7474394320223927`], 
              Complex[1.046299554905596, -3.2128735109668556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0573643959671113`, -1.7492057498319644`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.225820911212475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7492057498319644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.045494119551384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2146994321215847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "Discard", 1, {
              Complex[3.225820911212475, -1.7492057498319644`], 
              Complex[1.045494119551384, -3.2146994321215847`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0842282576226818, -1.7492057498319649`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0842282576226818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7492057498319649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0454941195513836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2146994321215856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "Discard", 2, {
              Complex[0.0842282576226818, -1.7492057498319649`], 
              Complex[1.0454941195513836`, -3.2146994321215856`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0576846181351023`, -1.750964842309831}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.225500689044484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.750964842309831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0446923177185734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "Discard", 1, {
              Complex[3.225500689044484, -1.750964842309831], 
              Complex[1.0446923177185734`, -3.2165187619890245`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08390803545469033, -1.7509648423098307`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08390803545469033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7509648423098307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0446923177185725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2165187619890236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "Discard", 2, {
              Complex[0.08390803545469033, -1.7509648423098307`], 
              Complex[1.0446923177185725`, -3.2165187619890236`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0580024809893747`, -1.7527167693797805`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2251828261902116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7527167693797805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0438941164242628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2183315537076793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "Discard", 1, {
              Complex[3.2251828261902116`, -1.7527167693797805`], 
              Complex[1.0438941164242628`, -3.2183315537076793`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0835901726004175, -1.752716769379781}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0835901726004175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.752716769379781`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0438941164242617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.218331553707678`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "Discard", 2, {
              Complex[0.0835901726004175, -1.752716769379781], 
              Complex[1.0438941164242617`, -3.218331553707678]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0583180109356283`, -1.7544615902128715`}],
            RowBox[{"{", 
              
              RowBox[{"36.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.224867296243958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0430994831389901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2201378597485246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "Discard", 1, {
              Complex[3.224867296243958, -1.7544615902128715`], 
              Complex[1.0430994831389901`, -3.2201378597485246`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08327464265416494, -1.7544615902128715`}],
            RowBox[{"{", 
              
              RowBox[{"36.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08327464265416494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7544615902128715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.04309948313899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2201378597485255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "Discard", 2, {
              Complex[0.08327464265416494, -1.7544615902128715`], 
              Complex[1.04309948313899, -3.2201378597485255`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.058631233978658, -1.7561993632401343`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2245540732009284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7561993632401343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0423083857784268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "Discard", 1, {
              Complex[3.2245540732009284`, -1.7561993632401343`], 
              Complex[1.0423083857784268`, -3.2219377319263685`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08296141961113473, -1.7561993632401347`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08296141961113473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561993632401347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0423083857784274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2219377319263676`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "Discard", 2, {
              Complex[0.08296141961113473, -1.7561993632401347`], 
              Complex[1.0423083857784274`, -3.2219377319263676`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.058942175730091, -1.7579301461650294`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2242431314494953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7579301461650294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0415207926952428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2237312214109846`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "Discard", 1, {
              Complex[3.2242431314494953`, -1.7579301461650294`], 
              Complex[1.0415207926952428`, -3.2237312214109846`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08265047785970185, -1.7579301461650303`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08265047785970185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7579301461650303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0415207926952421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.223731221410986`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "Discard", 2, {
              Complex[0.08265047785970185, -1.7579301461650303`], 
              Complex[1.0415207926952421`, -3.223731221410986]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.05925086141593, -1.7596539959756308`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.223934445763656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7596539959756308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0407366726711693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "Discard", 1, {
              Complex[3.223934445763656, -1.7596539959756308`], 
              Complex[1.0407366726711693`, -3.225518378738008]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08234179217386196, -1.759653995975626}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08234179217386196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.759653995975626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0407366726711678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.225518378738005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "Discard", 2, {
              Complex[0.08234179217386196, -1.759653995975626], 
              Complex[1.0407366726711678`, -3.225518378738005]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.059557315883926, -1.7613709689565495`}],
            RowBox[{"{", 
              
              RowBox[{"37.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2236279912956602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7613709689565495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0399559949092407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "Discard", 1, {
              Complex[3.2236279912956602`, -1.7613709689565495`], 
              Complex[1.0399559949092407`, -3.227299253819592]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08203533770586706, -1.7613709689565493`}],
            RowBox[{"{", 
              
              RowBox[{"37.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08203533770586706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7613709689565493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0399559949092405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.227299253819592`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "Discard", 2, {
              Complex[0.08203533770586706, -1.7613709689565493`], 
              Complex[1.0399559949092405`, -3.227299253819592]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.059861563610779, -1.7630811207006185`}],
            RowBox[{"{", 
              
              RowBox[{"37.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.223323743568807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7630811207006185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.229073895954844`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "Discard", 1, {
              Complex[3.223323743568807, -1.7630811207006185`], 
              Complex[1.039178729026203, -3.229073895954844]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0817310899790139, -1.763081120700618}],
            RowBox[{"{", 
              
              RowBox[{"37.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0817310899790139`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.763081120700618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.039178729026203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2290738959548437`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "Discard", 2, {
              Complex[0.0817310899790139, -1.763081120700618], 
              Complex[1.039178729026203, -3.2290738959548437`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0601636287091716`, -1.7647845061203178`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2230216784704147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7647845061203178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0384048450451053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "Discard", 1, {
              Complex[3.2230216784704147`, -1.7647845061203178`], 
              Complex[1.0384048450451053`, -3.230842353840041]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08142902488062087, -1.7647845061203167`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08142902488062087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7647845061203167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0384048450451058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.230842353840039`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "Discard", 2, {
              Complex[0.08142902488062087, -1.7647845061203167`], 
              Complex[1.0384048450451058`, -3.230842353840039]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.060463534934643, -1.7664811794589748`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.222721772244943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0376343133880408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "Discard", 1, {
              Complex[3.222721772244943, -1.7664811794589748`], 
              Complex[1.0376343133880408`, -3.2326046755786235`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08112911865515363, -1.7664811794589725`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08112911865515363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7664811794589725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0376343133880443`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2326046755786213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "Discard", 2, {
              Complex[0.08112911865515363, -1.7664811794589725`], 
              Complex[1.0376343133880443`, -3.2326046755786213`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.060761305692297, -1.7681711943017286`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.222424001487289`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0368671048690654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.234360908690994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "Discard", 1, {
              Complex[3.222424001487289, -1.7681711943017286`], 
              Complex[1.0368671048690654`, -3.234360908690994]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08083134789749542, -1.7681711943017286`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08083134789749542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7681711943017286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0368671048690645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2343609086909946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "Discard", 2, {
              Complex[0.08083134789749542, -1.7681711943017286`], 
              Complex[1.0368671048690645`, -3.2343609086909946`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0610569640433716`, -1.769854603586262}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2221283431362147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.769854603586262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0361031906872582`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "Discard", 1, {
              Complex[3.2221283431362147`, -1.769854603586262], 
              Complex[1.0361031906872582`, -3.2361111001240945`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08053568954642111, -1.7698546035862615`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08053568954642111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7698546035862615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0361031906872573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2361111001240945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "Discard", 2, {
              Complex[0.08053568954642111, -1.7698546035862615`], 
              Complex[1.0361031906872573`, -3.2361111001240945`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.06135053271164, -1.7715314596133196`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.221834774467946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0353425424199543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "Discard", 1, {
              Complex[3.221834774467946, -1.7715314596133196`], 
              Complex[1.0353425424199543`, -3.2378552962607934`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.08024212087815223, -1.7715314596133194`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.08024212087815223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7715314596133194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0353425424199532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2378552962607934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "Discard", 2, {
              Complex[0.08024212087815223, -1.7715314596133194`], 
              Complex[1.0353425424199532`, -3.2378552962607934`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.061642034089688, -1.7732018140570123`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2215432730898983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7732018140570123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0345851320160955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2395935429290827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "Discard", 1, {
              Complex[3.2215432730898983`, -1.7732018140570123`], 
              Complex[1.0345851320160955`, -3.2395935429290827`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07995061950010503, -1.773201814057012}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07995061950010503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.773201814057012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.034585132016095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.239593542929082`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "Discard", 2, {
              Complex[0.07995061950010503, -1.773201814057012], 
              Complex[1.034585132016095, -3.239593542929082]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0619314902450245`, -1.7748657179749052`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2212538169345617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0338309317897683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.24132588541108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "Discard", 1, {
              Complex[3.2212538169345617`, -1.7748657179749052`], 
              Complex[1.0338309317897683`, -3.24132588541108]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0796611633447683, -1.7748657179749043`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0796611633447683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7748657179749043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0338309317897687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2413258854110794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "Discard", 2, {
              Complex[0.0796611633447683, -1.7748657179749043`], 
              Complex[1.0338309317897687`, -3.2413258854110794`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.062218922926084, -1.7765232218179048`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.220966384253502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7765232218179048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0330799144138363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2430523684518433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "Discard", 1, {
              Complex[3.220966384253502, -1.7765232218179048`], 
              Complex[1.0330799144138363`, -3.2430523684518433`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07937373066370935, -1.776523221817905}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07937373066370935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.776523221817905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0330799144138367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.243052368451844`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "Discard", 2, {
              Complex[0.07937373066370935, -1.776523221817905], 
              Complex[1.0330799144138367`, -3.243052368451844]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.062504353568067, -1.7781743754399488`}],
            RowBox[{"{", 
              
              RowBox[{"38.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2206809536115193`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7781743754399488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "Discard", 1, {
              Complex[3.2206809536115193`, -1.7781743754399488`], 
              Complex[1.0323320529137487`, -3.2447730362680187`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07908830002172706, -1.7781743754399495`}],
            RowBox[{"{", 
              
              RowBox[{"38.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07908830002172706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7781743754399495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0323320529137487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2447730362680205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "Discard", 2, {
              Complex[0.07908830002172706, -1.7781743754399495`], 
              Complex[1.0323320529137487`, -3.2447730362680205`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.062787803298667, -1.7798192281074985`}],
            RowBox[{"{", 
              
              RowBox[{"38.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2203975038809194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325563003`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "Discard", 1, {
              Complex[3.2203975038809194`, -1.7798192281074985`], 
              Complex[1.0315873206614592`, -3.2464879325563003`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07880485029112587, -1.7798192281074985`}],
            RowBox[{"{", 
              
              RowBox[{"38.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07880485029112587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7798192281074985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0315873206614592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2464879325562994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "Discard", 2, {
              Complex[0.07880485029112587, -1.7798192281074985`], 
              Complex[1.0315873206614592`, -3.2464879325562994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.063069292943669, -1.7814578285088363`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2201160142359173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7814578285088363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.030845691369485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.248197100501716`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "Discard", 1, {
              Complex[3.2201160142359173`, -1.7814578285088363`], 
              Complex[1.030845691369485, -3.248197100501716]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07852336064612488, -1.781457828508837}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07852336064612488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.781457828508837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0308456913694903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2481971005017125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "Discard", 2, {
              Complex[0.07852336064612488, -1.781457828508837], 
              Complex[1.0308456913694903`, -3.2481971005017125`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.063348843032417, -1.78309022476319}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.219836464147169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.78309022476319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0301071390850915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.249900582785768`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "Discard", 1, {
              Complex[3.219836464147169, -1.78309022476319], 
              Complex[1.0301071390850915`, -3.249900582785768]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07824381055737564, -1.7830902247631892`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07824381055737564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7830902247631892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.030107139085092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.249900582785767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "Discard", 2, {
              Complex[0.07824381055737564, -1.7830902247631892`], 
              Complex[1.030107139085092, -3.249900582785767]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0636264738031667`, -1.7847164644296638`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2195588333764196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7847164644296638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0293716381846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.251598421594382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "Discard", 1, {
              Complex[3.2195588333764196`, -1.7847164644296638`], 
              Complex[1.0293716381846, -3.251598421594382]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07796617978662179, -1.7847164644296631`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07796617978662179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7847164644296631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0293716381845965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2515984215943754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "Discard", 2, {
              Complex[0.07796617978662179, -1.7847164644296631`], 
              Complex[1.0293716381845965`, -3.2515984215943754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0639022052083162`, -1.7863365945159997`}],
            RowBox[{"{", 
              
              RowBox[{"38.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.21928310197127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7863365945159997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0286391633678167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625719`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "Discard", 1, {
              Complex[3.21928310197127, -1.7863365945159997`], 
              Complex[1.0286391633678167`, -3.253290658625719]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0776904483814771, -1.7863365945160001`}],
            RowBox[{"{", 
              
              RowBox[{"38.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0776904483814771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7863365945160001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0286391633678178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.253290658625721`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "Discard", 2, {
              Complex[0.0776904483814771, -1.7863365945160001`], 
              Complex[1.0286391633678178`, -3.253290658625721]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.064176056919532, -1.7879506614871665`}],
            RowBox[{"{", 
              
              RowBox[{"38.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2190092502600542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7879506614871665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0279096896525775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2549773350978284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "Discard", 1, {
              Complex[3.2190092502600542`, -1.7879506614871665`], 
              Complex[1.0279096896525775`, -3.2549773350978284`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.077416596670261, -1.7879506614871654`}],
            RowBox[{"{", 
              
              RowBox[{"38.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.077416596670261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7879506614871654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.027909689652578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.254977335097826`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "Discard", 2, {
              Complex[0.077416596670261, -1.7879506614871654`], 
              Complex[1.027909689652578, -3.254977335097826]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0644480483327516`, -1.7895587112737734`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2187372588468346`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895587112737734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0271831923694072`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.256658491756127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "Discard", 1, {
              Complex[3.2187372588468346`, -1.7895587112737734`], 
              Complex[1.0271831923694072`, -3.256658491756127]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07714460525703772, -1.789558711273773}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07714460525703772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.789558711273773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0271831923693993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2566584917561223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "Discard", 2, {
              Complex[0.07714460525703772, -1.789558711273773], 
              Complex[1.0271831923693993`, -3.2566584917561223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0647181985730856`, -1.791160789280331}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2184671086065006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.791160789280331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2583341688807756`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "Discard", 1, {
              Complex[3.2184671086065006`, -1.791160789280331], 
              Complex[1.0264596471562961`, -3.2583341688807756`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07687445501670612, -1.7911607892803307`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07687445501670612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7911607892803307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0264596471562961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.258334168880775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "Discard", 2, {
              Complex[0.07687445501670612, -1.7911607892803307`], 
              Complex[1.0264596471562961`, -3.258334168880775]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.064986526499613, -1.79275694039334}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2181987806799732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.79275694039334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.025739029953579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "Discard", 1, {
              Complex[3.2181987806799732`, -1.79275694039334], 
              Complex[1.025739029953579, -3.2600044062938625`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07660612709017996, -1.7927569403933397`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07660612709017996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7927569403933397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0257390299535794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2600044062938625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "Discard", 2, {
              Complex[0.07660612709017996, -1.7927569403933397`], 
              Complex[1.0257390299535794`, -3.2600044062938625`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.065253050710064, -1.794347208989231}],
            RowBox[{"{", 
              
              RowBox[{"39.099999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2179322564695223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.794347208989231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.025021316998925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2616692433664776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "Discard", 1, {
              Complex[3.2179322564695223`, -1.794347208989231], 
              Complex[1.025021316998925, -3.2616692433664776`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07633960287973203, -1.7943472089892278`}],
            RowBox[{"{", 
              
              RowBox[{"39.099999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07633960287973203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7943472089892278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0250213169989348`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2616692433664767`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "Discard", 2, {
              Complex[0.07633960287973203, -1.7943472089892278`], 
              Complex[1.0250213169989348`, -3.2616692433664767`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0655177895454226`, -1.7959316389421525`}],
            RowBox[{"{", 
              
              RowBox[{"39.199999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2176675176341636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0243064848224217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "Discard", 1, {
              Complex[3.2176675176341636`, -1.7959316389421525`], 
              Complex[1.0243064848224217`, -3.2633287190256435`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07607486404437007, -1.7959316389421525`}],
            RowBox[{"{", 
              
              RowBox[{"39.199999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07607486404437007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7959316389421525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.024306484822421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2633287190256435`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "Discard", 2, {
              Complex[0.07607486404437007, -1.7959316389421525`], 
              Complex[1.024306484822421, -3.2633287190256435`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0657807610944086`, -1.7975102736315947`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2174045460851777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7975102736315947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0235945102417783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2649828717610987`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "Discard", 1, {
              Complex[3.2174045460851777`, -1.7975102736315947`], 
              Complex[1.0235945102417783`, -3.2649828717610987`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07581189249538411, -1.797510273631595}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07581189249538411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.797510273631595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0235945102417785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.264982871761099`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "Discard", 2, {
              Complex[0.07581189249538411, -1.797510273631595], 
              Complex[1.0235945102417785`, -3.264982871761099]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0660419831978802`, -1.7990831559498917`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.217143323981706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0228853703576102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.266631739631969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "Discard", 1, {
              Complex[3.217143323981706, -1.7990831559498917`], 
              Complex[1.0228853703576102`, -3.266631739631969]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07555067039191275, -1.7990831559498914`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07555067039191275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7990831559498914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0228853703576115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2666317396319684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "Discard", 2, {
              Complex[0.07555067039191275, -1.7990831559498914`], 
              Complex[1.0228853703576115`, -3.2666317396319684`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0663014734531355`, -1.8006503283095574`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2168838337264507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8006503283095574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.022179042548827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.268275360273292`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "Discard", 1, {
              Complex[3.2168838337264507`, -1.8006503283095574`], 
              Complex[1.022179042548827, -3.268275360273292]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07529118013665538, -1.8006503283095583`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07529118013665538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8006503283095583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0221790425488162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.26827536027329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "Discard", 2, {
              Complex[0.07529118013665538, -1.8006503283095583`], 
              Complex[1.0221790425488162`, -3.26827536027329]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.066559249218127, -1.8022118326504983`}],
            RowBox[{"{", 
              
              RowBox[{"39.599999999999994`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2166260579614594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8022118326504983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0214755044681103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.269913770902438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "Discard", 1, {
              Complex[3.2166260579614594`, -1.8022118326504983`], 
              Complex[1.0214755044681103`, -3.269913770902438]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07503340437166661, -1.802211832650498}],
            RowBox[{"{", 
              
              RowBox[{"39.599999999999994`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07503340437166661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.802211832650498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0214755044681099`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2699137709024373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "Discard", 2, {
              Complex[0.07503340437166661, -1.802211832650498], 
              Complex[1.0214755044681099`, -3.2699137709024373`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0668153276155836`, -1.8037677104470822`}],
            RowBox[{"{", 
              
              RowBox[{"39.699999999999996`", ",", "\"Discard\"", ",", "1", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2163699795640026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.020774734037491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.2715470083253844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "Discard", 1, {
              Complex[3.2163699795640026`, -1.8037677104470822`], 
              Complex[1.020774734037491, -3.2715470083253844`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0747773259742065, -1.8037677104470848`}],
            RowBox[{"{", 
              
              RowBox[{"39.699999999999996`", ",", "\"Discard\"", ",", "2", 
                ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0747773259742065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8037677104470848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0207747340374922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2715470083253804`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "Discard", 2, {
              Complex[0.0747773259742065, -1.8037677104470848`], 
              Complex[1.0207747340374922`, -3.2715470083253804`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0670697255370554`, -1.805318002715075}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.216115581642531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.27317510894289`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "Discard", 1, {
              Complex[3.216115581642531, -1.805318002715075], 
              Complex[1.0200767094440117`, -3.27317510894289]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0745229280527381, -1.805318002715075}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0745229280527381`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.805318002715075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0200767094440117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.273175108942891`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "Discard", 2, {
              Complex[0.0745229280527381, -1.805318002715075], 
              Complex[1.0200767094440117`, -3.273175108942891]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0673224596468587`, -1.8068627500184498`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2158628475327276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8068627500184498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0193814091354683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "Discard", 1, {
              Complex[3.2158628475327276`, -1.8068627500184498`], 
              Complex[1.0193814091354683`, -3.2747981087565443`]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.07427019394292937, -1.8068627500184438`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.07427019394292937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8068627500184438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0193814091354747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2747981087565288`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "Discard", 2, {
              Complex[0.07427019394292937, -1.8068627500184438`], 
              Complex[1.0193814091354747`, -3.2747981087565288`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{-3.0675735463859555`, -1.8084019924760657`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"Discard\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2156117607936308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0186888118162514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.276416043374702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "Discard", 1, {
              Complex[3.2156117607936308`, -1.8084019924760657`], 
              Complex[1.0186888118162514`, -3.276416043374702]}, 0}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{0.0740191072038374, -1.8084019924760677`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"Discard\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.0740191072038374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8084019924760677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.0186888118162511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.2764160433747036`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "Discard", 2, {
              Complex[0.0740191072038374, -1.8084019924760677`], 
              Complex[1.0186888118162511`, -3.2764160433747036`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.6980000948375882, -0.6433017314670934}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375882, -0.6433017314670934], 
              Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6944263543752545`, 0.006645071137818129}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.006645071137818129], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7333882582665036, -0.6165221792948049}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665036, -0.6165221792948049], 
              Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.654309125631486, 0.006712510785854934}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.006712510785854934], 
              Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7629774456127986, -0.5952855745698065}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127986, -0.5952855745698065], 
              Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.621891868208896, 0.006786025025047798}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047798], 
              Complex[6.122517060306257, -1.163371113059422]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7891581377234371, -0.5773156862277916}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234371, -0.5773156862277916], 
              Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.593955318850742, 0.0068633365731448895`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850742, 0.0068633365731448895`], 
              Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.813020240902394, -0.5615718710865851}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.813020240902394, -0.5615718710865851], 
              Complex[1.908828689419144, -2.052868131119601]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.569036631840206, 0.006943461497604872}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.569036631840206, 0.006943461497604872], 
              Complex[6.068475300453683, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.835170145892391, -0.5474736791133877}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.835170145892391, -0.5474736791133877], 
              Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5463246331431195`, 0.007025882918871681}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871681], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8559867126628703, -0.5346576120369388}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628703, -0.5346576120369388], 
              Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5253142371097725`, 0.007110298008162873}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.5253142371097725`, 0.007110298008162873], 
              Complex[6.023558855884933, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8757255721593927, -0.52287788641464}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593927, -0.52287788641464], 
              Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5056658326490995`, 0.007196517077880139}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880139], 
              Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8945689747906652, -0.5119589442981493}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906652, -0.5119589442981493], 
              Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.487138168550514, 0.007284416332243672}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243672], 
              Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9126523619522108, -0.5017701062164057}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522108, -0.5017701062164057], 
              Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.469552623884141, 0.007373913179256361}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884141, 0.007373913179256361], 
              Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9300797102089358, -0.4922109148816913}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.9300797102089358, -0.4922109148816913], 
              Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.452772601155936, 0.007464952252033912}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155936, 0.007464952252033912], 
              Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9469329539089921, -0.48320212310888055`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089921, -0.48320212310888055`], 
              Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.436690887655669, 0.007557496991163237}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.436690887655669, 0.007557496991163237], 
              Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9632780610078037, -0.47467987499817715`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078037, -0.47467987499817715`], 
              Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.421221515937318, 0.0076515243225991425`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937318, 0.0076515243225991425`], 
              Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9791691098460469, -0.46659179640833603`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460469, -0.46659179640833603`], 
              Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.406294309063904, 0.007747021157202576}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063904, 0.007747021157202576], 
              Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9946511165926878, -0.45889427989730874`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926878, -0.45889427989730874`], 
              Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.391851102143664, 0.007843982012263403}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143664, 0.007843982012263403], 
              Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.009762051806893, -0.45155054573492875`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806893, -0.45155054573492875`], 
              Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377843050837108, 0.007942407351021055}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837108, 0.007942407351021055], 
              Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.024534313536096, -0.4445292235923795}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.024534313536096, -0.4445292235923795], 
              Complex[2.119679474265541, -1.918057531021162]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3642286676832285`, 0.00804230239670521}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.00804230239670521], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0389958259885552`, -0.43780329333443724`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885552`, -0.43780329333443724`], 
              Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.350972359395372, 0.008143676269233574}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233574], 
              Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0531708739791161`, -0.43134927949335167`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791161`, -0.43134927949335167`], 
              Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.338043317353644, 0.008246541346654037}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353644, 0.008246541346654037], 
              Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0670807469468007`, -0.42514662876555165`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468007`, -0.42514662876555165`], 
              Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.325414662407916, 0.008350912786611275}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.325414662407916, 0.008350912786611275], 
              Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0807442431495686`, -0.4191772220375579}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495686`, -0.4191772220375579], 
              Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3130627762344576`, 0.00845680816400054}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.00845680816400054], 
              Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0941780694739518`, -0.41342498695323976`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739518`, -0.41342498695323976`], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.300966771833883, 0.008564247194411541}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411541], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.107397162145414, -0.4078755867501416}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145414, -0.4078755867501416], 
              Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.289108069365748, 0.008673251522090971}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.289108069365748, 0.008673251522090971], 
              Complex[5.777450742552286, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1204149466885311`, -0.40251616773611126`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.1204149466885311`, -0.40251616773611126`], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.277470052807503, 0.008783844556995735}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995735], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1332435506568057`, -0.39733515240586337`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568057`, -0.39733515240586337`], 
              Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.266037789390484, 0.008896051349858974}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349858974], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1458939792326737`, -0.3923220684765709}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326737`, -0.3923220684765709], 
              Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.254797798340199, 0.009009898497034034}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.254797798340199, 0.009009898497034034], 
              Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1583762613396105`, -0.38746740648134814`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396105`, -0.38746740648134814`], 
              Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.243737858735289, 0.009125414068990397}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990397], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1706995721155862`, -0.382762500281366}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155862`, -0.382762500281366], 
              Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.232846848694921, 0.009242627557842213}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694921, 0.009242627557842213], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1828723362728408`, -0.378199426130277}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728408`, -0.378199426130277], 
              Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.222114609872632, 0.009361569840391626}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391626], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1949023158791763`, -0.3737709168766501}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791763`, -0.3737709168766501], 
              Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.211531832555506, 0.009482273153986658}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555506, 0.009482273153986658], 
              Complex[5.695312895009785, -1.162653682569165]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2067966853478913`, -0.369470288610321}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.369470288610321], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.201089957665183, 0.009604771083122505}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122505], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2185620958524552`, -0.36529137760862845`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862845`], 
              Complex[2.317691837968342, -1.816262829010749]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.190781092718281, 0.009729098555121772}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121772], 
              Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2302047309418311`, -0.3612284858628565}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418311`, -0.3612284858628565], 
              Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.180597939390085, 0.00985529184370446}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.180597939390085, 0.00985529184370446], 
              Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2417303547902065`, -0.3572763337954378}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.3572763337954378], 
              Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.170533730780807, 0.009983388579384763}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384763], 
              Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.253144354246581, -0.35343001903737564`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.253144354246581, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.16058217684066, 0.010113427765967319`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967319`], 
              Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2644517756377363`, -0.34968498034029766`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377363`, -0.34968498034029766`], 
              Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1507374166916415`, 0.010245449802525813`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.1507374166916415`, 0.010245449802525813`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.275657357109484, -0.34603696586050564`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.275657357109484, -0.34603696586050564`], 
              Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140993976808082, 0.01037949651040012}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040012], 
              Complex[5.620051946974447, -1.162340058391703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.286765557155954, -0.34248200518323674`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.286765557155954, -0.34248200518323674`], 
              Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.131346734197311, 0.010515611164854463`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854463`], 
              Complex[5.609715869645587, -1.162290029994955]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.297780579877745, -0.33901638456087957`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.297780579877745, -0.33901638456087957`], 
              Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.121790883866403, 0.010653838531129443`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.010653838531129443`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3087063974214082`, -0.33563662492447366`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214082`, -0.33563662492447366`], 
              Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11232190997813, 0.010794224904694102`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694102`], 
              Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.319546769980594, -0.3323394622978922}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.319546769980594, -0.3323394622978922], 
              Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102935560194785, 0.010936818155564383`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194785, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3303052636801032`, -0.3291218303014382}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014382], 
              Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093627822786881, 0.011081667776607964`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.011081667776607964`], 
              Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3409852666152733`, -0.32598084447903347`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.3409852666152733`, -0.32598084447903347`], 
              Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.084394906148223, 0.011228824935798519`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798519`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.351590003278767, -0.32291378822242217`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.351590003278767, -0.32291378822242217`], 
              Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.075233220412342, 0.01137834253242333}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.01137834253242333], 
              Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.362122547573207, -0.319918100098616}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573207, -0.319918100098616], 
              Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.066139360909642, 0.01153027525727997}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525727997], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3725858345799593`, -0.31699136241415216`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799593`, -0.31699136241415216`], 
              Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.057110093241812, 0.011684679656931263`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931263`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.382982671230815, -0.31413129087274266`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.382982671230815, -0.31413129087274266`], 
              Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.04814233978115, 0.011841614202115778`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115778`], 
              Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3933157460094145`, -0.3113357252023996}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.3933157460094145`, -0.3113357252023996], 
              Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.039233167428713, 0.012001139360437396`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428713, 0.012001139360437396`], 
              Complex[5.510503169822832, -1.161705165156914]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4035876377924137`, -0.3086026206444544}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924137`, -0.3086026206444544], 
              Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.030379776487371, 0.012163317673485264`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485264`], 
              Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4138008239261344`, -0.3059300402110024}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261344`, -0.3059300402110024], 
              Complex[2.522758307852828, -1.730511398029892]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.021579490524692, 0.012328213838552492`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552492`], 
              Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4239576876222573`, -0.3033161476291157}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222573`, -0.3033161476291157], 
              Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.012829747116558, 0.012495894795164358`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164358`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.434060524745711, -0.30075920090048514`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.434060524745711, -0.30075920090048514`], 
              Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.004128089376173, 0.012666429816627254`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376173, 0.012666429816627254`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4441115500589816`, -0.29825754641387064`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589816`, -0.29825754641387064`], 
              Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.995472158184808, 0.012839890606854708`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854708`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.454112902979397, -0.29580961355530405`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.454112902979397, -0.29580961355530405`], 
              Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.986859685050743, 0.013016351402742245`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742245`], 
              Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4640666528993398`, -0.29341390976756415`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993398`, -0.29341390976756415`], 
              Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9782884855315257`, 0.013195889082391367`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391367`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4739748041135785`, -0.29106901601605945`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135785`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.70709401390507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9697564531622382`, 0.01337858327951261}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.9697564531622382`, 0.01337858327951261], 
              Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.483839300392978, -0.2887735826232169}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.961261553838926, 0.013564516504362838`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.961261553838926, 0.013564516504362838`], 
              Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4936620292395204`, -0.28652632543776696`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395204`, -0.28652632543776696`], 
              Complex[2.608435730175939, -1.699727637683005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.952801820612012, 0.013753774271608805`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612012, 0.013753774271608805`], 
              Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.503444825853813, -0.28432602230905957`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.503444825853813, -0.28432602230905957`], 
              Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9443753488495013`, 0.01394644523553293}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.01394644523553293], 
              Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.513189476842979, -0.2821715098398555}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.513189476842979, -0.2821715098398555], 
              Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9359802917339604`, 0.01414262133304412}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.01414262133304412], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5228977236939458`, -0.280061680393945}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939458`, -0.280061680393945], 
              Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.927614856061183, 0.014342397934981635`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5325712660346489`, -0.2779954793374565}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.5325712660346489`, -0.2779954793374565], 
              Complex[2.650557449990277, -1.685592253447088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9192772983115907`, 0.014545874006250778`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250778`], 
              Complex[5.379881023870964, -1.160554068514124]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5422117647034572`, -0.2759719024950626}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034572`, -0.2759719024950626], 
              Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.910965920968408, 0.014753152275367222`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367222`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5518208446451707`, -0.27398999380419353`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451707`, -0.27398999380419353`], 
              Complex[2.671487342062719, -1.678805872976879]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9026790690591686`, 0.014964339414034983`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.014964339414034983`], 
              Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5614000976502447`, -0.27204884315225314`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502447`, -0.27204884315225314`], 
              Complex[2.68192509329917, -1.675479597139089]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.894415126899331, 0.015179546227436329`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436329`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5709510849523987`, -0.27014758438335246`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335246`], 
              Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8861725150187785`, 0.015398887855965335`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965335`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5804753396984255`, -0.26828539346253044`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.26828539346253044`], 
              Complex[2.702753826320577, -1.668956496466899]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8779496872537016`, 0.015622483989198204`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198204`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5899743693028523`, -0.26646148678673565`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028523`, -0.26646148678673565`], 
              Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8697451279879247`, 0.015850459092959818`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.8697451279879247`, 0.015850459092959818`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5994496576990789`, -0.26467511963294016`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.5994496576990789`, -0.26467511963294016`], 
              Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.861557349529051, 0.01608294265041592}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.861557349529051, 0.01608294265041592], 
              Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6089026674977167`, -0.2629255847348713}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348713], 
              Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8533848896060525`, 0.0163200694182023}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.0163200694182023], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6183348420620054`, -0.2612122109807513}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620054`, -0.2612122109807513], 
              Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8452263089759486`, 0.01656197969868379}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759486`, 0.01656197969868379], 
              Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6277476075095596`, -0.2595343622253301}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.6277476075095596`, -0.2595343622253301], 
              Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.837080189128189, 0.016808819629533064`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533064`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.637142374648998, -0.2578914362102892}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.637142374648998, -0.2578914362102892], 
              Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8289451300761326`, 0.017060741491919426`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761326`, 0.017060741491919426`], 
              Complex[5.280454632721417, -1.159256290802515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6465205408595256`, -0.2562828635878306}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595256`, -0.2562828635878306], 
              Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.820819748225798, 0.01731790403871422}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.01731790403871422], 
              Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6558834919210377`, -0.25470810704296915`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210377`, -0.25470810704296915`], 
              Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.812702674312651, 0.0175804728442376}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.0175804728442376], 
              Complex[5.262480372776144, -1.158970392486303]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6652326038019236`, -0.2531666605106765}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106765], 
              Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8045925513977634`, 0.017848620677213583`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213583`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6745692444113933`, -0.251658048484637}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.251658048484637], 
              Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.796488032915171, 0.018122527898744724`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.796488032915171, 0.018122527898744724`], 
              Complex[5.244507580447731, -1.158666193825158]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6838947753228468`, -0.25018182541497563`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.6838947753228468`, -0.25018182541497563`], 
              Complex[2.816682213625116, -1.635923116971627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7883877807626547`, 0.018402382887287773`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287773`], 
              Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6932105534745874`, -0.2487375751928472}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745874`, -0.2487375751928472], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7802904634285417`, 0.018688382492788227`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7025179328539397`, -0.2473249107203387}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.7025179328539397`, -0.2473249107203387], 
              Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.772194754147412, 0.018980732522336802`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336802`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.711818266170711, -0.24594347356467736`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.711818266170711, -0.24594347356467736`], 
              Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7640993290778377`, 0.019279648259930993`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.7640993290778377`, 0.019279648259930993`], 
              Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7211129065258053`, -0.2445929336962447}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258053`, -0.2445929336962447], 
              Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7560028654954856`, 0.01958535502317048}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954856`, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7304032090806973`, -0.24327298931041993`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041993`], 
              Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.747904039995082, 0.01989808875998759}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995082, 0.01989808875998759], 
              Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.739690532733481, -0.24198336673385532`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.739690532733481, -0.24198336673385532`], 
              Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.739801526694796, 0.020218096688815523`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.020218096688815523`], 
              Complex[5.181444746812216, -1.157435637212811]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7489762418071482`, -0.24072382041628856`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071482`, -0.24072382041628856`], 
              Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7316939954367316`, 0.020545637985933}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985933], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.758261707755823, -0.23949413300958816`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.758261707755823, -0.23949413300958816`], 
              Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.723580109977185, 0.020880984524095002`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.723580109977185, 0.020880984524095002`], 
              Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7675483108947163`, -0.2382941155363085}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947163`, -0.2382941155363085], 
              Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7154585261603414`, 0.021224421666976207`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603414`, 0.021224421666976207`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.776837442159661, -0.23712360765068694`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.776837442159661, -0.23712360765068694`], 
              Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.707327890069032, 0.02157624912441267}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7861305049022496`, -0.23598247799562685`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022496`, -0.23598247799562685`], 
              Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6991868361460636`, 0.021936781873947247`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.021936781873947247`], 
              Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7954289167267061`, -0.23487062465998598`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267061`, -0.23487062465998598`], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6910339852795406`, 0.022306351154756415`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795406`, 0.022306351154756415`], 
              Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8047341113748927`, -0.23378797574120985`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.8047341113748927`, -0.23378797574120985`], 
              Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6828679428453777`, 0.022685305540684448`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684448`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.814047540666005, -0.23273449001922963`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.814047540666005, -0.23273449001922963`], 
              Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6746872967000694`, 0.0230740120998302}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.6746872967000694`, 0.0230740120998302], 
              Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8233706764978728`, -0.2317101577484136}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.8233706764978728`, -0.2317101577484136], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6664906151164782`, 0.023472857648944835`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944835`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8327050129169915`, -0.23071500157543248`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169915`, -0.23071500157543248`], 
              Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6582764446551637`, 0.023882250111808095`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.023882250111808095`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8420520682648396`, -0.22974907759194238`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.8420520682648396`, -0.22974907759194238`], 
              Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6500433079634345`, 0.02430261999177399}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.6500433079634345`, 0.02430261999177399], 
              Complex[5.080861117956597, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8514133874083418`, -0.22881247653229805`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.22881247653229805`], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.64178970149396, 0.024734421969833987`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.64178970149396, 0.024734421969833987`], 
              Complex[5.071567299655017, -1.154523602824754]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.860790544062835, -0.2279053251278246}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.860790544062835, -0.2279053251278246], 
              Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.633514093134369, 0.025178136640842893`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.633514093134369, 0.025178136640842893`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8701851432162653`, -0.22702778763077072`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162653`, -0.22702778763077072`], 
              Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.625214919738834, 0.025634272402031196`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.625214919738834, 0.025634272402031196`], 
              Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8795988236639012`, -0.22618006752276323`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.22618006752276323`], 
              Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6168905845521655`, 0.0261033675095845}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.6168905845521655`, 0.0261033675095845], 
              Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8890332606633722`, -0.22536240942454516`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454516`], 
              Complex[3.047400635096297, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6085394545164045`, 0.026585992320965875`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.6085394545164045`, 0.026585992320965875`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8984901687203608`, -0.2245751012259816}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.8984901687203608`, -0.2245751012259816], 
              Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6001598574493725`, 0.027082751742796535`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796535`], 
              Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9079713045159428`, -0.22381847645779898`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.22381847645779898`], 
              Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5917500790840515`, 0.02759428790654434}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840515`, 0.02759428790654434], 
              Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9174784699871426`, -0.22309291692935715`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.9174784699871426`, -0.22309291692935715`], 
              Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.583308359957026, 0.02812128309705336}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.583308359957026, 0.02812128309705336], 
              Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.927013515572947, -0.22239885565995451`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.927013515572947, -0.22239885565995451`], 
              Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5748328921336294`, 0.02866446296210389}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.5748328921336294`, 0.02866446296210389], 
              Complex[4.99589327476625, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9365783436386594`, -0.22173678013483558`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386594`, -0.22173678013483558`], 
              Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.566321815756732, 0.029224600034819154`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.566321815756732, 0.029224600034819154`], 
              Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9461749120921603`, -0.22110723592124693`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.22110723592124693`], 
              Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.557773215405521, 0.029802517604874564`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.029802517604874564`], 
              Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9558052382062334`, -0.22051083068468325`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.9558052382062334`, -0.22051083068468325`], 
              Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5491851162499515`, 0.030399093979211273`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211273`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.965471402661748, -0.21994823865092936`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092936`], 
              Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.540555479985998, 0.031015267178413904`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413904`], 
              Complex[4.956961006232221, -1.149994992121425]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9751755538269593`, -0.21942020556585135`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269593`, -0.21942020556585135`], 
              Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.531882200536309, 0.031652040121196476`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.531882200536309, 0.031652040121196476`], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.984919912288591, -0.2189275542121152}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.984919912288591, -0.2189275542121152], 
              Complex[3.157220421076432, -1.563457815486074]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5231630995005294`, 0.03231048635665899}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.5231630995005294`, 0.03231048635665899], 
              Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9947067756505623`, -0.21847119055042036`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505623`, -0.21847119055042036`], 
              Complex[3.168494941546649, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5143959213393177`, 0.03299175641234993}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234993], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.004538523616137, -0.21805211056251306`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.004538523616137, -0.21805211056251306`], 
              Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.505578328276208, 0.03369708483581626}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.03369708483581626], 
              Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.014417623368864, -0.21767140788446343`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.014417623368864, -0.21767140788446343`], 
              Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4967078949018573`, 0.03442779801852968}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.4967078949018573`, 0.03442779801852968], 
              Complex[4.9069682642347, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0243466352667068`, -0.21733028233169743`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667068`, -0.21733028233169743`], 
              Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4877821024662152`, 0.035185322904060734`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.035185322904060734`], 
              Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.034328218862186, -0.2170300494324249}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.2170300494324249], 
              Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.478798332845711, 0.03597119669747849}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.478798332845711, 0.03597119669747849], 
              Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0443651392587743`, -0.2167721511036576}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.0443651392587743`, -0.2167721511036576], 
              Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.469753862175173, 0.036787077710537186`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.469753862175173, 0.036787077710537186`], 
              Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.054460273810074, -0.2165581676245985}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.2165581676245985], 
              Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.460645854137856, 0.03763475749771081}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.460645854137856, 0.03763475749771081], 
              Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0646166191629156`, -0.21638983108607387`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.21638983108607387`], 
              Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4514713529124292`, 0.03851617446207811}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.4514713529124292`, 0.03851617446207811], 
              Complex[4.855165682495277, -1.144029106365958]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0748372986380015`, -0.2162690405227275}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380015`, -0.2162690405227275], 
              Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.442227275783197, 0.03943342913804209}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804209], 
              Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0851255699314044`, -0.21619787896744103`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.21619787896744103`], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4329104054302233`, 0.04038880139063529}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302233`, 0.04038880139063529], 
              Complex[4.833843395364207, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0954848331061537`, -0.21617863270584692`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584692`], 
              Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.423517381930075, 0.04138476980950441}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.04138476980950441], 
              Complex[4.823037890424123, -1.141619564099015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1059186388242215`, -0.21621381305374038`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.1059186388242215`, -0.21621381305374038`], 
              Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4140446945168277`, 0.042424033620649226`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.042424033620649226`], 
              Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.116430696743796, -0.21630618103294583`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.116430696743796, -0.21630618103294583`], 
              Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4044886731783923`, 0.043509537491681564`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.4044886731783923`, 0.043509537491681564`], 
              Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.127024883972908, -0.21645877538292152`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.127024883972908, -0.21645877538292152`], 
              Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3948454801970804`, 0.044644499668114825`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114825`], 
              Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.137705253425444, -0.21667494441768215`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.137705253425444, -0.21667494441768215`], 
              Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3851111017883304`, 0.045832443950466685`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.045832443950466685`], 
              Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1484760418658873`, -0.21695838232209172`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209172`], 
              Complex[3.347142736911111, -1.54216837655994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3752813400511936`, 0.04707723610641603}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.3752813400511936`, 0.04707723610641603], 
              Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.15934167735015, -0.21731317057992383`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992383`], 
              Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.365351805523236, 0.04838312541060397}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.04838312541060397], 
              Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.170306785665302, -0.21774382534019746`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.170306785665302, -0.21774382534019746`], 
              Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3553179107369844`, 0.049754792118764775`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.3553179107369844`, 0.049754792118764775`], 
              Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.181376195232895, -0.2182553516597405}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.2182553516597405], 
              Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.345174865313174, 0.0511974018142957}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.345174865313174, 0.0511974018142957], 
              Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1925549397581063`, -0.21885330570991673`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.1925549397581063`, -0.21885330570991673`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3349176733086154`, 0.052716667715368405`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.052716667715368405`], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2038482576658165`, -0.2195438662043097}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.2195438662043097], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3245411337774544`, 0.05431892219952697}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952697], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2152615870464745`, -0.2203339164903331}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.2152615870464745`, -0.2203339164903331], 
              Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.314039845823023, 0.05601119898888117}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.314039845823023, 0.05601119898888117], 
              Complex[4.696326724353138, -1.12850882102276]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2268005544144556`, -0.22123113894674887`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.2268005544144556`, -0.22123113894674887`], 
              Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3034082198375003`, 0.05780132763801396}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375003`, 0.05780132763801396], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.23847095502768, -0.2222441235311438}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.23847095502768, -0.2222441235311438], 
              Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.292640497180628, 0.059698042168788046`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180628, 0.059698042168788046`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.250278721787946, -0.22338249250843553`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.250278721787946, -0.22338249250843553`], 
              Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2817307812779952`, 0.061711105883242925`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.2817307812779952`, 0.061711105883242925`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2622298787838817`, -0.2246570435317342}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838817`, -0.2246570435317342], 
              Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.270673084076976, 0.06385145452602974}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.06385145452602974], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.274330474286138, -0.22607991328743204`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2594613930506555`, 0.06613136000835836}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.2594613930506555`, 0.06613136000835836], 
              Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2865864863773204`, -0.2276647637711871}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.2865864863773204`, -0.2276647637711871], 
              Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2480897655672782`, 0.06856461676025145}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672782`, 0.06856461676025145], 
              Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2990036923040837`, -0.2294269927942462}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.2990036923040837`, -0.2294269927942462], 
              Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.23655245953774, 0.07116675231062944}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.23655245953774, 0.07116675231062944], 
              Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.311587489979285, -0.23138396931833907`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.311587489979285, -0.23138396931833907`], 
              Complex[3.539668711719687, -1.54125837029078]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2248441119132174`, 0.07395526269357484}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.2248441119132174`, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.324342656755631, -0.2335552923600304}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.324342656755631, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.212959979911501, 0.07694987142173919}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.212959979911501, 0.07694987142173919], 
              Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3372730266129884`, -0.2359630690132302}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.2359630690132302], 
              Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.20089626382986, 0.0801728075757009}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.20089626382986, 0.0801728075757009], 
              Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3503810623577226`, -0.23863220192231419`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577226`, -0.23863220192231419`], 
              Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.18865053484601, 0.08364909334179278}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.18865053484601, 0.08364909334179278], 
              Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3636672947096224`, -0.24159066834690415`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.3636672947096224`, -0.24159066834690415`], 
              Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.176222295931689, 0.08740682313953917}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.176222295931689, 0.08740682313953917], 
              Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3771295961517165`, -0.24486976056502352`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517165`, -0.24486976056502352`], 
              Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1636137080034565`, 0.09147740408549974}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034565`, 0.09147740408549974], 
              Complex[4.519597775965093, -1.093160763626926]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3907622559358295`, -0.24850423935263424`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358295`, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1508305149179034`, 0.09589570953158899}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.1508305149179034`, 0.09589570953158899], 
              Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.404554826889628, -0.25253232740394693`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889628, -0.25253232740394693`], 
              Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.137883196665494, 0.10070007254234226`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.137883196665494, 0.10070007254234226`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4184907299124174`, -0.2569954375693104}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.66780561916792, -1.560366273382241]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.124788364875778, 0.1059320141880026}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.124788364875778, 0.1059320141880026], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4325456359616355`, -0.26193749411720374`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.26193749411720374`], 
              Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1115703808320068`, 0.11163556486001101`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320068`, 0.11163556486001101`], 
              Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4466857074528354`, -0.2674036718059935}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059935], 
              Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.098263114072366, 0.11785600339463051`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.098263114072366, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4608658796691665`, -0.2734383645589258}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.4608658796691665`, -0.2734383645589258], 
              Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.084911660981808, 0.1246378257982292}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981808, 0.1246378257982292], 
              Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4750284976365355`, -0.28008223230347307`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.4750284976365355`, -0.28008223230347307`], 
              Complex[3.736478521301466, -1.58190695616248]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.071573707918281, 0.1320217921353984}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918281, 0.1320217921353984], 
              Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4891027727434665`, -0.2873682998621285}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.4891027727434665`, -0.2873682998621285], 
              Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0583200745943513`, 0.1400410254670661}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.0583200745943513`, 0.1400410254670661], 
              Complex[4.393335070431694, -1.040700701679103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5030056270697787`, -0.29531732776612113`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697787`, -0.29531732776612113`], 
              Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0452338697500734`, 0.14871638271009868`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009868`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5166444532991594`, -0.3039330313949986}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.5166444532991594`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.032407731242035, 0.1580516738214428}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.1580516738214428], 
              Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5299220300509884`, -0.31319809514055186`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509884`, -0.31319809514055186`], 
              Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0199389107132126`, 0.16802967600526134`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132126`, 0.16802967600526134`], 
              Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5427432708771702`, -0.3230721172560292}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771702`, -0.3230721172560292], 
              Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.007922524597889, 0.17861007860412123`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.17861007860412123`], 
              Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5550227978429705`, -0.33349241406049857`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.5550227978429705`, -0.33349241406049857`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.996443980542599, 0.1897302873440814}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.1897302873440814], 
              Complex[4.317427040750872, -0.984655324990569]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5666918389490667`, -0.3443779449095298}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.5666918389490667`, -0.3443779449095298], 
              Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9855720799859258`, 0.20130934934494918`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859258`, 0.20130934934494918`], 
              Complex[4.303885430470007, -0.971377104797334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5777029731444694`, -0.35563571212946193`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946193`], 
              Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9753542731474694`, 0.21325435309295854`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474694`, 0.21325435309295854`], 
              Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.588031851130083, -0.3671682712416466}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.588031851130083, -0.3671682712416466], 
              Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.965814938226205, 0.22546793870233256`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.965814938226205, 0.22546793870233256`], 
              Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5976759196164494`, -0.3788808057418005}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.3788808057418005], 
              Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9569566571447035`, 0.2378553727309031}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.2378553727309031], 
              Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.606650933262854, -0.3906866010723904}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.606650933262854, -0.3906866010723904], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9487637036120304`, 0.25033002218771455`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771455`], 
              Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6149863657999486`, -0.40251041678372024`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.6149863657999486`, -0.40251041678372024`], 
              Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9412066320031385`, 0.2628167267283543}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.9412066320031385`, 0.2628167267283543], 
              Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6227207308158538`, -0.41428986426444875`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.6227207308158538`, -0.41428986426444875`], 
              Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.93424695657482, 0.27525317641875774`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.27525317641875774`], 
              Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.629897485254924, -0.42597525546826037`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.629897485254924, -0.42597525546826037`], 
              Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.927841247969024, 0.28758976049421764`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.28758976049421764`], 
              Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.636561822697944, -0.4375284851167467}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.636561822697944, -0.4375284851167467], 
              Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.921944339934747, 0.2997884495937316}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.921944339934747, 0.2997884495937316], 
              Complex[4.222645506003507, -0.856274787217682]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6427583897826854`, -0.4489214364481581}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826854`, -0.4489214364481581], 
              Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9165116129095963`, 0.31182120153934106`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934106`], 
              Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.648529805818011, -0.4601342612759221}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.648529805818011, -0.4601342612759221], 
              Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.911500474407813, 0.323668241424401}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.323668241424401], 
              Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.653915808537619, -0.4711537472500261}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.653915808537619, -0.4711537472500261], 
              Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.90687121326868, 0.33531642890390234`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.90687121326868, 0.33531642890390234`], 
              Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6589528500918, -0.48197187877303665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500918, -0.48197187877303665`], 
              Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9025874036669044`, 0.3467578191386486}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669044`, 0.3467578191386486], 
              Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6636739953559614`, -0.49258462786579826`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.6636739953559614`, -0.49258462786579826`], 
              Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8986160068062667`, 0.3579884536883491}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.3579884536883491], 
              Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.668109009751523, -0.50299097090211}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751523, -0.50299097090211], 
              Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8949272831009005`, 0.36900737727295585`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.8949272831009005`, 0.36900737727295585`], 
              Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6722845561748567`, -0.5131921073476409}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.6722845561748567`, -0.5131921073476409], 
              Complex[3.989240598169983, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8914945952485174`, 0.37981585653752775`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485174`, 0.37981585653752775`], 
              Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.67622444669189, -0.5231908494724435}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724435], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8882941565379943`, 0.3904167697900055}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379943`, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.679949913999627, -0.5329911517598123}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598123], 
              Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8853047593900265`, 0.4008141364346624}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346624], 
              Complex[4.173308062162179, -0.735357851265334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.683479881251108, -0.5425977517885688}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885688], 
              Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8825075055343556`, 0.41101275787833075`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.8825075055343556`, 0.41101275787833075`], 
              Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6868312180069145`, -0.5520158986267104}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.6868312180069145`, -0.5520158986267104], 
              Complex[4.009806376364359, -1.880054831501801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8798855500604437`, 0.42101794594737985`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.42101794594737985`], 
              Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6900189760399855`, -0.5612511491377956}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399855`, -0.5612511491377956], 
              Complex[4.01438190088909, -1.890520862682429]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8774238656148396`, 0.4308353192168015}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148396`, 0.4308353192168015], 
              Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.693056602464925, -0.5703092165540393}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.693056602464925, -0.5703092165540393], 
              Complex[4.018766629721939, -1.900792375423005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8751090292740487`, 0.4404706516054349}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.4404706516054349], 
              Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.695956129918709, -0.5791958590266285}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.695956129918709, -0.5791958590266285], 
              Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8729290323659913`, 0.4499297609478434}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.8729290323659913`, 0.4499297609478434], 
              Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.698728344803272, -0.5879167986060275}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.698728344803272, -0.5879167986060275], 
              Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8708731122295896`, 0.4592184279956057}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.8708731122295896`, 0.4592184279956057], 
              Complex[4.152955626516613, -0.664447166754532]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7013829352654026`, -0.5964776632911527}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911527], 
              Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8689316042370305`, 0.4683423384869718}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370305`, 0.4683423384869718], 
              Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7039286208715065`, -0.6048839465011073}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011073], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8670958121211547`, 0.477307042638535}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.477307042638535], 
              Complex[4.147506625196923, -0.642348121441579]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7063732659882276`, -0.613140979653751}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.613140979653751], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8653578945969786`, 0.48611792774323803`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.48611792774323803`], 
              Complex[4.144979724610491, -0.631560836108617]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.708723978803601, -0.6212539145605391}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.708723978803601, -0.6212539145605391], 
              Complex[4.041793889306879, -1.958660288701135]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8637107663426793`, 0.49478020058417876`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426793`, 0.49478020058417876`], 
              Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.710987197779323, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 1, {
              Complex[2.710987197779323, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8621480115494466`, 0.503298877159704}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 2, {
              Complex[2.8621480115494466`, 0.503298877159704], 
              Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7131687671511795`, -0.6370671424983351}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 1, {
              Complex[2.7131687671511795`, -0.6370671424983351], 
              Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.860663808423174, 0.5116787778163023}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 2, {
              Complex[2.860663808423174, 0.5116787778163023], 
              Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.71527400291423, -0.6447767740762022}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 1, {
              Complex[2.71527400291423, -0.6447767740762022], 
              Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8592528632013723`, 0.5199245263444046}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A", 2, {
              Complex[2.8592528632013723`, 0.5199245263444046], 
              Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.717307750554921, -0.6523609855265123}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 1, {
              Complex[2.717307750554921, -0.6523609855265123], 
              Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.857910352423154, 0.5280405519418746}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A", 2, {
              Complex[2.857910352423154, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7192744356306133`, -0.6598239647344449}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 1, {
              Complex[2.7192744356306133`, -0.6598239647344449], 
              Complex[4.057727034812088, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8566318723517807`, 0.5360310932164641}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A", 2, {
              Complex[2.8566318723517807`, 0.5360310932164641], 
              Complex[4.132077284632824, -0.570171279993703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7211781081510784`, -0.6671697152100743}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 1, {
              Complex[2.7211781081510784`, -0.6671697152100743], 
              Complex[4.060641656654434, -2.01093044740819]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8554133945952374`, 0.543900203601609}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A", 2, {
              Complex[2.8554133945952374`, 0.543900203601609], 
              Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7230224815870465`, -0.6744020624307276}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 1, {
              Complex[2.7230224815870465`, -0.6744020624307276], 
              Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.854251227099731, 0.5516517577146821}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 2, {
              Complex[2.854251227099731, 0.5516517577146821], 
              Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.724810967217476, -0.6815246607732999}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 1, {
              Complex[2.724810967217476, -0.6815246607732999], 
              Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8531419798044717`, 0.5592894583048513}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A", 2, {
              Complex[2.8531419798044717`, 0.5592894583048513], 
              Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7265467044285883`, -0.6885410007735716}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 1, {
              Complex[2.7265467044285883`, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.852082534344649, 0.5668168435275388}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A", 2, {
              Complex[2.852082534344649, 0.5668168435275388], 
              Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7282325874925664`, -0.6954544165180527}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 1, {
              Complex[2.7282325874925664`, -0.6954544165180527], 
              Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8510700172747567`, 0.5742372943510567}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 2, {
              Complex[2.8510700172747567`, 0.5742372943510567], 
              Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.729871289280439, -0.7022680930260651}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 1, {
              Complex[2.729871289280439, -0.7022680930260651], 
              Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.850101776357696, 0.5815540419531228}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 2, {
              Complex[2.850101776357696, 0.5815540419531228], 
              Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7314652823007664`, -0.7089850735194753}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 1, {
              Complex[2.7314652823007664`, -0.7089850735194753], 
              Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8491753595280755`, 0.5887701750046822}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 2, {
              Complex[2.8491753595280755`, 0.5887701750046822], 
              Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.733016857401756, -0.7156082665076033}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 1, {
              Complex[2.733016857401756, -0.7156082665076033], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.848288496192057, 0.5958886467685786}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A", 2, {
              Complex[2.848288496192057, 0.5958886467685786], 
              Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.734528140428245, -0.7221404526376912}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 1, {
              Complex[2.734528140428245, -0.7221404526376912], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.847439080572326, 0.6029122819634529}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A", 2, {
              Complex[2.847439080572326, 0.6029122819634529], 
              Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.736001107085408, -0.7285842912785057}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 1, {
              Complex[2.736001107085408, -0.7285842912785057], 
              Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8466251568463186`, 0.6098437833604624}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 2, {
              Complex[2.8466251568463186`, 0.6098437833604624], 
              Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7374375962271382`, -0.7349423268176083}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 1, {
              Complex[2.7374375962271382`, -0.7349423268176083], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.845844905859744, 0.6166857380933649}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 2, {
              Complex[2.845844905859744, 0.6166857380933649], 
              Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7388393217580846`, -0.7412169946624545}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 1, {
              Complex[2.7388393217580846`, -0.7412169946624545], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8450966332264747`, 0.6234406236721284}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7402078833132797`, -0.7474106269426312}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 1, {
              Complex[2.7402078833132797`, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8443787586507785`, 0.6301108136973931}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A", 2, {
              Complex[2.8443787586507785`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7415447758580713`, -0.7535254579157126}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 1, {
              Complex[2.7415447758580713`, -0.7535254579157126], 
              Complex[4.092654956897793, -2.109452014313655]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.843689806329271, 0.6366985832782687}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A", 2, {
              Complex[2.843689806329271, 0.6366985832782687], 
              Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.742851398332544, -0.7595636290829759}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 1, {
              Complex[2.742851398332544, -0.7595636290829759], 
              Complex[4.094763792064631, -2.11634961995984]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8430283963083336`, 0.6432061141597183}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A", 2, {
              Complex[2.8430283963083336`, 0.6432061141597183], 
              Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.744129061448893, -0.7655271940238008}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 1, {
              Complex[2.744129061448893, -0.7655271940238008], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.842393236688587, 0.6496354995683534}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A", 2, {
              Complex[2.842393236688587, 0.6496354995683534], 
              Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.745378994736478, -0.7714181229593412}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 1, {
              Complex[2.745378994736478, -0.7714181229593412], 
              Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8417831165816425`, 0.6559887487872518}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 2, {
              Complex[2.8417831165816425`, 0.6559887487872518], 
              Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.746602352917594, -0.7772383070571701}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 1, {
              Complex[2.746602352917594, -0.7772383070571701], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8411968997361448`, 0.6622677914714884}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 2, {
              Complex[2.8411968997361448`, 0.6622677914714884], 
              Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7478002216867257`, -0.7829895624892164}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 1, {
              Complex[2.7478002216867257`, -0.7829895624892164], 
              Complex[4.102814974771636, -2.143119636338954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8406335187602902`, 0.6684744817167128}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 2, {
              Complex[2.8406335187602902`, 0.6684744817167128], 
              Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.748973622957287, -0.7886736342555815}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 1, {
              Complex[2.748973622957287, -0.7886736342555815], 
              Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8400919698768647`, 0.6746106018933697}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 2, {
              Complex[2.8400919698768647`, 0.6746106018933697], 
              Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.750123519632142, -0.794292199786831}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409572, -2.156041173845927]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8395713081544542`, 0.6806778662591643}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 2, {
              Complex[2.8395713081544542`, 0.6806778662591643], 
              Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.751250819947598, -0.7998468723371362}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 1, {
              Complex[2.751250819947598, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.839070643165216, 0.6866779243621389}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 2, {
              Complex[2.839070643165216, 0.6866779243621389], 
              Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7523563814347085`, -0.8053392041803537}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 1, {
              Complex[2.7523563814347085`, -0.8053392041803537], 
              Complex[4.11031899238399, -2.168673807450607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.838589135025258, 0.6926123642464805}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A", 2, {
              Complex[2.838589135025258, 0.6926123642464805], 
              Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7534410145367234`, -0.8107706896206492}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 1, {
              Complex[2.7534410145367234`, -0.8107706896206492], 
              Complex[4.112118632879193, -2.174886099543967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8381259907789103`, 0.6984827154726537}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A", 2, {
              Complex[2.8381259907789103`, 0.6984827154726537], 
              Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7545054859170786`, -0.8161427678288303}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 1, {
              Complex[2.7545054859170786`, -0.8161427678288303], 
              Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8376804610924062`, 0.7042904519630285}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A", 2, {
              Complex[2.8376804610924062`, 0.7042904519630285], 
              Complex[4.102309515593154, -0.359742624540917]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7555505214884586`, -0.8214568255150109}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8372518372264883`, 0.710036994683633}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A", 2, {
              Complex[2.8372518372264883`, 0.710036994683633], 
              Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7565768091900997`, -0.8267141994476596}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 1, {
              Complex[2.7565768091900997`, -0.8267141994476596], 
              Complex[4.117350770809639, -2.193126103819013]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836839448260752, 0.7157237141721116}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A", 2, {
              Complex[2.836839448260752, 0.7157237141721116], 
              Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7575850015374925`, -0.8319161788285991}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 1, {
              Complex[2.7575850015374925`, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8364426585455744`, 0.7213519329214126}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A", 2, {
              Complex[2.8364426585455744`, 0.7213519329214126], 
              Complex[4.100239116839224, -0.338101803538321]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7585757179660733`, -0.8370640075328957}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 1, {
              Complex[2.7585757179660733`, -0.8370640075328957], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836060865360036, 0.7269229276281965}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 2, {
              Complex[2.836060865360036, 0.7269229276281965], 
              Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.759549546988155, -0.8421588862221198}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 1, {
              Complex[2.759549546988155, -0.8421588862221198], 
              Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8356934967565883`, 0.732437931314428}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 2, {
              Complex[2.8356934967565883`, 0.732437931314428], 
              Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.760507048180339, -0.8472019743388879}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 1, {
              Complex[2.760507048180339, -0.8472019743388879], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8353400095752215`, 0.7378981353300624}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 2, {
              Complex[2.8353400095752215`, 0.7378981353300624], 
              Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7614487540168455`, -0.8521943919901349}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 1, {
              Complex[2.7614487540168455`, -0.8521943919901349], 
              Complex[4.12556733480281, -2.222290341327314]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8349998876116986`, 0.7433046912443027}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 2, {
              Complex[2.8349998876116986`, 0.7433046912443027], 
              Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.762375171562624, -0.8571372217260823}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 1, {
              Complex[2.762375171562624, -0.8571372217260823], 
              Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8346726399259916`, 0.7486587126323618}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A", 2, {
              Complex[2.8346726399259916`, 0.7486587126323618], 
              Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7632867840386814`, -0.8620315102214068}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 1, {
              Complex[2.7632867840386814`, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8343577992784867`, 0.7539612767642822}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A", 2, {
              Complex[2.8343577992784867`, 0.7539612767642822], 
              Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.764184052270831, -0.8668782698647187}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 1, {
              Complex[2.764184052270831, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8340549206827474`, 0.7592134262018864}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A", 2, {
              Complex[2.8340549206827474`, 0.7592134262018864], 
              Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.765067416031943, -0.8716784802620265}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 1, {
              Complex[2.765067416031943, -0.8716784802620265], 
              Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8337635800647583`, 0.764416170309563}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 2, {
              Complex[2.8337635800647583`, 0.764416170309563], 
              Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7659372952868275`, -0.8764330896595155}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 1, {
              Complex[2.7659372952868275`, -0.8764330896595155], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8334833730195332`, 0.769570486684214}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7667940913479225`, -0.8811430162906054}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 1, {
              Complex[2.7667940913479225`, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8332139136568895`, 0.7746773225093263}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A", 2, {
              Complex[2.8332139136568895`, 0.7746773225093263], 
              Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7676381879492564`, -0.8858091496519156}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 1, {
              Complex[2.7676381879492564`, -0.8858091496519156], 
              Complex[4.136164053701611, -2.260791305494017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83295483352893, 0.7797375958378118}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A", 2, {
              Complex[2.83295483352893, 0.7797375958378118], 
              Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.768469952245414, -0.8904323517124777}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 1, {
              Complex[2.768469952245414, -0.8904323517124777], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8327057806325184`, 0.7847521968079433}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 2, {
              Complex[2.8327057806325184`, 0.7847521968079433], 
              Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7692897357415935`, -0.8950134580602265}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 1, {
              Complex[2.7692897357415935`, -0.8950134580602265], 
              Complex[4.139022292544098, -2.271338727751554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832466418480638, 0.7897219887964373}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.770097875160309, -0.8995532789895441}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 1, {
              Complex[2.770097875160309, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83223642523709, 0.7946478095124515}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 2, {
              Complex[2.83223642523709, 0.7946478095124515], 
              Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.770894693249766, -0.9040526005333875}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 1, {
              Complex[2.770894693249766, -0.9040526005333875], 
              Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832015492909507, 0.7995304720360317}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A", 2, {
              Complex[2.832015492909507, 0.7995304720360317], 
              Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.771680499538499, -0.9085121854432784}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 1, {
              Complex[2.771680499538499, -0.9085121854432784], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8318033265960922`, 0.8043707658042935}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A", 2, {
              Complex[2.8318033265960922`, 0.8043707658042935], 
              Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.772455591040422, -0.9129327741202401}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 1, {
              Complex[2.772455591040422, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8315996437819138`, 0.8091694575484238}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 2, {
              Complex[2.8315996437819138`, 0.8091694575484238], 
              Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.773220252914124, -0.9173150854995425}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 1, {
              Complex[2.773220252914124, -0.9173150854995425], 
              Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8314041736809603`, 0.8139272921843714}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 2, {
              Complex[2.8314041736809603`, 0.8139272921843714], 
              Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7739747590798687`, -0.9216598178919512}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 1, {
              Complex[2.7739747590798687`, -0.9216598178919512], 
              Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8312166566204735`, 0.8186449936599106}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 2, {
              Complex[2.8312166566204735`, 0.8186449936599106], 
              Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.774719372797445, -0.9259676497839711}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 1, {
              Complex[2.774719372797445, -0.9259676497839711], 
              Complex[4.148512526970578, -2.306826396101705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8310368434643864`, 0.8233232657606014}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A", 2, {
              Complex[2.8310368434643864`, 0.8233232657606014], 
              Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.775454347207829, -0.9302392405994732}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 1, {
              Complex[2.775454347207829, -0.9302392405994732], 
              Complex[4.149808341378721, -2.311725622493254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8308644950729818`, 0.8279627928769887}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A", 2, {
              Complex[2.8308644950729818`, 0.8279627928769887], 
              Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.776179925841262, -0.9344752314248258}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 1, {
              Complex[2.776179925841262, -0.9344752314248258], 
              Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8306993817960873`, 0.8325642407352367}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A", 2, {
              Complex[2.8306993817960873`, 0.8325642407352367], 
              Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.443592558752203, -0.6433017314670934}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 1, {
              Complex[3.8395927484273833`, -0.6433017314670934], 
              Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.5528337007854622`, 0.006645071137818026}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B", 2, {
              Complex[7.8360190079650485`, 0.006645071137818026], 
              Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.4082043953232866`, -0.6165221792948034}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 1, {
              Complex[3.8749809118562997`, -0.6165221792948034], 
              Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.512716472041693, 0.006712510785854963}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B", 2, {
              Complex[7.795901779221279, 0.006712510785854963], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.378615207976996, -0.5952855745698094}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 1, {
              Complex[3.9045700992025902`, -0.5952855745698094], 
              Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.4802992146191079`, 0.006786025025048383}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B", 2, {
              Complex[7.763484521798694, 0.006786025025048383], 
              Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.3524345158663564`, -0.5773156862277917}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 1, {
              Complex[3.93075079131323, -0.5773156862277917], 
              Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.4523626652609485`, 0.006863336573144897}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B", 2, {
              Complex[7.735547972440535, 0.006863336573144897], 
              Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.328572412687399, -0.5615718710865847}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 1, {
              Complex[3.9546128944921874`, -0.5615718710865847], 
              Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.4274439782504125`, 0.00694346149760476}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B", 2, {
              Complex[7.710629285429999, 0.00694346149760476], 
              Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.306422507697404, -0.5474736791133854}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 1, {
              Complex[3.976762799482182, -0.5474736791133854], 
              Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.4047319795533264`, 0.007025882918871702}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B", 2, {
              Complex[7.687917286732913, 0.007025882918871702], 
              Complex[6.045167287063117, -1.163332885610651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.285605940926922, -0.5346576120369394}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 1, {
              Complex[3.997579366252664, -0.5346576120369394], 
              Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.3837215835199812`, 0.007110298008162871}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B", 2, {
              Complex[7.666906890699567, 0.007110298008162871], 
              Complex[6.023558855884935, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.265867081430401, -0.5228778864146391}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 1, {
              Complex[4.017318225749185, -0.5228778864146391], 
              Complex[1.970954950697273, -2.009827028796297]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.3640731790593073`, 0.007196517077880152}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B", 2, {
              Complex[7.6472584862388935`, 0.007196517077880152], 
              Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.2470236787991285`, -0.5119589442981466}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 1, {
              Complex[4.036161628380458, -0.5119589442981466], 
              Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{1.3455455149607198`, 0.0072844163322486775`}],
            
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B", 2, {
              Complex[7.628730822140306, 0.0072844163322486775`], 
              Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.2289402916375805`, -0.5017701062164085}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 1, {
              Complex[4.054245015542006, -0.5017701062164085], 
              Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.3279599702943496`, 0.007373913179256576}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B", 2, {
              Complex[7.611145277473936, 0.007373913179256576], 
              Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.211512943380857, -0.49221091488169333`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 1, {
              Complex[4.071672363798729, -0.49221091488169333`], 
              Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.3111799475661403`, 0.0074649522520338}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B", 2, {
              Complex[7.5943652547457265`, 0.0074649522520338], 
              Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.194659699680801, -0.4832021231088809}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 1, {
              Complex[4.088525607498785, -0.4832021231088809], 
              Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{1.2950982340658763`, 0.0075574969911607935`}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B", 2, {
              Complex[7.5782835412454626`, 0.0075574969911607935`], 
              Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.178314592581989, -0.4746798749981737}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 1, {
              Complex[4.104870714597597, -0.4746798749981737], 
              Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2796288623475283`, 0.007651524322598731}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B", 2, {
              Complex[7.5628141695271145`, 0.007651524322598731], 
              Complex[5.915830554816423, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-2.1624235437437465`, -0.46659179640833626`}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 1, {
              Complex[4.12076176343584, -0.46659179640833626`], 
              Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2647016554741128`, 0.00774702115719995}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B", 2, {
              Complex[7.547886962653699, 0.00774702115719995], 
              Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.1469415369971063`, -0.4588942798973108}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 1, {
              Complex[4.13624377018248, -0.4588942798973108], 
              Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2502584485538728`, 0.007843982012263152}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B", 2, {
              Complex[7.533443755733459, 0.007843982012263152], 
              Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.1318306017829034`, -0.4515505457349306}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 1, {
              Complex[4.151354705396683, -0.4515505457349306], 
              Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2362503972473142`, 0.007942407351021058}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B", 2, {
              Complex[7.5194357044269005`, 0.007942407351021058], 
              Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-2.1170583400536973`, -0.44452922359237873`}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 1, {
              Complex[4.166126967125889, -0.44452922359237873`], 
              Complex[2.119679474265542, -1.918057531021161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2226360140934363`, 0.008042302396705316}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B", 2, {
              Complex[7.5058213212730225`, 0.008042302396705316], 
              Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.10259682760124, -0.43780329333443724`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 1, {
              Complex[4.180588479578346, -0.43780329333443724`], 
              Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.2093797058055777`, 0.008143676269233487}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B", 2, {
              Complex[7.492565012985164, 0.008143676269233487], 
              Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-2.0884217796106777`, -0.43134927949335283`}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 1, {
              Complex[4.194763527568909, -0.43134927949335283`], 
              Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1964506637638506`, 0.008246541346654087}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B", 2, {
              Complex[7.479635970943437, 0.008246541346654087], 
              Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.074511906642992, -0.42514662876555215`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 1, {
              Complex[4.208673400536594, -0.42514662876555215`], 
              Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1838220088181233`, 0.008350912786614366}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B", 2, {
              Complex[7.4670073159977095`, 0.008350912786614366], 
              Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.060848410440225, -0.41917722203755803`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 1, {
              Complex[4.222336896739361, -0.41917722203755803`], 
              Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1714701226446644`, 0.008456808164000526}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B", 2, {
              Complex[7.454655429824251, 0.008456808164000526], 
              Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-2.0474145841158418`, -0.41342498695324215`}],
            
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 1, {
              Complex[4.2357707230637445`, -0.41342498695324215`], 
              Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1593741182440898`, 0.008564247194411552}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B", 2, {
              Complex[7.442559425423676, 0.008564247194411552], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.034195491444378, -0.4078755867501412}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 1, {
              Complex[4.248989815735208, -0.4078755867501412], 
              Complex[2.203596585722578, -1.872357412196735]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1475154157759544`, 0.008673251522090992}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B", 2, {
              Complex[7.430700722955541, 0.008673251522090992], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-2.0211777069012626`, -0.4025161677361105}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 1, {
              Complex[4.262007600278324, -0.4025161677361105], 
              Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1358773992177111`, 0.008783844556995738}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B", 2, {
              Complex[7.419062706397297, 0.008783844556995738], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-2.0083491029329874`, -0.39733515240586165`}],
            
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 1, {
              Complex[4.274836204246599, -0.39733515240586165`], 
              Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1244451358006913`, 0.00889605134985899}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B", 2, {
              Complex[7.4076304429802775`, 0.00889605134985899], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.9956986743571195`, -0.39232206847656975`}],
            
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 1, {
              Complex[4.287486632822467, -0.39232206847656975`], 
              Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1132051447504105`, 0.009009898497033932}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B", 2, {
              Complex[7.396390451929997, 0.009009898497033932], 
              Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.9832163922501822`, -0.38746740648134725`}],
            
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 1, {
              Complex[4.299968914929404, -0.38746740648134725`], 
              Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.1021452051454963`, 0.009125414068990404}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B", 2, {
              Complex[7.3853305123250825`, 0.009125414068990404], 
              Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.9708930814742063`, -0.3827625002813669}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 1, {
              Complex[4.31229222570538, -0.3827625002813669], 
              Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.0912541951051313`, 0.00924262755784085}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B", 2, {
              Complex[7.374439502284718, 0.00924262755784085], 
              Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.95872031731695, -0.3781994261302779}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 1, {
              Complex[4.324464989862636, -0.3781994261302779], 
              Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.0805219562828396`, 0.009361569840391621}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B", 2, {
              Complex[7.363707263462426, 0.009361569840391621], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.9466903377106153`, -0.3737709168766498}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 1, {
              Complex[4.336494969468971, -0.3737709168766498], 
              Complex[2.293253543143011, -1.82773180818695]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.069939178965714, 0.009482273153988793}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B", 2, {
              Complex[7.3531244861453, 0.009482273153988793], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.9347959682419011`, -0.36947028861032294`}],
            
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 1, {
              Complex[4.348389338937685, -0.36947028861032294`], 
              Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.059497304075391, 0.009604771083122523}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.9230305577373388`, -0.3652913776086266}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 1, {
              Complex[4.3601547494422475`, -0.3652913776086266], 
              Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.0491884391284891`, 0.009729098555121761}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B", 2, {
              Complex[7.332373746308075, 0.009729098555121761], 
              Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.9113879226479638`, -0.36122848586285683`}],
            
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 1, {
              Complex[4.3717973845316225`, -0.36122848586285683`], 
              Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.0390052858002914`, 0.009855291843704485}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B", 2, {
              Complex[7.322190592979878, 0.009855291843704485], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.8998622987995866`, -0.35727633379543705`}],
            
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 1, {
              Complex[4.38332300838, -0.35727633379543705`], 
              Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.028941077191016, 0.009983388579384756}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B", 2, {
              Complex[7.312126384370602, 0.009983388579384756], 
              Complex[5.651636660481892, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.888448299343212, -0.35343001903737564`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 1, {
              Complex[4.394737007836374, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.018989523250868, 0.010113427765967268`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B", 2, {
              Complex[7.302174830430454, 0.010113427765967268`], 
              Complex[5.641006995243322, -1.162436027385382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.8771408779520566`, -0.3496849803402998}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 1, {
              Complex[4.40604442922753, -0.3496849803402998], 
              Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{1.0091447631018484`, 0.010245449802525817`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B", 2, {
              Complex[7.292330070281435, 0.010245449802525817`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.86593529648031, -0.3460369658605059}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 1, {
              Complex[4.417250010699276, -0.3460369658605059], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9994013232182901, 0.010379496510400103`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B", 2, {
              Complex[7.282586630397876, 0.010379496510400103`], 
              Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.8548270964338398`, -0.34248200518323846`}],
            
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 1, {
              Complex[4.428358210745746, -0.34248200518323846`], 
              Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9897540806075193, 0.010515611164854442`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B", 2, {
              Complex[7.272939387787106, 0.010515611164854442`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.8438120737120478`, -0.3390163845608803}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 1, {
              Complex[4.439373233467538, -0.3390163845608803], 
              Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9801982302766099, 0.010653838531129386`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B", 2, {
              Complex[7.263383537456196, 0.010653838531129386`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.8328862561683845`, -0.3356366249244736}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 1, {
              Complex[4.450299051011202, -0.3356366249244736], 
              Complex[2.411607470734253, -1.774754506235453]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9707292563883376, 0.010794224904694137`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B", 2, {
              Complex[7.253914563567924, 0.010794224904694137`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.8220458836091993`, -0.33233946229789096`}],
            
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 1, {
              Complex[4.461139423570387, -0.33233946229789096`], 
              Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9613429066049921, 0.010936818155564378`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B", 2, {
              Complex[7.244528213784578, 0.010936818155564378`], 
              Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.8112873899096904`, -0.3291218303014387}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 1, {
              Complex[4.471897917269896, -0.3291218303014387], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.952035169197087, 0.01108166777660797}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B", 2, {
              Complex[7.235220476376673, 0.01108166777660797], 
              Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.8006073869745203`, -0.3259808444790341}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 1, {
              Complex[4.482577920205066, -0.3259808444790341], 
              Complex[2.445554179476747, -1.760702890657421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9428022525584296, 0.011228824935798491`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B", 2, {
              Complex[7.225987559738016, 0.011228824935798491`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.7900026503110267`, -0.32291378822242134`}],
            
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 1, {
              Complex[4.4931826568685596`, -0.32291378822242134`], 
              Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9336405668225485, 0.011378342532423407`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B", 2, {
              Complex[7.216825874002135, 0.011378342532423407`], 
              Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.7794701060165856`, -0.3199181000986165}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 1, {
              Complex[4.503715201163001, -0.3199181000986165], 
              Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9245467073198483, 0.011530275257279964`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B", 2, {
              Complex[7.207732014499435, 0.011530275257279964`], 
              Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.7690068190098334`, -0.31699136241415254`}],
            
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 1, {
              Complex[4.514178488169753, -0.31699136241415254`], 
              Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.9155174396520191, 0.011684679656931228`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B", 2, {
              Complex[7.198702746831605, 0.011684679656931228`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.758609982358979, -0.31413129087274355`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 1, {
              Complex[4.524575324820607, -0.31413129087274355`], 
              Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.906549686191358, 0.011841614202115805`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B", 2, {
              Complex[7.189734993370944, 0.011841614202115805`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.7482769075803786`, -0.3113357252023988}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 1, {
              Complex[4.534908399599208, -0.3113357252023988], 
              Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.897640513838919, 0.012001139360437759`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B", 2, {
              Complex[7.180825821018505, 0.012001139360437759`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.7380050157973779`, -0.3086026206444535}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 1, {
              Complex[4.545180291382208, -0.3086026206444535], 
              Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.888787122897579, 0.012163317673485156`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B", 2, {
              Complex[7.171972430077165, 0.012163317673485156`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.7277918296636585`, -0.3059300402110033}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 1, {
              Complex[4.555393477515928, -0.3059300402110033], 
              Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8799868369348998, 0.012328213838552503`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B", 2, {
              Complex[7.163172144114486, 0.012328213838552503`], 
              Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.7176349659675356`, -0.3033161476291155}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 1, {
              Complex[4.565550341212051, -0.3033161476291155], 
              Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8712370935267648, 0.012495894795164308`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B", 2, {
              Complex[7.154422400706351, 0.012495894795164308`], 
              Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.7075321288440808`, -0.30075920090048514`}],
            
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 1, {
              Complex[4.5756531783355054`, -0.30075920090048514`], 
              Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8625354357863788, 0.012666429816627278`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B", 2, {
              Complex[7.145720742965965, 0.012666429816627278`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6974811035308113`, -0.2982575464138705}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 1, {
              Complex[4.585704203648775, -0.2982575464138705], 
              Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8538795045950156, 0.012839890606854724`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B", 2, {
              Complex[7.137064811774602, 0.012839890606854724`], 
              Complex[5.463037520285709, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6874797506103958`, -0.2958096135553045}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 1, {
              Complex[4.59570555656919, -0.2958096135553045], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8452670314609492, 0.013016351402742217`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B", 2, {
              Complex[7.128452338640535, 0.013016351402742217`], 
              Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6775260006904533`, -0.2934139097675642}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 1, {
              Complex[4.605659306489133, -0.2934139097675642], 
              Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8366958319417321, 0.01319588908239133}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B", 2, {
              Complex[7.119881139121318, 0.01319588908239133], 
              Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6676178494762155`, -0.2910690160160602}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 1, {
              Complex[4.615567457703371, -0.2910690160160602], 
              Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8281637995724456, 0.013378583279512458`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B", 2, {
              Complex[7.111349106752032, 0.013378583279512458`], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6577533531968163`, -0.2887735826232172}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 1, {
              Complex[4.62543195398277, -0.2887735826232172], 
              Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8196689002491322, 0.013564516504362785`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B", 2, {
              Complex[7.102854207428718, 0.013564516504362785`], 
              Complex[5.425781575481577, -1.161018749909008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6479306243502734`, -0.286526325437767}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 1, {
              Complex[4.635254682829313, -0.286526325437767], 
              Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8112091670222208, 0.013753774271608687`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B", 2, {
              Complex[7.094394474201807, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6381478277359784`, -0.2843260223090588}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 1, {
              Complex[4.645037479443608, -0.2843260223090588], 
              Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.8027826952597081, 0.013946445235532949`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B", 2, {
              Complex[7.085968002439294, 0.013946445235532949`], 
              Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6284031767468123`, -0.2821715098398547}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 1, {
              Complex[4.654782130432774, -0.2821715098398547], 
              Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7943876381441664, 0.014142621333044114`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B", 2, {
              Complex[7.077572945323753, 0.014142621333044114`], 
              Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.618694929895847, -0.28006168039394375`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 1, {
              Complex[4.664490377283739, -0.28006168039394375`], 
              Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7860222024713899, 0.014342397934981436`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B", 2, {
              Complex[7.069207509650976, 0.014342397934981436`], 
              Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.6090213875551438`, -0.2779954793374564}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 1, {
              Complex[4.674163919624442, -0.2779954793374564], 
              Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7776846447217975, 0.014545874006250832`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B", 2, {
              Complex[7.060869951901384, 0.014545874006250832`], 
              Complex[5.379881023870965, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.5993808888863352`, -0.2759719024950625}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 1, {
              Complex[4.683804418293251, -0.2759719024950625], 
              Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7693732673786151, 0.014753152275367028`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B", 2, {
              Complex[7.052558574558201, 0.014753152275367028`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.589771808944624, -0.2739899938041945}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 1, {
              Complex[4.693413498234962, -0.2739899938041945], 
              Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7610864154693759, 0.014964339414035013`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B", 2, {
              Complex[7.044271722648962, 0.014964339414035013`], 
              Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.580192555939548, -0.27204884315225375`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 1, {
              Complex[4.702992751240038, -0.27204884315225375`], 
              Complex[2.68192509329917, -1.67547959713909]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7528224733095374, 0.015179546227436098`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B", 2, {
              Complex[7.036007780489124, 0.015179546227436098`], 
              Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.5706415686373951`, -0.2701475843833519}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 1, {
              Complex[4.712543738542191, -0.2701475843833519], 
              Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7445798614289858, 0.01539888785596537}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B", 2, {
              Complex[7.027765168608572, 0.01539888785596537], 
              Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.5611173138913674`, -0.2682853934625311}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 1, {
              Complex[4.722067993288219, -0.2682853934625311], 
              Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7363570336639089, 0.015622483989198223`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B", 2, {
              Complex[7.019542340843495, 0.015622483989198223`], 
              Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.551618284286942, -0.26646148678673676`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 1, {
              Complex[4.731567022892644, -0.26646148678673676`], 
              Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7281524743981311, 0.015850459092959842`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B", 2, {
              Complex[7.011337781577717, 0.015850459092959842`], 
              Complex[5.325475035055747, -1.159899171471262]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.542142995890714, -0.26467511963294066`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 1, {
              Complex[4.741042311288872, -0.26467511963294066`], 
              Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7199646959392574, 0.016082942650415873`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B", 2, {
              Complex[7.003150003118844, 0.016082942650415873`], 
              Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.532689986092076, -0.26292558473487176`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 1, {
              Complex[4.75049532108751, -0.26292558473487176`], 
              Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.711792236016259, 0.016320069418202337`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B", 2, {
              Complex[6.994977543195845, 0.016320069418202337`], 
              Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.5232578115277864`, -0.2612122109807508}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 1, {
              Complex[4.7599274956518, -0.2612122109807508], 
              Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.7036336553861569, 0.016561979698683896`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B", 2, {
              Complex[6.986818962565743, 0.016561979698683896`], 
              Complex[5.298442228350345, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.5138450460802328`, -0.2595343622253304}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 1, {
              Complex[4.769340261099353, -0.2595343622253304], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6954875355383967, 0.01680881962953298}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B", 2, {
              Complex[6.978672842717983, 0.01680881962953298], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.5044502789407952`, -0.25789143621028987`}],
            
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 1, {
              Complex[4.778735028238791, -0.25789143621028987`], 
              Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.687352476486339, 0.017060741491919468`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B", 2, {
              Complex[6.970537783665925, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.4950721127302682`, -0.256282863587831}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 1, {
              Complex[4.788113194449318, -0.256282863587831], 
              Complex[2.775317254506115, -1.647405199653864]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6792270946360048, 0.017317904038714253`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B", 2, {
              Complex[6.962412401815591, 0.017317904038714253`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.4857091616687566`, -0.2547081070429694}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 1, {
              Complex[4.79747614551083, -0.2547081070429694], 
              Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6711100207228577, 0.01758047284423772}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B", 2, {
              Complex[6.954295327902444, 0.01758047284423772], 
              Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.4763600497878686`, -0.2531666605106761}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 1, {
              Complex[4.806825257391718, -0.2531666605106761], 
              Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6629998978079712, 0.017848620677213628`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B", 2, {
              Complex[6.946185204987557, 0.017848620677213628`], 
              Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.4670234091784007`, -0.2516580484846366}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 1, {
              Complex[4.8161618980011855`, -0.2516580484846366], 
              Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.654895379325378, 0.018122527898744748`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B", 2, {
              Complex[6.938080686504964, 0.018122527898744748`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.457697878266945, -0.2501818254149765}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 1, {
              Complex[4.825487428912641, -0.2501818254149765], 
              Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6467951271728616, 0.01840238288728782}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B", 2, {
              Complex[6.929980434352448, 0.01840238288728782], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4483821001152055`, -0.24873757519284634`}],
            
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6386978098387495, 0.018688382492788213`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B", 2, {
              Complex[6.921883117018336, 0.018688382492788213`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4390747207358539`, -0.24732491072033783`}],
            
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 1, {
              Complex[4.844110586443732, -0.24732491072033783`], 
              Complex[2.837373837167927, -1.630395790115732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6306021005576197, 0.018980732522336733`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B", 2, {
              Complex[6.913787407737206, 0.018980732522336733`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4297743874190818`, -0.24594347356467788`}],
            
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 1, {
              Complex[4.853410919760504, -0.24594347356467788`], 
              Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6225066754880437, 0.01927964825993098}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B", 2, {
              Complex[6.90569198266763, 0.01927964825993098], 
              Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4204797470639878`, -0.24459293369624477`}],
            
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 1, {
              Complex[4.862705560115598, -0.24459293369624477`], 
              Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6144102119056924, 0.01958535502317048}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B", 2, {
              Complex[6.897595519085279, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4111894445090956`, -0.24327298931041968`}],
            
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 1, {
              Complex[4.871995862670491, -0.24327298931041968`], 
              Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.6063113864052889, 0.019898088759987553`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B", 2, {
              Complex[6.889496693584875, 0.019898088759987553`], 
              Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.4019021208563105`, -0.24198336673385487`}],
            
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 1, {
              Complex[4.881283186323276, -0.24198336673385487`], 
              Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.598208873105003, 0.020218096688815555`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B", 2, {
              Complex[6.881394180284589, 0.020218096688815555`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3926164117826447`, -0.24072382041628823`}],
            
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 1, {
              Complex[4.8905688953969415`, -0.24072382041628823`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.590101341846939, 0.020545637985932938`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B", 2, {
              Complex[6.873286649026525, 0.020545637985932938`], 
              Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3833309458339702`, -0.23949413300958752`}],
            
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 1, {
              Complex[4.899854361345616, -0.23949413300958752`], 
              Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5819874563873926, 0.020880984524095033`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B", 2, {
              Complex[6.865172763566979, 0.020880984524095033`], 
              Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3740443426950764`, -0.23829411553630825`}],
            
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 1, {
              Complex[4.90914096448451, -0.23829411553630825`], 
              Complex[2.910034828740951, -1.612121547840817]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5738658725705488, 0.021224421666976113`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B", 2, {
              Complex[6.857051179750135, 0.021224421666976113`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.3647552114301336`, -0.2371236076506873}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 1, {
              Complex[4.918430095749453, -0.2371236076506873], 
              Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5657352364792381, 0.02157624912441265}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B", 2, {
              Complex[6.848920543658824, 0.02157624912441265], 
              Complex[5.145157618862018, -1.156595047683686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3554621486875433`, -0.23598247799562702`}],
            
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 1, {
              Complex[4.927723158492043, -0.23598247799562702`], 
              Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5575941825562714, 0.021936781873947195`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B", 2, {
              Complex[6.840779489735858, 0.021936781873947195`], 
              Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3461637368630859`, -0.23487062465998587`}],
            
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 1, {
              Complex[4.9370215703165, -0.23487062465998587`], 
              Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5494413316897475, 0.022306351154756456`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B", 2, {
              Complex[6.832626638869334, 0.022306351154756456`], 
              Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.3368585422149009`, -0.2337879757412101}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 1, {
              Complex[4.946326764964685, -0.2337879757412101], 
              Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5412752892555845, 0.022685305540684226`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B", 2, {
              Complex[6.824460596435171, 0.022685305540684226`], 
              Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.3275451129237874`, -0.2327344900192291}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 1, {
              Complex[4.955640194255799, -0.2327344900192291], 
              Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5330946431102754, 0.023074012099830184`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B", 2, {
              Complex[6.816279950289862, 0.023074012099830184`], 
              Complex[5.108566172536498, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.3182219770919197`, -0.23171015774841372`}],
            
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 1, {
              Complex[4.9649633300876665`, -0.23171015774841372`], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5248979615266851, 0.02347285764894464}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B", 2, {
              Complex[6.808083268706271, 0.02347285764894464], 
              Complex[5.099358827456356, -1.155369598409927]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.3088876406728005`, -0.2307150015754329}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 1, {
              Complex[4.974297666506786, -0.2307150015754329], 
              Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5166837910653701, 0.023882250111808064`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B", 2, {
              Complex[6.799869098244956, 0.023882250111808064`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2995405853249542`, -0.22974907759194269`}],
            
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 1, {
              Complex[4.983644721854632, -0.22974907759194269`], 
              Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.5084506543736422, 0.024302619991773983`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B", 2, {
              Complex[6.7916359615532285`, 0.024302619991773983`], 
              Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2901792661814513`, -0.22881247653229808`}],
            
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 1, {
              Complex[4.993006040998135, -0.22881247653229808`], 
              Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.500197047904166, 0.024734421969834053`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B", 2, {
              Complex[6.783382355083752, 0.024734421969834053`], 
              Complex[5.071567299655017, -1.154523602824754]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2808021095269577`, -0.22790532512782422`}],
            
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 1, {
              Complex[5.0023831976526285`, -0.22790532512782422`], 
              Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.49192143954457457`, 0.02517813664084302}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B", 2, {
              Complex[6.775106746724161, 0.02517813664084302], 
              Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.2714075103735283`, -0.2270277876307708}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.025955129189635, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.48362226614904014`, 0.02563427240203126}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B", 2, {
              Complex[6.766807573328626, 0.02563427240203126], 
              Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.261993829925891, -0.2261800675227632}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 1, {
              Complex[5.021191477253695, -0.2261800675227632], 
              Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.47529793096237327`, 0.02610336750958422}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B", 2, {
              Complex[6.7584832381419595`, 0.02610336750958422], 
              Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2525593929264218`, -0.22536240942454472`}],
            
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 1, {
              Complex[5.030625914253164, -0.22536240942454472`], 
              Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.46694680092661134`, 0.026585992320966013`}],
            
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B", 2, {
              Complex[6.750132108106198, 0.026585992320966013`], 
              Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.243102484869432, -0.22457510122598082`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 1, {
              Complex[5.040082822310154, -0.22457510122598082`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.4585672038595803, 0.02708275174279656}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B", 2, {
              Complex[6.7417525110391665`, 0.02708275174279656], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.233621349073851, -0.22381847645779873`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 1, {
              Complex[5.049563958105735, -0.22381847645779873`], 
              Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.4501574254942575, 0.027594287906544456`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B", 2, {
              Complex[6.733342732673844, 0.027594287906544456`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2241141836026497`, -0.22309291692935682`}],
            
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 1, {
              Complex[5.059071123576937, -0.22309291692935682`], 
              Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.44171570636723256`, 0.02812128309705345}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B", 2, {
              Complex[6.724901013546819, 0.02812128309705345], 
              Complex[5.005499610747705, -1.15214256927739]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2145791380168456`, -0.22239885565995454`}],
            
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 1, {
              Complex[5.068606169162741, -0.22239885565995454`], 
              Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.43324023854383586`, 0.02866446296210377}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B", 2, {
              Complex[6.716425545723422, 0.02866446296210377], 
              Complex[4.995893274766249, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.2050143099511326`, -0.22173678013483544`}],
            
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 1, {
              Complex[5.078170997228454, -0.22173678013483544`], 
              Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.4247291621669387, 0.029224600034819193`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B", 2, {
              Complex[6.707914469346525, 0.029224600034819193`], 
              Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.195417741497633, -0.22110723592124715`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 1, {
              Complex[5.087767565681953, -0.22110723592124715`], 
              Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.41618056181572793`, 0.02980251760487493}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B", 2, {
              Complex[6.699365868995314, 0.02980251760487493], 
              Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.18578741538356, -0.2205108306846836}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 1, {
              Complex[5.097397891796026, -0.2205108306846836], 
              Complex[3.123750747268463, -1.568770237634814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.40759246266015925`, 0.030399093979211252`}],
            
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B", 2, {
              Complex[6.6907777698397455`, 0.030399093979211252`], 
              Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.1761212509280456`, -0.21994823865093072`}],
            
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 1, {
              Complex[5.107064056251541, -0.21994823865093072`], 
              Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.39896282639620484`, 0.03101526717841391}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B", 2, {
              Complex[6.682148133575791, 0.03101526717841391], 
              Complex[4.956961006232221, -1.149994992121425]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.1664170997628345`, -0.21942020556585193`}],
            
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 1, {
              Complex[5.116768207416752, -0.21942020556585193`], 
              Complex[3.146006672598035, -1.565190320272424]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.39028954694651574`, 0.031652040121196295`}],
            
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B", 2, {
              Complex[6.673474854126102, 0.031652040121196295`], 
              Complex[4.947089201235956, -1.149509834990993]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.156672741301203, -0.21892755421211518`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 1, {
              Complex[5.126512565878383, -0.21892755421211518`], 
              Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.38157044591073586`, 0.03231048635665902}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B", 2, {
              Complex[6.664755753090322, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.1468858779392317`, -0.21847119055042014`}],
            
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 1, {
              Complex[5.1362994292403545`, -0.21847119055042014`], 
              Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.372803267749525, 0.03299175641235}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B", 2, {
              Complex[6.655988574929111, 0.03299175641235], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.1370541299736567`, -0.21805211056251345`}],
            
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 1, {
              Complex[5.1461311772059295`, -0.21805211056251345`], 
              Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.36398567468641385`, 0.03369708483581625}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B", 2, {
              Complex[6.647170981866, 0.03369708483581625], 
              Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.12717503022093, -0.21767140788446362`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 1, {
              Complex[5.156010276958656, -0.21767140788446362`], 
              Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.3551152413120633, 0.03442779801852971}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B", 2, {
              Complex[6.6383005484916495`, 0.03442779801852971], 
              Complex[4.906968264234699, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.1172460183230868`, -0.2173302823316979}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 1, {
              Complex[5.1659392888564994`, -0.2173302823316979], 
              Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.3461894488764221, 0.03518532290406068}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B", 2, {
              Complex[6.629374756056008, 0.03518532290406068], 
              Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.1072644347276075`, -0.21703004943242454`}],
            
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 1, {
              Complex[5.175920872451979, -0.21703004943242454`], 
              Complex[3.214258836551336, -1.555411285239044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.33720567925591816`, 0.03597119669747851}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B", 2, {
              Complex[6.620390986435504, 0.03597119669747851], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0972275143310188`, -0.21677215110365716`}],
            
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 1, {
              Complex[5.185957792848567, -0.21677215110365716`], 
              Complex[3.225881858451649, -1.553934201044293]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.3281612085853798, 0.03678707771053715}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B", 2, {
              Complex[6.611346515764966, 0.03678707771053715], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0871323797797183`, -0.21655816762459845`}],
            
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 1, {
              Complex[5.196052927399868, -0.21655816762459845`], 
              Complex[3.237584411566567, -1.552504823512188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.31905320054806374`, 0.037634757497710766`}],
            
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B", 2, {
              Complex[6.60223850772765, 0.037634757497710766`], 
              Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.0769760344268784`, -0.2163898310860751}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 1, {
              Complex[5.206209272752708, -0.2163898310860751], 
              Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.30987869932263656`, 0.038516174462077585`}],
            
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B", 2, {
              Complex[6.593064006502223, 0.038516174462077585`], 
              Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0667553549517894`, -0.21626904052272788`}],
            
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 1, {
              Complex[5.216429952227797, -0.21626904052272788`], 
              Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.300634622193404, 0.03943342913804175}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B", 2, {
              Complex[6.58381992937299, 0.03943342913804175], 
              Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.0564670836583883`, -0.2161978789674424}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 1, {
              Complex[5.226718223521198, -0.2161978789674424], 
              Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2913177518404302, 0.040388801390635574`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B", 2, {
              Complex[6.574503059020016, 0.040388801390635574`], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0461078204836394`, -0.21617863270584659`}],
            
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 1, {
              Complex[5.237077486695947, -0.21617863270584659`], 
              Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2819247283402815, 0.04138476980950452}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B", 2, {
              Complex[6.565110035519868, 0.04138476980950452], 
              Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.035674014765572, -0.21621381305374007`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 1, {
              Complex[5.247511292414014, -0.21621381305374007`], 
              Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.27245204092703457`, 0.04242403362064838}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B", 2, {
              Complex[6.555637348106621, 0.04242403362064838], 
              Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0251619568459969`, -0.21630618103294588`}],
            
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 1, {
              Complex[5.258023350333589, -0.21630618103294588`], 
              Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.26289601958859965`, 0.04350953749168187}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B", 2, {
              Complex[6.546081326768186, 0.04350953749168187], 
              Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{-1.0145677696168853`, -0.21645877538292138`}],
            
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 1, {
              Complex[5.268617537562701, -0.21645877538292138`], 
              Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2532528266072882, 0.04464449966811444}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B", 2, {
              Complex[6.536438133786874, 0.04464449966811444], 
              Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-1.0038874001643494`, -0.2166749444176823}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 1, {
              Complex[5.279297907015237, -0.2166749444176823], 
              Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.24351844819853774`, 0.045832443950467455`}],
            
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B", 2, {
              Complex[6.526703755378124, 0.045832443950467455`], 
              Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9931166117239059, -0.21695838232209166`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 1, {
              Complex[5.29006869545568, -0.21695838232209166`], 
              Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2336886864614005, 0.047077236106415926`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B", 2, {
              Complex[6.516873993640987, 0.047077236106415926`], 
              Complex[4.767386408695089, -1.136665739909799]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9822509762396416, -0.21731317057992383`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 1, {
              Complex[5.300934330939945, -0.21731317057992383`], 
              Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.22375915193344387`, 0.04838312541060556}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B", 2, {
              Complex[6.50694445911303, 0.04838312541060556], 
              Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9712858679244905, -0.21774382534019754`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 1, {
              Complex[5.311899439255096, -0.21774382534019754`], 
              Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2137252571471917, 0.04975479211876483}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B", 2, {
              Complex[6.496910564326778, 0.04975479211876483], 
              Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9602164583568982, -0.21825535165974055`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 1, {
              Complex[5.322968848822688, -0.21825535165974055`], 
              Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.2035822117233792, 0.0511974018142995}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B", 2, {
              Complex[6.486767518902965, 0.0511974018142995], 
              Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9490377138316877, -0.21885330570991693`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 1, {
              Complex[5.334147593347899, -0.21885330570991693`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.19332501971882188`, 0.05271666771536847}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B", 2, {
              Complex[6.476510326898408, 0.05271666771536847], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9377443959239766, -0.21954386620430968`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 1, {
              Complex[5.34544091125561, -0.21954386620430968`], 
              Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.18294848018766086`, 0.05431892219952709}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B", 2, {
              Complex[6.466133787367247, 0.05431892219952709], 
              Complex[4.70854473004717, -1.130085166709498]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9263310665433186, -0.2203339164903332}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 1, {
              Complex[5.356854240636268, -0.2203339164903332], 
              Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.17244719223323024`, 0.05601119898888104}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B", 2, {
              Complex[6.4556324994128165`, 0.05601119898888104], 
              Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9147920991753367, -0.2212311389467491}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 1, {
              Complex[5.36839320800425, -0.2212311389467491], 
              Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.1618155662477072, 0.05780132763801389}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B", 2, {
              Complex[6.445000873427293, 0.05780132763801389], 
              Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.9031216985621144, -0.22224412353114406`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 1, {
              Complex[5.380063608617472, -0.22224412353114406`], 
              Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.15104784359083556`, 0.05969804216878785}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B", 2, {
              Complex[6.434233150770422, 0.05969804216878785], 
              Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8913139318018466, -0.22338249250843517`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 1, {
              Complex[5.39187137537774, -0.22338249250843517`], 
              Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{0.14013812768820166`, 0.061711105883242766`}],
            
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B", 2, {
              Complex[6.423323434867788, 0.061711105883242766`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8793627748059114, -0.2246570435317341}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 1, {
              Complex[5.403822532373675, -0.2246570435317341], 
              Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.12908043048718199`, 0.06385145452602968}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B", 2, {
              Complex[6.412265737666768, 0.06385145452602968], 
              Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8672621793036548, -0.22607991328743238`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 1, {
              Complex[5.415923127875931, -0.22607991328743238`], 
              Complex[3.49540764739327, -1.538992497237254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.11786873946086285`, 0.06613136000835822}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B", 2, {
              Complex[6.401054046640449, 0.06613136000835822], 
              Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8550061672124718, -0.22766476377118722`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 1, {
              Complex[5.428179139967114, -0.22766476377118722`], 
              Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.10649711197748513`, 0.06856461676025156}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B", 2, {
              Complex[6.389682419157071, 0.06856461676025156], 
              Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.842588961285708, -0.22942699279424578`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 1, {
              Complex[5.440596345893878, -0.22942699279424578`], 
              Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.09495980594794684, 0.07116675231062962}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B", 2, {
              Complex[6.378145113127533, 0.07116675231062962], 
              Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8300051636105072, -0.23138396931833927`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 1, {
              Complex[5.453180143569079, -0.23138396931833927`], 
              Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.08325145832342429, 0.07395526269357508}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B", 2, {
              Complex[6.3664367655030105`, 0.07395526269357508], 
              Complex[4.591951242060748, -1.111090937656241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8172499968341622, -0.23355529236003053`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 1, {
              Complex[5.465935310345424, -0.23355529236003053`], 
              Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.07136732632170784, 0.07694987142174026}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B", 2, {
              Complex[6.354552633501294, 0.07694987142174026], 
              Complex[4.577957240848536, -1.108080936651698]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.8043196269768034, -0.23596306901323125`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 1, {
              Complex[5.478865680202783, -0.23596306901323125`], 
              Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.059303610240065474`, 0.08017280757570108}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B", 2, {
              Complex[6.342488917419652, 0.08017280757570108], 
              Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7912115912320683, -0.2386322019223144}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 1, {
              Complex[5.491973715947518, -0.2386322019223144], 
              Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.047057881256217016`, 0.08364909334179328}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B", 2, {
              Complex[6.330243188435803, 0.08364909334179328], 
              Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7779253588801698, -0.2415906683469046}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 1, {
              Complex[5.5052599482994165`, -0.2415906683469046], 
              Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.034629642341895917`, 0.08740682313953926}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B", 2, {
              Complex[6.317814949521482, 0.08740682313953926], 
              Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7644630574380749, -0.24486976056502427`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 1, {
              Complex[5.518722249741511, -0.24486976056502427`], 
              Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.02202105441366342, 0.09147740408549994}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B", 2, {
              Complex[6.30520636159325, 0.09147740408549994], 
              Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7508303976539636, -0.24850423935263424`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 1, {
              Complex[5.532354909525623, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{0.009237861328110775, 0.09589570953158878}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B", 2, {
              Complex[6.292423168507697, 0.09589570953158878], 
              Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7370378267001652, -0.25253232740394727`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 1, {
              Complex[5.546147480479421, -0.25253232740394727`], 
              Complex[3.650990035081118, -1.556521435684903]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.003709456924299026, 0.10070007254234241`}],
            
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B", 2, {
              Complex[6.279475850255287, 0.10070007254234241`], 
              Complex[4.488987856730723, -1.083460700125328]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7231019236773744, -0.2569954375693105}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 1, {
              Complex[5.560083383502212, -0.2569954375693105], 
              Complex[3.667805619167921, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.01680428871401496, 0.10593201418800262`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B", 2, {
              Complex[6.266381018465571, 0.10593201418800262`], 
              Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.7090470176281567, -0.26193749411720274`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 1, {
              Complex[5.5741382895514295`, -0.26193749411720274`], 
              Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.030022272757785906`, 0.11163556486001082`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B", 2, {
              Complex[6.2531630344218, 0.11163556486001082`], 
              Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6949069461369577, -0.267403671805992}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 1, {
              Complex[5.5882783610426285`, -0.267403671805992], 
              Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.04332953951742624, 0.11785600339462998`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B", 2, {
              Complex[6.23985576766216, 0.11785600339462998`], 
              Complex[4.44156860245767, -1.065050990167949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6807267739206289, -0.2734383645589251}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 1, {
              Complex[5.602458533258957, -0.2734383645589251], 
              Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.056680992607984315`, 0.12463782579822859`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B", 2, {
              Complex[6.226504314571602, 0.12463782579822859`], 
              Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6665641559532585, -0.2800822323034732}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 1, {
              Complex[5.616621151226328, -0.2800822323034732], 
              Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.07001894567151101, 0.13202179213539816`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B", 2, {
              Complex[6.213166361508075, 0.13202179213539816`], 
              Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6524898808463258, -0.2873682998621296}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 1, {
              Complex[5.6306954263332605`, -0.2873682998621296], 
              Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.08327257899544538, 0.14004102546706554`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B", 2, {
              Complex[6.199912728184141, 0.14004102546706554`], 
              Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6385870265200131, -0.29531732776612096`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 1, {
              Complex[5.644598280659573, -0.29531732776612096`], 
              Complex[3.770794613325991, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.09635878383971974, 0.1487163827100988}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.6249482002906337, -0.3039330313949986}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 1, {
              Complex[5.6582371068889525`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.10918492234776078`, 0.15805167382144575`}],
            
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B", 2, {
              Complex[6.1740003848318254`, 0.15805167382144575`], 
              Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.611670623538803, -0.31319809514055214`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 1, {
              Complex[5.671514683640783, -0.31319809514055214`], 
              Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.12165374287658093`, 0.16802967600526247`}],
            
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B", 2, {
              Complex[6.161531564303005, 0.16802967600526247`], 
              Complex[4.34645857273412, -1.009339964026806]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5988493827126256, -0.3230721172560274}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 1, {
              Complex[5.684335924466961, -0.3230721172560274], 
              Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.13367012899190378`, 0.1786100786041201}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B", 2, {
              Complex[6.1495151781876825`, 0.1786100786041201], 
              Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5865698557468226, -0.33349241406049873`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 1, {
              Complex[5.696615451432764, -0.33349241406049873`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.1451486730471938, 0.18973028734408198`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B", 2, {
              Complex[6.138036634132392, 0.18973028734408198`], 
              Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5749008146407251, -0.3443779449095292}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 1, {
              Complex[5.708284492538861, -0.3443779449095292], 
              Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.15602057360386734`, 0.20130934934495107`}],
            
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B", 2, {
              Complex[6.127164733575719, 0.20130934934495107`], 
              Complex[4.303885430470007, -0.971377104797332]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.563889680445322, -0.3556357121294631}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 1, {
              Complex[5.719295626734264, -0.3556357121294631], 
              Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.16623838044232375`, 0.21325435309295884`}],
            
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B", 2, {
              Complex[6.1169469267372625`, 0.21325435309295884`], 
              Complex[4.291086318485069, -0.957611110502011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5535608024597112, -0.3671682712416461}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 1, {
              Complex[5.729624504719875, -0.3671682712416461], 
              Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.1757777153635871, 0.22546793870233275`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B", 2, {
              Complex[6.107407591815999, 0.22546793870233275`], 
              Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5439167339733437, -0.37888080574180155`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 1, {
              Complex[5.7392685732062425`, -0.37888080574180155`], 
              Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.1846359964450901, 0.2378553727309036}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B", 2, {
              Complex[6.098549310734496, 0.2378553727309036], 
              Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5349417203269402, -0.3906866010723917}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 1, {
              Complex[5.748243586852646, -0.3906866010723917], 
              Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.1928289499777618, 0.2503300221877129}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B", 2, {
              Complex[6.0903563572018244`, 0.2503300221877129], 
              Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5266062877898463, -0.4025104167837189}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 1, {
              Complex[5.75657901938974, -0.4025104167837189], 
              Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.20038602158665597`, 0.26281672672835754`}],
            
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B", 2, {
              Complex[6.08279928559293, 0.26281672672835754`], 
              Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5188719227739398, -0.4142898642644478}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 1, {
              Complex[5.7643133844056464`, -0.4142898642644478], 
              Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.20734569701497296`, 0.27525317641875785`}],
            
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B", 2, {
              Complex[6.075839610164613, 0.27525317641875785`], 
              Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5116951683348692, -0.42597525546826004`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 1, {
              Complex[5.771490138844717, -0.42597525546826004`], 
              Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.21375140562076833`, 0.2875897604942178}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B", 2, {
              Complex[6.069433901558818, 0.2875897604942178], 
              Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.5050308308918483, -0.43752848511674675`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 1, {
              Complex[5.778154476287738, -0.43752848511674675`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.21964831365504534`, 0.2997884495937313}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B", 2, {
              Complex[6.063536993524541, 0.2997884495937313], 
              Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.49883426380710727`, -0.448921436448157}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 1, {
              Complex[5.784351043372479, -0.448921436448157], 
              Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2250810406801973, 0.311821201539341}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B", 2, {
              Complex[6.058104266499389, 0.311821201539341], 
              Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4930628477717809, -0.4601342612759226}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 1, {
              Complex[5.790122459407805, -0.4601342612759226], 
              Complex[3.95661157787795, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.23009217918198033`, 0.32366824142440104`}],
            
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B", 2, {
              Complex[6.053093127997606, 0.32366824142440104`], 
              Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.48767684505217357`, -0.4711537472500259}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 1, {
              Complex[5.795508462127413, -0.4711537472500259], 
              Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2347214403211133, 0.3353164289039027}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B", 2, {
              Complex[6.048463866858473, 0.3353164289039027], 
              Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4826398034979942, -0.4819718787730359}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 1, {
              Complex[5.800545503681592, -0.4819718787730359], 
              Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.23900524992289007`, 0.34675781913864817`}],
            
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B", 2, {
              Complex[6.044180057256696, 0.34675781913864817`], 
              Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4779186582338406, -0.4925846278657947}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 1, {
              Complex[5.805266648945746, -0.4925846278657947], 
              Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.24297664678352593`, 0.3579884536883503}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B", 2, {
              Complex[6.04020866039606, 0.3579884536883503], 
              Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.47348364383827235`, -0.5029909709021079}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 1, {
              Complex[5.809701663341314, -0.5029909709021079], 
              Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.24666537048889214`, 0.36900737727295657`}],
            
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B", 2, {
              Complex[6.036519936690694, 0.36900737727295657`], 
              Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4693080974149364, -0.5131921073476412}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 1, {
              Complex[5.81387720976465, -0.5131921073476412], 
              Complex[3.989240598169983, -1.836139309119696]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2500980583412753, 0.3798158565375278}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B", 2, {
              Complex[6.033087248838311, 0.3798158565375278], 
              Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.46536820689790304`, -0.5231908494724428}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 1, {
              Complex[5.817817100281683, -0.5231908494724428], 
              Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.25329849705179885`, 0.39041676979000506`}],
            
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B", 2, {
              Complex[6.029886810127787, 0.39041676979000506`], 
              Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.46164273959016544`, -0.5329911517598128}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 1, {
              Complex[5.821542567589421, -0.5329911517598128], 
              Complex[4.000015848490729, -1.858517093091784]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.25628789419976616`, 0.40081413643466185`}],
            
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4581127723386862, -0.5425977517885678}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 1, {
              Complex[5.8250725348409, -0.5425977517885678], 
              Complex[4.00502375333401, -1.869388672925242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.25908514805543703`, 0.4110127578783314}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B", 2, {
              Complex[6.024100159124149, 0.4110127578783314], 
              Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.45476143558287774`, -0.5520158986267112}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 1, {
              Complex[5.8284238715967085`, -0.5520158986267112], 
              Complex[4.009806376364359, -1.880054831501802]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2617071035293499, 0.4210179459473799}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B", 2, {
              Complex[6.021478203650236, 0.4210179459473799], 
              Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.45157367754980804`, -0.5612511491377962}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 1, {
              Complex[5.831611629629778, -0.5612511491377962], 
              Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2641687879749526, 0.4308353192168009}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B", 2, {
              Complex[6.019016519204634, 0.4308353192168009], 
              Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.44853605112486683`, -0.5703092165540443}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 1, {
              Complex[5.834649256054719, -0.5703092165540443], 
              Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.266483624315744, 0.4404706516054355}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B", 2, {
              Complex[6.016701682863842, 0.4404706516054355], 
              Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.44563652367108464`, -0.5791958590266288}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 1, {
              Complex[5.837548783508502, -0.5791958590266288], 
              Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2686636212238014, 0.4499297609478434}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B", 2, {
              Complex[6.014521685955785, 0.4499297609478434], 
              Complex[4.155898108440934, -0.675770415493782]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.44286430878652183`, -0.5879167986060267}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 1, {
              Complex[5.840320998393064, -0.5879167986060267], 
              Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2707195413602026, 0.4592184279956062}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B", 2, {
              Complex[6.012465765819384, 0.4592184279956062], 
              Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4402097183243878, -0.5964776632911535}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 1, {
              Complex[5.842975588855198, -0.5964776632911535], 
              Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.27266104935275504`, 0.4683423384869708}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B", 2, {
              Complex[6.010524257826831, 0.4683423384869708], 
              Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4376640327182866, -0.6048839465011082}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 1, {
              Complex[5.8455212744613, -0.6048839465011082], 
              Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{-0.27449684146863795`, 0.47730704263853474`}],
            
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B", 2, {
              Complex[6.008688465710948, 0.47730704263853474`], 
              Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.435219387601566, -0.6131409796537515}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 1, {
              Complex[5.84796591957802, -0.6131409796537515], 
              Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.276234758992814, 0.4861179277432377}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4328686747861914, -0.6212539145605389}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 1, {
              Complex[5.850316632393395, -0.6212539145605389], 
              Complex[4.04179388930688, -1.958660288701135]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2778818872471147, 0.4947802005841794}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B", 2, {
              Complex[6.0053034199324715`, 0.4947802005841794], 
              Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.43060545581047016`, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 1, {
              Complex[5.852579851369116, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2794446420403469, 0.5032988771597035}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B", 2, {
              Complex[6.003740665139239, 0.5032988771597035], 
              Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4284238864386145, -0.637067142498334}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.28092884516661876`, 0.5116787778163029}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B", 2, {
              Complex[6.0022564620129675`, 0.5116787778163029], 
              Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4263186506755634, -0.6447767740762016}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 1, {
              Complex[5.856866656504023, -0.6447767740762016], 
              Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2823397903884155, 0.519924526344405}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B", 2, {
              Complex[6.000845516791171, 0.519924526344405], 
              Complex[4.135993261432002, -0.5900329694879913]}, 0}, "Tooltip"]
           & ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.42428490303487276`, -0.6523609855265128}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 1, {
              Complex[5.8589004041447135`, -0.6523609855265128], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.28368230116663895`, 0.528040551941874}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B", 2, {
              Complex[5.999503006012947, 0.528040551941874], 
              Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.42231821795918023`, -0.6598239647344442}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 1, {
              Complex[5.860867089220406, -0.6598239647344442], 
              Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.28496078123801105`, 0.5360310932164654}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B", 2, {
              Complex[5.998224525941575, 0.5360310932164654], 
              Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4204145454387156, -0.6671697152100744}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 1, {
              Complex[5.862770761740871, -0.6671697152100744], 
              Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2861792589945562, 0.5439002036016083}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B", 2, {
              Complex[5.99700604818503, 0.5439002036016083], 
              Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.41857017200274615`, -0.6744020624307271}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 1, {
              Complex[5.86461513517684, -0.6744020624307271], 
              Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.28734142649006156`, 0.5516517577146818}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B", 2, {
              Complex[5.995843880689525, 0.5516517577146818], 
              Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4167816863723166, -0.6815246607732995}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 1, {
              Complex[5.86640362080727, -0.6815246607732995], 
              Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2884506737853183, 0.5592894583048527}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B", 2, {
              Complex[5.994734633394268, 0.5592894583048527], 
              Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.41504594916120485`, -0.6885410007735715}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 1, {
              Complex[5.868139358018381, -0.6885410007735715], 
              Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.28951011924514347`, 0.5668168435275391}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B", 2, {
              Complex[5.993675187934443, 0.5668168435275391], 
              Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4133600660972272, -0.6954544165180526}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 1, {
              Complex[5.869825241082359, -0.6954544165180526], 
              Complex[4.071554204602269, -2.043172220042138]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2905226363150346, 0.5742372943510564}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B", 2, {
              Complex[5.992662670864552, 0.5742372943510564], 
              Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.41172136430935424`, -0.7022680930260652}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 1, {
              Complex[5.871463942870232, -0.7022680930260652], 
              Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2914908772320972, 0.5815540419531224}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B", 2, {
              Complex[5.991694429947489, 0.5815540419531224], 
              Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4101273712890263, -0.7089850735194753}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 1, {
              Complex[5.87305793589056, -0.7089850735194753], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29241729406171757`, 0.588770175004682}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B", 2, {
              Complex[5.990768013117869, 0.588770175004682], 
              Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4085757961880372, -0.7156082665076038}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 1, {
              Complex[5.874609510991549, -0.7156082665076038], 
              Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29330415739773663`, 0.5958886467685789}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B", 2, {
              Complex[5.98988114978185, 0.5958886467685789], 
              Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4070645131615489, -0.7221404526376908}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 1, {
              Complex[5.876120794018037, -0.7221404526376908], 
              Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2941535730174669, 0.6029122819634535}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B", 2, {
              Complex[5.989031734162119, 0.6029122819634535], 
              Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4055915465043869, -0.7285842912785059}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29496749674347367`, 0.6098437833604634}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B", 2, {
              Complex[5.988217810436113, 0.6098437833604634], 
              Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.40415505736265533`, -0.7349423268176076}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 1, {
              Complex[5.879030249816931, -0.7349423268176076], 
              Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29574774773004897`, 0.616685738093365}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B", 2, {
              Complex[5.987437559449537, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.40275333183170936`, -0.7412169946624547}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 1, {
              Complex[5.880431975347877, -0.7412169946624547], 
              Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29649602036331757`, 0.6234406236721282}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B", 2, {
              Complex[5.986689286816269, 0.6234406236721282], 
              Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4013847702765121, -0.7474106269426314}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 1, {
              Complex[5.881800536903074, -0.7474106269426314], 
              Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29721389493901285`, 0.6301108136973947}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B", 2, {
              Complex[5.985971412240573, 0.6301108136973947], 
              Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.4000478777317218, -0.7535254579157123}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 1, {
              Complex[5.883137429447864, -0.7535254579157123], 
              Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29790284726052185`, 0.6366985832782691}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B", 2, {
              Complex[5.985282459919064, 0.6366985832782691], 
              Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.39874125525724846`, -0.7595636290829754}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 1, {
              Complex[5.884444051922338, -0.7595636290829754], 
              Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2985642572814591, 0.643206114159718}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B", 2, {
              Complex[5.984621049898127, 0.643206114159718], 
              Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3974635921409, -0.7655271940238007}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 1, {
              Complex[5.885721715038686, -0.7655271940238007], 
              Complex[4.096832656761998, -2.123163026694792]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.29919941690120755`, 0.6496354995683528}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B", 2, {
              Complex[5.983985890278379, 0.6496354995683528], 
              Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3962136588533154, -0.7714181229593432}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 1, {
              Complex[5.886971648326271, -0.7714181229593432], 
              Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.2998095370081506, 0.655988748787251}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B", 2, {
              Complex[5.983375770171436, 0.655988748787251], 
              Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3949903006721991, -0.7772383070571703}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 1, {
              Complex[5.888195006507387, -0.7772383070571703], 
              Complex[4.100856784915978, -2.136545961543077]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30039575385364703`, 0.6622677914714878}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B", 2, {
              Complex[5.982789553325939, 0.6622677914714878], 
              Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.39379243190306656`, -0.782989562489217}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 1, {
              Complex[5.88939287527652, -0.782989562489217], 
              Complex[4.102814974771636, -2.143119636338955]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3009591348295029, 0.6684744817167128}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B", 2, {
              Complex[5.982226172350083, 0.6684744817167128], 
              Complex[4.1071667491158, -0.4049877179062303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.39261903063250614`, -0.7886736342555825}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 1, {
              Complex[5.89056627654708, -0.7886736342555825], 
              Complex[4.104739060573037, -2.149617413966407]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3015006837129306, 0.6746106018933713}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B", 2, {
              Complex[5.981684623466656, 0.6746106018933713], 
              Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3914691339576519, -0.7942921997868306}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 1, {
              Complex[5.891716173221934, -0.7942921997868306], 
              Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3020213454353389, 0.6806778662591632}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B", 2, {
              Complex[5.981163961744247, 0.6806778662591632], 
              Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.39034183364219466`, -0.7998468723371351}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 1, {
              Complex[5.892843473537392, -0.7998468723371351], 
              Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30252201042457827`, 0.6866779243621381}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B", 2, {
              Complex[5.980663296755008, 0.6866779243621381], 
              Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3892362721550846, -0.8053392041803533}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 1, {
              Complex[5.893949035024502, -0.8053392041803533], 
              Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30300351856453567`, 0.6926123642464803}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B", 2, {
              Complex[5.980181788615051, 0.6926123642464803], 
              Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3881516390530697, -0.8107706896206487}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 1, {
              Complex[5.8950336681265165`, -0.8107706896206487], 
              Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30346666281088286`, 0.6984827154726538}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B", 2, {
              Complex[5.979718644368703, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.387087167672715, -0.8161427678288314}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 1, {
              Complex[5.896098139506871, -0.8161427678288314], 
              Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30391219249737933`, 0.7042904519630309}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B", 2, {
              Complex[5.979273114682207, 0.7042904519630309], 
              Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3860421321013341, -0.8214568255150104}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 1, {
              Complex[5.897143175078252, -0.8214568255150104], 
              Complex[4.115633584193734, -2.187110717536775]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3043408163633048, 0.7100369946836335}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B", 2, {
              Complex[5.978844490816281, 0.7100369946836335], 
              Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3850158443996934, -0.8267141994476594}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3047532053290407, 0.7157237141721113}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B", 2, {
              Complex[5.9784321018505455`, 0.7157237141721113], 
              Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3840076520523006, -0.8319161788285983}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 1, {
              Complex[5.899177655127286, -0.8319161788285983], 
              Complex[4.119042270745964, -2.199078825420971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3051499950442178, 0.7213519329214122}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B", 2, {
              Complex[5.978035312135368, 0.7213519329214122], 
              Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3830169356237194, -0.8370640075328958}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 1, {
              Complex[5.900168371555867, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30553178822975724`, 0.7269229276281969}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B", 2, {
              Complex[5.977653518949829, 0.7269229276281969], 
              Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3820431066016372, -0.8421588862221203}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 1, {
              Complex[5.901142200577949, -0.8421588862221203], 
              Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3058991568332061, 0.7324379313144281}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B", 2, {
              Complex[5.97728615034638, 0.7324379313144281], 
              Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3810856054094547, -0.8472019743388882}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 1, {
              Complex[5.9020997017701315`, -0.8472019743388882], 
              Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3062526440145703, 0.7378981353300635}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B", 2, {
              Complex[5.976932663165016, 0.7378981353300635], 
              Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.38014389957294803`, -0.852194391990135}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3065927659780945, 0.7433046912443029}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B", 2, {
              Complex[5.976592541201492, 0.7433046912443029], 
              Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3792174820271681, -0.8571372217260815}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 1, {
              Complex[5.903967825152418, -0.8571372217260815], 
              Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3069200136638006, 0.7486587126323617}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B", 2, {
              Complex[5.976265293515786, 0.7486587126323617], 
              Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.37830586955111123`, -0.8620315102214064}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 1, {
              Complex[5.904879437628475, -0.8620315102214064], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30723485431130726`, 0.7539612767642825}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B", 2, {
              Complex[5.975950452868279, 0.7539612767642825], 
              Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3774086013189635, -0.8668782698647188}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 1, {
              Complex[5.905776705860623, -0.8668782698647188], 
              Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3075377329070452, 0.7592134262018878}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B", 2, {
              Complex[5.975647574272541, 0.7592134262018878], 
              Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3765252375578507, -0.8716784802620264}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 1, {
              Complex[5.9066600696217355`, -0.8716784802620264], 
              Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30782907352503486`, 0.7644161703095629}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B", 2, {
              Complex[5.975356233654551, 0.7644161703095629], 
              Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.37565535830296515`, -0.8764330896595154}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 1, {
              Complex[5.907529948876621, -0.8764330896595154], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3081092805702603, 0.7695704866842142}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B", 2, {
              Complex[5.975076026609326, 0.7695704866842142], 
              Complex[4.095188685529604, -0.27663159198783]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.37479856224187014`, -0.8811430162906054}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 1, {
              Complex[5.908386744937716, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30837873993290366`, 0.7746773225093266}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B", 2, {
              Complex[5.974806567246683, 0.7746773225093266], 
              Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.37395446564053714`, -0.8858091496519155}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 1, {
              Complex[5.909230841539049, -0.8858091496519155], 
              Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3086378200608628, 0.779737595837812}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B", 2, {
              Complex[5.974547487118723, 0.779737595837812], 
              Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3731227013443785, -0.8904323517124778}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 1, {
              Complex[5.910062605835208, -0.8904323517124778], 
              Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3088868729572738, 0.7847521968079424}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B", 2, {
              Complex[5.974298434222312, 0.7847521968079424], 
              Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3723029178481996, -0.8950134580602268}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 1, {
              Complex[5.910882389331387, -0.8950134580602268], 
              Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3091262351091544, 0.7897219887964377}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B", 2, {
              Complex[5.974059072070432, 0.7897219887964377], 
              Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.37149477842948464`, -0.8995532789895441}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 1, {
              Complex[5.911690528750102, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30935622835270316`, 0.7946478095124517}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3706979603400269, -0.904052600533387}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 1, {
              Complex[5.912487346839559, -0.904052600533387], 
              Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30957716068028507`, 0.7995304720360318}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B", 2, {
              Complex[5.973608146499301, 0.7995304720360318], 
              Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.36991215405129463`, -0.9085121854432785}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 1, {
              Complex[5.913273153128292, -0.9085121854432785], 
              Complex[4.143183206373633, -2.286811288665357]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30978932699370176`, 0.8043707658042932}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3691370625493713, -0.9129327741202411}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 1, {
              Complex[5.914048244630215, -0.9129327741202411], 
              Complex[4.1445381709548, -2.291879330010546]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.30999300980787936`, 0.8091694575484238}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B", 2, {
              Complex[5.973192297371707, 0.8091694575484238], 
              Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3683724006756668, -0.9173150854995431}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 1, {
              Complex[5.914812906503919, -0.9173150854995431], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3101884799088319, 0.8139272921843711}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B", 2, {
              Complex[5.972996827270754, 0.8139272921843711], 
              Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.36761789450992577`, -0.9216598178919517}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 1, {
              Complex[5.9155674126696605`, -0.9216598178919517], 
              Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.31037599696932006`, 0.8186449936599097}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3668732807923485, -0.925967649783973}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 1, {
              Complex[5.916312026387238, -0.925967649783973], 
              Complex[4.148512526970577, -2.306826396101707]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.3105558101254058, 0.8233232657606012}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B", 2, {
              Complex[5.9726294970541804`, 0.8233232657606012], 
              Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.3661383063819681, -0.9302392405994727}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 1, {
              Complex[5.917047000797618, -0.9302392405994727], 
              Complex[4.149808341378717, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.31072815851681224`, 0.8279627928769886}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B", 2, {
              Complex[5.972457148662774, 0.8279627928769886], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{-0.36541272774853173`, -0.9344752314248252}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 1, {
              Complex[5.9177725794310545`, -0.9344752314248252], 
              Complex[4.15109024131099, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{-0.31089327179370585`, 0.8325642407352367}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B", 2, {
              Complex[5.97229203538588, 0.8325642407352367], 
              Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{4.976967927486167, 0.006887727487396918}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 1, {
              Complex[4.976967927486167, 0.006887727487396918], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.398301539299036, -0.01324317030169907}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D", 2, {
              Complex[7.398301539299036, -0.01324317030169907], 
              Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.020988084142068, 0.007042959985368871}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 1, {
              Complex[5.020988084142068, 0.007042959985368871], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.352914113679207, -0.013509876715323901`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D", 2, {
              Complex[7.352914113679207, -0.013509876715323901`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.05739532427709, 0.007197843246654808}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 1, {
              Complex[5.05739532427709, 0.007197843246654808], 
              Complex[6.557943371421671, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.315449803449272, -0.01375104485251276}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D", 2, {
              Complex[7.315449803449272, -0.01375104485251276], 
              Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.089412494295966, 0.007354951961001998}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 1, {
              Complex[5.089412494295966, 0.007354951961001998], 
              Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.282554763488937, -0.01397986959845826}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D", 2, {
              Complex[7.282554763488937, -0.01397986959845826], 
              Complex[8.685690080337723, -1.196609721074035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.118506250669166, 0.007515591774090762}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 1, {
              Complex[5.118506250669166, 0.007515591774090762], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.252703058118813, -0.014202465960727835`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D", 2, {
              Complex[7.252703058118813, -0.014202465960727835`], 
              Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.145491825926181, 0.007680628289980853}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 1, {
              Complex[5.145491825926181, 0.007680628289980853], 
              Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.225046713694154, -0.01442235766034999}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D", 2, {
              Complex[7.225046713694154, -0.01442235766034999], 
              Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.170878634413056, 0.007850743160533592}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 1, {
              Complex[5.170878634413056, 0.007850743160533592], 
              Complex[6.668857252414806, -1.162622520798364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.199056007873823, -0.014641876121436175`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D", 2, {
              Complex[7.199056007873823, -0.014641876121436175`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.19501091123548, 0.00802653852897203}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 1, {
              Complex[5.19501091123548, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.174373102447971, -0.014862729232274653`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D", 2, {
              Complex[7.174373102447971, -0.014862729232274653`], 
              Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.2181348551047995`, 0.008208588338762854}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 1, {
              Complex[5.2181348551047995`, 0.008208588338762854], 
              Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{7.1507421714555965`, -0.015086273942248003`}],
            
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D", 2, {
              Complex[7.1507421714555965`, -0.015086273942248003`], 
              Complex[8.556435217312076, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.240434389619399, 0.00839746770183686}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 1, {
              Complex[5.240434389619399, 0.00839746770183686], 
              Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.127972189674163, -0.015313663264596189`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D", 2, {
              Complex[7.127972189674163, -0.015313663264596189`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.262051805853028, 0.008593772293729816}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 1, {
              Complex[5.262051805853028, 0.008593772293729816], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{7.1059154551031405`, -0.015545933419028879`}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D", 2, {
              Complex[7.1059154551031405`, -0.015545933419028879`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.283100441464033, 0.008798133065178963}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 1, {
              Complex[5.283100441464033, 0.008798133065178963], 
              Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.084454398670628, -0.015784060035230123`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D", 2, {
              Complex[7.084454398670628, -0.015784060035230123`], 
              Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.303672866164795, 0.009011228909084937}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 1, {
              Complex[5.303672866164795, 0.009011228909084937], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.063493070122277, -0.01602899750358731}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D", 2, {
              Complex[7.063493070122277, -0.01602899750358731], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.323846388854408, 0.00923379877093513}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 1, {
              Complex[5.323846388854408, 0.00923379877093513], 
              Complex[6.816993839756789, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.042951411025012, -0.016281708942805718`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D", 2, {
              Complex[7.042951411025012, -0.016281708942805718`], 
              Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.343686896016404, 0.009466654168547547}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 1, {
              Complex[5.343686896016404, 0.009466654168547547], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.022761264330782, -0.01654319107188898}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D", 2, {
              Complex[7.022761264330782, -0.01654319107188898], 
              Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.363251612071681, 0.009710692858210855}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 1, {
              Complex[5.363251612071681, 0.009710692858210855], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.002863505905769, -0.016814496662831985`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D", 2, {
              Complex[7.002863505905769, -0.016814496662831985`], 
              Complex[8.412563676597296, -1.198158678433355]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.382591142510598, 0.009966914310096187}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 1, {
              Complex[5.382591142510598, 0.009966914310096187], 
              Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.983205922649462, -0.017096756417673678`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D", 2, {
              Complex[6.983205922649462, -0.017096756417673678`], 
              Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.401751028707841, 0.010236437677199473`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 1, {
              Complex[5.401751028707841, 0.010236437677199473`], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.963741599119119, -0.017391201699304113`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D", 2, {
              Complex[6.963741599119119, -0.017391201699304113`], 
              Complex[8.374692817528384, -1.198488112788141]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.4207729647332625`, 0.010520523036427932`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 1, {
              Complex[5.4207729647332625`, 0.010520523036427932`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.944427656372562, -0.01769918937958054}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D", 2, {
              Complex[6.944427656372562, -0.01769918937958054], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.439695778207934, 0.010820596844492497`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 1, {
              Complex[5.439695778207934, 0.010820596844492497`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.925224236986869, -0.01802223007164421}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D", 2, {
              Complex[6.925224236986869, -0.01802223007164421], 
              Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.458556246931596, 0.011138282794836883`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 1, {
              Complex[5.458556246931596, 0.011138282794836883`], 
              Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.906093661793765, -0.01836202115462416}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D", 2, {
              Complex[6.906093661793765, -0.01836202115462416], 
              Complex[8.319026572634915, -1.199065136952576]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.47738980371477, 0.011475439606775242`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 1, {
              Complex[5.47738980371477, 0.011475439606775242`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.886999703988066, -0.01872048627707082}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D", 2, {
              Complex[6.886999703988066, -0.01872048627707082], 
              Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.496231169626781, 0.011834207760463395`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 1, {
              Complex[5.496231169626781, 0.011834207760463395`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.867906939037359, -0.019099823463292427`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D", 2, {
              Complex[6.867906939037359, -0.019099823463292427`], 
              Complex[8.28224016277643, -1.199522741096495]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.515114948423251, 0.012217067867222332`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 1, {
              Complex[5.515114948423251, 0.012217067867222332`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{6.8487801366438275`, -0.019502564592186727`}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D", 2, {
              Complex[6.8487801366438275`, -0.019502564592186727`], 
              Complex[8.263840153003091, -1.199779292073964]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.5340762109349875`, 0.012626914319474934`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 1, {
              Complex[5.5340762109349875`, 0.012626914319474934`], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.829583665251546, -0.019931649951741116`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D", 2, {
              Complex[6.829583665251546, -0.019931649951741116`], 
              Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.553151097008939, 0.013067149229433903`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 1, {
              Complex[5.553151097008939, 0.013067149229433903`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.810280880968052, -0.020390522922278664`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D", 2, {
              Complex[6.810280880968052, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.200360975725519]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.57237746397503, 0.013541803645186435`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 1, {
              Complex[5.57237746397503, 0.013541803645186435`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.790833471518203, -0.020883251810279654`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D", 2, {
              Complex[6.790833471518203, -0.020883251810279654`], 
              Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.591795614755318, 0.014055695951277704`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 1, {
              Complex[5.591795614755318, 0.014055695951277704`], 
              Complex[7.073421269042283, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.771200721802021, -0.021414688765245018`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D", 2, {
              Complex[6.771200721802021, -0.021414688765245018`], 
              Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.611449146258794, 0.014614641743299664`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 1, {
              Complex[5.611449146258794, 0.014614641743299664`], 
              Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.751338660172414, -0.021990680088691934`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D", 2, {
              Complex[6.751338660172414, -0.021990680088691934`], 
              Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.631385970822487, 0.015225736181981623`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 1, {
              Complex[5.631385970822487, 0.015225736181981623`], 
              Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.731199032484283, -0.022618348956057268`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D", 2, {
              Complex[6.731199032484283, -0.022618348956057268`], 
              Complex[8.151078988162068, -1.201907179567137]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.651659582251507, 0.0158977403597609}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 1, {
              Complex[5.651659582251507, 0.0158977403597609], 
              Complex[7.130299515097565, -1.157225283537514]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.7107280322146305`, -0.02330648209651286}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D", 2, {
              Complex[6.7107280322146305`, -0.02330648209651286], 
              Complex[8.13150550216652, -1.202406603890853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.6723306669868805`, 0.016641620135819466`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 1, {
              Complex[5.6723306669868805`, 0.016641620135819466`], 
              Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.689864686007544, -0.024066068896217683`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D", 2, {
              Complex[6.689864686007544, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.693469206036438, 0.01747131387776226}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 1, {
              Complex[5.693469206036438, 0.01747131387776226], 
              Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.668538748914897, -0.024911069370827682`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D", 2, {
              Complex[6.668538748914897, -0.024911069370827682`], 
              Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.715157284805061, 0.018404853311322064`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 1, {
              Complex[5.715157284805061, 0.018404853311322064`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.646667892120967, -0.025859535214795407`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D", 2, {
              Complex[6.646667892120967, -0.025859535214795407`], 
              Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.737492944039841, 0.019466046203823834`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 1, {
              Complex[5.737492944039841, 0.019466046203823834`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.624153849873985, -0.02693529265819097}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D", 2, {
              Complex[6.624153849873985, -0.02693529265819097], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.76059559895939, 0.020687085496539206`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 1, {
              Complex[5.76059559895939, 0.020687085496539206`], 
              Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.600876998505349, -0.028170551750252844`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D", 2, {
              Complex[6.600876998505349, -0.028170551750252844`], 
              Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.78461388785291, 0.022112751073540098`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 1, {
              Complex[5.78461388785291, 0.022112751073540098`], 
              Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5766885062096785`, -0.02961010826063084}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D", 2, {
              Complex[6.5766885062096785`, -0.02961010826063084], 
              Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.809737407862617, 0.023807487220115758`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 1, {
              Complex[5.809737407862617, 0.023807487220115758`], 
              Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5513985958381715`, -0.03131842125415489}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D", 2, {
              Complex[6.5513985958381715`, -0.03131842125415489], 
              Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.836214897718771, 0.02586798658403449}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 1, {
              Complex[5.836214897718771, 0.02586798658403449], 
              Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5247583609077076`, -0.03339219715471046}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D", 2, {
              Complex[6.5247583609077076`, -0.03339219715471046], 
              Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.864383522178553, 0.028447097632704994`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 1, {
              Complex[5.864383522178553, 0.028447097632704994`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.496430480050892, -0.03598429729320658}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D", 2, {
              Complex[6.496430480050892, -0.03598429729320658], 
              Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.894717893374835, 0.031803157852374093`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 1, {
              Complex[5.894717893374835, 0.031803157852374093`], 
              Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.465940194681216, -0.03935307118737327}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D", 2, {
              Complex[6.465940194681216, -0.03935307118737327], 
              Complex[7.898547952604841, -1.215606555382372]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.927914095850698, 0.036413030935491676`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 1, {
              Complex[5.927914095850698, 0.036413030935491676`], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.432591283080759, -0.043975393800888975`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D", 2, {
              Complex[6.432591283080759, -0.043975393800888975`], 
              Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.96502471876488, 0.0432677226664523}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 1, {
              Complex[5.96502471876488, 0.0432677226664523], 
              Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.395331027411176, -0.05084228149319564}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D", 2, {
              Complex[6.395331027411176, -0.05084228149319564], 
              Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.007534506136697, 0.054768081877322586`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 1, {
              Complex[6.007534506136697, 0.054768081877322586`], 
              Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.352674562767395, -0.062354593032590215`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D", 2, {
              Complex[6.352674562767395, -0.062354593032590215`], 
              Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.055705576569384, 0.07734359441247692}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 1, {
              Complex[6.055705576569384, 0.07734359441247692], 
              Complex[7.512359287571745, -1.102232298445035]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.304359656824848, -0.08494182361233121}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D", 2, {
              Complex[6.304359656824848, -0.08494182361233121], 
              Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.097972756057953, 0.11902724764148631`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 1, {
              Complex[6.097972756057953, 0.11902724764148631`], 
              Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.261951376465343, -0.12663696940989244`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D", 2, {
              Complex[6.261951376465343, -0.12663696940989244`], 
              Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.120724694194671, 0.16611165996512534`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 1, {
              Complex[6.120724694194671, 0.16611165996512534`], 
              Complex[7.574268139734727, -1.019141232917107]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.239060971061035, -0.17373265713468317`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D", 2, {
              Complex[6.239060971061035, -0.17373265713468317`], 
              Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.132202365530885, 0.2069539217818524}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 1, {
              Complex[6.132202365530885, 0.2069539217818524], 
              Complex[7.58536879774568, -0.980787258766948]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.22744737065107, -0.21458598503237494`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D", 2, {
              Complex[6.22744737065107, -0.21458598503237494`], 
              Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.138977875500199, 0.24191392575349213`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 1, {
              Complex[6.138977875500199, 0.24191392575349213`], 
              Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.22053837960052, -0.24955685318475593`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D", 2, {
              Complex[6.22053837960052, -0.24955685318475593`], 
              Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.143492571886664, 0.27256109297706693`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 1, {
              Complex[6.143492571886664, 0.27256109297706693`], 
              Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.215892564752824, -0.2802146897125671}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D", 2, {
              Complex[6.215892564752824, -0.2802146897125671], 
              Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.146749395916181, 0.30000093008350615`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 1, {
              Complex[6.146749395916181, 0.30000093008350615`], 
              Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.212506903993471, -0.30766500790256135`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D", 2, {
              Complex[6.212506903993471, -0.30766500790256135`], 
              Complex[7.656512931924062, -1.465936381216481]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.149229270200796, 0.3249638924276399}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 1, {
              Complex[6.149229270200796, 0.3249638924276399], 
              Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.209900397991501, -0.3326382694231228}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D", 2, {
              Complex[6.209900397991501, -0.3326382694231228], 
              Complex[7.653771155925207, -1.489346210521607]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.151192034362995, 0.34794816918875576`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 1, {
              Complex[6.151192034362995, 0.34794816918875576`], 
              Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.207813134288261, -0.3556326694484139}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D", 2, {
              Complex[6.207813134288261, -0.3556326694484139], 
              Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.152791090696166, 0.3693076970042951}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 1, {
              Complex[6.152791090696166, 0.3693076970042951], 
              Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2060916413747425`, -0.3770021503134528}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D", 2, {
              Complex[6.2060916413747425`, -0.3770021503134528], 
              Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.154123300626686, 0.38930335076908473`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 1, {
              Complex[6.154123300626686, 0.38930335076908473`], 
              Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.204638991989324, -0.3970075923331428}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D", 2, {
              Complex[6.204638991989324, -0.3970075923331428], 
              Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.155253112689077, 0.4081334915298177}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 1, {
              Complex[6.155253112689077, 0.4081334915298177], 
              Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.203390674922197, -0.41584736171471254`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D", 2, {
              Complex[6.203390674922197, -0.41584736171471254`], 
              Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.156225240135477, 0.4259529280523631}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 1, {
              Complex[6.156225240135477, 0.4259529280523631], 
              Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.202301917203499, -0.4336762721416338}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D", 2, {
              Complex[6.202301917203499, -0.4336762721416338], 
              Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1570717804683675`, 0.44288515307919946`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 1, {
              Complex[6.1570717804683675`, 0.44288515307919946`], 
              Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.201340564384264, -0.4506178210463805}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D", 2, {
              Complex[6.201340564384264, -0.4506178210463805], 
              Complex[7.644243187304668, -1.599732810883159]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15781643675441, 0.45903052180506065`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 1, {
              Complex[6.15781643675441, 0.45903052180506065`], 
              Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2004828590509335`, -0.46677236810008377`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D", 2, {
              Complex[6.2004828590509335`, -0.46677236810008377`], 
              Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15847713590932, 0.4744718898931343}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199710822382092, -0.4822227732417416}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D", 2, {
              Complex[6.199710822382092, -0.4822227732417416], 
              Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1590677155468105`, 0.48927860682774}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 1, {
              Complex[6.1590677155468105`, 0.48927860682774], 
              Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199010567153125, -0.49703839004290984`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D", 2, {
              Complex[6.199010567153125, -0.49703839004290984`], 
              Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.159599046539053, 0.5035094122855176}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 1, {
              Complex[6.159599046539053, 0.5035094122855176], 
              Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.198371175040328, -0.5112779620899686}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D", 2, {
              Complex[6.198371175040328, -0.5112779620899686], 
              Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160079801248174, 0.5172145811965714}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 1, {
              Complex[6.160079801248174, 0.5172145811965714], 
              Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197783928263984, -0.5249917680556042}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160516992248921, 0.5304375419992584}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 1, {
              Complex[6.160516992248921, 0.5304375419992584], 
              Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197241770749233, -0.538223239963063}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D", 2, {
              Complex[6.197241770749233, -0.538223239963063], 
              Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160916358296958, 0.5432161176861712}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 1, {
              Complex[6.160916358296958, 0.5432161176861712], 
              Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1967389220498434`, -0.5510102042411117}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D", 2, {
              Complex[6.1967389220498434`, -0.5510102042411117], 
              Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161282646160605, 0.5555834916479535}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 1, {
              Complex[6.161282646160605, 0.5555834916479535], 
              Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1962705954158785`, -0.5633858475760002}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D", 2, {
              Complex[6.1962705954158785`, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1616198199314836`, 0.5675689693259762}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 1, {
              Complex[6.1616198199314836`, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195832788389601, -0.5753794785718529}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D", 2, {
              Complex[6.195832788389601, -0.5753794785718529], 
              Complex[7.637270060814722, -1.715957196142648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161931218858729, 0.5791985860418423}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 1, {
              Complex[6.161931218858729, 0.5791985860418423], 
              Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1954221248841135`, -0.5870171355873215}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D", 2, {
              Complex[6.1954221248841135`, -0.5870171355873215], 
              Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162219678012526, 0.5904955973399484}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 1, {
              Complex[6.162219678012526, 0.5904955973399484], 
              Complex[7.615928222964841, -0.621726996632902]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195035734438572, -0.5983220770848242}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D", 2, {
              Complex[6.195035734438572, -0.5983220770848242], 
              Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162487621687207, 0.6014808784641323}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 1, {
              Complex[6.162487621687207, 0.6014808784641323], 
              Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.194671158739189, -0.6093151811133911}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D", 2, {
              Complex[6.194671158739189, -0.6093151811133911], 
              Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162737136528052, 0.6121732527479822}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 1, {
              Complex[6.162737136528052, 0.6121732527479822], 
              Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.194326278421569, -0.6200152737048314}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D", 2, {
              Complex[6.194326278421569, -0.6200152737048314], 
              Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162970029380981, 0.6225897638061394}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 1, {
              Complex[6.162970029380981, 0.6225897638061394], 
              Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193999255154619, -0.63043940107047}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D", 2, {
              Complex[6.193999255154619, -0.63043940107047], 
              Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1631878734954, 0.6327459028649584}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 1, {
              Complex[6.1631878734954, 0.6327459028649584], 
              Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193688485375648, -0.6406030569368893}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163392045750655, 0.6426557999628854}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 1, {
              Complex[6.163392045750655, 0.6426557999628854], 
              Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193392563005682, -0.6505203737511226}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D", 2, {
              Complex[6.193392563005682, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163583756894771, 0.6523323858111204}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 1, {
              Complex[6.163583756894771, 0.6523323858111204], 
              Complex[7.617513055986503, -0.564265877881112]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193110249156134, -0.660204284545775}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D", 2, {
              Complex[6.193110249156134, -0.660204284545775], 
              Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163764076292796, 0.6617875296457958}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 1, {
              Complex[6.163764076292796, 0.6617875296457958], 
              Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192840447329175, -0.6696666607954201}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D", 2, {
              Complex[6.192840447329175, -0.6696666607954201], 
              Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16393395232409, 0.671032157293945}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 1, {
              Complex[6.16393395232409, 0.671032157293945], 
              Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192582182972333, -0.6789184304865281}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D", 2, {
              Complex[6.192582182972333, -0.6789184304865281], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164094229303429, 0.680076352824419}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 1, {
              Complex[6.164094229303429, 0.680076352824419], 
              Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192334586512061, -0.6879696797720971}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D", 2, {
              Complex[6.192334586512061, -0.6879696797720971], 
              Complex[7.632109194769857, -1.820245960840084]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164245661604394, 0.6889294464957759}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 1, {
              Complex[6.164245661604394, 0.6889294464957759], 
              Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192096879187743, -0.6968297409230599}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D", 2, {
              Complex[6.192096879187743, -0.6968297409230599], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164388925515004, 0.697600091198504}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 1, {
              Complex[6.164388925515004, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191868361155921, -0.7055072687737808}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D", 2, {
              Complex[6.191868361155921, -0.7055072687737808], 
              Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164524629243228, 0.7060963291837459}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 1, {
              Complex[6.164524629243228, 0.7060963291837459], 
              Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191648401446948, -0.7140103074539127}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D", 2, {
              Complex[6.191648401446948, -0.7140103074539127], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164653321403731, 0.7144256505494253}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 1, {
              Complex[6.164653321403731, 0.7144256505494253], 
              Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191436429442565, -0.7223463488774431}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D", 2, {
              Complex[6.191436429442565, -0.7223463488774431], 
              Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164775498250602, 0.7225950446980839}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 1, {
              Complex[6.164775498250602, 0.7225950446980839], 
              Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191231927609488, -0.7305223842033104}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D", 2, {
              Complex[6.191231927609488, -0.7305223842033104], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164891609869033, 0.7306110457745064}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 1, {
              Complex[6.164891609869033, 0.7306110457745064], 
              Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1910344252759195`, -0.738544949275635}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165002065498246, 0.738479772924393}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 1, {
              Complex[6.165002065498246, 0.738479772924393], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190843493278558, -0.7464201648848559}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D", 2, {
              Complex[6.190843493278558, -0.7464201648848559], 
              Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1651072381259, 0.7462069660795196}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 1, {
              Complex[6.1651072381259, 0.7462069660795196], 
              Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190658739339742, -0.7541537725552644}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D", 2, {
              Complex[6.190658739339742, -0.7541537725552644], 
              Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165207468468805, 0.7537980178639989}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 1, {
              Complex[6.165207468468805, 0.7537980178639989], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190479804059834, -0.761751166453437}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D", 2, {
              Complex[6.190479804059834, -0.761751166453437], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165303068434313, 0.761258002124613}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 1, {
              Complex[6.165303068434313, 0.761258002124613], 
              Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1903063574303445`, -0.7692174219206874}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165394324140473, 0.7685916995129604}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 1, {
              Complex[6.165394324140473, 0.7685916995129604], 
              Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190138095789615, -0.7765573210571961}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D", 2, {
              Complex[6.190138095789615, -0.7765573210571961], 
              Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1654814985597985`, 0.7758036204842987}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 1, {
              Complex[6.1654814985597985`, 0.7758036204842987], 
              Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18997473915616, -0.7837753757227331}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D", 2, {
              Complex[6.18997473915616, -0.7837753757227331], 
              Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1655648338407385`, 0.7828980260257037}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 1, {
              Complex[6.1655648338407385`, 0.7828980260257037], 
              Complex[7.619946700555888, -0.443528162616499]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189816028885474, -0.7908758482666055}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D", 2, {
              Complex[6.189816028885474, -0.7908758482666055], 
              Complex[7.627776768560513, -1.914949385030405]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165644553352178, 0.7898789463823163}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 1, {
              Complex[6.165644553352178, 0.7898789463823163], 
              Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189661725604909, -0.7978627702556053}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165720863489107, 0.7967501980135657}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 1, {
              Complex[6.165720863489107, 0.7967501980135657], 
              Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189511607388403, -0.804739959431843}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D", 2, {
              Complex[6.189511607388403, -0.804739959431843], 
              Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165793955271714, 0.8035153989801244}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 1, {
              Complex[6.165793955271714, 0.8035153989801244], 
              Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189365468138804, -0.8115110351012247}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D", 2, {
              Complex[6.189365468138804, -0.8115110351012247], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1658640057650915`, 0.8101779829358522}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 1, {
              Complex[6.1658640057650915`, 0.8101779829358522], 
              Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189223116150438, -0.8181794321268676}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D", 2, {
              Complex[6.189223116150438, -0.8181794321268676], 
              Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165931179342954, 0.8167412118766469}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 1, {
              Complex[6.165931179342954, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18908437282858, -0.8247484136793249}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D", 2, {
              Complex[6.18908437282858, -0.8247484136793249], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165995628815023, 0.823208187778776}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 1, {
              Complex[6.165995628815023, 0.823208187778776], 
              Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188949071546019, -0.8312210828762437}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D", 2, {
              Complex[6.188949071546019, -0.8312210828762437], 
              Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166057496435186, 0.8295818632429409}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 1, {
              Complex[6.166057496435186, 0.8295818632429409], 
              Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188817056619653, -0.8376003934276774}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D", 2, {
              Complex[6.188817056619653, -0.8376003934276774], 
              Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1661169148049755`, 0.8358650512460941}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 1, {
              Complex[6.1661169148049755`, 0.8358650512460941], 
              Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188688182392475, -0.8438891593891127}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D", 2, {
              Complex[6.188688182392475, -0.8438891593891127], 
              Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166174007684912, 0.8420604340909559}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188562312408357, -0.850090064112114}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D", 2, {
              Complex[6.188562312408357, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166228890724623, 0.8481705716325338}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 1, {
              Complex[6.166228890724623, 0.8481705716325338], 
              Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1884393186687205`, -0.8562056684719376}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D", 2, {
              Complex[6.1884393186687205`, -0.8562056684719376], 
              Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166281672121116, 0.8541979088518953}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 1, {
              Complex[6.166281672121116, 0.8541979088518953], 
              Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188319080961654, -0.8622384184423437}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D", 2, {
              Complex[6.188319080961654, -0.8622384184423437], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166332453213396, 0.8601447828394871}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 1, {
              Complex[6.166332453213396, 0.8601447828394871], 
              Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188201486255246, -0.8681906520799051}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166381329020564, 0.8660134292433507}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 1, {
              Complex[6.166381329020564, 0.8660134292433507], 
              Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188086428148008, -0.8740646059731705}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D", 2, {
              Complex[6.188086428148008, -0.8740646059731705], 
              Complex[7.6243541862563, -1.990999855207028]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166428388729593, 0.8718059882315833}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 1, {
              Complex[6.166428388729593, 0.8718059882315833], 
              Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187973806370098, -0.8798624212060279}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D", 2, {
              Complex[6.187973806370098, -0.8798624212060279], 
              Complex[7.624115410024538, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166473716138243, 0.877524510013052}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 1, {
              Complex[6.166473716138243, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187863526329917, -0.8855861488792874}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D", 2, {
              Complex[6.187863526329917, -0.8855861488792874], 
              Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166517390057898, 0.8831709599557609}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 1, {
              Complex[6.166517390057898, 0.8831709599557609], 
              Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187755498701229, -0.8912377552298747}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D", 2, {
              Complex[6.187755498701229, -0.8912377552298747], 
              Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166559484680516, 0.8887472233381511}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187649639046593, -0.8968191263829133}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D", 2, {
              Complex[6.187649639046593, -0.8968191263829133], 
              Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166600069913391, 0.8942551097650246}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 1, {
              Complex[6.166600069913391, 0.8942551097650246], 
              Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187545867473453, -0.9023320727684235}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D", 2, {
              Complex[6.187545867473453, -0.9023320727684235], 
              Complex[7.623188002862294, -2.016726496581311]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166639211685018, 0.8996963572765853}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 1, {
              Complex[6.166639211685018, 0.8996963572765853], 
              Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187444108319425, -0.9077783332310714}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D", 2, {
              Complex[6.187444108319425, -0.9077783332310714], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166676972224923, 0.9050726361762731}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 1, {
              Complex[6.166676972224923, 0.9050726361762731], 
              Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187344289864064, -0.9131595788587061}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D", 2, {
              Complex[6.187344289864064, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166713410320053, 0.9103855526005633}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 1, {
              Complex[6.166713410320053, 0.9103855526005633], 
              Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1872463440644, -0.9184774165528232}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166748581549979, 0.9156366518516704}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187150206311988, -0.923733392361904}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D", 2, {
              Complex[6.187150206311988, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166782538502952, 0.9208274215121246}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 1, {
              Complex[6.166782538502952, 0.9208274215121246], 
              Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1870558152094315`, -0.9289289945966069}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D", 2, {
              Complex[6.1870558152094315`, -0.9289289945966069], 
              Complex[7.622084507976148, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166815330974628, 0.9259592943584081}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 1, {
              Complex[6.166815330974628, 0.9259592943584081], 
              Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186963112364547, -0.9340656567439883}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D", 2, {
              Complex[6.186963112364547, -0.9340656567439883], 
              Complex[7.621870484005858, -2.045532964655917]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166847006151044, 0.9310336510892632}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 1, {
              Complex[6.166847006151044, 0.9310336510892632], 
              Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186872042200558, -0.9391447601963707}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D", 2, {
              Complex[6.186872042200558, -0.9391447601963707], 
              Complex[7.621658530284452, -2.050135996258457]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166877608777316, 0.9360518228828759}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 1, {
              Complex[6.166877608777316, 0.9360518228828759], 
              Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186782551780801, -0.9441676368090823}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166907181313368, 0.9410150937958539}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 1, {
              Complex[6.166907181313368, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186694590646789, -0.9491355712999217}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D", 2, {
              Complex[6.186694590646789, -0.9491355712999217], 
              Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166935764077781, 0.9459247030157971}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 1, {
              Complex[6.166935764077781, 0.9459247030157971], 
              Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186608110668219, -0.9540498035022783}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166963395380894, 0.9507818469782096}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 1, {
              Complex[6.166963395380894, 0.9507818469782096], 
              Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186523065904121, -0.9589115304824511}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D", 2, {
              Complex[6.186523065904121, -0.9589115304824511], 
              Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166990111648028, 0.9555876813576081}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 1, {
              Complex[6.166990111648028, 0.9555876813576081], 
              Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186439412474038, -0.9637219085313011}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D", 2, {
              Complex[6.186439412474038, -0.9637219085313011], 
              Complex[7.620627795708716, -2.072379088667851]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167015947533717, 0.960343322941825}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1863571084384, -0.9684820550389218}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D", 2, {
              Complex[6.1863571084384, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1670409360276865`, 0.9650498513977598}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 1, {
              Complex[6.1670409360276865`, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186276113687406, -0.9731930502608692}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D", 2, {
              Complex[6.186276113687406, -0.9731930502608692], 
              Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167065108553286, 0.9697083109361534}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186196389837632, -0.977855938983316}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D", 2, {
              Complex[6.186196389837632, -0.977855938983316], 
              Complex[7.620030720208938, -2.085147528272351]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1670884950589855`, 0.974319711882344}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 1, {
              Complex[6.1670884950589855`, 0.974319711882344], 
              Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186117900135718, -0.9824717320942182}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D", 2, {
              Complex[6.186117900135718, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167111124103515, 0.9788850321593934}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 1, {
              Complex[6.167111124103515, 0.9788850321593934], 
              Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186040609368656, -0.9870414080668142}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D", 2, {
              Complex[6.186040609368656, -0.9870414080668142], 
              Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167133022935145, 0.9834052186894809}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 1, {
              Complex[6.167133022935145, 0.9834052186894809], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18596448378006, -0.991565914361383}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D", 2, {
              Complex[6.18596448378006, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1671542175655905`, 0.9878811887189864}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 1, {
              Complex[6.1671542175655905`, 0.9878811887189864], 
              Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1858894909919995`, -0.9960461687506831}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.10155454761218]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167174732838952, 0.992313831072267}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 1, {
              Complex[6.167174732838952, 0.992313831072267], 
              Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185815599931938, -1.000483060574068}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D", 2, {
              Complex[6.185815599931938, -1.000483060574068], 
              Complex[7.619067332909202, -2.105552017907877]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167194592496085, 0.9967040073387544}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 1, {
              Complex[6.167194592496085, 0.9967040073387544], 
              Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185742780764412, -1.004877451924907}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D", 2, {
              Complex[6.185742780764412, -1.004877451924907], 
              Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167213819234735, 1.0010525529976395`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 1, {
              Complex[6.167213819234735, 1.0010525529976395`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185671004827051, -1.0092301787755908`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D", 2, {
              Complex[6.185671004827051, -1.0092301787755908`], 
              Complex[7.618692192411457, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16723243476579, 1.005360278484099}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 1, {
              Complex[6.16723243476579, 1.005360278484099], 
              Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18560024457066, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16725045986591, 1.0096279702007271`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 1, {
              Complex[6.16725045986591, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185530473503019, -1.017813858605525}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D", 2, {
              Complex[6.185530473503019, -1.017813858605525], 
              Complex[7.618322479547935, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167267914426828, 1.013856391477559}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 1, {
              Complex[6.167267914426828, 1.013856391477559], 
              Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185461666136161, -1.0220463622527831`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D", 2, {
              Complex[6.185461666136161, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167284817501548, 1.0180462834838364`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185393797936859, -1.0262403046082502`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D", 2, {
              Complex[6.185393797936859, -1.0262403046082502`], 
              Complex[7.617957948303616, -2.128722917140586]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167301187347679, 1.0221983660944405`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 1, {
              Complex[6.167301187347679, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185326845280091, -1.030396405990655}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D", 2, {
              Complex[6.185326845280091, -1.030396405990655], 
              Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167317041468107, 1.0263133387136971`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18526078540529, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167332396649198, 1.0303918810590926`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 1, {
              Complex[6.167332396649198, 1.0303918810590926`], 
              Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185195596375154, -1.0385978654970505`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D", 2, {
              Complex[6.185195596375154, -1.0385978654970505`], 
              Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1673472689966875`, 1.0344346539072418`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 1, {
              Complex[6.1673472689966875`, 1.0344346539072418`], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185131257036874, -1.0426445649584837`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D", 2, {
              Complex[6.185131257036874, -1.0426445649584837`], 
              Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16736167396946, 1.0384422998042997`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185067746985585, -1.0466561075785734`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D", 2, {
              Complex[6.185067746985585, -1.0466561075785734`], 
              Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167375626411306, 1.0424154437428594`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 1, {
              Complex[6.167375626411306, 1.0424154437428594`], 
              Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1850050465299, -1.0506331187508056`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D", 2, {
              Complex[6.1850050465299, -1.0506331187508056`], 
              Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167389140580846, 1.04635469380724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 1, {
              Complex[6.167389140580846, 1.04635469380724], 
              Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184943136659399, -1.0545762069524705`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167402230179722, 1.0502606417889433`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 1, {
              Complex[6.167402230179722, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1848819990139186`, -1.0584859643603293`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D", 2, {
              Complex[6.1848819990139186`, -1.0584859643603293`], 
              Complex[7.616547285902736, -2.157643104664951]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167414908379169, 1.054133863773935}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 1, {
              Complex[6.167414908379169, 1.054133863773935], 
              Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184821615854545, -1.062362967438099}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D", 2, {
              Complex[6.184821615854545, -1.062362967438099], 
              Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167427187845094, 1.0579749207033107`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 1, {
              Complex[6.167427187845094, 1.0579749207033107`], 
              Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184761970036191, -1.0662077774973115`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D", 2, {
              Complex[6.184761970036191, -1.0662077774973115`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167439080761725, 1.061784358908797}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 1, {
              Complex[6.167439080761725, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184703044981658, -1.070020941233001}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D", 2, {
              Complex[6.184703044981658, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167450598853971, 1.065562710624442}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184644824657079, -1.07380299123558}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D", 2, {
              Complex[6.184644824657079, -1.07380299123558], 
              Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167461753408532, 1.069310494475782}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 1, {
              Complex[6.167461753408532, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184587293548676, -1.0775544464801792`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D", 2, {
              Complex[6.184587293548676, -1.0775544464801792`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167472555293864, 1.0730282159476652`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1845304366407206`, -1.081275812794643}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D", 2, {
              Complex[6.1845304366407206`, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674830149790685`, 1.0767163678318639`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 1, {
              Complex[6.1674830149790685`, 1.0767163678318639`], 
              Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184474239394659, -1.0849675833073054`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D", 2, {
              Complex[6.184474239394659, -1.0849675833073054`], 
              Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674931425517565`, 1.08037543065552}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 1, {
              Complex[6.1674931425517565`, 1.08037543065552], 
              Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184418687729288, -1.0886302388755988`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D", 2, {
              Complex[6.184418687729288, -1.0886302388755988`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167502947734983, 1.0840058730914166`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 1, {
              Complex[6.167502947734983, 1.0840058730914166`], 
              Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1843637680019645`, -1.092264248496479}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167512439903273, 1.0876081523509995`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 1, {
              Complex[6.167512439903273, 1.0876081523509995`], 
              Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1843094669907455`, -1.0958700696995953`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D", 2, {
              Complex[6.1843094669907455`, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167521628097823, 1.0911827145610276`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 1, {
              Complex[6.167521628097823, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18425577187742, -1.0994481489240884`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D", 2, {
              Complex[6.18425577187742, -1.0994481489240884`], 
              Complex[7.614715122272779, -2.194233932689377]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167530521040912, 1.0947299951246656`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 1, {
              Complex[6.167530521040912, 1.0947299951246656`], 
              Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184202670231408, -1.1029989218798246`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D", 2, {
              Complex[6.184202670231408, -1.1029989218798246`], 
              Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167539127149569, 1.098250419067797}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 1, {
              Complex[6.167539127149569, 1.098250419067797], 
              Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184150149994408, -1.1065228138938465`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D", 2, {
              Complex[6.184150149994408, -1.1065228138938465`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167547454548559, 1.1017444013712936`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 1, {
              Complex[6.167547454548559, 1.1017444013712936`], 
              Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184098199465816, -1.1100202402427715`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D", 2, {
              Complex[6.184098199465816, -1.1100202402427715`], 
              Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167555511082704, 1.1052123472899034`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 1, {
              Complex[6.167555511082704, 1.1052123472899034`], 
              Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1840468072888495`, -1.1134916064718126`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D", 2, {
              Complex[6.1840468072888495`, -1.1134916064718126`], 
              Complex[7.614075476378116, -2.206739345003816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167563304328588, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183995962437312, -1.1169373087010905`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D", 2, {
              Complex[6.183995962437312, -1.1169373087010905`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16757084160569, 1.1120717041858348`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 1, {
              Complex[6.16757084160569, 1.1120717041858348`], 
              Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183945654203009, -1.1203577339198187`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D", 2, {
              Complex[6.183945654203009, -1.1203577339198187`], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167578129986962, 1.1154638797377099`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 1, {
              Complex[6.167578129986962, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1838958721837285`, -1.1237532602689642`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D", 2, {
              Complex[6.1838958721837285`, -1.1237532602689642`], 
              Complex[7.613604090254429, -2.215864050835693]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167585176308896, 1.1188315486078975`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 1, {
              Complex[6.167585176308896, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1838466062718, -1.1271242573129145`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D", 2, {
              Complex[6.1838466062718, -1.1271242573129145`], 
              Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167591987181104, 1.1221750717795362`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 1, {
              Complex[6.167591987181104, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183797846643169, -1.1304710863006642`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D", 2, {
              Complex[6.183797846643169, -1.1304710863006642`], 
              Complex[7.613293610009215, -2.221831501514852]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167598568995433, 1.1254948021761624`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 1, {
              Complex[6.167598568995433, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183749583746966, -1.1337941004170402`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D", 2, {
              Complex[6.183749583746966, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167604927934658, 1.128791084903274}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 1, {
              Complex[6.167604927934658, 1.128791084903274], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183701808295563, -1.1370936450243205`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D", 2, {
              Complex[6.183701808295563, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16761106998075, 1.1320642574808064`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 1, {
              Complex[6.16761106998075, 1.1320642574808064`], 
              Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183654511255059, -1.1403700578948637`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D", 2, {
              Complex[6.183654511255059, -1.1403700578948637`], 
              Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167617000922771, 1.1353146500669256`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183607683836199, -1.1436236694349755`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D", 2, {
              Complex[6.183607683836199, -1.1436236694349755`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167622726364391, 1.1385425856735312`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 1, {
              Complex[6.167622726364391, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183561317485685, -1.1468548029005128`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D", 2, {
              Complex[6.183561317485685, -1.1468548029005128`], 
              Complex[7.612529927102651, -2.236364734026166]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676282517310606`, 1.1417483803738426`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 1, {
              Complex[6.1676282517310606`, 1.1417483803738426`], 
              Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183515403877874, -1.1500637746045628`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D", 2, {
              Complex[6.183515403877874, -1.1500637746045628`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167633582276865, 1.1449323435024108`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 1, {
              Complex[6.167633582276865, 1.1449323435024108`], 
              Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183469934906837, -1.1532508941175408`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D", 2, {
              Complex[6.183469934906837, -1.1532508941175408`], 
              Complex[7.612229226993079, -2.242030438093195]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167638723091055, 1.1480947778478905`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 1, {
              Complex[6.167638723091055, 1.1480947778478905`], 
              Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183424902678746, -1.1564164644600665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D", 2, {
              Complex[6.183424902678746, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167643679104286, 1.1512359798388985`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 1, {
              Complex[6.167643679104286, 1.1512359798388985`], 
              Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1833802995046, -1.1595607822888863`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D", 2, {
              Complex[6.1833802995046, -1.1595607822888863`], 
              Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167648455094579, 1.154356239723236}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 1, {
              Complex[6.167648455094579, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183336117893254, -1.1626841380761952`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D", 2, {
              Complex[6.183336117893254, -1.1626841380761952`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167653055693024, 1.1574558417407834`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183292350544735, -1.1657868162826117`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D", 2, {
              Complex[6.183292350544735, -1.1657868162826117`], 
              Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16765748538922, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 1, {
              Complex[6.16765748538922, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183248990343842, -1.1688690955240477`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D", 2, {
              Complex[6.183248990343842, -1.1688690955240477`], 
              Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676617485364815`, 1.1635941800905014`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 1, {
              Complex[6.1676617485364815`, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1832060303540155`, -1.171931248732845}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D", 2, {
              Complex[6.1832060303540155`, -1.171931248732845], 
              Complex[7.611342435457713, -2.258551532233561]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167665849356821, 1.1666334563353578`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 1, {
              Complex[6.167665849356821, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183163463811437, -1.1749735433132202`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D", 2, {
              Complex[6.183163463811437, -1.1749735433132202`], 
              Complex[7.611196771510031, -2.261238440302506]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167669791945717, 1.1696531548443287`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 1, {
              Complex[6.167669791945717, 1.1696531548443287`], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183121284119393, -1.1779962412914966`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D", 2, {
              Complex[6.183121284119393, -1.1779962412914966`], 
              Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167673580276672, 1.1726535322072742`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 1, {
              Complex[6.167673580276672, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1830794848428505`, -1.180999599461101}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D", 2, {
              Complex[6.1830794848428505`, -1.180999599461101], 
              Complex[7.610907194686489, -2.266557440612444]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167677218205581, 1.1756348399245424`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 1, {
              Complex[6.167677218205581, 1.1756348399245424`], 
              Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183038059703257, -1.183983869522754}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167680709474919, 1.1785973245423345`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 1, {
              Complex[6.167680709474919, 1.1785973245423345`], 
              Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182997002573542, -1.1869492982198684`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.271804947320256]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676840577177385`, 1.1815412277835526`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 1, {
              Complex[6.1676840577177385`, 1.1815412277835526`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182956307473314, -1.1898961274694768`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D", 2, {
              Complex[6.182956307473314, -1.1898961274694768`], 
              Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167687266461523, 1.1844667866743102`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 1, {
              Complex[6.167687266461523, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182915968564257, -1.1928245944888065`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D", 2, {
              Complex[6.182915968564257, -1.1928245944888065`], 
              Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167690339131856, 1.1873742336662831`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 1, {
              Complex[6.167690339131856, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1828759801456865`, -1.1957349319176866`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D", 2, {
              Complex[6.1828759801456865`, -1.1957349319176866`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167693279055961, 1.1902637967550591`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 1, {
              Complex[6.167693279055961, 1.1902637967550591`], 
              Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182836336650298, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167696089466082, 1.193135699594645}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182797032640057, -1.201502126383065}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D", 2, {
              Complex[6.182797032640057, -1.201502126383065], 
              Complex[7.609911224902995, -2.284622879275391]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167698773502733, 1.1959901616082875`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 1, {
              Complex[6.167698773502733, 1.1959901616082875`], 
              Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182758062802262, -1.2043594268588764`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D", 2, {
              Complex[6.182758062802262, -1.2043594268588764`], 
              Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167701334217814, 1.19882739809574}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182719421945745, -1.2071994848410685`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167703774577614, 1.201647620337123}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 1, {
              Complex[6.167703774577614, 1.201647620337123], 
              Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1826811049972195`, -1.210022511784006}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167706097465667, 1.2044510356934945`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182643106997762, -1.2128287152203816`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D", 2, {
              Complex[6.182643106997762, -1.2128287152203816`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167708305685528, 1.2072378477042838`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 1, {
              Complex[6.167708305685528, 1.2072378477042838`], 
              Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182605423099423, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D", 2, {
              Complex[6.182605423099423, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677104019634195`, 1.210008256181661}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 1, {
              Complex[6.1677104019634195`, 1.210008256181661], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182568048561961, -1.218391462677644}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D", 2, {
              Complex[6.182568048561961, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167712388950775, 1.2127624573020033`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 1, {
              Complex[6.167712388950775, 1.2127624573020033`], 
              Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1825309787497025`, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167714269226694, 1.2155006436945395`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 1, {
              Complex[6.167714269226694, 1.2155006436945395`], 
              Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1824942091285005`, -1.2238893126698194`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D", 2, {
              Complex[6.1824942091285005`, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167716045300302, 1.2182230045272868`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 1, {
              Complex[6.167716045300302, 1.2182230045272868`], 
              Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182457735262816, -1.2266143809612575`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D", 2, {
              Complex[6.182457735262816, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167717719612997, 1.2209297255903704`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 1, {
              Complex[6.167717719612997, 1.2209297255903704`], 
              Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1824215528129, -1.229323793839144}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D", 2, {
              Complex[6.1824215528129, -1.229323793839144], 
              Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719294540649, 1.2236209893768326`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 1, {
              Complex[6.167719294540649, 1.2236209893768326`], 
              Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182385657532068, -1.2320177339512255`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D", 2, {
              Complex[6.182385657532068, -1.2320177339512255`], 
              Complex[7.608396583634034, -2.31141882849242]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720772395696, 1.2262969751610366`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 1, {
              Complex[6.167720772395696, 1.2262969751610366`], 
              Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182350045264077, -1.2346963807243223`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D", 2, {
              Complex[6.182350045264077, -1.2346963807243223`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772215542913, 1.2289578590746735`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 1, {
              Complex[6.16772215542913, 1.2289578590746735`], 
              Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182314711940597, -1.2373599104404132`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D", 2, {
              Complex[6.182314711940597, -1.2373599104404132`], 
              Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723445832482, 1.2316038141805976`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 1, {
              Complex[6.167723445832482, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182279653578758, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167724645739662, 1.2342350105444317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 1, {
              Complex[6.167724645739662, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182244866278791, -1.242642308546148}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D", 2, {
              Complex[6.182244866278791, -1.242642308546148], 
              Complex[7.607859712684855, -2.320721705723057]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725757228776, 1.2368516153041005`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 1, {
              Complex[6.167725757228776, 1.2368516153041005`], 
              Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1822103462217495`, -1.245261514429298}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D", 2, {
              Complex[6.1822103462217495`, -1.245261514429298], 
              Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772678232385, 1.2394537927373115`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 1, {
              Complex[6.16772678232385, 1.2394537927373115`], 
              Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182176089667306, -1.2478662783795629`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D", 2, {
              Complex[6.182176089667306, -1.2478662783795629`], 
              Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727722996508, 1.2420417043271579`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 1, {
              Complex[6.167727722996508, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182142092951617, -1.2504567620199438`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772858116758, 1.2446155088257413`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 1, {
              Complex[6.16772858116758, 1.2446155088257413`], 
              Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182108352485272, -1.2530331242405153`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D", 2, {
              Complex[6.182108352485272, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729358708656, 1.247175362316046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 1, {
              Complex[6.167729358708656, 1.247175362316046], 
              Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182074864751301, -1.2555955212603063`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D", 2, {
              Complex[6.182074864751301, -1.2555955212603063`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730057443585, 1.249721418272031}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 1, {
              Complex[6.167730057443585, 1.249721418272031], 
              Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182041626303249, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D", 2, {
              Complex[6.182041626303249, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730679149904, 1.2522538276170248`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 1, {
              Complex[6.167730679149904, 1.2522538276170248`], 
              Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182008633763318, -1.260679031577555}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731225560259, 1.2547727387804994`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181975883820568, -1.2632004444906197`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D", 2, {
              Complex[6.181975883820568, -1.2632004444906197`], 
              Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731698363721, 1.2572782977532326`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1819433732291715`, -1.2657084915461239`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D", 2, {
              Complex[6.1819433732291715`, -1.2657084915461239`], 
              Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732099207092, 1.2597706481409663`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 1, {
              Complex[6.167732099207092, 1.2597706481409663`], 
              Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181911098806735, -1.2682033164767692`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D", 2, {
              Complex[6.181911098806735, -1.2682033164767692`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732429696165, 1.2622499312165703`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 1, {
              Complex[6.167732429696165, 1.2622499312165703`], 
              Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1818790574326545`, -1.2706850606806677`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D", 2, {
              Complex[6.1818790574326545`, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732691396911, 1.2647162859707828`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181847246046556, -1.273153863272108}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D", 2, {
              Complex[6.181847246046556, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732885836667, 1.2671698491615644`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 1, {
              Complex[6.167732885836667, 1.2671698491615644`], 
              Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181815661646743, -1.275609861130944}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D", 2, {
              Complex[6.181815661646743, -1.275609861130944], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733014505244, 1.2696107553621172`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 1, {
              Complex[6.167733014505244, 1.2696107553621172`], 
              Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1817843012887375`, -1.2780531889506415`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D", 2, {
              Complex[6.1817843012887375`, -1.2780531889506415`], 
              Complex[7.606032678038458, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733078856032, 1.272039137007607}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 1, {
              Complex[6.167733078856032, 1.272039137007607], 
              Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181753162083825, -1.2804839792850273`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.353740237720617]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677330803070305`, 1.2744551244406346`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 1, {
              Complex[6.1677330803070305`, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181722241197679, -1.2829023625937932`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733020241881, 1.276858845955496}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 1, {
              Complex[6.167733020241881, 1.276858845955496], 
              Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181691535849006, -1.2853084672867796`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D", 2, {
              Complex[6.181691535849006, -1.2853084672867796`], 
              Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677329000108365`, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181661043308228, -1.2877024197670905`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D", 2, {
              Complex[6.181661043308228, -1.2877024197670905`], 
              Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732720931719, 1.2816299944237621`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 1, {
              Complex[6.167732720931719, 1.2816299944237621`], 
              Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181630760896252, -1.2900843444730699`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D", 2, {
              Complex[6.181630760896252, -1.2900843444730699`], 
              Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732484290831, 1.2839976681063678`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 1, {
              Complex[6.167732484290831, 1.2839976681063678`], 
              Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181600685983191, -1.2924543639191768`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D", 2, {
              Complex[6.181600685983191, -1.2924543639191768`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732191343831, 1.2863535694098465`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181570815987224, -1.2948125987358035`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D", 2, {
              Complex[6.181570815987224, -1.2948125987358035`], 
              Complex[7.605146784820535, -2.366194163693253]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731843316621, 1.2886978170110817`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 1, {
              Complex[6.167731843316621, 1.2886978170110817`], 
              Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181541148373396, -1.2971591677080394`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D", 2, {
              Complex[6.181541148373396, -1.2971591677080394`], 
              Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731441406146, 1.2910305277808336`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18151168065253, -1.2994941878134685`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D", 2, {
              Complex[6.18151168065253, -1.2994941878134685`], 
              Complex[7.604896783758138, -2.370257325860909]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730986781208, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181482410380124, -1.3018177742589643`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730480583245, 1.2956617974980968`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18145333515529, -1.3041300405165688`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D", 2, {
              Complex[6.18145333515529, -1.3041300405165688`], 
              Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729923927075, 1.2979605814829254`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 1, {
              Complex[6.167729923927075, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181424452619743, -1.3064310983584468`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D", 2, {
              Complex[6.181424452619743, -1.3064310983584468`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729317901629, 1.3002482787798992`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181395760456799, -1.3087210578909678`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D", 2, {
              Complex[6.181395760456799, -1.3087210578909678`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167728663570656, 1.3025249977626074`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 1, {
              Complex[6.167728663570656, 1.3025249977626074`], 
              Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181367256390402, -1.3110000275879252`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D", 2, {
              Complex[6.181367256390402, -1.3110000275879252`], 
              Complex[7.604277546409371, -2.380230742900865]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727961973395, 1.304790845205713}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 1, {
              Complex[6.167727961973395, 1.304790845205713], 
              Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181338938184205, -1.3132681143229286`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D", 2, {
              Complex[6.181338938184205, -1.3132681143229286`], 
              Complex[7.604154661093243, -2.382194632873834]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727214125249, 1.307045926316517}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 1, {
              Complex[6.167727214125249, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18131080364063, -1.3155254234009877`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D", 2, {
              Complex[6.18131080364063, -1.3155254234009877`], 
              Complex[7.604032089130619, -2.384148493285349]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167726421018415, 1.3092903447657456`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 1, {
              Complex[6.167726421018415, 1.3092903447657456`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181282850600006, -1.3177720585893227`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D", 2, {
              Complex[6.181282850600006, -1.3177720585893227`], 
              Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725583622502, 1.311524202717574}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 1, {
              Complex[6.167725583622502, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181255076939699, -1.3200081221474058`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772470288514, 1.313747600858923}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 1, {
              Complex[6.16772470288514, 1.313747600858923], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181227480573279, -1.32223371485628}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D", 2, {
              Complex[6.181227480573279, -1.32223371485628], 
              Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723779732554, 1.3159606384280345`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 1, {
              Complex[6.167723779732554, 1.3159606384280345`], 
              Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181200059449696, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D", 2, {
              Complex[6.181200059449696, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167722815070127, 1.3181634132423612`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 1, {
              Complex[6.167722815070127, 1.3181634132423612`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1811728115525035`, -1.3266538836292885`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D", 2, {
              Complex[6.1811728115525035`, -1.3266538836292885`], 
              Complex[7.603423824286758, -2.393770722784648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167721809782957, 1.3203560217257764`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 1, {
              Complex[6.167721809782957, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181145734899095, -1.3288486541172821`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D", 2, {
              Complex[6.181145734899095, -1.3288486541172821`], 
              Complex[7.603303069891951, -2.395666408981522]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720764736373, 1.322538558935139}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 1, {
              Complex[6.167720764736373, 1.322538558935139], 
              Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181118827539914, -1.3310333426575782`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D", 2, {
              Complex[6.181118827539914, -1.3310333426575782`], 
              Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719680776454, 1.3247111185862182`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 1, {
              Complex[6.167719680776454, 1.3247111185862182`], 
              Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1810920875578015`, -1.3332080430544786`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D", 2, {
              Complex[6.1810920875578015`, -1.3332080430544786`], 
              Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167718558730529, 1.326873793079005}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181065513067208, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677173994076595`, 1.3290266735224265`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1810391022135605`, -1.337527848075709}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D", 2, {
              Complex[6.1810391022135605`, -1.337527848075709], 
              Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.835375273896375, 0.0068877274873969585`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[8.118560581075961, 0.0068877274873969585`], 
              Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.256708885709244, -0.01324317030169899}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[10.53989419288883, -0.01324317030169899], 
              Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.8793954305522718`, 0.007042959985370651}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[8.162580737731858, 0.007042959985370651], 
              Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{4.2113214600894135`, -0.013509876715323853`}],
            
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[10.494506767269, -0.013509876715323853`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.915802670687297, 0.007197843246654797}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[8.198987977866883, 0.007197843246654797], 
              Complex[6.557943371421671, -1.162972548762566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.173857149859479, -0.013751044852512806`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[10.457042457039066`, -0.013751044852512806`], 
              Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{1.9478198407061686`, 0.0073549519610065905`}],
            
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[8.231005147885755, 0.0073549519610065905`], 
              Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.140962109899144, -0.0139798695984579}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[10.42414741707873, -0.0139798695984579], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{1.9769135970793723`, 0.007515591774090756}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[8.260098904258959, 0.007515591774090756], 
              Complex[6.61778553109412, -1.162803172863648]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.111110404529024, -0.014202465960725278`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[10.39429571170861, -0.014202465960725278`], 
              Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.0038991723363875`, 0.007680628289981289}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[8.287084479515974, 0.007680628289981289], 
              Complex[6.644124842294815, -1.162714599075609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.0834540601043585`, -0.014422357660350082`}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[10.366639367283945`, -0.014422357660350082`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.029285980823266, 0.00785074316053409}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[8.312471288002852, 0.00785074316053409], 
              Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.057463354284032, -0.014641876121436062`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[10.340648661463618`, -0.014641876121436062`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.0534182576456885`, 0.00802653852897203}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[8.336603564825275, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.03278044885818, -0.014862729232274637`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[10.315965756037766`, -0.014862729232274637`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.0765422015150072`, 0.008208588338762687}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[8.359727508694593, 0.008208588338762687], 
              Complex[6.714779367617378, -1.162425692393188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{4.009149517865804, -0.015086273942248}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[10.29233482504539, -0.015086273942248], 
              Complex[8.556435217312078, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.0988417360296054`, 0.008397467701836855}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[8.382027043209192, 0.008397467701836855], 
              Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.986379536084371, -0.01531366326459591}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[10.269564843263957`, -0.01531366326459591], 
              Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.1204591522632334`, 0.008593772293729832}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[8.40364445944282, 0.008593772293729832], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.964322801513349, -0.01554593341902805}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[10.247508108692935`, -0.01554593341902805], 
              Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.1415077878742395`, 0.00879813306517896}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[8.424693095053826, 0.00879813306517896], 
              Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.942861745080835, -0.01578406003523005}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[10.226047052260421`, -0.01578406003523005], 
              Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.1620802125750025`, 0.009011228909084963}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[8.445265519754589, 0.009011228909084963], 
              Complex[6.797539667322055, -1.161966845801127]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.921900416532484, -0.016028997503587203`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[10.20508572371207, -0.016028997503587203`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.1822537352646147`, 0.009233798770935121}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[8.465439042444201, 0.009233798770935121], 
              Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.9013587574352186`, -0.016281708942805753`}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[10.184544064614805`, -0.016281708942805753`], 
              Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.202094242426611, 0.009466654168547486}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[8.485279549606197, 0.009466654168547486], 
              Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.881168610740989, -0.016543191071888914`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[10.164353917920575`, -0.016543191071888914`], 
              Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.2216589584818873`, 0.009710692858210806}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[8.504844265661474, 0.009710692858210806], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.861270852315977, -0.016814496662831836`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[10.144456159495563`, -0.016814496662831836`], 
              Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.2409984889208037`, 0.00996691431009624}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.8416132690596694`, -0.017096756417673668`}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[10.124798576239256`, -0.017096756417673668`], 
              Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.260158375118049, 0.01023643767719948}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[8.543343682297635, 0.01023643767719948], 
              Complex[6.891907468896068, -1.161220171125207]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.8221489455293263`, -0.017391201699304026`}],
            
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[10.105334252708913`, -0.017391201699304026`], 
              Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.2791803111434685`, 0.010520523036427927`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[8.562365618323055, 0.010520523036427927`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.8028350027827695`, -0.017699189379580486`}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[10.086020309962356`, -0.017699189379580486`], 
              Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.298103124618141, 0.010820596844492403`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[8.581288431797727, 0.010820596844492403`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.7836315833970744`, -0.018022230071644385`}],
            
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[10.06681689057666, -0.018022230071644385`], 
              Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.3169635933418, 0.011138282794836918`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[8.600148900521386, 0.011138282794836918`], 
              Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.76450100820397, -0.018362021154624195`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[10.047686315383556`, -0.018362021154624195`], 
              Complex[8.319026572634915, -1.199065136952576]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.335797150124977, 0.011475439606775252`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[8.618982457304563, 0.011475439606775252`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.745407050398274, -0.018720486277070698`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[10.02859235757786, -0.018720486277070698`], 
              Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.354638516036987, 0.011834207760463409`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[8.637823823216573, 0.011834207760463409`], 
              Complex[6.982345361327388, -1.160172170534845]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.7263142854475664`, -0.019099823463292497`}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[10.009499592627153`, -0.019099823463292497`], 
              Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.3735222948334567`, 0.012217067867222313`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[8.656707602013043, 0.012217067867222313`], 
              Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.7071874830540352`, -0.01950256459218661}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[9.990372790233621, -0.01950256459218661], 
              Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.3924835573451926`, 0.012626914319474911`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[8.675668864524779, 0.012626914319474911`], 
              Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.6879910116617527`, -0.019931649951741043`}],
            
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[9.971176318841339, -0.019931649951741043`], 
              Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.411558443419146, 0.013067149229433986`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[8.694743750598732, 0.013067149229433986`], 
              Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.668688227378258, -0.020390522922278387`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[9.951873534557844, -0.020390522922278387`], 
              Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.430784810385237, 0.013541803645186434`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[8.713970117564823, 0.013541803645186434`], 
              Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.64924081792841, -0.020883251810279745`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[9.932426125107996, -0.020883251810279745`], 
              Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.4502029611655267`, 0.014055695951277626`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[8.733388268345113, 0.014055695951277626`], 
              Complex[7.073421269042284, -1.158603006979818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.629608068212228, -0.02141468876524509}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[9.912793375391814, -0.02141468876524509], 
              Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.4698564926690008`, 0.014614641743299649`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[8.753041799848587, 0.014614641743299649`], 
              Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.609746006582622, -0.021990680088691875`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[9.892931313762208, -0.021990680088691875`], 
              Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.489793317232694, 0.015225736181981687`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[8.77297862441228, 0.015225736181981687`], 
              Complex[7.111050585905176, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.589606378894489, -0.02261834895605743}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[9.872791686074075, -0.02261834895605743], 
              Complex[8.151078988162066, -1.201907179567137]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.5100669286617165`, 0.01589774035976148}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[8.793252235841303, 0.01589774035976148], 
              Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.5691353786248374`, -0.02330648209651281}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[9.852320685804424, -0.02330648209651281], 
              Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.5307380133970874`, 0.016641620135819556`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[8.813923320576674, 0.016641620135819556`], 
              Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.548272032417753, -0.02406606889621767}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[9.831457339597339, -0.02406606889621767], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.5518765524466467`, 0.017471313877762306`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[8.835061859626233, 0.017471313877762306`], 
              Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.526946095325103, -0.02491106937082747}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[9.81013140250469, -0.02491106937082747], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.573564631215268, 0.01840485331132207}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.01840485331132207], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.505075238531173, -0.02585953521479562}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479562], 
              Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.5959002904500483`, 0.019466046203823823`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629635, 0.019466046203823823`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.482561196284193, -0.02693529265819088}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.02693529265819088], 
              Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.6190029453695978`, 0.020687085496539234`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549184, 0.020687085496539234`], 
              Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.4592843449155595`, -0.028170551750257837`}],
            
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095146, -0.028170551750257837`], 
              Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.6430212342631165`, 0.02211275107353916}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442703, 0.02211275107353916], 
              Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.4350958526198863`, -0.029610108260631186`}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631186`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.6681447542728236`, 0.023807487220115792`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.023807487220115792`], 
              Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.409805942248381, -0.0313184212541546}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427967, -0.0313184212541546], 
              Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.694622244128986, 0.025867986584037196`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308572, 0.025867986584037196`], 
              Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.3831657073179144`, -0.033392197154710215`}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.033392197154710215`], 
              Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.72279086858876, 0.028447097632704935`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768346, 0.028447097632704935`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{3.3548378264610985`, -0.035984297293206895`}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.035984297293206895`], 
              Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.7531252397850405`, 0.031803157852373865`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964627, 0.031803157852373865`], 
              Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.324347541091422, -0.039353071187373335`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187373335`], 
              Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.786321442260892, 0.03641303093548226}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.069506749440478, 0.03641303093548226], 
              Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.290998629490968, -0.04397539380088848}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670554, -0.04397539380088848], 
              Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.823432065175087, 0.04326772266645232}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645232], 
              Complex[7.426654831776879, -1.133628019546016]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.2537383738213688`, -0.05084228149321134}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000955, -0.05084228149321134], 
              Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.865941852546902, 0.05476808187732223}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732223], 
              Complex[7.466802670715167, -1.123122290976753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.2110819091776026`, -0.062354593032578}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.494267216357189, -0.062354593032578], 
              Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.914112922979591, 0.07734359441247762}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.07734359441247762], 
              Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.1627670032350377`, -0.08494182361234351}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414624, -0.08494182361234351], 
              Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.9563801024681613`, 0.11902724764149018`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647748, 0.11902724764149018`], 
              Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.1203587228755527`, -0.12663696940988678`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055139, -0.12663696940988678`], 
              Complex[7.704988630788347, -1.296125883577755]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.9791320406048776`, 0.16611165996512323`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784464, 0.16611165996512323`], 
              Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.097468317471238, -0.17373265713467972`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650824, -0.17373265713467972`], 
              Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.9906097119410937`, 0.20695392178184982`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.20695392178184982`], 
              Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.08585471706132, -0.21458598503237647`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240906, -0.21458598503237647`], 
              Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{2.9973852219104025`, 0.24191392575349288`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.280570529089989, 0.24191392575349288`], 
              Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.078945726010728, -0.2495568531847539}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.2495568531847539], 
              Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0018999182968713`, 0.27256109297706776`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.285085225476458, 0.27256109297706776`], 
              Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0742999111630223`, -0.2802146897125705}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.2802146897125705], 
              Complex[7.660008665723722, -1.440191789692609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0051567423263883`, 0.3000009300835058}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835058], 
              Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0709142504036837`, -0.30766500790255313`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.35409955758327, -0.30766500790255313`], 
              Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.007636616611002, 0.32496389242763857`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790588, 0.32496389242763857`], 
              Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0683077444017055`, -0.33263826942312025`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581292, -0.33263826942312025`], 
              Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0095993807732047`, 0.34794816918876}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.34794816918876], 
              Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0662204806984583`, -0.35563266944840766`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.349405787878045, -0.35563266944840766`], 
              Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.011198437106371, 0.36930769700429716`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285957, 0.36930769700429716`], 
              Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0644989877849493`, -0.37700215031345224`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.37700215031345224`], 
              Complex[7.649655116243796, -1.530899113668034]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0125306470368933`, 0.3893033507690842}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.3893033507690842], 
              Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.063046338399529, -0.3970075923331433}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579115, -0.3970075923331433], 
              Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.013660459099288, 0.4081334915298239}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 1, {
              Complex[9.296845766278874, 0.4081334915298239], 
              Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.061798021332402, -0.41584736171471265`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 2, {
              Complex[9.344983328511988, -0.41584736171471265`], 
              Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0146325865456625`, 0.42595292805234636`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 1, {
              Complex[9.297817893725249, 0.42595292805234636`], 
              Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.060709263613706, -0.4336762721416326}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 2, {
              Complex[9.343894570793292, -0.4336762721416326], 
              Complex[7.645371333222616, -1.583906400971115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.015479126878571, 0.44288515307919907`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 1, {
              Complex[9.298664434058157, 0.44288515307919907`], 
              Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0597479107944707`, -0.45061782104638065`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C", 2, {
              Complex[9.342933217974057, -0.45061782104638065`], 
              Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0162237831646177`, 0.45903052180506093`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 1, {
              Complex[9.299409090344204, 0.45903052180506093`], 
              Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0588902054611413`, -0.4667723681000823}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 2, {
              Complex[9.342075512640728, -0.4667723681000823], 
              Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0168844823195258`, 0.47447188989313444`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 1, {
              Complex[9.300069789499112, 0.47447188989313444`], 
              Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0581181687923014`, -0.4822227732417421}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 2, {
              Complex[9.341303475971888, -0.4822227732417421], 
              Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0174750619570183`, 0.4892786068277399}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0574179135633273`, -0.497038390042908}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 2, {
              Complex[9.340603220742913, -0.497038390042908], 
              Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0180063929492604`, 0.503509412285517}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 1, {
              Complex[9.301191700128847, 0.503509412285517], 
              Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0567785214505356`, -0.5112779620899647}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 2, {
              Complex[9.339963828630122, -0.5112779620899647], 
              Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0184871476583695`, 0.5172145811965813}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 1, {
              Complex[9.301672454837956, 0.5172145811965813], 
              Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.056191274674193, -0.5249917680556035}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C", 2, {
              Complex[9.339376581853779, -0.5249917680556035], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0189243386591293`, 0.5304375419992581}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 1, {
              Complex[9.302109645838716, 0.5304375419992581], 
              Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.055649117159442, -0.5382232399630629}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C", 2, {
              Complex[9.338834424339028, -0.5382232399630629], 
              Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0193237047071655`, 0.5432161176861714}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 1, {
              Complex[9.302509011886752, 0.5432161176861714], 
              Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.055146268460051, -0.5510102042411122}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C", 2, {
              Complex[9.338331575639637, -0.5510102042411122], 
              Complex[7.638493829265324, -1.693304925020469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.019689992570811, 0.5555834916479572}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 1, {
              Complex[9.302875299750397, 0.5555834916479572], 
              Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.054677941826087, -0.5633858475760003}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 2, {
              Complex[9.337863249005673, -0.5633858475760003], 
              Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0200271663416896`, 0.5675689693259758}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 1, {
              Complex[9.303212473521276, 0.5675689693259758], 
              Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.054240134799807, -0.5753794785718535}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.020338565268938, 0.5791985860418385}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 1, {
              Complex[9.303523872448524, 0.5791985860418385], 
              Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0538294712943195`, -0.5870171355873209}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C", 2, {
              Complex[9.337014778473906, -0.5870171355873209], 
              Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0206270244227316`, 0.5904955973399487}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 1, {
              Complex[9.303812331602318, 0.5904955973399487], 
              Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.053443080848778, -0.5983220770848241}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 2, {
              Complex[9.336628388028364, -0.5983220770848241], 
              Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0208949680974175`, 0.6014808784641332}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 1, {
              Complex[9.304080275277004, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0530785051493954`, -0.609315181113391}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C", 2, {
              Complex[9.336263812328982, -0.609315181113391], 
              Complex[7.635641241458829, -1.747457014478097]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0211444829382597`, 0.612173252747982}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 1, {
              Complex[9.304329790117846, 0.612173252747982], 
              Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0527336248317756`, -0.6200152737048319}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 2, {
              Complex[9.335918932011362, -0.6200152737048319], 
              Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.021377375791184, 0.6225897638061416}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 1, {
              Complex[9.30456268297077, 0.6225897638061416], 
              Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.052406601564826, -0.6304394010704698}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 2, {
              Complex[9.335591908744412, -0.6304394010704698], 
              Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.021595219905608, 0.6327459028649576}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 1, {
              Complex[9.304780527085194, 0.6327459028649576], 
              Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.052095831785854, -0.6406030569368892}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 2, {
              Complex[9.33528113896544, -0.6406030569368892], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0217993921608617`, 0.6426557999628848}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 1, {
              Complex[9.304984699340448, 0.6426557999628848], 
              Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.051799909415889, -0.6505203737511226}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 2, {
              Complex[9.334985216595475, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.021991103304975, 0.6523323858111223}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 1, {
              Complex[9.305176410484561, 0.6523323858111223], 
              Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0515175955663416`, -0.6602042845457757}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C", 2, {
              Complex[9.334702902745928, -0.6602042845457757], 
              Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0221714227030034`, 0.6617875296457956}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 1, {
              Complex[9.30535672988259, 0.6617875296457956], 
              Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0512477937393783`, -0.6696666607954201}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C", 2, {
              Complex[9.334433100918964, -0.6696666607954201], 
              Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.022341298734297, 0.6710321572939462}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 1, {
              Complex[9.305526605913883, 0.6710321572939462], 
              Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.050989529382541, -0.6789184304865283}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C", 2, {
              Complex[9.334174836562127, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.022501575713637, 0.6800763528244194}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 1, {
              Complex[9.305686882893223, 0.6800763528244194], 
              Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.050741932922268, -0.6879696797720991}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 2, {
              Complex[9.333927240101854, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.022653008014599, 0.6889294464957751}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 1, {
              Complex[9.305838315194185, 0.6889294464957751], 
              Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0505042255979493`, -0.6968297409230606}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 2, {
              Complex[9.333689532777536, -0.6968297409230606], 
              Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.022796271925211, 0.697600091198504}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 1, {
              Complex[9.305981579104797, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0502757075661275`, -0.705507268773781}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C", 2, {
              Complex[9.333461014745714, -0.705507268773781], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0229319756534334`, 0.7060963291837463}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 1, {
              Complex[9.30611728283302, 0.7060963291837463], 
              Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0500557478571544`, -0.7140103074539126}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C", 2, {
              Complex[9.33324105503674, -0.7140103074539126], 
              Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0230606678139385`, 0.7144256505494249}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 1, {
              Complex[9.306245974993525, 0.7144256505494249], 
              Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0498437758527714`, -0.7223463488774439}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 2, {
              Complex[9.333029083032358, -0.7223463488774439], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0231828446608073`, 0.722595044698084}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 1, {
              Complex[9.306368151840394, 0.722595044698084], 
              Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.049639274019695, -0.73052238420331}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 2, {
              Complex[9.332824581199281, -0.73052238420331], 
              Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.023298956279243, 0.730611045774511}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 1, {
              Complex[9.30648426345883, 0.730611045774511], 
              Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0494417716861264`, -0.7385449492756353}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 2, {
              Complex[9.332627078865713, -0.7385449492756353], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.023409411908453, 0.7384797729243899}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 1, {
              Complex[9.30659471908804, 0.7384797729243899], 
              Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0492508396887654`, -0.7464201648848554}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C", 2, {
              Complex[9.332436146868352, -0.7464201648848554], 
              Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.023514584536107, 0.7462069660795199}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 1, {
              Complex[9.306699891715693, 0.7462069660795199], 
              Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.049066085749949, -0.7541537725552647}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0236148148790125`, 0.7537980178639988}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 1, {
              Complex[9.306800122058599, 0.7537980178639988], 
              Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0488871504700406`, -0.7617511664534365}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 2, {
              Complex[9.332072457649627, -0.7617511664534365], 
              Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.023710414844521, 0.7612580021246124}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 1, {
              Complex[9.306895722024107, 0.7612580021246124], 
              Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.048713703840553, -0.7692174219206883}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C", 2, {
              Complex[9.33189901102014, -0.7692174219206883], 
              Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0238016705506805`, 0.7685916995129599}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 1, {
              Complex[9.306986977730267, 0.7685916995129599], 
              Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0485454421998224`, -0.7765573210571958}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C", 2, {
              Complex[9.331730749379409, -0.7765573210571958], 
              Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0238888449700045`, 0.7758036204842984}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 1, {
              Complex[9.30707415214959, 0.7758036204842984], 
              Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0483820855663666`, -0.7837753757227326}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C", 2, {
              Complex[9.331567392745953, -0.7837753757227326], 
              Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0239721802509454`, 0.7828980260257034}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 1, {
              Complex[9.307157487430532, 0.7828980260257034], 
              Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.048223375295681, -0.7908758482666055}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 2, {
              Complex[9.331408682475267, -0.7908758482666055], 
              Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024051899762382, 0.7898789463823147}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 1, {
              Complex[9.307237206941968, 0.7898789463823147], 
              Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0480690720151156`, -0.7978627702556061}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 2, {
              Complex[9.331254379194702, -0.7978627702556061], 
              Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024128209899315, 0.7967501980135657}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 1, {
              Complex[9.307313517078901, 0.7967501980135657], 
              Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0479189537986056`, -0.8047399594318435}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 2, {
              Complex[9.331104260978192, -0.8047399594318435], 
              Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0242013016819165`, 0.8035153989801238}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 1, {
              Complex[9.307386608861503, 0.8035153989801238], 
              Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0477728145490097`, -0.811511035101225}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 2, {
              Complex[9.330958121728596, -0.811511035101225], 
              Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024271352175301, 0.8101779829358526}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 1, {
              Complex[9.307456659354887, 0.8101779829358526], 
              Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0476304625606456`, -0.818179432126868}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024338525753162, 0.8167412118766469}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 1, {
              Complex[9.307523832932748, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0474917192387867`, -0.824748413679325}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 2, {
              Complex[9.330677026418373, -0.824748413679325], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0244029752252324`, 0.8232081877787825}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 1, {
              Complex[9.307588282404819, 0.8232081877787825], 
              Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0473564179562196`, -0.8312210828762443}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 2, {
              Complex[9.330541725135806, -0.8312210828762443], 
              Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0244648428453935`, 0.8295818632429439}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 1, {
              Complex[9.30765015002498, 0.8295818632429439], 
              Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.047224403029862, -0.8376003934276777}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024524261215184, 0.8358650512460974}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 1, {
              Complex[9.30770956839477, 0.8358650512460974], 
              Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.047095528802684, -0.8438891593891124}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 2, {
              Complex[9.33028083598227, -0.8438891593891124], 
              Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024581354095119, 0.8420604340909561}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.046969658818565, -0.8500900641121139}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C", 2, {
              Complex[9.330154965998151, -0.8500900641121139], 
              Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024636237134832, 0.8481705716325364}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 1, {
              Complex[9.307821544314418, 0.8481705716325364], 
              Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0468466650789274`, -0.856205668471937}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C", 2, {
              Complex[9.330031972258514, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0246890185313227`, 0.8541979088518956}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 1, {
              Complex[9.307874325710909, 0.8541979088518956], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04672642737186, -0.8622384184423436}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 2, {
              Complex[9.329911734551446, -0.8622384184423436], 
              Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024739799623603, 0.860144782839487}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 1, {
              Complex[9.30792510680319, 0.860144782839487], 
              Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.046608832665454, -0.8681906520799052}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C", 2, {
              Complex[9.32979413984504, -0.8681906520799052], 
              Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02478867543077, 0.8660134292433511}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 1, {
              Complex[9.307973982610356, 0.8660134292433511], 
              Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.046493774558215, -0.8740646059731706}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.990999855207028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.024835735139801, 0.8718059882315835}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 1, {
              Complex[9.308021042319387, 0.8718059882315835], 
              Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.046381152780306, -0.8798624212060276}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 2, {
              Complex[9.329566459959892, -0.8798624212060276], 
              Complex[7.624115410024538, -1.996281512181469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0248810625484506`, 0.8775245100130518}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 1, {
              Complex[9.308066369728037, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0462708727401235`, -0.8855861488792872}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 2, {
              Complex[9.32945617991971, -0.8855861488792872], 
              Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0249247364681064`, 0.8831709599557607}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 1, {
              Complex[9.308110043647693, 0.8831709599557607], 
              Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0461628451114304`, -0.8912377552298729}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 2, {
              Complex[9.329348152291017, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0249668310907243`, 0.888747223338151}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0460569854568007`, -0.8968191263829126}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 2, {
              Complex[9.329242292636387, -0.8968191263829126], 
              Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0250074163235983`, 0.8942551097650254}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 1, {
              Complex[9.308192723503184, 0.8942551097650254], 
              Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04595321388366, -0.9023320727684233}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 2, {
              Complex[9.329138521063246, -0.9023320727684233], 
              Complex[7.623188002862294, -2.016726496581311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025046558095223, 0.8996963572765849}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 1, {
              Complex[9.30823186527481, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0458514547296307`, -0.9077783332310709}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C", 2, {
              Complex[9.329036761909217, -0.9077783332310709], 
              Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0250843186351304`, 0.9050726361762732}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 1, {
              Complex[9.308269625814717, 0.9050726361762732], 
              Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0457516362742716`, -0.9131595788587061}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C", 2, {
              Complex[9.328936943453858, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02512075673026, 0.9103855526005625}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 1, {
              Complex[9.308306063909846, 0.9103855526005625], 
              Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0456536904746105`, -0.9184774165528234}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C", 2, {
              Complex[9.328838997654197, -0.9184774165528234], 
              Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025155927960185, 0.9156366518516708}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 1, {
              Complex[9.308341235139771, 0.9156366518516708], 
              Complex[7.621537327849359, -0.321751242072515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0455575527221956`, -0.923733392361904}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0251898849131607`, 0.9208274215121248}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 1, {
              Complex[9.308375192092747, 0.9208274215121248], 
              Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0454631616196384`, -0.9289289945966074}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 2, {
              Complex[9.328648468799225, -0.9289289945966074], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025222677384834, 0.9259592943584085}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 1, {
              Complex[9.30840798456442, 0.9259592943584085], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0453704587747534`, -0.9340656567439881}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C", 2, {
              Complex[9.32855576595434, -0.9340656567439881], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02525435256125, 0.931033651089264}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 1, {
              Complex[9.308439659740836, 0.931033651089264], 
              Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0452793886107585`, -0.9391447601963729}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 2, {
              Complex[9.328464695790345, -0.9391447601963729], 
              Complex[7.621658530284444, -2.050135996258459]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025284955187523, 0.9360518228828761}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 1, {
              Complex[9.30847026236711, 0.9360518228828761], 
              Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0451898981910084`, -0.9441676368090878}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 2, {
              Complex[9.328375205370595, -0.9441676368090878], 
              Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025314527723575, 0.9410150937958542}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 1, {
              Complex[9.308499834903161, 0.9410150937958542], 
              Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0451019370569945`, -0.9491355712999281}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 2, {
              Complex[9.32828724423658, -0.9491355712999281], 
              Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0253431104879898`, 0.9459247030157971}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 1, {
              Complex[9.308528417667576, 0.9459247030157971], 
              Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.045015457078428, -0.9540498035022821}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 2, {
              Complex[9.328200764258014, -0.9540498035022821], 
              Complex[7.621034500886904, -2.063631600211478]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0253707417911, 0.9507818469782096}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 1, {
              Complex[9.308556048970686, 0.9507818469782096], 
              Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.044930412314331, -0.9589115304824558}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C", 2, {
              Complex[9.328115719493917, -0.9589115304824558], 
              Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0253974580582366`, 0.9555876813576076}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 1, {
              Complex[9.308582765237823, 0.9555876813576076], 
              Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0448467588842405`, -0.9637219085312987}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 2, {
              Complex[9.328032066063827, -0.9637219085312987], 
              Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0254232939439234`, 0.960343322941825}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 1, {
              Complex[9.30860860112351, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0447644548486057`, -0.9684820550389235}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 2, {
              Complex[9.327949762028192, -0.9684820550389235], 
              Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0254482824378925`, 0.9650498513977598}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 1, {
              Complex[9.308633589617479, 0.9650498513977598], 
              Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.044683460097616, -0.9731930502608676}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0254724549634933`, 0.9697083109361536}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 1, {
              Complex[9.30865776214308, 0.9697083109361536], 
              Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04460373624784, -0.9778559389833152}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C", 2, {
              Complex[9.327789043427426, -0.9778559389833152], 
              Complex[7.620030720208938, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025495841469194, 0.974319711882344}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 1, {
              Complex[9.30868114864878, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.044525246545925, -0.9824717320942182}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0255184705137257`, 0.9788850321593942}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 1, {
              Complex[9.308703777693312, 0.9788850321593942], 
              Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.044447955778864, -0.9870414080668136}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 2, {
              Complex[9.32763326295845, -0.9870414080668136], 
              Complex[7.619640805534105, -2.093436192381357]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025540369345352, 0.9834052186894814}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 1, {
              Complex[9.308725676524938, 0.9834052186894814], 
              Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0443718301902685`, -0.991565914361383}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0255615639757973`, 0.9878811887189863}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 1, {
              Complex[9.308746871155384, 0.9878811887189863], 
              Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0442968374022055`, -0.9960461687506829}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 2, {
              Complex[9.327482144581792, -0.9960461687506829], 
              Complex[7.619257020505317, -2.10155454761218]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02558207924916, 0.9923138310722672}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 1, {
              Complex[9.308767386428746, 0.9923138310722672], 
              Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0442229463421437`, -1.000483060574067}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 2, {
              Complex[9.32740825352173, -1.000483060574067], 
              Complex[7.6190673329092, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025601938906293, 0.9967040073387546}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 1, {
              Complex[9.30878724608588, 0.9967040073387546], 
              Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0441501271746194`, -1.0048774519249142`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 2, {
              Complex[9.327335434354206, -1.0048774519249142`], 
              Complex[7.618879068115525, -2.109509448113651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0256211656449423`, 1.0010525529976397`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0440783512372587`, -1.009230178775591}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 2, {
              Complex[9.327263658416845, -1.009230178775591], 
              Complex[7.618692192411457, -2.113427630566214]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025639781175995, 1.0053602784840994`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0440075909808684`, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025657806276117, 1.0096279702007276`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 1, {
              Complex[9.308843113455703, 1.0096279702007276`], 
              Complex[7.622275519945756, -0.236216870343528]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0439378199132374`, -1.0178138586055234`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C", 2, {
              Complex[9.327123127092824, -1.0178138586055234`], 
              Complex[7.618322479547946, -2.12114930362412]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025675260837035, 1.0138563914775585`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 1, {
              Complex[9.308860568016621, 1.0138563914775585`], 
              Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04386901254637, -1.0220463622527831`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 2, {
              Complex[9.327054319725956, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0256921639117547`, 1.0180462834838366`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 1, {
              Complex[9.308877471091341, 1.0180462834838366`], 
              Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.043801144347068, -1.0262403046082496`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C", 2, {
              Complex[9.326986451526654, -1.0262403046082496`], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0257085337578857`, 1.0221983660944407`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 1, {
              Complex[9.308893840937472, 1.0221983660944407`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.043734191690298, -1.030396405990655}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C", 2, {
              Complex[9.326919498869884, -1.030396405990655], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025724387878313, 1.0263133387136967`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 1, {
              Complex[9.3089096950579, 1.0263133387136967`], 
              Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0436681318154974`, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025739743059404, 1.0303918810590929`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 1, {
              Complex[9.30892505023899, 1.0303918810590929`], 
              Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0436029427853626`, -1.0385978654970531`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 2, {
              Complex[9.326788249964949, -1.0385978654970531`], 
              Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0257546154068944`, 1.034434653907242}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 1, {
              Complex[9.30893992258648, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0435386034470806`, -1.042644564958483}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 2, {
              Complex[9.326723910626667, -1.042644564958483], 
              Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025769020379668, 1.0384422998042997`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 1, {
              Complex[9.308954327559254, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0434750933957933`, -1.0466561075785734`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 2, {
              Complex[9.32666040057538, -1.0466561075785734`], 
              Complex[7.617067825366967, -2.147044806353595]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0257829728215118`, 1.042415443742859}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.043412392940107, -1.0506331187508058`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 2, {
              Complex[9.326597700119693, -1.0506331187508058`], 
              Complex[7.616893231354067, -2.150609297664497]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0257964869910534`, 1.04635469380724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 1, {
              Complex[9.30898179417064, 1.04635469380724], 
              Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0433504830696076`, -1.0545762069524702`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 2, {
              Complex[9.326535790249194, -1.0545762069524702`], 
              Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0258095765899284`, 1.0502606417889433`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 1, {
              Complex[9.308994883769515, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0432893454241263`, -1.058485964360329}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 2, {
              Complex[9.326474652603713, -1.058485964360329], 
              Complex[7.616547285902738, -2.157643104664951]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025822254789377, 1.0541338637739348`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0432289622647524`, -1.0623629674380988`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 2, {
              Complex[9.326414269444339, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025834534255301, 1.0579749207033116`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 1, {
              Complex[9.309019841434887, 1.0579749207033116`], 
              Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0431693164464004`, -1.0662077774973113`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C", 2, {
              Complex[9.326354623625987, -1.0662077774973113`], 
              Complex[7.616205519626703, -2.164553676487631]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025846427171931, 1.0617843589087967`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 1, {
              Complex[9.309031734351517, 1.0617843589087967`], 
              Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.043110391391865, -1.0700209412330057`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C", 2, {
              Complex[9.326295698571451, -1.0700209412330057`], 
              Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0258579452641765`, 1.0655627106244419`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 1, {
              Complex[9.309043252443763, 1.0655627106244419`], 
              Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0430521710672878`, -1.0738029912355802`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0258690998187383`, 1.069310494475782}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 1, {
              Complex[9.309054406998325, 1.069310494475782], 
              Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0429946399588808`, -1.077554446480185}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 2, {
              Complex[9.326179947138467, -1.077554446480185], 
              Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025879901704071, 1.0730282159476647`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 1, {
              Complex[9.309065208883657, 1.0730282159476647`], 
              Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0429377830509274`, -1.0812758127946427`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 2, {
              Complex[9.326123090230514, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0258903613892745`, 1.076716367831864}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 1, {
              Complex[9.30907566856886, 1.076716367831864], 
              Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0428815858048637`, -1.0849675833073058`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C", 2, {
              Complex[9.32606689298445, -1.0849675833073058`], 
              Complex[7.61536833755189, -2.181317982768311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259004889619625`, 1.0803754306555196`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 1, {
              Complex[9.309085796141549, 1.0803754306555196`], 
              Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0428260341394946`, -1.0886302388755993`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 2, {
              Complex[9.32601134131908, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259102941451896`, 1.0840058730914168`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 1, {
              Complex[9.309095601324776, 1.0840058730914168`], 
              Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0427711144121705`, -1.0922642484964793`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 2, {
              Complex[9.325956421591757, -1.0922642484964793`], 
              Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02591978631348, 1.0876081523510002`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 1, {
              Complex[9.309105093493066, 1.0876081523510002`], 
              Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0427168134009506`, -1.0958700696995949`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 2, {
              Complex[9.325902120580537, -1.0958700696995949`], 
              Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259289745080302`, 1.0911827145610287`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 1, {
              Complex[9.309114281687616, 1.0911827145610287`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042663118287626, -1.0994481489240884`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 2, {
              Complex[9.325848425467212, -1.0994481489240884`], 
              Complex[7.614715122272777, -2.194233932689377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259378674511197`, 1.0947299951246658`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 1, {
              Complex[9.309123174630706, 1.0947299951246658`], 
              Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042610016641614, -1.1029989218798244`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C", 2, {
              Complex[9.3257953238212, -1.1029989218798244`], 
              Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259464735597756`, 1.098250419067798}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 1, {
              Complex[9.309131780739362, 1.098250419067798], 
              Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0425574964046262`, -1.1065228138938557`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 2, {
              Complex[9.325742803584212, -1.1065228138938557`], 
              Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259548009587665`, 1.1017444013712938`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042505545876022, -1.1100202402427715`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 2, {
              Complex[9.325690853055608, -1.1100202402427715`], 
              Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259628574929103`, 1.1052123472899034`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 1, {
              Complex[9.309148164672497, 1.1052123472899034`], 
              Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0424541536990564`, -1.1134916064718128`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C", 2, {
              Complex[9.325639460878643, -1.1134916064718128`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259706507387953`, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 1, {
              Complex[9.309155957918382, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0424033088475184`, -1.1169373087010908`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C", 2, {
              Complex[9.325588616027105, -1.1169373087010908`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259781880158982`, 1.112071704185835}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 1, {
              Complex[9.309163495195484, 1.112071704185835], 
              Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0423530006132165`, -1.1203577339198192`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 2, {
              Complex[9.325538307792803, -1.1203577339198192`], 
              Complex[7.613760450846203, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.025985476397169, 1.11546387973771}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0423032185939363`, -1.1237532602689644`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 2, {
              Complex[9.325488525773522, -1.1237532602689644`], 
              Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0259925227191022`, 1.118831548607897}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 1, {
              Complex[9.309177829898688, 1.118831548607897], 
              Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0422539526820067`, -1.1271242573129148`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 2, {
              Complex[9.325439259861593, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02599933359131, 1.1221750717795362`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042205193053375, -1.1304710863006695`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 2, {
              Complex[9.325390500232961, -1.1304710863006695`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260059154056407`, 1.1254948021761624`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 1, {
              Complex[9.309191222585227, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042156930157173, -1.1337941004170402`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C", 2, {
              Complex[9.32534223733676, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260122743448647`, 1.1287910849032743`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 1, {
              Complex[9.309197581524451, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04210915470577, -1.1370936450243205`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C", 2, {
              Complex[9.325294461885356, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026018416390958, 1.1320642574808066`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 1, {
              Complex[9.309203723570544, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.042061857665267, -1.1403700578948632`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 2, {
              Complex[9.325247164844853, -1.1403700578948632`], 
              Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260243473329798`, 1.1353146500669253`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 1, {
              Complex[9.309209654512566, 1.1353146500669253`], 
              Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0420150302464055`, -1.1436236694349757`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260300727745975`, 1.1385425856735312`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 1, {
              Complex[9.309215379954184, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0419686638959007`, -1.1468548029005257`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 2, {
              Complex[9.325153971075487, -1.1468548029005257`], 
              Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260355981412665`, 1.1417483803738433`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 1, {
              Complex[9.309220905320853, 1.1417483803738433`], 
              Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04192275028808, -1.1500637746045623`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026040928687074, 1.1449323435024106`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.041877281317049, -1.1532508941175512`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C", 2, {
              Complex[9.325062588496635, -1.1532508941175512`], 
              Complex[7.612229226993084, -2.242030438093204]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260460695012643`, 1.1480947778478905`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 1, {
              Complex[9.30923137668085, 1.1480947778478905`], 
              Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0418322490889516`, -1.1564164644600665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C", 2, {
              Complex[9.325017556268538, -1.1564164644600665`], 
              Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260510255144926`, 1.151235979838898}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 1, {
              Complex[9.309236332694079, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.041787645914807, -1.159560782288886}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 2, {
              Complex[9.324972953094393, -1.159560782288886], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260558015047856`, 1.154356239723236}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 1, {
              Complex[9.309241108684372, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0417434643034635`, -1.1626841380761932`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 2, {
              Complex[9.32492877148305, -1.1626841380761932`], 
              Complex[7.611783032412532, -2.250378188362658]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026060402103232, 1.1574558417407832`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0416996969549412`, -1.165786816282607}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C", 2, {
              Complex[9.324885004134527, -1.165786816282607], 
              Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260648317994256`, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 1, {
              Complex[9.309250138979012, 1.1605350642903134`], 
              Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0416563367540554`, -1.168869095524045}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 2, {
              Complex[9.324841643933642, -1.168869095524045], 
              Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260690949466884`, 1.1635941800905014`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 1, {
              Complex[9.309254402126275, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0416133767642215`, -1.1719312487328415`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 2, {
              Complex[9.324798683943808, -1.1719312487328415`], 
              Complex[7.611342435457713, -2.258551532233558]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260731957670277`, 1.1666334563353578`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 1, {
              Complex[9.309258502946614, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0415708102216588`, -1.1749735433132202`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 2, {
              Complex[9.324756117401245, -1.1749735433132202`], 
              Complex[7.611196771510045, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026077138355923, 1.1696531548443287`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 1, {
              Complex[9.30926244553551, 1.1696531548443287`], 
              Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0415286305295997`, -1.1779962412914933`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 2, {
              Complex[9.324713937709186, -1.1779962412914933`], 
              Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260809266868804`, 1.1726535322072742`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 1, {
              Complex[9.309266233866467, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04148683125306, -1.180999599461105}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C", 2, {
              Complex[9.324672138432646, -1.180999599461105], 
              Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026084564615788, 1.1756348399245429`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 1, {
              Complex[9.309269871795374, 1.1756348399245429`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.041445406113464, -1.183983869522754}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C", 2, {
              Complex[9.32463071329305, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260880558851255`, 1.178597324542335}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 1, {
              Complex[9.309273363064712, 1.178597324542335], 
              Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0414043489837503`, -1.186949298219872}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C", 2, {
              Complex[9.324589656163337, -1.186949298219872], 
              Complex[7.610619897990326, -2.271804947320259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0260914041279463`, 1.1815412277835524`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 1, {
              Complex[9.309276711307533, 1.1815412277835524`], 
              Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.041363653883522, -1.18989612746948}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C", 2, {
              Complex[9.324548961063108, -1.18989612746948], 
              Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026094612871729, 1.18446678667431}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 1, {
              Complex[9.309279920051315, 1.18446678667431], 
              Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0413233149744627`, -1.1928245944888063`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C", 2, {
              Complex[9.324508622154049, -1.1928245944888063`], 
              Complex[7.61033481839468, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026097685542064, 1.1873742336662831`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 1, {
              Complex[9.30928299272165, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0412833265558934`, -1.195734931917687}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.61019309106805, -2.2795461787176903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261006254661673`, 1.1902637967550587`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 1, {
              Complex[9.309285932645754, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0412436830605056`, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026103435876289, 1.193135699594645}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 1, {
              Complex[9.309288743055875, 1.193135699594645], 
              Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0412043790502636`, -1.201502126383065}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 2, {
              Complex[9.32438968622985, -1.201502126383065], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261061199129387`, 1.195990161608288}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 1, {
              Complex[9.309291427092525, 1.195990161608288], 
              Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0411654092124696`, -1.2043594268588769`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 2, {
              Complex[9.324350716392056, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026108680628022, 1.1988273980957402`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 1, {
              Complex[9.309293987807608, 1.1988273980957402`], 
              Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0411267683559497`, -1.2071994848410685`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 2, {
              Complex[9.324312075535536, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026111120987819, 1.201647620337122}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 1, {
              Complex[9.309296428167405, 1.201647620337122], 
              Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0410884514074272`, -1.2100225117840062`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C", 2, {
              Complex[9.324273758587013, -1.2100225117840062`], 
              Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026113443875875, 1.204451035693495}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 1, {
              Complex[9.309298751055461, 1.204451035693495], 
              Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.041050453407969, -1.2128287152203814`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C", 2, {
              Complex[9.324235760587555, -1.2128287152203814`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261156520957346`, 1.2072378477042842`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0410127695096296`, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C", 2, {
              Complex[9.324198076689216, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261177483736255`, 1.2100082561816605`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 1, {
              Complex[9.309303055553212, 1.2100082561816605`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04097539497217, -1.2183914626776438`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C", 2, {
              Complex[9.324160702151756, -1.2183914626776438`], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261197353609823`, 1.212762457302003}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 1, {
              Complex[9.309305042540569, 1.212762457302003], 
              Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0409383251599102`, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026121615636903, 1.2155006436945397`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 1, {
              Complex[9.30930692281649, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0409015555387064`, -1.2238893126698196`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C", 2, {
              Complex[9.324086862718293, -1.2238893126698196`], 
              Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261233917105077`, 1.2182230045272866`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040865081673024, -1.2266143809612582`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C", 2, {
              Complex[9.32405038885261, -1.2266143809612582`], 
              Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026125066023205, 1.2209297255903702`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 1, {
              Complex[9.309310373202791, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040828899223108, -1.2293237938391435`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 2, {
              Complex[9.324014206402694, -1.2293237938391435`], 
              Complex[7.608531912472354, -2.309057802254565]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026126640950862, 1.2236209893768368`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040793003942275, -1.232017733951227}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 2, {
              Complex[9.323978311121861, -1.232017733951227], 
              Complex[7.608396583634034, -2.311418828492422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261281188059037`, 1.2262969751610369`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 1, {
              Complex[9.30931342598549, 1.2262969751610369`], 
              Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040757391674285, -1.2346963807243225`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261295018393355`, 1.2289578590746733`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 1, {
              Complex[9.309314809018922, 1.2289578590746733`], 
              Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040722058350797, -1.2373599104403945`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C", 2, {
              Complex[9.323907365530383, -1.2373599104403945`], 
              Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261307922426894`, 1.2316038141805976`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 1, {
              Complex[9.309316099422276, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0406869999889654`, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C", 2, {
              Complex[9.323872307168552, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026131992149871, 1.2342350105444317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 1, {
              Complex[9.309317299329457, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0406522126889985`, -1.242642308546154}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 2, {
              Complex[9.323837519868585, -1.242642308546154], 
              Complex[7.607859712684855, -2.320721705723063]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261331036389834`, 1.2368516153040952`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 1, {
              Complex[9.30931841081857, 1.2368516153040952`], 
              Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0406176926319564`, -1.2452615144292978`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 2, {
              Complex[9.323802999811543, -1.2452615144292978`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026134128734059, 1.2394537927373108`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 1, {
              Complex[9.309319435913645, 1.2394537927373108`], 
              Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0405834360775135`, -1.2478662783795624`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 2, {
              Complex[9.3237687432571, -1.2478662783795624`], 
              Complex[7.607593869964685, -2.32529066727406]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026135069406715, 1.2420417043271583`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 1, {
              Complex[9.309320376586301, 1.2420417043271583`], 
              Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0405494393618255`, -1.2504567620199438`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C", 2, {
              Complex[9.323734746541412, -1.2504567620199438`], 
              Complex[7.607461579018771, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026135927577787, 1.2446155088257416`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 1, {
              Complex[9.309321234757373, 1.2446155088257416`], 
              Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0405156988954793`, -1.253033124240515}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C", 2, {
              Complex[9.323701006075066, -1.253033124240515], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026136705118864, 1.247175362316046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 1, {
              Complex[9.30932201229845, 1.247175362316046], 
              Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040482211161507, -1.255595521260306}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C", 2, {
              Complex[9.323667518341093, -1.255595521260306], 
              Complex[7.607198233627162, -2.332044490630609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026137403853788, 1.2497214182720298`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 1, {
              Complex[9.309322711033374, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040448972713456, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261380255601154`, 1.2522538276170265`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 1, {
              Complex[9.309323332739702, 1.2522538276170265`], 
              Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0404159801735258`, -1.2606790315775551`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 2, {
              Complex[9.323601287353112, -1.2606790315775551`], 
              Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026138571970465, 1.254772738780499}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 1, {
              Complex[9.309323879150051, 1.254772738780499], 
              Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040383230230775, -1.2632004444906193`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261390447739327`, 1.2572782977532362`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 1, {
              Complex[9.309324351953519, 1.2572782977532362`], 
              Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0403507196393793`, -1.2657084915461236`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 2, {
              Complex[9.323536026818966, -1.2657084915461236`], 
              Complex[7.606676358179671, -2.340869773551443]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026139445617316, 1.2597706481409692`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 1, {
              Complex[9.309324752796902, 1.2597706481409692`], 
              Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040318445216945, -1.2682033164767677`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 2, {
              Complex[9.323503752396531, -1.2682033164767677`], 
              Complex[7.60654686627181, -2.343044919018725]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026139776106371, 1.26224993121657}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 1, {
              Complex[9.309325083285957, 1.26224993121657], 
              Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0402864038428614`, -1.2706850606806674`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 2, {
              Complex[9.323471711022448, -1.2706850606806674`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261400378071173`, 1.2647162859707826`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 1, {
              Complex[9.309325344986703, 1.2647162859707826`], 
              Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040254592456762, -1.273153863272108}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 2, {
              Complex[9.323439899636348, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026140232246874, 1.2671698491615646`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 1, {
              Complex[9.30932553942646, 1.2671698491615646`], 
              Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040223008056957, -1.2756098611309419`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C", 2, {
              Complex[9.323408315236543, -1.2756098611309419`], 
              Complex[7.60616066644672, -2.349497677693727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026140360915452, 1.2696107553621176`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 1, {
              Complex[9.309325668095038, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0401916476989452`, -1.2780531889506412`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.02614042526624, 1.2720391370076072`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 1, {
              Complex[9.309325732445826, 1.2720391370076072`], 
              Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040160508494033, -1.2804839792850278`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C", 2, {
              Complex[9.323345815673619, -1.2804839792850278`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261404267172374`, 1.2744551244406346`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0401295876078844`, -1.282902362593793}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026140366652088, 1.2768588459554961`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.04009888225921, -1.2853084672867803`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C", 2, {
              Complex[9.323284189438796, -1.2853084672867803`], 
              Complex[7.605650891587858, -2.357936536444798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261402464210434`, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.040068389718435, -1.2877024197670908`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C", 2, {
              Complex[9.323253696898021, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026140067341924, 1.2816299944237615`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 1, {
              Complex[9.30932537452151, 1.2816299944237615`], 
              Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0400381073064544`, -1.2900843444730699`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 2, {
              Complex[9.32322341448604, -1.2900843444730699`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261398307010356`, 1.2839976681063674`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0400080323933967`, -1.292454363919178}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 2, {
              Complex[9.323193339572983, -1.292454363919178], 
              Complex[7.605272293102371, -2.364146338317678]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261395377540428`, 1.286353569409846}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 1, {
              Complex[9.309324844933629, 1.286353569409846], 
              Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0399781623974302`, -1.2948125987358026`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 2, {
              Complex[9.323163469577016, -1.2948125987358026`], 
              Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261391897268286`, 1.2886978170110814`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039948494783605, -1.2971591677080403`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 2, {
              Complex[9.323133801963191, -1.2971591677080403`], 
              Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261387878163557`, 1.291030527780833}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 1, {
              Complex[9.309324094995942, 1.291030527780833], 
              Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039919027062737, -1.2994941878134678`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C", 2, {
              Complex[9.323104334242323, -1.2994941878134678`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261383331914136`, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 1, {
              Complex[9.309323640371, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039889756790334, -1.3018177742589656`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C", 2, {
              Complex[9.32307506396992, -1.3018177742589656`], 
              Complex[7.604772284075739, -2.372272881425941]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261378269934553`, 1.2956617974980962`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 1, {
              Complex[9.309323134173042, 1.2956617974980962`], 
              Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0398606815655, -1.3041300405165683`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C", 2, {
              Complex[9.323045988745086, -1.3041300405165683`], 
              Complex[7.604648113785146, -2.374277896400649]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261372703372817`, 1.2979605814829327`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 1, {
              Complex[9.309322577516868, 1.2979605814829327`], 
              Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0398317990299564`, -1.3064310983584502`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 2, {
              Complex[9.323017106209543, -1.3064310983584502`], 
              Complex[7.604524269574324, -2.376272476082065]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026136664311837, 1.300248278779899}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 1, {
              Complex[9.309321971491423, 1.300248278779899], 
              Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0398031068670086`, -1.3087210578909694`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 2, {
              Complex[9.322988414046595, -1.3087210578909694`], 
              Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261360099808634`, 1.3025249977626072`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 1, {
              Complex[9.30932131716045, 1.3025249977626072`], 
              Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0397746028006107`, -1.3110000275879254`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C", 2, {
              Complex[9.322959909980197, -1.3110000275879254`], 
              Complex[7.604277546409373, -2.380230742900865]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261353083836013`, 1.3047908452057129`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 1, {
              Complex[9.309320615563188, 1.3047908452057129`], 
              Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0397462845944094`, -1.3132681143229277`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C", 2, {
              Complex[9.322931591773996, -1.3132681143229277`], 
              Complex[7.604154661093239, -2.382194632873833]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026134560535457, 1.3070459263165168`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 1, {
              Complex[9.309319867715043, 1.3070459263165168`], 
              Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0397181500508346`, -1.315525423400987}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 2, {
              Complex[9.32290345723042, -1.315525423400987], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261337674286217`, 1.3092903447657454`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 1, {
              Complex[9.309319074608208, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0396901970102075`, -1.3177720585893213`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 2, {
              Complex[9.322875504189794, -1.3177720585893213`], 
              Complex[7.60390982746478, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026132930032709, 1.311524202717574}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 1, {
              Complex[9.309318237212295, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039662423349906, -1.3200081221474065`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 2, {
              Complex[9.322847730529492, -1.3200081221474065`], 
              Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026132049295347, 1.3137476008589228`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 1, {
              Complex[9.309317356474933, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0396348269834785`, -1.322233714856279}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C", 2, {
              Complex[9.322820134163065, -1.322233714856279], 
              Complex[7.603666223034595, -2.389950867251501]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261311261427615`, 1.3159606384280351`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 1, {
              Complex[9.309316433322348, 1.3159606384280351`], 
              Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039607405859904, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.391865572493939]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026130161480337, 1.3181634132423605`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 1, {
              Complex[9.309315468659923, 1.3181634132423605`], 
              Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0395801579627157`, -1.326653883629291}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026129156193173, 1.3203560217257788`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 1, {
              Complex[9.30931446337276, 1.3203560217257788`], 
              Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0395530813093004`, -1.3288486541172835`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 2, {
              Complex[9.322738388488887, -1.3288486541172835`], 
              Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261281111465834`, 1.3225385589351384`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 1, {
              Complex[9.30931341832617, 1.3225385589351384`], 
              Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0395261739501276`, -1.331033342657582}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 2, {
              Complex[9.322711481129714, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261270271866607`, 1.3247111185862175`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.04531544750647416]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0394994339680075`, -1.3332080430544797`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C", 2, {
              Complex[9.322684741147594, -1.3332080430544797`], 
              Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.026125905140738, 1.3268737930790047`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 1, {
              Complex[9.309311212320324, 1.3268737930790047`], 
              Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.039472859477417, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C", 2, {
              Complex[9.322658166657003, -1.3353728477954119`], 
              Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{3.0261247458178673`, 1.3290266735224268`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 1, {
              Complex[9.309310052997454, 1.3290266735224268`], 
              Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{3.0394464486237567`, -1.3375278480756927`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C", 2, {
              Complex[9.322631755803343, -1.3375278480756927`], 
              Complex[7.602822954346447, -2.40315628519697]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->900,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Demonstrating the Stokes transitions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FindStokesTransitions"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"FindStokesTransitions[S,\[LeftAssociation]\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(1\)]\)\[RightArrow]\[LeftAssociation]1\[RightArrow]{\!\(\
\*SubscriptBox[\(t\), \(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(11\)]\)},2\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\
\), \(12\)]\)}\[RightAssociation],\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\
\)]\)\[RightArrow]\[LeftAssociation]1\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(21\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(21\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(22\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(22\)]\)}\[RightAssociation],\
\[Ellipsis]\[RightAssociation]] finds the set {{\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(S\)]\)},{\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(AS\)]\
\)},n} of the Stokes and anti-Stokes transition energies for the given set of \
saddle points, where Re(S) changes sign after the \!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(S\)]\) and Im(S) changes sign after the \
\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(AS\)]\), and n is the index of the \
member of the pair that should be chosen after the transition (taken as the \
member with a positive imaginary part of the action at the largest \
\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(i\)]\) in the given \
keys).\\n\\nFindStokesTransitions[S,\[LeftAssociation]\!\(\*SubscriptBox[\(\
label\), \(1\)]\)\[RightArrow]\[LeftAssociation]\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(1\)]\)\[RightArrow]\[Ellipsis]\[RightAssociation]\
\[RightAssociation]] finds the Stokes transitions for the given set of \
saddle-point curve pairs, and returns them labeled with the \
\!\(\*SubscriptBox[\(label\), \(i\)]\).\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info143674213750-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "transitions", ",", "secondClassifierFunction", ",", 
     "zoomPlot"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"keyColour", "=", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\"\<A\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Black"}], ",", 
            RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<B\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Red"}], ",", 
            RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<C\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<D\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}],
         "\[RightAssociation]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"secondClassifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{"\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<A\>\"", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<A1\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<A\>\"", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<A\>\"", ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<A2\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<A\>\"", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]"}]}], "]"}], ",", "\"\<A3\>\"", 
         ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{"\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<B\>\"", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<B1\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<B\>\"", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<B\>\"", ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<B2\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<B\>\"", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]"}]}], "]"}], ",", "\"\<B3\>\"", 
         ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{"\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<C\>\"", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<C1\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<C\>\"", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<C\>\"", ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<C2\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<C\>\"", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]"}]}], "]"}], ",", "\"\<C3\>\"", 
         ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{"\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<D\>\"", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<D1\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<D\>\"", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]", "<", 
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<D\>\"", ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}], ",", "\"\<D2\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"transitions", "\[LeftDoubleBracket]", 
             RowBox[{"\"\<D\>\"", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[LessEqual]", "\[CapitalOmega]"}]}], "]"}], ",", "\"\<D3\>\"", 
         ",", "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\"\<A1\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       
       RowBox[{"\"\<A2\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Blue"}], ",", 
          RowBox[{"2", "\[Rule]", "Black"}]}], "\[RightAssociation]"}]}], ",", 
       RowBox[{"\"\<A3\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<B1\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<B2\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Magenta"}], ",", 
          RowBox[{"2", "\[Rule]", "Red"}]}], "\[RightAssociation]"}]}], ",", 
       RowBox[{"\"\<B3\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"\"\<C1\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<C2\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Orange"}], ",", 
          RowBox[{"2", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}]}], 
         "\[RightAssociation]"}]}], ",", 
       RowBox[{"\"\<C3\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"\"\<D1\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<D2\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Purple"}], ",", 
          RowBox[{"2", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}]}], 
         "\[RightAssociation]"}]}], ",", 
       RowBox[{"\"\<D3\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}], 
      "\[IndentingNewLine]", "\[RightAssociation]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "secondClassifierFunction", ",", "sortingFunction",
        ",", 
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"transitions", ",", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Function", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"n", ",", "t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", "n"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", "t"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", "n", ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "}"}]}], "]"}]}], "}"}]}], 
                   "\[IndentingNewLine]", "]"}], "@*", 
                  RowBox[{"Apply", "[", "Sequence", "]"}], "@*", "Flatten", "@*",
                   "List"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"selection", "[", 
                  RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "]"}], 
               "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[CapitalOmega]", ",", 
                RowBox[{"Keys", "[", 
                 RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"index", ",", 
              RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "900"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"zoomPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"keyColour", "[", 
                    RowBox[{"index", ",", "2"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{"PointSize", "[", "0.005", "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Subtract", "@@", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"t", "-", "\[Tau]"}]}], "]"}], "-", 
                    RowBox[{"\[CapitalOmega]", " ", "t"}]}]}], 
                    "\[IndentingNewLine]", "]"}], "@@", "#"}], "&"}], ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], 
                    "]"}]}], "\[IndentingNewLine]", "+", 
                    RowBox[{
                    RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"0.05", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], 
                    FractionBox[
                    RowBox[{"3", "\[Pi]"}], "4"], 
                    RowBox[{"Sign", "[", 
                    RowBox[{"Im", "[", "t", "]"}], "]"}]}]], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"\[Tau]", "-", "t"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}], "@@", 
                    RowBox[{"First", "[", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], 
                    "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\[CapitalOmega]", ",", 
                   RowBox[{"Keys", "[", 
                    RowBox[{"selection", "[", "index", "]"}], "]"}]}], 
                  "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"index", ",", 
                 RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
             "\[IndentingNewLine]", "]"}], ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{"Thin", ",", 
               RowBox[{"GrayLevel", "[", "0.2", "]"}], ",", 
               RowBox[{"Line", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "5"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "10"}], "}"}]}], "}"}], "]"}]}], "}"}], 
             "]"}]}], "}"}], "\[IndentingNewLine]", ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], "\[IndentingNewLine]", ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "900", "}"}], ",", 
             RowBox[{"{", "900", "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Re(\!\(\*SubscriptBox[\(S\), \(1\)]\)-\[CapitalOmega] \
\!\(\*SubscriptBox[\(t\), \(1\)]\))-Re(\!\(\*SubscriptBox[\(S\), \(2\)]\)-\
\[CapitalOmega] \!\(\*SubscriptBox[\(t\), \(2\)]\))\>\"", ",", 
             "\"\<Im(\!\(\*SubscriptBox[\(S\), \(1\)]\)-\[CapitalOmega] \
\!\(\*SubscriptBox[\(t\), \(1\)]\))-Im(\!\(\*SubscriptBox[\(S\), \(2\)]\)-\
\[CapitalOmega] \!\(\*SubscriptBox[\(t\), \(2\)]\))\>\""}], "}"}]}]}], 
         "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"zoomPlot", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", "0.005", "]"}], "\[Rule]", 
            RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
            RowBox[{"2", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
         RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\<\"A\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.767`", ",", "1.8354`", ",", "2"}], "}"}]}], ",", 
       RowBox[{"\<\"B\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.767`", ",", "1.8354`", ",", "2"}], "}"}]}], ",", 
       RowBox[{"\<\"D\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.1628`", ",", "1.1742`", ",", "1"}], "}"}]}], ",", 
       RowBox[{"\<\"C\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.1628`", ",", "1.1742`", ",", "1"}], "}"}]}]}], 
      "\[RightAssociation]"}]},
    {
     GraphicsBox[{{{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.6980000948375882, -0.6433017314670934}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A1", 1, {
              Complex[0.6980000948375882, -0.6433017314670934], 
              Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6944263543752545`, 0.006645071137818129}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A1", 2, {
              Complex[4.6944263543752545`, 0.006645071137818129], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7333882582665036, -0.6165221792948049}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A1", 1, {
              Complex[0.7333882582665036, -0.6165221792948049], 
              Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.654309125631486, 0.006712510785854934}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A1", 2, {
              Complex[4.654309125631486, 0.006712510785854934], 
              Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7629774456127986, -0.5952855745698065}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A1", 1, {
              Complex[0.7629774456127986, -0.5952855745698065], 
              Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.621891868208896, 0.006786025025047798}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A1", 2, {
              Complex[4.621891868208896, 0.006786025025047798], 
              Complex[6.122517060306257, -1.163371113059422]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7891581377234371, -0.5773156862277916}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A1", 1, {
              Complex[0.7891581377234371, -0.5773156862277916], 
              Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.593955318850742, 0.0068633365731448895`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A1", 2, {
              Complex[4.593955318850742, 0.0068633365731448895`], 
              Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.813020240902394, -0.5615718710865851}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A1", 1, {
              Complex[0.813020240902394, -0.5615718710865851], 
              Complex[1.908828689419144, -2.052868131119601]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.569036631840206, 0.006943461497604872}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A1", 2, {
              Complex[4.569036631840206, 0.006943461497604872], 
              Complex[6.068475300453683, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.835170145892391, -0.5474736791133877}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A1", 1, {
              Complex[0.835170145892391, -0.5474736791133877], 
              Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5463246331431195`, 0.007025882918871681}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A1", 2, {
              Complex[4.5463246331431195`, 0.007025882918871681], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8559867126628703, -0.5346576120369388}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A1", 1, {
              Complex[0.8559867126628703, -0.5346576120369388], 
              Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5253142371097725`, 0.007110298008162873}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A1", 2, {
              Complex[4.5253142371097725`, 0.007110298008162873], 
              Complex[6.023558855884933, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8757255721593927, -0.52287788641464}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A1", 1, {
              Complex[0.8757255721593927, -0.52287788641464], 
              Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5056658326490995`, 0.007196517077880139}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A1", 2, {
              Complex[4.5056658326490995`, 0.007196517077880139], 
              Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8945689747906652, -0.5119589442981493}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A1", 1, {
              Complex[0.8945689747906652, -0.5119589442981493], 
              Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.487138168550514, 0.007284416332243672}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A1", 2, {
              Complex[4.487138168550514, 0.007284416332243672], 
              Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9126523619522108, -0.5017701062164057}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A1", 1, {
              Complex[0.9126523619522108, -0.5017701062164057], 
              Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.469552623884141, 0.007373913179256361}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A1", 2, {
              Complex[4.469552623884141, 0.007373913179256361], 
              Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9300797102089358, -0.4922109148816913}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A1", 1, {
              Complex[0.9300797102089358, -0.4922109148816913], 
              Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.452772601155936, 0.007464952252033912}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A1", 2, {
              Complex[4.452772601155936, 0.007464952252033912], 
              Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9469329539089921, -0.48320212310888055`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A1", 1, {
              Complex[0.9469329539089921, -0.48320212310888055`], 
              Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.436690887655669, 0.007557496991163237}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A1", 2, {
              Complex[4.436690887655669, 0.007557496991163237], 
              Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9632780610078037, -0.47467987499817715`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A1", 1, {
              Complex[0.9632780610078037, -0.47467987499817715`], 
              Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.421221515937318, 0.0076515243225991425`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A1", 2, {
              Complex[4.421221515937318, 0.0076515243225991425`], 
              Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9791691098460469, -0.46659179640833603`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A1", 1, {
              Complex[0.9791691098460469, -0.46659179640833603`], 
              Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.406294309063904, 0.007747021157202576}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A1", 2, {
              Complex[4.406294309063904, 0.007747021157202576], 
              Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9946511165926878, -0.45889427989730874`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A1", 1, {
              Complex[0.9946511165926878, -0.45889427989730874`], 
              Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.391851102143664, 0.007843982012263403}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A1", 2, {
              Complex[4.391851102143664, 0.007843982012263403], 
              Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.009762051806893, -0.45155054573492875`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A1", 1, {
              Complex[1.009762051806893, -0.45155054573492875`], 
              Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377843050837108, 0.007942407351021055}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A1", 2, {
              Complex[4.377843050837108, 0.007942407351021055], 
              Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.024534313536096, -0.4445292235923795}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A1", 1, {
              Complex[1.024534313536096, -0.4445292235923795], 
              Complex[2.119679474265541, -1.918057531021162]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3642286676832285`, 0.00804230239670521}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A1", 2, {
              Complex[4.3642286676832285`, 0.00804230239670521], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0389958259885552`, -0.43780329333443724`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A1", 1, {
              Complex[1.0389958259885552`, -0.43780329333443724`], 
              Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.350972359395372, 0.008143676269233574}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A1", 2, {
              Complex[4.350972359395372, 0.008143676269233574], 
              Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0531708739791161`, -0.43134927949335167`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A1", 1, {
              Complex[1.0531708739791161`, -0.43134927949335167`], 
              Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.338043317353644, 0.008246541346654037}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A1", 2, {
              Complex[4.338043317353644, 0.008246541346654037], 
              Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0670807469468007`, -0.42514662876555165`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A1", 1, {
              Complex[1.0670807469468007`, -0.42514662876555165`], 
              Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.325414662407916, 0.008350912786611275}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A1", 2, {
              Complex[4.325414662407916, 0.008350912786611275], 
              Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0807442431495686`, -0.4191772220375579}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A1", 1, {
              Complex[1.0807442431495686`, -0.4191772220375579], 
              Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3130627762344576`, 0.00845680816400054}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A1", 2, {
              Complex[4.3130627762344576`, 0.00845680816400054], 
              Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0941780694739518`, -0.41342498695323976`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A1", 1, {
              Complex[1.0941780694739518`, -0.41342498695323976`], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.300966771833883, 0.008564247194411541}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A1", 2, {
              Complex[4.300966771833883, 0.008564247194411541], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.107397162145414, -0.4078755867501416}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A1", 1, {
              Complex[1.107397162145414, -0.4078755867501416], 
              Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.289108069365748, 0.008673251522090971}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A1", 2, {
              Complex[4.289108069365748, 0.008673251522090971], 
              Complex[5.777450742552286, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1204149466885311`, -0.40251616773611126`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A1", 1, {
              Complex[1.1204149466885311`, -0.40251616773611126`], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.277470052807503, 0.008783844556995735}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A1", 2, {
              Complex[4.277470052807503, 0.008783844556995735], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1332435506568057`, -0.39733515240586337`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A1", 1, {
              Complex[1.1332435506568057`, -0.39733515240586337`], 
              Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.266037789390484, 0.008896051349858974}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A1", 2, {
              Complex[4.266037789390484, 0.008896051349858974], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1458939792326737`, -0.3923220684765709}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A1", 1, {
              Complex[1.1458939792326737`, -0.3923220684765709], 
              Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.254797798340199, 0.009009898497034034}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A1", 2, {
              Complex[4.254797798340199, 0.009009898497034034], 
              Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1583762613396105`, -0.38746740648134814`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A1", 1, {
              Complex[1.1583762613396105`, -0.38746740648134814`], 
              Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.243737858735289, 0.009125414068990397}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A1", 2, {
              Complex[4.243737858735289, 0.009125414068990397], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1706995721155862`, -0.382762500281366}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A1", 1, {
              Complex[1.1706995721155862`, -0.382762500281366], 
              Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.232846848694921, 0.009242627557842213}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A1", 2, {
              Complex[4.232846848694921, 0.009242627557842213], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1828723362728408`, -0.378199426130277}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A1", 1, {
              Complex[1.1828723362728408`, -0.378199426130277], 
              Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.222114609872632, 0.009361569840391626}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A1", 2, {
              Complex[4.222114609872632, 0.009361569840391626], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1949023158791763`, -0.3737709168766501}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A1", 1, {
              Complex[1.1949023158791763`, -0.3737709168766501], 
              Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.211531832555506, 0.009482273153986658}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A1", 2, {
              Complex[4.211531832555506, 0.009482273153986658], 
              Complex[5.695312895009785, -1.162653682569165]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2067966853478913`, -0.369470288610321}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A1", 1, {
              Complex[1.2067966853478913`, -0.369470288610321], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.201089957665183, 0.009604771083122505}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A1", 2, {
              Complex[4.201089957665183, 0.009604771083122505], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2185620958524552`, -0.36529137760862845`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A1", 1, {
              Complex[1.2185620958524552`, -0.36529137760862845`], 
              Complex[2.317691837968342, -1.816262829010749]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.190781092718281, 0.009729098555121772}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A1", 2, {
              Complex[4.190781092718281, 0.009729098555121772], 
              Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2302047309418311`, -0.3612284858628565}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A1", 1, {
              Complex[1.2302047309418311`, -0.3612284858628565], 
              Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.180597939390085, 0.00985529184370446}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A1", 2, {
              Complex[4.180597939390085, 0.00985529184370446], 
              Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2417303547902065`, -0.3572763337954378}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A1", 1, {
              Complex[1.2417303547902065`, -0.3572763337954378], 
              Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.170533730780807, 0.009983388579384763}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A1", 2, {
              Complex[4.170533730780807, 0.009983388579384763], 
              Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.253144354246581, -0.35343001903737564`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A1", 1, {
              Complex[1.253144354246581, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.16058217684066, 0.010113427765967319`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A1", 2, {
              Complex[4.16058217684066, 0.010113427765967319`], 
              Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2644517756377363`, -0.34968498034029766`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A1", 1, {
              Complex[1.2644517756377363`, -0.34968498034029766`], 
              Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1507374166916415`, 0.010245449802525813`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A1", 2, {
              Complex[4.1507374166916415`, 0.010245449802525813`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.275657357109484, -0.34603696586050564`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A1", 1, {
              Complex[1.275657357109484, -0.34603696586050564`], 
              Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140993976808082, 0.01037949651040012}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A1", 2, {
              Complex[4.140993976808082, 0.01037949651040012], 
              Complex[5.620051946974447, -1.162340058391703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.286765557155954, -0.34248200518323674`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A1", 1, {
              Complex[1.286765557155954, -0.34248200518323674`], 
              Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.131346734197311, 0.010515611164854463`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A1", 2, {
              Complex[4.131346734197311, 0.010515611164854463`], 
              Complex[5.609715869645587, -1.162290029994955]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.297780579877745, -0.33901638456087957`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A1", 1, {
              Complex[1.297780579877745, -0.33901638456087957`], 
              Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.121790883866403, 0.010653838531129443`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A1", 2, {
              Complex[4.121790883866403, 0.010653838531129443`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3087063974214082`, -0.33563662492447366`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A1", 1, {
              Complex[1.3087063974214082`, -0.33563662492447366`], 
              Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11232190997813, 0.010794224904694102`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A1", 2, {
              Complex[4.11232190997813, 0.010794224904694102`], 
              Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.319546769980594, -0.3323394622978922}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A1", 1, {
              Complex[1.319546769980594, -0.3323394622978922], 
              Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102935560194785, 0.010936818155564383`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A1", 2, {
              Complex[4.102935560194785, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3303052636801032`, -0.3291218303014382}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A1", 1, {
              Complex[1.3303052636801032`, -0.3291218303014382], 
              Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093627822786881, 0.011081667776607964`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A1", 2, {
              Complex[4.093627822786881, 0.011081667776607964`], 
              Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3409852666152733`, -0.32598084447903347`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A1", 1, {
              Complex[1.3409852666152733`, -0.32598084447903347`], 
              Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.084394906148223, 0.011228824935798519`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A1", 2, {
              Complex[4.084394906148223, 0.011228824935798519`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.351590003278767, -0.32291378822242217`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A1", 1, {
              Complex[1.351590003278767, -0.32291378822242217`], 
              Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.075233220412342, 0.01137834253242333}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A1", 2, {
              Complex[4.075233220412342, 0.01137834253242333], 
              Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.362122547573207, -0.319918100098616}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A1", 1, {
              Complex[1.362122547573207, -0.319918100098616], 
              Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.066139360909642, 0.01153027525727997}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A1", 2, {
              Complex[4.066139360909642, 0.01153027525727997], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3725858345799593`, -0.31699136241415216`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A1", 1, {
              Complex[1.3725858345799593`, -0.31699136241415216`], 
              Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.057110093241812, 0.011684679656931263`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A1", 2, {
              Complex[4.057110093241812, 0.011684679656931263`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.382982671230815, -0.31413129087274266`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A1", 1, {
              Complex[1.382982671230815, -0.31413129087274266`], 
              Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.04814233978115, 0.011841614202115778`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A1", 2, {
              Complex[4.04814233978115, 0.011841614202115778`], 
              Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3933157460094145`, -0.3113357252023996}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A1", 1, {
              Complex[1.3933157460094145`, -0.3113357252023996], 
              Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.039233167428713, 0.012001139360437396`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A1", 2, {
              Complex[4.039233167428713, 0.012001139360437396`], 
              Complex[5.510503169822832, -1.161705165156914]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4035876377924137`, -0.3086026206444544}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A1", 1, {
              Complex[1.4035876377924137`, -0.3086026206444544], 
              Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.030379776487371, 0.012163317673485264`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A1", 2, {
              Complex[4.030379776487371, 0.012163317673485264`], 
              Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4138008239261344`, -0.3059300402110024}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A1", 1, {
              Complex[1.4138008239261344`, -0.3059300402110024], 
              Complex[2.522758307852828, -1.730511398029892]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.021579490524692, 0.012328213838552492`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A1", 2, {
              Complex[4.021579490524692, 0.012328213838552492`], 
              Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4239576876222573`, -0.3033161476291157}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A1", 1, {
              Complex[1.4239576876222573`, -0.3033161476291157], 
              Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.012829747116558, 0.012495894795164358`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A1", 2, {
              Complex[4.012829747116558, 0.012495894795164358`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.434060524745711, -0.30075920090048514`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A1", 1, {
              Complex[1.434060524745711, -0.30075920090048514`], 
              Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.004128089376173, 0.012666429816627254`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A1", 2, {
              Complex[4.004128089376173, 0.012666429816627254`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4441115500589816`, -0.29825754641387064`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A1", 1, {
              Complex[1.4441115500589816`, -0.29825754641387064`], 
              Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.995472158184808, 0.012839890606854708`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A1", 2, {
              Complex[3.995472158184808, 0.012839890606854708`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.454112902979397, -0.29580961355530405`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A1", 1, {
              Complex[1.454112902979397, -0.29580961355530405`], 
              Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.986859685050743, 0.013016351402742245`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A1", 2, {
              Complex[3.986859685050743, 0.013016351402742245`], 
              Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4640666528993398`, -0.29341390976756415`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A1", 1, {
              Complex[1.4640666528993398`, -0.29341390976756415`], 
              Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9782884855315257`, 0.013195889082391367`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A1", 2, {
              Complex[3.9782884855315257`, 0.013195889082391367`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4739748041135785`, -0.29106901601605945`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A1", 1, {
              Complex[1.4739748041135785`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.70709401390507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9697564531622382`, 0.01337858327951261}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A1", 2, {
              Complex[3.9697564531622382`, 0.01337858327951261], 
              Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.483839300392978, -0.2887735826232169}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A1", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.961261553838926, 0.013564516504362838`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A1", 2, {
              Complex[3.961261553838926, 0.013564516504362838`], 
              Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4936620292395204`, -0.28652632543776696`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A1", 1, {
              Complex[1.4936620292395204`, -0.28652632543776696`], 
              Complex[2.608435730175939, -1.699727637683005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.952801820612012, 0.013753774271608805`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A1", 2, {
              Complex[3.952801820612012, 0.013753774271608805`], 
              Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.503444825853813, -0.28432602230905957`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A1", 1, {
              Complex[1.503444825853813, -0.28432602230905957`], 
              Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9443753488495013`, 0.01394644523553293}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A1", 2, {
              Complex[3.9443753488495013`, 0.01394644523553293], 
              Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.513189476842979, -0.2821715098398555}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A1", 1, {
              Complex[1.513189476842979, -0.2821715098398555], 
              Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9359802917339604`, 0.01414262133304412}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A1", 2, {
              Complex[3.9359802917339604`, 0.01414262133304412], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5228977236939458`, -0.280061680393945}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A1", 1, {
              Complex[1.5228977236939458`, -0.280061680393945], 
              Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.927614856061183, 0.014342397934981635`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A1", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5325712660346489`, -0.2779954793374565}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A1", 1, {
              Complex[1.5325712660346489`, -0.2779954793374565], 
              Complex[2.650557449990277, -1.685592253447088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9192772983115907`, 0.014545874006250778`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A1", 2, {
              Complex[3.9192772983115907`, 0.014545874006250778`], 
              Complex[5.379881023870964, -1.160554068514124]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5422117647034572`, -0.2759719024950626}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A1", 1, {
              Complex[1.5422117647034572`, -0.2759719024950626], 
              Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.910965920968408, 0.014753152275367222`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A1", 2, {
              Complex[3.910965920968408, 0.014753152275367222`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5518208446451707`, -0.27398999380419353`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A1", 1, {
              Complex[1.5518208446451707`, -0.27398999380419353`], 
              Complex[2.671487342062719, -1.678805872976879]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9026790690591686`, 0.014964339414034983`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A1", 2, {
              Complex[3.9026790690591686`, 0.014964339414034983`], 
              Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5614000976502447`, -0.27204884315225314`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A1", 1, {
              Complex[1.5614000976502447`, -0.27204884315225314`], 
              Complex[2.68192509329917, -1.675479597139089]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.894415126899331, 0.015179546227436329`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A1", 2, {
              Complex[3.894415126899331, 0.015179546227436329`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5709510849523987`, -0.27014758438335246`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A1", 1, {
              Complex[1.5709510849523987`, -0.27014758438335246`], 
              Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8861725150187785`, 0.015398887855965335`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A1", 2, {
              Complex[3.8861725150187785`, 0.015398887855965335`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5804753396984255`, -0.26828539346253044`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A1", 1, {
              Complex[1.5804753396984255`, -0.26828539346253044`], 
              Complex[2.702753826320577, -1.668956496466899]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8779496872537016`, 0.015622483989198204`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A1", 2, {
              Complex[3.8779496872537016`, 0.015622483989198204`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5899743693028523`, -0.26646148678673565`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A1", 1, {
              Complex[1.5899743693028523`, -0.26646148678673565`], 
              Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8697451279879247`, 0.015850459092959818`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A1", 2, {
              Complex[3.8697451279879247`, 0.015850459092959818`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5994496576990789`, -0.26467511963294016`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A1", 1, {
              Complex[1.5994496576990789`, -0.26467511963294016`], 
              Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.861557349529051, 0.01608294265041592}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A1", 2, {
              Complex[3.861557349529051, 0.01608294265041592], 
              Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6089026674977167`, -0.2629255847348713}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A1", 1, {
              Complex[1.6089026674977167`, -0.2629255847348713], 
              Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8533848896060525`, 0.0163200694182023}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A1", 2, {
              Complex[3.8533848896060525`, 0.0163200694182023], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6183348420620054`, -0.2612122109807513}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A1", 1, {
              Complex[1.6183348420620054`, -0.2612122109807513], 
              Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8452263089759486`, 0.01656197969868379}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A1", 2, {
              Complex[3.8452263089759486`, 0.01656197969868379], 
              Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6277476075095596`, -0.2595343622253301}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A1", 1, {
              Complex[1.6277476075095596`, -0.2595343622253301], 
              Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.837080189128189, 0.016808819629533064`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A1", 2, {
              Complex[3.837080189128189, 0.016808819629533064`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.637142374648998, -0.2578914362102892}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A1", 1, {
              Complex[1.637142374648998, -0.2578914362102892], 
              Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8289451300761326`, 0.017060741491919426`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A1", 2, {
              Complex[3.8289451300761326`, 0.017060741491919426`], 
              Complex[5.280454632721417, -1.159256290802515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6465205408595256`, -0.2562828635878306}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A1", 1, {
              Complex[1.6465205408595256`, -0.2562828635878306], 
              Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.820819748225798, 0.01731790403871422}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A1", 2, {
              Complex[3.820819748225798, 0.01731790403871422], 
              Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6558834919210377`, -0.25470810704296915`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A1", 1, {
              Complex[1.6558834919210377`, -0.25470810704296915`], 
              Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.812702674312651, 0.0175804728442376}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A1", 2, {
              Complex[3.812702674312651, 0.0175804728442376], 
              Complex[5.262480372776144, -1.158970392486303]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6652326038019236`, -0.2531666605106765}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A1", 1, {
              Complex[1.6652326038019236`, -0.2531666605106765], 
              Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8045925513977634`, 0.017848620677213583`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A1", 2, {
              Complex[3.8045925513977634`, 0.017848620677213583`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6745692444113933`, -0.251658048484637}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A1", 1, {
              Complex[1.6745692444113933`, -0.251658048484637], 
              Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.796488032915171, 0.018122527898744724`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A1", 2, {
              Complex[3.796488032915171, 0.018122527898744724`], 
              Complex[5.244507580447731, -1.158666193825158]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6838947753228468`, -0.25018182541497563`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A1", 1, {
              Complex[1.6838947753228468`, -0.25018182541497563`], 
              Complex[2.816682213625116, -1.635923116971627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7883877807626547`, 0.018402382887287773`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A1", 2, {
              Complex[3.7883877807626547`, 0.018402382887287773`], 
              Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6932105534745874`, -0.2487375751928472}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A1", 1, {
              Complex[1.6932105534745874`, -0.2487375751928472], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7802904634285417`, 0.018688382492788227`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A1", 2, {
              Complex[3.7802904634285417`, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7025179328539397`, -0.2473249107203387}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A1", 1, {
              Complex[1.7025179328539397`, -0.2473249107203387], 
              Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.772194754147412, 0.018980732522336802`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A1", 2, {
              Complex[3.772194754147412, 0.018980732522336802`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.711818266170711, -0.24594347356467736`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A1", 1, {
              Complex[1.711818266170711, -0.24594347356467736`], 
              Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7640993290778377`, 0.019279648259930993`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A1", 2, {
              Complex[3.7640993290778377`, 0.019279648259930993`], 
              Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7211129065258053`, -0.2445929336962447}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A1", 1, {
              Complex[1.7211129065258053`, -0.2445929336962447], 
              Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7560028654954856`, 0.01958535502317048}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A1", 2, {
              Complex[3.7560028654954856`, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7304032090806973`, -0.24327298931041993`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A1", 1, {
              Complex[1.7304032090806973`, -0.24327298931041993`], 
              Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.747904039995082, 0.01989808875998759}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A1", 2, {
              Complex[3.747904039995082, 0.01989808875998759], 
              Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.739690532733481, -0.24198336673385532`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A1", 1, {
              Complex[1.739690532733481, -0.24198336673385532`], 
              Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.739801526694796, 0.020218096688815523`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A1", 2, {
              Complex[3.739801526694796, 0.020218096688815523`], 
              Complex[5.181444746812216, -1.157435637212811]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7489762418071482`, -0.24072382041628856`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A1", 1, {
              Complex[1.7489762418071482`, -0.24072382041628856`], 
              Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7316939954367316`, 0.020545637985933}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A1", 2, {
              Complex[3.7316939954367316`, 0.020545637985933], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.758261707755823, -0.23949413300958816`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A1", 1, {
              Complex[1.758261707755823, -0.23949413300958816`], 
              Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.723580109977185, 0.020880984524095002`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A1", 2, {
              Complex[3.723580109977185, 0.020880984524095002`], 
              Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7675483108947163`, -0.2382941155363085}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A1", 1, {
              Complex[1.7675483108947163`, -0.2382941155363085], 
              Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7154585261603414`, 0.021224421666976207`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A1", 2, {
              Complex[3.7154585261603414`, 0.021224421666976207`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.776837442159661, -0.23712360765068694`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A1", 1, {
              Complex[1.776837442159661, -0.23712360765068694`], 
              Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.707327890069032, 0.02157624912441267}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A1", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7861305049022496`, -0.23598247799562685`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A1", 1, {
              Complex[1.7861305049022496`, -0.23598247799562685`], 
              Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6991868361460636`, 0.021936781873947247`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A1", 2, {
              Complex[3.6991868361460636`, 0.021936781873947247`], 
              Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7954289167267061`, -0.23487062465998598`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A1", 1, {
              Complex[1.7954289167267061`, -0.23487062465998598`], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6910339852795406`, 0.022306351154756415`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A1", 2, {
              Complex[3.6910339852795406`, 0.022306351154756415`], 
              Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8047341113748927`, -0.23378797574120985`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A1", 1, {
              Complex[1.8047341113748927`, -0.23378797574120985`], 
              Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6828679428453777`, 0.022685305540684448`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A1", 2, {
              Complex[3.6828679428453777`, 0.022685305540684448`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.814047540666005, -0.23273449001922963`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A1", 1, {
              Complex[1.814047540666005, -0.23273449001922963`], 
              Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6746872967000694`, 0.0230740120998302}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A1", 2, {
              Complex[3.6746872967000694`, 0.0230740120998302], 
              Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8233706764978728`, -0.2317101577484136}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A1", 1, {
              Complex[1.8233706764978728`, -0.2317101577484136], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6664906151164782`, 0.023472857648944835`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A1", 2, {
              Complex[3.6664906151164782`, 0.023472857648944835`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8327050129169915`, -0.23071500157543248`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A1", 1, {
              Complex[1.8327050129169915`, -0.23071500157543248`], 
              Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6582764446551637`, 0.023882250111808095`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A1", 2, {
              Complex[3.6582764446551637`, 0.023882250111808095`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8420520682648396`, -0.22974907759194238`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A1", 1, {
              Complex[1.8420520682648396`, -0.22974907759194238`], 
              Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6500433079634345`, 0.02430261999177399}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A1", 2, {
              Complex[3.6500433079634345`, 0.02430261999177399], 
              Complex[5.080861117956597, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8514133874083418`, -0.22881247653229805`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A1", 1, {
              Complex[1.8514133874083418`, -0.22881247653229805`], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.64178970149396, 0.024734421969833987`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A1", 2, {
              Complex[3.64178970149396, 0.024734421969833987`], 
              Complex[5.071567299655017, -1.154523602824754]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.860790544062835, -0.2279053251278246}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A1", 1, {
              Complex[1.860790544062835, -0.2279053251278246], 
              Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.633514093134369, 0.025178136640842893`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A1", 2, {
              Complex[3.633514093134369, 0.025178136640842893`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8701851432162653`, -0.22702778763077072`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A1", 1, {
              Complex[1.8701851432162653`, -0.22702778763077072`], 
              Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.625214919738834, 0.025634272402031196`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A1", 2, {
              Complex[3.625214919738834, 0.025634272402031196`], 
              Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8795988236639012`, -0.22618006752276323`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A1", 1, {
              Complex[1.8795988236639012`, -0.22618006752276323`], 
              Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6168905845521655`, 0.0261033675095845}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A1", 2, {
              Complex[3.6168905845521655`, 0.0261033675095845], 
              Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8890332606633722`, -0.22536240942454516`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A1", 1, {
              Complex[1.8890332606633722`, -0.22536240942454516`], 
              Complex[3.047400635096297, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6085394545164045`, 0.026585992320965875`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A1", 2, {
              Complex[3.6085394545164045`, 0.026585992320965875`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8984901687203608`, -0.2245751012259816}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A1", 1, {
              Complex[1.8984901687203608`, -0.2245751012259816], 
              Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6001598574493725`, 0.027082751742796535`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A1", 2, {
              Complex[3.6001598574493725`, 0.027082751742796535`], 
              Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9079713045159428`, -0.22381847645779898`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A1", 1, {
              Complex[1.9079713045159428`, -0.22381847645779898`], 
              Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5917500790840515`, 0.02759428790654434}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A1", 2, {
              Complex[3.5917500790840515`, 0.02759428790654434], 
              Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9174784699871426`, -0.22309291692935715`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A1", 1, {
              Complex[1.9174784699871426`, -0.22309291692935715`], 
              Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.583308359957026, 0.02812128309705336}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A1", 2, {
              Complex[3.583308359957026, 0.02812128309705336], 
              Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.927013515572947, -0.22239885565995451`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A1", 1, {
              Complex[1.927013515572947, -0.22239885565995451`], 
              Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5748328921336294`, 0.02866446296210389}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A1", 2, {
              Complex[3.5748328921336294`, 0.02866446296210389], 
              Complex[4.99589327476625, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9365783436386594`, -0.22173678013483558`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A1", 1, {
              Complex[1.9365783436386594`, -0.22173678013483558`], 
              Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.566321815756732, 0.029224600034819154`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A1", 2, {
              Complex[3.566321815756732, 0.029224600034819154`], 
              Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9461749120921603`, -0.22110723592124693`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A1", 1, {
              Complex[1.9461749120921603`, -0.22110723592124693`], 
              Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.557773215405521, 0.029802517604874564`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A1", 2, {
              Complex[3.557773215405521, 0.029802517604874564`], 
              Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9558052382062334`, -0.22051083068468325`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A1", 1, {
              Complex[1.9558052382062334`, -0.22051083068468325`], 
              Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5491851162499515`, 0.030399093979211273`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A1", 2, {
              Complex[3.5491851162499515`, 0.030399093979211273`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.965471402661748, -0.21994823865092936`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A1", 1, {
              Complex[1.965471402661748, -0.21994823865092936`], 
              Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.540555479985998, 0.031015267178413904`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A1", 2, {
              Complex[3.540555479985998, 0.031015267178413904`], 
              Complex[4.956961006232221, -1.149994992121425]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9751755538269593`, -0.21942020556585135`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A1", 1, {
              Complex[1.9751755538269593`, -0.21942020556585135`], 
              Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.531882200536309, 0.031652040121196476`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A1", 2, {
              Complex[3.531882200536309, 0.031652040121196476`], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.984919912288591, -0.2189275542121152}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A1", 1, {
              Complex[1.984919912288591, -0.2189275542121152], 
              Complex[3.157220421076432, -1.563457815486074]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5231630995005294`, 0.03231048635665899}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A1", 2, {
              Complex[3.5231630995005294`, 0.03231048635665899], 
              Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9947067756505623`, -0.21847119055042036`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A1", 1, {
              Complex[1.9947067756505623`, -0.21847119055042036`], 
              Complex[3.168494941546649, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5143959213393177`, 0.03299175641234993}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A1", 2, {
              Complex[3.5143959213393177`, 0.03299175641234993], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.004538523616137, -0.21805211056251306`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A1", 1, {
              Complex[2.004538523616137, -0.21805211056251306`], 
              Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.505578328276208, 0.03369708483581626}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A1", 2, {
              Complex[3.505578328276208, 0.03369708483581626], 
              Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.014417623368864, -0.21767140788446343`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A1", 1, {
              Complex[2.014417623368864, -0.21767140788446343`], 
              Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4967078949018573`, 0.03442779801852968}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A1", 2, {
              Complex[3.4967078949018573`, 0.03442779801852968], 
              Complex[4.9069682642347, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0243466352667068`, -0.21733028233169743`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A1", 1, {
              Complex[2.0243466352667068`, -0.21733028233169743`], 
              Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4877821024662152`, 0.035185322904060734`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A1", 2, {
              Complex[3.4877821024662152`, 0.035185322904060734`], 
              Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.034328218862186, -0.2170300494324249}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A1", 1, {
              Complex[2.034328218862186, -0.2170300494324249], 
              Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.478798332845711, 0.03597119669747849}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A1", 2, {
              Complex[3.478798332845711, 0.03597119669747849], 
              Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0443651392587743`, -0.2167721511036576}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A1", 1, {
              Complex[2.0443651392587743`, -0.2167721511036576], 
              Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.469753862175173, 0.036787077710537186`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A1", 2, {
              Complex[3.469753862175173, 0.036787077710537186`], 
              Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.054460273810074, -0.2165581676245985}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A1", 1, {
              Complex[2.054460273810074, -0.2165581676245985], 
              Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.460645854137856, 0.03763475749771081}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A1", 2, {
              Complex[3.460645854137856, 0.03763475749771081], 
              Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0646166191629156`, -0.21638983108607387`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A1", 1, {
              Complex[2.0646166191629156`, -0.21638983108607387`], 
              Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4514713529124292`, 0.03851617446207811}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A1", 2, {
              Complex[3.4514713529124292`, 0.03851617446207811], 
              Complex[4.855165682495277, -1.144029106365958]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0748372986380015`, -0.2162690405227275}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A1", 1, {
              Complex[2.0748372986380015`, -0.2162690405227275], 
              Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.442227275783197, 0.03943342913804209}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A1", 2, {
              Complex[3.442227275783197, 0.03943342913804209], 
              Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0851255699314044`, -0.21619787896744103`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A1", 1, {
              Complex[2.0851255699314044`, -0.21619787896744103`], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4329104054302233`, 0.04038880139063529}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A1", 2, {
              Complex[3.4329104054302233`, 0.04038880139063529], 
              Complex[4.833843395364207, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0954848331061537`, -0.21617863270584692`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A1", 1, {
              Complex[2.0954848331061537`, -0.21617863270584692`], 
              Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.423517381930075, 0.04138476980950441}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A1", 2, {
              Complex[3.423517381930075, 0.04138476980950441], 
              Complex[4.823037890424123, -1.141619564099015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1059186388242215`, -0.21621381305374038`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A1", 1, {
              Complex[2.1059186388242215`, -0.21621381305374038`], 
              Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4140446945168277`, 0.042424033620649226`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A1", 2, {
              Complex[3.4140446945168277`, 0.042424033620649226`], 
              Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.116430696743796, -0.21630618103294583`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A1", 1, {
              Complex[2.116430696743796, -0.21630618103294583`], 
              Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4044886731783923`, 0.043509537491681564`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A1", 2, {
              Complex[3.4044886731783923`, 0.043509537491681564`], 
              Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.127024883972908, -0.21645877538292152`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A1", 1, {
              Complex[2.127024883972908, -0.21645877538292152`], 
              Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3948454801970804`, 0.044644499668114825`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A1", 2, {
              Complex[3.3948454801970804`, 0.044644499668114825`], 
              Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.137705253425444, -0.21667494441768215`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A1", 1, {
              Complex[2.137705253425444, -0.21667494441768215`], 
              Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3851111017883304`, 0.045832443950466685`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A1", 2, {
              Complex[3.3851111017883304`, 0.045832443950466685`], 
              Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1484760418658873`, -0.21695838232209172`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A1", 1, {
              Complex[2.1484760418658873`, -0.21695838232209172`], 
              Complex[3.347142736911111, -1.54216837655994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3752813400511936`, 0.04707723610641603}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A1", 2, {
              Complex[3.3752813400511936`, 0.04707723610641603], 
              Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.15934167735015, -0.21731317057992383`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A1", 1, {
              Complex[2.15934167735015, -0.21731317057992383`], 
              Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.365351805523236, 0.04838312541060397}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A1", 2, {
              Complex[3.365351805523236, 0.04838312541060397], 
              Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.170306785665302, -0.21774382534019746`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A1", 1, {
              Complex[2.170306785665302, -0.21774382534019746`], 
              Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3553179107369844`, 0.049754792118764775`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A1", 2, {
              Complex[3.3553179107369844`, 0.049754792118764775`], 
              Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.181376195232895, -0.2182553516597405}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A1", 1, {
              Complex[2.181376195232895, -0.2182553516597405], 
              Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.345174865313174, 0.0511974018142957}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A1", 2, {
              Complex[3.345174865313174, 0.0511974018142957], 
              Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1925549397581063`, -0.21885330570991673`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A1", 1, {
              Complex[2.1925549397581063`, -0.21885330570991673`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3349176733086154`, 0.052716667715368405`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A1", 2, {
              Complex[3.3349176733086154`, 0.052716667715368405`], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2038482576658165`, -0.2195438662043097}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A1", 1, {
              Complex[2.2038482576658165`, -0.2195438662043097], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3245411337774544`, 0.05431892219952697}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A1", 2, {
              Complex[3.3245411337774544`, 0.05431892219952697], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2152615870464745`, -0.2203339164903331}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A1", 1, {
              Complex[2.2152615870464745`, -0.2203339164903331], 
              Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.314039845823023, 0.05601119898888117}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A1", 2, {
              Complex[3.314039845823023, 0.05601119898888117], 
              Complex[4.696326724353138, -1.12850882102276]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2268005544144556`, -0.22123113894674887`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A1", 1, {
              Complex[2.2268005544144556`, -0.22123113894674887`], 
              Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3034082198375003`, 0.05780132763801396}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A1", 2, {
              Complex[3.3034082198375003`, 0.05780132763801396], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.23847095502768, -0.2222441235311438}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A1", 1, {
              Complex[2.23847095502768, -0.2222441235311438], 
              Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.292640497180628, 0.059698042168788046`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A1", 2, {
              Complex[3.292640497180628, 0.059698042168788046`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.250278721787946, -0.22338249250843553`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A1", 1, {
              Complex[2.250278721787946, -0.22338249250843553`], 
              Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2817307812779952`, 0.061711105883242925`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A1", 2, {
              Complex[3.2817307812779952`, 0.061711105883242925`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2622298787838817`, -0.2246570435317342}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A1", 1, {
              Complex[2.2622298787838817`, -0.2246570435317342], 
              Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.270673084076976, 0.06385145452602974}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A1", 2, {
              Complex[3.270673084076976, 0.06385145452602974], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.274330474286138, -0.22607991328743204`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A1", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2594613930506555`, 0.06613136000835836}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A1", 2, {
              Complex[3.2594613930506555`, 0.06613136000835836], 
              Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2865864863773204`, -0.2276647637711871}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A1", 1, {
              Complex[2.2865864863773204`, -0.2276647637711871], 
              Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2480897655672782`, 0.06856461676025145}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A1", 2, {
              Complex[3.2480897655672782`, 0.06856461676025145], 
              Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2990036923040837`, -0.2294269927942462}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A1", 1, {
              Complex[2.2990036923040837`, -0.2294269927942462], 
              Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.23655245953774, 0.07116675231062944}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A1", 2, {
              Complex[3.23655245953774, 0.07116675231062944], 
              Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.311587489979285, -0.23138396931833907`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A1", 1, {
              Complex[2.311587489979285, -0.23138396931833907`], 
              Complex[3.539668711719687, -1.54125837029078]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2248441119132174`, 0.07395526269357484}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A1", 2, {
              Complex[3.2248441119132174`, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.324342656755631, -0.2335552923600304}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A1", 1, {
              Complex[2.324342656755631, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.212959979911501, 0.07694987142173919}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A1", 2, {
              Complex[3.212959979911501, 0.07694987142173919], 
              Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3372730266129884`, -0.2359630690132302}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A1", 1, {
              Complex[2.3372730266129884`, -0.2359630690132302], 
              Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.20089626382986, 0.0801728075757009}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A1", 2, {
              Complex[3.20089626382986, 0.0801728075757009], 
              Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3503810623577226`, -0.23863220192231419`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A1", 1, {
              Complex[2.3503810623577226`, -0.23863220192231419`], 
              Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.18865053484601, 0.08364909334179278}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A1", 2, {
              Complex[3.18865053484601, 0.08364909334179278], 
              Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3636672947096224`, -0.24159066834690415`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A1", 1, {
              Complex[2.3636672947096224`, -0.24159066834690415`], 
              Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.176222295931689, 0.08740682313953917}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A1", 2, {
              Complex[3.176222295931689, 0.08740682313953917], 
              Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3771295961517165`, -0.24486976056502352`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A1", 1, {
              Complex[2.3771295961517165`, -0.24486976056502352`], 
              Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1636137080034565`, 0.09147740408549974}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A1", 2, {
              Complex[3.1636137080034565`, 0.09147740408549974], 
              Complex[4.519597775965093, -1.093160763626926]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3907622559358295`, -0.24850423935263424`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A1", 1, {
              Complex[2.3907622559358295`, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1508305149179034`, 0.09589570953158899}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A1", 2, {
              Complex[3.1508305149179034`, 0.09589570953158899], 
              Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.404554826889628, -0.25253232740394693`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A1", 1, {
              Complex[2.404554826889628, -0.25253232740394693`], 
              Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.137883196665494, 0.10070007254234226`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A1", 2, {
              Complex[3.137883196665494, 0.10070007254234226`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4184907299124174`, -0.2569954375693104}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A1", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.66780561916792, -1.560366273382241]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.124788364875778, 0.1059320141880026}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A1", 2, {
              Complex[3.124788364875778, 0.1059320141880026], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4325456359616355`, -0.26193749411720374`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A1", 1, {
              Complex[2.4325456359616355`, -0.26193749411720374`], 
              Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1115703808320068`, 0.11163556486001101`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A1", 2, {
              Complex[3.1115703808320068`, 0.11163556486001101`], 
              Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4466857074528354`, -0.2674036718059935}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A1", 1, {
              Complex[2.4466857074528354`, -0.2674036718059935], 
              Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.098263114072366, 0.11785600339463051`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A1", 2, {
              Complex[3.098263114072366, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8395927484273833`, -0.6433017314670934}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8395927484273833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B1", 1, {
              Complex[3.8395927484273833`, -0.6433017314670934], 
              Complex[1.7951626777960417`, -2.1401483895471043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.8360190079650485`, 0.006645071137818026}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "B1", 2, {
              Complex[7.8360190079650485`, 0.006645071137818026], 
              Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.8749809118562997`, -0.6165221792948034}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8749809118562997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971957`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B1", 1, {
              Complex[3.8749809118562997`, -0.6165221792948034], 
              Complex[1.8301368298409684`, -2.112021181971957]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.795901779221279, 0.006712510785854963}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "B1", 2, {
              Complex[7.795901779221279, 0.006712510785854963], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9045700992025902`, -0.5952855745698094}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9045700992025902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698094`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.859366613529833`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0894057490922258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B1", 1, {
              Complex[3.9045700992025902`, -0.5952855745698094], 
              Complex[1.859366613529833, -2.0894057490922258`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.763484521798694, 0.006786025025048383}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "B1", 2, {
              Complex[7.763484521798694, 0.006786025025048383], 
              Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.93075079131323, -0.5773156862277917}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.93075079131323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5773156862277917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B1", 1, {
              Complex[3.93075079131323, -0.5773156862277917], 
              Complex[1.8852354657886536`, -2.0700333477056216`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.735547972440535, 0.006863336573144897}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "B1", 2, {
              Complex[7.735547972440535, 0.006863336573144897], 
              Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.9546128944921874`, -0.5615718710865847}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9546128944921874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5615718710865847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9088286894191442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0528681311196006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B1", 1, {
              Complex[3.9546128944921874`, -0.5615718710865847], 
              Complex[1.9088286894191442`, -2.0528681311196006`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.710629285429999, 0.00694346149760476}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "B1", 2, {
              Complex[7.710629285429999, 0.00694346149760476], 
              Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.976762799482182, -0.5474736791133854}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.976762799482182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589238`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0373330727564842`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B1", 1, {
              Complex[3.976762799482182, -0.5474736791133854], 
              Complex[1.9307493118589238`, -2.0373330727564842`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.687917286732913, 0.007025882918871702}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "B1", 2, {
              Complex[7.687917286732913, 0.007025882918871702], 
              Complex[6.045167287063117, -1.163332885610651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{3.997579366252664, -0.5346576120369394}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.997579366252664`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5346576120369394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.951373568464064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0230672781048282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B1", 1, {
              Complex[3.997579366252664, -0.5346576120369394], 
              Complex[1.951373568464064, -2.0230672781048282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.666906890699567, 0.007110298008162871}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "B1", 2, {
              Complex[7.666906890699567, 0.007110298008162871], 
              Complex[6.023558855884935, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.017318225749185, -0.5228778864146391}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.017318225749185`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228778864146391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.970954950697273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.009827028796297`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B1", 1, {
              Complex[4.017318225749185, -0.5228778864146391], 
              Complex[1.970954950697273, -2.009827028796297]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.6472584862388935`, 0.007196517077880152}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "B1", 2, {
              Complex[7.6472584862388935`, 0.007196517077880152], 
              Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.036161628380458, -0.5119589442981466}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.036161628380458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5119589442981466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.997438454007966`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B1", 1, {
              Complex[4.036161628380458, -0.5119589442981466], 
              Complex[1.9896739101964112`, -1.997438454007966]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.628730822140306, 0.0072844163322486775`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "B1", 2, {
              Complex[7.628730822140306, 0.0072844163322486775`], 
              Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.054245015542006, -0.5017701062164085}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.054245015542006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5017701062164085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0076643409453054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.985772283295857`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B1", 1, {
              Complex[4.054245015542006, -0.5017701062164085], 
              Complex[2.0076643409453054`, -1.985772283295857]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.611145277473936, 0.007373913179256576}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "B1", 2, {
              Complex[7.611145277473936, 0.007373913179256576], 
              Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.071672363798729, -0.49221091488169333`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.071672363798729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49221091488169333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0250288646775303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9747292562304544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B1", 1, {
              Complex[4.071672363798729, -0.49221091488169333`], 
              Complex[2.0250288646775303`, -1.9747292562304544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5943652547457265`, 0.0074649522520338}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "B1", 2, {
              Complex[7.5943652547457265`, 0.0074649522520338], 
              Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.088525607498785, -0.4832021231088809}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.088525607498785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4832021231088809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9642311559465844`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B1", 1, {
              Complex[4.088525607498785, -0.4832021231088809], 
              Complex[2.0418482129451156`, -1.9642311559465844`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           
           TooltipBox[PointBox[{7.5782835412454626`, 0.0075574969911607935`}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "B1", 2, {
              Complex[7.5782835412454626`, 0.0075574969911607935`], 
              Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.104870714597597, -0.4746798749981737}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.104870714597597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4746798749981737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.058187273894044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9542150231143423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B1", 1, {
              Complex[4.104870714597597, -0.4746798749981737], 
              Complex[2.058187273894044, -1.9542150231143423`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5628141695271145`, 0.007651524322598731}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "B1", 2, {
              Complex[7.5628141695271145`, 0.007651524322598731], 
              Complex[5.915830554816423, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.12076176343584, -0.46659179640833626`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.12076176343584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.46659179640833626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B1", 1, {
              Complex[4.12076176343584, -0.46659179640833626`], 
              Complex[2.0740991475740485`, -1.9446292707044917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.547886962653699, 0.00774702115719995}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "B1", 2, {
              Complex[7.547886962653699, 0.00774702115719995], 
              Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.13624377018248, -0.4588942798973108}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.13624377018248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4588942798973108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B1", 1, {
              Complex[4.13624377018248, -0.4588942798973108], 
              Complex[2.089627957098804, -1.9354309873904456`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.533443755733459, 0.007843982012263152}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "B1", 2, {
              Complex[7.533443755733459, 0.007843982012263152], 
              Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.151354705396683, -0.4515505457349306}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.151354705396683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4515505457349306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9265840128958314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B1", 1, {
              Complex[4.151354705396683, -0.4515505457349306], 
              Complex[2.1048108525831077`, -1.9265840128958314`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5194357044269005`, 0.007942407351021058}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "B1", 2, {
              Complex[7.5194357044269005`, 0.007942407351021058], 
              Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.166126967125889, -0.44452922359237873`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.166126967125889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.44452922359237873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B1", 1, {
              Complex[4.166126967125889, -0.44452922359237873`], 
              Complex[2.119679474265542, -1.918057531021161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.5058213212730225`, 0.008042302396705316}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "B1", 2, {
              Complex[7.5058213212730225`, 0.008042302396705316], 
              Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.180588479578346, -0.43780329333443724`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180588479578346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1342610431682947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9098250195461792`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B1", 1, {
              Complex[4.180588479578346, -0.43780329333443724`], 
              Complex[2.1342610431682947`, -1.9098250195461792`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.492565012985164, 0.008143676269233487}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "B1", 2, {
              Complex[7.492565012985164, 0.008143676269233487], 
              Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.194763527568909, -0.43134927949335283`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.194763527568909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43134927949335283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B1", 1, {
              Complex[4.194763527568909, -0.43134927949335283`], 
              Complex[2.148579189013271, -1.9018634521265059`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.479635970943437, 0.008246541346654087}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "B1", 2, {
              Complex[7.479635970943437, 0.008246541346654087], 
              Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.208673400536594, -0.42514662876555215`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.208673400536594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42514662876555215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126024`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B1", 1, {
              Complex[4.208673400536594, -0.42514662876555215`], 
              Complex[2.1626545888502187`, -1.8941526819126024`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.4670073159977095`, 0.008350912786614366}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "B1", 2, {
              Complex[7.4670073159977095`, 0.008350912786614366], 
              Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.222336896739361, -0.41917722203755803`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222336896739361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41917722203755803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1765054667524417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.886674958680205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B1", 1, {
              Complex[4.222336896739361, -0.41917722203755803`], 
              Complex[2.1765054667524417`, -1.886674958680205]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.454655429824251, 0.008456808164000526}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "B1", 2, {
              Complex[7.454655429824251, 0.008456808164000526], 
              Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.2357707230637445`, -0.41342498695324215`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.2357707230637445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695324215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1901479898323104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.879414545694765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B1", 1, {
              Complex[4.2357707230637445`, -0.41342498695324215`], 
              Complex[2.1901479898323104`, -1.879414545694765]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.442559425423676, 0.008564247194411552}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "B1", 2, {
              Complex[7.442559425423676, 0.008564247194411552], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.248989815735208, -0.4078755867501412}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.248989815735208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.872357412196735`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B1", 1, {
              Complex[4.248989815735208, -0.4078755867501412], 
              Complex[2.203596585722578, -1.872357412196735]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.430700722955541, 0.008673251522090992}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "B1", 2, {
              Complex[7.430700722955541, 0.008673251522090992], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.262007600278324, -0.4025161677361105}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.262007600278324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025161677361105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B1", 1, {
              Complex[4.262007600278324, -0.4025161677361105], 
              Complex[2.216864199765703, -1.8654909840009626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.419062706397297, 0.008783844556995738}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "B1", 2, {
              Complex[7.419062706397297, 0.008783844556995738], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.274836204246599, -0.39733515240586165`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.274836204246599`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39733515240586165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045286`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B1", 1, {
              Complex[4.274836204246599, -0.39733515240586165`], 
              Complex[2.2299625053481056`, -1.8588039393045286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.4076304429802775`, 0.00889605134985899}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "B1", 2, {
              Complex[7.4076304429802775`, 0.00889605134985899], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.287486632822467, -0.39232206847656975`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.287486632822467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.39232206847656975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2429020774149055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8522860400567247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B1", 1, {
              Complex[4.287486632822467, -0.39232206847656975`], 
              Complex[2.2429020774149055`, -1.8522860400567247`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.396390451929997, 0.009009898497033932}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "B1", 2, {
              Complex[7.396390451929997, 0.009009898497033932], 
              Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.299968914929404, -0.38746740648134725`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.299968914929404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.38746740648134725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B1", 1, {
              Complex[4.299968914929404, -0.38746740648134725`], 
              Complex[2.2556925367556317`, -1.8459279915891416`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.3853305123250825`, 0.009125414068990404}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "B1", 2, {
              Complex[7.3853305123250825`, 0.009125414068990404], 
              Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.31229222570538, -0.3827625002813669}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.31229222570538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3827625002813669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2683426708688654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8397213249141586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B1", 1, {
              Complex[4.31229222570538, -0.3827625002813669], 
              Complex[2.2683426708688654`, -1.8397213249141586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.374439502284718, 0.00924262755784085}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "B1", 2, {
              Complex[7.374439502284718, 0.00924262755784085], 
              Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.324464989862636, -0.3781994261302779}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.324464989862636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3781994261302779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B1", 1, {
              Complex[4.324464989862636, -0.3781994261302779], 
              Complex[2.280860535897552, -1.8336582973639262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.363707263462426, 0.009361569840391621}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "B1", 2, {
              Complex[7.363707263462426, 0.009361569840391621], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.336494969468971, -0.3737709168766498}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.336494969468971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3737709168766498`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.82773180818695`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B1", 1, {
              Complex[4.336494969468971, -0.3737709168766498], 
              Complex[2.293253543143011, -1.82773180818695]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.3531244861453, 0.009482273153988793}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "B1", 2, {
              Complex[7.3531244861453, 0.009482273153988793], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.348389338937685, -0.36947028861032294`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.348389338937685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.36947028861032294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3055285329225508`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8219353264340112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B1", 1, {
              Complex[4.348389338937685, -0.36947028861032294`], 
              Complex[2.3055285329225508`, -1.8219353264340112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.342682611254977, 0.009604771083122523}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "B1", 2, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.3601547494422475`, -0.3652913776086266}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3601547494422475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3652913776086266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3176918379683404`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8162628290107474`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B1", 1, {
              Complex[4.3601547494422475`, -0.3652913776086266], 
              Complex[2.3176918379683404`, -1.8162628290107474`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.332373746308075, 0.009729098555121761}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "B1", 2, {
              Complex[7.332373746308075, 0.009729098555121761], 
              Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.3717973845316225`, -0.36122848586285683`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3717973845316225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36122848586285683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951673`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B1", 1, {
              Complex[4.3717973845316225`, -0.36122848586285683`], 
              Complex[2.329749338128145, -1.8107087471951673`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.322190592979878, 0.009855291843704485}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "B1", 2, {
              Complex[7.322190592979878, 0.009855291843704485], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.38332300838, -0.35727633379543705`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.38332300838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35727633379543705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.341706507788824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8052679202454827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B1", 1, {
              Complex[4.38332300838, -0.35727633379543705`], 
              Complex[2.341706507788824, -1.8052679202454827`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.312126384370602, 0.009983388579384756}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.312126384370602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.651636660481892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162482038362008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "B1", 2, {
              Complex[7.312126384370602, 0.009983388579384756], 
              Complex[5.651636660481892, -1.162482038362008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.394737007836374, -0.35343001903737564`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.394737007836374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7999355549805411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B1", 1, {
              Complex[4.394737007836374, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.7999355549805411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.302174830430454, 0.010113427765967268`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.302174830430454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.641006995243322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162436027385382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "B1", 2, {
              Complex[7.302174830430454, 0.010113427765967268`], 
              Complex[5.641006995243322, -1.162436027385382]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.40604442922753, -0.3496849803402998}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.40604442922753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3496849803402998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.365339968482914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7947071904178578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B1", 1, {
              Complex[4.40604442922753, -0.3496849803402998], 
              Complex[2.365339968482914, -1.7947071904178578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.292330070281435, 0.010245449802525817`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.292330070281435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010245449802525817`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "B1", 2, {
              Complex[7.292330070281435, 0.010245449802525817`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.417250010699276, -0.3460369658605059}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.417250010699276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3460369658605059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795718`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B1", 1, {
              Complex[4.417250010699276, -0.3460369658605059], 
              Complex[2.3770255275795718`, -1.7895786667158644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.282586630397876, 0.010379496510400103`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282586630397876`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010379496510400103`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.620051946974448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623400583917027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "B1", 2, {
              Complex[7.282586630397876, 0.010379496510400103`], 
              Complex[5.620051946974448, -1.1623400583917027`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.428358210745746, -0.34248200518323846`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.428358210745746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B1", 1, {
              Complex[4.428358210745746, -0.34248200518323846`], 
              Complex[2.388629351988557, -1.7845460977964323`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.272939387787106, 0.010515611164854442`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.272939387787106`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854442`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622900299949552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "B1", 2, {
              Complex[7.272939387787106, 0.010515611164854442`], 
              Complex[5.609715869645588, -1.1622900299949552`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.439373233467538, -0.3390163845608803}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.439373233467538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3390163845608803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.400155415619292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7796058471281262`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B1", 1, {
              Complex[4.439373233467538, -0.3390163845608803], 
              Complex[2.400155415619292, -1.7796058471281262`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.263383537456196, 0.010653838531129386`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.263383537456196`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129386`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "B1", 2, {
              Complex[7.263383537456196, 0.010653838531129386`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.450299051011202, -0.3356366249244736}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.450299051011202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3356366249244736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.411607470734253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B1", 1, {
              Complex[4.450299051011202, -0.3356366249244736], 
              Complex[2.411607470734253, -1.774754506235453]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.253914563567924, 0.010794224904694137`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.253914563567924`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694137`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "B1", 2, {
              Complex[7.253914563567924, 0.010794224904694137`], 
              Complex[5.58930230415447, -1.1621856987234664`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.461139423570387, -0.33233946229789096`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.461139423570387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33233946229789096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.422989067514498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7699888755685127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B1", 1, {
              Complex[4.461139423570387, -0.33233946229789096`], 
              Complex[2.422989067514498, -1.7699888755685127`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.244528213784578, 0.010936818155564378`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.244528213784578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564378`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "B1", 2, {
              Complex[7.244528213784578, 0.010936818155564378`], 
              Complex[5.579215944909337, -1.1621313167255454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.471897917269896, -0.3291218303014387}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.471897917269896`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3291218303014387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.765305947424264`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B1", 1, {
              Complex[4.471897917269896, -0.3291218303014387], 
              Complex[2.434303571543256, -1.765305947424264]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.235220476376673, 0.01108166777660797}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.235220476376673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01108166777660797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "B1", 2, {
              Complex[7.235220476376673, 0.01108166777660797], 
              Complex[5.569204368643545, -1.1620754018281332`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.482577920205066, -0.3259808444790341}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.482577920205066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3259808444790341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.445554179476747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.760702890657421`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B1", 1, {
              Complex[4.482577920205066, -0.3259808444790341], 
              Complex[2.445554179476747, -1.760702890657421]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.225987559738016, 0.011228824935798491`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225987559738016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798491`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "B1", 2, {
              Complex[7.225987559738016, 0.011228824935798491`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.4931826568685596`, -0.32291378822242134`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.4931826568685596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32291378822242134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4567439331314382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.756177036957859`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B1", 1, {
              Complex[4.4931826568685596`, -0.32291378822242134`], 
              Complex[2.4567439331314382`, -1.756177036957859]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.216825874002135, 0.011378342532423407`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.216825874002135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011378342532423407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.549390383803342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "B1", 2, {
              Complex[7.216825874002135, 0.011378342532423407`], 
              Complex[5.549390383803342, -1.1619587976643722`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.503715201163001, -0.3199181000986165}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.503715201163001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3199181000986165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.467875732183709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7517258685037114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B1", 1, {
              Complex[4.503715201163001, -0.3199181000986165], 
              Complex[2.467875732183709, -1.7517258685037114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.207732014499435, 0.011530275257279964`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.207732014499435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011530275257279964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.539580869749671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "B1", 2, {
              Complex[7.207732014499435, 0.011530275257279964`], 
              Complex[5.539580869749671, -1.1618980163266774`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.514178488169753, -0.31699136241415254`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.514178488169753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31699136241415254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263868`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B1", 1, {
              Complex[4.514178488169753, -0.31699136241415254`], 
              Complex[2.478952345649964, -1.7473470068263868`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.198702746831605, 0.011684679656931228`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.198702746831605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931228`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "B1", 2, {
              Complex[7.198702746831605, 0.011684679656931228`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.524575324820607, -0.31413129087274355`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.524575324820607`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B1", 1, {
              Complex[4.524575324820607, -0.31413129087274355`], 
              Complex[2.4899764222920573`, -1.7430382027464797`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.189734993370944, 0.011841614202115805`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.189734993370944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "B1", 2, {
              Complex[7.189734993370944, 0.011841614202115805`], 
              Complex[5.520140327071446, -1.1617712515975436`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.534908399599208, -0.3113357252023988}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.534908399599208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3113357252023988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5009505000731345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738797327258689`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B1", 1, {
              Complex[4.534908399599208, -0.3113357252023988], 
              Complex[2.5009505000731345`, -1.738797327258689]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.180825821018505, 0.012001139360437759`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.180825821018505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437759`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617051651569135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "B1", 2, {
              Complex[7.180825821018505, 0.012001139360437759`], 
              Complex[5.510503169822832, -1.1617051651569135`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.545180291382208, -0.3086026206444535}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.545180291382208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3086026206444535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600861`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B1", 1, {
              Complex[4.545180291382208, -0.3086026206444535], 
              Complex[2.511877014772339, -1.7346223632600861`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.171972430077165, 0.012163317673485156`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.171972430077165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485156`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967813`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "B1", 2, {
              Complex[7.171972430077165, 0.012163317673485156`], 
              Complex[5.500917563878367, -1.1616372039967813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.555393477515928, -0.3059300402110033}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.555393477515928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3059300402110033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5227583078528286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7305113980298918`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B1", 1, {
              Complex[4.555393477515928, -0.3059300402110033], 
              Complex[2.5227583078528286`, -1.7305113980298918`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.163172144114486, 0.012328213838552503`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.163172144114486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552503`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "B1", 2, {
              Complex[7.163172144114486, 0.012328213838552503`], 
              Complex[5.491380770642326, -1.1615673115173935`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.565550341212051, -0.3033161476291155}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.565550341212051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3033161476291155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B1", 1, {
              Complex[4.565550341212051, -0.3033161476291155], 
              Complex[2.5335966336654483`, -1.726462616380607]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.154422400706351, 0.012495894795164308`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.154422400706351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164308`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.481890164152063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "B1", 2, {
              Complex[7.154422400706351, 0.012495894795164308`], 
              Complex[5.481890164152063, -1.1614954289364903`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.5756531783355054`, -0.30075920090048514`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5756531783355054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B1", 1, {
              Complex[4.5756531783355054`, -0.30075920090048514`], 
              Complex[2.544394166060118, -1.7224742944105473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.145720742965965, 0.012666429816627278`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.145720742965965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "B1", 2, {
              Complex[7.145720742965965, 0.012666429816627278`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.585704203648775, -0.2982575464138705}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.585704203648775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2982575464138705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.55515300446826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7185447937963196`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B1", 1, {
              Complex[4.585704203648775, -0.2982575464138705], 
              Complex[2.55515300446826, -1.7185447937963196`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.137064811774602, 0.012839890606854724`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.137064811774602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "B1", 2, {
              Complex[7.137064811774602, 0.012839890606854724`], 
              Complex[5.463037520285709, -1.161345446865949]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.59570555656919, -0.2958096135553045}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.59570555656919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2958096135553045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713112`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B1", 1, {
              Complex[4.59570555656919, -0.2958096135553045], 
              Complex[2.5658751795119756`, -1.7146725565713112`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.128452338640535, 0.013016351402742217`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.128452338640535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742217`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.453670720869239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354267`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "B1", 2, {
              Complex[7.128452338640535, 0.013016351402742217`], 
              Complex[5.453670720869239, -1.1612672180354267`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.605659306489133, -0.2934139097675642}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.605659306489133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2934139097675642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7108561003427043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B1", 1, {
              Complex[4.605659306489133, -0.2934139097675642], 
              Complex[2.5765626581891583`, -1.7108561003427043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.119881139121318, 0.01319588908239133}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.119881139121318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01319588908239133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "B1", 2, {
              Complex[7.119881139121318, 0.01319588908239133], 
              Complex[5.444340570285955, -1.1611867402067304`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.615567457703371, -0.2910690160160602}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.615567457703371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2910690160160602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5872173486781147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7070940139050714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B1", 1, {
              Complex[4.615567457703371, -0.2910690160160602], 
              Complex[2.5872173486781147`, -1.7070940139050714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.111349106752032, 0.013378583279512458`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.111349106752032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013378583279512458`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161103942175881`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "B1", 2, {
              Complex[7.111349106752032, 0.013378583279512458`], 
              Complex[5.435044890840143, -1.161103942175881]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.62543195398277, -0.2887735826232172}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.62543195398277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B1", 1, {
              Complex[4.62543195398277, -0.2887735826232172], 
              Complex[2.5978411048003474`, -1.7033849532134373`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.102854207428718, 0.013564516504362785`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.102854207428718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362785`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161018749909008`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "B1", 2, {
              Complex[7.102854207428718, 0.013564516504362785`], 
              Complex[5.425781575481577, -1.161018749909008]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.635254682829313, -0.286526325437767}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.635254682829313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.286526325437767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6997276376830048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B1", 1, {
              Complex[4.635254682829313, -0.286526325437767], 
              Complex[2.608435730175939, -1.6997276376830048`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.094394474201807, 0.013753774271608687`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.094394474201807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108735`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "B1", 2, {
              Complex[7.094394474201807, 0.013753774271608687`], 
              Complex[5.416548582534639, -1.1609310864108735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.645037479443608, -0.2843260223090588}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.645037479443608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2843260223090588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.619002982102262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B1", 1, {
              Complex[4.645037479443608, -0.2843260223090588], 
              Complex[2.619002982102262, -1.6961208467863331`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.085968002439294, 0.013946445235532949`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.085968002439294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013946445235532949`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855625`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "B1", 2, {
              Complex[7.085968002439294, 0.013946445235532949`], 
              Complex[5.407343930794649, -1.1608408715855625`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.654782130432774, -0.2821715098398547}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654782130432774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B1", 1, {
              Complex[4.654782130432774, -0.2821715098398547], 
              Complex[2.6295445751835325`, -1.6925634169220711`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.077572945323753, 0.014142621333044114`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.077572945323753`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014142621333044114`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.398165694955261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "B1", 2, {
              Complex[7.077572945323753, 0.014142621333044114`], 
              Complex[5.398165694955261, -1.1607480220888433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.664490377283739, -0.28006168039394375`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.664490377283739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28006168039394375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6400621847358976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.689054238532184`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B1", 1, {
              Complex[4.664490377283739, -0.28006168039394375`], 
              Complex[2.6400621847358976`, -1.689054238532184]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.069207509650976, 0.014342397934981436`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.069207509650976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981436`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "B1", 2, {
              Complex[7.069207509650976, 0.014342397934981436`], 
              Complex[5.389012001334583, -1.1606524511716514`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.674163919624442, -0.2779954793374564}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.674163919624442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2779954793374564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6855922534470877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B1", 1, {
              Complex[4.674163919624442, -0.2779954793374564], 
              Complex[2.650557449990278, -1.6855922534470877`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.060869951901384, 0.014545874006250832`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.060869951901384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014545874006250832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "B1", 2, {
              Complex[7.060869951901384, 0.014545874006250832`], 
              Complex[5.379881023870965, -1.160554068514124]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.683804418293251, -0.2759719024950625}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.683804418293251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2759719024950625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6821764524403946`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B1", 1, {
              Complex[4.683804418293251, -0.2759719024950625], 
              Complex[2.6610319771130446`, -1.6821764524403946`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.052558574558201, 0.014753152275367028`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.052558574558201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367028`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "B1", 2, {
              Complex[7.052558574558201, 0.014753152275367028`], 
              Complex[5.3707709803622485`, -1.1604527800495483`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.693413498234962, -0.2739899938041945}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.693413498234962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2739899938041945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6788058729768809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B1", 1, {
              Complex[4.693413498234962, -0.2739899938041945], 
              Complex[2.671487342062718, -1.6788058729768809`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.044271722648962, 0.014964339414035013`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.044271722648962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014964339414035013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.361680128924861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "B1", 2, {
              Complex[7.044271722648962, 0.014964339414035013`], 
              Complex[5.361680128924861, -1.1603484877775456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.702992751240038, -0.27204884315225375`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.702992751240038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27204884315225375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.67547959713909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B1", 1, {
              Complex[4.702992751240038, -0.27204884315225375`], 
              Complex[2.68192509329917, -1.67547959713909]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.036007780489124, 0.015179546227436098`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.036007780489124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657405`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "B1", 2, {
              Complex[7.036007780489124, 0.015179546227436098`], 
              Complex[5.352606764651277, -1.1602410895657405`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.712543738542191, -0.2701475843833519}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.712543738542191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2701475843833519`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B1", 1, {
              Complex[4.712543738542191, -0.2701475843833519], 
              Complex[2.692346754360387, -1.6721967497195434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.027765168608572, 0.01539888785596537}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.027765168608572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01539888785596537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "B1", 2, {
              Complex[7.027765168608572, 0.01539888785596537], 
              Complex[5.343549216446447, -1.1601304789391282`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.722067993288219, -0.2682853934625311}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.722067993288219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682853934625311`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6689564964669001`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B1", 1, {
              Complex[4.722067993288219, -0.2682853934625311], 
              Complex[2.702753826320577, -1.6689564964669001`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.019542340843495, 0.015622483989198223`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.019542340843495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015622483989198223`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1600165448562518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "B1", 2, {
              Complex[7.019542340843495, 0.015622483989198223`], 
              Complex[5.334505844025381, -1.1600165448562518`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.731567022892644, -0.26646148678673676`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.731567022892644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26646148678673676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B1", 1, {
              Complex[4.731567022892644, -0.26646148678673676`], 
              Complex[2.7131477901421968`, -1.6657580424757268`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.011337781577717, 0.015850459092959842`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.011337781577717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015850459092959842`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159899171471262`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "B1", 2, {
              Complex[7.011337781577717, 0.015850459092959842`], 
              Complex[5.325475035055747, -1.159899171471262]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.741042311288872, -0.26467511963294066`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.741042311288872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26467511963294066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106498`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B1", 1, {
              Complex[4.741042311288872, -0.26467511963294066`], 
              Complex[2.7235301089335926`, -1.6626006307106498`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{7.003150003118844, 0.016082942650415873`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.003150003118844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016082942650415873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.316455202430542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "B1", 2, {
              Complex[7.003150003118844, 0.016082942650415873`], 
              Complex[5.316455202430542, -1.1597782378808235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.75049532108751, -0.26292558473487176`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.75049532108751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.26292558473487176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7339022301229714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6594835406566917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B1", 1, {
              Complex[4.75049532108751, -0.26292558473487176`], 
              Complex[2.7339022301229714`, -1.6594835406566917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.994977543195845, 0.016320069418202337`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.994977543195845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016320069418202337`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.307444781657182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "B1", 2, {
              Complex[6.994977543195845, 0.016320069418202337`], 
              Complex[5.307444781657182, -1.1596536178547647`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.7599274956518, -0.2612122109807508}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.7599274956518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2612122109807508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.656406087088548`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B1", 1, {
              Complex[4.7599274956518, -0.2612122109807508], 
              Complex[2.7442655875587207`, -1.656406087088548]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.986818962565743, 0.016561979698683896`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.986818962565743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016561979698683896`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.298442228350345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159525179549259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "B1", 2, {
              Complex[6.986818962565743, 0.016561979698683896`], 
              Complex[5.298442228350345, -1.159525179549259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.769340261099353, -0.2595343622253304}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.769340261099353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2595343622253304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6533676189524371`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B1", 1, {
              Complex[4.769340261099353, -0.2595343622253304], 
              Complex[2.7546216035454143`, -1.6533676189524371`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.978672842717983, 0.01680881962953298}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.978672842717983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01680881962953298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "B1", 2, {
              Complex[6.978672842717983, 0.01680881962953298], 
              Complex[5.289446015816816, -1.159392785201224]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.778735028238791, -0.25789143621028987`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.778735028238791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25789143621028987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242414`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549193`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B1", 1, {
              Complex[4.778735028238791, -0.25789143621028987`], 
              Complex[2.7649716908242414`, -1.6503675183549193`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.970537783665925, 0.017060741491919468`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.970537783665925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017060741491919468`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1592562908025152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "B1", 2, {
              Complex[6.970537783665925, 0.017060741491919468`], 
              Complex[5.280454632721416, -1.1592562908025152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.788113194449318, -0.256282863587831}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.788113194449318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.256282863587831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.775317254506115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.647405199653864`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B1", 1, {
              Complex[4.788113194449318, -0.256282863587831], 
              Complex[2.775317254506115, -1.647405199653864]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.962412401815591, 0.017317904038714253`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.962412401815591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017317904038714253`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.271466580823748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "B1", 2, {
              Complex[6.962412401815591, 0.017317904038714253`], 
              Complex[5.271466580823748, -1.1591155457523543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.79747614551083, -0.2547081070429694}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.79747614551083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2547081070429694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.785659693965298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6444801086473977`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B1", 1, {
              Complex[4.79747614551083, -0.2547081070429694], 
              Complex[2.785659693965298, -1.6444801086473977`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.954295327902444, 0.01758047284423772}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.954295327902444`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01758047284423772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589703924863028`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "B1", 2, {
              Complex[6.954295327902444, 0.01758047284423772], 
              Complex[5.262480372776143, -1.1589703924863028`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.806825257391718, -0.2531666605106761}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.806825257391718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2531666605106761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7960004047009623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6415917218573366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B1", 1, {
              Complex[4.806825257391718, -0.2531666605106761], 
              Complex[2.7960004047009623`, -1.6415917218573366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.946185204987557, 0.017848620677213628`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.946185204987557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017848620677213628`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "B1", 2, {
              Complex[6.946185204987557, 0.017848620677213628`], 
              Complex[5.253494529973699, -1.1588206660799294`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8161618980011855`, -0.2516580484846366}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8161618980011855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2516580484846366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.806340780173878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6387395459042151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B1", 1, {
              Complex[4.8161618980011855`, -0.2516580484846366], 
              Complex[2.806340780173878, -1.6387395459042151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.938080686504964, 0.018122527898744748`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.938080686504964`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744748`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.24450758044773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1586661938251581`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "B1", 2, {
              Complex[6.938080686504964, 0.018122527898744748`], 
              Complex[5.24450758044773, -1.1586661938251581`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.825487428912641, -0.2501818254149765}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.825487428912641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2501818254149765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8166822136251186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6359231169716282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B1", 1, {
              Complex[4.825487428912641, -0.2501818254149765], 
              Complex[2.8166822136251186`, -1.6359231169716282`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.929980434352448, 0.01840238288728782}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.929980434352448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840238288728782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.235518056794405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158506794777096`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "B1", 2, {
              Complex[6.929980434352448, 0.01840238288728782], 
              Complex[5.235518056794405, -1.158506794777096]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.834803207064381, -0.24873757519284634`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.834803207064381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24873757519284634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.827026099883429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6331420003581558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B1", 1, {
              Complex[4.834803207064381, -0.24873757519284634`], 
              Complex[2.827026099883429, -1.6331420003581558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.921883117018336, 0.018688382492788213`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.921883117018336`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018688382492788213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1583422792689293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "B1", 2, {
              Complex[6.921883117018336, 0.018688382492788213`], 
              Complex[5.226524494130514, -1.1583422792689293`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.844110586443732, -0.24732491072033783`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.844110586443732`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24732491072033783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.837373837167927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.630395790115732`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B1", 1, {
              Complex[4.844110586443732, -0.24732491072033783`], 
              Complex[2.837373837167927, -1.630395790115732]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.913787407737206, 0.018980732522336733`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.913787407737206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336733`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "B1", 2, {
              Complex[6.913787407737206, 0.018980732522336733`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.853410919760504, -0.24594347356467788`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.853410919760504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.847726828892449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6276841087738219`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B1", 1, {
              Complex[4.853410919760504, -0.24594347356467788`], 
              Complex[2.847726828892449, -1.6276841087738219`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.90569198266763, 0.01927964825993098}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.90569198266763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01927964825993098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2085193927050835`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "B1", 2, {
              Complex[6.90569198266763, 0.01927964825993098], 
              Complex[5.2085193927050835`, -1.1579970934399617`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.862705560115598, -0.24459293369624477`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.862705560115598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24459293369624477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.858086485478033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B1", 1, {
              Complex[4.862705560115598, -0.24459293369624477`], 
              Complex[2.858086485478033, -1.6250066071493976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.897595519085279, 0.01958535502317048}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.897595519085279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "B1", 2, {
              Complex[6.897595519085279, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.871995862670491, -0.24327298931041968`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.871995862670491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24327298931041968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.868454226179847`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6223629642431858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B1", 1, {
              Complex[4.871995862670491, -0.24327298931041968`], 
              Complex[2.868454226179847, -1.6223629642431858`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.889496693584875, 0.019898088759987553`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.889496693584875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019898088759987553`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "B1", 2, {
              Complex[6.889496693584875, 0.019898088759987553`], 
              Complex[5.190480530819805, -1.1576289238560522`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.881283186323276, -0.24198336673385487`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.881283186323276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.619752887223283`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B1", 1, {
              Complex[4.881283186323276, -0.24198336673385487`], 
              Complex[2.8788314809349793`, -1.619752887223283]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.881394180284589, 0.020218096688815555`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.881394180284589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815555`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1574356372128107`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "B1", 2, {
              Complex[6.881394180284589, 0.020218096688815555`], 
              Complex[5.181444746812216, -1.1574356372128107`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.8905688953969415`, -0.24072382041628823`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.8905688953969415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8892196922375373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6171761114978092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B1", 1, {
              Complex[4.8905688953969415`, -0.24072382041628823`], 
              Complex[2.8892196922375373`, -1.6171761114978092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.873286649026525, 0.020545637985932938`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.873286649026525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020545637985932938`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.172396074472307`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "B1", 2, {
              Complex[6.873286649026525, 0.020545637985932938`], 
              Complex[5.172396074472307, -1.1572358810391412`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.899854361345616, -0.23949413300958752`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.899854361345616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.614632400878879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B1", 1, {
              Complex[4.899854361345616, -0.23949413300958752`], 
              Complex[2.8996203170476367`, -1.614632400878879]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.865172763566979, 0.020880984524095033`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.865172763566979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095033`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "B1", 2, {
              Complex[6.865172763566979, 0.020880984524095033`], 
              Complex[5.163333010028643, -1.1570293877270228`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.90914096448451, -0.23829411553630825`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.90914096448451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23829411553630825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.612121547840817`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B1", 1, {
              Complex[4.90914096448451, -0.23829411553630825`], 
              Complex[2.910034828740951, -1.612121547840817]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.857051179750135, 0.021224421666976113`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.857051179750135`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021224421666976113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "B1", 2, {
              Complex[6.857051179750135, 0.021224421666976113`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.918430095749453, -0.2371236076506873}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.918430095749453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2371236076506873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762483`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B1", 1, {
              Complex[4.918430095749453, -0.2371236076506873], 
              Complex[2.920464719105736, -1.6096433738762483`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.848920543658824, 0.02157624912441265}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.848920543658824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "B1", 2, {
              Complex[6.848920543658824, 0.02157624912441265], 
              Complex[5.145157618862018, -1.156595047683686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.927723158492043, -0.23598247799562702`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.927723158492043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23598247799562702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543907`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B1", 1, {
              Complex[4.927723158492043, -0.23598247799562702`], 
              Complex[2.930911500394467, -1.6071977299543907`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.840779489735858, 0.021936781873947195`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.840779489735858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.021936781873947195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "B1", 2, {
              Complex[6.840779489735858, 0.021936781873947195`], 
              Complex[5.136042207268362, -1.1563665913076093`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.9370215703165, -0.23487062465998587`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9370215703165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23487062465998587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.94137670743742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B1", 1, {
              Complex[4.9370215703165, -0.23487062465998587`], 
              Complex[2.94137670743742, -1.6047844970867333`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.832626638869334, 0.022306351154756456`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.832626638869334`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022306351154756456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "B1", 2, {
              Complex[6.832626638869334, 0.022306351154756456`], 
              Complex[5.126906229415363, -1.1561301764198548`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.946326764964685, -0.2337879757412101}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.946326764964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2337879757412101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.602403587006065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B1", 1, {
              Complex[4.946326764964685, -0.2337879757412101], 
              Complex[2.9518618998259747`, -1.602403587006065]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.824460596435171, 0.022685305540684226`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.824460596435171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022685305540684226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "B1", 2, {
              Complex[6.824460596435171, 0.022685305540684226`], 
              Complex[5.117748090945092, -1.1558854547185569`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.955640194255799, -0.2327344900192291}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.955640194255799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2327344900192291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9623686641736446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6000549429658446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B1", 1, {
              Complex[4.955640194255799, -0.2327344900192291], 
              Complex[2.9623686641736446`, -1.6000549429658446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.816279950289862, 0.023074012099830184`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.816279950289862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023074012099830184`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.108566172536498`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "B1", 2, {
              Complex[6.816279950289862, 0.023074012099830184`], 
              Complex[5.108566172536498, -1.155632058324808]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.9649633300876665`, -0.23171015774841372`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.9649633300876665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23171015774841372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B1", 1, {
              Complex[4.9649633300876665`, -0.23171015774841372`], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.808083268706271, 0.02347285764894464}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.808083268706271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02347285764894464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.155369598409927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "B1", 2, {
              Complex[6.808083268706271, 0.02347285764894464], 
              Complex[5.099358827456356, -1.155369598409927]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.974297666506786, -0.2307150015754329}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.974297666506786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2307150015754329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.98345340448965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B1", 1, {
              Complex[4.974297666506786, -0.2307150015754329], 
              Complex[2.98345340448965, -1.5954543893273736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.799869098244956, 0.023882250111808064`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.799869098244956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023882250111808064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "B1", 2, {
              Complex[6.799869098244956, 0.023882250111808064`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.983644721854632, -0.22974907759194269`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.983644721854632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22974907759194269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.994034710406032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5932025328859931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B1", 1, {
              Complex[4.983644721854632, -0.22974907759194269`], 
              Complex[2.994034710406032, -1.5932025328859931`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.7916359615532285`, 0.024302619991773983`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7916359615532285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.024302619991773983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1548158188904898`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "B1", 2, {
              Complex[6.7916359615532285`, 0.024302619991773983`], 
              Complex[5.080861117956597, -1.1548158188904898`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{4.993006040998135, -0.22881247653229808`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.993006040998135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22881247653229808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.004644253386099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5909830513843417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B1", 1, {
              Complex[4.993006040998135, -0.22881247653229808`], 
              Complex[3.004644253386099, -1.5909830513843417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.783382355083752, 0.024734421969834053`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.783382355083752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969834053`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "B1", 2, {
              Complex[6.783382355083752, 0.024734421969834053`], 
              Complex[5.071567299655017, -1.154523602824754]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.0023831976526285`, -0.22790532512782422`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.0023831976526285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22790532512782422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.015283792410421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5887960625076492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B1", 1, {
              Complex[5.0023831976526285`, -0.22790532512782422`], 
              Complex[3.015283792410421, -1.5887960625076492`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.775106746724161, 0.02517813664084302}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.775106746724161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02517813664084302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.062241141302126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1542205266440744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "B1", 2, {
              Complex[6.775106746724161, 0.02517813664084302], 
              Complex[5.062241141302126, -1.1542205266440744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.011777796806058, -0.2270277876307708}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.011777796806058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2270277876307708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.025955129189635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B1", 1, {
              Complex[5.011777796806058, -0.2270277876307708], 
              Complex[3.025955129189635, -1.586641723319602]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.766807573328626, 0.02563427240203126}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.766807573328626`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02563427240203126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.05288081887921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "B1", 2, {
              Complex[6.766807573328626, 0.02563427240203126], 
              Complex[5.05288081887921, -1.1539060716710015`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.021191477253695, -0.2261800675227632}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.021191477253695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2261800675227632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0366601112360136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5845202322015444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B1", 1, {
              Complex[5.021191477253695, -0.2261800675227632], 
              Complex[3.0366601112360136`, -1.5845202322015444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.7584832381419595`, 0.02610336750958422}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7584832381419595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02610336750958422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.0434844640179035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1535796871411725`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "B1", 2, {
              Complex[6.7584832381419595`, 0.02610336750958422], 
              Complex[5.0434844640179035`, -1.1535796871411725`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.030625914253164, -0.22536240942454472`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.030625914253164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22536240942454472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0474006350962957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5824318310164627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B1", 1, {
              Complex[5.030625914253164, -0.22536240942454472`], 
              Complex[3.0474006350962957`, -1.5824318310164627`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.750132108106198, 0.026585992320966013`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.750132108106198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.026585992320966013`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "B1", 2, {
              Complex[6.750132108106198, 0.026585992320966013`], 
              Complex[5.034050160698049, -1.1532407877189195`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.040082822310154, -0.22457510122598082`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.040082822310154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22457510122598082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.058178649759413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5803768075197013`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B1", 1, {
              Complex[5.040082822310154, -0.22457510122598082`], 
              Complex[3.058178649759413, -1.5803768075197013`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.7417525110391665`, 0.02708275174279656}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7417525110391665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02708275174279656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.152888750780241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "B1", 2, {
              Complex[6.7417525110391665`, 0.02708275174279656], 
              Complex[5.024575941774229, -1.152888750780241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.049563958105735, -0.22381847645779873`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.049563958105735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22381847645779873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.068996160253663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5783554980412644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B1", 1, {
              Complex[5.049563958105735, -0.22381847645779873`], 
              Complex[3.068996160253663, -1.5783554980412644`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.733342732673844, 0.027594287906544456`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.733342732673844`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.027594287906544456`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0150597853162315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.152522913437557`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "B1", 2, {
              Complex[6.733342732673844, 0.027594287906544456`], 
              Complex[5.0150597853162315`, -1.152522913437557]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.059071123576937, -0.22309291692935682`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.059071123576937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22309291692935682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.079855231448904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5763682904678322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B1", 1, {
              Complex[5.059071123576937, -0.22309291692935682`], 
              Complex[3.079855231448904, -1.5763682904678322`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.724901013546819, 0.02812128309705345}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.724901013546819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15214256927739`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "B1", 2, {
              Complex[6.724901013546819, 0.02812128309705345], 
              Complex[5.005499610747705, -1.15214256927739]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.068606169162741, -0.22239885565995454`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.068606169162741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5744156275563803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B1", 1, {
              Complex[5.068606169162741, -0.22239885565995454`], 
              Complex[3.0907579920802744`, -1.5744156275563803`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.716425545723422, 0.02866446296210377}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.716425545723422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02866446296210377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.995893274766249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "B1", 2, {
              Complex[6.716425545723422, 0.02866446296210377], 
              Complex[4.995893274766249, -1.151746964778438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.078170997228454, -0.22173678013483544`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.078170997228454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22173678013483544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5724980106155328`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B1", 1, {
              Complex[5.078170997228454, -0.22173678013483544`], 
              Complex[3.1017066390111174`, -1.5724980106155328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.707914469346525, 0.029224600034819193`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.707914469346525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819193`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.9862385670271525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1513352953732714`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "B1", 2, {
              Complex[6.707914469346525, 0.029224600034819193`], 
              Complex[4.9862385670271525`, -1.1513352953732714`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.087767565681953, -0.22110723592124715`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.087767565681953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22110723592124715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B1", 1, {
              Complex[5.087767565681953, -0.22110723592124715`], 
              Complex[3.112703441753819, -1.5706160035957248`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.699365868995314, 0.02980251760487493}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.699365868995314`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02980251760487493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "B1", 2, {
              Complex[6.699365868995314, 0.02980251760487493], 
              Complex[4.976533205571878, -1.1509067011120153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.097397891796026, -0.2205108306846836}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.097397891796026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2205108306846836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.568770237634814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B1", 1, {
              Complex[5.097397891796026, -0.2205108306846836], 
              Complex[3.123750747268463, -1.568770237634814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.6907777698397455`, 0.030399093979211252`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6907777698397455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "B1", 2, {
              Complex[6.6907777698397455`, 0.030399093979211252`], 
              Complex[4.966774831981249, -1.1504602618808102`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.107064056251541, -0.21994823865093072`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.107064056251541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865093072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5669614161122616`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B1", 1, {
              Complex[5.107064056251541, -0.21994823865093072`], 
              Complex[3.1348509850602837`, -1.5669614161122616`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.682148133575791, 0.03101526717841391}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.682148133575791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03101526717841391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "B1", 2, {
              Complex[6.682148133575791, 0.03101526717841391], 
              Complex[4.956961006232221, -1.149994992121425]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.116768207416752, -0.21942020556585193`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.116768207416752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21942020556585193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.146006672598035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.565190320272424`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B1", 1, {
              Complex[5.116768207416752, -0.21942020556585193`], 
              Complex[3.146006672598035, -1.565190320272424]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.673474854126102, 0.031652040121196295`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.673474854126102`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196295`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "B1", 2, {
              Complex[6.673474854126102, 0.031652040121196295`], 
              Complex[4.947089201235956, -1.149509834990993]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.126512565878383, -0.21892755421211518`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.126512565878383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21892755421211518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1572204210764307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5634578154860739`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B1", 1, {
              Complex[5.126512565878383, -0.21892755421211518`], 
              Complex[3.1572204210764307`, -1.5634578154860739`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.664755753090322, 0.03231048635665902}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.664755753090322`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03231048635665902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "B1", 2, {
              Complex[6.664755753090322, 0.03231048635665902], 
              Complex[4.937156797033987, -1.1490036558923018`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1362994292403545`, -0.21847119055042014`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1362994292403545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1684949415466477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B1", 1, {
              Complex[5.1362994292403545`, -0.21847119055042014`], 
              Complex[3.1684949415466477`, -1.561764858229167]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.655988574929111, 0.03299175641235}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.655988574929111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03299175641235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "B1", 2, {
              Complex[6.655988574929111, 0.03299175641235], 
              Complex[4.927161074628285, -1.1484752352951793`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1461311772059295`, -0.21805211056251345`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1461311772059295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21805211056251345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B1", 1, {
              Complex[5.1461311772059295`, -0.21805211056251345`], 
              Complex[3.179833051439644, -1.5601125038693657`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.647170981866, 0.03369708483581625}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.647170981866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "B1", 2, {
              Complex[6.647170981866, 0.03369708483581625], 
              Complex[4.917099209420432, -1.1479232607580627`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.156010276958656, -0.21767140788446362`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.156010276958656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1912376815073618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B1", 1, {
              Complex[5.156010276958656, -0.21767140788446362`], 
              Complex[3.1912376815073618`, -1.5585019153641586`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.6383005484916495`, 0.03442779801852971}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.6383005484916495`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.906968264234699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "B1", 2, {
              Complex[6.6383005484916495`, 0.03442779801852971], 
              Complex[4.906968264234699, -1.147346318045541]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.1659392888564994`, -0.2173302823316979}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.1659392888564994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2173302823316979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5569343729898855`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B1", 1, {
              Complex[5.1659392888564994`, -0.2173302823316979], 
              Complex[3.2027118832068138`, -1.5569343729898855`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.629374756056008, 0.03518532290406068}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.629374756056008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03518532290406068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.896765181899933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "B1", 2, {
              Complex[6.629374756056008, 0.03518532290406068], 
              Complex[4.896765181899933, -1.1467428812221825`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.175920872451979, -0.21703004943242454`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.175920872451979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21703004943242454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.214258836551336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.555411285239044`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B1", 1, {
              Complex[5.175920872451979, -0.21703004943242454`], 
              Complex[3.214258836551336, -1.555411285239044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.620390986435504, 0.03597119669747851}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.620390986435504`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.146111301584947`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "B1", 2, {
              Complex[6.620390986435504, 0.03597119669747851], 
              Complex[4.886486777365879, -1.146111301584947]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.185957792848567, -0.21677215110365716`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.185957792848567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21677215110365716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.553934201044293`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B1", 1, {
              Complex[5.185957792848567, -0.21677215110365716`], 
              Complex[3.225881858451649, -1.553934201044293]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.611346515764966, 0.03678707771053715}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.611346515764966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03678707771053715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8761297293312476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1454497952754268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "B1", 2, {
              Complex[6.611346515764966, 0.03678707771053715], 
              Complex[4.8761297293312476`, -1.1454497952754268`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.196052927399868, -0.21655816762459845`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.196052927399868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21655816762459845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.237584411566567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.552504823512188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B1", 1, {
              Complex[5.196052927399868, -0.21655816762459845`], 
              Complex[3.237584411566567, -1.552504823512188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.60223850772765, 0.037634757497710766`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.60223850772765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.037634757497710766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.86569057136354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "B1", 2, {
              Complex[6.60223850772765, 0.037634757497710766`], 
              Complex[4.86569057136354, -1.1447564293886006`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.206209272752708, -0.2163898310860751}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.206209272752708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2163898310860751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B1", 1, {
              Complex[5.206209272752708, -0.2163898310860751], 
              Complex[3.2493701136786943`, -1.5511250253784865`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.593064006502223, 0.038516174462077585`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.593064006502223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.038516174462077585`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.855165682495278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1440291063659584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "B1", 2, {
              Complex[6.593064006502223, 0.038516174462077585`], 
              Complex[4.855165682495278, -1.1440291063659584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.216429952227797, -0.21626904052272788`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.216429952227797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21626904052272788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2612427476037635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B1", 1, {
              Complex[5.216429952227797, -0.21626904052272788`], 
              Complex[3.2612427476037635`, -1.5497968664306097`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.58381992937299, 0.03943342913804175}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.58381992937299`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "B1", 2, {
              Complex[6.58381992937299, 0.03943342913804175], 
              Complex[4.844551277287892, -1.1432655464271397`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.226718223521198, -0.2161978789674424}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.226718223521198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2161978789674424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.273206271632577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5485226131825387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B1", 1, {
              Complex[5.226718223521198, -0.2161978789674424], 
              Complex[3.273206271632577, -1.5485226131825387`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.574503059020016, 0.040388801390635574`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.574503059020016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.040388801390635574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1424632677545632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "B1", 2, {
              Complex[6.574503059020016, 0.040388801390635574`], 
              Complex[4.833843395364207, -1.1424632677545632`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.237077486695947, -0.21617863270584659`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.237077486695947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21617863270584659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B1", 1, {
              Complex[5.237077486695947, -0.21617863270584659`], 
              Complex[3.2852648304909686`, -1.5473047611339115`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.565110035519868, 0.04138476980950452}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.565110035519868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950452`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1416195640990143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "B1", 2, {
              Complex[6.565110035519868, 0.04138476980950452], 
              Complex[4.823037890424123, -1.1416195640990143`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.247511292414014, -0.21621381305374007`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.247511292414014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21621381305374007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B1", 1, {
              Complex[5.247511292414014, -0.21621381305374007`], 
              Complex[3.297422766784157, -1.5461460599999748`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.555637348106621, 0.04242403362064838}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.555637348106621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04242403362064838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "B1", 2, {
              Complex[6.555637348106621, 0.04242403362064838], 
              Complex[4.812130418776984, -1.1407314794193455`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.258023350333589, -0.21630618103294588`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.258023350333589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5450495423633641`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B1", 1, {
              Complex[5.258023350333589, -0.21630618103294588`], 
              Complex[3.3096846328660456`, -1.5450495423633641`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.546081326768186, 0.04350953749168187}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.546081326768186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04350953749168187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050335`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "B1", 2, {
              Complex[6.546081326768186, 0.04350953749168187], 
              Complex[4.801116427450052, -1.1397957791050335`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.268617537562701, -0.21645877538292138`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.268617537562701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.32205520303872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5440185562746336`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B1", 1, {
              Complex[5.268617537562701, -0.21645877538292138`], 
              Complex[3.32205520303872, -1.5440185562746336`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.536438133786874, 0.04464449966811444}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.536438133786874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04464449966811444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545461`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "B1", 2, {
              Complex[6.536438133786874, 0.04464449966811444], 
              Complex[4.78999114196779, -1.1388089172545461`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.279297907015237, -0.2166749444176823}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.279297907015237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2166749444176823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.334539485939789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B1", 1, {
              Complex[5.279297907015237, -0.2166749444176823], 
              Complex[3.334539485939789, -1.5430568024175473`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.526703755378124, 0.045832443950467455`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.526703755378124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.045832443950467455`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "B1", 2, {
              Complex[6.526703755378124, 0.045832443950467455`], 
              Complex[4.778749553944275, -1.1377669993932322`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.29006869545568, -0.21695838232209166`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.29006869545568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21695838232209166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.34714273691111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5421683765599403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B1", 1, {
              Complex[5.29006869545568, -0.21695838232209166`], 
              Complex[3.34714273691111, -1.5421683765599403`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.516873993640987, 0.047077236106415926`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.516873993640987`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.047077236106415926`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.136665739909799`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "B1", 2, {
              Complex[6.516873993640987, 0.047077236106415926`], 
              Complex[4.767386408695089, -1.136665739909799]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.300934330939945, -0.21731317057992383`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.300934330939945`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3598704700566717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B1", 1, {
              Complex[5.300934330939945, -0.21731317057992383`], 
              Complex[3.3598704700566717`, -1.5413578181336938`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.50694445911303, 0.04838312541060556}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.50694445911303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.75589619316095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676139`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "B1", 2, {
              Complex[6.50694445911303, 0.04838312541060556], 
              Complex[4.75589619316095, -1.1355004133676139`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.311899439255096, -0.21774382534019754`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.311899439255096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307426`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B1", 1, {
              Complex[5.311899439255096, -0.21774382534019754`], 
              Complex[3.3727284695824955`, -1.5406301659307426`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.496910564326778, 0.04975479211876483}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496910564326778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04975479211876483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "B1", 2, {
              Complex[6.496910564326778, 0.04975479211876483], 
              Complex[4.744273124550122, -1.1342657987037834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.322968848822688, -0.21825535165974055`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.322968848822688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21825535165974055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.385722799858257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5399910220686344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B1", 1, {
              Complex[5.322968848822688, -0.21825535165974055`], 
              Complex[3.385722799858257, -1.5399910220686344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.486767518902965, 0.0511974018142995}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.486767518902965`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.732511140259881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1329561151622733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "B1", 2, {
              Complex[6.486767518902965, 0.0511974018142995], 
              Complex[4.732511140259881, -1.1329561151622733`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.334147593347899, -0.21885330570991693`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.334147593347899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21885330570991693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B1", 1, {
              Complex[5.334147593347899, -0.21885330570991693`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.476510326898408, 0.05271666771536847}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.476510326898408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05271666771536847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.720603889841738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "B1", 2, {
              Complex[6.476510326898408, 0.05271666771536847], 
              Complex[4.720603889841738, -1.1315649486154922`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.34544091125561, -0.21954386620430968`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.34544091125561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21954386620430968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B1", 1, {
              Complex[5.34544091125561, -0.21954386620430968`], 
              Complex[3.4121461559885464`, -1.5390039371286068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.466133787367247, 0.05431892219952709}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.466133787367247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05431892219952709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "B1", 2, {
              Complex[6.466133787367247, 0.05431892219952709], 
              Complex[4.70854473004717, -1.130085166709498]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.356854240636268, -0.2203339164903332}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.356854240636268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2203339164903332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.425588766769954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386707368477481`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B1", 1, {
              Complex[5.356854240636268, -0.2203339164903332], 
              Complex[3.425588766769954, -1.5386707368477481`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.4556324994128165`, 0.05601119898888104}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.4556324994128165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05601119898888104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1285088210227605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "B1", 2, {
              Complex[6.4556324994128165`, 0.05601119898888104], 
              Complex[4.696326724353139, -1.1285088210227605`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.36839320800425, -0.2212311389467491}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.36839320800425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2212311389467491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538455737070505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B1", 1, {
              Complex[5.36839320800425, -0.2212311389467491], 
              Complex[3.4391948727143986`, -1.538455737070505]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.445000873427293, 0.05780132763801389}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.445000873427293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05780132763801389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.68394264884831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "B1", 2, {
              Complex[6.445000873427293, 0.05780132763801389], 
              Complex[4.68394264884831, -1.1268270341592392`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.380063608617472, -0.22224412353114406`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.380063608617472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22224412353114406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232324`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B1", 1, {
              Complex[5.380063608617472, -0.22224412353114406`], 
              Complex[3.452971973654926, -1.5383687126232324`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.434233150770422, 0.05969804216878785}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.434233150770422`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05969804216878785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.671385007001144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "B1", 2, {
              Complex[6.434233150770422, 0.05969804216878785], 
              Complex[4.671385007001144, -1.1250298694138172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.39187137537774, -0.22338249250843517`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.39187137537774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B1", 1, {
              Complex[5.39187137537774, -0.22338249250843517`], 
              Complex[3.466927815290494, -1.5384206511375544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.423323434867788, 0.061711105883242766`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.423323434867788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.061711105883242766`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "B1", 2, {
              Complex[6.423323434867788, 0.061711105883242766`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.403822532373675, -0.2246570435317341}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.403822532373675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2246570435317341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.481070345408924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5386239263253454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B1", 1, {
              Complex[5.403822532373675, -0.2246570435317341], 
              Complex[3.481070345408924, -1.5386239263253454`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.412265737666768, 0.06385145452602968}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.412265737666768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "B1", 2, {
              Complex[6.412265737666768, 0.06385145452602968], 
              Complex[4.645717853916904, -1.1210434375401022`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.415923127875931, -0.22607991328743238`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.415923127875931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B1", 1, {
              Complex[5.415923127875931, -0.22607991328743238`], 
              Complex[3.49540764739327, -1.538992497237254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.401054046640449, 0.06613136000835822}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.401054046640449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06613136000835822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.632592319391073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1188275290397078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "B1", 2, {
              Complex[6.401054046640449, 0.06613136000835822], 
              Complex[4.632592319391073, -1.1188275290397078`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.428179139967114, -0.22766476377118722`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.428179139967114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22766476377118722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B1", 1, {
              Complex[5.428179139967114, -0.22766476377118722`], 
              Complex[3.5099478431009343`, -1.5395421364907365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.389682419157071, 0.06856461676025156}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.389682419157071`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06856461676025156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748182`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "B1", 2, {
              Complex[6.389682419157071, 0.06856461676025156], 
              Complex[4.619261335536663, -1.1164425322748182`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.440596345893878, -0.22942699279424578`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.440596345893878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22942699279424578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5246989546875493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5402906900657307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B1", 1, {
              Complex[5.440596345893878, -0.22942699279424578`], 
              Complex[3.5246989546875493`, -1.5402906900657307`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.378145113127533, 0.07116675231062962}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.378145113127533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "B1", 2, {
              Complex[6.378145113127533, 0.07116675231062962], 
              Complex[4.605716884708898, -1.1138704540789914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.453180143569079, -0.23138396931833927`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.453180143569079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5396687117196883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B1", 1, {
              Complex[5.453180143569079, -0.23138396931833927`], 
              Complex[3.5396687117196883`, -1.54125837029078]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.3664367655030105`, 0.07395526269357508}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.3664367655030105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.111090937656241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "B1", 2, {
              Complex[6.3664367655030105`, 0.07395526269357508], 
              Complex[4.591951242060748, -1.111090937656241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.465935310345424, -0.23355529236003053`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.465935310345424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23355529236003053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B1", 1, {
              Complex[5.465935310345424, -0.23355529236003053`], 
              Complex[3.554864285859266, -1.5424680817046266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.354552633501294, 0.07694987142174026}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.354552633501294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142174026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.108080936651698`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "B1", 2, {
              Complex[6.354552633501294, 0.07694987142174026], 
              Complex[4.577957240848536, -1.108080936651698]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.478865680202783, -0.23596306901323125`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.478865680202783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23596306901323125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.570291930439357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5439457760136326`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B1", 1, {
              Complex[5.478865680202783, -0.23596306901323125`], 
              Complex[3.570291930439357, -1.5439457760136326`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.342488917419652, 0.08017280757570108}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.342488917419652`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08017280757570108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.56372863284657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285865`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "B1", 2, {
              Complex[6.342488917419652, 0.08017280757570108], 
              Complex[4.56372863284657, -1.1048143601285865`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.491973715947518, -0.2386322019223144}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.491973715947518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2386322019223144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B1", 1, {
              Complex[5.491973715947518, -0.2386322019223144], 
              Complex[3.5859564964599846`, -1.545720826549354]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.330243188435803, 0.08364909334179328}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.330243188435803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "B1", 2, {
              Complex[6.330243188435803, 0.08364909334179328], 
              Complex[4.549260572342168, -1.1012616980470773`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5052599482994165`, -0.2415906683469046}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5052599482994165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2415906683469046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.601860790294313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5478264033073161`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B1", 1, {
              Complex[5.5052599482994165`, -0.2415906683469046], 
              Complex[3.601860790294313, -1.5478264033073161`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.317814949521482, 0.08740682313953926}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.317814949521482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "B1", 2, {
              Complex[6.317814949521482, 0.08740682313953926], 
              Complex[4.534550258420687, -1.0973896461639485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.518722249741511, -0.24486976056502427`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.518722249741511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24486976056502427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929646`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B1", 1, {
              Complex[5.518722249741511, -0.24486976056502427`], 
              Complex[3.6180047326806664`, -1.5502998152929646`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.30520636159325, 0.09147740408549994}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.30520636159325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09147740408549994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0931607636269258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "B1", 2, {
              Complex[6.30520636159325, 0.09147740408549994], 
              Complex[4.519597775965093, -1.0931607636269258`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.532354909525623, -0.24850423935263424`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.532354909525623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B1", 1, {
              Complex[5.532354909525623, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.292423168507697, 0.09589570953158878}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.292423168507697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.09589570953158878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "B1", 2, {
              Complex[6.292423168507697, 0.09589570953158878], 
              Complex[4.504407178973381, -1.0885332177365608`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.546147480479421, -0.25253232740394727`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.546147480479421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.650990035081118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.556521435684903`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B1", 1, {
              Complex[5.546147480479421, -0.25253232740394727`], 
              Complex[3.650990035081118, -1.556521435684903]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.279475850255287, 0.10070007254234241`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.279475850255287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "B1", 2, {
              Complex[6.279475850255287, 0.10070007254234241`], 
              Complex[4.488987856730723, -1.083460700125328]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.560083383502212, -0.2569954375693105}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.560083383502212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2569954375693105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.667805619167921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B1", 1, {
              Complex[5.560083383502212, -0.2569954375693105], 
              Complex[3.667805619167921, -1.560366273382241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.266381018465571, 0.10593201418800262`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.266381018465571`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10593201418800262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "B1", 2, {
              Complex[6.266381018465571, 0.10593201418800262`], 
              Complex[4.473356207864623, -1.0778926376684699`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5741382895514295`, -0.26193749411720274`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5741382895514295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B1", 1, {
              Complex[5.5741382895514295`, -0.26193749411720274`], 
              Complex[3.6848056561525757`, -1.564771318831328]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.2531630344218, 0.11163556486001082`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2531630344218`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11163556486001082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.457537610074803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0717748675240166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "B1", 2, {
              Complex[6.2531630344218, 0.11163556486001082`], 
              Complex[4.457537610074803, -1.0717748675240166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.5882783610426285`, -0.267403671805992}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5882783610426285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.267403671805992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5697928508801484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B1", 1, {
              Complex[5.5882783610426285`, -0.267403671805992], 
              Complex[3.7019536132591457`, -1.5697928508801484`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.23985576766216, 0.11785600339462998`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.23985576766216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339462998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.065050990167949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "B1", 2, {
              Complex[6.23985576766216, 0.11785600339462998`], 
              Complex[4.44156860245767, -1.065050990167949]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{4.976967927486167, 0.006887727487396918}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.976967927486167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006887727487396918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.478753355849043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D1", 1, {
              Complex[4.976967927486167, 0.006887727487396918], 
              Complex[6.478753355849043, -1.1631402225643317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.398301539299036, -0.01324317030169907}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.398301539299036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D1", 2, {
              Complex[7.398301539299036, -0.01324317030169907], 
              Complex[8.80001605246603, -1.1961486271318056`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.020988084142068, 0.007042959985368871}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.020988084142068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985368871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.52215878639839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630554690196362`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D1", 1, {
              Complex[5.020988084142068, 0.007042959985368871], 
              Complex[6.52215878639839, -1.1630554690196362`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.352914113679207, -0.013509876715323901`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.352914113679207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323901`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D1", 2, {
              Complex[7.352914113679207, -0.013509876715323901`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.05739532427709, 0.007197843246654808}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.05739532427709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654808`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D1", 1, {
              Complex[5.05739532427709, 0.007197843246654808], 
              Complex[6.557943371421671, -1.162972548762566]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.315449803449272, -0.01375104485251276}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.315449803449272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01375104485251276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.718101741665087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "D1", 2, {
              Complex[7.315449803449272, -0.01375104485251276], 
              Complex[8.718101741665087, -1.1964748219538675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.089412494295966, 0.007354951961001998}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.089412494295966`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007354951961001998`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5893300788606926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.16288887895032`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D1", 1, {
              Complex[5.089412494295966, 0.007354951961001998], 
              Complex[6.5893300788606926`, -1.16288887895032]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.282554763488937, -0.01397986959845826}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.282554763488937`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01397986959845826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196609721074035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D1", 2, {
              Complex[7.282554763488937, -0.01397986959845826], 
              Complex[8.685690080337723, -1.196609721074035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.118506250669166, 0.007515591774090762}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.118506250669166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090762`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628031728636479`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D1", 1, {
              Complex[5.118506250669166, 0.007515591774090762], 
              Complex[6.61778553109412, -1.1628031728636479`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.252703058118813, -0.014202465960727835`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.252703058118813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960727835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "D1", 2, {
              Complex[7.252703058118813, -0.014202465960727835`], 
              Complex[8.656331133890319, -1.1967364397628115`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.145491825926181, 0.007680628289980853}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.145491825926181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289980853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627145990756098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D1", 1, {
              Complex[5.145491825926181, 0.007680628289980853], 
              Complex[6.644124842294816, -1.1627145990756098`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.225046713694154, -0.01442235766034999}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.225046713694154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01442235766034999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1968585230000408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D1", 2, {
              Complex[7.225046713694154, -0.01442235766034999], 
              Complex[8.629176867782464, -1.1968585230000408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.170878634413056, 0.007850743160533592}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.170878634413056`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007850743160533592`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.668857252414806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162622520798364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D1", 1, {
              Complex[5.170878634413056, 0.007850743160533592], 
              Complex[6.668857252414806, -1.162622520798364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.199056007873823, -0.014641876121436175`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.199056007873823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014641876121436175`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D1", 2, {
              Complex[7.199056007873823, -0.014641876121436175`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.19501091123548, 0.00802653852897203}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.19501091123548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D1", 1, {
              Complex[5.19501091123548, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.174373102447971, -0.014862729232274653`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.174373102447971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014862729232274653`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "D1", 2, {
              Complex[7.174373102447971, -0.014862729232274653`], 
              Complex[8.579535601926914, -1.1970974543173976`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.2181348551047995`, 0.008208588338762854}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.2181348551047995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008208588338762854`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.7147793676173775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624256923931877`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D1", 1, {
              Complex[5.2181348551047995`, 0.008208588338762854], 
              Complex[6.7147793676173775`, -1.1624256923931877`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{7.1507421714555965`, -0.015086273942248003`}],
            
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1507421714555965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015086273942248003`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.556435217312076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D1", 2, {
              Complex[7.1507421714555965`, -0.015086273942248003`], 
              Complex[8.556435217312076, -1.197217311276035]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.240434389619399, 0.00839746770183686}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.240434389619399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00839746770183686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D1", 1, {
              Complex[5.240434389619399, 0.00839746770183686], 
              Complex[6.736398653893472, -1.1623199234705248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.127972189674163, -0.015313663264596189`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.127972189674163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015313663264596189`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "D1", 2, {
              Complex[7.127972189674163, -0.015313663264596189`], 
              Complex[8.534205636043778, -1.1973389757687458`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.262051805853028, 0.008593772293729816}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.262051805853028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729816`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D1", 1, {
              Complex[5.262051805853028, 0.008593772293729816], 
              Complex[6.757326609412582, -1.1622085635431993`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{7.1059154551031405`, -0.015545933419028879`}],
            
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.1059154551031405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.015545933419028879`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.512699415121855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "D1", 2, {
              Complex[7.1059154551031405`, -0.015545933419028879`], 
              Complex[8.512699415121855, -1.1974634260014825`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.283100441464033, 0.008798133065178963}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.283100441464033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008798133065178963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D1", 1, {
              Complex[5.283100441464033, 0.008798133065178963], 
              Complex[6.777676219425206, -1.1620910662296873`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.084454398670628, -0.015784060035230123`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.084454398670628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015784060035230123`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D1", 2, {
              Complex[7.084454398670628, -0.015784060035230123`], 
              Complex[8.491799285559544, -1.1975915689762857`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.303672866164795, 0.009011228909084937}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.303672866164795`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084937`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D1", 1, {
              Complex[5.303672866164795, 0.009011228909084937], 
              Complex[6.797539667322055, -1.161966845801127]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.063493070122277, -0.01602899750358731}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.063493070122277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01602899750358731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "D1", 2, {
              Complex[7.063493070122277, -0.01602899750358731], 
              Complex[8.471409637754663, -1.1977242798043068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.323846388854408, 0.00923379877093513}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.323846388854408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00923379877093513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.816993839756789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D1", 1, {
              Complex[5.323846388854408, 0.00923379877093513], 
              Complex[6.816993839756789, -1.161835265847092]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.042951411025012, -0.016281708942805718`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.042951411025012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016281708942805718`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D1", 2, {
              Complex[7.042951411025012, -0.016281708942805718`], 
              Complex[8.451450795228002, -1.1978624312936874`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.343686896016404, 0.009466654168547547}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.343686896016404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547547`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D1", 1, {
              Complex[5.343686896016404, 0.009466654168547547], 
              Complex[6.836104162316992, -1.1616956277315165`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.022761264330782, -0.01654319107188898}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.022761264330782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01654319107188898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "D1", 2, {
              Complex[7.022761264330782, -0.01654319107188898], 
              Complex[8.431855025955324, -1.1980069181435884`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.363251612071681, 0.009710692858210855}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.363251612071681`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185315`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D1", 1, {
              Complex[5.363251612071681, 0.009710692858210855], 
              Complex[6.854927356440139, -1.1615471581185315`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{7.002863505905769, -0.016814496662831985`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.002863505905769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016814496662831985`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198158678433355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "D1", 2, {
              Complex[7.002863505905769, -0.016814496662831985`], 
              Complex[8.412563676597296, -1.198158678433355]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.382591142510598, 0.009966914310096187}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.382591142510598`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009966914310096187`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.873513478358427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D1", 1, {
              Complex[5.382591142510598, 0.009966914310096187], 
              Complex[6.873513478358427, -1.1613889949346565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.983205922649462, -0.017096756417673678`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.983205922649462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017096756417673678`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.39352505422987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405294`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D1", 2, {
              Complex[6.983205922649462, -0.017096756417673678`], 
              Complex[8.39352505422987, -1.1983187142405294`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.401751028707841, 0.010236437677199473`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.401751028707841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010236437677199473`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D1", 1, {
              Complex[5.401751028707841, 0.010236437677199473`], 
              Complex[6.891907468896068, -1.161220171125207]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.963741599119119, -0.017391201699304113`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.963741599119119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.017391201699304113`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.198488112788141`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "D1", 2, {
              Complex[6.963741599119119, -0.017391201699304113`], 
              Complex[8.374692817528384, -1.198488112788141]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.4207729647332625`, 0.010520523036427932`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.4207729647332625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010520523036427932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D1", 1, {
              Complex[5.4207729647332625`, 0.010520523036427932`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.944427656372562, -0.01769918937958054}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.944427656372562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01769918937958054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D1", 2, {
              Complex[6.944427656372562, -0.01769918937958054], 
              Complex[8.356024721208028, -1.1986680693372453`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.439695778207934, 0.010820596844492497`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.439695778207934`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D1", 1, {
              Complex[5.439695778207934, 0.010820596844492497`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.925224236986869, -0.01802223007164421}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.925224236986869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01802223007164421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.33748160781912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "D1", 2, {
              Complex[6.925224236986869, -0.01802223007164421], 
              Complex[8.33748160781912, -1.1988599130234303`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.458556246931596, 0.011138282794836883`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.458556246931596`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836883`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D1", 1, {
              Complex[5.458556246931596, 0.011138282794836883`], 
              Complex[6.946333169123367, -1.1606380604240905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.906093661793765, -0.01836202115462416}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.906093661793765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01836202115462416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D1", 2, {
              Complex[6.906093661793765, -0.01836202115462416], 
              Complex[8.319026572634915, -1.199065136952576]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.47738980371477, 0.011475439606775242`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.47738980371477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775242`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D1", 1, {
              Complex[5.47738980371477, 0.011475439606775242`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.886999703988066, -0.01872048627707082}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.886999703988066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01872048627707082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.30062424755183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D1", 2, {
              Complex[6.886999703988066, -0.01872048627707082], 
              Complex[8.30062424755183, -1.1992854341178674`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.496231169626781, 0.011834207760463395`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.496231169626781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463395`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601721705348451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D1", 1, {
              Complex[5.496231169626781, 0.011834207760463395`], 
              Complex[6.982345361327388, -1.1601721705348451`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.867906939037359, -0.019099823463292427`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.867906939037359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019099823463292427`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199522741096495`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "D1", 2, {
              Complex[6.867906939037359, -0.019099823463292427`], 
              Complex[8.28224016277643, -1.199522741096495]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.515114948423251, 0.012217067867222332`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.515114948423251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222332`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.00037192564026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D1", 1, {
              Complex[5.515114948423251, 0.012217067867222332`], 
              Complex[7.00037192564026, -1.1599101980783053`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           
           TooltipBox[PointBox[{6.8487801366438275`, -0.019502564592186727`}],
            
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.8487801366438275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019502564592186727`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.263840153003091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199779292073964`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D1", 2, {
              Complex[6.8487801366438275`, -0.019502564592186727`], 
              Complex[8.263840153003091, -1.199779292073964]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.5340762109349875`, 0.012626914319474934`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.5340762109349875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.012626914319474934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D1", 1, {
              Complex[5.5340762109349875`, 0.012626914319474934`], 
              Complex[7.018457172595782, -1.1596255988326747`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.829583665251546, -0.019931649951741116`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.829583665251546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741116`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004602`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D1", 2, {
              Complex[6.829583665251546, -0.019931649951741116`], 
              Complex[8.24538977916942, -1.2000576866004602`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.553151097008939, 0.013067149229433903`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.553151097008939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433903`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D1", 1, {
              Complex[5.553151097008939, 0.013067149229433903`], 
              Complex[7.036635886648769, -1.1593153672755068`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.810280880968052, -0.020390522922278664`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.810280880968052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.200360975725519`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D1", 2, {
              Complex[6.810280880968052, -0.020390522922278664`], 
              Complex[8.226853738441678, -1.200360975725519]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.57237746397503, 0.013541803645186435`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.57237746397503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186435`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D1", 1, {
              Complex[5.57237746397503, 0.013541803645186435`], 
              Complex[7.054944396120724, -1.1589759311366727`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.790833471518203, -0.020883251810279654`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.790833471518203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279654`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D1", 2, {
              Complex[6.790833471518203, -0.020883251810279654`], 
              Complex[8.208195234091122, -1.2006927729717154`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.591795614755318, 0.014055695951277704`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.591795614755318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277704`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D1", 1, {
              Complex[5.591795614755318, 0.014055695951277704`], 
              Complex[7.073421269042283, -1.158603006979818]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.771200721802021, -0.021414688765245018`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.771200721802021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021414688765245018`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "D1", 2, {
              Complex[6.771200721802021, -0.021414688765245018`], 
              Complex[8.18937527323683, -1.2010573992945919`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.611449146258794, 0.014614641743299664`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.611449146258794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299664`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.0921081211151265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1581914085205158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D1", 1, {
              Complex[5.611449146258794, 0.014614641743299664`], 
              Complex[7.0921081211151265`, -1.1581914085205158`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.751338660172414, -0.021990680088691934`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.751338660172414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484787`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208562`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "D1", 2, {
              Complex[6.751338660172414, -0.021990680088691934`], 
              Complex[8.170351853484787, -1.2014600752208562`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.631385970822487, 0.015225736181981623`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.631385970822487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981623`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1577347882945952`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D1", 1, {
              Complex[5.631385970822487, 0.015225736181981623`], 
              Complex[7.111050585905176, -1.1577347882945952`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.731199032484283, -0.022618348956057268`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.731199032484283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.022618348956057268`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.151078988162068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "D1", 2, {
              Complex[6.731199032484283, -0.022618348956057268`], 
              Complex[8.151078988162068, -1.201907179567137]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.651659582251507, 0.0158977403597609}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.651659582251507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0158977403597609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157225283537514`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D1", 1, {
              Complex[5.651659582251507, 0.0158977403597609], 
              Complex[7.130299515097565, -1.157225283537514]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.7107280322146305`, -0.02330648209651286}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.7107280322146305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02330648209651286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202406603890853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D1", 2, {
              Complex[6.7107280322146305`, -0.02330648209651286], 
              Complex[8.13150550216652, -1.202406603890853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.6723306669868805`, 0.016641620135819466`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6723306669868805`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.016641620135819466`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D1", 1, {
              Complex[5.6723306669868805`, 0.016641620135819466`], 
              Complex[7.149912504017515, -1.1566530214405544`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.689864686007544, -0.024066068896217683`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.689864686007544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024066068896217683`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D1", 2, {
              Complex[6.689864686007544, -0.024066068896217683`], 
              Complex[8.11157350310953, -1.202968247517296]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.693469206036438, 0.01747131387776226}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.693469206036438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01747131387776226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.169955880282914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D1", 1, {
              Complex[5.693469206036438, 0.01747131387776226], 
              Complex[7.169955880282914, -1.1560054129682458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.668538748914897, -0.024911069370827682`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.668538748914897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.024911069370827682`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "D1", 2, {
              Complex[6.668538748914897, -0.024911069370827682`], 
              Complex[8.09121638979124, -1.2036047239664331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.715157284805061, 0.018404853311322064`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.715157284805061`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018404853311322064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D1", 1, {
              Complex[5.715157284805061, 0.018404853311322064`], 
              Complex[7.190507361138085, -1.1552661200223417`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.646667892120967, -0.025859535214795407`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.646667892120967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.025859535214795407`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D1", 2, {
              Complex[6.646667892120967, -0.025859535214795407`], 
              Complex[8.070356192382524, -1.2043323940004822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.737492944039841, 0.019466046203823834`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.737492944039841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823834`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D1", 1, {
              Complex[5.737492944039841, 0.019466046203823834`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.624153849873985, -0.02693529265819097}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.624153849873985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "D1", 2, {
              Complex[6.624153849873985, -0.02693529265819097], 
              Complex[8.048899928737553, -1.2051729191751688`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.76059559895939, 0.020687085496539206`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.76059559895939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539206`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.23352578639705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D1", 1, {
              Complex[5.76059559895939, 0.020687085496539206`], 
              Complex[7.23352578639705, -1.1534182031380908`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.600876998505349, -0.028170551750252844`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.600876998505349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750252844`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293858`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D1", 2, {
              Complex[6.600876998505349, -0.028170551750252844`], 
              Complex[8.026734477486405, -1.2061556750293858`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.78461388785291, 0.022112751073540098`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.78461388785291`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.022112751073540098`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053032`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D1", 1, {
              Complex[5.78461388785291, 0.022112751073540098`], 
              Complex[7.256246121108593, -1.1522392586053032`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5766885062096785`, -0.02961010826063084}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5766885062096785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.02961010826063084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878654`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D1", 2, {
              Complex[6.5766885062096785`, -0.02961010826063084], 
              Complex[8.003719151417389, -1.2073216443878654`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.809737407862617, 0.023807487220115758`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809737407862617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115758`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D1", 1, {
              Complex[5.809737407862617, 0.023807487220115758`], 
              Complex[7.279999873987635, -1.1508175252699346`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5513985958381715`, -0.03131842125415489}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5513985958381715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03131842125415489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "D1", 2, {
              Complex[6.5513985958381715`, -0.03131842125415489], 
              Complex[7.979674588033218, -1.2087299874638697`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.836214897718771, 0.02586798658403449}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.836214897718771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02586798658403449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.3050221318566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295195`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D1", 1, {
              Complex[5.836214897718771, 0.02586798658403449], 
              Complex[7.3050221318566, -1.1490639772295195`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.5247583609077076`, -0.03339219715471046}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.5247583609077076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.03339219715471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661469`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D1", 2, {
              Complex[6.5247583609077076`, -0.03339219715471046], 
              Complex[7.954365525461625, -1.2104697460661469`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.864383522178553, 0.028447097632704994`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.864383522178553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704994`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D1", 1, {
              Complex[5.864383522178553, 0.028447097632704994`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.496430480050892, -0.03598429729320658}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.496430480050892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03598429729320658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194965`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "D1", 2, {
              Complex[6.496430480050892, -0.03598429729320658], 
              Complex[7.927473033284, -1.2126821236194965`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.894717893374835, 0.031803157852374093`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.894717893374835`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852374093`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D1", 1, {
              Complex[5.894717893374835, 0.031803157852374093`], 
              Complex[7.360277468735851, -1.1438984501954066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.465940194681216, -0.03935307118737327}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.465940194681216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.03935307118737327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.898547952604841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215606555382372`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "D1", 2, {
              Complex[6.465940194681216, -0.03935307118737327], 
              Complex[7.898547952604841, -1.215606555382372]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.927914095850698, 0.036413030935491676`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.927914095850698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036413030935491676`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.391618832430633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155711`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D1", 1, {
              Complex[5.927914095850698, 0.036413030935491676`], 
              Complex[7.391618832430633, -1.1398036000155711`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.432591283080759, -0.043975393800888975`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.432591283080759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.043975393800888975`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.866930860848724`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147183`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "D1", 2, {
              Complex[6.432591283080759, -0.043975393800888975`], 
              Complex[7.866930860848724, -1.2196865044147183`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{5.96502471876488, 0.0432677226664523}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.96502471876488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0432677226664523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1336280195460162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D1", 1, {
              Complex[5.96502471876488, 0.0432677226664523], 
              Complex[7.426654831776879, -1.1336280195460162`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.395331027411176, -0.05084228149319564}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.395331027411176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149319564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.83162254397556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686628`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D1", 2, {
              Complex[6.395331027411176, -0.05084228149319564], 
              Complex[7.83162254397556, -1.2258468389686628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.007534506136697, 0.054768081877322586`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.007534506136697`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.054768081877322586`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.46680267071517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231222909767526`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D1", 1, {
              Complex[6.007534506136697, 0.054768081877322586`], 
              Complex[7.46680267071517, -1.1231222909767526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.352674562767395, -0.062354593032590215`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.352674562767395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032590215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.791205671196033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2363369885208044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D1", 2, {
              Complex[6.352674562767395, -0.062354593032590215`], 
              Complex[7.791205671196033, -1.2363369885208044`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.118560581075961, 0.0068877274873969585`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C1", 1, {
              Complex[8.118560581075961, 0.0068877274873969585`], 
              Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.53989419288883, -0.01324317030169899}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C1", 2, {
              Complex[10.53989419288883, -0.01324317030169899], 
              Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.162580737731858, 0.007042959985370651}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C1", 1, {
              Complex[8.162580737731858, 0.007042959985370651], 
              Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.494506767269, -0.013509876715323853`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C1", 2, {
              Complex[10.494506767269, -0.013509876715323853`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.198987977866883, 0.007197843246654797}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C1", 1, {
              Complex[8.198987977866883, 0.007197843246654797], 
              Complex[6.557943371421671, -1.162972548762566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.457042457039066`, -0.013751044852512806`}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C1", 2, {
              Complex[10.457042457039066`, -0.013751044852512806`], 
              Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.231005147885755, 0.0073549519610065905`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C1", 1, {
              Complex[8.231005147885755, 0.0073549519610065905`], 
              Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.42414741707873, -0.0139798695984579}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C1", 2, {
              Complex[10.42414741707873, -0.0139798695984579], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.260098904258959, 0.007515591774090756}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C1", 1, {
              Complex[8.260098904258959, 0.007515591774090756], 
              Complex[6.61778553109412, -1.162803172863648]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.39429571170861, -0.014202465960725278`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C1", 2, {
              Complex[10.39429571170861, -0.014202465960725278`], 
              Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.287084479515974, 0.007680628289981289}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C1", 1, {
              Complex[8.287084479515974, 0.007680628289981289], 
              Complex[6.644124842294815, -1.162714599075609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.366639367283945`, -0.014422357660350082`}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C1", 2, {
              Complex[10.366639367283945`, -0.014422357660350082`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.312471288002852, 0.00785074316053409}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C1", 1, {
              Complex[8.312471288002852, 0.00785074316053409], 
              Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.340648661463618`, -0.014641876121436062`}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C1", 2, {
              Complex[10.340648661463618`, -0.014641876121436062`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.336603564825275, 0.00802653852897203}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C1", 1, {
              Complex[8.336603564825275, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.315965756037766`, -0.014862729232274637`}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C1", 2, {
              Complex[10.315965756037766`, -0.014862729232274637`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.359727508694593, 0.008208588338762687}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C1", 1, {
              Complex[8.359727508694593, 0.008208588338762687], 
              Complex[6.714779367617378, -1.162425692393188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.29233482504539, -0.015086273942248}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C1", 2, {
              Complex[10.29233482504539, -0.015086273942248], 
              Complex[8.556435217312078, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.382027043209192, 0.008397467701836855}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C1", 1, {
              Complex[8.382027043209192, 0.008397467701836855], 
              Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.269564843263957`, -0.01531366326459591}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C1", 2, {
              Complex[10.269564843263957`, -0.01531366326459591], 
              Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.40364445944282, 0.008593772293729832}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C1", 1, {
              Complex[8.40364445944282, 0.008593772293729832], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.247508108692935`, -0.01554593341902805}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C1", 2, {
              Complex[10.247508108692935`, -0.01554593341902805], 
              Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.424693095053826, 0.00879813306517896}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C1", 1, {
              Complex[8.424693095053826, 0.00879813306517896], 
              Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.226047052260421`, -0.01578406003523005}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C1", 2, {
              Complex[10.226047052260421`, -0.01578406003523005], 
              Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.445265519754589, 0.009011228909084963}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C1", 1, {
              Complex[8.445265519754589, 0.009011228909084963], 
              Complex[6.797539667322055, -1.161966845801127]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.20508572371207, -0.016028997503587203`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C1", 2, {
              Complex[10.20508572371207, -0.016028997503587203`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.465439042444201, 0.009233798770935121}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C1", 1, {
              Complex[8.465439042444201, 0.009233798770935121], 
              Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.184544064614805`, -0.016281708942805753`}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C1", 2, {
              Complex[10.184544064614805`, -0.016281708942805753`], 
              Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.485279549606197, 0.009466654168547486}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C1", 1, {
              Complex[8.485279549606197, 0.009466654168547486], 
              Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.164353917920575`, -0.016543191071888914`}],
            
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C1", 2, {
              Complex[10.164353917920575`, -0.016543191071888914`], 
              Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.504844265661474, 0.009710692858210806}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C1", 1, {
              Complex[8.504844265661474, 0.009710692858210806], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.144456159495563`, -0.016814496662831836`}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C1", 2, {
              Complex[10.144456159495563`, -0.016814496662831836`], 
              Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.52418379610039, 0.00996691431009624}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C1", 1, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.124798576239256`, -0.017096756417673668`}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C1", 2, {
              Complex[10.124798576239256`, -0.017096756417673668`], 
              Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.543343682297635, 0.01023643767719948}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C1", 1, {
              Complex[8.543343682297635, 0.01023643767719948], 
              Complex[6.891907468896068, -1.161220171125207]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.105334252708913`, -0.017391201699304026`}],
            
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C1", 2, {
              Complex[10.105334252708913`, -0.017391201699304026`], 
              Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.562365618323055, 0.010520523036427927`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C1", 1, {
              Complex[8.562365618323055, 0.010520523036427927`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.086020309962356`, -0.017699189379580486`}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C1", 2, {
              Complex[10.086020309962356`, -0.017699189379580486`], 
              Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.581288431797727, 0.010820596844492403`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C1", 1, {
              Complex[8.581288431797727, 0.010820596844492403`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.06681689057666, -0.018022230071644385`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C1", 2, {
              Complex[10.06681689057666, -0.018022230071644385`], 
              Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.600148900521386, 0.011138282794836918`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C1", 1, {
              Complex[8.600148900521386, 0.011138282794836918`], 
              Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.047686315383556`, -0.018362021154624195`}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C1", 2, {
              Complex[10.047686315383556`, -0.018362021154624195`], 
              Complex[8.319026572634915, -1.199065136952576]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.618982457304563, 0.011475439606775252`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C1", 1, {
              Complex[8.618982457304563, 0.011475439606775252`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{10.02859235757786, -0.018720486277070698`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C1", 2, {
              Complex[10.02859235757786, -0.018720486277070698`], 
              Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.637823823216573, 0.011834207760463409`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C1", 1, {
              Complex[8.637823823216573, 0.011834207760463409`], 
              Complex[6.982345361327388, -1.160172170534845]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.009499592627153`, -0.019099823463292497`}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C1", 2, {
              Complex[10.009499592627153`, -0.019099823463292497`], 
              Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.656707602013043, 0.012217067867222313`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C1", 1, {
              Complex[8.656707602013043, 0.012217067867222313`], 
              Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.990372790233621, -0.01950256459218661}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C1", 2, {
              Complex[9.990372790233621, -0.01950256459218661], 
              Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.675668864524779, 0.012626914319474911`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C1", 1, {
              Complex[8.675668864524779, 0.012626914319474911`], 
              Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.971176318841339, -0.019931649951741043`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C1", 2, {
              Complex[9.971176318841339, -0.019931649951741043`], 
              Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.694743750598732, 0.013067149229433986`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C1", 1, {
              Complex[8.694743750598732, 0.013067149229433986`], 
              Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.951873534557844, -0.020390522922278387`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C1", 2, {
              Complex[9.951873534557844, -0.020390522922278387`], 
              Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.713970117564823, 0.013541803645186434`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C1", 1, {
              Complex[8.713970117564823, 0.013541803645186434`], 
              Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.932426125107996, -0.020883251810279745`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C1", 2, {
              Complex[9.932426125107996, -0.020883251810279745`], 
              Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.733388268345113, 0.014055695951277626`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C1", 1, {
              Complex[8.733388268345113, 0.014055695951277626`], 
              Complex[7.073421269042284, -1.158603006979818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.912793375391814, -0.02141468876524509}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C1", 2, {
              Complex[9.912793375391814, -0.02141468876524509], 
              Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.753041799848587, 0.014614641743299649`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C1", 1, {
              Complex[8.753041799848587, 0.014614641743299649`], 
              Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.892931313762208, -0.021990680088691875`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C1", 2, {
              Complex[9.892931313762208, -0.021990680088691875`], 
              Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.77297862441228, 0.015225736181981687`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C1", 1, {
              Complex[8.77297862441228, 0.015225736181981687`], 
              Complex[7.111050585905176, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.872791686074075, -0.02261834895605743}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C1", 2, {
              Complex[9.872791686074075, -0.02261834895605743], 
              Complex[8.151078988162066, -1.201907179567137]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.793252235841303, 0.01589774035976148}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C1", 1, {
              Complex[8.793252235841303, 0.01589774035976148], 
              Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.852320685804424, -0.02330648209651281}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C1", 2, {
              Complex[9.852320685804424, -0.02330648209651281], 
              Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.813923320576674, 0.016641620135819556`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C1", 1, {
              Complex[8.813923320576674, 0.016641620135819556`], 
              Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.831457339597339, -0.02406606889621767}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C1", 2, {
              Complex[9.831457339597339, -0.02406606889621767], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.835061859626233, 0.017471313877762306`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C1", 1, {
              Complex[8.835061859626233, 0.017471313877762306`], 
              Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.81013140250469, -0.02491106937082747}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C1", 2, {
              Complex[9.81013140250469, -0.02491106937082747], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.856749938394854, 0.01840485331132207}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C1", 1, {
              Complex[8.856749938394854, 0.01840485331132207], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.78826054571076, -0.02585953521479562}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C1", 2, {
              Complex[9.78826054571076, -0.02585953521479562], 
              Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.879085597629635, 0.019466046203823823`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C1", 1, {
              Complex[8.879085597629635, 0.019466046203823823`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.76574650346378, -0.02693529265819088}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C1", 2, {
              Complex[9.76574650346378, -0.02693529265819088], 
              Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.902188252549184, 0.020687085496539234`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C1", 1, {
              Complex[8.902188252549184, 0.020687085496539234`], 
              Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.742469652095146, -0.028170551750257837`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C1", 2, {
              Complex[9.742469652095146, -0.028170551750257837`], 
              Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.926206541442703, 0.02211275107353916}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C1", 1, {
              Complex[8.926206541442703, 0.02211275107353916], 
              Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.718281159799472, -0.029610108260631186`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C1", 2, {
              Complex[9.718281159799472, -0.029610108260631186`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.95133006145241, 0.023807487220115792`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C1", 1, {
              Complex[8.95133006145241, 0.023807487220115792`], 
              Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.692991249427967, -0.0313184212541546}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C1", 2, {
              Complex[9.692991249427967, -0.0313184212541546], 
              Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.977807551308572, 0.025867986584037196`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C1", 1, {
              Complex[8.977807551308572, 0.025867986584037196`], 
              Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.6663510144975, -0.033392197154710215`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C1", 2, {
              Complex[9.6663510144975, -0.033392197154710215`], 
              Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.005976175768346, 0.028447097632704935`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C1", 1, {
              Complex[9.005976175768346, 0.028447097632704935`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.638023133640685, -0.035984297293206895`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C1", 2, {
              Complex[9.638023133640685, -0.035984297293206895`], 
              Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.036310546964627, 0.031803157852373865`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C1", 1, {
              Complex[9.036310546964627, 0.031803157852373865`], 
              Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.607532848271008, -0.039353071187373335`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C1", 2, {
              Complex[9.607532848271008, -0.039353071187373335`], 
              Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.069506749440478, 0.03641303093548226}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C1", 1, {
              Complex[9.069506749440478, 0.03641303093548226], 
              Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.574183936670554, -0.04397539380088848}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C1", 2, {
              Complex[9.574183936670554, -0.04397539380088848], 
              Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.106617372354673, 0.04326772266645232}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C1", 1, {
              Complex[9.106617372354673, 0.04326772266645232], 
              Complex[7.426654831776879, -1.133628019546016]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.536923681000955, -0.05084228149321134}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C1", 2, {
              Complex[9.536923681000955, -0.05084228149321134], 
              Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.149127159726488, 0.05476808187732223}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C1\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C1", 1, {
              Complex[9.149127159726488, 0.05476808187732223], 
              Complex[7.466802670715167, -1.123122290976753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.494267216357189, -0.062354593032578}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C1\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C1", 2, {
              Complex[9.494267216357189, -0.062354593032578], 
              Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.197298230159177, 0.07734359441247762}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C2", 1, {
              Complex[9.197298230159177, 0.07734359441247762], 
              Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.445952310414624, -0.08494182361234351}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C2", 2, {
              Complex[9.445952310414624, -0.08494182361234351], 
              Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.239565409647748, 0.11902724764149018`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C2", 1, {
              Complex[9.239565409647748, 0.11902724764149018`], 
              Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.403544030055139, -0.12663696940988678`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C2", 2, {
              Complex[9.403544030055139, -0.12663696940988678`], 
              Complex[7.704988630788347, -1.296125883577755]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.055705576569384, 0.07734359441247692}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.055705576569384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.102232298445035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D2", 1, {
              Complex[6.055705576569384, 0.07734359441247692], 
              Complex[7.512359287571745, -1.102232298445035]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.304359656824848, -0.08494182361233121}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.304359656824848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361233121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "D2", 2, {
              Complex[6.304359656824848, -0.08494182361233121], 
              Complex[7.745383184720156, -1.2572110799472327`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.097972756057953, 0.11902724764148631`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.097972756057953`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764148631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.552491023448565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0633012820313106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D2", 1, {
              Complex[6.097972756057953, 0.11902724764148631`], 
              Complex[7.552491023448565, -1.0633012820313106`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.261951376465343, -0.12663696940989244`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.261951376465343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940989244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2961258835777605`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "D2", 2, {
              Complex[6.261951376465343, -0.12663696940989244`], 
              Complex[7.704988630788345, -1.2961258835777605`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.120724694194671, 0.16611165996512534`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.120724694194671`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.019141232917107`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D3", 1, {
              Complex[6.120724694194671, 0.16611165996512534`], 
              Complex[7.574268139734727, -1.019141232917107]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.239060971061035, -0.17373265713468317`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.239060971061035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713468317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D3", 2, {
              Complex[6.239060971061035, -0.17373265713468317`], 
              Complex[7.682951641637805, -1.3402694180832762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.132202365530885, 0.2069539217818524}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.132202365530885`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2069539217818524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.58536879774568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.980787258766948`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D3", 1, {
              Complex[6.132202365530885, 0.2069539217818524], 
              Complex[7.58536879774568, -0.980787258766948]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.22744737065107, -0.21458598503237494`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22744737065107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349245`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D3", 2, {
              Complex[6.22744737065107, -0.21458598503237494`], 
              Complex[7.671593955391059, -1.3786065851349245`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.138977875500199, 0.24191392575349213`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138977875500199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909482`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D3", 1, {
              Complex[6.138977875500199, 0.24191392575349213`], 
              Complex[7.591990895909482, -0.9479498476029747]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.22053837960052, -0.24955685318475593`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.22053837960052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24955685318475593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666702`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D3", 2, {
              Complex[6.22053837960052, -0.24955685318475593`], 
              Complex[7.664717578441819, -1.4114269055666702`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.143492571886664, 0.27256109297706693`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.143492571886664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.596448189109472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D3", 1, {
              Complex[6.143492571886664, 0.27256109297706693`], 
              Complex[7.596448189109472, -0.9191675975214392]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.215892564752824, -0.2802146897125671}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.215892564752824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125671`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4401917896926058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "D3", 2, {
              Complex[6.215892564752824, -0.2802146897125671], 
              Complex[7.660008665723728, -1.4401917896926058`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.146749395916181, 0.30000093008350615`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.146749395916181`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.30000093008350615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D3", 1, {
              Complex[6.146749395916181, 0.30000093008350615`], 
              Complex[7.599694877117055, -0.8934053728141105]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.212506903993471, -0.30766500790256135`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.212506903993471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790256135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.465936381216481`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "D3", 2, {
              Complex[6.212506903993471, -0.30766500790256135`], 
              Complex[7.656512931924062, -1.465936381216481]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.149229270200796, 0.3249638924276399}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.149229270200796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3249638924276399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D3", 1, {
              Complex[6.149229270200796, 0.3249638924276399], 
              Complex[7.602190099828044, -0.8699776507064143]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.209900397991501, -0.3326382694231228}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.209900397991501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3326382694231228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.489346210521607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D3", 2, {
              Complex[6.209900397991501, -0.3326382694231228], 
              Complex[7.653771155925207, -1.489346210521607]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.151192034362995, 0.34794816918875576`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.151192034362995`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918875576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714225`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D3", 1, {
              Complex[6.151192034362995, 0.34794816918875576`], 
              Complex[7.604182742222913, -0.8484162452714225]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.207813134288261, -0.3556326694484139}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.207813134288261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556326694484139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.65153437555002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5108894707826943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "D3", 2, {
              Complex[6.207813134288261, -0.3556326694484139], 
              Complex[7.65153437555002, -1.5108894707826943`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.152791090696166, 0.3693076970042951}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.152791090696166`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3693076970042951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D3", 1, {
              Complex[6.152791090696166, 0.3693076970042951], 
              Complex[7.605820205415675, -0.8283882117511523]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2060916413747425`, -0.3770021503134528}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2060916413747425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3770021503134528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5308991136680343`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "D3", 2, {
              Complex[6.2060916413747425`, -0.3770021503134528], 
              Complex[7.649655116243796, -1.5308991136680343`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.154123300626686, 0.38930335076908473`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.154123300626686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38930335076908473`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D3", 1, {
              Complex[6.154123300626686, 0.38930335076908473`], 
              Complex[7.607195850080814, -0.8096479618228547]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.204638991989324, -0.3970075923331428}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.204638991989324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.648039947400698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5496207340949584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "D3", 2, {
              Complex[6.204638991989324, -0.3970075923331428], 
              Complex[7.648039947400698, -1.5496207340949584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.155253112689077, 0.4081334915298177}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.155253112689077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709222`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D3", 1, {
              Complex[6.155253112689077, 0.4081334915298177], 
              Complex[7.608371984798493, -0.7920086413709222]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.203390674922197, -0.41584736171471254`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.203390674922197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.646626493792042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5672411924777168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D3", 2, {
              Complex[6.203390674922197, -0.41584736171471254`], 
              Complex[7.646626493792042, -1.5672411924777168`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.156225240135477, 0.4259529280523631}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.156225240135477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4259529280523631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60939196819019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7753243442615727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D3", 1, {
              Complex[6.156225240135477, 0.4259529280523631], 
              Complex[7.60939196819019, -0.7753243442615727]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.202301917203499, -0.4336762721416338}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.202301917203499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6453713332226165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.583906400971116`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D3", 2, {
              Complex[6.202301917203499, -0.4336762721416338], 
              Complex[7.6453713332226165`, -1.583906400971116]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1570717804683675`, 0.44288515307919946`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1570717804683675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44288515307919946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6102870179530235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7594786249471304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D3", 1, {
              Complex[6.1570717804683675`, 0.44288515307919946`], 
              Complex[7.6102870179530235`, -0.7594786249471304]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.201340564384264, -0.4506178210463805}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.201340564384264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4506178210463805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.599732810883159`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "D3", 2, {
              Complex[6.201340564384264, -0.4506178210463805], 
              Complex[7.644243187304668, -1.599732810883159]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15781643675441, 0.45903052180506065`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15781643675441`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213614`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D3", 1, {
              Complex[6.15781643675441, 0.45903052180506065`], 
              Complex[7.611080255416446, -0.7443768154213614]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.2004828590509335`, -0.46677236810008377`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.2004828590509335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46677236810008377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352279`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D3", 2, {
              Complex[6.2004828590509335`, -0.46677236810008377`], 
              Complex[7.6432188767245925`, -1.6148150957352279`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.15847713590932, 0.4744718898931343}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.15847713590932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4744718898931343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319834`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D3", 1, {
              Complex[6.15847713590932, 0.4744718898931343], 
              Complex[7.611789218669329, -0.7299407258319834]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199710822382092, -0.4822227732417416}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199710822382092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.642280807952738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D3", 2, {
              Complex[6.199710822382092, -0.4822227732417416], 
              Complex[7.642280807952738, -1.6292314506639922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1590677155468105`, 0.48927860682774}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1590677155468105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48927860682774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D3", 1, {
              Complex[6.1590677155468105`, 0.48927860682774], 
              Complex[7.612427484506159, -0.7161048892141155]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.199010567153125, -0.49703839004290984`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199010567153125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.49703839004290984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.641415351146402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6430473477013012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D3", 2, {
              Complex[6.199010567153125, -0.49703839004290984`], 
              Complex[7.641415351146402, -1.6430473477013012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.159599046539053, 0.5035094122855176}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.159599046539053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5035094122855176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825414`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D3", 1, {
              Complex[6.159599046539053, 0.5035094122855176], 
              Complex[7.613005749670383, -0.7028138366825414]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.198371175040328, -0.5112779620899686}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.198371175040328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942466`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D3", 2, {
              Complex[6.198371175040328, -0.5112779620899686], 
              Complex[7.640611758766885, -1.6563182605942466`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160079801248174, 0.5172145811965714}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160079801248174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D3", 1, {
              Complex[6.160079801248174, 0.5172145811965714], 
              Complex[7.613532572082205, -0.6900200786894305]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197783928263984, -0.5249917680556042}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197783928263984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6398614242223575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6690916835589533`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "D3", 2, {
              Complex[6.197783928263984, -0.5249917680556042], 
              Complex[7.6398614242223575`, -1.6690916835589533`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160516992248921, 0.5304375419992584}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160516992248921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6140148915107115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6776825815576774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D3", 1, {
              Complex[6.160516992248921, 0.5304375419992584], 
              Complex[7.6140148915107115`, -0.6776825815576774]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.197241770749233, -0.538223239963063}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.197241770749233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.538223239963063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63915736107556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "D3", 2, {
              Complex[6.197241770749233, -0.538223239963063], 
              Complex[7.63915736107556, -1.6814086547578186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.160916358296958, 0.5432161176861712}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.160916358296958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D3", 1, {
              Complex[6.160916358296958, 0.5432161176861712], 
              Complex[7.614458403240932, -0.6657655987699648]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1967389220498434`, -0.5510102042411117}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1967389220498434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5510102042411117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6933049250204686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "D3", 2, {
              Complex[6.1967389220498434`, -0.5510102042411117], 
              Complex[7.638493829265324, -1.6933049250204686`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161282646160605, 0.5555834916479535}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161282646160605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D3", 1, {
              Complex[6.161282646160605, 0.5555834916479535], 
              Complex[7.6148678313818445`, -0.6542377611605094]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1962705954158785`, -0.5633858475760002}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1962705954158785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5633858475760002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7048118676611494`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D3", 2, {
              Complex[6.1962705954158785`, -0.5633858475760002], 
              Complex[7.6378660616946545`, -1.7048118676611494`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1616198199314836`, 0.5675689693259762}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1616198199314836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5675689693259762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.643071359259793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D3", 1, {
              Complex[6.1616198199314836`, 0.5675689693259762], 
              Complex[7.615247132185832, -0.643071359259793]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195832788389601, -0.5753794785718529}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195832788389601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.715957196142648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D3", 2, {
              Complex[6.195832788389601, -0.5753794785718529], 
              Complex[7.637270060814722, -1.715957196142648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.161931218858729, 0.5791985860418423}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161931218858729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D3", 1, {
              Complex[6.161931218858729, 0.5791985860418423], 
              Complex[7.615599647619971, -0.6322417704324717]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1954221248841135`, -0.5870171355873215}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1954221248841135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5870171355873215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "D3", 2, {
              Complex[6.1954221248841135`, -0.5870171355873215], 
              Complex[7.636702444963452, -1.7267655369464132`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162219678012526, 0.5904955973399484}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162219678012526`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.621726996632902`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D3", 1, {
              Complex[6.162219678012526, 0.5904955973399484], 
              Complex[7.615928222964841, -0.621726996632902]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.195035734438572, -0.5983220770848242}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.195035734438572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D3", 2, {
              Complex[6.195035734438572, -0.5983220770848242], 
              Complex[7.636160330682662, -1.7372588918245433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162487621687207, 0.6014808784641323}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162487621687207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162352979952175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.611507287733823`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D3", 1, {
              Complex[6.162487621687207, 0.6014808784641323], 
              Complex[7.6162352979952175`, -0.611507287733823]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.194671158739189, -0.6093151811133911}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194671158739189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6093151811133911`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7474570144780972`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "D3", 2, {
              Complex[6.194671158739189, -0.6093151811133911], 
              Complex[7.635641241458829, -1.7474570144780972`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162737136528052, 0.6121732527479822}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162737136528052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6121732527479822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D3", 1, {
              Complex[6.162737136528052, 0.6121732527479822], 
              Complex[7.616522978484024, -0.6015648318155974]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.194326278421569, -0.6200152737048314}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.194326278421569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D3", 2, {
              Complex[6.194326278421569, -0.6200152737048314], 
              Complex[7.635143036145728, -1.7573777202744643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.162970029380981, 0.6225897638061394}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.162970029380981`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038951`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D3", 1, {
              Complex[6.162970029380981, 0.6225897638061394], 
              Complex[7.616793092860657, -0.5918834984038951]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193999255154619, -0.63043940107047}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193999255154619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.63043940107047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158252`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D3", 2, {
              Complex[6.193999255154619, -0.63043940107047], 
              Complex[7.63466385223734, -1.7670371430158252`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1631878734954, 0.6327459028649584}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1631878734954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D3", 1, {
              Complex[6.1631878734954, 0.6327459028649584], 
              Complex[7.617047237536007, -0.5824486239818053]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193688485375648, -0.6406030569368893}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193688485375648`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328054`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D3", 2, {
              Complex[6.193688485375648, -0.6406030569368893], 
              Complex[7.634202060478484, -1.7764499494328054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163392045750655, 0.6426557999628854}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163392045750655`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D3", 1, {
              Complex[6.163392045750655, 0.6426557999628854], 
              Complex[7.617286813480894, -0.5732468315559037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193392563005682, -0.6505203737511226}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193392563005682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D3", 2, {
              Complex[6.193392563005682, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238634`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163583756894771, 0.6523323858111204}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163583756894771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617513055986503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.564265877881112`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D3", 1, {
              Complex[6.163583756894771, 0.6523323858111204], 
              Complex[7.617513055986503, -0.564265877881112]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.193110249156134, -0.660204284545775}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.193110249156134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.660204284545775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "D3", 2, {
              Complex[6.193110249156134, -0.660204284545775], 
              Complex[7.633325089631601, -1.7945880998355053`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.163764076292796, 0.6617875296457958}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.163764076292796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61772705906054`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226198`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D3", 1, {
              Complex[6.163764076292796, 0.6617875296457958], 
              Complex[7.61772705906054, -0.5554945233226198]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192840447329175, -0.6696666607954201}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192840447329175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632907521192611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8033369326051631`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "D3", 2, {
              Complex[6.192840447329175, -0.6696666607954201], 
              Complex[7.632907521192611, -1.8033369326051631`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16393395232409, 0.671032157293945}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16393395232409`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.671032157293945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D3", 1, {
              Complex[6.16393395232409, 0.671032157293945], 
              Complex[7.617929795566583, -0.5469224203770383]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192582182972333, -0.6789184304865281}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192582182972333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "D3", 2, {
              Complex[6.192582182972333, -0.6789184304865281], 
              Complex[7.632502521562484, -1.8118863682445574`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164094229303429, 0.680076352824419}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164094229303429`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.680076352824419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D3", 1, {
              Complex[6.164094229303429, 0.680076352824419], 
              Complex[7.618122133957997, -0.5385400176762598]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192334586512061, -0.6879696797720971}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192334586512061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.820245960840084`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D3", 2, {
              Complex[6.192334586512061, -0.6879696797720971], 
              Complex[7.632109194769857, -1.820245960840084]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164245661604394, 0.6889294464957759}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164245661604394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6183048522674195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5303384769181542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D3", 1, {
              Complex[6.164245661604394, 0.6889294464957759], 
              Complex[7.6183048522674195`, -0.5303384769181542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.192096879187743, -0.6968297409230599}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.192096879187743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D3", 2, {
              Complex[6.192096879187743, -0.6968297409230599], 
              Complex[7.631726736184741, -1.8284245513261357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164388925515004, 0.697600091198504}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164388925515004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D3", 1, {
              Complex[6.164388925515004, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191868361155921, -0.7055072687737808}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191868361155921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7055072687737808`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.836430339702474`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "D3", 2, {
              Complex[6.191868361155921, -0.7055072687737808], 
              Complex[7.6313544207148105`, -1.836430339702474]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164524629243228, 0.7060963291837459}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164524629243228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837459`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D3", 1, {
              Complex[6.164524629243228, 0.7060963291837459], 
              Complex[7.618644157419197, -0.5144457692358496]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191648401446948, -0.7140103074539127}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191648401446948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "D3", 2, {
              Complex[6.191648401446948, -0.7140103074539127], 
              Complex[7.630991592823766, -1.8442709480852433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164653321403731, 0.7144256505494253}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164653321403731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D3", 1, {
              Complex[6.164653321403731, 0.7144256505494253], 
              Complex[7.618801945306149, -0.5067398855588758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191436429442565, -0.7223463488774431}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191436429442565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D3", 2, {
              Complex[6.191436429442565, -0.7223463488774431], 
              Complex[7.630637658047721, -1.8519534759784038`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164775498250602, 0.7225950446980839}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164775498250602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7225950446980839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4991853264171629`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D3", 1, {
              Complex[6.164775498250602, 0.7225950446980839], 
              Complex[7.61895253085656, -0.4991853264171629]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.191231927609488, -0.7305223842033104}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.191231927609488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7305223842033104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D3", 2, {
              Complex[6.191231927609488, -0.7305223842033104], 
              Complex[7.630292075750293, -1.8594845489107188`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.164891609869033, 0.7306110457745064}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.164891609869033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7306110457745064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619096384518943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4917758995586621`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D3", 1, {
              Complex[6.164891609869033, 0.7306110457745064], 
              Complex[7.619096384518943, -0.4917758995586621]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1910344252759195`, -0.738544949275635}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1910344252759195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.738544949275635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D3", 2, {
              Complex[6.1910344252759195`, -0.738544949275635], 
              Complex[7.629954352907652, -1.8668703613890223`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165002065498246, 0.738479772924393}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165002065498246`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.738479772924393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D3", 1, {
              Complex[6.165002065498246, 0.738479772924393], 
              Complex[7.619233935186141, -0.4845058056239236]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190843493278558, -0.7464201648848559}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190843493278558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "D3", 2, {
              Complex[6.190843493278558, -0.7464201648848559], 
              Complex[7.629624038754354, -1.8741167149612883`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1651072381259, 0.7462069660795196}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1651072381259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47736960431039205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D3", 1, {
              Complex[6.1651072381259, 0.7462069660795196], 
              Complex[7.619365574796855, -0.47736960431039205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190658739339742, -0.7541537725552644}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190658739339742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8812290520550745`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D3", 2, {
              Complex[6.190658739339742, -0.7541537725552644], 
              Complex[7.629300720152121, -1.8812290520550745`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165207468468805, 0.7537980178639989}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165207468468805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47036218420022063`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D3", 1, {
              Complex[6.165207468468805, 0.7537980178639989], 
              Complex[7.619491662328772, -0.47036218420022063`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190479804059834, -0.761751166453437}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190479804059834`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.761751166453437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522416`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D3", 2, {
              Complex[6.190479804059834, -0.761751166453437], 
              Complex[7.628984017568608, -1.8882124861522416`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165303068434313, 0.761258002124613}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165303068434313`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.761258002124613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D3", 1, {
              Complex[6.165303068434313, 0.761258002124613], 
              Complex[7.619612527276209, -0.4634787357769724]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1903063574303445`, -0.7692174219206874}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1903063574303445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7692174219206874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628673581573148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287746993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "D3", 2, {
              Complex[6.1903063574303445`, -0.7692174219206874], 
              Complex[7.628673581573148, -1.8950718287746993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165394324140473, 0.7685916995129604}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165394324140473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D3", 1, {
              Complex[6.165394324140473, 0.7685916995129604], 
              Complex[7.619728472689179, -0.4567147272275415]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.190138095789615, -0.7765573210571961}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.190138095789615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "D3", 2, {
              Complex[6.190138095789615, -0.7765573210571961], 
              Complex[7.62836908977242, -1.9018116136847978`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1654814985597985`, 0.7758036204842987}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1654814985597985`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7758036204842987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4500658826848904`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D3", 1, {
              Complex[6.1654814985597985`, 0.7758036204842987], 
              Complex[7.619839777837857, -0.4500658826848904]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18997473915616, -0.7837753757227331}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18997473915616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "D3", 2, {
              Complex[6.18997473915616, -0.7837753757227331], 
              Complex[7.628070244122036, -1.9084361186447762`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1655648338407385`, 0.7828980260257037}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1655648338407385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7828980260257037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.443528162616499`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D3", 1, {
              Complex[6.1655648338407385`, 0.7828980260257037], 
              Complex[7.619946700555888, -0.443528162616499]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189816028885474, -0.7908758482666055}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189816028885474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.914949385030405`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D3", 2, {
              Complex[6.189816028885474, -0.7908758482666055], 
              Complex[7.627776768560513, -1.914949385030405]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165644553352178, 0.7898789463823163}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165644553352178`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6200494793073075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.43709774610477803`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D3", 1, {
              Complex[6.165644553352178, 0.7898789463823163], 
              Complex[7.6200494793073075`, -0.43709774610477803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189661725604909, -0.7978627702556053}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189661725604909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525556`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D3", 2, {
              Complex[6.189661725604909, -0.7978627702556053], 
              Complex[7.627488406920755, -1.9213552355525556`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165720863489107, 0.7967501980135657}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165720863489107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004999`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D3", 1, {
              Complex[6.165720863489107, 0.7967501980135657], 
              Complex[7.620148335014862, -0.4307710148004999]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189511607388403, -0.804739959431843}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189511607388403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.804739959431843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D3", 2, {
              Complex[6.189511607388403, -0.804739959431843], 
              Complex[7.627204921081207, -1.9276572903056552`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165793955271714, 0.8035153989801244}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165793955271714`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681651`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966854`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D3", 1, {
              Complex[6.165793955271714, 0.8035153989801244], 
              Complex[7.620243472681651, -0.42454453835966854`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189365468138804, -0.8115110351012247}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189365468138804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8115110351012247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62692608932472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D3", 2, {
              Complex[6.189365468138804, -0.8115110351012247], 
              Complex[7.62692608932472, -1.9338589813326057`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1658640057650915`, 0.8101779829358522}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1658640057650915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8101779829358522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62033508283309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41841506119925653`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D3", 1, {
              Complex[6.1658640057650915`, 0.8101779829358522], 
              Complex[7.62033508283309, -0.41841506119925653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.189223116150438, -0.8181794321268676}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.189223116150438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8181794321268676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626651704878013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9399635658707657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D3", 2, {
              Complex[6.189223116150438, -0.8181794321268676], 
              Complex[7.626651704878013, -1.9399635658707657`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165931179342954, 0.8167412118766469}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165931179342954`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D3", 1, {
              Complex[6.165931179342954, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18908437282858, -0.8247484136793249}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18908437282858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8247484136793249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9459741384224638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D3", 2, {
              Complex[6.18908437282858, -0.8247484136793249], 
              Complex[7.626381574608516, -1.9459741384224638`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.165995628815023, 0.823208187778776}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.165995628815023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.823208187778776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6205084178793125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4064348848292471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D3", 1, {
              Complex[6.165995628815023, 0.823208187778776], 
              Complex[7.6205084178793125`, -0.4064348848292471]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188949071546019, -0.8312210828762437}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188949071546019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752963`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D3", 2, {
              Complex[6.188949071546019, -0.8312210828762437], 
              Complex[7.626115517858932, -1.9518936417752963`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166057496435186, 0.8295818632429409}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166057496435186`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4005784447793382`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D3", 1, {
              Complex[6.166057496435186, 0.8295818632429409], 
              Complex[7.620590462338552, -0.4005784447793382]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188817056619653, -0.8376003934276774}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188817056619653`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "D3", 2, {
              Complex[6.188817056619653, -0.8376003934276774], 
              Complex[7.625853365402522, -1.9577248770820381`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1661169148049755`, 0.8358650512460941}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1661169148049755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8358650512460941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162878`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D3", 1, {
              Complex[6.1661169148049755`, 0.8358650512460941], 
              Complex[7.620669620363362, -0.3948075030162878]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188688182392475, -0.8438891593891127}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188688182392475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504517`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965748`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D3", 2, {
              Complex[6.188688182392475, -0.8438891593891127], 
              Complex[7.625594958504517, -1.9634705130965748`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166174007684912, 0.8420604340909559}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166174007684912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D3", 1, {
              Complex[6.166174007684912, 0.8420604340909559], 
              Complex[7.620746026875822, -0.38911951616260565`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188562312408357, -0.850090064112114}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188562312408357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.850090064112114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077104`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "D3", 2, {
              Complex[6.188562312408357, -0.850090064112114], 
              Complex[7.625340148077104, -1.9691330946508248`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166228890724623, 0.8481705716325338}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166228890724623`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3835120569340166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D3", 1, {
              Complex[6.166228890724623, 0.8481705716325338], 
              Complex[7.620819808285306, -0.3835120569340166]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1884393186687205`, -0.8562056684719376}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1884393186687205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562056684719376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "D3", 2, {
              Complex[6.1884393186687205`, -0.8562056684719376], 
              Complex[7.625088793917112, -1.9747150504476338`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166281672121116, 0.8541979088518953}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166281672121116`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D3", 1, {
              Complex[6.166281672121116, 0.8541979088518953], 
              Complex[7.620891083164294, -0.3779828069654454]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188319080961654, -0.8622384184423437}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188319080961654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423437`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624840764016902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360259`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D3", 2, {
              Complex[6.188319080961654, -0.8622384184423437], 
              Complex[7.624840764016902, -1.9802187002360259`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166332453213396, 0.8601447828394871}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166332453213396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8601447828394871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3725295501957073`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D3", 1, {
              Complex[6.166332453213396, 0.8601447828394871], 
              Complex[7.620959962859786, -0.3725295501957073]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188201486255246, -0.8681906520799051}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188201486255246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "D3", 2, {
              Complex[6.188201486255246, -0.8681906520799051], 
              Complex[7.624595933940285, -1.9856462614276869`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166381329020564, 0.8660134292433507}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166381329020564`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857526`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D3", 1, {
              Complex[6.166381329020564, 0.8660134292433507], 
              Complex[7.6210265520474145`, -0.36715016675857526`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.188086428148008, -0.8740646059731705}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.188086428148008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D3", 2, {
              Complex[6.188086428148008, -0.8740646059731705], 
              Complex[7.6243541862563, -1.990999855207028]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166428388729593, 0.8718059882315833}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166428388729593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.36184262733357525`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D3", 1, {
              Complex[6.166428388729593, 0.8718059882315833], 
              Complex[7.621090949234536, -0.36184262733357525`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187973806370098, -0.8798624212060279}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187973806370098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D3", 2, {
              Complex[6.187973806370098, -0.8798624212060279], 
              Complex[7.624115410024538, -1.996281512181469]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166473716138243, 0.877524510013052}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166473716138243`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.877524510013052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D3", 1, {
              Complex[6.166473716138243, 0.877524510013052], 
              Complex[7.621153247217728, -0.35660498791489154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187863526329917, -0.8855861488792874}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187863526329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D3", 2, {
              Complex[6.187863526329917, -0.8855861488792874], 
              Complex[7.623879500326577, -2.0014931776135643`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166517390057898, 0.8831709599557609}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166517390057898`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D3", 1, {
              Complex[6.166517390057898, 0.8831709599557609], 
              Complex[7.621213533499525, -0.3514353849611334]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187755498701229, -0.8912377552298747}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187755498701229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0066367162722307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D3", 2, {
              Complex[6.187755498701229, -0.8912377552298747], 
              Complex[7.623646357838647, -2.0066367162722307`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166559484680516, 0.8887472233381511}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166559484680516`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8887472233381511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259046`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D3", 1, {
              Complex[6.166559484680516, 0.8887472233381511], 
              Complex[7.621271890668613, -0.34633203089259046`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187649639046593, -0.8968191263829133}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187649639046593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364293`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D3", 2, {
              Complex[6.187649639046593, -0.8968191263829133], 
              Complex[7.623415888441284, -2.0117139169364293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166600069913391, 0.8942551097650246}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166600069913391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621328396747193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3412932099060136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D3", 1, {
              Complex[6.166600069913391, 0.8942551097650246], 
              Complex[7.621328396747193, -0.3412932099060136]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187545867473453, -0.9023320727684235}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187545867473453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D3", 2, {
              Complex[6.187545867473453, -0.9023320727684235], 
              Complex[7.623188002862294, -2.016726496581311]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166639211685018, 0.8996963572765853}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166639211685018`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3363172740799594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D3", 1, {
              Complex[6.166639211685018, 0.8996963572765853], 
              Complex[7.621383125508848, -0.3363172740799594]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187444108319425, -0.9077783332310714}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187444108319425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737277`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "D3", 2, {
              Complex[6.187444108319425, -0.9077783332310714], 
              Complex[7.622962616349545, -2.0216761042737277`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166676972224923, 0.9050726361762731}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166676972224923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762731`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D3", 1, {
              Complex[6.166676972224923, 0.9050726361762731], 
              Complex[7.621436146769792, -0.33140263974642126`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187344289864064, -0.9131595788587061}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187344289864064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "D3", 2, {
              Complex[6.187344289864064, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166713410320053, 0.9103855526005633}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166713410320053`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6214875266561215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3265477841068153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D3", 1, {
              Complex[6.166713410320053, 0.9103855526005633], 
              Complex[7.6214875266561215`, -0.3265477841068153]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1872463440644, -0.9184774165528232}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1872463440644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "D3", 2, {
              Complex[6.1872463440644, -0.9184774165528232], 
              Complex[7.622519022338055, -2.0313926820579584`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166748581549979, 0.9156366518516704}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166748581549979`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3217512420725154`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D3", 1, {
              Complex[6.166748581549979, 0.9156366518516704], 
              Complex[7.621537327849361, -0.3217512420725154]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.187150206311988, -0.923733392361904}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.187150206311988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "D3", 2, {
              Complex[6.187150206311988, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166782538502952, 0.9208274215121246}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166782538502952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621585609812358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D3", 1, {
              Complex[6.166782538502952, 0.9208274215121246], 
              Complex[7.621585609812358, -0.3170116033119914]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1870558152094315`, -0.9289289945966069}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1870558152094315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9289289945966069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D3", 2, {
              Complex[6.1870558152094315`, -0.9289289945966069], 
              Complex[7.622084507976148, -2.040875616614767]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166815330974628, 0.9259592943584081}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166815330974628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948828003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D3", 1, {
              Complex[6.166815330974628, 0.9259592943584081], 
              Complex[7.621632428997374, -0.31232750948828003`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186963112364547, -0.9340656567439883}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186963112364547`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621870484005858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "D3", 2, {
              Complex[6.186963112364547, -0.9340656567439883], 
              Complex[7.621870484005858, -2.045532964655917]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166847006151044, 0.9310336510892632}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166847006151044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9310336510892632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720174`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D3", 1, {
              Complex[6.166847006151044, 0.9310336510892632], 
              Complex[7.621677839037962, -0.3076976516720174]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186872042200558, -0.9391447601963707}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186872042200558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284452`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258457`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D3", 2, {
              Complex[6.186872042200558, -0.9391447601963707], 
              Complex[7.621658530284452, -2.050135996258457]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166877608777316, 0.9360518228828759}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166877608777316`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D3", 1, {
              Complex[6.166877608777316, 0.9360518228828759], 
              Complex[7.621721890926154, -0.3031207679165936]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186782551780801, -0.9441676368090823}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186782551780801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D3", 2, {
              Complex[6.186782551780801, -0.9441676368090823], 
              Complex[7.621448586511419, -2.0546859743506385`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166907181313368, 0.9410150937958539}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166907181313368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2985956409831943`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D3", 1, {
              Complex[6.166907181313368, 0.9410150937958539], 
              Complex[7.62176463317627, -0.2985956409831943]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186694590646789, -0.9491355712999217}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186694590646789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D3", 2, {
              Complex[6.186694590646789, -0.9491355712999217], 
              Complex[7.621240595073559, -2.0591841171322436`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166935764077781, 0.9459247030157971}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166935764077781`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D3", 1, {
              Complex[6.166935764077781, 0.9459247030157971], 
              Complex[7.621806111976445, -0.29412109620456683`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186608110668219, -0.9540498035022783}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186608110668219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210345008869025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0636316002114743`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D3", 2, {
              Complex[6.186608110668219, -0.9540498035022783], 
              Complex[7.6210345008869025`, -2.0636316002114743`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166963395380894, 0.9507818469782096}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166963395380894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621846371329061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D3", 1, {
              Complex[6.166963395380894, 0.9507818469782096], 
              Complex[7.621846371329061, -0.28969599947733177`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186523065904121, -0.9589115304824511}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186523065904121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "D3", 2, {
              Complex[6.186523065904121, -0.9589115304824511], 
              Complex[7.620830251250191, -2.0680295586131554`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.166990111648028, 0.9555876813576081}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.166990111648028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.28531925537351294`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D3", 1, {
              Complex[6.166990111648028, 0.9555876813576081], 
              Complex[7.621885453180955, -0.28531925537351294`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186439412474038, -0.9637219085313011}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186439412474038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085313011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620627795708716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.072379088667851`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D3", 2, {
              Complex[6.186439412474038, -0.9637219085313011], 
              Complex[7.620627795708716, -2.072379088667851]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167015947533717, 0.960343322941825}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167015947533717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D3", 1, {
              Complex[6.167015947533717, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1863571084384, -0.9684820550389218}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1863571084384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D3", 2, {
              Complex[6.1863571084384, -0.9684820550389218], 
              Complex[7.620427085927699, -2.0766812497901035`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1670409360276865`, 0.9650498513977598}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670409360276865`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621960242608855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D3", 1, {
              Complex[6.1670409360276865`, 0.9650498513977598], 
              Complex[7.621960242608855, -0.276706626137473]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186276113687406, -0.9731930502608692}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186276113687406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539055`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "D3", 2, {
              Complex[6.186276113687406, -0.9731930502608692], 
              Complex[7.620228075574519, -2.0809370661539055`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167065108553286, 0.9697083109361534}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167065108553286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358463`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D3", 1, {
              Complex[6.167065108553286, 0.9697083109361534], 
              Complex[7.6219960248466, -0.27246872803358463`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186196389837632, -0.977855938983316}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186196389837632`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.977855938983316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.085147528272351`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "D3", 2, {
              Complex[6.186196389837632, -0.977855938983316], 
              Complex[7.620030720208938, -2.085147528272351]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1670884950589855`, 0.974319711882344}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1670884950589855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D3", 1, {
              Complex[6.1670884950589855`, 0.974319711882344], 
              Complex[7.622030779108827, -0.2682751535405323]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186117900135718, -0.9824717320942182}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186117900135718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D3", 2, {
              Complex[6.186117900135718, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167111124103515, 0.9788850321593934}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167111124103515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220645387168675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2641249758942419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D3", 1, {
              Complex[6.167111124103515, 0.9788850321593934], 
              Complex[7.6220645387168675`, -0.2641249758942419]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.186040609368656, -0.9870414080668142}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.186040609368656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534103`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0934361923813576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D3", 2, {
              Complex[6.186040609368656, -0.9870414080668142], 
              Complex[7.619640805534103, -2.0934361923813576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167133022935145, 0.9834052186894809}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167133022935145`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774762006`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D3", 1, {
              Complex[6.167133022935145, 0.9834052186894809], 
              Complex[7.6220973355465995`, -0.26001729774762006`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18596448378006, -0.991565914361383}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18596448378006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D3", 2, {
              Complex[6.18596448378006, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1671542175655905`, 0.9878811887189864}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1671542175655905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9878811887189864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6221292001073655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D3", 1, {
              Complex[6.1671542175655905`, 0.9878811887189864], 
              Complex[7.6221292001073655`, -0.2559512499133873]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1858894909919995`, -0.9960461687506831}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1858894909919995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9960461687506831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D3", 2, {
              Complex[6.1858894909919995`, -0.9960461687506831], 
              Complex[7.619257020505318, -2.10155454761218]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167174732838952, 0.992313831072267}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167174732838952`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.992313831072267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2519259901745176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D3", 1, {
              Complex[6.167174732838952, 0.992313831072267], 
              Complex[7.622160161615688, -0.2519259901745176]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185815599931938, -1.000483060574068}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185815599931938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619067332909202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907877`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D3", 2, {
              Complex[6.185815599931938, -1.000483060574068], 
              Complex[7.619067332909202, -2.105552017907877]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167194592496085, 0.9967040073387544}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167194592496085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D3", 1, {
              Complex[6.167194592496085, 0.9967040073387544], 
              Complex[7.622190248064221, -0.24794070215790154`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185742780764412, -1.004877451924907}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185742780764412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.004877451924907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1095094481136445`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D3", 2, {
              Complex[6.185742780764412, -1.004877451924907], 
              Complex[7.618879068115525, -2.1095094481136445`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167213819234735, 1.0010525529976395`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167213819234735`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D3", 1, {
              Complex[6.167213819234735, 1.0010525529976395`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185671004827051, -1.0092301787755908`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185671004827051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0092301787755908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D3", 2, {
              Complex[6.185671004827051, -1.0092301787755908`], 
              Complex[7.618692192411457, -2.113427630566214]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16723243476579, 1.005360278484099}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16723243476579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.005360278484099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107705`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D3", 1, {
              Complex[6.16723243476579, 1.005360278484099], 
              Complex[7.622247902016086, -0.24008689867107705`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18560024457066, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18560024457066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D3", 2, {
              Complex[6.18560024457066, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16725045986591, 1.0096279702007271`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16725045986591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23621687034352862`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D3", 1, {
              Complex[6.16725045986591, 1.0096279702007271`], 
              Complex[7.622275519945756, -0.23621687034352862`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185530473503019, -1.017813858605525}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185530473503019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.017813858605525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.121149303624121`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "D3", 2, {
              Complex[6.185530473503019, -1.017813858605525], 
              Complex[7.618322479547935, -2.121149303624121]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167267914426828, 1.013856391477559}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167267914426828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.013856391477559`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278943`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D3", 1, {
              Complex[6.167267914426828, 1.013856391477559], 
              Complex[7.622302363778045, -0.23238378615278943`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185461666136161, -1.0220463622527831`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185461666136161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D3", 2, {
              Complex[6.185461666136161, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167284817501548, 1.0180462834838364`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167284817501548`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399614007`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D3", 1, {
              Complex[6.167284817501548, 1.0180462834838364`], 
              Complex[7.622328456276393, -0.22858694399614007`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185393797936859, -1.0262403046082502`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185393797936859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617957948303616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.128722917140586`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "D3", 2, {
              Complex[6.185393797936859, -1.0262403046082502`], 
              Complex[7.617957948303616, -2.128722917140586]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167301187347679, 1.0221983660944405`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167301187347679`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2248256619776559`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D3", 1, {
              Complex[6.167301187347679, 1.0221983660944405`], 
              Complex[7.622353819311706, -0.2248256619776559]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185326845280091, -1.030396405990655}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185326845280091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627533`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "D3", 2, {
              Complex[6.185326845280091, -1.030396405990655], 
              Complex[7.617777553627533, -2.1324559462163153`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167317041468107, 1.0263133387136971`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167317041468107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622378473906381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2210992776263989`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D3", 1, {
              Complex[6.167317041468107, 1.0263133387136971`], 
              Complex[7.622378473906381, -0.2210992776263989]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18526078540529, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18526078540529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D3", 2, {
              Complex[6.18526078540529, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167332396649198, 1.0303918810590926`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167332396649198`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2174071471526355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D3", 1, {
              Complex[6.167332396649198, 1.0303918810590926`], 
              Complex[7.622402440275708, -0.2174071471526355]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185195596375154, -1.0385978654970505`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185195596375154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D3", 2, {
              Complex[6.185195596375154, -1.0385978654970505`], 
              Complex[7.617420370497284, -2.1398177654127495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1673472689966875`, 1.0344346539072418`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1673472689966875`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0344346539072418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986205`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D3", 1, {
              Complex[6.1673472689966875`, 1.0344346539072418`], 
              Complex[7.622425737866838, -0.21374864473986205`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185131257036874, -1.0426445649584837`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185131257036874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0426445649584837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288352`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D3", 2, {
              Complex[6.185131257036874, -1.0426445649584837`], 
              Complex[7.617243530524916, -2.1434478264288352`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16736167396946, 1.0384422998042997`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16736167396946`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D3", 1, {
              Complex[6.16736167396946, 1.0384422998042997`], 
              Complex[7.622448385395497, -0.2101231618705582]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.185067746985585, -1.0466561075785734`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.185067746985585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6170678253669655`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D3", 2, {
              Complex[6.185067746985585, -1.0466561075785734`], 
              Complex[7.6170678253669655`, -2.147044806353595]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167375626411306, 1.0424154437428594`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167375626411306`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0424154437428594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373498`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D3", 1, {
              Complex[6.167375626411306, 1.0424154437428594`], 
              Complex[7.622470400880571, -0.20653010668373498`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1850050465299, -1.0506331187508056`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1850050465299`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508056`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6168932313540685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.150609297664496`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D3", 2, {
              Complex[6.1850050465299, -1.0506331187508056`], 
              Complex[7.6168932313540685`, -2.150609297664496]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167389140580846, 1.04635469380724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167389140580846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622491801676729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2029689033624723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D3", 1, {
              Complex[6.167389140580846, 1.04635469380724], 
              Complex[7.622491801676729, -0.2029689033624723]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184943136659399, -1.0545762069524705`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184943136659399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61671972558691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D3", 2, {
              Complex[6.184943136659399, -1.0545762069524705`], 
              Complex[7.61671972558691, -2.1541418767841933`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167402230179722, 1.0502606417889433`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167402230179722`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D3", 1, {
              Complex[6.167402230179722, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1848819990139186`, -1.0584859643603293`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1848819990139186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0584859643603293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902736`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D3", 2, {
              Complex[6.1848819990139186`, -1.0584859643603293`], 
              Complex[7.616547285902736, -2.157643104664951]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167414908379169, 1.054133863773935}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167414908379169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.054133863773935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D3", 1, {
              Complex[6.167414908379169, 1.054133863773935], 
              Complex[7.622532825482894, -0.19593982579105432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184821615854545, -1.062362967438099}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184821615854545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.062362967438099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D3", 2, {
              Complex[6.184821615854545, -1.062362967438099], 
              Complex[7.616375890843667, -2.1611135273463358`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167427187845094, 1.0579749207033107`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167427187845094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021312`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D3", 1, {
              Complex[6.167427187845094, 1.0579749207033107`], 
              Complex[7.62255248014975, -0.1924708750021312]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184761970036191, -1.0662077774973115`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184761970036191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6162055196267024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "D3", 2, {
              Complex[6.184761970036191, -1.0662077774973115`], 
              Complex[7.6162055196267024`, -2.164553676487631]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167439080761725, 1.061784358908797}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167439080761725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.061784358908797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225715834948`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D3", 1, {
              Complex[6.167439080761725, 1.061784358908797], 
              Complex[7.6225715834948, -0.18903162196075954`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184703044981658, -1.070020941233001}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184703044981658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.070020941233001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "D3", 2, {
              Complex[6.184703044981658, -1.070020941233001], 
              Complex[7.616036152115315, -2.1679640698763754`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167450598853971, 1.065562710624442}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167450598853971`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.065562710624442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62259014998067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D3", 1, {
              Complex[6.167450598853971, 1.065562710624442], 
              Complex[7.62259014998067, -0.18562156282100936`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184644824657079, -1.07380299123558}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184644824657079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.07380299123558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1713452119143026`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D3", 2, {
              Complex[6.184644824657079, -1.07380299123558], 
              Complex[7.615867768792521, -2.1713452119143026`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167461753408532, 1.069310494475782}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167461753408532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891874`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D3", 1, {
              Complex[6.167461753408532, 1.069310494475782], 
              Complex[7.622608193566829, -0.18224020664891874`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184587293548676, -1.0775544464801792`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184587293548676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0775544464801792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D3", 2, {
              Complex[6.184587293548676, -1.0775544464801792`], 
              Complex[7.615700350735352, -2.1746975940818927`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167472555293864, 1.0730282159476652`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167472555293864`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1788870749784164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D3", 1, {
              Complex[6.167472555293864, 1.0730282159476652`], 
              Complex[7.622625727731571, -0.1788870749784164]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1845304366407206`, -1.081275812794643}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1845304366407206`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.081275812794643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D3", 2, {
              Complex[6.1845304366407206`, -1.081275812794643], 
              Complex[7.615533879590611, -2.17802169538267]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674830149790685`, 1.0767163678318639`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674830149790685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0767163678318639`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642138`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D3", 1, {
              Complex[6.1674830149790685`, 1.0767163678318639`], 
              Complex[7.622642765492878, -0.17556170138642138`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184474239394659, -1.0849675833073054`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184474239394659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6153683375518915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1813179827683102`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "D3", 2, {
              Complex[6.184474239394659, -1.0849675833073054`], 
              Complex[7.6153683375518915`, -2.1813179827683102`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1674931425517565`, 1.08037543065552}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1674931425517565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.08037543065552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D3", 1, {
              Complex[6.1674931425517565`, 1.08037543065552], 
              Complex[7.622659319428154, -0.1722636310861375]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184418687729288, -1.0886302388755988`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184418687729288`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D3", 2, {
              Complex[6.184418687729288, -1.0886302388755988`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167502947734983, 1.0840058730914166`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167502947734983`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759095`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D3", 1, {
              Complex[6.167502947734983, 1.0840058730914166`], 
              Complex[7.622675401692968, -0.16899242053759095`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1843637680019645`, -1.092264248496479}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843637680019645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.092264248496479`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.187828925765876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D3", 2, {
              Complex[6.1843637680019645`, -1.092264248496479], 
              Complex[7.6150399721707815`, -2.187828925765876]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167512439903273, 1.0876081523509995`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167512439903273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523509995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454118`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D3", 1, {
              Complex[6.167512439903273, 1.0876081523509995`], 
              Complex[7.622691024038829, -0.16574763707454118`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1843094669907455`, -1.0958700696995953`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1843094669907455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0958700696995953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.191044458598743`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D3", 2, {
              Complex[6.1843094669907455`, -1.0958700696995953`], 
              Complex[7.614877115758213, -2.191044458598743]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167521628097823, 1.0911827145610276`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167521628097823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854693042`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D3", 1, {
              Complex[6.167521628097823, 1.0911827145610276`], 
              Complex[7.622706197830052, -0.16252885854693042`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18425577187742, -1.0994481489240884`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18425577187742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D3", 2, {
              Complex[6.18425577187742, -1.0994481489240884`], 
              Complex[7.614715122272779, -2.194233932689377]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167530521040912, 1.0947299951246656`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167530521040912`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622720934059783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15933567297809756`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D3", 1, {
              Complex[6.167530521040912, 1.0947299951246656`], 
              Complex[7.622720934059783, -0.15933567297809756`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184202670231408, -1.1029989218798246`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184202670231408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "D3", 2, {
              Complex[6.184202670231408, -1.1029989218798246`], 
              Complex[7.6145539763350305`, -2.1973977605017105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167539127149569, 1.098250419067797}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167539127149569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360204`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D3", 1, {
              Complex[6.167539127149569, 1.098250419067797], 
              Complex[7.622735243365228, -0.1561676782360204]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184150149994408, -1.1065228138938465`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184150149994408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614393662996269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D3", 2, {
              Complex[6.184150149994408, -1.1065228138938465`], 
              Complex[7.614393662996269, -2.2005363446473227`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167547454548559, 1.1017444013712936`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167547454548559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788982`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D3", 1, {
              Complex[6.167547454548559, 1.1017444013712936`], 
              Complex[7.622749136042124, -0.15302448171788982`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.184098199465816, -1.1100202402427715`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.184098199465816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D3", 2, {
              Complex[6.184098199465816, -1.1100202402427715`], 
              Complex[7.614234167722325, -2.2036500782010373`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167555511082704, 1.1052123472899034`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167555511082704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058503`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D3", 1, {
              Complex[6.167555511082704, 1.1052123472899034`], 
              Complex[7.622762622058503, -0.14990570004738207`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1840468072888495`, -1.1134916064718126`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1840468072888495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1134916064718126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.206739345003816`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "D3", 2, {
              Complex[6.1840468072888495`, -1.1134916064718126`], 
              Complex[7.614075476378116, -2.206739345003816]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167563304328588, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167563304328588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D3", 1, {
              Complex[6.167563304328588, 1.1086546526584367`], 
              Complex[7.622775711067786, -0.14681095878399034`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183995962437312, -1.1169373087010905`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183995962437312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "D3", 2, {
              Complex[6.183995962437312, -1.1169373087010905`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16757084160569, 1.1120717041858348`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16757084160569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1120717041858348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421259`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385857`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D3", 1, {
              Complex[6.16757084160569, 1.1120717041858348`], 
              Complex[7.622788412421259, -0.14373989214385857`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183945654203009, -1.1203577339198187`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183945654203009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D3", 2, {
              Complex[6.183945654203009, -1.1203577339198187`], 
              Complex[7.613760450846203, -2.212845969284587]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167578129986962, 1.1154638797377099`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167578129986962`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1154638797377099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155717`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D3", 1, {
              Complex[6.167578129986962, 1.1154638797377099`], 
              Complex[7.622800735179931, -0.14069214273155717`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1838958721837285`, -1.1237532602689642`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838958721837285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1237532602689642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.215864050835693`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D3", 2, {
              Complex[6.1838958721837285`, -1.1237532602689642`], 
              Complex[7.613604090254429, -2.215864050835693]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167585176308896, 1.1188315486078975`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167585176308896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1188315486078975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622812688125852`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1376673612822912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D3", 1, {
              Complex[6.167585176308896, 1.1188315486078975`], 
              Complex[7.622812688125852, -0.1376673612822912]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1838466062718, -1.1271242573129145`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1838466062718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2188591143084135`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D3", 2, {
              Complex[6.1838466062718, -1.1271242573129145`], 
              Complex[7.613448480758017, -2.2188591143084135`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167591987181104, 1.1221750717795362`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167591987181104`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D3", 1, {
              Complex[6.167591987181104, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140493]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183797846643169, -1.1304710863006642`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183797846643169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006642`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613293610009215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.221831501514852`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D3", 2, {
              Complex[6.183797846643169, -1.1304710863006642`], 
              Complex[7.613293610009215, -2.221831501514852]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167598568995433, 1.1254948021761624`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167598568995433`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.13168534438923143`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D3", 1, {
              Complex[6.167598568995433, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183749583746966, -1.1337941004170402`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183749583746966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "D3", 2, {
              Complex[6.183749583746966, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167604927934658, 1.128791084903274}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167604927934658`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.128791084903274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D3", 1, {
              Complex[6.167604927934658, 1.128791084903274], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183701808295563, -1.1370936450243205`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183701808295563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "D3", 2, {
              Complex[6.183701808295563, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16761106998075, 1.1320642574808064`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16761106998075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12579120077420358`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D3", 1, {
              Complex[6.16761106998075, 1.1320642574808064`], 
              Complex[7.622856968249285, -0.12579120077420358`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183654511255059, -1.1403700578948637`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183654511255059`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D3", 2, {
              Complex[6.183654511255059, -1.1403700578948637`], 
              Complex[7.612833311505916, -2.2306159102625105`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167617000922771, 1.1353146500669256`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167617000922771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D3", 1, {
              Complex[6.167617000922771, 1.1353146500669256`], 
              Complex[7.622867194825846, -0.12287628790968698`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183607683836199, -1.1436236694349755`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183607683836199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D3", 2, {
              Complex[6.183607683836199, -1.1436236694349755`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167622726364391, 1.1385425856735312`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167622726364391`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D3", 1, {
              Complex[6.167622726364391, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183561317485685, -1.1468548029005128`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183561317485685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.236364734026166`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D3", 2, {
              Complex[6.183561317485685, -1.1468548029005128`], 
              Complex[7.612529927102651, -2.236364734026166]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676282517310606`, 1.1417483803738426`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676282517310606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1417483803738426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228866878581005`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.11710925302543031`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D3", 1, {
              Complex[6.1676282517310606`, 1.1417483803738426`], 
              Complex[7.6228866878581005`, -0.11710925302543031`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183515403877874, -1.1500637746045628`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183515403877874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "D3", 2, {
              Complex[6.183515403877874, -1.1500637746045628`], 
              Complex[7.612379246706457, -2.2392078288294064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167633582276865, 1.1449323435024108`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167633582276865`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902027`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D3", 1, {
              Complex[6.167633582276865, 1.1449323435024108`], 
              Complex[7.622895968318211, -0.11425653981902027`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183469934906837, -1.1532508941175408`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183469934906837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093195`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "D3", 2, {
              Complex[6.183469934906837, -1.1532508941175408`], 
              Complex[7.612229226993079, -2.242030438093195]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167638723091055, 1.1480947778478905`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167638723091055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62290494707578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D3", 1, {
              Complex[6.167638723091055, 1.1480947778478905`], 
              Complex[7.62290494707578, -0.11142397911299567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183424902678746, -1.1564164644600665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183424902678746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6120798578880935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "D3", 2, {
              Complex[6.183424902678746, -1.1564164644600665`], 
              Complex[7.6120798578880935`, -2.2448328483902147`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167643679104286, 1.1512359798388985`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167643679104286`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1512359798388985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761375`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D3", 1, {
              Complex[6.167643679104286, 1.1512359798388985`], 
              Complex[7.622913630641643, -0.10861129074761375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1833802995046, -1.1595607822888863`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1833802995046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1595607822888863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D3", 2, {
              Complex[6.1833802995046, -1.1595607822888863`], 
              Complex[7.611931129560044, -2.2476153402566923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167648455094579, 1.154356239723236}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167648455094579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396892`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D3", 1, {
              Complex[6.167648455094579, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183336117893254, -1.1626841380761952`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183336117893254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61178303241253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2503781883626597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D3", 2, {
              Complex[6.183336117893254, -1.1626841380761952`], 
              Complex[7.61178303241253, -2.2503781883626597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167653055693024, 1.1574558417407834`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167653055693024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986399`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D3", 1, {
              Complex[6.167653055693024, 1.1574558417407834`], 
              Complex[7.622930137328205, -0.10304443953986399`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183292350544735, -1.1657868162826117`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183292350544735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1657868162826117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "D3", 2, {
              Complex[6.183292350544735, -1.1657868162826117`], 
              Complex[7.611635557076617, -2.2531216616761847`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16765748538922, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16765748538922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622937972576472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D3", 1, {
              Complex[6.16765748538922, 1.1605350642903134`], 
              Complex[7.622937972576472, -0.10028974503145566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183248990343842, -1.1688690955240477`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183248990343842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1688690955240477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218125`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D3", 2, {
              Complex[6.183248990343842, -1.1688690955240477`], 
              Complex[7.611488694403536, -2.2558460236218125`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676617485364815`, 1.1635941800905014`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676617485364815`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040954`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D3", 1, {
              Complex[6.1676617485364815`, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1832060303540155`, -1.171931248732845}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1832060303540155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.171931248732845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233561`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D3", 2, {
              Complex[6.1832060303540155`, -1.171931248732845], 
              Complex[7.611342435457713, -2.258551532233561]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167665849356821, 1.1666334563353578`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167665849356821`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0948365296663518`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D3", 1, {
              Complex[6.167665849356821, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.0948365296663518]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183163463811437, -1.1749735433132202`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183163463811437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D3", 2, {
              Complex[6.183163463811437, -1.1749735433132202`], 
              Complex[7.611196771510031, -2.261238440302506]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167669791945717, 1.1696531548443287`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167669791945717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229598752347245`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D3", 1, {
              Complex[6.167669791945717, 1.1696531548443287`], 
              Complex[7.6229598752347245`, -0.09213750902438231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183121284119393, -1.1779962412914966`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183121284119393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194215`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D3", 2, {
              Complex[6.183121284119393, -1.1779962412914966`], 
              Complex[7.611051694031386, -2.2639069955194215`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167673580276672, 1.1726535322072742`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167673580276672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D3", 1, {
              Complex[6.167673580276672, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1830794848428505`, -1.180999599461101}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1830794848428505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.180999599461101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.266557440612444`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "D3", 2, {
              Complex[6.1830794848428505`, -1.180999599461101], 
              Complex[7.610907194686489, -2.266557440612444]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167677218205581, 1.1756348399245424`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167677218205581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340755`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D3", 1, {
              Complex[6.167677218205581, 1.1756348399245424`], 
              Complex[7.6229731957414195`, -0.08679342975340755]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.183038059703257, -1.183983869522754}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.183038059703257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "D3", 2, {
              Complex[6.183038059703257, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167680709474919, 1.1785973245423345`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167680709474919`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1785973245423345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08414790069647231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D3", 1, {
              Complex[6.167680709474919, 1.1785973245423345`], 
              Complex[7.622979487241572, -0.08414790069647231]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182997002573542, -1.1869492982198684`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182997002573542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1869492982198684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "D3", 2, {
              Complex[6.182997002573542, -1.1869492982198684`], 
              Complex[7.610619897990325, -2.271804947320256]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1676840577177385`, 1.1815412277835526`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1676840577177385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1815412277835526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D3", 1, {
              Complex[6.1676840577177385`, 1.1815412277835526`], 
              Complex[7.622985539529303, -0.08151973944306815]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182956307473314, -1.1898961274694768`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182956307473314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1898961274694768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "D3", 2, {
              Complex[6.182956307473314, -1.1898961274694768`], 
              Complex[7.610477084885045, -2.2744024707536155`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167687266461523, 1.1844667866743102`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167687266461523`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1844667866743102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07890872215171531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D3", 1, {
              Complex[6.167687266461523, 1.1844667866743102`], 
              Complex[7.622991357408529, -0.07890872215171531]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182915968564257, -1.1928245944888065`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182915968564257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610334818394682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2769828079447083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "D3", 2, {
              Complex[6.182915968564257, -1.1928245944888065`], 
              Complex[7.610334818394682, -2.2769828079447083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167690339131856, 1.1873742336662831`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167690339131856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07631462931689799`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D3", 1, {
              Complex[6.167690339131856, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.07631462931689799]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1828759801456865`, -1.1957349319176866`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1828759801456865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1957349319176866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610193091068048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.27954617871769`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "D3", 2, {
              Complex[6.1828759801456865`, -1.1957349319176866`], 
              Complex[7.610193091068048, -2.27954617871769]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167693279055961, 1.1902637967550591`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167693279055961`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672758`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D3", 1, {
              Complex[6.167693279055961, 1.1902637967550591`], 
              Complex[7.623002308533653, -0.07373724565672758]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182836336650298, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182836336650298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6100518956152605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.282092798668853`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D3", 2, {
              Complex[6.182836336650298, -1.1986273679369637`], 
              Complex[7.6100518956152605`, -2.282092798668853]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167696089466082, 1.193135699594645}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167696089466082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.07117636000425528`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D3", 1, {
              Complex[6.167696089466082, 1.193135699594645], 
              Complex[7.623007450776046, -0.07117636000425528]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182797032640057, -1.201502126383065}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182797032640057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D3", 2, {
              Complex[6.182797032640057, -1.201502126383065], 
              Complex[7.609911224902995, -2.284622879275391]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167698773502733, 1.1959901616082875`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167698773502733`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1959901616082875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62301237661067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228148`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D3", 1, {
              Complex[6.167698773502733, 1.1959901616082875`], 
              Complex[7.62301237661067, -0.06863176520228148]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182758062802262, -1.2043594268588764`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182758062802262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D3", 2, {
              Complex[6.182758062802262, -1.2043594268588764`], 
              Complex[7.60977107194993, -2.2871366280006606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167701334217814, 1.19882739809574}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167701334217814`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.19882739809574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154536`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D3", 1, {
              Complex[6.167701334217814, 1.19882739809574], 
              Complex[7.623017090253322, -0.06610325800154536]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182719421945745, -1.2071994848410685`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182719421945745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D3", 2, {
              Complex[6.182719421945745, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167703774577614, 1.201647620337123}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167703774577614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0635906389621443`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D3", 1, {
              Complex[6.167703774577614, 1.201647620337123], 
              Complex[7.623021595813279, -0.0635906389621443]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1826811049972195`, -1.210022511784006}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1826811049972195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.210022511784006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "D3", 2, {
              Complex[6.1826811049972195`, -1.210022511784006], 
              Complex[7.609492292129981, -2.2921159401997615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167706097465667, 1.2044510356934945`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167706097465667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2044510356934945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079776`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D3", 1, {
              Complex[6.167706097465667, 1.2044510356934945`], 
              Complex[7.623025897296652, -0.061093712358079776`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182643106997762, -1.2128287152203816`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182643106997762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "D3", 2, {
              Complex[6.182643106997762, -1.2128287152203816`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167708305685528, 1.2072378477042838`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167708305685528`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D3", 1, {
              Complex[6.167708305685528, 1.2072378477042838`], 
              Complex[7.62302999860963, -0.05861228608478186]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182605423099423, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182605423099423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "D3", 2, {
              Complex[6.182605423099423, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677104019634195`, 1.210008256181661}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677104019634195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.210008256181661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D3", 1, {
              Complex[6.1677104019634195`, 1.210008256181661], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182568048561961, -1.218391462677644}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182568048561961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.218391462677644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.299467386227517`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "D3", 2, {
              Complex[6.182568048561961, -1.218391462677644], 
              Complex[7.6090778393267975`, -2.299467386227517]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167712388950775, 1.2127624573020033`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167712388950775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2127624573020033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470476`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D3", 1, {
              Complex[6.167712388950775, 1.2127624573020033`], 
              Complex[7.623037615868166, -0.05369518368470476]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1825309787497025`, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1825309787497025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.301887288061049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D3", 2, {
              Complex[6.1825309787497025`, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.301887288061049]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167714269226694, 1.2155006436945395`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167714269226694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05125914066353671`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D3", 1, {
              Complex[6.167714269226694, 1.2155006436945395`], 
              Complex[7.623041139153993, -0.05125914066353671]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1824942091285005`, -1.2238893126698194`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824942091285005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2238893126698194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "D3", 2, {
              Complex[6.1824942091285005`, -1.2238893126698194`], 
              Complex[7.608803942069356, -2.3042922060350675`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167716045300302, 1.2182230045272868`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167716045300302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669026`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D3", 1, {
              Complex[6.167716045300302, 1.2182230045272868`], 
              Complex[7.623044476955637, -0.048837864018669026`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182457735262816, -1.2266143809612575`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182457735262816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.30668231891301`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "D3", 2, {
              Complex[6.182457735262816, -1.2266143809612575`], 
              Complex[7.608667696724579, -2.30668231891301]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167717719612997, 1.2209297255903704`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167717719612997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230476327242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630232`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D3", 1, {
              Complex[6.167717719612997, 1.2209297255903704`], 
              Complex[7.6230476327242, -0.0464311784630232]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1824215528129, -1.229323793839144}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1824215528129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.229323793839144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3090578022545656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D3", 2, {
              Complex[6.1824215528129, -1.229323793839144], 
              Complex[7.608531912472353, -2.3090578022545656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719294540649, 1.2236209893768326`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719294540649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623050609827915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183312117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D3", 1, {
              Complex[6.167719294540649, 1.2236209893768326`], 
              Complex[7.623050609827915, -0.04403891183312117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182385657532068, -1.2320177339512255`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182385657532068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2320177339512255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.31141882849242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D3", 2, {
              Complex[6.182385657532068, -1.2320177339512255`], 
              Complex[7.608396583634034, -2.31141882849242]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720772395696, 1.2262969751610366`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720772395696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04166089501468188`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D3", 1, {
              Complex[6.167720772395696, 1.2262969751610366`], 
              Complex[7.623053411554656, -0.04166089501468188]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182350045264077, -1.2346963807243223`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182350045264077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D3", 2, {
              Complex[6.182350045264077, -1.2346963807243223`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772215542913, 1.2289578590746735`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772215542913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.039296961870488506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D3", 1, {
              Complex[6.16772215542913, 1.2289578590746735`], 
              Complex[7.623056041114285, -0.039296961870488506`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182314711940597, -1.2373599104404132`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182314711940597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104404132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972363`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "D3", 2, {
              Complex[6.182314711940597, -1.2373599104404132`], 
              Complex[7.608127270038645, -2.3160981841972363`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723445832482, 1.2316038141805976`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723445832482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D3", 1, {
              Complex[6.167723445832482, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182279653578758, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182279653578758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "D3", 2, {
              Complex[6.182279653578758, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167724645739662, 1.2342350105444317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167724645739662`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D3", 1, {
              Complex[6.167724645739662, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182244866278791, -1.242642308546148}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182244866278791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723057`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D3", 2, {
              Complex[6.182244866278791, -1.242642308546148], 
              Complex[7.607859712684855, -2.320721705723057]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725757228776, 1.2368516153041005`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725757228776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153041005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.032288046310477825`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D3", 1, {
              Complex[6.167725757228776, 1.2368516153041005`], 
              Complex[7.6230629277676165`, -0.032288046310477825`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1822103462217495`, -1.245261514429298}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1822103462217495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.245261514429298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3230129285768606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D3", 2, {
              Complex[6.1822103462217495`, -1.245261514429298], 
              Complex[7.607726579534131, -2.3230129285768606`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772678232385, 1.2394537927373115`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772678232385`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02997884362362546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D3", 1, {
              Complex[6.16772678232385, 1.2394537927373115`], 
              Complex[7.623064899277237, -0.02997884362362546]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182176089667306, -1.2478662783795629`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182176089667306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3252906672740608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D3", 2, {
              Complex[6.182176089667306, -1.2478662783795629`], 
              Complex[7.607593869964685, -2.3252906672740608`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727722996508, 1.2420417043271579`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727722996508`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02768293620018037`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D3", 1, {
              Complex[6.167727722996508, 1.2420417043271579`], 
              Complex[7.62306671357756, -0.02768293620018037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182142092951617, -1.2504567620199438`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182142092951617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60746157901877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3275550743239184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "D3", 2, {
              Complex[6.182142092951617, -1.2504567620199438`], 
              Complex[7.60746157901877, -2.3275550743239184`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772858116758, 1.2446155088257413`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772858116758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.025400174364271125`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D3", 1, {
              Complex[6.16772858116758, 1.2446155088257413`], 
              Complex[7.623068373456371, -0.025400174364271125`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182108352485272, -1.2530331242405153`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182108352485272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2530331242405153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "D3", 2, {
              Complex[6.182108352485272, -1.2530331242405153`], 
              Complex[7.607329701831238, -2.32980629964634]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729358708656, 1.247175362316046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729358708656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.023130410967731017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D3", 1, {
              Complex[6.167729358708656, 1.247175362316046], 
              Complex[7.623069881638044, -0.023130410967731017`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182074864751301, -1.2555955212603063`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182074864751301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2555955212603063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3320444906306093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "D3", 2, {
              Complex[6.182074864751301, -1.2555955212603063`], 
              Complex[7.607198233627164, -2.3320444906306093`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730057443585, 1.249721418272031}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730057443585`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.249721418272031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071240785351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333079632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D3", 1, {
              Complex[6.167730057443585, 1.249721418272031], 
              Complex[7.623071240785351, -0.020873501333079632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182041626303249, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182041626303249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "D3", 2, {
              Complex[6.182041626303249, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730679149904, 1.2522538276170248`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730679149904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198120395`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D3", 1, {
              Complex[6.167730679149904, 1.2522538276170248`], 
              Complex[7.623072453501178, -0.018629303198120395`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.182008633763318, -1.260679031577555}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.182008633763318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.260679031577555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D3", 2, {
              Complex[6.182008633763318, -1.260679031577555], 
              Complex[7.6069365055072815`, -2.3364823468295484`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731225560259, 1.2547727387804994`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731225560259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2547727387804994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069472`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D3", 1, {
              Complex[6.167731225560259, 1.2547727387804994`], 
              Complex[7.623073522330235, -0.016397676662069472`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181975883820568, -1.2632004444906197`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181975883820568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753214`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D3", 2, {
              Complex[6.181975883820568, -1.2632004444906197`], 
              Complex[7.606806236472662, -2.3386822946753214`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731698363721, 1.2572782977532326`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731698363721`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133223097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D3", 1, {
              Complex[6.167731698363721, 1.2572782977532326`], 
              Complex[7.623074449760662, -0.014178484133223097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1819433732291715`, -1.2657084915461239`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1819433732291715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2657084915461239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3408697735514434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D3", 2, {
              Complex[6.1819433732291715`, -1.2657084915461239`], 
              Complex[7.606676358179671, -2.3408697735514434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732099207092, 1.2597706481409663`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732099207092`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307523822561`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804809`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D3", 1, {
              Complex[6.167732099207092, 1.2597706481409663`], 
              Complex[7.62307523822561, -0.01197159027804809]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181911098806735, -1.2682033164767692`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181911098806735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606546866271806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D3", 2, {
              Complex[6.181911098806735, -1.2682033164767692`], 
              Complex[7.606546866271806, -2.343044919018727]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732429696165, 1.2622499312165703`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732429696165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2622499312165703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D3", 1, {
              Complex[6.167732429696165, 1.2622499312165703`], 
              Complex[7.623075890104745, -0.009776861971693968]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1818790574326545`, -1.2706850606806677`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1818790574326545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2706850606806677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D3", 2, {
              Complex[6.1818790574326545`, -1.2706850606806677`], 
              Complex[7.606417756470163, -2.345207864426671]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732691396911, 1.2647162859707828`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732691396911`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0075941682498535355`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D3", 1, {
              Complex[6.167732691396911, 1.2647162859707828`], 
              Complex[7.623076407725729, -0.0075941682498535355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181847246046556, -1.273153863272108}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181847246046556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D3", 2, {
              Complex[6.181847246046556, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732885836667, 1.2671698491615644`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732885836667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D3", 1, {
              Complex[6.167732885836667, 1.2671698491615644`], 
              Complex[7.62307679336563, -0.005423380261944609]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181815661646743, -1.275609861130944}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181815661646743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.275609861130944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606160666446714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693729`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "D3", 2, {
              Complex[6.181815661646743, -1.275609861130944], 
              Complex[7.606160666446714, -2.349497677693729]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733014505244, 1.2696107553621172`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733014505244`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0032643712255543632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D3", 1, {
              Complex[6.167733014505244, 1.2696107553621172`], 
              Complex[7.623077049252293, -0.0032643712255543632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1817843012887375`, -1.2780531889506415`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1817843012887375`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2780531889506415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "D3", 2, {
              Complex[6.1817843012887375`, -1.2780531889506415`], 
              Complex[7.606032678038458, -2.351624801622354]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733078856032, 1.272039137007607}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733078856032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.272039137007607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821177432`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D3", 1, {
              Complex[6.167733078856032, 1.272039137007607], 
              Complex[7.623077177565682, -0.0011170163821177432`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181753162083825, -1.2804839792850273`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181753162083825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.353740237720617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "D3", 2, {
              Complex[6.181753162083825, -1.2804839792850273`], 
              Complex[7.605905055360047, -2.353740237720617]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677330803070305`, 1.2744551244406346`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677330803070305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462172547`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D3", 1, {
              Complex[6.1677330803070305`, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462172547`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181722241197679, -1.2829023625937932`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181722241197679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2829023625937932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "D3", 2, {
              Complex[6.181722241197679, -1.2829023625937932`], 
              Complex[7.605777794493473, -2.355844108978483]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167733020241881, 1.276858845955496}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167733020241881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.276858845955496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898571836`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D3", 1, {
              Complex[6.167733020241881, 1.276858845955496], 
              Complex[7.62307705996065, 0.003143219898571836]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181691535849006, -1.2853084672867796`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181691535849006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3579365364447975`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "D3", 2, {
              Complex[6.181691535849006, -1.2853084672867796`], 
              Complex[7.605650891587861, -2.3579365364447975`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677329000108365`, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677329000108365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D3", 1, {
              Complex[6.1677329000108365`, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181661043308228, -1.2877024197670905`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181661043308228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3600176392681966`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "D3", 2, {
              Complex[6.181661043308228, -1.2877024197670905`], 
              Complex[7.60552434285789, -2.3600176392681966`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732720931719, 1.2816299944237621`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732720931719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076457080134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782328045`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D3", 1, {
              Complex[6.167732720931719, 1.2816299944237621`], 
              Complex[7.623076457080134, 0.007358287782328045]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181630760896252, -1.2900843444730699`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181630760896252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D3", 2, {
              Complex[6.181630760896252, -1.2900843444730699`], 
              Complex[7.605398144582301, -2.3620875347369377`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732484290831, 1.2839976681063678`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732484290831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230759786378925`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.009449175160798436`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D3", 1, {
              Complex[6.167732484290831, 1.2839976681063678`], 
              Complex[7.6230759786378925`, 0.009449175160798436]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181600685983191, -1.2924543639191768`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181600685983191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2924543639191768`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3641463383176777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D3", 2, {
              Complex[6.181600685983191, -1.2924543639191768`], 
              Complex[7.605272293102373, -2.3641463383176777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167732191343831, 1.2863535694098465`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167732191343831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2863535694098465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075384765489`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.011529116733913576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D3", 1, {
              Complex[6.167732191343831, 1.2863535694098465`], 
              Complex[7.623075384765489, 0.011529116733913576`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181570815987224, -1.2948125987358035`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181570815987224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.366194163693253`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D3", 2, {
              Complex[6.181570815987224, -1.2948125987358035`], 
              Complex[7.605146784820535, -2.366194163693253]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731843316621, 1.2886978170110817`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731843316621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01359822423913699`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D3", 1, {
              Complex[6.167731843316621, 1.2886978170110817`], 
              Complex[7.62307467734139, 0.01359822423913699]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181541148373396, -1.2971591677080394`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181541148373396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D3", 2, {
              Complex[6.181541148373396, -1.2971591677080394`], 
              Complex[7.605021616198942, -2.3682311227994597`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167731441406146, 1.2910305277808336`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167731441406146`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2910305277808336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073858205366`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.01565660770491178`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D3", 1, {
              Complex[6.167731441406146, 1.2910305277808336`], 
              Complex[7.623073858205366, 0.01565660770491178]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18151168065253, -1.2994941878134685`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18151168065253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "D3", 2, {
              Complex[6.18151168065253, -1.2994941878134685`], 
              Complex[7.604896783758138, -2.370257325860909]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730986781208, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730986781208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D3", 1, {
              Complex[6.167730986781208, 1.2933518168205271`], 
              Complex[7.623072929159485, 0.017704375485551985`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181482410380124, -1.3018177742589643`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181482410380124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3722728814259395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "D3", 2, {
              Complex[6.181482410380124, -1.3018177742589643`], 
              Complex[7.604772284075737, -2.3722728814259395`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167730480583245, 1.2956617974980968`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167730480583245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969078`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295235202`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D3", 1, {
              Complex[6.167730480583245, 1.2956617974980968`], 
              Complex[7.623071891969078, 0.019741634295235202`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18145333515529, -1.3041300405165688`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18145333515529`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3742778964006495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "D3", 2, {
              Complex[6.18145333515529, -1.3041300405165688`], 
              Complex[7.604648113785144, -2.3742778964006495`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729923927075, 1.2979605814829254`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729923927075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.021768489241138847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D3", 1, {
              Complex[6.167729923927075, 1.2979605814829254`], 
              Complex[7.623070748363671, 0.021768489241138847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181424452619743, -1.3064310983584468`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181424452619743`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60452426957432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3762724760820615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D3", 2, {
              Complex[6.181424452619743, -1.3064310983584468`], 
              Complex[7.60452426957432, -2.3762724760820615`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167729317901629, 1.3002482787798992`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167729317901629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3002482787798992`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D3", 1, {
              Complex[6.167729317901629, 1.3002482787798992`], 
              Complex[7.623069500037891, 0.023785043855733566`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181395760456799, -1.3087210578909678`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181395760456799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6044007481845695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3782567241904524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D3", 2, {
              Complex[6.181395760456799, -1.3087210578909678`], 
              Complex[7.6044007481845695`, -2.3782567241904524`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167728663570656, 1.3025249977626074`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167728663570656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{
                    "0.025791400128269082`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D3", 1, {
              Complex[6.167728663570656, 1.3025249977626074`], 
              Complex[7.623068148652344, 0.025791400128269082`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181367256390402, -1.3110000275879252`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181367256390402`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "D3", 2, {
              Complex[6.181367256390402, -1.3110000275879252`], 
              Complex[7.604277546409371, -2.380230742900865]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727961973395, 1.304790845205713}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727961973395`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.304790845205713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.027787658535467812`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D3", 1, {
              Complex[6.167727961973395, 1.304790845205713], 
              Complex[7.623066695834459, 0.027787658535467812`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181338938184205, -1.3132681143229286`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181338938184205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093243`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873834`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "D3", 2, {
              Complex[6.181338938184205, -1.3132681143229286`], 
              Complex[7.604154661093243, -2.382194632873834]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167727214125249, 1.307045926316517}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167727214125249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.307045926316517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179327`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D3", 1, {
              Complex[6.167727214125249, 1.307045926316517], 
              Complex[7.623065143179327, 0.02977391807145791]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.18131080364063, -1.3155254234009877`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.18131080364063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3155254234009877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.384148493285349`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D3", 2, {
              Complex[6.18131080364063, -1.3155254234009877`], 
              Complex[7.604032089130619, -2.384148493285349]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167726421018415, 1.3092903447657456`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167726421018415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696591`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D3", 1, {
              Complex[6.167726421018415, 1.3092903447657456`], 
              Complex[7.623063492250484, 0.03175027627696591]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181282850600006, -1.3177720585893227`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181282850600006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603909827464783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3860924218560764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D3", 2, {
              Complex[6.181282850600006, -1.3177720585893227`], 
              Complex[7.603909827464783, -2.3860924218560764`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167725583622502, 1.311524202717574}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167725583622502`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778366`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D3", 1, {
              Complex[6.167725583622502, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778366]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181255076939699, -1.3200081221474058`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181255076939699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.388026514879854`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D3", 2, {
              Complex[6.181255076939699, -1.3200081221474058`], 
              Complex[7.603787873086824, -2.388026514879854]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.16772470288514, 1.313747600858923}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.16772470288514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.313747600858923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D3", 1, {
              Complex[6.16772470288514, 1.313747600858923], 
              Complex[7.623059901672726, 0.03567367176254808]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181227480573279, -1.32223371485628}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181227480573279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32223371485628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3899508672515015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "D3", 2, {
              Complex[6.181227480573279, -1.32223371485628], 
              Complex[7.603666223034602, -2.3899508672515015`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167723779732554, 1.3159606384280345`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167723779732554`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623057965000035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03762089710983448`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D3", 1, {
              Complex[6.167723779732554, 1.3159606384280345`], 
              Complex[7.623057965000035, 0.03762089710983448]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181200059449696, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181200059449696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3918655724939386`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "D3", 2, {
              Complex[6.181200059449696, -1.32444893604715], 
              Complex[7.603544874391759, -2.3918655724939386`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167722815070127, 1.3181634132423612`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167722815070127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007519`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03955859731459801`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D3", 1, {
              Complex[6.167722815070127, 1.3181634132423612`], 
              Complex[7.623055936007519, 0.03955859731459801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1811728115525035`, -1.3266538836292885`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1811728115525035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3266538836292885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603423824286758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.393770722784648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D3", 2, {
              Complex[6.1811728115525035`, -1.3266538836292885`], 
              Complex[7.603423824286758, -2.393770722784648]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167721809782957, 1.3203560217257764`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167721809782957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305381611219`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D3", 1, {
              Complex[6.167721809782957, 1.3203560217257764`], 
              Complex[7.62305381611219, 0.04148686306397192]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181145734899095, -1.3288486541172821`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181145734899095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.395666408981522`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D3", 2, {
              Complex[6.181145734899095, -1.3288486541172821`], 
              Complex[7.603303069891951, -2.395666408981522]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167720764736373, 1.322538558935139}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167720764736373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.322538558935139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305160670384`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245208`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D3", 1, {
              Complex[6.167720764736373, 1.322538558935139], 
              Complex[7.62305160670384, 0.04340578375245208]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181118827539914, -1.3310333426575782`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181118827539914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3310333426575782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60318260842262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D3", 2, {
              Complex[6.181118827539914, -1.3310333426575782`], 
              Complex[7.60318260842262, -2.3975527206480334`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167719680776454, 1.3247111185862182`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167719680776454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.045315447506474774`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D3", 1, {
              Complex[6.167719680776454, 1.3247111185862182`], 
              Complex[7.6230493091457, 0.045315447506474774`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1810920875578015`, -1.3332080430544786`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810920875578015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3332080430544786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3994297460778915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "D3", 2, {
              Complex[6.1810920875578015`, -1.3332080430544786`], 
              Complex[7.6030624371361615`, -2.3994297460778915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.167718558730529, 1.326873793079005}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.167718558730529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.326873793079005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04721594120841103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D3", 1, {
              Complex[6.167718558730529, 1.326873793079005], 
              Complex[7.623046924775063, 0.04721594120841103]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.181065513067208, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.181065513067208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "D3", 2, {
              Complex[6.181065513067208, -1.3353728477954119`], 
              Complex[7.602942553331131, -2.4012975723190064`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], 
          TagBox[
           TooltipBox[PointBox[{6.1677173994076595`, 1.3290266735224265`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1677173994076595`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3290266735224265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999627`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D3", 1, {
              Complex[6.1677173994076595`, 1.3290266735224265`], 
              Complex[7.623044454903904, 0.04910735051999627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], 
          TagBox[
           TooltipBox[PointBox[{6.1810391022135605`, -1.337527848075709}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1810391022135605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.337527848075709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4031562851969848`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "D3", 2, {
              Complex[6.1810391022135605`, -1.337527848075709], 
              Complex[7.602822954346457, -2.4031562851969848`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.262317347784464, 0.16611165996512323`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C3", 1, {
              Complex[9.262317347784464, 0.16611165996512323`], 
              Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.380653624650824, -0.17373265713467972`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C3", 2, {
              Complex[9.380653624650824, -0.17373265713467972`], 
              Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.27379501912068, 0.20695392178184982`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C3", 1, {
              Complex[9.27379501912068, 0.20695392178184982`], 
              Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.369040024240906, -0.21458598503237647`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C3", 2, {
              Complex[9.369040024240906, -0.21458598503237647`], 
              Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.280570529089989, 0.24191392575349288`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C3", 1, {
              Complex[9.280570529089989, 0.24191392575349288`], 
              Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.362131033190314, -0.2495568531847539}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C3", 2, {
              Complex[9.362131033190314, -0.2495568531847539], 
              Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.285085225476458, 0.27256109297706776`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C3", 1, {
              Complex[9.285085225476458, 0.27256109297706776`], 
              Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.357485218342608, -0.2802146897125705}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C3", 2, {
              Complex[9.357485218342608, -0.2802146897125705], 
              Complex[7.660008665723722, -1.440191789692609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.288342049505975, 0.3000009300835058}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C3", 1, {
              Complex[9.288342049505975, 0.3000009300835058], 
              Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.35409955758327, -0.30766500790255313`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C3", 2, {
              Complex[9.35409955758327, -0.30766500790255313`], 
              Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.290821923790588, 0.32496389242763857`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C3", 1, {
              Complex[9.290821923790588, 0.32496389242763857`], 
              Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.351493051581292, -0.33263826942312025`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C3", 2, {
              Complex[9.351493051581292, -0.33263826942312025`], 
              Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.292784687952791, 0.34794816918876}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C3", 1, {
              Complex[9.292784687952791, 0.34794816918876], 
              Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.349405787878045, -0.35563266944840766`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C3", 2, {
              Complex[9.349405787878045, -0.35563266944840766`], 
              Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.294383744285957, 0.36930769700429716`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C3", 1, {
              Complex[9.294383744285957, 0.36930769700429716`], 
              Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.347684294964536, -0.37700215031345224`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C3", 2, {
              Complex[9.347684294964536, -0.37700215031345224`], 
              Complex[7.649655116243796, -1.530899113668034]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.29571595421648, 0.3893033507690842}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C3", 1, {
              Complex[9.29571595421648, 0.3893033507690842], 
              Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.346231645579115, -0.3970075923331433}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C3", 2, {
              Complex[9.346231645579115, -0.3970075923331433], 
              Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.296845766278874, 0.4081334915298239}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C3", 1, {
              Complex[9.296845766278874, 0.4081334915298239], 
              Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.344983328511988, -0.41584736171471265`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.344983328511988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.41584736171471265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6466264937920405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5672411924777172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.499999999999996`, "C3", 2, {
              Complex[9.344983328511988, -0.41584736171471265`], 
              Complex[7.6466264937920405`, -1.5672411924777172`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.297817893725249, 0.42595292805234636`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C3", 1, {
              Complex[9.297817893725249, 0.42595292805234636`], 
              Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.343894570793292, -0.4336762721416326}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.343894570793292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4336762721416326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.645371333222616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.583906400971115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.599999999999998`, "C3", 2, {
              Complex[9.343894570793292, -0.4336762721416326], 
              Complex[7.645371333222616, -1.583906400971115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.298664434058157, 0.44288515307919907`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C3", 1, {
              Complex[9.298664434058157, 0.44288515307919907`], 
              Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.342933217974057, -0.45061782104638065`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342933217974057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45061782104638065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.644243187304668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5997328108831592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.7, "C3", 2, {
              Complex[9.342933217974057, -0.45061782104638065`], 
              Complex[7.644243187304668, -1.5997328108831592`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.299409090344204, 0.45903052180506093`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C3", 1, {
              Complex[9.299409090344204, 0.45903052180506093`], 
              Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.342075512640728, -0.4667723681000823}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.342075512640728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4667723681000823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6432188767245925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6148150957352265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.799999999999997`, "C3", 2, {
              Complex[9.342075512640728, -0.4667723681000823], 
              Complex[7.6432188767245925`, -1.6148150957352265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.300069789499112, 0.47447188989313444`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C3", 1, {
              Complex[9.300069789499112, 0.47447188989313444`], 
              Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.341303475971888, -0.4822227732417421}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.341303475971888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4822227732417421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.64228080795274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6292314506639929`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.899999999999995`, "C3", 2, {
              Complex[9.341303475971888, -0.4822227732417421], 
              Complex[7.64228080795274, -1.6292314506639929`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.300660369136605, 0.4892786068277399}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C3", 1, {
              Complex[9.300660369136605, 0.4892786068277399], 
              Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.340603220742913, -0.497038390042908}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.340603220742913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.497038390042908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6414153511463985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6430473477012997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.999999999999996`, "C3", 2, {
              Complex[9.340603220742913, -0.497038390042908], 
              Complex[7.6414153511463985`, -1.6430473477012997`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.301191700128847, 0.503509412285517}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C3", 1, {
              Complex[9.301191700128847, 0.503509412285517], 
              Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.339963828630122, -0.5112779620899647}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339963828630122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5112779620899647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.640611758766885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6563182605942428`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.099999999999998`, "C3", 2, {
              Complex[9.339963828630122, -0.5112779620899647], 
              Complex[7.640611758766885, -1.6563182605942428`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.301672454837956, 0.5172145811965813}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C3", 1, {
              Complex[9.301672454837956, 0.5172145811965813], 
              Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.339376581853779, -0.5249917680556035}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.339376581853779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5249917680556035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639861424222358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6690916835589524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.2, "C3", 2, {
              Complex[9.339376581853779, -0.5249917680556035], 
              Complex[7.639861424222358, -1.6690916835589524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302109645838716, 0.5304375419992581}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C3", 1, {
              Complex[9.302109645838716, 0.5304375419992581], 
              Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.338834424339028, -0.5382232399630629}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338834424339028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5382232399630629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.639157361075561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6814086547578186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.3, "C3", 2, {
              Complex[9.338834424339028, -0.5382232399630629], 
              Complex[7.639157361075561, -1.6814086547578186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302509011886752, 0.5432161176861714}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C3", 1, {
              Complex[9.302509011886752, 0.5432161176861714], 
              Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.338331575639637, -0.5510102042411122}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.338331575639637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5510102042411122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.638493829265324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.693304925020469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.4, "C3", 2, {
              Complex[9.338331575639637, -0.5510102042411122], 
              Complex[7.638493829265324, -1.693304925020469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.302875299750397, 0.5555834916479572}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C3", 1, {
              Complex[9.302875299750397, 0.5555834916479572], 
              Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337863249005673, -0.5633858475760003}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337863249005673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5633858475760003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6378660616946545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.70481186766115`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.499999999999996`, "C3", 2, {
              Complex[9.337863249005673, -0.5633858475760003], 
              Complex[7.6378660616946545`, -1.70481186766115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.303212473521276, 0.5675689693259758}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C3", 1, {
              Complex[9.303212473521276, 0.5675689693259758], 
              Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337425441979393, -0.5753794785718535}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337425441979393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5753794785718535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.637270060814722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7159571961426487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.599999999999998`, "C3", 2, {
              Complex[9.337425441979393, -0.5753794785718535], 
              Complex[7.637270060814722, -1.7159571961426487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.303523872448524, 0.5791985860418385}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C3", 1, {
              Complex[9.303523872448524, 0.5791985860418385], 
              Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.337014778473906, -0.5870171355873209}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.337014778473906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5870171355873209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636702444963451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7267655369464128`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.7, "C3", 2, {
              Complex[9.337014778473906, -0.5870171355873209], 
              Complex[7.636702444963451, -1.7267655369464128`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.303812331602318, 0.5904955973399487}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C3", 1, {
              Complex[9.303812331602318, 0.5904955973399487], 
              Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.336628388028364, -0.5983220770848241}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336628388028364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5983220770848241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.636160330682661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7372588918245433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.799999999999997`, "C3", 2, {
              Complex[9.336628388028364, -0.5983220770848241], 
              Complex[7.636160330682661, -1.7372588918245433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304080275277004, 0.6014808784641332}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C3", 1, {
              Complex[9.304080275277004, 0.6014808784641332], 
              Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.336263812328982, -0.609315181113391}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.336263812328982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.609315181113391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635641241458829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.747457014478097`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.9, "C3", 2, {
              Complex[9.336263812328982, -0.609315181113391], 
              Complex[7.635641241458829, -1.747457014478097]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304329790117846, 0.612173252747982}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C3", 1, {
              Complex[9.304329790117846, 0.612173252747982], 
              Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.335918932011362, -0.6200152737048319}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335918932011362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6200152737048319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.635143036145728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7573777202744643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {22.999999999999996`, "C3", 2, {
              Complex[9.335918932011362, -0.6200152737048319], 
              Complex[7.635143036145728, -1.7573777202744643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30456268297077, 0.6225897638061416}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C3", 1, {
              Complex[9.30456268297077, 0.6225897638061416], 
              Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.335591908744412, -0.6304394010704698}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.335591908744412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6304394010704698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.63466385223734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7670371430158247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.099999999999998`, "C3", 2, {
              Complex[9.335591908744412, -0.6304394010704698], 
              Complex[7.63466385223734, -1.7670371430158247`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304780527085194, 0.6327459028649576}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C3", 1, {
              Complex[9.304780527085194, 0.6327459028649576], 
              Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33528113896544, -0.6406030569368892}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33528113896544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6406030569368892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.634202060478484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7764499494328059`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.199999999999996`, "C3", 2, {
              Complex[9.33528113896544, -0.6406030569368892], 
              Complex[7.634202060478484, -1.7764499494328059`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.304984699340448, 0.6426557999628848}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C3", 1, {
              Complex[9.304984699340448, 0.6426557999628848], 
              Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334985216595475, -0.6505203737511226}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334985216595475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6505203737511226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633756228225985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7856295196238638`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.299999999999997`, "C3", 2, {
              Complex[9.334985216595475, -0.6505203737511226], 
              Complex[7.633756228225985, -1.7856295196238638`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305176410484561, 0.6523323858111223}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C3", 1, {
              Complex[9.305176410484561, 0.6523323858111223], 
              Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334702902745928, -0.6602042845457757}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334702902745928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6602042845457757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.633325089631603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7945880998355062`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.4, "C3", 2, {
              Complex[9.334702902745928, -0.6602042845457757], 
              Complex[7.633325089631603, -1.7945880998355062`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30535672988259, 0.6617875296457956}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C3", 1, {
              Complex[9.30535672988259, 0.6617875296457956], 
              Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334433100918964, -0.6696666607954201}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334433100918964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6696666607954201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6329075211926085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.803336932605163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.5, "C3", 2, {
              Complex[9.334433100918964, -0.6696666607954201], 
              Complex[7.6329075211926085`, -1.803336932605163]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305526605913883, 0.6710321572939462}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C3", 1, {
              Complex[9.305526605913883, 0.6710321572939462], 
              Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.334174836562127, -0.6789184304865283}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.334174836562127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6789184304865283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632502521562484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8118863682445574`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.6, "C3", 2, {
              Complex[9.334174836562127, -0.6789184304865283], 
              Complex[7.632502521562484, -1.8118863682445574`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305686882893223, 0.6800763528244194}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C3", 1, {
              Complex[9.305686882893223, 0.6800763528244194], 
              Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333927240101854, -0.6879696797720991}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333927240101854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6879696797720991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.632109194769857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8202459608400863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.699999999999996`, "C3", 2, {
              Complex[9.333927240101854, -0.6879696797720991], 
              Complex[7.632109194769857, -1.8202459608400863`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305838315194185, 0.6889294464957751}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C3", 1, {
              Complex[9.305838315194185, 0.6889294464957751], 
              Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333689532777536, -0.6968297409230606}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333689532777536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6968297409230606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.631726736184739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8284245513261361`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.799999999999997`, "C3", 2, {
              Complex[9.333689532777536, -0.6968297409230606], 
              Complex[7.631726736184739, -1.8284245513261361`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.305981579104797, 0.697600091198504}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C3", 1, {
              Complex[9.305981579104797, 0.697600091198504], 
              Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333461014745714, -0.705507268773781}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333461014745714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.705507268773781`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6313544207148105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8364303397024744`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {23.9, "C3", 2, {
              Complex[9.333461014745714, -0.705507268773781], 
              Complex[7.6313544207148105`, -1.8364303397024744`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30611728283302, 0.7060963291837463}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C3", 1, {
              Complex[9.30611728283302, 0.7060963291837463], 
              Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33324105503674, -0.7140103074539126}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33324105503674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7140103074539126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630991592823766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8442709480852433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24., "C3", 2, {
              Complex[9.33324105503674, -0.7140103074539126], 
              Complex[7.630991592823766, -1.8442709480852433`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306245974993525, 0.7144256505494249}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C3", 1, {
              Complex[9.306245974993525, 0.7144256505494249], 
              Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.333029083032358, -0.7223463488774439}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.333029083032358`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7223463488774439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630637658047721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8519534759784038`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.099999999999994`, "C3", 2, {
              Complex[9.333029083032358, -0.7223463488774439], 
              Complex[7.630637658047721, -1.8519534759784038`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306368151840394, 0.722595044698084}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C3", 1, {
              Complex[9.306368151840394, 0.722595044698084], 
              Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332824581199281, -0.73052238420331}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332824581199281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.73052238420331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.630292075750291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8594845489107188`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.199999999999996`, "C3", 2, {
              Complex[9.332824581199281, -0.73052238420331], 
              Complex[7.630292075750291, -1.8594845489107188`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30648426345883, 0.730611045774511}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C3", 1, {
              Complex[9.30648426345883, 0.730611045774511], 
              Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332627078865713, -0.7385449492756353}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332627078865713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7385449492756353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629954352907652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8668703613890223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.299999999999997`, "C3", 2, {
              Complex[9.332627078865713, -0.7385449492756353], 
              Complex[7.629954352907652, -1.8668703613890223`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30659471908804, 0.7384797729243899}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C3", 1, {
              Complex[9.30659471908804, 0.7384797729243899], 
              Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332436146868352, -0.7464201648848554}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332436146868352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7464201648848554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629624038754354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8741167149612874`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.4, "C3", 2, {
              Complex[9.332436146868352, -0.7464201648848554], 
              Complex[7.629624038754354, -1.8741167149612874`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306699891715693, 0.7462069660795199}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C3", 1, {
              Complex[9.306699891715693, 0.7462069660795199], 
              Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332251392929535, -0.7541537725552647}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332251392929535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7541537725552647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.629300720152121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.881229052055075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.499999999999996`, "C3", 2, {
              Complex[9.332251392929535, -0.7541537725552647], 
              Complex[7.629300720152121, -1.881229052055075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306800122058599, 0.7537980178639988}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C3", 1, {
              Complex[9.306800122058599, 0.7537980178639988], 
              Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.332072457649627, -0.7617511664534365}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.332072457649627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7617511664534365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628984017568608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8882124861522411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.599999999999998`, "C3", 2, {
              Complex[9.332072457649627, -0.7617511664534365], 
              Complex[7.628984017568608, -1.8882124861522411`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306895722024107, 0.7612580021246124}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C3", 1, {
              Complex[9.306895722024107, 0.7612580021246124], 
              Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33189901102014, -0.7692174219206883}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33189901102014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7692174219206883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62867358157315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8950718287747004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.7, "C3", 2, {
              Complex[9.33189901102014, -0.7692174219206883], 
              Complex[7.62867358157315, -1.8950718287747004`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.306986977730267, 0.7685916995129599}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C3", 1, {
              Complex[9.306986977730267, 0.7685916995129599], 
              Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331730749379409, -0.7765573210571958}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331730749379409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7765573210571958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62836908977242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018116136847973`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.8, "C3", 2, {
              Complex[9.331730749379409, -0.7765573210571958], 
              Complex[7.62836908977242, -1.9018116136847973`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30707415214959, 0.7758036204842984}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C3", 1, {
              Complex[9.30707415214959, 0.7758036204842984], 
              Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331567392745953, -0.7837753757227326}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331567392745953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7837753757227326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.628070244122036`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9084361186447758`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.9, "C3", 2, {
              Complex[9.331567392745953, -0.7837753757227326], 
              Complex[7.628070244122036, -1.9084361186447758`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307157487430532, 0.7828980260257034}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C3", 1, {
              Complex[9.307157487430532, 0.7828980260257034], 
              Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331408682475267, -0.7908758482666055}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331408682475267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7908758482666055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627776768560511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9149493850304053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {24.999999999999996`, "C3", 2, {
              Complex[9.331408682475267, -0.7908758482666055], 
              Complex[7.627776768560511, -1.9149493850304053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307237206941968, 0.7898789463823147}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C3", 1, {
              Complex[9.307237206941968, 0.7898789463823147], 
              Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331254379194702, -0.7978627702556061}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331254379194702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7978627702556061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627488406920755`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9213552355525565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.099999999999998`, "C3", 2, {
              Complex[9.331254379194702, -0.7978627702556061], 
              Complex[7.627488406920755, -1.9213552355525565`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307313517078901, 0.7967501980135657}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C3", 1, {
              Complex[9.307313517078901, 0.7967501980135657], 
              Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.331104260978192, -0.8047399594318435}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.331104260978192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8047399594318435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.627204921081202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9276572903056561`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.199999999999996`, "C3", 2, {
              Complex[9.331104260978192, -0.8047399594318435], 
              Complex[7.627204921081202, -1.9276572903056561`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307386608861503, 0.8035153989801238}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C3", 1, {
              Complex[9.307386608861503, 0.8035153989801238], 
              Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330958121728596, -0.811511035101225}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330958121728596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.811511035101225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626926089324718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9338589813326057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.299999999999997`, "C3", 2, {
              Complex[9.330958121728596, -0.811511035101225], 
              Complex[7.626926089324718, -1.9338589813326057`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307456659354887, 0.8101779829358526}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C3", 1, {
              Complex[9.307456659354887, 0.8101779829358526], 
              Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330815769740232, -0.818179432126868}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330815769740232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.818179432126868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6266517048780145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9399635658707661`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.399999999999995`, "C3", 2, {
              Complex[9.330815769740232, -0.818179432126868], 
              Complex[7.6266517048780145`, -1.9399635658707661`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307523832932748, 0.8167412118766469}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C3", 1, {
              Complex[9.307523832932748, 0.8167412118766469], 
              Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330677026418373, -0.824748413679325}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330677026418373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.824748413679325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626381574608514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.945974138422464`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.499999999999996`, "C3", 2, {
              Complex[9.330677026418373, -0.824748413679325], 
              Complex[7.626381574608514, -1.945974138422464]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307588282404819, 0.8232081877787825}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C3", 1, {
              Complex[9.307588282404819, 0.8232081877787825], 
              Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330541725135806, -0.8312210828762443}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330541725135806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8312210828762443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.626115517858926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9518936417752968`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.599999999999998`, "C3", 2, {
              Complex[9.330541725135806, -0.8312210828762443], 
              Complex[7.626115517858926, -1.9518936417752968`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30765015002498, 0.8295818632429439}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C3", 1, {
              Complex[9.30765015002498, 0.8295818632429439], 
              Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330409710209448, -0.8376003934276777}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330409710209448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8376003934276777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625853365402524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9577248770820381`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.7, "C3", 2, {
              Complex[9.330409710209448, -0.8376003934276777], 
              Complex[7.625853365402524, -1.9577248770820381`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30770956839477, 0.8358650512460974}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C3", 1, {
              Complex[9.30770956839477, 0.8358650512460974], 
              Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.33028083598227, -0.8438891593891124}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.33028083598227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8438891593891124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625594958504519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9634705130965746`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.799999999999997`, "C3", 2, {
              Complex[9.33028083598227, -0.8438891593891124], 
              Complex[7.625594958504519, -1.9634705130965746`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307766661274705, 0.8420604340909561}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C3", 1, {
              Complex[9.307766661274705, 0.8420604340909561], 
              Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330154965998151, -0.8500900641121139}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330154965998151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8500900641121139`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625340148077106`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9691330946508248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {25.9, "C3", 2, {
              Complex[9.330154965998151, -0.8500900641121139], 
              Complex[7.625340148077106, -1.9691330946508248`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307821544314418, 0.8481705716325364}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26., "C3", 1, {
              Complex[9.307821544314418, 0.8481705716325364], 
              Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.330031972258514, -0.856205668471937}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.330031972258514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856205668471937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.625088793917112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747150504476334`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26., "C3", 2, {
              Complex[9.330031972258514, -0.856205668471937], 
              Complex[7.625088793917112, -1.9747150504476334`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307874325710909, 0.8541979088518956}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C3", 1, {
              Complex[9.307874325710909, 0.8541979088518956], 
              Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329911734551446, -0.8622384184423436}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329911734551446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8622384184423436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6248407640169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9802187002360254`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.099999999999998`, "C3", 2, {
              Complex[9.329911734551446, -0.8622384184423436], 
              Complex[7.6248407640169, -1.9802187002360254`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30792510680319, 0.860144782839487}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C3", 1, {
              Complex[9.30792510680319, 0.860144782839487], 
              Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32979413984504, -0.8681906520799052}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32979413984504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8681906520799052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624595933940287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9856462614276869`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.2, "C3", 2, {
              Complex[9.32979413984504, -0.8681906520799052], 
              Complex[7.624595933940287, -1.9856462614276869`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.307973982610356, 0.8660134292433511}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C3", 1, {
              Complex[9.307973982610356, 0.8660134292433511], 
              Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329679081737801, -0.8740646059731706}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329679081737801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8740646059731706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6243541862563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.990999855207028`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.299999999999997`, "C3", 2, {
              Complex[9.329679081737801, -0.8740646059731706], 
              Complex[7.6243541862563, -1.990999855207028]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308021042319387, 0.8718059882315835}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C3", 1, {
              Complex[9.308021042319387, 0.8718059882315835], 
              Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329566459959892, -0.8798624212060276}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329566459959892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8798624212060276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.624115410024538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.996281512181469`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.399999999999995`, "C3", 2, {
              Complex[9.329566459959892, -0.8798624212060276], 
              Complex[7.624115410024538, -1.996281512181469]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308066369728037, 0.8775245100130518}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C3", 1, {
              Complex[9.308066369728037, 0.8775245100130518], 
              Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32945617991971, -0.8855861488792872}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32945617991971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8855861488792872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623879500326575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0014931776135643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.499999999999996`, "C3", 2, {
              Complex[9.32945617991971, -0.8855861488792872], 
              Complex[7.623879500326575, -2.0014931776135643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308110043647693, 0.8831709599557607}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C3", 1, {
              Complex[9.308110043647693, 0.8831709599557607], 
              Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329348152291017, -0.8912377552298729}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329348152291017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8912377552298729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623646357838642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.006636716272229`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.599999999999998`, "C3", 2, {
              Complex[9.329348152291017, -0.8912377552298729], 
              Complex[7.623646357838642, -2.006636716272229]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30815213827031, 0.888747223338151}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C3", 1, {
              Complex[9.30815213827031, 0.888747223338151], 
              Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329242292636387, -0.8968191263829126}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329242292636387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8968191263829126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623415888441285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0117139169364284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.699999999999996`, "C3", 2, {
              Complex[9.329242292636387, -0.8968191263829126], 
              Complex[7.623415888441285, -2.0117139169364284`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308192723503184, 0.8942551097650254}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C3", 1, {
              Complex[9.308192723503184, 0.8942551097650254], 
              Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329138521063246, -0.9023320727684233}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329138521063246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9023320727684233`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623188002862294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.016726496581311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.799999999999997`, "C3", 2, {
              Complex[9.329138521063246, -0.9023320727684233], 
              Complex[7.623188002862294, -2.016726496581311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30823186527481, 0.8996963572765849}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C3", 1, {
              Complex[9.30823186527481, 0.8996963572765849], 
              Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.329036761909217, -0.9077783332310709}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.329036761909217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9077783332310709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622962616349544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0216761042737272`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {26.9, "C3", 2, {
              Complex[9.329036761909217, -0.9077783332310709], 
              Complex[7.622962616349544, -2.0216761042737272`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308269625814717, 0.9050726361762732}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27., "C3", 1, {
              Complex[9.308269625814717, 0.9050726361762732], 
              Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328936943453858, -0.9131595788587061}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328936943453858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9131595788587061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227396483708265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.026564324801445`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27., "C3", 2, {
              Complex[9.328936943453858, -0.9131595788587061], 
              Complex[7.6227396483708265`, -2.026564324801445]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308306063909846, 0.9103855526005625}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C3", 1, {
              Complex[9.308306063909846, 0.9103855526005625], 
              Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328838997654197, -0.9184774165528234}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328838997654197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9184774165528234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622519022338057`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0313926820579584`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.1, "C3", 2, {
              Complex[9.328838997654197, -0.9184774165528234], 
              Complex[7.622519022338057, -2.0313926820579584`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308341235139771, 0.9156366518516708}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C3", 1, {
              Complex[9.308341235139771, 0.9156366518516708], 
              Complex[7.621537327849359, -0.321751242072515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328742859901782, -0.923733392361904}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328742859901782`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.923733392361904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62230066535352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.036162642202724`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.2, "C3", 2, {
              Complex[9.328742859901782, -0.923733392361904], 
              Complex[7.62230066535352, -2.036162642202724]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308375192092747, 0.9208274215121248}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C3", 1, {
              Complex[9.308375192092747, 0.9208274215121248], 
              Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328648468799225, -0.9289289945966074}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328648468799225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9289289945966074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622084507976147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.040875616614767`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.299999999999997`, "C3", 2, {
              Complex[9.328648468799225, -0.9289289945966074], 
              Complex[7.622084507976147, -2.040875616614767]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30840798456442, 0.9259592943584085}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C3", 1, {
              Complex[9.30840798456442, 0.9259592943584085], 
              Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32855576595434, -0.9340656567439881}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32855576595434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9340656567439881`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62187048400586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.045532964655917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.4, "C3", 2, {
              Complex[9.32855576595434, -0.9340656567439881], 
              Complex[7.62187048400586, -2.045532964655917]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308439659740836, 0.931033651089264}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C3", 1, {
              Complex[9.308439659740836, 0.931033651089264], 
              Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328464695790345, -0.9391447601963729}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328464695790345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9391447601963729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621658530284444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.050135996258459`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.499999999999993`, "C3", 2, {
              Complex[9.328464695790345, -0.9391447601963729], 
              Complex[7.621658530284444, -2.050135996258459]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30847026236711, 0.9360518228828761}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C3", 1, {
              Complex[9.30847026236711, 0.9360518228828761], 
              Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328375205370595, -0.9441676368090878}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328375205370595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9441676368090878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621448586511421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0546859743506434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.599999999999994`, "C3", 2, {
              Complex[9.328375205370595, -0.9441676368090878], 
              Complex[7.621448586511421, -2.0546859743506434`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308499834903161, 0.9410150937958542}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C3", 1, {
              Complex[9.308499834903161, 0.9410150937958542], 
              Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32828724423658, -0.9491355712999281}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32828724423658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9491355712999281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621240595073557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0591841171322502`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.699999999999996`, "C3", 2, {
              Complex[9.32828724423658, -0.9491355712999281], 
              Complex[7.621240595073557, -2.0591841171322502`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308528417667576, 0.9459247030157971}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C3", 1, {
              Complex[9.308528417667576, 0.9459247030157971], 
              Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328200764258014, -0.9540498035022821}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328200764258014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9540498035022821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621034500886904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.063631600211478`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.799999999999997`, "C3", 2, {
              Complex[9.328200764258014, -0.9540498035022821], 
              Complex[7.621034500886904, -2.063631600211478]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308556048970686, 0.9507818469782096}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C3", 1, {
              Complex[9.308556048970686, 0.9507818469782096], 
              Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328115719493917, -0.9589115304824558}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328115719493917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9589115304824558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620830251250195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0680295586131603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.9, "C3", 2, {
              Complex[9.328115719493917, -0.9589115304824558], 
              Complex[7.620830251250195, -2.0680295586131603`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308582765237823, 0.9555876813576076}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C3", 1, {
              Complex[9.308582765237823, 0.9555876813576076], 
              Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.328032066063827, -0.9637219085312987}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.328032066063827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9637219085312987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6206277957087085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0723790886678484`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {27.999999999999996`, "C3", 2, {
              Complex[9.328032066063827, -0.9637219085312987], 
              Complex[7.6206277957087085`, -2.0723790886678484`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30860860112351, 0.960343322941825}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C3", 1, {
              Complex[9.30860860112351, 0.960343322941825], 
              Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327949762028192, -0.9684820550389235}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327949762028192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9684820550389235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620427085927699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0766812497901053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.099999999999998`, "C3", 2, {
              Complex[9.327949762028192, -0.9684820550389235], 
              Complex[7.620427085927699, -2.0766812497901053`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308633589617479, 0.9650498513977598}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C3", 1, {
              Complex[9.308633589617479, 0.9650498513977598], 
              Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327868767277202, -0.9731930502608676}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327868767277202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9731930502608676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620228075574522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809370661539037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.2, "C3", 2, {
              Complex[9.327868767277202, -0.9731930502608676], 
              Complex[7.620228075574522, -2.0809370661539037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30865776214308, 0.9697083109361536}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C3", 1, {
              Complex[9.30865776214308, 0.9697083109361536], 
              Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327789043427426, -0.9778559389833152}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327789043427426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9778559389833152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620030720208938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.08514752827235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.3, "C3", 2, {
              Complex[9.327789043427426, -0.9778559389833152], 
              Complex[7.620030720208938, -2.08514752827235]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30868114864878, 0.974319711882344}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C3", 1, {
              Complex[9.30868114864878, 0.974319711882344], 
              Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327710553725511, -0.9824717320942182}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327710553725511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9824717320942182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619834977180716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.089313594488205`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.399999999999995`, "C3", 2, {
              Complex[9.327710553725511, -0.9824717320942182], 
              Complex[7.619834977180716, -2.089313594488205]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308703777693312, 0.9788850321593942}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C3", 1, {
              Complex[9.308703777693312, 0.9788850321593942], 
              Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32763326295845, -0.9870414080668136}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32763326295845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9870414080668136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619640805534105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.093436192381357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.499999999999996`, "C3", 2, {
              Complex[9.32763326295845, -0.9870414080668136], 
              Complex[7.619640805534105, -2.093436192381357]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308725676524938, 0.9834052186894814}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C3", 1, {
              Complex[9.308725676524938, 0.9834052186894814], 
              Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327557137369855, -0.991565914361383}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327557137369855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.991565914361383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619448165918566`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.097516220098791`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.599999999999998`, "C3", 2, {
              Complex[9.327557137369855, -0.991565914361383], 
              Complex[7.619448165918566, -2.097516220098791]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308746871155384, 0.9878811887189863}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C3", 1, {
              Complex[9.308746871155384, 0.9878811887189863], 
              Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327482144581792, -0.9960461687506829}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327482144581792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9960461687506829`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619257020505317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.10155454761218`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.699999999999996`, "C3", 2, {
              Complex[9.327482144581792, -0.9960461687506829], 
              Complex[7.619257020505317, -2.10155454761218]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308767386428746, 0.9923138310722672}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C3", 1, {
              Complex[9.308767386428746, 0.9923138310722672], 
              Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32740825352173, -1.000483060574067}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32740825352173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.000483060574067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190673329092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.105552017907876`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.799999999999994`, "C3", 2, {
              Complex[9.32740825352173, -1.000483060574067], 
              Complex[7.6190673329092, -2.105552017907876]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30878724608588, 0.9967040073387546}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C3", 1, {
              Complex[9.30878724608588, 0.9967040073387546], 
              Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327335434354206, -1.0048774519249142`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327335434354206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0048774519249142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618879068115525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109509448113651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.899999999999995`, "C3", 2, {
              Complex[9.327335434354206, -1.0048774519249142`], 
              Complex[7.618879068115525, -2.109509448113651]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308806472824529, 1.0010525529976397`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C3", 1, {
              Complex[9.308806472824529, 1.0010525529976397`], 
              Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327263658416845, -1.009230178775591}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327263658416845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009230178775591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618692192411457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.113427630566214`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {28.999999999999996`, "C3", 2, {
              Complex[9.327263658416845, -1.009230178775591], 
              Complex[7.618692192411457, -2.113427630566214]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308825088355581, 1.0053602784840994`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C3", 1, {
              Complex[9.308825088355581, 1.0053602784840994`], 
              Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327192898160455, -1.013542052044059}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327192898160455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.013542052044059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618506673321678`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1173073338233785`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.099999999999998`, "C3", 2, {
              Complex[9.327192898160455, -1.013542052044059], 
              Complex[7.618506673321678, -2.1173073338233785`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308843113455703, 1.0096279702007276`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C3", 1, {
              Complex[9.308843113455703, 1.0096279702007276`], 
              Complex[7.622275519945756, -0.236216870343528]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327123127092824, -1.0178138586055234`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327123127092824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0178138586055234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618322479547946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.12114930362412`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.2, "C3", 2, {
              Complex[9.327123127092824, -1.0178138586055234`], 
              Complex[7.618322479547946, -2.12114930362412]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308860568016621, 1.0138563914775585`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C3", 1, {
              Complex[9.308860568016621, 1.0138563914775585`], 
              Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.327054319725956, -1.0220463622527831`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.327054319725956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0220463622527831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618139580912272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.124954263799971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.299999999999997`, "C3", 2, {
              Complex[9.327054319725956, -1.0220463622527831`], 
              Complex[7.618139580912272, -2.124954263799971]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308877471091341, 1.0180462834838366`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C3", 1, {
              Complex[9.308877471091341, 1.0180462834838366`], 
              Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326986451526654, -1.0262403046082496`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326986451526654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0262403046082496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6179579483036175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.128722917140585`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.4, "C3", 2, {
              Complex[9.326986451526654, -1.0262403046082496`], 
              Complex[7.6179579483036175`, -2.128722917140585]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308893840937472, 1.0221983660944407`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C3", 1, {
              Complex[9.308893840937472, 1.0221983660944407`], 
              Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326919498869884, -1.030396405990655}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326919498869884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.030396405990655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617777553627534`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1324559462163153`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.5, "C3", 2, {
              Complex[9.326919498869884, -1.030396405990655], 
              Complex[7.617777553627534, -2.1324559462163153`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.3089096950579, 1.0263133387136967`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C3", 1, {
              Complex[9.3089096950579, 1.0263133387136967`], 
              Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326853438995084, -1.034515366239107}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326853438995084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.034515366239107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175983697588965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.136154014160339`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.599999999999998`, "C3", 2, {
              Complex[9.326853438995084, -1.034515366239107], 
              Complex[7.6175983697588965`, -2.136154014160339]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30892505023899, 1.0303918810590929`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C3", 1, {
              Complex[9.30892505023899, 1.0303918810590929`], 
              Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326788249964949, -1.0385978654970531`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326788249964949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0385978654970531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617420370497285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1398177654127517`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.699999999999996`, "C3", 2, {
              Complex[9.326788249964949, -1.0385978654970531`], 
              Complex[7.617420370497285, -2.1398177654127517`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30893992258648, 1.034434653907242}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C3", 1, {
              Complex[9.30893992258648, 1.034434653907242], 
              Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326723910626667, -1.042644564958483}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326723910626667`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.042644564958483`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617243530524916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1434478264288344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.799999999999997`, "C3", 2, {
              Complex[9.326723910626667, -1.042644564958483], 
              Complex[7.617243530524916, -2.1434478264288344`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308954327559254, 1.0384422998042997`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C3", 1, {
              Complex[9.308954327559254, 1.0384422998042997`], 
              Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32666040057538, -1.0466561075785734`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32666040057538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0466561075785734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617067825366967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.147044806353595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.899999999999995`, "C3", 2, {
              Complex[9.32666040057538, -1.0466561075785734`], 
              Complex[7.617067825366967, -2.147044806353595]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308968280001098, 1.042415443742859}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C3", 1, {
              Complex[9.308968280001098, 1.042415443742859], 
              Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326597700119693, -1.0506331187508058`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326597700119693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0506331187508058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616893231354067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.150609297664497`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {29.999999999999996`, "C3", 2, {
              Complex[9.326597700119693, -1.0506331187508058`], 
              Complex[7.616893231354067, -2.150609297664497]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30898179417064, 1.04635469380724}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C3", 1, {
              Complex[9.30898179417064, 1.04635469380724], 
              Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326535790249194, -1.0545762069524702`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326535790249194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0545762069524702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616719725586911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1541418767841924`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.099999999999998`, "C3", 2, {
              Complex[9.326535790249194, -1.0545762069524702`], 
              Complex[7.616719725586911, -2.1541418767841924`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.308994883769515, 1.0502606417889433`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C3", 1, {
              Complex[9.308994883769515, 1.0502606417889433`], 
              Complex[7.622512604505212, -0.199438991549757]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326474652603713, -1.058485964360329}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326474652603713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.058485964360329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616547285902738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.157643104664951`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.199999999999996`, "C3", 2, {
              Complex[9.326474652603713, -1.058485964360329], 
              Complex[7.616547285902738, -2.157643104664951]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309007561968963, 1.0541338637739348`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C3", 1, {
              Complex[9.309007561968963, 1.0541338637739348`], 
              Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326414269444339, -1.0623629674380988`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326414269444339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0623629674380988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616375890843669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1611135273463358`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.299999999999997`, "C3", 2, {
              Complex[9.326414269444339, -1.0623629674380988`], 
              Complex[7.616375890843669, -2.1611135273463358`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309019841434887, 1.0579749207033116`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C3", 1, {
              Complex[9.309019841434887, 1.0579749207033116`], 
              Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326354623625987, -1.0662077774973113`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326354623625987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0662077774973113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616205519626703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.164553676487631`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.4, "C3", 2, {
              Complex[9.326354623625987, -1.0662077774973113`], 
              Complex[7.616205519626703, -2.164553676487631]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309031734351517, 1.0617843589087967`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C3", 1, {
              Complex[9.309031734351517, 1.0617843589087967`], 
              Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326295698571451, -1.0700209412330057`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326295698571451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0700209412330057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616036152115314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1679640698763802`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.5, "C3", 2, {
              Complex[9.326295698571451, -1.0700209412330057`], 
              Complex[7.616036152115314, -2.1679640698763802`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309043252443763, 1.0655627106244419`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C3", 1, {
              Complex[9.309043252443763, 1.0655627106244419`], 
              Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326237478246874, -1.0738029912355802`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326237478246874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0738029912355802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615867768792523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.171345211914303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.599999999999998`, "C3", 2, {
              Complex[9.326237478246874, -1.0738029912355802`], 
              Complex[7.615867768792523, -2.171345211914303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309054406998325, 1.069310494475782}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C3", 1, {
              Complex[9.309054406998325, 1.069310494475782], 
              Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326179947138467, -1.077554446480185}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326179947138467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.077554446480185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615700350735349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1746975940818984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.699999999999996`, "C3", 2, {
              Complex[9.326179947138467, -1.077554446480185], 
              Complex[7.615700350735349, -2.1746975940818984`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309065208883657, 1.0730282159476647`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C3", 1, {
              Complex[9.309065208883657, 1.0730282159476647`], 
              Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.326123090230514, -1.0812758127946427`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.326123090230514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0812758127946427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615533879590611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.17802169538267`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.799999999999997`, "C3", 2, {
              Complex[9.326123090230514, -1.0812758127946427`], 
              Complex[7.615533879590611, -2.17802169538267]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30907566856886, 1.076716367831864}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C3", 1, {
              Complex[9.30907566856886, 1.076716367831864], 
              Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32606689298445, -1.0849675833073058`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32606689298445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0849675833073058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61536833755189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.181317982768311`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.9, "C3", 2, {
              Complex[9.32606689298445, -1.0849675833073058`], 
              Complex[7.61536833755189, -2.181317982768311]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309085796141549, 1.0803754306555196`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C3", 1, {
              Complex[9.309085796141549, 1.0803754306555196`], 
              Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32601134131908, -1.0886302388755993`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32601134131908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0886302388755993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615203707337716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1845869115455567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "C3", 2, {
              Complex[9.32601134131908, -1.0886302388755993`], 
              Complex[7.615203707337716, -2.1845869115455567`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309095601324776, 1.0840058730914168`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C3", 1, {
              Complex[9.309095601324776, 1.0840058730914168`], 
              Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325956421591757, -1.0922642484964793`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325956421591757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0922642484964793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6150399721707815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1878289257658765`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "C3", 2, {
              Complex[9.325956421591757, -1.0922642484964793`], 
              Complex[7.6150399721707815`, -2.1878289257658765`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309105093493066, 1.0876081523510002`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C3", 1, {
              Complex[9.309105093493066, 1.0876081523510002`], 
              Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325902120580537, -1.0958700696995949`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325902120580537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0958700696995949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614877115758213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1910444585987423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "C3", 2, {
              Complex[9.325902120580537, -1.0958700696995949`], 
              Complex[7.614877115758213, -2.1910444585987423`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309114281687616, 1.0911827145610287`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C3", 1, {
              Complex[9.309114281687616, 1.0911827145610287`], 
              Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325848425467212, -1.0994481489240884`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325848425467212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0994481489240884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614715122272777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.194233932689377`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "C3", 2, {
              Complex[9.325848425467212, -1.0994481489240884`], 
              Complex[7.614715122272777, -2.194233932689377]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309123174630706, 1.0947299951246658`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C3", 1, {
              Complex[9.309123174630706, 1.0947299951246658`], 
              Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.3257953238212, -1.1029989218798244`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3257953238212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1029989218798244`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6145539763350305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1973977605017097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "C3", 2, {
              Complex[9.3257953238212, -1.1029989218798244`], 
              Complex[7.6145539763350305`, -2.1973977605017097`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309131780739362, 1.098250419067798}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C3", 1, {
              Complex[9.309131780739362, 1.098250419067798], 
              Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325742803584212, -1.1065228138938557`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325742803584212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1065228138938557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61439366299628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2005363446473316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "C3", 2, {
              Complex[9.325742803584212, -1.1065228138938557`], 
              Complex[7.61439366299628, -2.2005363446473316`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309140108138353, 1.1017444013712938`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C3", 1, {
              Complex[9.309140108138353, 1.1017444013712938`], 
              Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325690853055608, -1.1100202402427715`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325690853055608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1100202402427715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614234167722324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2036500782010373`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "C3", 2, {
              Complex[9.325690853055608, -1.1100202402427715`], 
              Complex[7.614234167722324, -2.2036500782010373`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309148164672497, 1.1052123472899034`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C3", 1, {
              Complex[9.309148164672497, 1.1052123472899034`], 
              Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325639460878643, -1.1134916064718128`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325639460878643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1134916064718128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614075476378116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2067393450038164`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "C3", 2, {
              Complex[9.325639460878643, -1.1134916064718128`], 
              Complex[7.614075476378116, -2.2067393450038164`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309155957918382, 1.1086546526584367`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C3", 1, {
              Complex[9.309155957918382, 1.1086546526584367`], 
              Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325588616027105, -1.1169373087010908`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325588616027105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1169373087010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613917575212898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2098045199535914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "C3", 2, {
              Complex[9.325588616027105, -1.1169373087010908`], 
              Complex[7.613917575212898, -2.2098045199535914`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309163495195484, 1.112071704185835}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C3", 1, {
              Complex[9.309163495195484, 1.112071704185835], 
              Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325538307792803, -1.1203577339198192`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325538307792803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1203577339198192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613760450846203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.212845969284587`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "C3", 2, {
              Complex[9.325538307792803, -1.1203577339198192`], 
              Complex[7.613760450846203, -2.212845969284587]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309170783576755, 1.11546387973771}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C3", 1, {
              Complex[9.309170783576755, 1.11546387973771], 
              Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325488525773522, -1.1237532602689644`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325488525773522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1237532602689644`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613604090254429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2158640508356933`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "C3", 2, {
              Complex[9.325488525773522, -1.1237532602689644`], 
              Complex[7.613604090254429, -2.2158640508356933`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309177829898688, 1.118831548607897}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C3", 1, {
              Complex[9.309177829898688, 1.118831548607897], 
              Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325439259861593, -1.1271242573129148`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325439259861593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1271242573129148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613448480758017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.218859114308414`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "C3", 2, {
              Complex[9.325439259861593, -1.1271242573129148`], 
              Complex[7.613448480758017, -2.218859114308414]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309184640770896, 1.1221750717795362`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C3", 1, {
              Complex[9.309184640770896, 1.1221750717795362`], 
              Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325390500232961, -1.1304710863006695`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325390500232961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1304710863006695`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6132936100092135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2218315015148575`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "C3", 2, {
              Complex[9.325390500232961, -1.1304710863006695`], 
              Complex[7.6132936100092135`, -2.2218315015148575`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309191222585227, 1.1254948021761624`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C3", 1, {
              Complex[9.309191222585227, 1.1254948021761624`], 
              Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32534223733676, -1.1337941004170402`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32534223733676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1337941004170402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613139465980372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2247815466162493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "C3", 2, {
              Complex[9.32534223733676, -1.1337941004170402`], 
              Complex[7.613139465980372, -2.2247815466162493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309197581524451, 1.1287910849032743`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C3", 1, {
              Complex[9.309197581524451, 1.1287910849032743`], 
              Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325294461885356, -1.1370936450243205`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325294461885356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1370936450243205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612986036952771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.227709576352396`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "C3", 2, {
              Complex[9.325294461885356, -1.1370936450243205`], 
              Complex[7.612986036952771, -2.227709576352396]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309203723570544, 1.1320642574808066`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C3", 1, {
              Complex[9.309203723570544, 1.1320642574808066`], 
              Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325247164844853, -1.1403700578948632`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325247164844853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1403700578948632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612833311505918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2306159102625105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "C3", 2, {
              Complex[9.325247164844853, -1.1403700578948632`], 
              Complex[7.612833311505918, -2.2306159102625105`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309209654512566, 1.1353146500669253`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C3", 1, {
              Complex[9.309209654512566, 1.1353146500669253`], 
              Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325200337425992, -1.1436236694349757`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325200337425992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1436236694349757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612681278507311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335008608977986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "C3", 2, {
              Complex[9.325200337425992, -1.1436236694349757`], 
              Complex[7.612681278507311, -2.2335008608977986`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309215379954184, 1.1385425856735312`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C3", 1, {
              Complex[9.309215379954184, 1.1385425856735312`], 
              Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325153971075487, -1.1468548029005257`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325153971075487`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1468548029005257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612529927102659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2363647340261776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "C3", 2, {
              Complex[9.325153971075487, -1.1468548029005257`], 
              Complex[7.612529927102659, -2.2363647340261776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309220905320853, 1.1417483803738433`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C3", 1, {
              Complex[9.309220905320853, 1.1417483803738433`], 
              Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325108057467666, -1.1500637746045623`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325108057467666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1500637746045623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612379246706456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2392078288294064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "C3", 2, {
              Complex[9.325108057467666, -1.1500637746045623`], 
              Complex[7.612379246706456, -2.2392078288294064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30922623586666, 1.1449323435024106`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C3", 1, {
              Complex[9.30922623586666, 1.1449323435024106`], 
              Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325062588496635, -1.1532508941175512`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325062588496635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532508941175512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612229226993084`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.242030438093204`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "C3", 2, {
              Complex[9.325062588496635, -1.1532508941175512`], 
              Complex[7.612229226993084, -2.242030438093204]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30923137668085, 1.1480947778478905`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33., "C3", 1, {
              Complex[9.30923137668085, 1.1480947778478905`], 
              Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.325017556268538, -1.1564164644600665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.325017556268538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1564164644600665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612079857888092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2448328483902147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "C3", 2, {
              Complex[9.325017556268538, -1.1564164644600665`], 
              Complex[7.612079857888092, -2.2448328483902147`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309236332694079, 1.151235979838898}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C3", 1, {
              Complex[9.309236332694079, 1.151235979838898], 
              Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324972953094393, -1.159560782288886}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324972953094393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159560782288886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611931129560043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2476153402566923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "C3", 2, {
              Complex[9.324972953094393, -1.159560782288886], 
              Complex[7.611931129560043, -2.2476153402566923`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309241108684372, 1.154356239723236}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C3", 1, {
              Complex[9.309241108684372, 1.154356239723236], 
              Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32492877148305, -1.1626841380761932`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32492877148305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626841380761932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611783032412532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.250378188362658`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "C3", 2, {
              Complex[9.32492877148305, -1.1626841380761932`], 
              Complex[7.611783032412532, -2.250378188362658]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309245709282818, 1.1574558417407832`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C3", 1, {
              Complex[9.309245709282818, 1.1574558417407832`], 
              Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324885004134527, -1.165786816282607}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324885004134527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.165786816282607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611635557076616`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2531216616761798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "C3", 2, {
              Complex[9.324885004134527, -1.165786816282607], 
              Complex[7.611635557076616, -2.2531216616761798`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309250138979012, 1.1605350642903134`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C3", 1, {
              Complex[9.309250138979012, 1.1605350642903134`], 
              Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324841643933642, -1.168869095524045}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324841643933642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.168869095524045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611488694403542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2558460236218103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "C3", 2, {
              Complex[9.324841643933642, -1.168869095524045], 
              Complex[7.611488694403542, -2.2558460236218103`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309254402126275, 1.1635941800905014`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C3", 1, {
              Complex[9.309254402126275, 1.1635941800905014`], 
              Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324798683943808, -1.1719312487328415`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324798683943808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1719312487328415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611342435457713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.258551532233558`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "C3", 2, {
              Complex[9.324798683943808, -1.1719312487328415`], 
              Complex[7.611342435457713, -2.258551532233558]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309258502946614, 1.1666334563353578`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C3", 1, {
              Complex[9.309258502946614, 1.1666334563353578`], 
              Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324756117401245, -1.1749735433132202`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324756117401245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1749735433132202`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611196771510045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.261238440302506`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "C3", 2, {
              Complex[9.324756117401245, -1.1749735433132202`], 
              Complex[7.611196771510045, -2.261238440302506]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30926244553551, 1.1696531548443287`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C3", 1, {
              Complex[9.30926244553551, 1.1696531548443287`], 
              Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324713937709186, -1.1779962412914933`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324713937709186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1779962412914933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611051694031386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2639069955194184`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "C3", 2, {
              Complex[9.324713937709186, -1.1779962412914933`], 
              Complex[7.611051694031386, -2.2639069955194184`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309266233866467, 1.1726535322072742`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C3", 1, {
              Complex[9.309266233866467, 1.1726535322072742`], 
              Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324672138432646, -1.180999599461105}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324672138432646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.180999599461105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610907194686491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2665574406124485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "C3", 2, {
              Complex[9.324672138432646, -1.180999599461105], 
              Complex[7.610907194686491, -2.2665574406124485`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309269871795374, 1.1756348399245429`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C3", 1, {
              Complex[9.309269871795374, 1.1756348399245429`], 
              Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32463071329305, -1.183983869522754}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32463071329305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.183983869522754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610763265327906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2691900134801815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "C3", 2, {
              Complex[9.32463071329305, -1.183983869522754], 
              Complex[7.610763265327906, -2.2691900134801815`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309273363064712, 1.178597324542335}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C3", 1, {
              Complex[9.309273363064712, 1.178597324542335], 
              Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324589656163337, -1.186949298219872}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324589656163337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.186949298219872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610619897990326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271804947320259`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "C3", 2, {
              Complex[9.324589656163337, -1.186949298219872], 
              Complex[7.610619897990326, -2.271804947320259]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309276711307533, 1.1815412277835524`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C3", 1, {
              Complex[9.309276711307533, 1.1815412277835524`], 
              Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324548961063108, -1.18989612746948}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324548961063108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.18989612746948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610477084885046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2744024707536186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "C3", 2, {
              Complex[9.324548961063108, -1.18989612746948], 
              Complex[7.610477084885046, -2.2744024707536186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309279920051315, 1.18446678667431}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C3", 1, {
              Complex[9.309279920051315, 1.18446678667431], 
              Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324508622154049, -1.1928245944888063`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324508622154049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1928245944888063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61033481839468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.276982807944708`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "C3", 2, {
              Complex[9.324508622154049, -1.1928245944888063`], 
              Complex[7.61033481839468, -2.276982807944708]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30928299272165, 1.1873742336662831`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C3", 1, {
              Complex[9.30928299272165, 1.1873742336662831`], 
              Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32446863373548, -1.195734931917687}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32446863373548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.195734931917687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61019309106805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2795461787176903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "C3", 2, {
              Complex[9.32446863373548, -1.195734931917687], 
              Complex[7.61019309106805, -2.2795461787176903`]}, 0}, "Tooltip"]
           & ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309285932645754, 1.1902637967550587`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C3", 1, {
              Complex[9.309285932645754, 1.1902637967550587`], 
              Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324428990240092, -1.1986273679369637`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324428990240092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986273679369637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.610051895615262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2820927986688537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "C3", 2, {
              Complex[9.324428990240092, -1.1986273679369637`], 
              Complex[7.610051895615262, -2.2820927986688537`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309288743055875, 1.193135699594645}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C3", 1, {
              Complex[9.309288743055875, 1.193135699594645], 
              Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32438968622985, -1.201502126383065}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32438968622985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201502126383065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609911224902993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.284622879275391`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "C3", 2, {
              Complex[9.32438968622985, -1.201502126383065], 
              Complex[7.609911224902993, -2.284622879275391]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309291427092525, 1.195990161608288}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C3", 1, {
              Complex[9.309291427092525, 1.195990161608288], 
              Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324350716392056, -1.2043594268588769`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324350716392056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043594268588769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60977107194993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2871366280006615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "C3", 2, {
              Complex[9.324350716392056, -1.2043594268588769`], 
              Complex[7.60977107194993, -2.2871366280006615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309293987807608, 1.1988273980957402`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C3", 1, {
              Complex[9.309293987807608, 1.1988273980957402`], 
              Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324312075535536, -1.2071994848410685`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324312075535536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2071994848410685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609631429922364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2896342483960783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "C3", 2, {
              Complex[9.324312075535536, -1.2071994848410685`], 
              Complex[7.609631429922364, -2.2896342483960783`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309296428167405, 1.201647620337122}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C3", 1, {
              Complex[9.309296428167405, 1.201647620337122], 
              Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324273758587013, -1.2100225117840062`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324273758587013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2100225117840062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609492292129981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2921159401997615`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "C3", 2, {
              Complex[9.324273758587013, -1.2100225117840062`], 
              Complex[7.609492292129981, -2.2921159401997615`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309298751055461, 1.204451035693495}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C3", 1, {
              Complex[9.309298751055461, 1.204451035693495], 
              Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324235760587555, -1.2128287152203814`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324235760587555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2128287152203814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609353652021759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2945818994320715`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "C3", 2, {
              Complex[9.324235760587555, -1.2128287152203814`], 
              Complex[7.609353652021759, -2.2945818994320715`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30930095927532, 1.2072378477042842`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35., "C3", 1, {
              Complex[9.30930095927532, 1.2072378477042842`], 
              Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324198076689216, -1.215618298858686}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324198076689216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.215618298858686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.609215503182056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2970323184881387`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "C3", 2, {
              Complex[9.324198076689216, -1.215618298858686], 
              Complex[7.609215503182056, -2.2970323184881387`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309303055553212, 1.2100082561816605`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C3", 1, {
              Complex[9.309303055553212, 1.2100082561816605`], 
              Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324160702151756, -1.2183914626776438`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324160702151756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2183914626776438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6090778393267975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2994673862275166`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "C3", 2, {
              Complex[9.324160702151756, -1.2183914626776438`], 
              Complex[7.6090778393267975`, -2.2994673862275166`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309305042540569, 1.212762457302003}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C3", 1, {
              Complex[9.309305042540569, 1.212762457302003], 
              Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324123632339496, -1.2211484030177213`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324123632339496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2211484030177213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608940654299824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018872880610495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "C3", 2, {
              Complex[9.324123632339496, -1.2211484030177213`], 
              Complex[7.608940654299824, -2.3018872880610495`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30930692281649, 1.2155006436945397`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C3", 1, {
              Complex[9.30930692281649, 1.2155006436945397`], 
              Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324086862718293, -1.2238893126698196`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324086862718293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2238893126698196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608803942069354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3042922060350675`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "C3", 2, {
              Complex[9.324086862718293, -1.2238893126698196`], 
              Complex[7.608803942069354, -2.3042922060350675`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309308698890094, 1.2182230045272866`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C3", 1, {
              Complex[9.309308698890094, 1.2182230045272866`], 
              Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32405038885261, -1.2266143809612582`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32405038885261`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2266143809612582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608667696724579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3066823189130106`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "C3", 2, {
              Complex[9.32405038885261, -1.2266143809612582`], 
              Complex[7.608667696724579, -2.3066823189130106`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309310373202791, 1.2209297255903702`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C3", 1, {
              Complex[9.309310373202791, 1.2209297255903702`], 
              Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.324014206402694, -1.2293237938391435`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.324014206402694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2293237938391435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608531912472354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.309057802254565`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "C3", 2, {
              Complex[9.324014206402694, -1.2293237938391435`], 
              Complex[7.608531912472354, -2.309057802254565]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309311948130448, 1.2236209893768368`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C3", 1, {
              Complex[9.309311948130448, 1.2236209893768368`], 
              Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323978311121861, -1.232017733951227}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323978311121861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.232017733951227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608396583634034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311418828492422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "C3", 2, {
              Complex[9.323978311121861, -1.232017733951227], 
              Complex[7.608396583634034, -2.311418828492422]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30931342598549, 1.2262969751610369`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C3", 1, {
              Complex[9.30931342598549, 1.2262969751610369`], 
              Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323942698853871, -1.2346963807243225`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323942698853871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2346963807243225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608261704642392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3137655670067088`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "C3", 2, {
              Complex[9.323942698853871, -1.2346963807243225`], 
              Complex[7.608261704642392, -2.3137655670067088`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309314809018922, 1.2289578590746733`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C3", 1, {
              Complex[9.309314809018922, 1.2289578590746733`], 
              Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323907365530383, -1.2373599104403945`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323907365530383`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2373599104403945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608127270038639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3160981841972186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "C3", 2, {
              Complex[9.323907365530383, -1.2373599104403945`], 
              Complex[7.608127270038639, -2.3160981841972186`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309316099422276, 1.2316038141805976`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C3", 1, {
              Complex[9.309316099422276, 1.2316038141805976`], 
              Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323872307168552, -1.2400084963104758`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323872307168552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2400084963104758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6079932744696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3184168435535706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "C3", 2, {
              Complex[9.323872307168552, -1.2400084963104758`], 
              Complex[7.6079932744696, -2.3184168435535706`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309317299329457, 1.2342350105444317`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C3", 1, {
              Complex[9.309317299329457, 1.2342350105444317`], 
              Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323837519868585, -1.242642308546154}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323837519868585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.242642308546154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607859712684855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.320721705723063`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "C3", 2, {
              Complex[9.323837519868585, -1.242642308546154], 
              Complex[7.607859712684855, -2.320721705723063]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30931841081857, 1.2368516153040952`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C3", 1, {
              Complex[9.30931841081857, 1.2368516153040952`], 
              Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323802999811543, -1.2452615144292978`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323802999811543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2452615144292978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607726579534131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32301292857686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "C3", 2, {
              Complex[9.323802999811543, -1.2452615144292978`], 
              Complex[7.607726579534131, -2.32301292857686]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319435913645, 1.2394537927373108`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C3", 1, {
              Complex[9.309319435913645, 1.2394537927373108`], 
              Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.3237687432571, -1.2478662783795624`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.3237687432571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2478662783795624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607593869964685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32529066727406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "C3", 2, {
              Complex[9.3237687432571, -1.2478662783795624`], 
              Complex[7.607593869964685, -2.32529066727406]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309320376586301, 1.2420417043271583`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C3", 1, {
              Complex[9.309320376586301, 1.2420417043271583`], 
              Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323734746541412, -1.2504567620199438`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323734746541412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2504567620199438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607461579018771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.327555074323918`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "C3", 2, {
              Complex[9.323734746541412, -1.2504567620199438`], 
              Complex[7.607461579018771, -2.327555074323918]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309321234757373, 1.2446155088257416`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C3", 1, {
              Complex[9.309321234757373, 1.2446155088257416`], 
              Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323701006075066, -1.253033124240515}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323701006075066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.253033124240515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607329701831238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.32980629964634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "C3", 2, {
              Complex[9.323701006075066, -1.253033124240515], 
              Complex[7.607329701831238, -2.32980629964634]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932201229845, 1.247175362316046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C3", 1, {
              Complex[9.30932201229845, 1.247175362316046], 
              Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323667518341093, -1.255595521260306}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323667518341093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.255595521260306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607198233627162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.332044490630609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "C3", 2, {
              Complex[9.323667518341093, -1.255595521260306], 
              Complex[7.607198233627162, -2.332044490630609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309322711033374, 1.2497214182720298`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C3", 1, {
              Complex[9.309322711033374, 1.2497214182720298`], 
              Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323634279893042, -1.2581441066874384`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323634279893042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2581441066874384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607067169719584`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3342697921924636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "C3", 2, {
              Complex[9.323634279893042, -1.2581441066874384`], 
              Complex[7.607067169719584, -2.3342697921924636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323332739702, 1.2522538276170265`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C3", 1, {
              Complex[9.309323332739702, 1.2522538276170265`], 
              Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323601287353112, -1.2606790315775551`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323601287353112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2606790315775551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6069365055072815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3364823468295493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "C3", 2, {
              Complex[9.323601287353112, -1.2606790315775551`], 
              Complex[7.6069365055072815`, -2.3364823468295493`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323879150051, 1.254772738780499}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C3", 1, {
              Complex[9.309323879150051, 1.254772738780499], 
              Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323568537410361, -1.2632004444906193`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323568537410361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2632004444906193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606806236472662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3386822946753205`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "C3", 2, {
              Complex[9.323568537410361, -1.2632004444906193`], 
              Complex[7.606806236472662, -2.3386822946753205`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324351953519, 1.2572782977532362`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C3", 1, {
              Complex[9.309324351953519, 1.2572782977532362`], 
              Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323536026818966, -1.2657084915461236`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323536026818966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2657084915461236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606676358179671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.340869773551443`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "C3", 2, {
              Complex[9.323536026818966, -1.2657084915461236`], 
              Complex[7.606676358179671, -2.340869773551443]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324752796902, 1.2597706481409692`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C3", 1, {
              Complex[9.309324752796902, 1.2597706481409692`], 
              Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323503752396531, -1.2682033164767677`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323503752396531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2682033164767677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60654686627181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.343044919018725`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "C3", 2, {
              Complex[9.323503752396531, -1.2682033164767677`], 
              Complex[7.60654686627181, -2.343044919018725]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325083285957, 1.26224993121657}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C3", 1, {
              Complex[9.309325083285957, 1.26224993121657], 
              Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323471711022448, -1.2706850606806674`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323471711022448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2706850606806674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606417756470162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.345207864426671`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "C3", 2, {
              Complex[9.323471711022448, -1.2706850606806674`], 
              Complex[7.606417756470162, -2.345207864426671]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325344986703, 1.2647162859707826`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C3", 1, {
              Complex[9.309325344986703, 1.2647162859707826`], 
              Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323439899636348, -1.273153863272108}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323439899636348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.273153863272108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606289024571562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3473587409616403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "C3", 2, {
              Complex[9.323439899636348, -1.273153863272108], 
              Complex[7.606289024571562, -2.3473587409616403`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932553942646, 1.2671698491615646`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C3", 1, {
              Complex[9.30932553942646, 1.2671698491615646`], 
              Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323408315236543, -1.2756098611309419`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323408315236543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2756098611309419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60616066644672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.349497677693727`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "C3", 2, {
              Complex[9.323408315236543, -1.2756098611309419`], 
              Complex[7.60616066644672, -2.349497677693727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325668095038, 1.2696107553621176`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C3", 1, {
              Complex[9.309325668095038, 1.2696107553621176`], 
              Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323376954878531, -1.2780531889506412`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323376954878531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2780531889506412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.606032678038458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.351624801622354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "C3", 2, {
              Complex[9.323376954878531, -1.2780531889506412`], 
              Complex[7.606032678038458, -2.351624801622354]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325732445826, 1.2720391370076072`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C3", 1, {
              Complex[9.309325732445826, 1.2720391370076072`], 
              Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323345815673619, -1.2804839792850278`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323345815673619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2804839792850278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605905055360047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3537402377206176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "C3", 2, {
              Complex[9.323345815673619, -1.2804839792850278`], 
              Complex[7.605905055360047, -2.3537402377206176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325733896824, 1.2744551244406346`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C3", 1, {
              Complex[9.309325733896824, 1.2744551244406346`], 
              Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32331489478747, -1.282902362593793}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32331489478747`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.282902362593793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605777794493471`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.355844108978483`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "C3", 2, {
              Complex[9.32331489478747, -1.282902362593793], 
              Complex[7.605777794493471, -2.355844108978483]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325673831674, 1.2768588459554961`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C3", 1, {
              Complex[9.309325673831674, 1.2768588459554961`], 
              Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323284189438796, -1.2853084672867803`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323284189438796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2853084672867803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605650891587858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.357936536444798`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "C3", 2, {
              Complex[9.323284189438796, -1.2853084672867803`], 
              Complex[7.605650891587858, -2.357936536444798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932555360063, 1.2792504278412689`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C3", 1, {
              Complex[9.30932555360063, 1.2792504278412689`], 
              Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323253696898021, -1.2877024197670908`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323253696898021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2877024197670908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60552434285789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.360017639268197`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "C3", 2, {
              Complex[9.323253696898021, -1.2877024197670908`], 
              Complex[7.60552434285789, -2.360017639268197]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932537452151, 1.2816299944237615`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C3", 1, {
              Complex[9.30932537452151, 1.2816299944237615`], 
              Complex[7.62307645708013, 0.007358287782327438]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32322341448604, -1.2900843444730699`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32322341448604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2900843444730699`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605398144582298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3620875347369377`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "C3", 2, {
              Complex[9.32322341448604, -1.2900843444730699`], 
              Complex[7.605398144582298, -2.3620875347369377`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309325137880622, 1.2839976681063674`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C3", 1, {
              Complex[9.309325137880622, 1.2839976681063674`], 
              Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323193339572983, -1.292454363919178}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323193339572983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.292454363919178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605272293102371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.364146338317678`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "C3", 2, {
              Complex[9.323193339572983, -1.292454363919178], 
              Complex[7.605272293102371, -2.364146338317678]}, 0}, "Tooltip"]& 
           ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324844933629, 1.286353569409846}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C3", 1, {
              Complex[9.309324844933629, 1.286353569409846], 
              Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323163469577016, -1.2948125987358026`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323163469577016`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2948125987358026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605146784820535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3661941636932524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "C3", 2, {
              Complex[9.323163469577016, -1.2948125987358026`], 
              Complex[7.605146784820535, -2.3661941636932524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324496906415, 1.2886978170110814`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C3", 1, {
              Complex[9.309324496906415, 1.2886978170110814`], 
              Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323133801963191, -1.2971591677080403`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323133801963191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2971591677080403`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605021616198944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3682311227994606`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "C3", 2, {
              Complex[9.323133801963191, -1.2971591677080403`], 
              Complex[7.605021616198944, -2.3682311227994606`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309324094995942, 1.291030527780833}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C3", 1, {
              Complex[9.309324094995942, 1.291030527780833], 
              Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323104334242323, -1.2994941878134678`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323104334242323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2994941878134678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604896783758137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.370257325860909`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "C3", 2, {
              Complex[9.323104334242323, -1.2994941878134678`], 
              Complex[7.604896783758137, -2.370257325860909]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323640371, 1.2933518168205271`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C3", 1, {
              Complex[9.309323640371, 1.2933518168205271`], 
              Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32307506396992, -1.3018177742589656`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32307506396992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3018177742589656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604772284075739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.372272881425941`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "C3", 2, {
              Complex[9.32307506396992, -1.3018177742589656`], 
              Complex[7.604772284075739, -2.372272881425941]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309323134173042, 1.2956617974980962`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C3", 1, {
              Complex[9.309323134173042, 1.2956617974980962`], 
              Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323045988745086, -1.3041300405165683`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323045988745086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3041300405165683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604648113785146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.374277896400649`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "C3", 2, {
              Complex[9.323045988745086, -1.3041300405165683`], 
              Complex[7.604648113785146, -2.374277896400649]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309322577516868, 1.2979605814829327`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C3", 1, {
              Complex[9.309322577516868, 1.2979605814829327`], 
              Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.323017106209543, -1.3064310983584502`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.323017106209543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3064310983584502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604524269574324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.376272476082065`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "C3", 2, {
              Complex[9.323017106209543, -1.3064310983584502`], 
              Complex[7.604524269574324, -2.376272476082065]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309321971491423, 1.300248278779899}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C3", 1, {
              Complex[9.309321971491423, 1.300248278779899], 
              Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322988414046595, -1.3087210578909694`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322988414046595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3087210578909694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604400748184571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3782567241904538`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "C3", 2, {
              Complex[9.322988414046595, -1.3087210578909694`], 
              Complex[7.604400748184571, -2.3782567241904538`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30932131716045, 1.3025249977626072`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C3", 1, {
              Complex[9.30932131716045, 1.3025249977626072`], 
              Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322959909980197, -1.3110000275879254`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322959909980197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3110000275879254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604277546409373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.380230742900865`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "C3", 2, {
              Complex[9.322959909980197, -1.3110000275879254`], 
              Complex[7.604277546409373, -2.380230742900865]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309320615563188, 1.3047908452057129`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C3", 1, {
              Complex[9.309320615563188, 1.3047908452057129`], 
              Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322931591773996, -1.3132681143229277`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322931591773996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3132681143229277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604154661093239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.382194632873833`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "C3", 2, {
              Complex[9.322931591773996, -1.3132681143229277`], 
              Complex[7.604154661093239, -2.382194632873833]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319867715043, 1.3070459263165168`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C3", 1, {
              Complex[9.309319867715043, 1.3070459263165168`], 
              Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32290345723042, -1.315525423400987}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32290345723042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.315525423400987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604032089130615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3841484932853487`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "C3", 2, {
              Complex[9.32290345723042, -1.315525423400987], 
              Complex[7.604032089130615, -2.3841484932853487`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309319074608208, 1.3092903447657454`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C3", 1, {
              Complex[9.309319074608208, 1.3092903447657454`], 
              Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322875504189794, -1.3177720585893213`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322875504189794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3177720585893213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.60390982746478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.386092421856075`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "C3", 2, {
              Complex[9.322875504189794, -1.3177720585893213`], 
              Complex[7.60390982746478, -2.386092421856075]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309318237212295, 1.311524202717574}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C3", 1, {
              Complex[9.309318237212295, 1.311524202717574], 
              Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322847730529492, -1.3200081221474065`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322847730529492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3200081221474065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603787873086826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3880265148798543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "C3", 2, {
              Complex[9.322847730529492, -1.3200081221474065`], 
              Complex[7.603787873086826, -2.3880265148798543`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309317356474933, 1.3137476008589228`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C3", 1, {
              Complex[9.309317356474933, 1.3137476008589228`], 
              Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322820134163065, -1.322233714856279}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322820134163065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.322233714856279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603666223034595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.389950867251501`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "C3", 2, {
              Complex[9.322820134163065, -1.322233714856279], 
              Complex[7.603666223034595, -2.389950867251501]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309316433322348, 1.3159606384280351`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C3", 1, {
              Complex[9.309316433322348, 1.3159606384280351`], 
              Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.32279271303949, -1.32444893604715}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.32279271303949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.32444893604715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603544874391759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.391865572493939`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "C3", 2, {
              Complex[9.32279271303949, -1.32444893604715], 
              Complex[7.603544874391759, -2.391865572493939]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309315468659923, 1.3181634132423605`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C3", 1, {
              Complex[9.309315468659923, 1.3181634132423605`], 
              Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322765465142302, -1.326653883629291}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322765465142302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.326653883629291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6034238242867636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3937707227846508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "C3", 2, {
              Complex[9.322765465142302, -1.326653883629291], 
              Complex[7.6034238242867636`, -2.3937707227846508`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30931446337276, 1.3203560217257788`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C3", 1, {
              Complex[9.30931446337276, 1.3203560217257788`], 
              Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322738388488887, -1.3288486541172835`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322738388488887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3288486541172835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603303069891951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3956664089815227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "C3", 2, {
              Complex[9.322738388488887, -1.3288486541172835`], 
              Complex[7.603303069891951, -2.3956664089815227`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.30931341832617, 1.3225385589351384`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C3", 1, {
              Complex[9.30931341832617, 1.3225385589351384`], 
              Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322711481129714, -1.331033342657582}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322711481129714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.331033342657582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.603182608422626`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3975527206480365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "C3", 2, {
              Complex[9.322711481129714, -1.331033342657582], 
              Complex[7.603182608422626, -2.3975527206480365`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309312334366247, 1.3247111185862175`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C3", 1, {
              Complex[9.309312334366247, 1.3247111185862175`], 
              Complex[7.6230493091457, 0.04531544750647416]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322684741147594, -1.3332080430544797`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322684741147594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3332080430544797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6030624371361615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.399429746077893`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "C3", 2, {
              Complex[9.322684741147594, -1.3332080430544797`], 
              Complex[7.6030624371361615`, -2.399429746077893]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309311212320324, 1.3268737930790047`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C3", 1, {
              Complex[9.309311212320324, 1.3268737930790047`], 
              Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322658166657003, -1.3353728477954119`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322658166657003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3353728477954119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602942553331133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4012975723190064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "C3", 2, {
              Complex[9.322658166657003, -1.3353728477954119`], 
              Complex[7.602942553331133, -2.4012975723190064`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.309310052997454, 1.3290266735224268`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "C3", 1, {
              Complex[9.309310052997454, 1.3290266735224268`], 
              Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.322631755803343, -1.3375278480756927`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.322631755803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3375278480756927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602822954346447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.40315628519697`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "C3", 2, {
              Complex[9.322631755803343, -1.3375278480756927`], 
              Complex[7.602822954346447, -2.40315628519697]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.602458533258957, -0.2734383645589251}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.602458533258957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2734383645589251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552313`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B2", 1, {
              Complex[5.602458533258957, -0.2734383645589251], 
              Complex[3.719199600336583, -1.5754871190552313`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.226504314571602, 0.12463782579822859`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.226504314571602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12463782579822859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {30.999999999999993`, "B2", 2, {
              Complex[6.226504314571602, 0.12463782579822859`], 
              Complex[4.425499081603797, -1.0576646374765928`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.616621151226328, -0.2800822323034732}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.616621151226328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2800822323034732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5819069561624801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B2", 1, {
              Complex[5.616621151226328, -0.2800822323034732], 
              Complex[3.736478521301464, -1.5819069561624801`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.213166361508075, 0.13202179213539816`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.213166361508075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13202179213539816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148914`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775768`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.099999999999994`, "B2", 2, {
              Complex[6.213166361508075, 0.13202179213539816`], 
              Complex[4.409394150148914, -1.0495628600775768`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.6306954263332605`, -0.2873682998621296}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6306954263332605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B2", 1, {
              Complex[5.6306954263332605`, -0.2873682998621296], 
              Complex[3.7537091204741753`, -1.5890972039111027`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.199912728184141, 0.14004102546706554`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.199912728184141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14004102546706554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.39333507043169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0407007016791037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.199999999999996`, "B2", 2, {
              Complex[6.199912728184141, 0.14004102546706554`], 
              Complex[4.39333507043169, -1.0407007016791037`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.644598280659573, -0.29531732776612096`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.644598280659573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29531732776612096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.597089166697644`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B2", 1, {
              Complex[5.644598280659573, -0.29531732776612096`], 
              Complex[3.770794613325991, -1.597089166697644]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.1868265233398665`, 0.1487163827100988}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1868265233398665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1487163827100988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.299999999999997`, "B2", 2, {
              Complex[6.1868265233398665`, 0.1487163827100988], 
              Complex[4.377418633740918, -1.0310467452404806`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.6582371068889525`, -0.3039330313949986}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.6582371068889525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B2", 1, {
              Complex[5.6582371068889525`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.1740003848318254`, 0.15805167382144575`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1740003848318254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15805167382144575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238657`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.4, "B2", 2, {
              Complex[6.1740003848318254`, 0.15805167382144575`], 
              Complex[4.361754274818783, -1.0205889908238657`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.671514683640783, -0.31319809514055214`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.671514683640783`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31319809514055214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6155012704525782`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B2", 1, {
              Complex[5.671514683640783, -0.31319809514055214`], 
              Complex[3.8040854242836257`, -1.6155012704525782`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.161531564303005, 0.16802967600526247`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.161531564303005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16802967600526247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.009339964026806`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.499999999999996`, "B2", 2, {
              Complex[6.161531564303005, 0.16802967600526247`], 
              Complex[4.34645857273412, -1.009339964026806]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.684335924466961, -0.3230721172560274}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.684335924466961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3230721172560274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.625868648866983`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B2", 1, {
              Complex[5.684335924466961, -0.3230721172560274], 
              Complex[3.8200582761098634`, -1.625868648866983]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.1495151781876825`, 0.1786100786041201}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1495151781876825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1786100786041201`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188027`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.599999999999998`, "B2", 2, {
              Complex[6.1495151781876825`, 0.1786100786041201], 
              Complex[4.331647428673966, -0.9973396858188027]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.696615451432764, -0.33349241406049873`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.696615451432764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33349241406049873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B2", 1, {
              Complex[5.696615451432764, -0.33349241406049873`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.138036634132392, 0.18973028734408198`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.138036634132392`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18973028734408198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9846553249905683`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.7, "B2", 2, {
              Complex[6.138036634132392, 0.18973028734408198`], 
              Complex[4.317427040750873, -0.9846553249905683]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.708284492538861, -0.3443779449095292}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.708284492538861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3443779449095292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.850136390976634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6485937815375413`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B2", 1, {
              Complex[5.708284492538861, -0.3443779449095292], 
              Complex[3.850136390976634, -1.6485937815375413`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.127164733575719, 0.20130934934495107`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.127164733575719`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20130934934495107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797332`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.8, "B2", 2, {
              Complex[6.127164733575719, 0.20130934934495107`], 
              Complex[4.303885430470007, -0.971377104797332]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.719295626734264, -0.3556357121294631}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.719295626734264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3556357121294631`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8640899263017117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6607550217891227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B2", 1, {
              Complex[5.719295626734264, -0.3556357121294631], 
              Complex[3.8640899263017117`, -1.6607550217891227`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.1169469267372625`, 0.21325435309295884`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.1169469267372625`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.957611110502011`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.899999999999995`, "B2", 2, {
              Complex[6.1169469267372625`, 0.21325435309295884`], 
              Complex[4.291086318485069, -0.957611110502011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.729624504719875, -0.3671682712416461}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.729624504719875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.673300014636814`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B2", 1, {
              Complex[5.729624504719875, -0.3671682712416461], 
              Complex[3.8772617652382877`, -1.673300014636814]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.107407591815999, 0.22546793870233275`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.107407591815999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.279066489303967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9434705428233617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {31.999999999999996`, "B2", 2, {
              Complex[6.107407591815999, 0.22546793870233275`], 
              Complex[4.279066489303967, -0.9434705428233617]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.7392685732062425`, -0.37888080574180155`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7392685732062425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37888080574180155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B2", 1, {
              Complex[5.7392685732062425`, -0.37888080574180155`], 
              Complex[3.889641123048907, -1.6861168153853237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{6.098549310734496, 0.2378553727309036}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.098549310734496`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2378553727309036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.099999999999994`, "B2", 2, {
              Complex[6.098549310734496, 0.2378553727309036], 
              Complex[4.267836735050403, -0.9290672478326635]}, 0}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.4608658796691665`, -0.2734383645589258}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A2", 1, {
              Complex[2.4608658796691665`, -0.2734383645589258], 
              Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.084911660981808, 0.1246378257982292}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A2", 2, {
              Complex[3.084911660981808, 0.1246378257982292], 
              Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.4750284976365355`, -0.28008223230347307`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A2", 1, {
              Complex[2.4750284976365355`, -0.28008223230347307`], 
              Complex[3.736478521301466, -1.58190695616248]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.071573707918281, 0.1320217921353984}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A2", 2, {
              Complex[3.071573707918281, 0.1320217921353984], 
              Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.4891027727434665`, -0.2873682998621285}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A2", 1, {
              Complex[2.4891027727434665`, -0.2873682998621285], 
              Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0583200745943513`, 0.1400410254670661}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A2", 2, {
              Complex[3.0583200745943513`, 0.1400410254670661], 
              Complex[4.393335070431694, -1.040700701679103]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5030056270697787`, -0.29531732776612113`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A2", 1, {
              Complex[2.5030056270697787`, -0.29531732776612113`], 
              Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0452338697500734`, 0.14871638271009868`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A2", 2, {
              Complex[3.0452338697500734`, 0.14871638271009868`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5166444532991594`, -0.3039330313949986}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A2", 1, {
              Complex[2.5166444532991594`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.032407731242035, 0.1580516738214428}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A2", 2, {
              Complex[3.032407731242035, 0.1580516738214428], 
              Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5299220300509884`, -0.31319809514055186`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A2", 1, {
              Complex[2.5299220300509884`, -0.31319809514055186`], 
              Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.0199389107132126`, 0.16802967600526134`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A2", 2, {
              Complex[3.0199389107132126`, 0.16802967600526134`], 
              Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5427432708771702`, -0.3230721172560292}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A2", 1, {
              Complex[2.5427432708771702`, -0.3230721172560292], 
              Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{3.007922524597889, 0.17861007860412123`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A2", 2, {
              Complex[3.007922524597889, 0.17861007860412123`], 
              Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5550227978429705`, -0.33349241406049857`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A2", 1, {
              Complex[2.5550227978429705`, -0.33349241406049857`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.996443980542599, 0.1897302873440814}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A2", 2, {
              Complex[2.996443980542599, 0.1897302873440814], 
              Complex[4.317427040750872, -0.984655324990569]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5666918389490667`, -0.3443779449095298}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A2", 1, {
              Complex[2.5666918389490667`, -0.3443779449095298], 
              Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9855720799859258`, 0.20130934934494918`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A2", 2, {
              Complex[2.9855720799859258`, 0.20130934934494918`], 
              Complex[4.303885430470007, -0.971377104797334]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5777029731444694`, -0.35563571212946193`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A2", 1, {
              Complex[2.5777029731444694`, -0.35563571212946193`], 
              Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9753542731474694`, 0.21325435309295854`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A2", 2, {
              Complex[2.9753542731474694`, 0.21325435309295854`], 
              Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.588031851130083, -0.3671682712416466}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A2", 1, {
              Complex[2.588031851130083, -0.3671682712416466], 
              Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.965814938226205, 0.22546793870233256`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A2", 2, {
              Complex[2.965814938226205, 0.22546793870233256`], 
              Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.5976759196164494`, -0.3788808057418005}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A2\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A2", 1, {
              Complex[2.5976759196164494`, -0.3788808057418005], 
              Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.9569566571447035`, 0.2378553727309031}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A2\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A2", 2, {
              Complex[2.9569566571447035`, 0.2378553727309031], 
              Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.606650933262854, -0.3906866010723904}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A3", 1, {
              Complex[2.606650933262854, -0.3906866010723904], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9487637036120304`, 0.25033002218771455`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A3", 2, {
              Complex[2.9487637036120304`, 0.25033002218771455`], 
              Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6149863657999486`, -0.40251041678372024`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A3", 1, {
              Complex[2.6149863657999486`, -0.40251041678372024`], 
              Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9412066320031385`, 0.2628167267283543}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A3", 2, {
              Complex[2.9412066320031385`, 0.2628167267283543], 
              Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6227207308158538`, -0.41428986426444875`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A3", 1, {
              Complex[2.6227207308158538`, -0.41428986426444875`], 
              Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.93424695657482, 0.27525317641875774`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A3", 2, {
              Complex[2.93424695657482, 0.27525317641875774`], 
              Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.629897485254924, -0.42597525546826037`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A3", 1, {
              Complex[2.629897485254924, -0.42597525546826037`], 
              Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.927841247969024, 0.28758976049421764`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A3", 2, {
              Complex[2.927841247969024, 0.28758976049421764`], 
              Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.636561822697944, -0.4375284851167467}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A3", 1, {
              Complex[2.636561822697944, -0.4375284851167467], 
              Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.921944339934747, 0.2997884495937316}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A3", 2, {
              Complex[2.921944339934747, 0.2997884495937316], 
              Complex[4.222645506003507, -0.856274787217682]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6427583897826854`, -0.4489214364481581}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A3", 1, {
              Complex[2.6427583897826854`, -0.4489214364481581], 
              Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9165116129095963`, 0.31182120153934106`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A3", 2, {
              Complex[2.9165116129095963`, 0.31182120153934106`], 
              Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.648529805818011, -0.4601342612759221}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A3", 1, {
              Complex[2.648529805818011, -0.4601342612759221], 
              Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.911500474407813, 0.323668241424401}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A3", 2, {
              Complex[2.911500474407813, 0.323668241424401], 
              Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.653915808537619, -0.4711537472500261}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A3", 1, {
              Complex[2.653915808537619, -0.4711537472500261], 
              Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.90687121326868, 0.33531642890390234`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A3", 2, {
              Complex[2.90687121326868, 0.33531642890390234`], 
              Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6589528500918, -0.48197187877303665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A3", 1, {
              Complex[2.6589528500918, -0.48197187877303665`], 
              Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9025874036669044`, 0.3467578191386486}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A3", 2, {
              Complex[2.9025874036669044`, 0.3467578191386486], 
              Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6636739953559614`, -0.49258462786579826`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A3", 1, {
              Complex[2.6636739953559614`, -0.49258462786579826`], 
              Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8986160068062667`, 0.3579884536883491}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A3", 2, {
              Complex[2.8986160068062667`, 0.3579884536883491], 
              Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.668109009751523, -0.50299097090211}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A3", 1, {
              Complex[2.668109009751523, -0.50299097090211], 
              Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8949272831009005`, 0.36900737727295585`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A3", 2, {
              Complex[2.8949272831009005`, 0.36900737727295585`], 
              Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6722845561748567`, -0.5131921073476409}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A3", 1, {
              Complex[2.6722845561748567`, -0.5131921073476409], 
              Complex[3.989240598169983, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8914945952485174`, 0.37981585653752775`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A3", 2, {
              Complex[2.8914945952485174`, 0.37981585653752775`], 
              Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.67622444669189, -0.5231908494724435}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A3", 1, {
              Complex[2.67622444669189, -0.5231908494724435], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8882941565379943`, 0.3904167697900055}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A3", 2, {
              Complex[2.8882941565379943`, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.679949913999627, -0.5329911517598123}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A3", 1, {
              Complex[2.679949913999627, -0.5329911517598123], 
              Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8853047593900265`, 0.4008141364346624}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A3", 2, {
              Complex[2.8853047593900265`, 0.4008141364346624], 
              Complex[4.173308062162179, -0.735357851265334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.683479881251108, -0.5425977517885688}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A3", 1, {
              Complex[2.683479881251108, -0.5425977517885688], 
              Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8825075055343556`, 0.41101275787833075`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A3", 2, {
              Complex[2.8825075055343556`, 0.41101275787833075`], 
              Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6868312180069145`, -0.5520158986267104}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A3", 1, {
              Complex[2.6868312180069145`, -0.5520158986267104], 
              Complex[4.009806376364359, -1.880054831501801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8798855500604437`, 0.42101794594737985`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A3", 2, {
              Complex[2.8798855500604437`, 0.42101794594737985`], 
              Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6900189760399855`, -0.5612511491377956}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A3", 1, {
              Complex[2.6900189760399855`, -0.5612511491377956], 
              Complex[4.01438190088909, -1.890520862682429]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8774238656148396`, 0.4308353192168015}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A3", 2, {
              Complex[2.8774238656148396`, 0.4308353192168015], 
              Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.693056602464925, -0.5703092165540393}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A3", 1, {
              Complex[2.693056602464925, -0.5703092165540393], 
              Complex[4.018766629721939, -1.900792375423005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8751090292740487`, 0.4404706516054349}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A3", 2, {
              Complex[2.8751090292740487`, 0.4404706516054349], 
              Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.695956129918709, -0.5791958590266285}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A3", 1, {
              Complex[2.695956129918709, -0.5791958590266285], 
              Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8729290323659913`, 0.4499297609478434}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A3", 2, {
              Complex[2.8729290323659913`, 0.4499297609478434], 
              Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.698728344803272, -0.5879167986060275}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A3", 1, {
              Complex[2.698728344803272, -0.5879167986060275], 
              Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8708731122295896`, 0.4592184279956057}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A3", 2, {
              Complex[2.8708731122295896`, 0.4592184279956057], 
              Complex[4.152955626516613, -0.664447166754532]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7013829352654026`, -0.5964776632911527}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A3", 1, {
              Complex[2.7013829352654026`, -0.5964776632911527], 
              Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8689316042370305`, 0.4683423384869718}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A3", 2, {
              Complex[2.8689316042370305`, 0.4683423384869718], 
              Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7039286208715065`, -0.6048839465011073}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A3", 1, {
              Complex[2.7039286208715065`, -0.6048839465011073], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8670958121211547`, 0.477307042638535}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A3", 2, {
              Complex[2.8670958121211547`, 0.477307042638535], 
              Complex[4.147506625196923, -0.642348121441579]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7063732659882276`, -0.613140979653751}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A3", 1, {
              Complex[2.7063732659882276`, -0.613140979653751], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8653578945969786`, 0.48611792774323803`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A3", 2, {
              Complex[2.8653578945969786`, 0.48611792774323803`], 
              Complex[4.144979724610491, -0.631560836108617]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.708723978803601, -0.6212539145605391}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A3", 1, {
              Complex[2.708723978803601, -0.6212539145605391], 
              Complex[4.041793889306879, -1.958660288701135]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8637107663426793`, 0.49478020058417876`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A3", 2, {
              Complex[2.8637107663426793`, 0.49478020058417876`], 
              Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.710987197779323, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A3", 1, {
              Complex[2.710987197779323, -0.6292277131331433], 
              Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8621480115494466`, 0.503298877159704}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8621480115494466`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.503298877159704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830696`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A3", 2, {
              Complex[2.8621480115494466`, 0.503298877159704], 
              Complex[4.140277152714267, -0.6104830975830696]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7131687671511795`, -0.6370671424983351}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A3", 1, {
              Complex[2.7131687671511795`, -0.6370671424983351], 
              Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.860663808423174, 0.5116787778163023}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.860663808423174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5116787778163023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A3", 2, {
              Complex[2.860663808423174, 0.5116787778163023], 
              Complex[4.1380862591666565`, -0.6001821017863883]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.71527400291423, -0.6447767740762022}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A3", 1, {
              Complex[2.71527400291423, -0.6447767740762022], 
              Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8592528632013723`, 0.5199245263444046}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8592528632013723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5199245263444046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261431996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.8, "A3", 2, {
              Complex[2.8592528632013723`, 0.5199245263444046], 
              Complex[4.135993261431996, -0.5900329694879923]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.717307750554921, -0.6523609855265123}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A3", 1, {
              Complex[2.717307750554921, -0.6523609855265123], 
              Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.857910352423154, 0.5280405519418746}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.857910352423154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5280405519418746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.9, "A3", 2, {
              Complex[2.857910352423154, 0.5280405519418746], 
              Complex[4.133992114800525, -0.5800308993285684]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7192744356306133`, -0.6598239647344449}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A3", 1, {
              Complex[2.7192744356306133`, -0.6598239647344449], 
              Complex[4.057727034812088, -2.002562003206256]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8566318723517807`, 0.5360310932164641}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8566318723517807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5360310932164641`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.132077284632824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.570171279993703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35., "A3", 2, {
              Complex[2.8566318723517807`, 0.5360310932164641], 
              Complex[4.132077284632824, -0.570171279993703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7211781081510784`, -0.6671697152100743}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A3", 1, {
              Complex[2.7211781081510784`, -0.6671697152100743], 
              Complex[4.060641656654434, -2.01093044740819]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8554133945952374`, 0.543900203601609}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8554133945952374`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.543900203601609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212127`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.1, "A3", 2, {
              Complex[2.8554133945952374`, 0.543900203601609], 
              Complex[4.130243693579622, -0.5604496874212127]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7230224815870465`, -0.6744020624307276}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A3", 1, {
              Complex[2.7230224815870465`, -0.6744020624307276], 
              Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.854251227099731, 0.5516517577146821}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.854251227099731`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640704`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A3", 2, {
              Complex[2.854251227099731, 0.5516517577146821], 
              Complex[4.128486675066932, -0.5508618804640704]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.724810967217476, -0.6815246607732999}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A3", 1, {
              Complex[2.724810967217476, -0.6815246607732999], 
              Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8531419798044717`, 0.5592894583048513}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8531419798044717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5592894583048513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.3, "A3", 2, {
              Complex[2.8531419798044717`, 0.5592894583048513], 
              Complex[4.126801932234572, -0.5414037954825226]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7265467044285883`, -0.6885410007735716}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A3", 1, {
              Complex[2.7265467044285883`, -0.6885410007735716], 
              Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.852082534344649, 0.5668168435275388}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.852082534344649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250119`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.4, "A3", 2, {
              Complex[2.852082534344649, 0.5668168435275388], 
              Complex[4.125185501625341, -0.5320715402250119]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7282325874925664`, -0.6954544165180527}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A3", 1, {
              Complex[2.7282325874925664`, -0.6954544165180527], 
              Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8510700172747567`, 0.5742372943510567}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8510700172747567`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5742372943510567`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A3", 2, {
              Complex[2.8510700172747567`, 0.5742372943510567], 
              Complex[4.123633721017262, -0.5228613872697347]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.729871289280439, -0.7022680930260651}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A3", 1, {
              Complex[2.729871289280439, -0.7022680930260651], 
              Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.850101776357696, 0.5815540419531228}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.850101776357696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122143200873719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A3", 2, {
              Complex[2.850101776357696, 0.5815540419531228], 
              Complex[4.122143200873719, -0.5137697672312344]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7314652823007664`, -0.7089850735194753}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A3", 1, {
              Complex[2.7314652823007664`, -0.7089850735194753], 
              Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8491753595280755`, 0.5887701750046822}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8491753595280755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5887701750046822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845051`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A3", 2, {
              Complex[2.8491753595280755`, 0.5887701750046822], 
              Complex[4.120710798957502, -0.5047932618845051]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.733016857401756, -0.7156082665076033}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A3", 1, {
              Complex[2.733016857401756, -0.7156082665076033], 
              Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.848288496192057, 0.5958886467685786}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.848288496192057`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685786`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920325`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.8, "A3", 2, {
              Complex[2.848288496192057, 0.5958886467685786], 
              Complex[4.1193335977160075`, -0.49592859731920325`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.734528140428245, -0.7221404526376912}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A3", 1, {
              Complex[2.734528140428245, -0.7221404526376912], 
              Complex[4.081447520434109, -2.07361729918916]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.847439080572326, 0.6029122819634529}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.847439080572326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.9, "A3", 2, {
              Complex[2.847439080572326, 0.6029122819634529], 
              Complex[4.118008884097688, -0.4871726372059103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.736001107085408, -0.7285842912785057}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A3", 1, {
              Complex[2.736001107085408, -0.7285842912785057], 
              Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8466251568463186`, 0.6098437833604624}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8466251568463186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6098437833604624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.47852237623289673`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A3", 2, {
              Complex[2.8466251568463186`, 0.6098437833604624], 
              Complex[4.116734131505034, -0.47852237623289673`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7374375962271382`, -0.7349423268176083}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A3", 1, {
              Complex[2.7374375962271382`, -0.7349423268176083], 
              Complex[4.086071031729208, -2.088230594606227]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.845844905859744, 0.6166857380933649}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.845844905859744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6166857380933649`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384036`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A3", 2, {
              Complex[2.845844905859744, 0.6166857380933649], 
              Complex[4.115506983628505, -0.46997493375384036`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7388393217580846`, -0.7412169946624545}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A3", 1, {
              Complex[2.7388393217580846`, -0.7412169946624545], 
              Complex[4.088310451090251, -2.095394940608318]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8450966332264747`, 0.6234406236721284}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8450966332264747`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6234406236721284`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4615275476732827`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A3", 2, {
              Complex[2.8450966332264747`, 0.6234406236721284], 
              Complex[4.114325239939221, -0.4615275476732827]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7402078833132797`, -0.7474106269426312}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A3", 1, {
              Complex[2.7402078833132797`, -0.7474106269426312], 
              Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8443787586507785`, 0.6301108136973931}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8443787586507785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6301108136973931`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647121`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861368`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.3, "A3", 2, {
              Complex[2.8443787586507785`, 0.6301108136973931], 
              Complex[4.113186842647121, -0.4531775685861368]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7415447758580713`, -0.7535254579157126}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A3", 1, {
              Complex[2.7415447758580713`, -0.7535254579157126], 
              Complex[4.092654956897793, -2.109452014313655]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.843689806329271, 0.6366985832782687}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.843689806329271`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.44492245417978044`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.4, "A3", 2, {
              Complex[2.843689806329271, 0.6366985832782687], 
              Complex[4.112089864956078, -0.44492245417978044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.742851398332544, -0.7595636290829759}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A3", 1, {
              Complex[2.742851398332544, -0.7595636290829759], 
              Complex[4.094763792064631, -2.11634961995984]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8430283963083336`, 0.6432061141597183}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8430283963083336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6432061141597183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013432`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.5, "A3", 2, {
              Complex[2.8430283963083336`, 0.6432061141597183], 
              Complex[4.111032500468935, -0.4367597639013432]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.744129061448893, -0.7655271940238008}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A3", 1, {
              Complex[2.744129061448893, -0.7655271940238008], 
              Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.842393236688587, 0.6496354995683534}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.842393236688587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4286871538884808`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.6, "A3", 2, {
              Complex[2.842393236688587, 0.6496354995683534], 
              Complex[4.110013053613794, -0.4286871538884808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.745378994736478, -0.7714181229593412}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A3", 1, {
              Complex[2.745378994736478, -0.7714181229593412], 
              Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8417831165816425`, 0.6559887487872518}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8417831165816425`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6559887487872518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42070237215874656`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A3", 2, {
              Complex[2.8417831165816425`, 0.6559887487872518], 
              Complex[4.109029930978956, -0.42070237215874656`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.746602352917594, -0.7772383070571701}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A3", 1, {
              Complex[2.746602352917594, -0.7772383070571701], 
              Complex[4.100856784915977, -2.136545961543077]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8411968997361448`, 0.6622677914714884}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8411968997361448`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6622677914714884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108081633457668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043816`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A3", 2, {
              Complex[2.8411968997361448`, 0.6622677914714884], 
              Complex[4.108081633457668, -0.41280325405043816`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7478002216867257`, -0.7829895624892164}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A3", 1, {
              Complex[2.7478002216867257`, -0.7829895624892164], 
              Complex[4.102814974771636, -2.143119636338954]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8406335187602902`, 0.6684744817167128}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8406335187602902`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.107166749115801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A3", 2, {
              Complex[2.8406335187602902`, 0.6684744817167128], 
              Complex[4.107166749115801, -0.4049877179062305]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.748973622957287, -0.7886736342555815}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A3", 1, {
              Complex[2.748973622957287, -0.7886736342555815], 
              Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8400919698768647`, 0.6746106018933697}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8400919698768647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6746106018933697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106283946706008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.39725376098988346`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A3", 2, {
              Complex[2.8400919698768647`, 0.6746106018933697], 
              Complex[4.106283946706008, -0.39725376098988346`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.750123519632142, -0.794292199786831}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A3", 1, {
              Complex[2.750123519632142, -0.794292199786831], 
              Complex[4.106630306409572, -2.156041173845927]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8395713081544542`, 0.6806778662591643}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8395713081544542`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6806778662591643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10543196976093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38959945562569726`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A3", 2, {
              Complex[2.8395713081544542`, 0.6806778662591643], 
              Complex[4.10543196976093, -0.38959945562569726`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.751250819947598, -0.7998468723371362}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A3", 1, {
              Complex[2.751250819947598, -0.7998468723371362], 
              Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.839070643165216, 0.6866779243621389}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.839070643165216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10460963120591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501247`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A3", 2, {
              Complex[2.839070643165216, 0.6866779243621389], 
              Complex[4.10460963120591, -0.3820229455501247]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7523563814347085`, -0.8053392041803537}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A3", 1, {
              Complex[2.7523563814347085`, -0.8053392041803537], 
              Complex[4.11031899238399, -2.168673807450607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.838589135025258, 0.6926123642464805}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.838589135025258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479255`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.3, "A3", 2, {
              Complex[2.838589135025258, 0.6926123642464805], 
              Complex[4.103815808438448, -0.37452244246479255`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7534410145367234`, -0.8107706896206492}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A3", 1, {
              Complex[2.7534410145367234`, -0.8107706896206492], 
              Complex[4.112118632879193, -2.174886099543967]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8381259907789103`, 0.6984827154726537}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8381259907789103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6984827154726537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103049438827799`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36709622278037274`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.4, "A3", 2, {
              Complex[2.8381259907789103`, 0.6984827154726537], 
              Complex[4.103049438827799, -0.36709622278037274`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7545054859170786`, -0.8161427678288303}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A3", 1, {
              Complex[2.7545054859170786`, -0.8161427678288303], 
              Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8376804610924062`, 0.7042904519630285}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8376804610924062`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7042904519630285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.359742624540917`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.5, "A3", 2, {
              Complex[2.8376804610924062`, 0.7042904519630285], 
              Complex[4.102309515593154, -0.359742624540917]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7555505214884586`, -0.8214568255150109}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A3", 1, {
              Complex[2.7555505214884586`, -0.8214568255150109], 
              Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8372518372264883`, 0.710036994683633}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8372518372264883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.710036994683633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858165`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.6, "A3", 2, {
              Complex[2.8372518372264883`, 0.710036994683633], 
              Complex[4.101595084023627, -0.35246004451858165`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7565768091900997`, -0.8267141994476596}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A3", 1, {
              Complex[2.7565768091900997`, -0.8267141994476596], 
              Complex[4.117350770809639, -2.193126103819013]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836839448260752, 0.7157237141721116}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836839448260752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7157237141721116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3452469354690401`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.7, "A3", 2, {
              Complex[2.836839448260752, 0.7157237141721116], 
              Complex[4.100905238007176, -0.3452469354690401]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7575850015374925`, -0.8319161788285991}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A3", 1, {
              Complex[2.7575850015374925`, -0.8319161788285991], 
              Complex[4.119042270745964, -2.199078825420972]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8364426585455744`, 0.7213519329214126}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8364426585455744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7213519329214126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.338101803538321`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.8, "A3", 2, {
              Complex[2.8364426585455744`, 0.7213519329214126], 
              Complex[4.100239116839224, -0.338101803538321]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7585757179660733`, -0.8370640075328957}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A3", 1, {
              Complex[2.7585757179660733`, -0.8370640075328957], 
              Complex[4.120708909659479, -2.204970281578657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.836060865360036, 0.7269229276281965}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.836060865360036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3310232058121986`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A3", 2, {
              Complex[2.836060865360036, 0.7269229276281965], 
              Complex[4.099595902284807, -0.3310232058121986]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.759549546988155, -0.8421588862221198}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A3", 1, {
              Complex[2.759549546988155, -0.8421588862221198], 
              Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8356934967565883`, 0.732437931314428}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8356934967565883`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.732437931314428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3240097479997231`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A3", 2, {
              Complex[2.8356934967565883`, 0.732437931314428], 
              Complex[4.098974815870868, -0.3240097479997231]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.760507048180339, -0.8472019743388879}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A3", 1, {
              Complex[2.760507048180339, -0.8472019743388879], 
              Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8353400095752215`, 0.7378981353300624}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8353400095752215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7378981353300624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0983751163877695`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.31706008224295984`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A3", 2, {
              Complex[2.8353400095752215`, 0.7378981353300624], 
              Complex[4.0983751163877695`, -0.31706008224295984`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7614487540168455`, -0.8521943919901349}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A3", 1, {
              Complex[2.7614487540168455`, -0.8521943919901349], 
              Complex[4.12556733480281, -2.222290341327314]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8349998876116986`, 0.7433046912443027}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8349998876116986`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7433046912443027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A3", 2, {
              Complex[2.8349998876116986`, 0.7433046912443027], 
              Complex[4.097796097581198, -0.31017290504537054`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.762375171562624, -0.8571372217260823}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A3", 1, {
              Complex[2.762375171562624, -0.8571372217260823], 
              Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8346726399259916`, 0.7486587126323618}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8346726399259916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7486587126323618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0972370860175795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033469553117824`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.3, "A3", 2, {
              Complex[2.8346726399259916`, 0.7486587126323618], 
              Complex[4.0972370860175795`, -0.3033469553117824]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7632867840386814`, -0.8620315102214068}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A3", 1, {
              Complex[2.7632867840386814`, -0.8620315102214068], 
              Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8343577992784867`, 0.7539612767642822}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8343577992784867`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7539612767642822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2965810124932367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.4, "A3", 2, {
              Complex[2.8343577992784867`, 0.7539612767642822], 
              Complex[4.096697439107836, -0.2965810124932367]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.764184052270831, -0.8668782698647187}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A3", 1, {
              Complex[2.764184052270831, -0.8668782698647187], 
              Complex[4.130228184469746, -2.239105006921373]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8340549206827474`, 0.7592134262018864}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8340549206827474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7592134262018864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2898738948304563`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.5, "A3", 2, {
              Complex[2.8340549206827474`, 0.7592134262018864], 
              Complex[4.096176543275775, -0.2898738948304563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.765067416031943, -0.8716784802620265}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A3", 1, {
              Complex[2.765067416031943, -0.8716784802620265], 
              Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8337635800647583`, 0.764416170309563}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8337635800647583`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.764416170309563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900403`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A3", 2, {
              Complex[2.8337635800647583`, 0.764416170309563], 
              Complex[4.095673812258774, -0.2832244576900403]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7659372952868275`, -0.8764330896595155}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A3", 1, {
              Complex[2.7659372952868275`, -0.8764330896595155], 
              Complex[4.133234044285656, -2.25004936804117]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8334833730195332`, 0.769570486684214}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8334833730195332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.769570486684214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2766315919878302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A3", 2, {
              Complex[2.8334833730195332`, 0.769570486684214], 
              Complex[4.095188685529604, -0.2766315919878302]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7667940913479225`, -0.8811430162906054}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A3", 1, {
              Complex[2.7667940913479225`, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8332139136568895`, 0.7746773225093263}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8332139136568895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7746773225093263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428623`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.8, "A3", 2, {
              Complex[2.8332139136568895`, 0.7746773225093263], 
              Complex[4.094720626829336, -0.27009422269428623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7676381879492564`, -0.8858091496519156}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A3", 1, {
              Complex[2.7676381879492564`, -0.8858091496519156], 
              Complex[4.136164053701611, -2.260791305494017]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83295483352893, 0.7797375958378118}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83295483352893`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7797375958378118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698546`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.9, "A3", 2, {
              Complex[2.83295483352893, 0.7797375958378118], 
              Complex[4.094269122802148, -0.26361130741698546`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.768469952245414, -0.8904323517124777}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A3", 1, {
              Complex[2.768469952245414, -0.8904323517124777], 
              Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8327057806325184`, 0.7847521968079433}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8327057806325184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7847521968079433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570624`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A3", 2, {
              Complex[2.8327057806325184`, 0.7847521968079433], 
              Complex[4.093833681723804, -0.25718183505570624`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7692897357415935`, -0.8950134580602265}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A3", 1, {
              Complex[2.7692897357415935`, -0.8950134580602265], 
              Complex[4.139022292544098, -2.271338727751554]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832466418480638, 0.7897219887964373}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832466418480638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093413832316266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25080482452581293`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A3", 2, {
              Complex[2.832466418480638, 0.7897219887964373], 
              Complex[4.093413832316266, -0.25080482452581293`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.770097875160309, -0.8995532789895441}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A3", 1, {
              Complex[2.770097875160309, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.83223642523709, 0.7946478095124515}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.83223642523709`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2444793235459523`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A3", 2, {
              Complex[2.83223642523709, 0.7946478095124515], 
              Complex[4.0930091226416065`, -0.2444793235459523]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.770894693249766, -0.9040526005333875}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A3", 1, {
              Complex[2.770894693249766, -0.9040526005333875], 
              Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.832015492909507, 0.7995304720360317}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.832015492909507`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926191190690275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382044074863149`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.3, "A3", 2, {
              Complex[2.832015492909507, 0.7995304720360317], 
              Complex[4.0926191190690275`, -0.2382044074863149]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.771680499538499, -0.9085121854432784}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A3", 1, {
              Complex[2.771680499538499, -0.9085121854432784], 
              Complex[4.143183206373633, -2.286811288665357]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8318033265960922`, 0.8043707658042935}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8318033265960922`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.4, "A3", 2, {
              Complex[2.8318033265960922`, 0.8043707658042935], 
              Complex[4.092243405309307, -0.23197917827395628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.772455591040422, -0.9129327741202401}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A3", 1, {
              Complex[2.772455591040422, -0.9129327741202401], 
              Complex[4.1445381709548, -2.291879330010544]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8315996437819138`, 0.8091694575484238}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8315996437819138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091881581511521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2258027633518864`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A3", 2, {
              Complex[2.8315996437819138`, 0.8091694575484238], 
              Complex[4.091881581511521, -0.2258027633518864]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.773220252914124, -0.9173150854995425}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A3", 1, {
              Complex[2.773220252914124, -0.9173150854995425], 
              Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8314041736809603`, 0.8139272921843714}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8314041736809603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8139272921843714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886164`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A3", 2, {
              Complex[2.8314041736809603`, 0.8139272921843714], 
              Complex[4.091533263417342, -0.21967431468886164`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7739747590798687`, -0.9216598178919512}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A3", 1, {
              Complex[2.7739747590798687`, -0.9216598178919512], 
              Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8312166566204735`, 0.8186449936599106}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8312166566204735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8186449936599106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A3", 2, {
              Complex[2.8312166566204735`, 0.8186449936599106], 
              Complex[4.091198081568593, -0.21359300783699628`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.774719372797445, -0.9259676497839711}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A3", 1, {
              Complex[2.774719372797445, -0.9259676497839711], 
              Complex[4.148512526970578, -2.306826396101705]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8310368434643864`, 0.8233232657606014}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8310368434643864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448097`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.8, "A3", 2, {
              Complex[2.8310368434643864`, 0.8233232657606014], 
              Complex[4.090875680564112, -0.20755804103448097`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.775454347207829, -0.9302392405994732}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A3", 1, {
              Complex[2.775454347207829, -0.9302392405994732], 
              Complex[4.149808341378721, -2.311725622493254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8308644950729818`, 0.8279627928769887}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8308644950729818`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8279627928769887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {39.9, "A3", 2, {
              Complex[2.8308644950729818`, 0.8279627928769887], 
              Complex[4.090565718362366, -0.2015686343508945]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.776179925841262, -0.9344752314248258}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A3", 1, {
              Complex[2.776179925841262, -0.9344752314248258], 
              Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8306993817960873`, 0.8325642407352367}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8306993817960873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19562402887272815`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {40., "A3", 2, {
              Complex[2.8306993817960873`, 0.8325642407352367], 
              Complex[4.090267865626449, -0.19562402887272815`]}, -1}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.748243586852646, -0.3906866010723917}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.748243586852646`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6991015885376035`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B3", 1, {
              Complex[5.748243586852646, -0.3906866010723917], 
              Complex[3.901239519558195, -1.6991015885376035`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0903563572018244`, 0.2503300221877129}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0903563572018244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2503300221877129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864037`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.199999999999996`, "B3", 2, {
              Complex[6.0903563572018244`, 0.2503300221877129], 
              Complex[4.257385543344473, -0.9145049639864037]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.75657901938974, -0.4025104167837189}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.75657901938974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4025104167837189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9120856219032407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7121629626858914`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B3", 1, {
              Complex[5.75657901938974, -0.4025104167837189], 
              Complex[3.9120856219032407`, -1.7121629626858914`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.08279928559293, 0.26281672672835754`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.08279928559293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26281672672835754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010666`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.3, "B3", 2, {
              Complex[6.08279928559293, 0.26281672672835754`], 
              Complex[4.247684254548456, -0.8998749672010666]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.7643133844056464`, -0.4142898642644478}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.7643133844056464`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4142898642644478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B3", 1, {
              Complex[5.7643133844056464`, -0.4142898642644478], 
              Complex[3.9222198214979045`, -1.7252240340035674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.075839610164613, 0.27525317641875785`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.075839610164613`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.238692484798848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8852540673280812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.4, "B3", 2, {
              Complex[6.075839610164613, 0.27525317641875785`], 
              Complex[4.238692484798848, -0.8852540673280812]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.771490138844717, -0.42597525546826004`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.771490138844717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.931689378166075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7382225152116566`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B3", 1, {
              Complex[5.771490138844717, -0.42597525546826004`], 
              Complex[3.931689378166075, -1.7382225152116566`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.069433901558818, 0.2875897604942178}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.069433901558818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2875897604942178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.49999999999999, "B3", 2, {
              Complex[6.069433901558818, 0.2875897604942178], 
              Complex[4.230362981869569, -0.8707044591549226]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.778154476287738, -0.43752848511674675`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.778154476287738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.43752848511674675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B3", 1, {
              Complex[5.778154476287738, -0.43752848511674675`], 
              Complex[3.9405445393067433`, -1.7511096707348452`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.063536993524541, 0.2997884495937313}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.063536993524541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2226455060035075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8562747872176826`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.599999999999994`, "B3", 2, {
              Complex[6.063536993524541, 0.2997884495937313], 
              Complex[4.2226455060035075`, -0.8562747872176826]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.784351043372479, -0.448921436448157}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.784351043372479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.448921436448157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780146`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B3", 1, {
              Complex[5.784351043372479, -0.448921436448157], 
              Complex[3.948835712532858, -1.7638486148780146`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.058104266499389, 0.311821201539341}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.058104266499389`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.311821201539341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.215489657270424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8420018475938849`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.699999999999996`, "B3", 2, {
              Complex[6.058104266499389, 0.311821201539341], 
              Complex[4.215489657270424, -0.8420018475938849]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.790122459407805, -0.4601342612759226}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.790122459407805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.95661157787795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.77641239731018`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B3", 1, {
              Complex[5.790122459407805, -0.4601342612759226], 
              Complex[3.95661157787795, -1.77641239731018]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.053093127997606, 0.32366824142440104`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.053093127997606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32366824142440104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887509`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.8, "B3", 2, {
              Complex[6.053093127997606, 0.32366824142440104`], 
              Complex[4.208846763357215, -0.8279125023887509]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.795508462127413, -0.4711537472500259}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.795508462127413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500259`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B3", 1, {
              Complex[5.795508462127413, -0.4711537472500259], 
              Complex[3.963917947183657, -1.7887821416602485`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.048463866858473, 0.3353164289039027}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.048463866858473`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3353164289039027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {32.9, "B3", 2, {
              Complex[6.048463866858473, 0.3353164289039027], 
              Complex[4.202671020177384, -0.8140255411104014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.800545503681592, -0.4819718787730359}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.800545503681592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4819718787730359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.970797171183352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8009453770853798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B3", 1, {
              Complex[5.800545503681592, -0.4819718787730359], 
              Complex[3.970797171183352, -1.8009453770853798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.044180057256696, 0.34675781913864817`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.044180057256696`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34675781913864817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784546`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732548`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33., "B3", 2, {
              Complex[6.044180057256696, 0.34675781913864817`], 
              Complex[4.196920084784546, -0.8003533490732548]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.805266648945746, -0.4925846278657947}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.805266648945746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4925846278657947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9772879223008717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.812894617501449`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B3", 1, {
              Complex[5.805266648945746, -0.4925846278657947], 
              Complex[3.9772879223008717`, -1.812894617501449]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.04020866039606, 0.3579884536883503}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.04020866039606`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3579884536883503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400241`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.099999999999994`, "B3", 2, {
              Complex[6.04020866039606, 0.3579884536883503], 
              Complex[4.1915552925709445`, -0.7869033281400241]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.809701663341314, -0.5029909709021079}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.809701663341314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5029909709021079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.983425219490024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8246261926386411`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B3", 1, {
              Complex[5.809701663341314, -0.5029909709021079], 
              Complex[3.983425219490024, -1.8246261926386411`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.036519936690694, 0.36900737727295657`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.036519936690694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36900737727295657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.186541632425325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7736790656393441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.199999999999996`, "B3", 2, {
              Complex[6.036519936690694, 0.36900737727295657`], 
              Complex[4.186541632425325, -0.7736790656393441]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.81387720976465, -0.5131921073476412}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.81387720976465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5131921073476412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B3", 1, {
              Complex[5.81387720976465, -0.5131921073476412], 
              Complex[3.989240598169983, -1.836139309119696]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.033087248838311, 0.3798158565375278}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.033087248838311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3798158565375278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613814`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.3, "B3", 2, {
              Complex[6.033087248838311, 0.3798158565375278], 
              Complex[4.1818475767949295`, -0.7606812732613814]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.817817100281683, -0.5231908494724428}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.817817100281683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8474353092142086`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B3", 1, {
              Complex[5.817817100281683, -0.5231908494724428], 
              Complex[3.994762358551031, -1.8474353092142086`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.029886810127787, 0.39041676979000506`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.029886810127787`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.39041676979000506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781011`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.39999999999999, "B3", 2, {
              Complex[6.029886810127787, 0.39041676979000506`], 
              Complex[4.177444833357386, -0.7479085282781011]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.821542567589421, -0.5329911517598128}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.821542567589421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.858517093091784`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B3", 1, {
              Complex[5.821542567589421, -0.5329911517598128], 
              Complex[4.000015848490729, -1.858517093091784]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.02689741297982, 0.40081413643466185`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.02689741297982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40081413643466185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7353578512653347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.49999999999999, "B3", 2, {
              Complex[6.02689741297982, 0.40081413643466185`], 
              Complex[4.173308062162179, -0.7353578512653347]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8250725348409, -0.5425977517885678}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8250725348409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.00502375333401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.869388672925242`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B3", 1, {
              Complex[5.8250725348409, -0.5425977517885678], 
              Complex[4.00502375333401, -1.869388672925242]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.024100159124149, 0.4110127578783314}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.024100159124149`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4110127578783314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753931`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.599999999999994`, "B3", 2, {
              Complex[6.024100159124149, 0.4110127578783314], 
              Complex[4.169414585788293, -0.7230251519753931]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8284238715967085`, -0.5520158986267112}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8284238715967085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501802`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B3", 1, {
              Complex[5.8284238715967085`, -0.5520158986267112], 
              Complex[4.009806376364359, -1.880054831501802]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.021478203650236, 0.4210179459473799}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.021478203650236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4210179459473799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023495`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.699999999999996`, "B3", 2, {
              Complex[6.021478203650236, 0.4210179459473799], 
              Complex[4.165744108890899, -0.7109055707023495]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.831611629629778, -0.5612511491377962}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.831611629629778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5612511491377962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.014381900889091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8905208626824301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B3", 1, {
              Complex[5.831611629629778, -0.5612511491377962], 
              Complex[4.014381900889091, -1.8905208626824301`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.019016519204634, 0.4308353192168009}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.019016519204634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4308353192168009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997093`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.8, "B3", 2, {
              Complex[6.019016519204634, 0.4308353192168009], 
              Complex[4.162278456114007, -0.6989937377997093]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.834649256054719, -0.5703092165540443}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.834649256054719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9007923754230098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B3", 1, {
              Complex[5.834649256054719, -0.5703092165540443], 
              Complex[4.018766629721941, -1.9007923754230098`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.016701682863842, 0.4404706516054355}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.016701682863842`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4404706516054355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {33.9, "B3", 2, {
              Complex[6.016701682863842, 0.4404706516054355], 
              Complex[4.159001332605871, -0.6872839696368798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.837548783508502, -0.5791958590266288}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.837548783508502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759233`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578686`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B3", 1, {
              Complex[5.837548783508502, -0.5791958590266288], 
              Complex[4.022975200759233, -1.9108751468578686`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.014521685955785, 0.4499297609478434}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.014521685955785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.675770415493782`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34., "B3", 2, {
              Complex[6.014521685955785, 0.4499297609478434], 
              Complex[4.155898108440934, -0.675770415493782]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.840320998393064, -0.5879167986060267}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.840320998393064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.027020779081279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848578`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B3", 1, {
              Complex[5.840320998393064, -0.5879167986060267], 
              Complex[4.027020779081279, -1.9207750130848578`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.012465765819384, 0.4592184279956062}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.012465765819384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4592184279956062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6644471667545314`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.1, "B3", 2, {
              Complex[6.012465765819384, 0.4592184279956062], 
              Complex[4.152955626516614, -0.6644471667545314]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.842975588855198, -0.5964776632911535}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.842975588855198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5964776632911535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211992`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B3", 1, {
              Complex[5.842975588855198, -0.5964776632911535], 
              Complex[4.030915226970469, -1.9304977888211992`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.010524257826831, 0.4683423384869708}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.010524257826831`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4683423384869708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307831`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.2, "B3", 2, {
              Complex[6.010524257826831, 0.4683423384869708], 
              Complex[4.150162032533443, -0.6533083372307831]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8455212744613, -0.6048839465011082}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8455212744613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6048839465011082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B3", 1, {
              Complex[5.8455212744613, -0.6048839465011082], 
              Complex[4.034669253707697, -1.9400492091033892`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.008688465710948, 0.47730704263853474`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.008688465710948`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47730704263853474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6423481214415794`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.3, "B3", 2, {
              Complex[6.008688465710948, 0.47730704263853474`], 
              Complex[4.147506625196922, -0.6423481214415794]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.84796591957802, -0.6131409796537515}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.84796591957802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6131409796537515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B3", 1, {
              Complex[5.84796591957802, -0.6131409796537515], 
              Complex[4.038292547177893, -1.9494348877721936`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.006950548186772, 0.4861179277432377}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.006950548186772`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4861179277432377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6315608361086175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.39999999999999, "B3", 2, {
              Complex[6.006950548186772, 0.4861179277432377], 
              Complex[4.144979724610491, -0.6315608361086175]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.850316632393395, -0.6212539145605389}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.850316632393395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04179388930688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B3", 1, {
              Complex[5.850316632393395, -0.6212539145605389], 
              Complex[4.04179388930688, -1.958660288701135]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0053034199324715`, 0.4947802005841794}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0053034199324715`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4947802005841794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084491`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.49999999999999, "B3", 2, {
              Complex[6.0053034199324715`, 0.4947802005841794], 
              Complex[4.1425725568370115`, -0.6209409489084491]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.852579851369116, -0.6292277131331433}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.852579851369116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.04518125724443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670984`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B3", 1, {
              Complex[5.852579851369116, -0.6292277131331433], 
              Complex[4.04518125724443, -1.9677307066670984`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.003740665139239, 0.5032988771597035}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.003740665139239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5032988771597035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.140277152714267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6104830975830703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.599999999999994`, "B3", 2, {
              Complex[6.003740665139239, 0.5032988771597035], 
              Complex[4.140277152714267, -0.6104830975830703]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.854761420740972, -0.637067142498334}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.854761420740972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.637067142498334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854916`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B3", 1, {
              Complex[5.854761420740972, -0.637067142498334], 
              Complex[4.048461912051172, -1.9766512554854916`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.0022564620129675`, 0.5116787778163029}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.0022564620129675`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5116787778163029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1380862591666565`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6001821017863873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.699999999999996`, "B3", 2, {
              Complex[6.0022564620129675`, 0.5116787778163029], 
              Complex[4.1380862591666565`, -0.6001821017863873]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.856866656504023, -0.6447767740762016}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.856866656504023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885529`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B3", 1, {
              Complex[5.856866656504023, -0.6447767740762016], 
              Complex[4.051642476470394, -1.9854268615885529`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{6.000845516791171, 0.519924526344405}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"6.000845516791171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.519924526344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.135993261432002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5900329694879913`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.8, "B3", 2, {
              Complex[6.000845516791171, 0.519924526344405], 
              Complex[4.135993261432002, -0.5900329694879913]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8589004041447135`, -0.6523609855265128}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8589004041447135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6523609855265128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B3", 1, {
              Complex[5.8589004041447135`, -0.6523609855265128], 
              Complex[4.054729003187752, -1.9940622616524237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.999503006012947, 0.528040551941874}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.999503006012947`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.528040551941874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133992114800525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5800308993285693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {34.9, "B3", 2, {
              Complex[5.999503006012947, 0.528040551941874], 
              Complex[4.133992114800525, -0.5800308993285693]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.860867089220406, -0.6598239647344442}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.860867089220406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6598239647344442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0025620032062545`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B3", 1, {
              Complex[5.860867089220406, -0.6598239647344442], 
              Complex[4.057727034812087, -2.0025620032062545`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.998224525941575, 0.5360310932164654}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.998224525941575`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5360310932164654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1320772846328255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5701712799937014`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35., "B3", 2, {
              Complex[5.998224525941575, 0.5360310932164654], 
              Complex[4.1320772846328255`, -0.5701712799937014]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.862770761740871, -0.6671697152100744}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.862770761740871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6671697152100744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0606416566544326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0109304474081906`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B3", 1, {
              Complex[5.862770761740871, -0.6671697152100744], 
              Complex[4.0606416566544326`, -2.0109304474081906`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.99700604818503, 0.5439002036016083}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.99700604818503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5439002036016083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130243693579622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5604496874212136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.1, "B3", 2, {
              Complex[5.99700604818503, 0.5439002036016083], 
              Complex[4.130243693579622, -0.5604496874212136]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.86461513517684, -0.6744020624307271}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86461513517684`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6744020624307271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B3", 1, {
              Complex[5.86461513517684, -0.6744020624307271], 
              Complex[4.063477543241718, -2.0191717733661467`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.995843880689525, 0.5516517577146818}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.995843880689525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5516517577146818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128486675066932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5508618804640709`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.199999999999996`, "B3", 2, {
              Complex[5.995843880689525, 0.5516517577146818], 
              Complex[4.128486675066932, -0.5508618804640709]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.86640362080727, -0.6815246607732995}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.86640362080727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B3", 1, {
              Complex[5.86640362080727, -0.6815246607732995], 
              Complex[4.066238999377148, -2.0272899835297697`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.994734633394268, 0.5592894583048527}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.994734633394268`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5592894583048527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.126801932234575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5414037954825208`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.3, "B3", 2, {
              Complex[5.994734633394268, 0.5592894583048527], 
              Complex[4.126801932234575, -0.5414037954825208]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.868139358018381, -0.6885410007735715}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.868139358018381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6885410007735715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939633`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B3", 1, {
              Complex[5.868139358018381, -0.6885410007735715], 
              Complex[4.06892999644998, -2.0352889097939633`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.993675187934443, 0.5668168435275391}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.993675187934443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668168435275391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.125185501625341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5320715402250115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.4, "B3", 2, {
              Complex[5.993675187934443, 0.5668168435275391], 
              Complex[4.125185501625341, -0.5320715402250115]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.869825241082359, -0.6954544165180526}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.869825241082359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6954544165180526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.071554204602269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.043172220042138`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B3", 1, {
              Complex[5.869825241082359, -0.6954544165180526], 
              Complex[4.071554204602269, -2.043172220042138]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.992662670864552, 0.5742372943510564}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.992662670864552`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5742372943510564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123633721017264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5228613872697351`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.49999999999999, "B3", 2, {
              Complex[5.992662670864552, 0.5742372943510564], 
              Complex[4.123633721017264, -0.5228613872697351]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.871463942870232, -0.7022680930260652}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.871463942870232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B3", 1, {
              Complex[5.871463942870232, -0.7022680930260652], 
              Complex[4.074115021277763, -2.0509434249247764`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.991694429947489, 0.5815540419531224}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.991694429947489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5815540419531224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12214320087372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5137697672312349`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.599999999999994`, "B3", 2, {
              Complex[5.991694429947489, 0.5815540419531224], 
              Complex[4.12214320087372, -0.5137697672312349]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.87305793589056, -0.7089850735194753}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.87305793589056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B3", 1, {
              Complex[5.87305793589056, -0.7089850735194753], 
              Complex[4.076615596606936, -2.0586058847208237`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.990768013117869, 0.588770175004682}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.990768013117869`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.588770175004682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120710798957501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5047932618845052`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.699999999999996`, "B3", 2, {
              Complex[5.990768013117869, 0.588770175004682], 
              Complex[4.120710798957501, -0.5047932618845052]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.874609510991549, -0.7156082665076038}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.874609510991549`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B3", 1, {
              Complex[5.874609510991549, -0.7156082665076038], 
              Complex[4.079058856020895, -2.0661628161692955`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.98988114978185, 0.5958886467685789}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.98988114978185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5958886467685789`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1193335977160075`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.49592859731920275`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {35.8, "B3", 2, {
              Complex[5.98988114978185, 0.5958886467685789], 
              Complex[4.1193335977160075`, -0.49592859731920275`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.876120794018037, -0.7221404526376908}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.876120794018037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0736172991891597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B3", 1, {
              Complex[5.876120794018037, -0.7221404526376908], 
              Complex[4.081447520434107, -2.0736172991891597`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.989031734162119, 0.6029122819634535}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.989031734162119`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6029122819634535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.118008884097689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4871726372059098`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.9, "B3", 2, {
              Complex[5.989031734162119, 0.6029122819634535], 
              Complex[4.118008884097689, -0.4871726372059098]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.877593760675199, -0.7285842912785059}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.877593760675199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785059`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.083784124290591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0809722834290376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B3", 1, {
              Complex[5.877593760675199, -0.7285842912785059], 
              Complex[4.083784124290591, -2.0809722834290376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.988217810436113, 0.6098437833604634}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.988217810436113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6098437833604634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.116734131505035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4785223762328954`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {35.99999999999999, "B3", 2, {
              Complex[5.988217810436113, 0.6098437833604634], 
              Complex[4.116734131505035, -0.4785223762328954]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.879030249816931, -0.7349423268176076}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.879030249816931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7349423268176076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0882305946062263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B3", 1, {
              Complex[5.879030249816931, -0.7349423268176076], 
              Complex[4.086071031729207, -2.0882305946062263`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.987437559449537, 0.616685738093365}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.987437559449537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.616685738093365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115506983628505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46997493375384003`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.099999999999994`, "B3", 2, {
              Complex[5.987437559449537, 0.616685738093365], 
              Complex[4.115506983628505, -0.46997493375384003`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.880431975347877, -0.7412169946624547}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.880431975347877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7412169946624547`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0883104510902495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B3", 1, {
              Complex[5.880431975347877, -0.7412169946624547], 
              Complex[4.0883104510902495`, -2.095394940608318]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.986689286816269, 0.6234406236721282}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.986689286816269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6234406236721282`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.114325239939222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.46152754767328286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.199999999999996`, "B3", 2, {
              Complex[5.986689286816269, 0.6234406236721282], 
              Complex[4.114325239939222, -0.46152754767328286`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.881800536903074, -0.7474106269426314}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.881800536903074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7474106269426314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B3", 1, {
              Complex[5.881800536903074, -0.7474106269426314], 
              Complex[4.090504447956573, -2.1024679173410123`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.985971412240573, 0.6301108136973947}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985971412240573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6301108136973947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113186842647122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4531775685861346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.3, "B3", 2, {
              Complex[5.985971412240573, 0.6301108136973947], 
              Complex[4.113186842647122, -0.4531775685861346]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.883137429447864, -0.7535254579157123}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.883137429447864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7535254579157123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0926549568977935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B3", 1, {
              Complex[5.883137429447864, -0.7535254579157123], 
              Complex[4.0926549568977935`, -2.109452014313655]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.985282459919064, 0.6366985832782691}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.985282459919064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6366985832782691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112089864956078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4449224541797798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.4, "B3", 2, {
              Complex[5.985282459919064, 0.6366985832782691], 
              Complex[4.112089864956078, -0.4449224541797798]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.884444051922338, -0.7595636290829754}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.884444051922338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1163496199598395`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B3", 1, {
              Complex[5.884444051922338, -0.7595636290829754], 
              Complex[4.094763792064631, -2.1163496199598395`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.984621049898127, 0.643206114159718}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.984621049898127`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.643206114159718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.111032500468935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4367597639013438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.5, "B3", 2, {
              Complex[5.984621049898127, 0.643206114159718], 
              Complex[4.111032500468935, -0.4367597639013438]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.885721715038686, -0.7655271940238007}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.885721715038686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.123163026694792`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B3", 1, {
              Complex[5.885721715038686, -0.7655271940238007], 
              Complex[4.096832656761998, -2.123163026694792]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.983985890278379, 0.6496354995683528}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983985890278379`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6496354995683528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.110013053613793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42868715388848116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.6, "B3", 2, {
              Complex[5.983985890278379, 0.6496354995683528], 
              Complex[4.110013053613793, -0.42868715388848116`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.886971648326271, -0.7714181229593432}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.886971648326271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144114`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B3", 1, {
              Complex[5.886971648326271, -0.7714181229593432], 
              Complex[4.098863152113465, -2.1298944357144114`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.983375770171436, 0.655988748787251}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.983375770171436`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.655988748787251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.109029930978956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4207023721587472`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.699999999999996`, "B3", 2, {
              Complex[5.983375770171436, 0.655988748787251], 
              Complex[4.109029930978956, -0.4207023721587472]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.888195006507387, -0.7772383070571703}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.888195006507387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B3", 1, {
              Complex[5.888195006507387, -0.7772383070571703], 
              Complex[4.100856784915978, -2.136545961543077]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.982789553325939, 0.6622677914714878}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982789553325939`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6622677914714878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.10808163345767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.41280325405043844`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {36.79999999999999, "B3", 2, {
              Complex[5.982789553325939, 0.6622677914714878], 
              Complex[4.10808163345767, -0.41280325405043844`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.88939287527652, -0.782989562489217}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.88939287527652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.782989562489217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B3", 1, {
              Complex[5.88939287527652, -0.782989562489217], 
              Complex[4.102814974771636, -2.143119636338955]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.982226172350083, 0.6684744817167128}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.982226172350083`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6684744817167128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1071667491158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4049877179062303`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.89999999999999, "B3", 2, {
              Complex[5.982226172350083, 0.6684744817167128], 
              Complex[4.1071667491158, -0.4049877179062303]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.89056627654708, -0.7886736342555825}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.89056627654708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.149617413966407`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B3", 1, {
              Complex[5.89056627654708, -0.7886736342555825], 
              Complex[4.104739060573037, -2.149617413966407]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.981684623466656, 0.6746106018933713}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981684623466656`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6746106018933713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1062839467060055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3972537609898815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {36.99999999999999, "B3", 2, {
              Complex[5.981684623466656, 0.6746106018933713], 
              Complex[4.1062839467060055`, -0.3972537609898815]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.891716173221934, -0.7942921997868306}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.891716173221934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7942921997868306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1066303064095715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B3", 1, {
              Complex[5.891716173221934, -0.7942921997868306], 
              Complex[4.1066303064095715`, -2.156041173845927]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.981163961744247, 0.6806778662591632}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.981163961744247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6806778662591632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.105431969760929`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3895994556256985`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.099999999999994`, "B3", 2, {
              Complex[5.981163961744247, 0.6806778662591632], 
              Complex[4.105431969760929, -0.3895994556256985]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.892843473537392, -0.7998468723371351}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.892843473537392`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B3", 1, {
              Complex[5.892843473537392, -0.7998468723371351], 
              Complex[4.108489906954296, -2.1623927245921415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.980663296755008, 0.6866779243621381}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980663296755008`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6866779243621381`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104609631205909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3820229455501256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.199999999999996`, "B3", 2, {
              Complex[5.980663296755008, 0.6866779243621381], 
              Complex[4.104609631205909, -0.3820229455501256]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.893949035024502, -0.8053392041803533}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.893949035024502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8053392041803533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1103189923839905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1686738074506064`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B3", 1, {
              Complex[5.893949035024502, -0.8053392041803533], 
              Complex[4.1103189923839905`, -2.1686738074506064`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.980181788615051, 0.6926123642464803}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.980181788615051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6926123642464803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.103815808438448`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37452244246479277`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.3, "B3", 2, {
              Complex[5.980181788615051, 0.6926123642464803], 
              Complex[4.103815808438448, -0.37452244246479277`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.8950336681265165`, -0.8107706896206487}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.8950336681265165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1748860995439667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B3", 1, {
              Complex[5.8950336681265165`, -0.8107706896206487], 
              Complex[4.112118632879191, -2.1748860995439667`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.979718644368703, 0.6984827154726538}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979718644368703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6984827154726538`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1030494388277985`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3670962227803727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.4, "B3", 2, {
              Complex[5.979718644368703, 0.6984827154726538], 
              Complex[4.1030494388277985`, -0.3670962227803727]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.896098139506871, -0.8161427678288314}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.896098139506871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8161427678288314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1138898427456025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.181031216937888`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B3", 1, {
              Complex[5.896098139506871, -0.8161427678288314], 
              Complex[4.1138898427456025`, -2.181031216937888]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.979273114682207, 0.7042904519630309}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.979273114682207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7042904519630309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102309515593163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3597426245409141`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.5, "B3", 2, {
              Complex[5.979273114682207, 0.7042904519630309], 
              Complex[4.102309515593163, -0.3597426245409141]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.897143175078252, -0.8214568255150104}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.897143175078252`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8214568255150104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.187110717536775`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B3", 1, {
              Complex[5.897143175078252, -0.8214568255150104], 
              Complex[4.115633584193734, -2.187110717536775]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.978844490816281, 0.7100369946836335}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978844490816281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7100369946836335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.101595084023627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35246004451858104`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.6, "B3", 2, {
              Complex[5.978844490816281, 0.7100369946836335], 
              Complex[4.101595084023627, -0.35246004451858104`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.898169462779893, -0.8267141994476594}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.898169462779893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8267141994476594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11735077080964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B3", 1, {
              Complex[5.898169462779893, -0.8267141994476594], 
              Complex[4.11735077080964, -2.193126103819013]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9784321018505455`, 0.7157237141721113}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9784321018505455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7157237141721113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100905238007176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34524693546904034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.7, "B3", 2, {
              Complex[5.9784321018505455`, 0.7157237141721113], 
              Complex[4.100905238007176, -0.34524693546904034`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.899177655127286, -0.8319161788285983}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.899177655127286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8319161788285983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420971`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B3", 1, {
              Complex[5.899177655127286, -0.8319161788285983], 
              Complex[4.119042270745964, -2.199078825420971]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.978035312135368, 0.7213519329214122}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.978035312135368`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7213519329214122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100239116839226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3381018035383217`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.8, "B3", 2, {
              Complex[5.978035312135368, 0.7213519329214122], 
              Complex[4.100239116839226, -0.3381018035383217]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.900168371555867, -0.8370640075328958}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.900168371555867`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8370640075328958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B3", 1, {
              Complex[5.900168371555867, -0.8370640075328958], 
              Complex[4.120708909659479, -2.204970281578657]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.977653518949829, 0.7269229276281969}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.977653518949829`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7269229276281969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.099595902284807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33102320581219813`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.89999999999999, "B3", 2, {
              Complex[5.977653518949829, 0.7269229276281969], 
              Complex[4.099595902284807, -0.33102320581219813`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.901142200577949, -0.8421588862221203}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.901142200577949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353843`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B3", 1, {
              Complex[5.901142200577949, -0.8421588862221203], 
              Complex[4.122351473418492, -2.2108018234353843`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.97728615034638, 0.7324379313144281}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97728615034638`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7324379313144281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098974815870868`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.32400974799972276`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {37.99999999999999, "B3", 2, {
              Complex[5.97728615034638, 0.7324379313144281], 
              Complex[4.098974815870868, -0.32400974799972276`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9020997017701315`, -0.8472019743388882}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9020997017701315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8472019743388882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B3", 1, {
              Complex[5.9020997017701315`, -0.8472019743388882], 
              Complex[4.123970710601056, -2.2165747562234497`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976932663165016, 0.7378981353300635}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976932663165016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7378981353300635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098375116387771`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31706008224295834`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.099999999999994`, "B3", 2, {
              Complex[5.976932663165016, 0.7378981353300635], 
              Complex[4.098375116387771, -0.31706008224295834`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.903041407606638, -0.852194391990135}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903041407606638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.852194391990135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B3", 1, {
              Complex[5.903041407606638, -0.852194391990135], 
              Complex[4.12556733480281, -2.222290341327314]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976592541201492, 0.7433046912443029}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976592541201492`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7433046912443029`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.097796097581198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31017290504537054`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.199999999999996`, "B3", 2, {
              Complex[5.976592541201492, 0.7433046912443029], 
              Complex[4.097796097581198, -0.31017290504537054`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.903967825152418, -0.8571372217260815}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.903967825152418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B3", 1, {
              Complex[5.903967825152418, -0.8571372217260815], 
              Complex[4.127142026771301, -2.2279497982353833`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.976265293515786, 0.7486587126323617}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.976265293515786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7486587126323617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.09723708601758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.30334695531178235`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.3, "B3", 2, {
              Complex[5.976265293515786, 0.7486587126323617], 
              Complex[4.09723708601758, -0.30334695531178235`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.904879437628475, -0.8620315102214064}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.904879437628475`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8620315102214064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B3", 1, {
              Complex[5.904879437628475, -0.8620315102214064], 
              Complex[4.128695436382012, -2.2335543063870658`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975950452868279, 0.7539612767642825}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975950452868279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7539612767642825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096697439107836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29658101249323643`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.4, "B3", 2, {
              Complex[5.975950452868279, 0.7539612767642825], 
              Complex[4.096697439107836, -0.29658101249323643`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.905776705860623, -0.8668782698647188}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.905776705860623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2391050069213736`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B3", 1, {
              Complex[5.905776705860623, -0.8668782698647188], 
              Complex[4.130228184469745, -2.2391050069213736`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975647574272541, 0.7592134262018878}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975647574272541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7592134262018878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096176543275776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.28987389483045467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.5, "B3", 2, {
              Complex[5.975647574272541, 0.7592134262018878], 
              Complex[4.096176543275776, -0.28987389483045467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9066600696217355`, -0.8716784802620264}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9066600696217355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8716784802620264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B3", 1, {
              Complex[5.9066600696217355`, -0.8716784802620264], 
              Complex[4.131740864527742, -2.2446030043329674`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975356233654551, 0.7644161703095629}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975356233654551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7644161703095629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095673812258775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2832244576900404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.599999999999994`, "B3", 2, {
              Complex[5.975356233654551, 0.7644161703095629], 
              Complex[4.095673812258775, -0.2832244576900404]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.907529948876621, -0.8764330896595154}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.907529948876621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8764330896595154`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B3", 1, {
              Complex[5.907529948876621, -0.8764330896595154], 
              Complex[4.133234044285656, -2.25004936804117]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.975076026609326, 0.7695704866842142}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.975076026609326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7695704866842142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.095188685529604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.27663159198783`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.699999999999996`, "B3", 2, {
              Complex[5.975076026609326, 0.7695704866842142], 
              Complex[4.095188685529604, -0.27663159198783]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.908386744937716, -0.8811430162906054}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.908386744937716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B3", 1, {
              Complex[5.908386744937716, -0.8811430162906054], 
              Complex[4.134708267176491, -2.2554451338771337`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974806567246683, 0.7746773225093266}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974806567246683`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7746773225093266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094720626829336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27009422269428585`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.8, "B3", 2, {
              Complex[5.974806567246683, 0.7746773225093266], 
              Complex[4.094720626829336, -0.27009422269428585`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.909230841539049, -0.8858091496519155}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.909230841539049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8858091496519155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2607913054940165`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B3", 1, {
              Complex[5.909230841539049, -0.8858091496519155], 
              Complex[4.136164053701611, -2.2607913054940165`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974547487118723, 0.779737595837812}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974547487118723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.779737595837812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094269122802148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26361130741698524`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.9, "B3", 2, {
              Complex[5.974547487118723, 0.779737595837812], 
              Complex[4.094269122802148, -0.26361130741698524`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.910062605835208, -0.8904323517124778}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910062605835208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B3", 1, {
              Complex[5.910062605835208, -0.8904323517124778], 
              Complex[4.137601902702118, -2.2660888557047376`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974298434222312, 0.7847521968079424}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974298434222312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7847521968079424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.093833681723805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25718183505570735`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {38.99999999999999, "B3", 2, {
              Complex[5.974298434222312, 0.7847521968079424], 
              Complex[4.093833681723805, -0.25718183505570735`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.910882389331387, -0.8950134580602268}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.910882389331387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8950134580602268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2713387277515547`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B3", 1, {
              Complex[5.910882389331387, -0.8950134580602268], 
              Complex[4.139022292544099, -2.2713387277515547`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.974059072070432, 0.7897219887964377}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.974059072070432`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7897219887964377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0934138323162665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2508048245258122`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.099999999999994`, "B3", 2, {
              Complex[5.974059072070432, 0.7897219887964377], 
              Complex[4.0934138323162665`, -0.2508048245258122]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.911690528750102, -0.8995532789895441}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.911690528750102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B3", 1, {
              Complex[5.911690528750102, -0.8995532789895441], 
              Complex[4.1404256822245795`, -2.2765418365114747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973829078826883, 0.7946478095124517}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973829078826883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7946478095124517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0930091226416065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.244479323545952`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.199999999999996`, "B3", 2, {
              Complex[5.973829078826883, 0.7946478095124517], 
              Complex[4.0930091226416065`, -0.244479323545952]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.912487346839559, -0.904052600533387}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.912487346839559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.904052600533387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412356`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B3", 1, {
              Complex[5.912487346839559, -0.904052600533387], 
              Complex[4.141812512404397, -2.2816990696412356`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973608146499301, 0.7995304720360318}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973608146499301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7995304720360318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092619119069028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2382044074863148`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.3, "B3", 2, {
              Complex[5.973608146499301, 0.7995304720360318], 
              Complex[4.092619119069028, -0.2382044074863148]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.913273153128292, -0.9085121854432785}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.913273153128292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432785`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B3", 1, {
              Complex[5.913273153128292, -0.9085121854432785], 
              Complex[4.143183206373633, -2.286811288665357]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9733959801858845`, 0.8043707658042932}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9733959801858845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8043707658042932`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092243405309306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23197917827395678`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.4, "B3", 2, {
              Complex[5.9733959801858845`, 0.8043707658042932], 
              Complex[4.092243405309306, -0.23197917827395678`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.914048244630215, -0.9129327741202411}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914048244630215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010546`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B3", 1, {
              Complex[5.914048244630215, -0.9129327741202411], 
              Complex[4.1445381709548, -2.291879330010546]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.973192297371707, 0.8091694575484238}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.973192297371707`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8091694575484238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0918815815115215`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.22580276335188598`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.49999999999999, "B3", 2, {
              Complex[5.973192297371707, 0.8091694575484238], 
              Complex[4.0918815815115215`, -0.22580276335188598`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.914812906503919, -0.9173150854995431}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.914812906503919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.145877797348456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.296904005989524`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B3", 1, {
              Complex[5.914812906503919, -0.9173150854995431], 
              Complex[4.145877797348456, -2.296904005989524]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972996827270754, 0.8139272921843711}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972996827270754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8139272921843711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091533263417343`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21967431468886214`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.599999999999994`, "B3", 2, {
              Complex[5.972996827270754, 0.8139272921843711], 
              Complex[4.091533263417343, -0.21967431468886214`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9155674126696605`, -0.9216598178919517}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9155674126696605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371853`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B3", 1, {
              Complex[5.9155674126696605`, -0.9216598178919517], 
              Complex[4.147202461925567, -2.3018861057371853`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972809310210266, 0.8186449936599097}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972809310210266`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8186449936599097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.091198081568591`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21359300783699628`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.699999999999996`, "B3", 2, {
              Complex[5.972809310210266, 0.8186449936599097], 
              Complex[4.091198081568591, -0.21359300783699628`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.916312026387238, -0.925967649783973}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.916312026387238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.925967649783973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101707`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B3", 1, {
              Complex[5.916312026387238, -0.925967649783973], 
              Complex[4.148512526970577, -2.306826396101707]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.9726294970541804`, 0.8233232657606012}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9726294970541804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8233232657606012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090875680564113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20755804103448117`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {39.8, "B3", 2, {
              Complex[5.9726294970541804`, 0.8233232657606012], 
              Complex[4.090875680564113, -0.20755804103448117`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.917047000797618, -0.9302392405994727}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.917047000797618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B3", 1, {
              Complex[5.917047000797618, -0.9302392405994727], 
              Complex[4.149808341378717, -2.311725622493254]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.972457148662774, 0.8279627928769886}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.972457148662774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8279627928769886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090565718362365`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2015686343508945`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {39.9, "B3", 2, {
              Complex[5.972457148662774, 0.8279627928769886], 
              Complex[4.090565718362365, -0.2015686343508945]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], 
          TagBox[
           TooltipBox[PointBox[{5.9177725794310545`, -0.9344752314248252}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B3\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.9177725794310545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9344752314248252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.15109024131099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.316584509692523`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {40., "B3", 1, {
              Complex[5.9177725794310545`, -0.9344752314248252], 
              Complex[4.15109024131099, -2.316584509692523]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{5.97229203538588, 0.8325642407352367}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B3\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"5.97229203538588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8325642407352367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090267865626448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.19562402887272795`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                 ",", "0"}], "}"}]],
           Annotation[#, {40., "B3", 2, {
              Complex[5.97229203538588, 0.8325642407352367], 
              Complex[4.090267865626448, -0.19562402887272795`]}, 0}, 
            "Tooltip"]& ]}}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->900,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-32.48921089704068, -5.49727768712696}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.245615698905056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.546462974510604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.3583570943027`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11658019540031805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A1", 
             Association[1 -> {
                Complex[12.245615698905056`, -11.285995288896373`], 
                Complex[31.494082066597198`, -37.546462974510604`]}, 2 -> {
                Complex[82.3583570943027, 0.11658019540031805`], 
                Complex[108.70582923184111`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-32.09349671692901, -5.433681341367}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.866460671342168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.816178584119385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.10766368142046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.65454606371028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A1", 
             Association[1 -> {
                Complex[12.866460671342168`, -10.816178584119385`], 
                Complex[32.10766368142046, -37.05300319249051]}, 2 -> {
                Complex[81.65454606371028, 0.11776334712026199`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-31.704586653157186`, -5.372449776918645}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.385569221277168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.443606571400114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.62046690403218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.08582224927886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "A1", 
             Association[1 -> {
                Complex[13.385569221277168`, -10.443606571400114`], 
                Complex[32.62046690403218, -36.65624121214425]}, 2 -> {
                Complex[81.08582224927886, 0.11905307061487365`], 
                Complex[107.41258000537293`, -20.41001952735828]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-31.321453687498853`, -5.313159149602601}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.844879609183106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.128345372417396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.074306417344815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.59570734825861`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12040941356394542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A1", 
             Association[1 -> {
                Complex[13.844879609183106`, -10.128345372417396`], 
                Complex[33.074306417344815`, -36.31637452115125]}, 2 -> {
                Complex[80.59570734825861, 0.12040941356394542`], 
                Complex[106.91207211908184`, -20.409835465464518`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.943450473277032`, -5.255540138212494}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.263512998287613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.852138089238336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.48822262138849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.01523037051932`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.15853740070536`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12181511399306792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40960872633279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "A1", 
             Association[1 -> {
                Complex[14.263512998287613`, -9.852138089238336], 
                Complex[33.48822262138849, -36.01523037051932]}, 2 -> {
                Complex[80.15853740070536, 0.12181511399306792`], 
                Complex[106.46447895532776`, -20.40960872633279]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.570120334519938`, -5.1994013782971695`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.652107822673527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.60480138795417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.87279494489345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.74268548695589`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.76008128321261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12326110383985404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.05556643970378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409348870362294`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A1", 
             Association[1 -> {
                Complex[14.652107822673527`, -9.60480138795417], 
                Complex[33.87279494489345, -35.74268548695589]}, 2 -> {
                Complex[79.76008128321261, 0.12326110383985404`], 
                Complex[106.05556643970378`, -20.409348870362294`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.201118717270784`, -5.1445975468436735`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.017310748471408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.379958105911207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.3914778440311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1247420703186469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A1", 
             Association[1 -> {
                Complex[15.017310748471408`, -9.379958105911207], 
                Complex[34.23462400814145, -35.492408387804]}, 2 -> {
                Complex[79.3914778440311, 0.1247420703186469], 
                Complex[105.67647115587602`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.83617369065385, -5.091013266903429}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.363606529112152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.17329625288842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.260123312215754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.04676899384386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12625468557684455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.32123318016059`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408750516874484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "A1", 
             Association[1 -> {
                Complex[15.363606529112152`, -9.17329625288842], 
                Complex[34.57815702977675, -35.260123312215754`]}, 2 -> {
                Complex[79.04676899384386, 0.12625468557684455`], 
                Complex[105.32123318016059`, -20.408750516874484`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.47506357698316, -5.038553965960297}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.694192540187109`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.981735864879811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.906559828007246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.04277989487664`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.72172225527217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1277967777586609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A1", 
             Association[1 -> {
                Complex[15.694192540187109`, -8.981735864879811], 
                Complex[34.906559828007246`, -35.04277989487664]}, 2 -> {
                Complex[78.72172225527217, 0.1277967777586609], 
                Complex[104.98561848841774`, -20.40841808612212]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.11760319400199, -4.987140237632351}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.011444946530013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.802984319586065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.8381102332606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.41320392779194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12936689788169053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40806597206126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "A1", 
             Association[1 -> {
                Complex[16.011444946530013`, -8.802984319586065], 
                Complex[35.22218142009305, -34.8381102332606]}, 2 -> {
                Complex[78.41320392779194, 0.12936689788169053`], 
                Complex[104.66649203468586`, -20.40806597206126]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-28.763634862057778`, -4.9367041456348755`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.31718789840238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.635279208450724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.52682218732508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.11881756413922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13096407459708617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "A1", 
             Association[1 -> {
                Complex[16.31718789840238, -8.635279208450724], 
                Complex[35.52682218732508, -34.644372916323725`]}, 2 -> {
                Complex[78.11881756413922, 0.13096407459708617`], 
                Complex[104.36145617205713`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-28.413022242772556`, -4.887186684238857}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.612858840508633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.47723022998036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.83668223957315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13258766651163573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A1", 
             Association[1 -> {
                Complex[16.612858840508633`, -8.47723022998036], 
                Complex[35.82189847272132, -34.46019571836112]}, 2 -> {
                Complex[77.83668223957315, 0.13258766651163573`], 
                Complex[104.06862888444635`, -20.407307041147234`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-28.06564595641145, -4.838535966689122}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.899615105400063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.327717105231178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.1085486648078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.284474089725364`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.56528975328628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13423726881752882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "A1", 
             Association[1 -> {
                Complex[16.899615105400063`, -8.327717105231178], 
                Complex[36.1085486648078, -34.284474089725364`]}, 2 -> {
                Complex[77.56528975328628, 0.13423726881752882`], 
                Complex[103.78650096169157`, -20.406901625797378`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.721400367522214`, -4.790705892723485}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.17840543589556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.18582098961993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.116302994815634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.30340893094568`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13591265188074694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A1", 
             Association[1 -> {
                Complex[17.17840543589556, -8.18582098961993], 
                Complex[36.38770434340436, -34.116302994815634`]}, 2 -> {
                Complex[77.30340893094568, 0.13591265188074694`], 
                Complex[103.51384028303791`, -20.406479492338008`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.38019116652061, -4.743655143165185}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.4500195893454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.660139598224646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.9549296033411`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.05001933585376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951339305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "A1", 
             Association[1 -> {
                Complex[17.4500195893454, -8.050776840303662], 
                Complex[36.660139598224646`, -33.9549296033411]}, 2 -> {
                Complex[77.05001933585376, 0.13761371951339305`], 
                Complex[103.24962551411932`, -20.406040889030564`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.041933510426674`, -4.697346404749755}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.715123715910405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.921939398858399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.926506185668615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.799719524488225`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.80426404977382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13934047984247463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "A1", 
             Association[1 -> {
                Complex[17.715123715910405`, -7.921939398858399], 
                Complex[36.926506185668615`, -33.799719524488225`]}, 2 -> {
                Complex[76.80426404977382, 0.13934047984247463`], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.706550566766644`, -4.6517457612953965`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.97428620238765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.18735919764107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.65013212317828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.56541522251278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A1", 
             Association[1 -> {
                Complex[17.97428620238765, -7.798758308638237], 
                Complex[37.18735919764107, -33.65013212317828]}, 2 -> {
                Complex[76.56541522251278, 0.14109302450360017`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.37397235476145, -4.606822207779906}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.227996947167636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.44317619593503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.50570209730137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.33284841044511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14287151349532584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "A1", 
             Association[1 -> {
                Complex[18.227996947167636`, -7.680759532183109], 
                Complex[37.44317619593503, -33.50570209730137]}, 2 -> {
                Complex[76.33284841044511, 0.14287151349532584`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.044134810046817`, -4.562547257019681}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.476681999633616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.567531219181608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.694371737074945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.366025475903584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.10602311146744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1446761639763866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A1", 
             Association[1 -> {
                Complex[18.476681999633616`, -7.567531219181608], 
                Complex[37.694371737074945`, -33.366025475903584`]}, 2 -> {
                Complex[76.10602311146744, 0.1446761639763866], 
                Complex[102.26185863012617`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.716979020375305`, -4.5188946173236}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.7207148587158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.458712785360555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.23074880548425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.8844677615424`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187037323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "A1", 
             Association[1 -> {
                Complex[18.7207148587158, -7.458712785360555], 
                Complex[37.94130857631962, -33.23074880548425]}, 2 -> {
                Complex[75.8844677615424, 0.14650724187037323`], 
                Complex[102.02923912251609`, -20.403602844982533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.3924505941045, -4.475839925377928}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.960425318413485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.353986351536103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.18430643425337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.09956067860008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.66776800411328`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1483650555087814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A1", 
             Association[1 -> {
                Complex[18.960425318413485`, -7.353986351536103], 
                Complex[38.18430643425337, -33.09956067860008]}, 2 -> {
                Complex[75.66776800411328, 0.1483650555087814], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.070499133215673`, -4.433360522696326}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.196106481999152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.253069946548066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.42364894442649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.97218501218881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.45555740059443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15024995077914985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A1", 
             Association[1 -> {
                Complex[19.196106481999152`, -7.253069946548066], 
                Complex[38.42364894442649, -32.97218501218881]}, 2 -> {
                Complex[75.45555740059443, 0.15024995077914985`], 
                Complex[101.57804924438945`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.75107778962585, -4.391435266852968}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.428020388516035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.155712048248098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.659589223203085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.848375652574305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.24750998887278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15216230740510475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "A1", 
             Association[1 -> {
                Complex[19.428020388516035`, -7.155712048248098], 
                Complex[38.659589223203085`, -32.848375652574305`]}, 2 -> {
                Complex[75.24750998887278, 0.15216230740510475`], 
                Complex[101.35878495705765`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.434142888604857`, -4.350044370793775}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.656402573483003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.06168715326511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.892354381854474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.04333425978076`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15410253608764446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A1", 
             Association[1 -> {
                Complex[19.656402573483003`, -7.06168715326511], 
                Complex[38.892354381854474`, -32.727912000016886`]}, 2 -> {
                Complex[75.04333425978076, 0.15410253608764446`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.11965360679628, -4.30916926503895}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.88146580099659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.122149216633446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.610595426395264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.84276823492078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15607107631331532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506859`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400745136126783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A1", 
             Association[1 -> {
                Complex[19.88146580099659, -6.970792147471287], 
                Complex[39.122149216633446`, -32.610595426395264`]}, 2 -> {
                Complex[74.84276823492078, 0.15607107631331532`], 
                Complex[100.93145144506859`, -20.400745136126783`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.807571695076838`, -4.268792478719192}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.10340314443287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.3491592528931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.64557540947717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580683946848076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.7228822269972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.4001205101715`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A1", 
             Association[1 -> {
                Complex[20.10340314443287, -6.882843306606507], 
                Complex[39.3491592528931, -32.49624631678466]}, 2 -> {
                Complex[74.64557540947717, 0.1580683946848076], 
                Complex[100.7228822269972, -20.4001205101715]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.497861238541585`, -4.228897536235095}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.322390549817726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.797673797918388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.573553276414586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.38470160682706`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.45154138132087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1600949836664982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A1", 
             Association[1 -> {
                Complex[20.322390549817726`, -6.797673797918388], 
                Complex[39.573553276414586`, -32.38470160682706]}, 2 -> {
                Complex[74.45154138132087, 0.1600949836664982], 
                Complex[100.51741711927747`, -20.399477392046542`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.19048844746747, -4.189468866976496}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.53858898448397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.79548545383973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.27581271779224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.26047102973546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1621513606638985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.3148602374095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.398815388055127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "A1", 
             Association[1 -> {
                Complex[20.53858898448397, -6.715131583883614], 
                Complex[39.79548545383973, -32.27581271779224]}, 2 -> {
                Complex[74.26047102973546, 0.1621513606638985], 
                Complex[100.3148602374095, -20.398815388055127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.885421474306472`, -4.150491726035257}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.752146250400717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.635077651408368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340219`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07218613811635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16423806737529167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39813408035839`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "A1", 
             Association[1 -> {
                Complex[20.752146250400717`, -6.635077651408368], 
                Complex[40.01509712100966, -32.16944381340219]}, 2 -> {
                Complex[74.07218613811635, 0.16423806737529167`], 
                Complex[100.11503259520978`, -20.39813408035839]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.58263025269607, -4.111952124232918}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.963198524196073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.557384506607896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.065470319069306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.88652337816677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936818696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "A1", 
             Association[1 -> {
                Complex[20.963198524196073`, -6.557384506607896], 
                Complex[40.23251830075455, -32.065470319069306`]}, 2 -> {
                Complex[73.88652337816677, 0.16635566936818696`], 
                Complex[99.91777008789096, -20.397433027529207`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.282086355205085`, -4.073836766087403}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.171871672770024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.481934887900368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.447868998641226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.963777656737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.70333259061725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16850475584425448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.72292177174809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A1", 
             Association[1 -> {
                Complex[21.171871672770024`, -6.481934887900368], 
                Complex[40.447868998641226`, -31.963777656737]}, 2 -> {
                Complex[73.70333259061725, 0.16850475584425448`], 
                Complex[99.72292177174809, -20.39671176490144]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.98376286711323, -4.036132994585326}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.378282383376405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.408620659800499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.661260315234074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.864260158083315`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.52247531084704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17068593956353983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A1", 
             Association[1 -> {
                Complex[21.378282383376405`, -6.408620659800499], 
                Complex[40.661260315234074`, -31.864260158083315`]}, 2 -> {
                Complex[73.52247531084704, 0.17068593956353983`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.68763427398533, -3.9988287418178725`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.58253913933037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.76682012623099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34382349807167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1728998569070958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "A1", 
             Association[1 -> {
                Complex[21.58253913933037, -6.337341857243096], 
                Complex[40.87279540575696, -31.76682012623099]}, 2 -> {
                Complex[73.34382349807167, 0.1728998569070958], 
                Complex[99.33992109514008, -20.39520663629768]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.393676361172393`, -3.961912484693128}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.78474306649485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.08257031208464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.671367021850585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.167258434751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1751471680593818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39442172564926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A1", 
             Association[1 -> {
                Complex[21.78474306649485, -6.268005856060312], 
                Complex[41.08257031208464, -31.671367021850585`]}, 2 -> {
                Complex[73.167258434751, 0.1751471680593818], 
                Complex[99.15152035933141, -20.39442172564926]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.10186612367236, -3.925373205064215}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.98498867099265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.577816754044576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.99266976913438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17742855729767226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.9650350042688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39361451553301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "A1", 
             Association[1 -> {
                Complex[21.98498867099265, -6.20052664977852], 
                Complex[41.290674687319935`, -31.577816754044576`]}, 2 -> {
                Complex[72.99266976913438, 0.17742855729767226`], 
                Complex[98.9650350042688, -20.39361451553301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.81218168503001, -3.889200353713644}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.183364484872566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.13482421649645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.497192429524794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.486091059962376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.81995467880073`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17974473337764585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A1", 
             Association[1 -> {
                Complex[22.183364484872566`, -6.13482421649645], 
                Complex[41.497192429524794`, -31.486091059962376`]}, 2 -> {
                Complex[72.81995467880073, 0.17974473337764585`], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.52460222415466, -3.853383817719923}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.379953633499717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.070823962465011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.702202238238115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.396116959927433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.6490171369839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18209643000701964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391930848977243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A1", 
             Association[1 -> {
                Complex[22.379953633499717`, -6.070823962465011], 
                Complex[41.702202238238115`, -31.396116959927433`]}, 2 -> {
                Complex[72.6490171369839, 0.18209643000701964`], 
                Complex[98.59740257849907, -20.391930848977243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.239107909102145`, -3.8179138908009556`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.574834336069365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.008456231284855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.47976726661949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18448440640095548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391053157806226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "A1", 
             Association[1 -> {
                Complex[22.574834336069365`, -6.008456231284855], 
                Complex[41.905778105062396`, -31.30782627713036]}, 2 -> {
                Complex[72.47976726661949, 0.18448440640095548`], 
                Complex[98.41606788851907, -20.391053157806226`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.955679837004457`, -3.7827812462868895`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.76808034873237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.9476558694891155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.31212076958602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18690944791455164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A1", 
             Association[1 -> {
                Complex[22.76808034873237, -5.9476558694891155`], 
                Complex[42.10798974770687, -31.221155212774136`]}, 2 -> {
                Complex[72.31212076958602, 0.18690944791455164`], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.674299979444683`, -3.747976912423253}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.959761358270317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.888361840780239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.14599842066895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18937236674901933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38922278462222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "A1", 
             Association[1 -> {
                Complex[22.959761358270317`, -5.888361840780239], 
                Complex[42.30890299533776, -31.136043969043037`]}, 2 -> {
                Complex[72.14599842066895, 0.18937236674901933`], 
                Complex[98.05793516060473, -20.38922278462222]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.394951132672542`, -3.713492249745922}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.149943332992876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.830516882419161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.98132561745237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19187400272919972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "A1", 
             Association[1 -> {
                Complex[23.149943332992876`, -5.830516882419161], 
                Complex[42.50858013183331, -31.052436413482706`]}, 2 -> {
                Complex[71.98132561745237, 0.19187400272919972`], 
                Complex[97.88098148963748, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.117616872135905`, -3.67931893030301}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.338688836493038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.774067198270846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.970279779373037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.8180319787172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1944152241510169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "A1", 
             Association[1 -> {
                Complex[23.338688836493038`, -5.774067198270846], 
                Complex[42.70708020251328, -30.970279779373037`]}, 2 -> {
                Complex[71.8180319787172, 0.1944152241510169], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.842281510872276`, -3.6454489185281425`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.52605730903988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7189621838426925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.90445928906574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.889524397498597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.65605098505654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1969969286982196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A1", 
             Association[1 -> {
                Complex[23.52605730903988, -5.7189621838426925`], 
                Complex[42.90445928906574, -30.889524397498597`]}, 2 -> {
                Complex[71.65605098505654, 0.1969969286982196], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.5689300613629, -3.6118744535941687`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.712105320680124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.66515417934074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.10077075669193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.49531965635687`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19962004442847947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.385242064287233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A1", 
             Association[1 -> {
                Complex[23.712105320680124`, -5.66515417934074], 
                Complex[43.10077075669193, -30.810123455401047`]}, 2 -> {
                Complex[71.49531965635687, 0.19962004442847947`], 
                Complex[97.35772603163758, -20.385242064287233`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.29754820050191, -3.5785880330967768`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.89688679952995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.61259824734414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.29606547690717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.73203278076685`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.33577826157267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20228553082947315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.1856292938539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "A1", 
             Association[1 -> {
                Complex[23.89688679952995, -5.61259824734414], 
                Complex[43.29606547690717, -30.73203278076685]}, 2 -> {
                Complex[71.33577826157267, 0.20228553082947315`], 
                Complex[97.1856292938539, -20.38417572502943]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.02812223737448, -3.5455823979361014`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.0804532382449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.490392028946715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.655210646076952`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.1773700568739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20499437994616249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "A1", 
             Association[1 -> {
                Complex[24.0804532382449, -5.561251972178108], 
                Complex[43.490392028946715`, -30.655210646076952`]}, 2 -> {
                Complex[71.1773700568739, 0.20499437994616249`], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.760639083576077`, -3.512850518279514}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.262853881242368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.5110752784691694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.6837968823168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.579617592043476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.02004104879211`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20774761758097854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38195178241304`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A1", 
             Association[1 -> {
                Complex[24.262853881242368`, -5.5110752784691694`], 
                Complex[43.6837968823168, -30.579617592043476`]}, 2 -> {
                Complex[71.02004104879211, 0.20774761758097854`], 
                Complex[96.84456714160432, -20.38195178241304]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.49508622583483, -3.4803855805021815`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.444135894902008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.462030266708765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.50521626769631`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.8637397794511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117393`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A1", 
             Association[1 -> {
                Complex[24.444135894902008`, -5.462030266708765], 
                Complex[43.87632456268656, -30.50521626769631]}, 2 -> {
                Complex[70.8637397794511, 0.2105463045690771], 
                Complex[96.6754942074181, -20.38079237117393]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.231451700728176`, -3.4481809750134182`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.624344522673923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.414081063937796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.431971285264723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.7084171313574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21339153813132042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.379600070118972`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A1", 
             Association[1 -> {
                Complex[24.624344522673923`, -5.414081063937796], 
                Complex[44.06801780302345, -30.431971285264723`]}, 2 -> {
                Complex[70.7084171313574, 0.21339153813132042`], 
                Complex[96.50732568207661, -20.379600070118972`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.96972407130601, -3.4162302848870283`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.803523226774285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.367193687912322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.25891768162856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.35984908824372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.554026149556`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21628445330793847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.3400135200408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.378373886270055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "A1", 
             Association[1 -> {
                Complex[24.803523226774285`, -5.367193687912322], 
                Complex[44.25891768162856, -30.35984908824372]}, 2 -> {
                Complex[70.554026149556, 0.21628445330793847`], 
                Complex[96.3400135200408, -20.378373886270055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.709892405456237`, -3.3845272752226805`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.981713817934338`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.321335923317819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.40052187923786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21922622447656767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "A1", 
             Association[1 -> {
                Complex[24.981713817934338`, -5.321335923317819], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[70.40052187923786, 0.21922622447656767`], 
                Complex[96.17351165179056, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.45194625586437, -3.353065883172423}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.158956574486158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.24786121712583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22221806695837287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A1", 
             Association[1 -> {
                Complex[25.158956574486158`, -5.276477208780441], 
                Complex[44.63849414140556, -30.218847270360484`]}, 2 -> {
                Complex[70.24786121712583, 0.22221806695837287`], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.195875641435784`, -3.3218402085738745`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.335290351911958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.232588533576678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.14990866309333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.09600277517207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22526123871674927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "A1", 
             Association[1 -> {
                Complex[25.335290351911958`, -5.232588533576678], 
                Complex[44.82724569242562, -30.14990866309333]}, 2 -> {
                Complex[70.09600277517207, 0.22526123871674927`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.941671030061947`, -3.2908445051367625`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.51075268384907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.01535402652587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.081974676689654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.9449067552762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2283570421533727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.373109088340822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "A1", 
             Association[1 -> {
                Complex[25.51075268384907, -5.189642343075509], 
                Complex[45.01535402652587, -30.081974676689654`]}, 2 -> {
                Complex[69.9449067552762, 0.2283570421533727], 
                Complex[95.67843369946034, -20.373109088340822`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.689323322626525`, -3.260073172135142}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.685379875427014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.147612452062529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.015019304257965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.79453483388642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23150682600686606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3716971966093`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "A1", 
             Association[1 -> {
                Complex[25.685379875427014`, -5.147612452062529], 
                Complex[45.20285365244138, -30.015019304257965`]}, 2 -> {
                Complex[69.79453483388642, 0.23150682600686606`], 
                Complex[95.51474684712201, -20.3716971966093]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.438823838154573`, -3.2295207465618603`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.8592070897119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.389778046984475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.949017787808245`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.64485005547786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23471198735987034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.370244599576857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A1", 
             Association[1 -> {
                Complex[25.8592070897119, -5.106473965194025], 
                Complex[45.389778046984475`, -29.949017787808245`]}, 2 -> {
                Complex[69.64485005547786, 0.23471198735987034`], 
                Complex[95.35166475158147, -20.370244599576857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.19016430002113, -3.1991818957059213`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.03226842794698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.49581673401624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23797397376075155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.368749998403654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A1", 
             Association[1 -> {
                Complex[26.03226842794698, -5.066203203916086], 
                Complex[45.57615973333944, -29.88394654760415]}, 2 -> {
                Complex[69.49581673401624, 0.23797397376075155`], 
                Complex[95.18915044704522, -20.368749998403654`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.94333682314167, -3.1690514101170244`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.20459700420211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.819783117245702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.34740036161425`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546682113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36721204229602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "A1", 
             Association[1 -> {
                Complex[26.20459700420211, -5.026777639259069], 
                Complex[45.76203035396384, -29.819783117245702`]}, 2 -> {
                Complex[69.34740036161425, 0.24129428546682113`], 
                Complex[95.02716811464276, -20.36721204229602]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.698333902074943`, -3.1391241969244934`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.376225014979173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.988175829983501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.19956752367546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24467447781636717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.365629326062496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A1", 
             Association[1 -> {
                Complex[26.376225014979173`, -4.988175829983501], 
                Complex[45.94742073863614, -29.756506083970773`]}, 2 -> {
                Complex[69.19956752367546, 0.24467447781636717`], 
                Complex[94.86568299639735, -20.365629326062496`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.455148399976451`, -3.109395273480745}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.54718380426279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9503773656115`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"46.13236096813211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.05228581989404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2481161637376161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A1", 
             Association[1 -> {
                Complex[26.54718380426279, -4.9503773656115], 
                Complex[46.13236096813211, -29.694095033720565`]}, 2 -> {
                Complex[69.05228581989404, 0.2481161637376161], 
                Complex[94.70466131500459, -20.364000387523564`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.213773538345677`, -3.0798597613018472`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.71750392445519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.91336281392886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.31688043396312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.63253050056466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.90552379054706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.25162101640318657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A1", 
             Association[1 -> {
                Complex[26.71750392445519, -4.91336281392886], 
                Complex[46.31688043396312, -29.63253050056466]}, 2 -> {
                Complex[68.90552379054706, 0.25162101640318657`], 
                Complex[94.54407019885232, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.974202887516057`, -3.0505128802798946`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.88721519359033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.8771136725869555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.501007894566264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.57179392012435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.75925084757176`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2551907720394873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.3838776117713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A1", 
             Association[1 -> {
                Complex[26.88721519359033, -4.8771136725869555`], 
                Complex[46.501007894566264`, -29.57179392012435]}, 2 -> {
                Complex[68.75925084757176, 0.2551907720394873], 
                Complex[94.3838776117713, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.736430357841435`, -3.0213499431438393`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.056346749183458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.841612324474782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.511867586673578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.61343720997206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2588272329011793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "A1", 
             Association[1 -> {
                Complex[27.056346749183458`, -4.841612324474782], 
                Complex[46.684771528299024`, -29.511867586673578`]}, 2 -> {
                Complex[68.61343720997206, 0.2588272329011793], 
                Complex[94.22405228705699, -20.358820702623657`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.500450191538128`, -2.992366350147382}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.22492709903808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.86819898355647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.452734613629456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.46805384314331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2625322704216664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "A1", 
             Association[1 -> {
                Complex[27.22492709903808, -4.806841996564799], 
                Complex[46.86819898355647, -29.452734613629456`]}, 2 -> {
                Complex[68.46805384314331, 0.2625322704216664], 
                Complex[94.06456366534842, -20.35699101364115]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.26625695514327, -2.963557583963391}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.392984169302537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.772786721969353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.32307240174265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2663078285515145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486676`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "A1", 
             Association[1 -> {
                Complex[27.392984169302537`, -4.772786721969353], 
                Complex[47.051317426301225`, -29.394378897177]}, 2 -> {
                Complex[68.32307240174265, 0.2663078285515145], 
                Complex[93.90538183598731, -20.355106834486676`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.03384553255713, -2.9349192047666914`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.56054535004208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.739431304971095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.234153585269965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.336785082799015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.17846517576804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27015592729763743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A1", 
             Association[1 -> {
                Complex[27.56054535004208, -4.739431304971095], 
                Complex[47.234153585269965`, -29.336785082799015`]}, 2 -> {
                Complex[68.17846517576804, 0.27015592729763743`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.803211118636789`, -2.906446845487306}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.727637538568867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.706761288816323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.03420503953862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27407866647716145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.351167453618455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A1", 
             Association[1 -> {
                Complex[27.727637538568867`, -4.706761288816323], 
                Complex[47.41673379509784, -29.279938534507]}, 2 -> {
                Complex[68.03420503953862, 0.27407866647716145`], 
                Complex[93.58782182500669, -20.351167453618455`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.574349213315081`, -2.8781362072179117`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.894287180751792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.674762926083082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.599084037582415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.223825306591664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.89026540329692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2780782297010494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.349108271425646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "A1", 
             Association[1 -> {
                Complex[27.894287180751792`, -4.674762926083082], 
                Complex[47.599084037582415`, -29.223825306591664`]}, 2 -> {
                Complex[67.89026540329692, 0.2780782297010494], 
                Complex[93.42938657992539, -20.349108271425646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.34725561621783, -2.8499830547596368`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.060520310510153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.6434231514550905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.78122998129108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.16843211773069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.74662016717633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.282156888603788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.27114390229022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A1", 
             Association[1 -> {
                Complex[28.060520310510153`, -4.6434231514550905`], 
                Complex[47.78122998129108, -29.16843211773069]}, 2 -> {
                Complex[67.74662016717633, 0.282156888603788], 
                Complex[93.27114390229022, -20.34698662948813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.12192642175826, -2.8219832122920128`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.22636258767924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.113746327310373`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.60324367729916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2863170073368824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "A1", 
             Association[1 -> {
                Complex[28.22636258767924, -4.612729556752129], 
                Complex[47.96319701970124, -29.113746327310373`]}, 2 -> {
                Complex[67.60324367729916, 0.2863170073368824], 
                Complex[93.11306634486286, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.898358014687474`, -2.7941325591524535`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.391839334421146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.582670368083356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834188`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.46011068378857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.342547009636124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A1", 
             Association[1 -> {
                Complex[28.391839334421146`, -4.582670368083356], 
                Complex[48.14501030804771, -29.059755913834188`]}, 2 -> {
                Complex[67.46011068378857, 0.2905610473453296], 
                Complex[92.95512681316393, -20.342547009636124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.676547066083096`, -2.7664270257122823`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.556975570343152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.553234425005791`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.326694799042336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.00644945530591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.31719630049454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29489157244794845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A1", 
             Association[1 -> {
                Complex[28.556975570343152`, -4.553234425005791], 
                Complex[48.326694799042336`, -29.00644945530591]}, 2 -> {
                Complex[67.31719630049454, 0.29489157244794845`], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.456490529760053`, -2.7388625893361542`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.721796046473646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.524411161584021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.9538161114898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.17447596624794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29931125424420046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A1", 
             Association[1 -> {
                Complex[28.721796046473646`, -4.524411161584021], 
                Complex[48.50827527761825, -28.9538161114898]}, 2 -> {
                Complex[67.17447596624794, 0.29931125424420046`], 
                Complex[92.63955496002485, -20.337829663202015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.238185639088748`, -2.711435270412446}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.88632527823729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.68977639484416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.901845607962514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.03192540747014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3038228778721793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A1", 
             Association[1 -> {
                Complex[28.88632527823729, -4.496190589260186], 
                Complex[48.68977639484416, -28.901845607962514`]}, 2 -> {
                Complex[67.03192540747014, 0.3038228778721793], 
                Complex[92.48186983901314, -20.33536045179569]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.02162990420851, -2.6841411284423433`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.050587577562062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.468563281455599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.871222701145584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.850528221884158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.88952060197633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3084293481445193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.332813903268473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "A1", 
             Association[1 -> {
                Complex[29.050587577562062`, -4.468563281455599], 
                Complex[48.871222701145584`, -28.850528221884158`]}, 2 -> {
                Complex[66.88952060197633, 0.3084293481445193], 
                Complex[92.32421706624814, -20.332813903268473`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.806821109624941`, -2.656976258176025}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.21460708424427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.44152035983643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.79985476942697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.7472377438204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31313369609146635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33018712420928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "A1", 
             Association[1 -> {
                Complex[29.21460708424427, -4.44152035983643], 
                Complex[49.05263867896423, -28.79985476942697]}, 2 -> {
                Complex[66.7472377438204, 0.31313369609146635`], 
                Complex[92.16657070129293, -20.33018712420928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.593757312182326`, -2.629936785783782}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.37840779669111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.23404877498035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.7498165948108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.60505320903809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3179390859428899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651893`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "A1", 
             Association[1 -> {
                Complex[29.37840779669111, -4.4150534821866145`], 
                Complex[49.23404877498035, -28.7498165948108]}, 2 -> {
                Complex[66.60505320903809, 0.3179390859428899], 
                Complex[92.00890492013563, -20.327477084651893`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.38243683940241, -2.603018865050693}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.542013602155205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.389154831841678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.46294352215183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.322848822583996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.85119397884918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.324680610124492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A1", 
             Association[1 -> {
                Complex[29.542013602155205`, -4.389154831841678], 
                Complex[49.41547743201958, -28.700405560905736`]}, 2 -> {
                Complex[66.46294352215183, 0.322848822583996], 
                Complex[91.85119397884918, -20.324680610124492`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.172858288183662`, -2.576218673583348}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.705448306571707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.363817108646442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.596949120761906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.651614041371168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.32088532330775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32786635952260046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.321794373139106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A1", 
             Association[1 -> {
                Complex[29.705448306571707`, -4.363817108646442], 
                Complex[49.596949120761906`, -28.651614041371168`]}, 2 -> {
                Complex[66.32088532330775, 0.32786635952260046`], 
                Complex[91.6934121777283, -20.321794373139106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.96502052385543, -2.549532409016802}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.868735664104204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.33903352140945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.60343491431109`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.17885533591951`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3329953074094176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "A1", 
             Association[1 -> {
                Complex[29.868735664104204`, -4.33903352140945], 
                Complex[49.77848837136716, -28.60343491431109]}, 2 -> {
                Complex[66.17885533591951, 0.3329953074094176], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.758922679583286, -2.5229562852100145`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.0318994065037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.960119805130674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.555861557435456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.0368303346989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3382394431566841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "A1", 
             Association[1 -> {
                Complex[30.0318994065037, -4.314797781836445], 
                Complex[49.960119805130674`, -28.555861557435456`]}, 2 -> {
                Complex[66.0368303346989, 0.3382394431566841], 
                Complex[91.37753320535236, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.554564156122666, -2.496486528417938}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.194963272382548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.291104099934118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.141868166281284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.50888784472627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.89478711395589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.312561321201745`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A1", 
             Association[1 -> {
                Complex[30.194963272382548`, -4.291104099934118], 
                Complex[50.141868166281284`, -28.50888784472627]}, 2 -> {
                Complex[65.89478711395589, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.312561321201745`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.351944621919706, -2.4701193734280054`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.35795103650346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.26794718088456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.3237583540324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.46250814461731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.75270245605407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34908927649101035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A1", 
             Association[1 -> {
                Complex[30.35795103650346, -4.26794718088456], 
                Complex[50.3237583540324, -28.46250814461731]}, 2 -> {
                Complex[65.75270245605407, 0.34908927649101035`], 
                Complex[91.0610619442071, -20.30927936589565]}]}, "Tooltip"]& 
           ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.151064013558923, -2.4438510596483187`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.520886539183877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.24532222340097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.50581545499962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.416717319706727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.6105530999087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3547034506809741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A1", 
             Association[1 -> {
                Complex[30.520886539183877`, -4.24532222340097], 
                Complex[50.50581545499962, -28.416717319706727`]}, 2 -> {
                Complex[65.6105530999087, 0.3547034506809741], 
                Complex[90.90253941775816, -20.305888372154577`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.951922536558712, -2.4176778271346624`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.683793715914877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.22322491958401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.688064776097136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.371510728031744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.46831570941634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36044978922689475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.7437907802159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "A1", 
             Association[1 -> {
                Complex[30.683793715914877`, -4.22322491958401], 
                Complex[50.688064776097136`, -28.371510728031744`]}, 2 -> {
                Complex[65.46831570941634, 0.36044978922689475`], 
                Complex[90.7437907802159, -20.30238387787967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.754520666516932, -2.3915959125426483`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.846696627295138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.201651456308564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.87053187802873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.326884225945257`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.325966841705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3663330618262281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.298761188193378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A1", 
             Association[1 -> {
                Complex[30.846696627295138`, -4.201651456308564], 
                Complex[50.87053187802873, -28.326884225945257`]}, 2 -> {
                Complex[65.325966841705, 0.3663330618262281], 
                Complex[90.58478964962532, -20.298761188193378`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.558859150610026, -2.3656015449910406`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.009619489380988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.180598518180851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.28283417264592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.1834829150937`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3723582748592317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A1", 
             Association[1 -> {
                Complex[31.009619489380988`, -4.180598518180851], 
                Complex[51.05324260949038, -28.28283417264592]}, 2 -> {
                Complex[65.1834829150937, 0.3723582748592317], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.364939009450417, -2.3396909418210683`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.172586704555457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.160063292117314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.236223142205915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.239357436425397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.04084017664968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3785306863932047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "A1", 
             Association[1 -> {
                Complex[31.172586704555457`, -4.160063292117314], 
                Complex[51.236223142205915`, -28.239357436425397`]}, 2 -> {
                Complex[65.04084017664968, 0.3785306863932047], 
                Complex[90.26592313793014, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.172761539307587, -2.313860304236032}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.33562289302192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.89801466922918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3848558223499517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.287133180835255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "A1", 
             Association[1 -> {
                Complex[31.33562289302192, -4.140043473607489], 
                Complex[51.419500006920465`, -28.196451402708604`]}, 2 -> {
                Complex[64.89801466922918, 0.3848558223499517], 
                Complex[90.10600363628704, -20.287133180835255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.982328314700709, -2.288105812804716}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.49875292502993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.603100130481025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.75498219788668`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.391339493943095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "A1", 
             Association[1 -> {
                Complex[31.49875292502993, -4.120537274736596], 
                Complex[51.603100130481025`, -28.154113983977776`]}, 2 -> {
                Complex[64.75498219788668, 0.391339493943095], 
                Complex[89.94572332307655, -20.282985551225515`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.793641191370554, -2.262423622810296}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.662001953945484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.101543434056313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.61171829553294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3979878165032359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.7850542271069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A1", 
             Association[1 -> {
                Complex[31.662001953945484`, -4.101543434056313], 
                Complex[51.78705087413992, -28.112343631685345`]}, 2 -> {
                Complex[64.61171829553294, 0.3979878165032359], 
                Complex[89.7850542271069, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.60670230964103, -2.2368098594262147`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.825395450280787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.083061228407537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277985`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.46819818772052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40480722982158246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.62396793923683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A1", 
             Association[1 -> {
                Complex[31.825395450280787`, -4.083061228407537], 
                Complex[51.97138007322182, -28.071139350277985`]}, 2 -> {
                Complex[64.46819818772052, 0.40480722982158246`], 
                Complex[89.62396793923683, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.421514098181014, -2.2112606126978562`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.988959236804785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.065090486814274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.32439675642944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4118045201569269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.269642077367138`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A1", 
             Association[1 -> {
                Complex[31.988959236804785`, -4.065090486814274], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[64.32439675642944, 0.4118045201569269], 
                Complex[89.46243556940976, -20.269642077367138`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.238079278179278, -2.185771932308567}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.1527195248595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.99042788293637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.18028850272216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.41898684406680864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A1", 
             Association[1 -> {
                Complex[32.1527195248595, -4.047631606586535], 
                Complex[52.34128779806401, -27.99042788293637]}, 2 -> {
                Complex[64.18028850272216, 0.41898684406680864`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.056400867946785, -2.1603398221055095`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.31670295201473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.52692474396548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.95092162957881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.03584750813043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42636175424164896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A1", 
             Association[1 -> {
                Complex[32.31670295201473, -4.030685571788463], 
                Complex[52.52692474396548, -27.95092162957881]}, 2 -> {
                Complex[64.03584750813043, 0.42636175424164896`], 
                Complex[89.13791435011574, -20.259926647201578`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.876482187961557, -2.1349602343598484`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.48093662119898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.7130570769491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.911983357620024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.891047394630874`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4339372275409471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A1", 
             Association[1 -> {
                Complex[32.48093662119898, -4.014253974250843], 
                Complex[52.7130570769491, -27.911983357620024`]}, 2 -> {
                Complex[63.891047394630874`, 0.4339372275409471], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.698326866373847, -2.109629063732683}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.645448141453244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.998339037330256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.89971565632317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87361513171316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.7458612830591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4417216954533841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24948292358025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A1", 
             Association[1 -> {
                Complex[32.645448141453244`, -3.998339037330256], 
                Complex[52.89971565632317, -27.87361513171316]}, 2 -> {
                Complex[63.7458612830591, 0.4417216954533841], 
                Complex[88.81124809301977, -20.24948292358025]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.521938844990224, -2.08434214091624}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.810265670460794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9829436426451004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.086932091046236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.600261749804105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.243966169666688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "A1", 
             Association[1 -> {
                Complex[32.810265670460794`, -3.9829436426451004`], 
                Complex[53.086932091046236`, -27.835819707361438`]}, 2 -> {
                Complex[63.600261749804105`, 0.44972407722861746`], 
                Complex[88.64703191016159, -20.243966169666688`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.347322385758012, -2.0590952259162663`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.97541795901581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.27473879361426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.798600564939377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.45422078161694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45795381595762275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23824012528373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A1", 
             Association[1 -> {
                Complex[32.97541795901581, -3.968071360048478], 
                Complex[53.27473879361426, -27.798600564939377`]}, 2 -> {
                Complex[63.45422078161694, 0.45795381595762275`], 
                Complex[88.48218357926147, -20.23824012528373]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.174482077772204, -2.0338840009390537`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.14093439760302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.953726481132371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.76196194765724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.30770972835797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.466420917911682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23229452138455`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "A1", 
             Association[1 -> {
                Complex[33.14093439760302, -3.953726481132371], 
                Complex[53.46316903677714, -27.76196194765724]}, 2 -> {
                Complex[63.30770972835797, 0.466420917911682], 
                Complex[88.31666948593067, -20.23229452138455]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.003422844830105, -2.008704062842172}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.306845065269485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.939914056596168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.72590890385442`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.16069925349776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4751359954876585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "A1", 
             Association[1 -> {
                Complex[33.306845065269485`, -3.939914056596168], 
                Complex[53.65225701332302, -27.72590890385442]}, 2 -> {
                Complex[63.16069925349776, 0.4751359954876585], 
                Complex[88.15045511884611, -20.226118434741064`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.834149953560505, -1.9835509151043969`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.47318078098145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9266399378561223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.842037899187076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.69044733405728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.01315928217634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4841103141499007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A1", 
             Association[1 -> {
                Complex[33.47318078098145, -3.9266399378561223`], 
                Complex[53.842037899187076`, -27.69044733405728]}, 2 -> {
                Complex[63.01315928217634, 0.4841103141499007], 
                Complex[87.98350500554794, -20.219700235746625`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.666669022156675, -1.9584199592654077`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.63997315766917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.0325479201562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.655584043295313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.86505894661449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49335584380795366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.8157826446966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.21302753118228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "A1", 
             Association[1 -> {
                Complex[33.63997315766917, -3.913910823322055], 
                Complex[54.0325479201562, -27.655584043295313`]}, 2 -> {
                Complex[62.86505894661449, 0.49335584380795366`], 
                Complex[87.8157826446966, -20.21302753118228]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.500986029744887, -1.9333064857805216`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.80725465917451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9017343098237633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.223824422460964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.621326799234737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.71636652866016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5028853151246296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A1", 
             Association[1 -> {
                Complex[33.80725465917451, -3.9017343098237633`], 
                Complex[54.223824422460964`, -27.621326799234737`]}, 2 -> {
                Complex[62.71636652866016, 0.5028853151246296], 
                Complex[87.64725043449562, -20.206087101376106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.3371073264222915`, -1.908205664230099}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.975058660327356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8901189497339574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.415905947563445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.587684396763738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.56704939924091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5127122813126167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.4778695969676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19886483111003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A1", 
             Association[1 -> {
                Complex[33.975058660327356`, -3.8901189497339574`], 
                Complex[54.415905947563445`, -27.587684396763738`]}, 2 -> {
                Complex[62.56704939924091, 0.5127122813126167], 
                Complex[87.4778695969676, -20.19886483111003]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.175039644001416, -1.8831125328162965`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.143419510388775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.879074314407841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.417073954482824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19134563354414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A1", 
             Association[1 -> {
                Complex[34.143419510388775`, -3.879074314407841], 
                Complex[54.60883231147051, -27.554666729749552`]}, 2 -> {
                Complex[62.417073954482824`, 0.5228511860504309], 
                Complex[87.30760009775224, -20.19134563354414]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.014790107500879, -1.8580219870723287`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.312372600109356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8686110646435656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.80264468892042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.5222848707862`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.26640554824476`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5333174382317767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A1", 
             Association[1 -> {
                Complex[34.312372600109356`, -3.8686110646435656`], 
                Complex[54.80264468892042, -27.5222848707862]}, 2 -> {
                Complex[62.26640554824476, 0.5333174382317767], 
                Complex[87.13640056107454, -20.183513366330008`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.856366247423921, -1.8329287677007002`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.48195443266224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49055115986421`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.11500842080698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A1", 
             Association[1 -> {
                Complex[34.48195443266224, -3.8587410289636725`], 
                Complex[54.99738570281197, -27.49055115986421]}, 2 -> {
                Complex[62.11500842080698, 0.5441274943581387], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.699776012871993, -1.807827447447309}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.65220269871858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.193099519263775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.45947930302496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.96284562344401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.555298949494675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A1", 
             Association[1 -> {
                Complex[34.65220269871858, -3.849477290628971], 
                Complex[55.193099519263775`, -27.45947930302496]}, 2 -> {
                Complex[61.96284562344401, 0.555298949494675], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.545027785540228, -1.7827124169069233`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.82315635594019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8408342844230736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.429084482211824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.80987893860578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668506378361227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.157958875303546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "A1", 
             Association[1 -> {
                Complex[34.82315635594019, -3.8408342844230736`], 
                Complex[55.38983194870933, -27.429084482211824`]}, 2 -> {
                Complex[61.80987893860578, 0.5668506378361227], 
                Complex[86.61678591287696, -20.157958875303546`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.3921303946479355`, -1.7575778691429758`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.99485571316776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.58763055344998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.65606879542663`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5788027440763145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "A1", 
             Association[1 -> {
                Complex[34.99485571316776, -3.8328279043933393`], 
                Complex[55.58763055344998, -27.39938347770468]}, 2 -> {
                Complex[61.65606879542663, 0.5788027440763145], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.241093132858161, -1.7324177829899607`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.16734251958135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.501374180284344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "A1", 
             Association[1 -> {
                Complex[35.16734251958135, -3.8254756239037375`], 
                Complex[55.78654476209901, -27.370394804725706`]}, 2 -> {
                Complex[61.501374180284344`, 0.5911769269441449], 
                Complex[86.26489841088478, -20.139004574702856`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.091925773245386, -1.707225904890441}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.34066005910287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.81879662955199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.342138866037867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.345752542137845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.603996456465433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "A1", 
             Association[1 -> {
                Complex[35.34066005910287, -3.81879662955199], 
                Complex[55.98662599135723, -27.342138866037867`]}, 2 -> {
                Complex[61.345752542137845`, 0.603996456465433], 
                Complex[86.08716253043333, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.9446385873712657`, -1.68199572909921}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.5148532502931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8128119707315338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.31463812262956`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.18915969238974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6172863667379076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A1", 
             Association[1 -> {
                Complex[35.5148532502931, -3.8128119707315338`], 
                Complex[56.18792777555814, -27.31463812262956]}, 2 -> {
                Complex[61.18915969238974, 0.6172863667379076], 
                Complex[85.90816108596371, -20.118296161792685`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.799242364533555, -1.6567204760658996`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.68996875196817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.39050590440941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.28791728489552`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.03154969904756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6310736262715524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.107215817279773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "A1", 
             Association[1 -> {
                Complex[35.68996875196817, -3.807544726884647], 
                Complex[56.39050590440941, -27.28791728489552]}, 2 -> {
                Complex[61.03154969904756, 0.6310736262715524], 
                Complex[85.72783819940136, -20.107215817279773`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.6557484322533327`, -1.631393068781625}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.866055074715334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8030201948010105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.262003527092865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.872874775003034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.5461356023026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.095610443428537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A1", 
             Association[1 -> {
                Complex[35.866055074715334`, -3.8030201948010105`], 
                Complex[56.594418569327175`, -27.262003527092865`]}, 2 -> {
                Complex[60.872874775003034`, 0.6453873282550383], 
                Complex[85.5461356023026, -20.095610443428537`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.5141686780691046`, -1.6060061068470048`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.04316269842235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7992660986771667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.799726518711694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.236926728284004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.71308516031326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6602589034686106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.36299248006208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A1", 
             Association[1 -> {
                Complex[36.04316269842235, -3.7992660986771667`], 
                Complex[56.799726518711694`, -27.236926728284004`]}, 2 -> {
                Complex[60.71308516031326, 0.6602589034686106], 
                Complex[85.36299248006208, -20.08344612962457]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.3745155727057607`, -1.5805518379850394`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.22134419584062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7963128260714716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.006493222433235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.212719743482186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.552128998463665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595752`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A1", 
             Association[1 -> {
                Complex[36.22134419584062, -3.7963128260714716`], 
                Complex[57.006493222433235`, -27.212719743482186`]}, 2 -> {
                Complex[60.552128998463665`, 0.6757223589838265], 
                Complex[85.17834530693467, -20.070686076595752`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.236802194687911, -1.555022126684264}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.4006543620702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794193693381184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.389952206722754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.99212767171738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A1", 
             Association[1 -> {
                Complex[36.4006543620702, -3.794193693381184], 
                Complex[57.21478504568002, -27.18941870930894]}, 2 -> {
                Complex[60.389952206722754`, 0.6918145462814401], 
                Complex[84.99212767171738, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.101042256461575, -1.5294084196127038`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.58115034967376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.16706338916731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.22649834088111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7085754629936015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.04321522376426`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "A1", 
             Association[1 -> {
                Complex[36.58115034967376, -3.7929452450428247`], 
                Complex[57.42467143215045, -27.16706338916731]}, 2 -> {
                Complex[60.22649834088111, 0.7085754629936015], 
                Complex[84.80427009410889, -20.04321522376426]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.9672501320875426`, -1.5037017073917376`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.76289180887989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.636225096332794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.145697563752844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.06170845491359`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245878`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A1", 
             Association[1 -> {
                Complex[36.76289180887989, -3.7926075913306474`], 
                Complex[57.636225096332794`, -27.145697563752844`]}, 2 -> {
                Complex[60.06170845491359, 0.7260485931492001], 
                Complex[84.61469983200216, -20.028413405245878`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.8354408865584446`, -1.477892482258861}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.94594103200389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7932247904164975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.84952222428347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.125369473683783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.89552095643557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7442812915903373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.012832972269205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A1", 
             Association[1 -> {
                Complex[36.94594103200389, -3.7932247904164975`], 
                Complex[57.84952222428347, -27.125369473683783`]}, 2 -> {
                Complex[59.89552095643557, 0.7442812915903373], 
                Complex[84.42334068029797, -20.012832972269205`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.7056303067808116`, -1.4519706910786851`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.13036310076835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794845281279751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.106132322164278`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.72787145927004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7633252191523081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "A1", 
             Association[1 -> {
                Complex[37.13036310076835, -3.794845281279751], 
                Complex[58.06464268186045, -27.106132322164278`]}, 2 -> {
                Complex[59.72787145927004, 0.7633252191523081], 
                Complex[84.2301127622816, -19.996417177281284`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.5778349342455513`, -1.4259256830803757`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.31622603461241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.797522375138974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.0880448469234`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.5586926350365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7832368362827162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.97910381148327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "A1", 
             Association[1 -> {
                Complex[37.31622603461241, -3.797522375138974], 
                Complex[58.28167022874946, -27.0880448469234]}, 2 -> {
                Complex[59.5586926350365, 0.7832368362827162], 
                Complex[84.03493231522438, -19.97910381148327]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.452072099382015, -1.3997461516050382`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.503600937288496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8013148143453006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.50069273578578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.38791406646194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8040779640432751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.960824550758474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A1", 
             Association[1 -> {
                Complex[37.503600937288496`, -3.8013148143453006`], 
                Complex[58.50069273578578, -27.07117197223767]}, 2 -> {
                Complex[59.38791406646194, 0.8040779640432751], 
                Complex[83.83771147270659, -19.960824550758474`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.3283599575578293`, -1.3734200690368468`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.692562137998024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.806287409159504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.72180240194932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.05558555368316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.21546210616129`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.941504208943837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A1", 
             Association[1 -> {
                Complex[37.692562137998024`, -3.806287409159504], 
                Complex[58.72180240194932, -27.05558555368316]}, 2 -> {
                Complex[59.21546210616129, 0.8259164229195795], 
                Complex[83.63835804728225, -19.941504208943837`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.2067175266326657`, -1.3469346139626257`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.88318732193246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.9450959659065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.04125974602169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8488267615895433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642382`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A1", 
             Association[1 -> {
                Complex[37.88318732193246, -3.812511764560067], 
                Complex[58.9450959659065, -27.04136523041568]}, 2 -> {
                Complex[59.04125974602169, 0.8488267615895433], 
                Complex[83.43677531861314, -19.921059883642382`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.08716472590838, -1.3202760894555912`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.07555764325092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.820067111231534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.170674904956044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.028599402293732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.86522650415762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8728910898028908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A1", 
             Association[1 -> {
                Complex[38.07555764325092, -3.820067111231534], 
                Complex[59.170674904956044`, -27.028599402293732`]}, 2 -> {
                Complex[58.86522650415762, 0.8728910898028908], 
                Complex[83.23286183421266, -19.899399977259353`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.9697224162240374`, -1.293429831204353}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.26975781110342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.82904125718843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.68727833882761`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318297491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A1", 
             Association[1 -> {
                Complex[38.26975781110342, -3.82904125718843], 
                Complex[59.39864561154835, -27.017386352081296`]}, 2 -> {
                Complex[58.68727833882761, 0.8982000318297491], 
                Complex[83.02651123262952, -19.876423073022412`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.8544124408204894`, -1.2663801040064282`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.46587613610713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.839531679121346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.62911953396363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.50732760190553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9248538195678667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A1", 
             Association[1 -> {
                Complex[38.46587613610713, -3.839531679121346], 
                Complex[59.62911953396363, -27.007835536336128`]}, 2 -> {
                Complex[58.50732760190553, 0.9248538195678667], 
                Complex[82.81761210248663, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.7412576664319346`, -1.2391099849106713`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.66400452045292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8516467755142054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.32528304872727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9529635473601222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A1", 
             Association[1 -> {
                Complex[38.66400452045292, -3.8516467755142054`], 
                Complex[59.86221326295697, -27.000069072431693`]}, 2 -> {
                Complex[58.32528304872727, 0.9529635473601222], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.6302820238401239`, -1.2116012310240976`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.86423836923639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.99422345346926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.141049926719695`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.798400368820353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A1", 
             Association[1 -> {
                Complex[38.86423836923639, -3.865507306847949], 
                Complex[60.09804853982374, -26.99422345346926]}, 2 -> {
                Complex[58.141049926719695`, 0.9826526138400205], 
                Complex[82.39169691847611, -19.798400368820353`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.5215105468322534`, -1.1838341296895951`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.06667639323606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.336752152884166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.990451527552715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.954530172587724`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.01405837961428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "A1", 
             Association[1 -> {
                Complex[39.06667639323606, -3.8812480516973484`], 
                Complex[60.336752152884166`, -26.990451527552715`]}, 2 -> {
                Complex[57.954530172587724`, 1.01405837961428], 
                Complex[82.17443243593527, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.4149694081091937`, -1.1557873283926217`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.271420263643506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8990197110726985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.57845567815663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.988924782863712`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.76562275755487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0473340731366323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.9541229298446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A1", 
             Association[1 -> {
                Complex[39.271420263643506`, -3.8990197110726985`], 
                Complex[60.57845567815663, -26.988924782863712`]}, 2 -> {
                Complex[57.76562275755487, 1.0473340731366323`], 
                Complex[81.9541229298446, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.3106859501730952`, -1.1274376413669849`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.478574066455195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.91899109663922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869384`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.57422423294728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "A1", 
             Association[1 -> {
                Complex[39.478574066455195`, -3.91899109663922], 
                Complex[60.823295005096384`, -26.989835984869384`]}, 2 -> {
                Complex[57.57422423294728, 1.0826509804077706`], 
                Complex[81.73063257333023, -19.70361719945588]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.2086887085344244`, -1.098759829448257}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.68824348743652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9413516409076177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.380229545210106`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1202009565970128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "A1", 
             Association[1 -> {
                Complex[39.68824348743652, -3.9413516409076177`], 
                Complex[61.071409568577636`, -26.993402216234124`]}, 2 -> {
                Complex[57.380229545210106`, 1.1202009565970128`], 
                Complex[81.50382199854218, -19.66742872877372]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.1090074236716987`, -1.0697263492830587`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.900534636598906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.966314268200562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.183533211415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1601992983922518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A1", 
             Association[1 -> {
                Complex[39.900534636598906`, -3.966314268200562], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[57.183533211415, 1.1601992983922518`], 
                Complex[81.27354946300127, -19.628553141047497`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.0116730369831757`, -1.04030706757022}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.11555239258457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9941186626524052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.98403097486453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2028880133377449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A1", 
             Association[1 -> {
                Complex[40.11555239258457, -3.9941186626524052`], 
                Complex[61.57803233510409, -27.009511166504147`]}, 2 -> {
                Complex[56.98403097486453, 1.2028880133377449`], 
                Complex[81.03967255327478, -19.586711092540675`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.9167176644059509, -1.0104689356365544`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.33339811059796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.02264368536371`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.78162209715333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.248539514221569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.54158691366652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A1", 
             Association[1 -> {
                Complex[40.33339811059796, -4.025034961302564], 
                Complex[61.836823766448205`, -27.02264368536371]}, 2 -> {
                Complex[56.78162209715333, 1.248539514221569], 
                Complex[80.80205060892806, -19.54158691366652]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.82417453933855, -0.9801756194190041}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.554166490864645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.059367882777878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.57621248970557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.297460749010085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653356`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A1", 
             Association[1 -> {
                Complex[40.554166490864645`, -4.059367882777878], 
                Complex[62.09945108280152, -27.039620531417192`]}, 2 -> {
                Complex[56.57621248970557, 1.297460749010085], 
                Complex[80.56054810632892, -19.492823467653356`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.7340779138702729, -0.9493870799732953}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.77794134659001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.097461269474217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.060843538677656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.3677189458158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3499977442410382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.3150393131322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A1", 
             Association[1 -> {
                Complex[40.77794134659001, -4.097461269474217], 
                Complex[62.36604010279412, -27.060843538677656`]}, 2 -> {
                Complex[56.3677189458158, 1.3499977442410382`], 
                Complex[80.3150393131322, -19.440016432485955`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.6464629039577261, -0.9180591001727549}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.004789940578746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.139702965144389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.15607480403263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.4065404837842264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A1", 
             Association[1 -> {
                Complex[41.004789940578746`, -4.139702965144389], 
                Complex[62.63670053402378, -27.086768000239154`]}, 2 -> {
                Complex[56.15607480403263, 1.4065404837842264`], 
                Complex[80.06541461134336, -19.382708072431345`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.5613652599694205, -0.8861427546325906}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.23475547996004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.911517481754075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.941237453438774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A1", 
             Association[1 -> {
                Complex[41.23475547996004, -4.186529858286214], 
                Complex[62.911517481754075`, -27.117909237707966`]}, 2 -> {
                Complex[55.941237453438774`, 1.4675279533647856`], 
                Complex[79.81158898845908, -19.320380667492593`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.478821038865469, -0.8535838225878223}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.46784727560741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.238432778015862`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.1548491808301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.72319817424016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.5334530375357749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A1", 
             Association[1 -> {
                Complex[41.46784727560741, -4.238432778015862], 
                Complex[63.19054018060197, -27.1548491808301]}, 2 -> {
                Complex[55.72319817424016, 1.5334530375357749`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.3988661482299847, -0.8203221481835214}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.704028002661694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.295960711667079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.473767240011654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.198242373560767`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.50199487725362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6048667383421007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.1782590109987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "A1", 
             Association[1 -> {
                Complex[41.704028002661694`, -4.295960711667079], 
                Complex[63.473767240011654`, -27.198242373560767`]}, 2 -> {
                Complex[55.50199487725362, 1.6048667383421007`], 
                Complex[79.29118905201918, -19.1782590109987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.3215357257380731, -0.7862909603813755}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.94319747255841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.27772833189304`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6823808689752453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.09707399537825`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "A1", 
             Association[1 -> {
                Complex[41.94319747255841, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[55.27772833189304, 1.6823808689752453`], 
                Complex[79.02468735041018, -19.09707399537825]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.246863311209637, -0.7514161767054528}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.185172401572416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.430391708841174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.307393608507066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.05058239764025`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.7666679393393379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A1", 
             Association[1 -> {
                Complex[42.185172401572416`, -4.430391708841174], 
                Complex[64.05245675580908, -27.307393608507066`]}, 2 -> {
                Complex[55.05058239764025, 1.7666679393393379`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.17487976381707426`, -0.7156157327657127}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.42966192828803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.8208485065926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.8584563892632036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A1", 
             Association[1 -> {
                Complex[42.42966192828803, -4.508691887180884], 
                Complex[64.34746700294596, -27.374846901442822`]}, 2 -> {
                Complex[54.8208485065926, 1.8584563892632036`], 
                Complex[78.47993347130917, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.1056118771944341, -0.6787990041552856}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.67623922739711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.452128400549633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.588954049684325`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A1", 
             Association[1 -> {
                Complex[42.67623922739711, -4.595394633635153], 
                Complex[64.64571326583466, -27.452128400549633`]}, 2 -> {
                Complex[54.588954049684325`, 1.9585186817545792`], 
                Complex[78.20241421183864, -18.803067851298525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.03908065481800804, -0.6408664191814282}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.92431065706729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.94655461858153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.540225454037717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.35549322933975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0676491823619387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.92225618346788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "A1", 
             Association[1 -> {
                Complex[42.92431065706729, -4.691292487824447], 
                Complex[64.94655461858153, -27.540225454037717`]}, 2 -> {
                Complex[54.35549322933975, 2.0676491823619387`], 
                Complex[77.92225618346788, -18.685105090665765`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-32.3781388235867, -5.6083497605809285`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.3612762881997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.5464629745106`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"137.47401768359734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11658019540031624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "B1", 
             Association[1 -> {
                Complex[67.3612762881997, -11.285995288896373`], 
                Complex[31.494082066597223`, -37.5464629745106]}, 2 -> {
                Complex[137.47401768359734`, 0.11658019540031624`], 
                Complex[108.70582923184112`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-31.98242464347506, -5.544753414820963}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.98212126063683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.816178584119356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.1076636814205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249047`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"136.7702066530049`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "B1", 
             Association[1 -> {
                Complex[67.98212126063683, -10.816178584119356`], 
                Complex[32.1076636814205, -37.05300319249047]}, 2 -> {
                Complex[136.7702066530049, 0.11776334712026251`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-31.593514579703278`, -5.4835218503726075`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.50122981057176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.443606571400164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.620466904032156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65624121214431`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"136.20148283857358`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1190530706148839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "B1", 
             Association[1 -> {
                Complex[68.50122981057176, -10.443606571400164`], 
                Complex[32.620466904032156`, -36.65624121214431]}, 2 -> {
                Complex[136.20148283857358`, 0.1190530706148839], 
                Complex[107.41258000537304`, -20.41001952735827]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-31.210381614044888`, -5.424231223056562}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.96054019847772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.128345372417398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.0743064173448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"135.71136793755323`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12040941356394556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "B1", 
             Association[1 -> {
                Complex[68.96054019847772, -10.128345372417398`], 
                Complex[33.0743064173448, -36.31637452115125]}, 2 -> {
                Complex[135.71136793755323`, 0.12040941356394556`], 
                Complex[106.91207211908184`, -20.409835465464514`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.83237839982309, -5.366612211666439}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.37917358758223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.852138089238327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.488222621388495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.01523037051931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"135.27419798999998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12181511399306597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409608726332795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "B1", 
             Association[1 -> {
                Complex[69.37917358758223, -9.852138089238327], 
                Complex[33.488222621388495`, -36.01523037051931]}, 2 -> {
                Complex[135.27419798999998`, 0.12181511399306597`], 
                Complex[106.46447895532776`, -20.409608726332795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.45904826106597, -5.31047345175115}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.7677684119681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.60480138795413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.8727949448934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.742685486955864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.87574187250723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1232611038398544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.0555664397038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.409348870362297`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "B1", 
             Association[1 -> {
                Complex[69.7677684119681, -9.60480138795413], 
                Complex[33.8727949448934, -35.742685486955864`]}, 2 -> {
                Complex[134.87574187250723`, 0.1232611038398544], 
                Complex[106.0555664397038, -20.409348870362297`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-30.0900466438168, -5.2556696202976205`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.13297133776604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.379958105911218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804005`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.50713843332574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12474207031864686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "B1", 
             Association[1 -> {
                Complex[70.13297133776604, -9.379958105911218], 
                Complex[34.23462400814147, -35.492408387804005`]}, 2 -> {
                Complex[134.50713843332574`, 0.12474207031864686`], 
                Complex[105.67647115587604`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.72510161719988, -5.20208534035741}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.47926711840675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173296252888404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.26012331221573`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.16242958313848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12625468557684477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.3212331801606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.408750516874488`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "B1", 
             Association[1 -> {
                Complex[70.47926711840675, -9.173296252888404], 
                Complex[34.57815702977672, -35.26012331221573]}, 2 -> {
                Complex[134.16242958313848`, 0.12625468557684477`], 
                Complex[105.3212331801606, -20.408750516874488`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.363991503529203`, -5.1496260394142706`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.80985312948171`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.981735864879765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.90655982800721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.042779894876595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.83738284456678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12779677775874873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841773`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612203`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "B1", 
             Association[1 -> {
                Complex[70.80985312948171, -8.981735864879765], 
                Complex[34.90655982800721, -35.042779894876595`]}, 2 -> {
                Complex[133.83738284456678`, 0.12779677775874873`], 
                Complex[104.98561848841773`, -20.40841808612203]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-29.00653112054803, -5.098212311086311}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.12710553582465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.802984319586114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83811023326065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.5288645170866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1293668978816943`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408065972061255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "B1", 
             Association[1 -> {
                Complex[71.12710553582465, -8.802984319586114], 
                Complex[35.22218142009308, -34.83811023326065]}, 2 -> {
                Complex[133.5288645170866, 0.1293668978816943], 
                Complex[104.66649203468589`, -20.408065972061255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-28.652562788603827`, -5.047776219088847}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.432848487697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.63527920845076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.526822187325095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.2344781534338`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1309640745970842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "B1", 
             Association[1 -> {
                Complex[71.432848487697, -8.63527920845076], 
                Complex[35.526822187325095`, -34.64437291632376]}, 2 -> {
                Complex[133.2344781534338, 0.1309640745970842], 
                Complex[104.36145617205709`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-28.301950169318612`, -4.998258757692817}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.72851942980324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.477230229980366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.95234282886776`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13258766651159287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147277`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "B1", 
             Association[1 -> {
                Complex[71.72851942980324, -8.477230229980366], 
                Complex[35.82189847272132, -34.46019571836113]}, 2 -> {
                Complex[132.95234282886776`, 0.13258766651159287`], 
                Complex[104.06862888444634`, -20.407307041147277`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.9545738829575, -4.949608040143076}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.01527569469468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.327717105231118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.10854866480779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.2844740897253`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.68095034258096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1342372688175216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797385`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "B1", 
             Association[1 -> {
                Complex[72.01527569469468, -8.327717105231118], 
                Complex[36.10854866480779, -34.2844740897253]}, 2 -> {
                Complex[132.68095034258096`, 0.1342372688175216], 
                Complex[103.78650096169163`, -20.406901625797385`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.610328294068257`, -4.901777966177439}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.29406602519018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.185820989619934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.11630299481564`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.41906952024033`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13591265188070087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338054`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "B1", 
             Association[1 -> {
                Complex[72.29406602519018, -8.185820989619934], 
                Complex[36.38770434340436, -34.11630299481564]}, 2 -> {
                Complex[132.41906952024033`, 0.13591265188070087`], 
                Complex[103.51384028303795`, -20.406479492338054`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-27.269119093066667`, -4.85472721661915}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.56568017864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.66013959822463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.95492960334115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.1656799251484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951338863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "B1", 
             Association[1 -> {
                Complex[72.56568017864, -8.050776840303698], 
                Complex[36.66013959822463, -33.95492960334115]}, 2 -> {
                Complex[132.1656799251484, 0.13761371951338863`], 
                Complex[103.24962551411933`, -20.406040889030567`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.9308614369727, -4.808418478203722}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.83078430520496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.921939398858431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.92650618566856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.79971952448827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.91992463906843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1393404798424747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "B1", 
             Association[1 -> {
                Complex[72.83078430520496, -7.921939398858431], 
                Complex[36.92650618566856, -33.79971952448827]}, 2 -> {
                Complex[131.91992463906843`, 0.1393404798424747], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.595478493312708`, -4.7628178347493595`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.08994679168227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.187359197641086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.65013212317826`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.6810758118074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "B1", 
             Association[1 -> {
                Complex[73.08994679168227, -7.798758308638223], 
                Complex[37.187359197641086`, -33.65013212317826]}, 2 -> {
                Complex[131.6810758118074, 0.14109302450360203`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-26.262900281307477`, -4.717894281233873}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34365753646222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.443176195934996`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.50570209730139`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.44850899973972`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14287151349532431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "B1", 
             Association[1 -> {
                Complex[73.34365753646222, -7.680759532183109], 
                Complex[37.443176195934996`, -33.50570209730139]}, 2 -> {
                Complex[131.44850899973972`, 0.14287151349532431`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.933062736592884`, -4.673619330473642}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.59234258892822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.567531219181628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.69437173707493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.36602547590361`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.22168370076204`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1446761639763875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "B1", 
             Association[1 -> {
                Complex[73.59234258892822, -7.567531219181628], 
                Complex[37.69437173707493, -33.36602547590361]}, 2 -> {
                Complex[131.22168370076204`, 0.1446761639763875], 
                Complex[102.26185863012616`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.605906946921355`, -4.629966690777559}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.83637544801043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.4587127853605635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.230748805484254`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.000128350837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187042746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982483`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "B1", 
             Association[1 -> {
                Complex[73.83637544801043, -7.4587127853605635`], 
                Complex[37.94130857631963, -33.230748805484254`]}, 2 -> {
                Complex[131.000128350837, 0.14650724187042746`], 
                Complex[102.02923912251606`, -20.403602844982483`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-25.281378520650545`, -4.586911998831905}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07608590770809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.353986351536106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.184306434253365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.099560678600085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.7834285934079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14836505550878115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "B1", 
             Association[1 -> {
                Complex[74.07608590770809, -7.353986351536106], 
                Complex[38.184306434253365`, -33.099560678600085`]}, 2 -> {
                Complex[130.7834285934079, 0.14836505550878115`], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.95942705976169, -4.544432596150269}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.31176707129376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.253069946548107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.423648944426496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.97218501218886`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.57121798988905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15024995077915002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "B1", 
             Association[1 -> {
                Complex[74.31176707129376, -7.253069946548107], 
                Complex[38.423648944426496`, -32.97218501218886]}, 2 -> {
                Complex[130.57121798988905`, 0.15024995077915002`], 
                Complex[101.57804924438946`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.640005716171903`, -4.502507340306927}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.54368097781067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.155712048248091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.65958922320312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.8483756525743`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.36317057816737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1521623074051051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "B1", 
             Association[1 -> {
                Complex[74.54368097781067, -7.155712048248091], 
                Complex[38.65958922320312, -32.8483756525743]}, 2 -> {
                Complex[130.36317057816737`, 0.1521623074051051], 
                Complex[101.35878495705762`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.32307081515084, -4.461116444247727}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.7720631627776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061687153265096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.89235438185443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.15899484907538`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15410253608764451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "B1", 
             Association[1 -> {
                Complex[74.7720631627776, -7.061687153265096], 
                Complex[38.89235438185443, -32.727912000016886`]}, 2 -> {
                Complex[130.15899484907538`, 0.15410253608764451`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-24.008581533342333`, -4.420241338492918}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.9971263902912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.12214921663343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.610595426395236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.9584288242154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1560710763133156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40074513612678`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "B1", 
             Association[1 -> {
                Complex[74.9971263902912, -6.970792147471257], 
                Complex[39.12214921663343, -32.610595426395236`]}, 2 -> {
                Complex[129.9584288242154, 0.1560710763133156], 
                Complex[100.93145144506857`, -20.40074513612678]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.696499621622873`, -4.379864552173151}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.21906373372748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.34915925289308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678464`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.76123599877187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15806839468480582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.72288222699729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40012051017151`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "B1", 
             Association[1 -> {
                Complex[75.21906373372748, -6.882843306606486], 
                Complex[39.34915925289308, -32.49624631678464]}, 2 -> {
                Complex[129.76123599877187`, 0.15806839468480582`], 
                Complex[100.72288222699729`, -20.40012051017151]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.386789165087617`, -4.339969609689053}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.43805113911235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.797673797918373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.57355327641459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.38470160682704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.56720197061549`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1600949836664983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "B1", 
             Association[1 -> {
                Complex[75.43805113911235, -6.797673797918373], 
                Complex[39.57355327641459, -32.38470160682704]}, 2 -> {
                Complex[129.56720197061549`, 0.1600949836664983], 
                Complex[100.51741711927747`, -20.399477392046546`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-23.0794163740135, -4.300540940430434}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.6542495737786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.795485453839746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.275812717792256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.37613161903013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16215136066387456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.31486023740956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39881538805515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "B1", 
             Association[1 -> {
                Complex[75.6542495737786, -6.715131583883629], 
                Complex[39.795485453839746`, -32.275812717792256`]}, 2 -> {
                Complex[129.37613161903013`, 0.16215136066387456`], 
                Complex[100.31486023740956`, -20.39881538805515]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.774349400852525`, -4.261563799489229}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.86780683969536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.635077651408384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100969`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.18784672741097`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1642380673752916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398134080358393`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "B1", 
             Association[1 -> {
                Complex[75.86780683969536, -6.635077651408384], 
                Complex[40.01509712100969, -32.16944381340221]}, 2 -> {
                Complex[129.18784672741097`, 0.1642380673752916], 
                Complex[100.11503259520978`, -20.398134080358393`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.47155817924212, -4.223024197686884}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.07885911349071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.5573845066078915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.0654703190693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.0021839674614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936822443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789097`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "B1", 
             Association[1 -> {
                Complex[76.07885911349071, -6.5573845066078915`], 
                Complex[40.23251830075458, -32.0654703190693]}, 2 -> {
                Complex[129.0021839674614, 0.16635566936822443`], 
                Complex[99.91777008789097, -20.397433027529168`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-22.17101428175108, -4.18490883954134}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.28753226206464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.481934887900402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.44786899864124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.963777656737037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.81899317991187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16850475584425478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.7229217717481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "B1", 
             Association[1 -> {
                Complex[76.28753226206464, -6.481934887900402], 
                Complex[40.44786899864124, -31.963777656737037`]}, 2 -> {
                Complex[128.81899317991187`, 0.16850475584425478`], 
                Complex[99.7229217717481, -20.39671176490144]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.872690793659277`, -4.147205068039286}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.49394297267101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.408620659800467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.66126031523404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.864260158083287`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.63813590014166`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17068593956353967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "B1", 
             Association[1 -> {
                Complex[76.49394297267101, -6.408620659800467], 
                Complex[40.66126031523404, -31.864260158083287`]}, 2 -> {
                Complex[128.63813590014166`, 0.17068593956353967`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.576562200531374`, -4.109900815271832}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.69819972862496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.766820126231003`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.45948408736626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17289985690709622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "B1", 
             Association[1 -> {
                Complex[76.69819972862496, -6.337341857243102], 
                Complex[40.87279540575693, -31.766820126231003`]}, 2 -> {
                Complex[128.45948408736626`, 0.17289985690709622`], 
                Complex[99.33992109514007, -20.39520663629768]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-21.28260428771841, -4.072984558147098}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.90040365578946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060299`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.082570312084634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.67136702185057`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.28291902404564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17514716805938169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.394421725649263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "B1", 
             Association[1 -> {
                Complex[76.90040365578946, -6.268005856060299], 
                Complex[41.082570312084634`, -31.67136702185057]}, 2 -> {
                Complex[128.28291902404564`, 0.17514716805938169`], 
                Complex[99.15152035933144, -20.394421725649263`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.9907940502184, -4.036445278518176}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.10064926028727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.57781675404458`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.10833035842901`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17742855729767137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.96503500426881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.393614515533017`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "B1", 
             Association[1 -> {
                Complex[77.10064926028727, -6.20052664977852], 
                Complex[41.290674687319935`, -31.57781675404458]}, 2 -> {
                Complex[128.10833035842901`, 0.17742855729767137`], 
                Complex[98.96503500426881, -20.393614515533017`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.70110961157607, -4.0002724271675945`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.29902507416718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.1348242164964875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.4971924295248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.486091059962416`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.93561526809535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1797447333776459`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "B1", 
             Association[1 -> {
                Complex[77.29902507416718, -6.1348242164964875`], 
                Complex[41.4971924295248, -31.486091059962416`]}, 2 -> {
                Complex[127.93561526809535`, 0.1797447333776459], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.41353015070067, -3.9644558911738836`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.49561422279432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.070823962465016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.7022022382381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.396116959927443`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.76467772627852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18209643000701933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39193084897724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "B1", 
             Association[1 -> {
                Complex[77.49561422279432, -6.070823962465016], 
                Complex[41.7022022382381, -31.396116959927443`]}, 2 -> {
                Complex[127.76467772627852`, 0.18209643000701933`], 
                Complex[98.59740257849909, -20.39193084897724]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-20.12803583564821, -3.9289859642549305`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.69049492536396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.008456231284885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713039`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.59542785591412`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18448440640095512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39105315780623`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "B1", 
             Association[1 -> {
                Complex[77.69049492536396, -6.008456231284885], 
                Complex[41.905778105062396`, -31.30782627713039]}, 2 -> {
                Complex[127.59542785591412`, 0.18448440640095512`], 
                Complex[98.41606788851908, -20.39105315780623]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.84460776355049, -3.8938533197408307`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.88374093802699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.947655869489128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.42778135888064`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1869094479145506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "B1", 
             Association[1 -> {
                Complex[77.88374093802699, -5.947655869489128], 
                Complex[42.10798974770688, -31.221155212774143`]}, 2 -> {
                Complex[127.42778135888064`, 0.1869094479145506], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.563227905990704`, -3.859048985877203}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.07542194756493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.888361840780238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043033`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.26165900996357`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18937236674901994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.389222784622216`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "B1", 
             Association[1 -> {
                Complex[78.07542194756493, -5.888361840780238], 
                Complex[42.30890299533777, -31.136043969043033`]}, 2 -> {
                Complex[127.26165900996357`, 0.18937236674901994`], 
                Complex[98.05793516060473, -20.389222784622216`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.283879059218602`, -3.824564323199876}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.26560392228748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.83051688241914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482678`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.09698620674699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1918740027291996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "B1", 
             Association[1 -> {
                Complex[78.26560392228748, -5.83051688241914], 
                Complex[42.50858013183329, -31.052436413482678`]}, 2 -> {
                Complex[127.09698620674699`, 0.1918740027291996], 
                Complex[97.88098148963749, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-19.006544798681947`, -3.7903910037569815`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.45434942578764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7740671982708545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.97027977937305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.93369256801181`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19441522415101703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "B1", 
             Association[1 -> {
                Complex[78.45434942578764, -5.7740671982708545`], 
                Complex[42.70708020251326, -30.97027977937305]}, 2 -> {
                Complex[126.93369256801181`, 0.19441522415101703`], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.731209437418304`, -3.7565209919821068`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.64171789833449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.718962183842703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.904459289065734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.88952439749861`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.77171157435116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19699692869821914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "B1", 
             Association[1 -> {
                Complex[78.64171789833449, -5.718962183842703], 
                Complex[42.904459289065734`, -30.88952439749861]}, 2 -> {
                Complex[126.77171157435116`, 0.19699692869821914`], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.457857987908934`, -3.722946527048124}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.82776590997473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.665154179340725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.1007707566919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.61098024565148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19962004442848083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38524206428723`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "B1", 
             Association[1 -> {
                Complex[78.82776590997473, -5.665154179340725], 
                Complex[43.1007707566919, -30.810123455401037`]}, 2 -> {
                Complex[126.61098024565148`, 0.19962004442848083`], 
                Complex[97.35772603163757, -20.38524206428723]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-18.186476127047957`, -3.689660106550727}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.01254738882457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.612598247344149`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.296065476907174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.732032780766865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.45143885086726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20228553082947306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.18562929385388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "B1", 
             Association[1 -> {
                Complex[79.01254738882457, -5.612598247344149], 
                Complex[43.296065476907174`, -30.732032780766865`]}, 2 -> {
                Complex[126.45143885086726`, 0.20228553082947306`], 
                Complex[97.18562929385388, -20.38417572502943]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.917050163920546`, -3.656654471390041}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.19611382753952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.49039202894673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.65521064607696`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.29303064616852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2049943799461619`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "B1", 
             Association[1 -> {
                Complex[79.19611382753952, -5.561251972178114], 
                Complex[43.49039202894673, -30.65521064607696]}, 2 -> {
                Complex[126.29303064616852`, 0.2049943799461619], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.649567010122095`, -3.6239225917334585`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.37851447053697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.5110752784691845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.68379688231679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.5796175920435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.13570163808673`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20774761758097904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.381951782413044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "B1", 
             Association[1 -> {
                Complex[79.37851447053697, -5.5110752784691845`], 
                Complex[43.68379688231679, -30.5796175920435]}, 2 -> {
                Complex[126.13570163808673`, 0.20774761758097904`], 
                Complex[96.84456714160432, -20.381951782413044`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.384014152380896`, -3.591457653956146}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.55979648419662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4620302667087515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.505216267696298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.9794003687457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117392`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "B1", 
             Association[1 -> {
                Complex[79.55979648419662, -5.4620302667087515`], 
                Complex[43.87632456268657, -30.505216267696298`]}, 2 -> {
                Complex[125.9794003687457, 0.2105463045690835], 
                Complex[96.6754942074181, -20.38079237117392]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-17.120379627274243`, -3.5592530484673737`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.74000511196857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.41408106393778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.43197128526467`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.82407772065201`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21339153813131853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37960007011897`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "B1", 
             Association[1 -> {
                Complex[79.74000511196857, -5.41408106393778], 
                Complex[44.06801780302349, -30.43197128526467]}, 2 -> {
                Complex[125.82407772065201`, 0.21339153813131853`], 
                Complex[96.50732568207661, -20.37960007011897]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.858651997852075`, -3.527302358340991}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.91918381606891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.367193687912338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.258917681628574`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.359849088243717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.66968673885063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21628445330793863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.34001352004081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37837388627006`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "B1", 
             Association[1 -> {
                Complex[79.91918381606891, -5.367193687912338], 
                Complex[44.258917681628574`, -30.359849088243717`]}, 2 -> {
                Complex[125.66968673885063`, 0.21628445330793863`], 
                Complex[96.34001352004081, -20.37837388627006]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.598820332002273`, -3.4955993486766395`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.09737440722895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321335923317816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.51618246853248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2192262244765668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "B1", 
             Association[1 -> {
                Complex[80.09737440722895, -5.321335923317816], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[125.51618246853248`, 0.2192262244765668], 
                Complex[96.17351165179058, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.34087418241044, -3.464137956626366}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.27461716378079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360477`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.36352180642044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2222180669583733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "B1", 
             Association[1 -> {
                Complex[80.27461716378079, -5.276477208780441], 
                Complex[44.63849414140558, -30.218847270360477`]}, 2 -> {
                Complex[125.36352180642044`, 0.2222180669583733], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-16.084803567981847`, -3.43291228202783}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.45095094120657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.232588533576675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.149908663093328`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.21166336446669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22526123871674955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "B1", 
             Association[1 -> {
                Complex[80.45095094120657, -5.232588533576675], 
                Complex[44.82724569242561, -30.149908663093328`]}, 2 -> {
                Complex[125.21166336446669`, 0.22526123871674955`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.830598956607995`, -3.401916578590727}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.62641327314368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.015354026525884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.08197467668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.0605673445708`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22835704215337221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37310908834082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "B1", 
             Association[1 -> {
                Complex[80.62641327314368, -5.189642343075517], 
                Complex[45.015354026525884`, -30.08197467668967]}, 2 -> {
                Complex[125.0605673445708, 0.22835704215337221`], 
                Complex[95.67843369946033, -20.37310908834082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.578251249172562`, -3.3711452455890956`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.80104046472162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.14761245206253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.01501930425797`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.91019542318102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23150682600686542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.371697196609304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "B1", 
             Association[1 -> {
                Complex[80.80104046472162, -5.14761245206253], 
                Complex[45.20285365244137, -30.01501930425797]}, 2 -> {
                Complex[124.91019542318102`, 0.23150682600686542`], 
                Complex[95.51474684712201, -20.371697196609304`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.32775176470061, -3.3405928200158157`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.97486767900651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194039`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.38977804698447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.94901778780827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.76051064477248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23471198735986767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37024459957686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "B1", 
             Association[1 -> {
                Complex[80.97486767900651, -5.106473965194039], 
                Complex[45.38977804698447, -29.94901778780827]}, 2 -> {
                Complex[124.76051064477248`, 0.23471198735986767`], 
                Complex[95.35166475158147, -20.37024459957686]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-15.079092226567193`, -3.3102539691598643`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.14792901724158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.61147732331085`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2379739737607506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36874999840365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "B1", 
             Association[1 -> {
                Complex[81.14792901724158, -5.066203203916091], 
                Complex[45.57615973333942, -29.88394654760416]}, 2 -> {
                Complex[124.61147732331085`, 0.2379739737607506], 
                Complex[95.18915044704521, -20.36874999840365]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.832264749687718`, -3.2801234835709834`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.32025759349672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.8197831172457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.4630609509089`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546681905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.367212042296025`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "B1", 
             Association[1 -> {
                Complex[81.32025759349672, -5.026777639259071], 
                Complex[45.76203035396384, -29.8197831172457]}, 2 -> {
                Complex[124.4630609509089, 0.24129428546681905`], 
                Complex[95.02716811464279, -20.367212042296025`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.58726182862099, -3.250196270378449}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.49188560427382`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.988175829983487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.31522811297008`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.24467447781636753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3656293260625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "B1", 
             Association[1 -> {
                Complex[81.49188560427382, -4.988175829983487], 
                Complex[45.94742073863617, -29.756506083970756`]}, 2 -> {
                Complex[124.31522811297008`, 0.24467447781636753`], 
                Complex[94.86568299639735, -20.3656293260625]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.344076326522506`, -3.2204673469347074`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.66284439355744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.950377365611486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.13236096813215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.16794640918864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.24811616373761602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523568`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "B1", 
             Association[1 -> {
                Complex[81.66284439355744, -4.950377365611486], 
                Complex[46.13236096813215, -29.694095033720544`]}, 2 -> {
                Complex[124.16794640918864`, 0.24811616373761602`], 
                Complex[94.70466131500457, -20.364000387523568`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-14.10270146489176, -3.190931834755815}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.83316451374981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9133628139288374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.316880433963114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.63253050056463`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.02118437984169`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2516210164031831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "B1", 
             Association[1 -> {
                Complex[81.83316451374981, -4.9133628139288374`], 
                Complex[46.316880433963114`, -29.63253050056463]}, 2 -> {
                Complex[124.02118437984169`, 0.2516210164031831], 
                Complex[94.54407019885234, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.86313081406209, -3.1615849537338536`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.00287578288496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.877113672586954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.50100789456628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.571793920124346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.87491143686638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25519077203948826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.38387761177131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "B1", 
             Association[1 -> {
                Complex[82.00287578288496, -4.877113672586954], 
                Complex[46.50100789456628, -29.571793920124346`]}, 2 -> {
                Complex[123.87491143686638`, 0.25519077203948826`], 
                Complex[94.38387761177131, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.625358284387511`, -3.1324220165978107`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.17200733847808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.84161232447478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.51186758667359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.72909779926668`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25882723290117593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623653`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "B1", 
             Association[1 -> {
                Complex[82.17200733847808, -4.84161232447478], 
                Complex[46.684771528299024`, -29.51186758667359]}, 2 -> {
                Complex[123.72909779926668`, 0.25882723290117593`], 
                Complex[94.22405228705699, -20.358820702623653`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.389378118084204`, -3.103438423601325}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.34058768833268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.868198983556454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.452734613629488`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.58371443243793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2625322704216669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "B1", 
             Association[1 -> {
                Complex[82.34058768833268, -4.806841996564815], 
                Complex[46.868198983556454`, -29.452734613629488`]}, 2 -> {
                Complex[123.58371443243793`, 0.2625322704216669], 
                Complex[94.06456366534843, -20.35699101364115]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-13.155184881689289`, -3.0746296574173484`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.50864475859716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.772786721969363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177013`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.43873299103726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2663078285515105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486673`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "B1", 
             Association[1 -> {
                Complex[82.50864475859716, -4.772786721969363], 
                Complex[47.051317426301225`, -29.394378897177013`]}, 2 -> {
                Complex[123.43873299103726`, 0.2663078285515105], 
                Complex[93.90538183598731, -20.355106834486673`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.922773459103121`, -3.0459912782206273`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.67620593933668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7394313049710854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.23415358526995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.336785082799004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.29412576506266`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27015592729763804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "B1", 
             Association[1 -> {
                Complex[82.67620593933668, -4.7394313049710854`], 
                Complex[47.23415358526995, -29.336785082799004`]}, 2 -> {
                Complex[123.29412576506266`, 0.27015592729763804`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.692139045182836`, -3.01751891894127}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.84329812786348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7067612888163355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507018`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.14986562883324`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2740786664771618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35116745361845`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "B1", 
             Association[1 -> {
                Complex[82.84329812786348, -4.7067612888163355`], 
                Complex[47.41673379509784, -29.279938534507018`]}, 2 -> {
                Complex[123.14986562883324`, 0.2740786664771618], 
                Complex[93.58782182500669, -20.35116745361845]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.463277139861171`, -2.989208280671853}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.0099477700464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.674762926083101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.5990840375824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.223825306591696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.00592599259153`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27807822970104984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34910827142565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "B1", 
             Association[1 -> {
                Complex[83.0099477700464, -4.674762926083101], 
                Complex[47.5990840375824, -29.223825306591696`]}, 2 -> {
                Complex[123.00592599259153`, 0.27807822970104984`], 
                Complex[93.42938657992538, -20.34910827142565]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.236183542763891`, -2.9610551282135975`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.17618089980478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.643423151455099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.7812299812911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.168432117730696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.86228075647094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.28215688860378724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.2711439022902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "B1", 
             Association[1 -> {
                Complex[83.17618089980478, -4.643423151455099], 
                Complex[47.7812299812911, -29.168432117730696`]}, 2 -> {
                Complex[122.86228075647094`, 0.28215688860378724`], 
                Complex[93.2711439022902, -20.34698662948813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-12.010854348304301`, -2.9330552857459824`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.34202317697387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.11374632731038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.71890426659377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2863170073368831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "B1", 
             Association[1 -> {
                Complex[83.34202317697387, -4.612729556752136], 
                Complex[47.96319701970125, -29.11374632731038]}, 2 -> {
                Complex[122.71890426659377`, 0.2863170073368831], 
                Complex[93.11306634486284, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.787285941233486`, -2.9052046326064054`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.50749992371578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.582670368083347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.5757712730832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34254700963612`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "B1", 
             Association[1 -> {
                Complex[83.50749992371578, -4.582670368083347], 
                Complex[48.14501030804773, -29.059755913834174`]}, 2 -> {
                Complex[122.5757712730832, 0.2905610473453315], 
                Complex[92.95512681316394, -20.34254700963612]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.565474992629115`, -2.8774990991662537`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.67263615963778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.553234425005796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.32669479904236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.006449455305912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.43285688978916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.294891572447947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "B1", 
             Association[1 -> {
                Complex[83.67263615963778, -4.553234425005796], 
                Complex[48.32669479904236, -29.006449455305912`]}, 2 -> {
                Complex[122.43285688978916`, 0.294891572447947], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.345418456306087`, -2.849934662790115}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.83745663576826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.524411161584033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.95381611148981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.29013655554255`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2993112542442012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "B1", 
             Association[1 -> {
                Complex[83.83745663576826, -4.524411161584033], 
                Complex[48.50827527761827, -28.95381611148981]}, 2 -> {
                Complex[122.29013655554255`, 0.2993112542442012], 
                Complex[92.63955496002484, -20.337829663202022`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-11.12711356563481, -2.8225073438663926`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.00198586753189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.689776394844124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.901845607962525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.14758599676475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3038228778721799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "B1", 
             Association[1 -> {
                Complex[84.00198586753189, -4.496190589260192], 
                Complex[48.689776394844124`, -28.901845607962525`]}, 2 -> {
                Complex[122.14758599676475`, 0.3038228778721799], 
                Complex[92.48186983901313, -20.33536045179569]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.910557830754565`, -2.795213201896295}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.16624816685666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.468563281455603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.87122270114558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.85052822188417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.00518119127094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3084293481445214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33281390326847`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "B1", 
             Association[1 -> {
                Complex[84.16624816685666, -4.468563281455603], 
                Complex[48.87122270114558, -28.85052822188417]}, 2 -> {
                Complex[122.00518119127094`, 0.3084293481445214], 
                Complex[92.32421706624812, -20.33281390326847]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.695749036171003`, -2.768048331630007}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.3302676735389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.441520359836423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.799854769426958`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.86289833311504`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31313369609146713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.330187124209285`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "B1", 
             Association[1 -> {
                Complex[84.3302676735389, -4.441520359836423], 
                Complex[49.05263867896425, -28.799854769426958`]}, 2 -> {
                Complex[121.86289833311504`, 0.31313369609146713`], 
                Complex[92.16657070129295, -20.330187124209285`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.482685238728374`, -2.741008859237739}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.49406838598571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.234048774980316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.74981659481079`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.7207137983327`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31793908594289033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651896`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "B1", 
             Association[1 -> {
                Complex[84.49406838598571, -4.4150534821866065`], 
                Complex[49.234048774980316`, -28.74981659481079]}, 2 -> {
                Complex[121.7207137983327, 0.31793908594289033`], 
                Complex[92.00890492013562, -20.327477084651896`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.271364765948443`, -2.7140909385046466`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.65767419144984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.389154831841693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905757`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.57860411144645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3228488225839969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.8511939788492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.32468061012449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "B1", 
             Association[1 -> {
                Complex[84.65767419144984, -4.389154831841693], 
                Complex[49.41547743201962, -28.700405560905757`]}, 2 -> {
                Complex[121.57860411144645`, 0.3228488225839969], 
                Complex[91.8511939788492, -20.32468061012449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-10.061786214729674`, -2.6872907470373}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.82110889586633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.363817108646427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.59694912076191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.651614041371154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.43654591260237`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32786635952260024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.32179437313911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "B1", 
             Association[1 -> {
                Complex[84.82110889586633, -4.363817108646427], 
                Complex[49.59694912076191, -28.651614041371154`]}, 2 -> {
                Complex[121.43654591260237`, 0.32786635952260024`], 
                Complex[91.6934121777283, -20.32179437313911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.853948450401484, -2.6606044824707555`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.98439625339881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.339033521409435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.603434914311087`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.29451592521413`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.33299530740941635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "B1", 
             Association[1 -> {
                Complex[84.98439625339881, -4.339033521409435], 
                Complex[49.77848837136714, -28.603434914311087`]}, 2 -> {
                Complex[121.29451592521413`, 0.33299530740941635`], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.64785060612932, -2.6340283586639752`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.14755999579832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.96011980513068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.55586155743547`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.1524909239935`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33823944315668386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "B1", 
             Association[1 -> {
                Complex[85.14755999579832, -4.314797781836454], 
                Complex[49.96011980513068, -28.55586155743547]}, 2 -> {
                Complex[121.1524909239935, 0.33823944315668386`], 
                Complex[91.37753320535234, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.44349208266872, -2.6075586018718826`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.31062386167716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.291104099934119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.14186816628128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.508887844726274`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.0104477032505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31256132120175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "B1", 
             Association[1 -> {
                Complex[85.31062386167716, -4.291104099934119], 
                Complex[50.14186816628128, -28.508887844726274`]}, 2 -> {
                Complex[121.0104477032505, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.31256132120175]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.240872548465768, -2.5811914468819626`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.47361162579809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.267947180884556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.32375835403241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.462508144617296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.86836304534869`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3490892764910097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "B1", 
             Association[1 -> {
                Complex[85.47361162579809, -4.267947180884556], 
                Complex[50.32375835403241, -28.462508144617296`]}, 2 -> {
                Complex[120.86836304534869`, 0.3490892764910097], 
                Complex[91.0610619442071, -20.30927936589565]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-9.039991940104949, -2.5549231331022972`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.63654712847851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.245322223400962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.505815454999635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.416717319706716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.72621368920332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.35470345068097464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "B1", 
             Association[1 -> {
                Complex[85.63654712847851, -4.245322223400962], 
                Complex[50.505815454999635`, -28.416717319706716`]}, 2 -> {
                Complex[120.72621368920332`, 0.35470345068097464`], 
                Complex[90.90253941775816, -20.305888372154573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.840850463104738, -2.5287499005886267`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.7994543052095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.223224919584004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.68806477609714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.371510728031737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.58397629871097`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36044978922689364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.74379078021592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "B1", 
             Association[1 -> {
                Complex[85.7994543052095, -4.223224919584004], 
                Complex[50.68806477609714, -28.371510728031737`]}, 2 -> {
                Complex[120.58397629871097`, 0.36044978922689364`], 
                Complex[90.74379078021592, -20.30238387787967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.643448593062994, -2.5026679859966143`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.96235721658975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.201651456308553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.870531878028714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.326884225945246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.44162743099962`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36633306182622866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29876118819338`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "B1", 
             Association[1 -> {
                Complex[85.96235721658975, -4.201651456308553], 
                Complex[50.870531878028714`, -28.326884225945246`]}, 2 -> {
                Complex[120.44162743099962`, 0.36633306182622866`], 
                Complex[90.58478964962532, -20.29876118819338]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.44778707715606, -2.4766736184450155`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.1252800786756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.1805985181808465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.282834172645913`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.29914350438833`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37235827485923007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "B1", 
             Association[1 -> {
                Complex[86.1252800786756, -4.1805985181808465`], 
                Complex[51.05324260949037, -28.282834172645913`]}, 2 -> {
                Complex[120.29914350438833`, 0.37235827485923007`], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.253866935996493, -2.4507630152750344`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.28824729385005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.160063292117321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.23622314220589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.239357436425408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.15650076594429`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37853068639320436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "B1", 
             Association[1 -> {
                Complex[86.28824729385005, -4.160063292117321], 
                Complex[51.23622314220589, -28.239357436425408`]}, 2 -> {
                Complex[120.15650076594429`, 0.37853068639320436`], 
                Complex[90.26592313793013, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-8.06168946585367, -2.424932377689998}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.45128348231654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.01367525852382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38485582234995075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.28713318083525`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "B1", 
             Association[1 -> {
                Complex[86.45128348231654, -4.140043473607491], 
                Complex[51.419500006920465`, -28.196451402708608`]}, 2 -> {
                Complex[120.01367525852382`, 0.38485582234995075`], 
                Complex[90.10600363628706, -20.28713318083525]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.871256241246764, -2.399177886258664}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.61441351432457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.60310013048105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.8706427871813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3913394939430957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "B1", 
             Association[1 -> {
                Complex[86.61441351432457, -4.120537274736594], 
                Complex[51.60310013048105, -28.154113983977776`]}, 2 -> {
                Complex[119.8706427871813, 0.3913394939430957], 
                Complex[89.94572332307655, -20.282985551225522`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.682569117916595, -2.373495696264262}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.77766254324008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.1015434340563175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.72737888482756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.397987816503232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.78505422710688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "B1", 
             Association[1 -> {
                Complex[86.77766254324008, -4.1015434340563175`], 
                Complex[51.78705087413991, -28.112343631685352`]}, 2 -> {
                Complex[119.72737888482756`, 0.397987816503232], 
                Complex[89.78505422710688, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.495630236187077, -2.347881932880165}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.94105603957541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.083061228407528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.58385877701511`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4048072298215822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.6239679392368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "B1", 
             Association[1 -> {
                Complex[86.94105603957541, -4.083061228407528], 
                Complex[51.97138007322184, -28.071139350277974`]}, 2 -> {
                Complex[119.58385877701511`, 0.4048072298215822], 
                Complex[89.6239679392368, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.310442024727019, -2.322332686151824}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.10461982609941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.065090486814276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.44005734572406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4118045201569235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26964207736714`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "B1", 
             Association[1 -> {
                Complex[87.10461982609941, -4.065090486814276], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[119.44005734572406`, 0.4118045201569235], 
                Complex[89.46243556940976, -20.26964207736714]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-7.1270072047253255`, -2.296844005762542}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.26838011415413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.990427882936377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.29594909201677`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41898684406680814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "B1", 
             Association[1 -> {
                Complex[87.26838011415413, -4.047631606586542], 
                Complex[52.34128779806404, -27.990427882936377`]}, 2 -> {
                Complex[119.29594909201677`, 0.41898684406680814`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.945328794492804, -2.2714118955594773`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.43236354130933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.526924743965466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.950921629578826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.15150809742505`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4263617542416488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "B1", 
             Association[1 -> {
                Complex[87.43236354130933, -4.030685571788468], 
                Complex[52.526924743965466`, -27.950921629578826`]}, 2 -> {
                Complex[119.15150809742505`, 0.4263617542416488], 
                Complex[89.13791435011574, -20.259926647201574`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.765410114507597, -2.2460323078138056`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.5965972104936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.713057076949106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.91198335762003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.00670798392548`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.43393722754094827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "B1", 
             Association[1 -> {
                Complex[87.5965972104936, -4.014253974250844], 
                Complex[52.713057076949106`, -27.91198335762003]}, 2 -> {
                Complex[119.00670798392548`, 0.43393722754094827`], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.587254792919859, -2.2207011371866456`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.76110873074786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.998339037330249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.899715656323174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.87361513171314`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.86152187235369`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4417216954533863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.249482923580253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "B1", 
             Association[1 -> {
                Complex[87.76110873074786, -3.998339037330249], 
                Complex[52.899715656323174`, -27.87361513171314]}, 2 -> {
                Complex[118.86152187235369`, 0.4417216954533863], 
                Complex[88.81124809301974, -20.249482923580253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.410866771536243, -2.1954142143702007`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.9259262597554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9829436426451017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.08693209104623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.71592233909871`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24396616966669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "B1", 
             Association[1 -> {
                Complex[87.9259262597554, -3.9829436426451017`], 
                Complex[53.08693209104623, -27.835819707361438`]}, 2 -> {
                Complex[118.71592233909871`, 0.44972407722861857`], 
                Complex[88.64703191016157, -20.24396616966669]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.236250312304032, -2.170167299370229}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.09107854831043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.274738793614276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.798600564939374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.56988137091156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4579538159576179`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.238240125283728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "B1", 
             Association[1 -> {
                Complex[88.09107854831043, -3.968071360048477], 
                Complex[53.274738793614276`, -27.798600564939374`]}, 2 -> {
                Complex[118.56988137091156`, 0.4579538159576179], 
                Complex[88.48218357926146, -20.238240125283728`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-6.063410004318266, -2.144956074393011}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.25659498689762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9537264811323634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.761961947657237`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.42337031765258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.46642091791168444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232294521384553`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "B1", 
             Association[1 -> {
                Complex[88.25659498689762, -3.9537264811323634`], 
                Complex[53.46316903677712, -27.761961947657237`]}, 2 -> {
                Complex[118.42337031765258`, 0.46642091791168444`], 
                Complex[88.31666948593069, -20.232294521384553`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.892350771376124, -2.1197761362961187`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.4225056545641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9399140565961543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.725908903854407`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.27635984279239`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4751359954876589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "B1", 
             Association[1 -> {
                Complex[88.4225056545641, -3.9399140565961543`], 
                Complex[53.65225701332303, -27.725908903854407`]}, 2 -> {
                Complex[118.27635984279239`, 0.4751359954876589], 
                Complex[88.15045511884611, -20.226118434741068`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.72307788010651, -2.0946229885583487`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.58884137027606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.926639937856118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.84203789918707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.690447334057268`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.12881987147094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48411031414990274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746615`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "B1", 
             Association[1 -> {
                Complex[88.58884137027606, -3.926639937856118], 
                Complex[53.84203789918707, -27.690447334057268`]}, 2 -> {
                Complex[118.12881987147094`, 0.48411031414990274`], 
                Complex[87.98350500554793, -20.219700235746615`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.555596948702709, -2.069492032719363}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.7556337469638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.032547920156205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.655584043295303`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.9807195359091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4933558438079552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.81578264469658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.213027531182277`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "B1", 
             Association[1 -> {
                Complex[88.7556337469638, -3.913910823322049], 
                Complex[54.032547920156205`, -27.655584043295303`]}, 2 -> {
                Complex[117.9807195359091, 0.4933558438079552], 
                Complex[87.81578264469658, -20.213027531182277`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.389913956290949, -2.04437855923447}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.92291524846912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.901734309823764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.22382442246095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.62132679923474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.83202711795477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5028853151246275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376102`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "B1", 
             Association[1 -> {
                Complex[88.92291524846912, -3.901734309823764], 
                Complex[54.22382442246095, -27.62132679923474]}, 2 -> {
                Complex[117.83202711795477`, 0.5028853151246275], 
                Complex[87.64725043449559, -20.206087101376102`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.226035252968325, -2.019277737684049}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.09071924962198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8901189497339552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.41590594756346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.587684396763734`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.68270998853552`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5127122813126174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.47786959696758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.198864831110026`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "B1", 
             Association[1 -> {
                Complex[89.09071924962198, -3.8901189497339552`], 
                Complex[54.41590594756346, -27.587684396763734`]}, 2 -> {
                Complex[117.68270998853552`, 0.5127122813126174], 
                Complex[87.47786959696758, -20.198864831110026`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.063967570547485, -1.9941846062702628`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.25908009968339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8790743144078443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.53273454377744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.191345633544127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "B1", 
             Association[1 -> {
                Complex[89.25908009968339, -3.8790743144078443`], 
                Complex[54.60883231147051, -27.554666729749556`]}, 2 -> {
                Complex[117.53273454377744`, 0.5228511860504373], 
                Complex[87.30760009775223, -20.191345633544127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.903718034046884, -1.9690940605263056`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.42803318940396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.868611064643572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.8026446889204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.52228487078621`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.38206613753938`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5333174382317764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "B1", 
             Association[1 -> {
                Complex[89.42803318940396, -3.868611064643572], 
                Complex[54.8026446889204, -27.52228487078621]}, 2 -> {
                Complex[117.38206613753938`, 0.5333174382317764], 
                Complex[87.13640056107454, -20.183513366330004`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.745294173969947, -1.9440008411546559`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.59761502195686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.490551159864236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.2306690101016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "B1", 
             Association[1 -> {
                Complex[89.59761502195686, -3.8587410289636965`], 
                Complex[54.99738570281199, -27.490551159864236`]}, 2 -> {
                Complex[117.2306690101016, 0.5441274943581388], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.58870393941802, -1.918899520901263}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.76786328801319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.19309951926377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.45947930302498`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.07850621273863`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5552989494946718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "B1", 
             Association[1 -> {
                Complex[89.76786328801319, -3.849477290628981], 
                Complex[55.19309951926377, -27.45947930302498]}, 2 -> {
                Complex[117.07850621273863`, 0.5552989494946718], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.433955712086268, -1.8937844903608843`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.93881694523479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.840834284423073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.42908448221182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.92553952790038`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5668506378361231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.15795887530354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "B1", 
             Association[1 -> {
                Complex[89.93881694523479, -3.840834284423073], 
                Complex[55.38983194870931, -27.42908448221182]}, 2 -> {
                Complex[116.92553952790038`, 0.5668506378361231], 
                Complex[86.61678591287696, -20.15795887530354]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.281058321193962, -1.8686499425969403`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.11051630246236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.587630553449955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.77172938472124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5788027440763157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "B1", 
             Association[1 -> {
                Complex[90.11051630246236, -3.8328279043933358`], 
                Complex[55.587630553449955`, -27.39938347770468]}, 2 -> {
                Complex[116.77172938472124`, 0.5788027440763157], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.130021059404223, -1.8434898564439288`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.28300310887596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725713`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.61703476957895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "B1", 
             Association[1 -> {
                Complex[90.28300310887596, -3.8254756239037446`], 
                Complex[55.78654476209901, -27.370394804725713`]}, 2 -> {
                Complex[116.61703476957895`, 0.5911769269441447], 
                Complex[86.26489841088478, -20.139004574702852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.9808536997913913`, -1.8182979783444038`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.45632064839748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.818796629551993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.34213886603787`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.46141313143245`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6039964564654334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "B1", 
             Association[1 -> {
                Complex[90.45632064839748, -3.818796629551993], 
                Complex[55.98662599135722, -27.34213886603787]}, 2 -> {
                Complex[116.46141313143245`, 0.6039964564654334], 
                Complex[86.08716253043332, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.8335665139173423`, -1.7930678025531746`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.6305138395877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812811970731542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.314638122629567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.30482028168436`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6172863667379066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "B1", 
             Association[1 -> {
                Complex[90.6305138395877, -3.812811970731542], 
                Complex[56.18792777555814, -27.314638122629567`]}, 2 -> {
                Complex[116.30482028168436`, 0.6172863667379066], 
                Complex[85.90816108596373, -20.118296161792674`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.6881702910795817`, -1.767792549519857}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.80562934126279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884641`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.390505904409395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.28791728489551`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.14721028834218`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6310736262715528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.10721581727977`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "B1", 
             Association[1 -> {
                Complex[90.80562934126279, -3.807544726884641], 
                Complex[56.390505904409395`, -27.28791728489551]}, 2 -> {
                Complex[116.14721028834218`, 0.6310736262715528], 
                Complex[85.72783819940138, -20.10721581727977]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.544676358799388, -1.7424651422355895`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.98171566400995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8030201948010025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.26200352709286`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.98853536429765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.54613560230258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.09561044342854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "B1", 
             Association[1 -> {
                Complex[90.98171566400995, -3.8030201948010025`], 
                Complex[56.594418569327175`, -27.26200352709286]}, 2 -> {
                Complex[115.98853536429765`, 0.6453873282550378], 
                Complex[85.54613560230258, -20.09561044342854]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.4030966046151243`, -1.7170781803009534`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.15882328771697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.799266098677166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.7997265187117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.236926728284`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.82874574960789`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6602589034686099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.3629924800621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "B1", 
             Association[1 -> {
                Complex[91.15882328771697, -3.799266098677166], 
                Complex[56.7997265187117, -27.236926728284]}, 2 -> {
                Complex[115.82874574960789`, 0.6602589034686099], 
                Complex[85.3629924800621, -20.08344612962457]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.26344349925183, -1.6916239114389897`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.33700478513522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.796312826071493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.00649322243323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.212719743482218`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.66778958775829`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595763`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "B1", 
             Association[1 -> {
                Complex[91.33700478513522, -3.796312826071493], 
                Complex[57.00649322243323, -27.212719743482218`]}, 2 -> {
                Complex[115.66778958775829`, 0.6757223589838173], 
                Complex[85.17834530693469, -20.070686076595763`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.1257301212339663`, -1.6660942001382304`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.51631495136485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7941936933811906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.50561279601737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.9921276717174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "B1", 
             Association[1 -> {
                Complex[91.51631495136485, -3.7941936933811906`], 
                Complex[57.21478504568006, -27.18941870930894]}, 2 -> {
                Complex[115.50561279601737`, 0.6918145462814342], 
                Complex[84.9921276717174, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.9899701830076233`, -1.6404804930666665`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.69681093896838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.167063389167346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.34215893017573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7085754629936065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.043215223764264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "B1", 
             Association[1 -> {
                Complex[91.69681093896838, -3.7929452450428487`], 
                Complex[57.42467143215047, -27.167063389167346`]}, 2 -> {
                Complex[115.34215893017573`, 0.7085754629936065], 
                Complex[84.80427009410889, -20.043215223764264`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.8561780586335836`, -1.6147737808456915`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.8785523981745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.63622509633278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.145697563752833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.1773690442082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "B1", 
             Association[1 -> {
                Complex[91.8785523981745, -3.7926075913306416`], 
                Complex[57.63622509633278, -27.145697563752833`]}, 2 -> {
                Complex[115.1773690442082, 0.7260485931492021], 
                Complex[84.61469983200216, -20.028413405245864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.7243688131044714`, -1.5889645557128131`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.0616016212985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.793224790416492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.849522224283454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.12536947368377`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.01118154573018`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7442812915903224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.01283297226922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "B1", 
             Association[1 -> {
                Complex[92.0616016212985, -3.793224790416492], 
                Complex[57.849522224283454`, -27.12536947368377]}, 2 -> {
                Complex[115.01118154573018`, 0.7442812915903224], 
                Complex[84.42334068029797, -20.01283297226922]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.594558233326888, -1.5630427645326497`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.24602369006297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7948452812797524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.10613232216428`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.84353204856465`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7633252191523134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281288`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "B1", 
             Association[1 -> {
                Complex[92.24602369006297, -3.7948452812797524`], 
                Complex[58.06464268186045, -27.10613232216428]}, 2 -> {
                Complex[114.84353204856465`, 0.7633252191523134], 
                Complex[84.2301127622816, -19.996417177281288`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.4667628607915995`, -1.5369977565343242`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.43188662390703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7975223751389713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.088044846923395`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.67435322433113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7832368362827095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.979103811483267`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "B1", 
             Association[1 -> {
                Complex[92.43188662390703, -3.7975223751389713`], 
                Complex[58.28167022874947, -27.088044846923395`]}, 2 -> {
                Complex[114.67435322433113`, 0.7832368362827095], 
                Complex[84.03493231522438, -19.979103811483267`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.341000025928049, -1.5108182250589957`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.6192615265831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8013148143453037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.500692735785776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.50357465575655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8040779640432887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.96082455075846`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "B1", 
             Association[1 -> {
                Complex[92.6192615265831, -3.8013148143453037`], 
                Complex[58.500692735785776`, -27.07117197223767]}, 2 -> {
                Complex[114.50357465575655`, 0.8040779640432887], 
                Complex[83.83771147270657, -19.96082455075846]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.2172878841038774`, -1.4844921424908077`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.80822272729263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.806287409159503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.7218024019493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.055585553683162`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.3311226954559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.94150420894384`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "B1", 
             Association[1 -> {
                Complex[92.80822272729263, -3.806287409159503], 
                Complex[58.7218024019493, -27.055585553683162`]}, 2 -> {
                Complex[114.3311226954559, 0.8259164229195777], 
                Complex[83.63835804728225, -19.94150420894384]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.0956454531787565`, -1.4580066874165885`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.99884791122709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.94509596590652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.15692033531631`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8488267615895713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861316`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "B1", 
             Association[1 -> {
                Complex[92.99884791122709, -3.812511764560067], 
                Complex[58.94509596590652, -27.04136523041568]}, 2 -> {
                Complex[114.15692033531631`, 0.8488267615895713], 
                Complex[83.43677531861316, -19.921059883642346`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.9760926524543925`, -1.4313481629095361`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.19121823254554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8200671112315354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.17067490495606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.02859940229373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.98088709345224`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8728910898028918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "B1", 
             Association[1 -> {
                Complex[93.19121823254554, -3.8200671112315354`], 
                Complex[59.17067490495606, -27.02859940229373]}, 2 -> {
                Complex[113.98088709345224`, 0.8728910898028918], 
                Complex[83.23286183421266, -19.899399977259357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.858650342770057, -1.404501904658314}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.38541840039804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8290412571884307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081303`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.8029389281222`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318298158`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022337`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "B1", 
             Association[1 -> {
                Complex[93.38541840039804, -3.8290412571884307`], 
                Complex[59.39864561154836, -27.017386352081303`]}, 2 -> {
                Complex[113.8029389281222, 0.8982000318298158], 
                Complex[83.02651123262949, -19.876423073022337`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.7433403673665515`, -1.3774521774603856`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.58153672540173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8395316791213494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.629119533963625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.62298819120014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9248538195678678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "B1", 
             Association[1 -> {
                Complex[93.58153672540173, -3.8395316791213494`], 
                Complex[59.629119533963625`, -27.007835536336128`]}, 2 -> {
                Complex[113.62298819120014`, 0.9248538195678678], 
                Complex[82.81761210248662, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.6301855929779328`, -1.3501820583646393`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.77966510974753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.851646775514205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.44094363802188`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9529635473601243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "B1", 
             Association[1 -> {
                Complex[93.77966510974753, -3.851646775514205], 
                Complex[59.86221326295695, -27.000069072431696`]}, 2 -> {
                Complex[113.44094363802188`, 0.9529635473601243], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.519209950386122, -1.3226733044780639`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.97989895853101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.994223453469264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.25671051601432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400181`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.79840036882036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "B1", 
             Association[1 -> {
                Complex[93.97989895853101, -3.865507306847951], 
                Complex[60.09804853982375, -26.994223453469264`]}, 2 -> {
                Complex[113.25671051601432`, 0.9826526138400181], 
                Complex[82.39169691847613, -19.79840036882036]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.4104384733783297`, -1.2949062031435525`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.18233698253069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.33675215288419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.990451527552718`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.07019076188233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0140583796142788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "B1", 
             Association[1 -> {
                Complex[94.18233698253069, -3.8812480516973524`], 
                Complex[60.33675215288419, -26.990451527552718`]}, 2 -> {
                Complex[113.07019076188233`, 1.0140583796142788`], 
                Complex[82.17443243593526, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.3038973346552416`, -1.2668594018465862`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.3870808529381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8990197110727025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.578455678156594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.988924782863727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.8812833468495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.047334073136629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.95412292984462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "B1", 
             Association[1 -> {
                Complex[94.3870808529381, -3.8990197110727025`], 
                Complex[60.578455678156594`, -26.988924782863727`]}, 2 -> {
                Complex[112.8812833468495, 1.047334073136629], 
                Complex[81.95412292984462, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.1996138767190934`, -1.2385097148209334`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.59423465574982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.918991096639213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.6898848222419`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "B1", 
             Association[1 -> {
                Complex[94.59423465574982, -3.918991096639213], 
                Complex[60.823295005096384`, -26.989835984869377`]}, 2 -> {
                Complex[112.6898848222419, 1.0826509804077677`], 
                Complex[81.73063257333021, -19.70361719945588]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.0976166350804795`, -1.2098319029022073`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.80390407673113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.941351640907616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.4958901345047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.120200956597012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "B1", 
             Association[1 -> {
                Complex[94.80390407673113, -3.941351640907616], 
                Complex[61.071409568577614`, -26.993402216234127`]}, 2 -> {
                Complex[112.4958901345047, 1.120200956597012], 
                Complex[81.50382199854216, -19.66742872877372]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.9979353502177253, -1.1807984227370125`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.01619522589353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.966314268200568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.29919380070963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1601992983922493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "B1", 
             Association[1 -> {
                Complex[95.01619522589353, -3.966314268200568], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[112.29919380070963`, 1.1601992983922493`], 
                Complex[81.27354946300129, -19.628553141047504`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.9006009635292094, -1.151379141024181}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.2312129818792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.994118662652407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.09969156415914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2028880133377466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540668`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "B1", 
             Association[1 -> {
                Complex[95.2312129818792, -3.994118662652407], 
                Complex[61.57803233510411, -27.009511166504147`]}, 2 -> {
                Complex[112.09969156415914`, 1.2028880133377466`], 
                Complex[81.03967255327478, -19.586711092540668`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.8056455909520202, -1.1215410090904976`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.4490586998926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.022643685363697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.89728268644794`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2485395142215723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.541586913666517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "B1", 
             Association[1 -> {
                Complex[95.4490586998926, -4.025034961302557], 
                Complex[61.836823766448234`, -27.022643685363697`]}, 2 -> {
                Complex[111.89728268644794`, 1.2485395142215723`], 
                Complex[80.80205060892804, -19.541586913666517`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.7131024658845979, -1.0912476928729562`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.66982708015928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.059367882777882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.69187307900017`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2974607490100891`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "B1", 
             Association[1 -> {
                Complex[95.66982708015928, -4.059367882777882], 
                Complex[62.09945108280155, -27.039620531417192`]}, 2 -> {
                Complex[111.69187307900017`, 1.2974607490100891`], 
                Complex[80.56054810632891, -19.492823467653352`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.6230058404162782, -1.060459153427258}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.89360193588463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.09746126947422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.06084353867766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.48337953511042`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3499977442410571`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.31503931313222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "B1", 
             Association[1 -> {
                Complex[95.89360193588463, -4.09746126947422], 
                Complex[62.36604010279414, -27.06084353867766]}, 2 -> {
                Complex[111.48337953511042`, 1.3499977442410571`], 
                Complex[80.31503931313222, -19.440016432485926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.5353908305037953, -1.0291311736267106`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.12045052987338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.139702965144408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.27173539332722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4065404837842295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "B1", 
             Association[1 -> {
                Complex[96.12045052987338, -4.139702965144408], 
                Complex[62.63670053402381, -27.086768000239168`]}, 2 -> {
                Complex[111.27173539332722`, 1.4065404837842295`], 
                Complex[80.06541461134333, -19.382708072431342`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.45029318651551825`, -0.9972148280865516}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.35041606925469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.91151748175411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.05689804273338`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "B1", 
             Association[1 -> {
                Complex[96.35041606925469, -4.186529858286217], 
                Complex[62.91151748175411, -27.117909237707966`]}, 2 -> {
                Complex[111.05689804273338`, 1.4675279533647945`], 
                Complex[79.81158898845908, -19.320380667492582`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.36774896541147434`, -0.9646558960417779}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.58350786490203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.23843277801587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.154849180830105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.83885876353477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.5334530375357764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "B1", 
             Association[1 -> {
                Complex[96.58350786490203, -4.23843277801587], 
                Complex[63.19054018060198, -27.154849180830105`]}, 2 -> {
                Complex[110.83885876353477`, 1.5334530375357764`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.28779407477602553`, -0.9313942216374842}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.81968859195634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.295960711667092`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.47376724001169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.19824237356078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.61765546654823`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.6048667383421042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.178259010998698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "B1", 
             Association[1 -> {
                Complex[96.81968859195634, -4.295960711667092], 
                Complex[63.47376724001169, -27.19824237356078]}, 2 -> {
                Complex[110.61765546654823`, 1.6048667383421042`], 
                Complex[79.29118905201918, -19.178259010998698`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.21046365228414238`, -0.8973630338353435}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.05885806185303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.39338892118766`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.6823808689752418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.097073995378256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "B1", 
             Association[1 -> {
                Complex[97.05885806185303, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[110.39338892118766`, 1.6823808689752418`], 
                Complex[79.02468735041019, -19.097073995378256`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.13579123775569207`, -0.8624882501594067}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.30083299086704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.43039170884118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.30739360850707`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.16624298693486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.7666679393393405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "B1", 
             Association[1 -> {
                Complex[97.30083299086704, -4.43039170884118], 
                Complex[64.05245675580909, -27.30739360850707]}, 2 -> {
                Complex[110.16624298693486`, 1.7666679393393405`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.0638076903631009, -0.8266878062196665}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.54532251758266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.93650909588722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.8584563892632038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "B1", 
             Association[1 -> {
                Complex[97.54532251758266, -4.508691887180885], 
                Complex[64.34746700294598, -27.374846901442822`]}, 2 -> {
                Complex[109.93650909588722`, 1.8584563892632038`], 
                Complex[78.47993347130918, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.005460196259525055, -0.7898710776092537}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.79189981669174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.45212840054961`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.70461463897895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298536`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "B1", 
             Association[1 -> {
                Complex[97.79189981669174, -4.595394633635136], 
                Complex[64.64571326583466, -27.45212840054961]}, 2 -> {
                Complex[109.70461463897895`, 1.9585186817545757`], 
                Complex[78.20241421183866, -18.803067851298536`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.07199141863592269, -0.751938492635382}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.0399712463619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.9465546185815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.54022545403769`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.47115381863438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0676491823619294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.9222561834679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665772`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "B1", 
             Association[1 -> {
                Complex[98.0399712463619, -4.691292487824421], 
                Complex[64.9465546185815, -27.54022545403769]}, 2 -> {
                Complex[109.47115381863438`, 2.0676491823619294`], 
                Complex[77.9222561834679, -18.685105090665772`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.99002448405696, 0.19849482270659813`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.31522679800293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1208373243402968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629899`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.7947638473515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23233632108243982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D1", 
             Association[1 -> {
                Complex[87.31522679800293, 0.1208373243402968], 
                Complex[113.66233957629899`, -20.405968816918097`]}, 2 -> {
                Complex[129.7947638473515, -0.23233632108243982`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.752538679540407, 0.19646030682920568`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.08751024810645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12356070149769949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786649`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404481912625194`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.99849322244222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23701538097059474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D1", 
             Association[1 -> {
                Complex[88.08751024810645, 0.12356070149769949`], 
                Complex[114.42383835786649`, -20.404481912625194`]}, 2 -> {
                Complex[128.99849322244222`, -0.23701538097059474`], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.523133019782662, 0.1943850909393916}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.7262337592472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.34122462191704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2412464009212765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.9491533625454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99078635006785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "D1", 
             Association[1 -> {
                Complex[88.7262337592472, 0.1262779516956984], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[128.34122462191704`, -0.2412464009212765], 
                Complex[152.9491533625454, -20.99078635006785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.3006324543978565`, 0.1922708587797306}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.28793849642045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1290342449298596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.6022820852753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.401559279830174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.76411865770065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24526087014839051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.3805277252232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.993153001298857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D1", 
             Association[1 -> {
                Complex[89.28793849642045, 0.1290342449298596], 
                Complex[115.6022820852753, -20.401559279830174`]}, 2 -> {
                Complex[127.76411865770065`, -0.24526087014839051`], 
                Complex[152.3805277252232, -20.993153001298857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.08430700680708, 0.19011821350981606`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.79835527489765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1318524872647502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400055664274525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.24040452840023`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24916606948645323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.86545848930385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.995376136189673`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "D1", 
             Association[1 -> {
                Complex[89.79835527489765, 0.1318524872647502], 
                Complex[116.10150054551087`, -20.400055664274525`]}, 2 -> {
                Complex[127.24040452840023`, -0.24916606948645323`], 
                Complex[151.86545848930385`, -20.995376136189673`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.8736502901770535`, 0.18792718940707154`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.27178641975755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13474786473650618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39850173816859`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.75520550340622`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2530238186026314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.3890678558327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.997517947369136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D1", 
             Association[1 -> {
                Complex[90.27178641975755, 0.13474786473650618`], 
                Complex[116.56359372447045`, -20.39850173816859]}, 2 -> {
                Complex[126.75520550340622`, -0.2530238186026314], 
                Complex[151.3890678558327, -20.997517947369136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.6682875730944176`, 0.1856974587412772}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.71716902479046`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614971214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.9974956564001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39688632979586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.29922820831268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D1", 
             Association[1 -> {
                Complex[90.71716902479046, 0.13773233614971214`], 
                Complex[116.9974956564001, -20.39688632979586]}, 2 -> {
                Complex[126.29922820831268`, -0.25687501967431886`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.467929619072834, 0.18342843130866804`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.14054230237684`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.40924174082738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.395199814614816`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.86619477978897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26074963565394127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "D1", 
             Association[1 -> {
                Complex[91.14054230237684, 0.14081646542056195`], 
                Complex[117.40924174082738`, -20.395199814614816`]}, 2 -> {
                Complex[125.86619477978897`, -0.26074963565394127`], 
                Complex[150.51816845485814`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.272346595370905, 0.18111930677087962`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.54622552815437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173268163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.393433199880487`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.45161704308063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2646714726710176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.11289854933466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D1", 
             Association[1 -> {
                Complex[91.54622552815437, 0.14401032173268163`], 
                Complex[117.80314680030486`, -20.393433199880487`]}, 2 -> {
                Complex[125.45161704308063`, -0.2646714726710176], 
                Complex[150.11289854933466`, -21.00381247852693]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.081352069562826, 0.1787691029444236}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.93744543191927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1473239947690677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.05214367849409`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2686607590280033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.00594694331133`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "D1", 
             Association[1 -> {
                Complex[91.93744543191927, 0.1473239947690677], 
                Complex[118.18243252444688`, -20.391577604746047`]}, 2 -> {
                Complex[125.05214367849409`, -0.2686607590280033], 
                Complex[149.72290589550488`, -21.00594694331133]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.8947925876769176`, 0.17637667034979287`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.31669834829874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15076793497771607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.54958963881722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.66518342286211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2727356740180505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727762`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "D1", 
             Association[1 -> {
                Complex[92.31669834829874, 0.15076793497771607`], 
                Complex[118.54958963881722`, -20.389623921810514`]}, 2 -> {
                Complex[124.66518342286211`, -0.2727356740180505], 
                Complex[149.34560377406763`, -21.008130280727762`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.7125405708247854`, 0.17394069807808243`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.68597265726372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15435321166980637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.28867366088821`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27691333395140566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D1", 
             Association[1 -> {
                Complex[92.68597265726372, 0.15435321166980637`], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[124.28867366088821`, -0.27691333395140566`], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.534489299122143, 0.17145971360922374`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.04689238885605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15809173524710415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.92093105477679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2812104825190756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "D1", 
             Association[1 -> {
                Complex[93.04689238885605, 0.15809173524710415`], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[123.92093105477679`, -0.2812104825190756], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.360549269951136, 0.16893207798071153`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.400813839551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16199646966552858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.383074839422665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.56055107061424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.2710665829474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.015130373573463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D1", 
             Association[1 -> {
                Complex[93.400813839551, 0.16199646966552858`], 
                Complex[119.59638315362787`, -20.383074839422665`]}, 2 -> {
                Complex[123.56055107061424`, -0.2856440165404512], 
                Complex[148.2710665829474, -21.015130373573463`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.1906454965630076`, 0.16635597701688987`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.7488929125685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1660816520797815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38062504792134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.20633797071547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29023142231384175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "D1", 
             Association[1 -> {
                Complex[93.7488929125685, 0.1660816520797815], 
                Complex[119.93165197047354`, -20.38062504792134]}, 2 -> {
                Complex[123.20633797071547`, -0.29023142231384175`], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.0247154718802847`, 0.16372940890664367`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.0921335451172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17036303260019042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868973`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.8572544895749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2949911695233682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "D1", 
             Association[1 -> {
                Complex[94.0921335451172, 0.17036303260019042`], 
                Complex[120.26188344631822`, -20.378020317868973`]}, 2 -> {
                Complex[122.8572544895749, -0.2949911695233682], 
                Complex[147.58883643153152`, -21.020327691813247`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.862707617193678, 0.16105016812593043`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.43142355281749`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17485814579116116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.51238460788528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29994309504690664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D1", 
             Association[1 -> {
                Complex[94.43142355281749, 0.17485814579116116`], 
                Complex[120.58795576067415`, -20.37524552516941]}, 2 -> {
                Complex[122.51238460788528`, -0.29994309504690664`], 
                Complex[147.25482551280476`, -21.023135337553146`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.7045800944174516`, 0.1583158254747321}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.76756190715511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17958662591578023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.17090524770384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.02610724189721`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "D1", 
             Association[1 -> {
                Complex[94.76756190715511, 0.17958662591578023`], 
                Complex[120.91065734905382`, -20.372283703951]}, 2 -> {
                Complex[122.17090524770384`, -0.3051088017421774], 
                Complex[146.9244353952348, -21.02610724189721]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.5502998985781034`, 0.15552370379195501`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.10128008303968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.83206414688705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.029264374337636`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D1", 
             Association[1 -> {
                Complex[95.10128008303968, 0.18457057958645495`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[121.83206414688705`, -0.310512094378606], 
                Complex[146.59692493347416`, -21.029264374337636`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.399842172560554, 0.1526708487010957}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.43325926680586`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18983503235951749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.49516205240121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3161794749411265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.032630053042638`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "D1", 
             Association[1 -> {
                Complex[95.43325926680586, 0.18983503235951749`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[121.49516205240121`, -0.3161794749411265], 
                Complex[146.27160715472138`, -21.032630053042638`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.253189703613188, 0.14975399350120888`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.76414468301044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1954084700848576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.1595379262064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D1", 
             Association[1 -> {
                Complex[95.76414468301044, 0.1954084700848576], 
                Complex[121.86549419514678`, -20.36207123551036]}, 2 -> {
                Complex[121.1595379262064, -0.3221407220109502], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.110332573615594, 0.14676951702942276`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.09455795990824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20132350187324985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.82455621031696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32842958380826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D1", 
             Association[1 -> {
                Complex[96.09455795990824, 0.20132350187324985`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[120.82455621031696`, -0.32842958380826], 
                Complex[145.62498679915493`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.9712679444441932`, 0.1437133929558403}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.42510823906633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20761768000812972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.353897728681492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.48959542170805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "D1", 
             Association[1 -> {
                Complex[96.42510823906633, 0.20761768000812972`], 
                Complex[122.49728704083137`, -20.353897728681492`]}, 2 -> {
                Complex[120.48959542170805`, -0.33508462216302504`], 
                Complex[145.30245899607772`, -21.044258615727983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.835999967117246, 0.14058112849641802`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.75640260391667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2143345239863567`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509227`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.15403748497943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.97965180707178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.048759510069544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D1", 
             Association[1 -> {
                Complex[96.75640260391667, 0.2143345239863567], 
                Complex[122.81354255509227`, -20.34930172067202]}, 2 -> {
                Complex[120.15403748497943`, -0.3421502560032759], 
                Complex[144.97965180707178`, -21.048759510069544`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.7045398095899174`, 0.1373676898941234}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.08905633219275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22152481262236726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.81725728511483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D1", 
             Association[1 -> {
                Complex[97.08905633219275, 0.22152481262236726`], 
                Complex[123.13082758939967`, -20.34430875145043]}, 2 -> {
                Complex[119.81725728511483`, -0.3496780693287915], 
                Complex[144.65596103805998`, -21.053643624569474`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.5769058037275556`, 0.13406741115674414`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.42370345629718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22924823209533163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.44975239734681`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.47861194680793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D1", 
             Association[1 -> {
                Complex[97.42370345629718, 0.22924823209533163`], 
                Complex[123.44975239734681`, -20.33886609255275]}, 2 -> {
                Complex[119.47861194680793`, -0.35772847232067834`], 
                Complex[144.33076734108207`, -21.058964486412613`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.453123717644118, 0.13067388134875202`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.7610081399128`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790742`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.13742932488076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.366372838776836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.00342515949336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.064785490731847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D1", 
             Association[1 -> {
                Complex[97.7610081399128, 0.23757550254713045`], 
                Complex[123.77095431790742`, -20.332911072573207`]}, 2 -> {
                Complex[119.13742932488076`, -0.366372838776836], 
                Complex[144.00342515949336`, -21.064785490731847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.3332271657881734`, 0.12717980406095108`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.10167745184768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2465911570399597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.7929951193337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37569629412710553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.07118244376477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "D1", 
             Association[1 -> {
                Complex[98.10167745184768, 0.2465911570399597], 
                Complex[124.09510998319794`, -20.32636854350558]}, 2 -> {
                Complex[118.7929951193337, -0.37569629412710553`], 
                Complex[143.6732504076637, -21.07118244376477]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.217258176499584, 0.12357682029059447`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.44647625015428`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.44453789776165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3858014050647708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.3395062014875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.07824693369923`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "D1", 
             Association[1 -> {
                Complex[98.44647625015428, 0.2563972235666608], 
                Complex[124.42294949324783`, -20.319147517903787`]}, 2 -> {
                Complex[118.44453789776165`, -0.3858014050647708], 
                Complex[143.3395062014875, -21.07824693369923]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.1052679460279506`, 0.11985528248170496`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.79624510214889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.311136636747282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.09121109621549`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39681313957995207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "D1", 
             Association[1 -> {
                Complex[98.79624510214889, 0.26711817863125653`], 
                Complex[124.7552734369329, -20.311136636747282`]}, 2 -> {
                Complex[118.09121109621549`, -0.39681313957995207`], 
                Complex[143.00138575722926`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.9973178203207596, 0.11600396230100252`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.15192249564048`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27890772560984034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.30219795679849`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.73207074060755`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4088856508160151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.094852699839524`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D1", 
             Association[1 -> {
                Complex[99.15192249564048, 0.27890772560984034`], 
                Complex[125.09297394908009`, -20.30219795679849]}, 2 -> {
                Complex[117.73207074060755`, -0.4088856508160151], 
                Complex[142.6579912660793, -21.094852699839524`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.8934805628971247, 0.11200966686181069`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.514573105033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29195824799683273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.36604712293936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42221173502136283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D1", 
             Association[1 -> {
                Complex[99.514573105033, 0.29195824799683273`], 
                Complex[125.43706147399149`, -20.29215827088692]}, 2 -> {
                Complex[117.36604712293936`, -0.42221173502136283`], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.7938419914153911, 0.10785672585827655`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.88542466730593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3065142785572326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.7886996540862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.280796718741154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.99190787569995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475136285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.1158723502883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "D1", 
             Association[1 -> {
                Complex[99.88542466730593, 0.3065142785572326], 
                Complex[125.7886996540862, -20.280796718741154`]}, 2 -> {
                Complex[116.99190787569995`, -0.43703630475136285`], 
                Complex[141.95116473317964`, -21.1158723502883]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.6985031012682299, 0.10352629244348677`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.26591727728177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.60820863370117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45367605639991937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D1", 
             Association[1 -> {
                Complex[100.26591727728177`, 0.32289216335652743`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[116.60820863370117`, -0.45367605639991937`], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.6075828486224282, 0.0989953682178939}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.65777094806738`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34150958252322516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.2132254363857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4725489940033503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "D1", 
             Association[1 -> {
                Complex[100.65777094806738`, 0.34150958252322516`], 
                Complex[126.52034552601546`, -20.252868457449622`]}, 2 -> {
                Complex[116.2132254363857, -0.4725489940033503], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.521221849658204, 0.0942354069932918}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.06308068349807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3629313245006878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.80485962290086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614478673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D1", 
             Association[1 -> {
                Complex[101.06308068349807`, 0.3629313245006878], 
                Complex[126.90396116486052`, -20.235407072598086`]}, 2 -> {
                Complex[115.80485962290086`, -0.49422020614478673`], 
                Complex[140.81990311379658`, -21.160625877708522`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.43958738849867984`, 0.08921025233040503}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.48445417285807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.38050010894172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.181081480488864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D1", 
             Association[1 -> {
                Complex[101.48445417285807`, 0.3879430012901771], 
                Complex[127.30256352822093`, -20.214723835180756`]}, 2 -> {
                Complex[115.38050010894172`, -0.5194755835198392], 
                Complex[140.41612546346295`, -21.181081480488864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.3628803523328088, 0.08387297650391368}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.92521768180029`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41767521438799576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.7192960348708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.18978114508657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.93681747084511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.549445986914998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.99429101812663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2057892537521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "D1", 
             Association[1 -> {
                Complex[101.92521768180029`, 0.41767521438799576`], 
                Complex[127.7192960348708, -20.18978114508657]}, 2 -> {
                Complex[114.93681747084511`, -0.549445986914998], 
                Complex[139.99429101812663`, -21.2057892537521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.2913451025024898, 0.07816081527476726}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.38973504769774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4538243260356928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.46944492820539`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5858280202580782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.236311334493806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D1", 
             Association[1 -> {
                Complex[102.38973504769774`, 0.4538243260356928], 
                Complex[128.15828301502808`, -20.159017144377533`]}, 2 -> {
                Complex[114.46944492820539`, -0.5858280202580782], 
                Complex[139.55027237651973`, -21.236311334493806`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.2252839892092453, 0.07198659525592888}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.883921441729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829307003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.97246456229634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.631303461284326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578064`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "D1", 
             Association[1 -> {
                Complex[102.883921441729, 0.49907188829307003`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[113.97246456229634`, -0.631303461284326], 
                Complex[139.07847426814035`, -21.27512497578064]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.1650795054641776, 0.06522319508245289}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.41610339254098`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.12767489010264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.43754727510904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.57101671236563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.326430796181967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "D1", 
             Association[1 -> {
                Complex[103.41610339254098`, 0.5579501377609489], 
                Complex[129.12767489010264`, -20.068393863077308`]}, 2 -> {
                Complex[113.43754727510904`, -0.6904047576732153], 
                Complex[138.57101671236563`, -21.326430796181967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.11122942849407025`, 0.05767278866942149}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.99849290966137`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041314329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.67752337597602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.99655438623809`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.85247865053964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368577013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.01633089208286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.39800884938102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "D1", 
             Association[1 -> {
                Complex[103.99849290966137`, 0.6388251041314329], 
                Complex[129.67752337597602`, -19.99655438623809]}, 2 -> {
                Complex[112.85247865053964`, -0.7714981368577013], 
                Complex[138.01633089208286`, -21.39800884938102]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.06440378728204621, 0.04899855821403065}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.6495564695593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7590828537974087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.888210869228352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.19878995458203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8919698507578182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.39688673641334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.506084894187065`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D1", 
             Association[1 -> {
                Complex[104.6495564695593, 0.7590828537974087], 
                Complex[130.2921900311733, -19.888210869228352`]}, 2 -> {
                Complex[112.19878995458203`, -0.8919698507578182], 
                Complex[137.39688673641334`, -21.506084894187065`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.025528397795653746`, 0.038549307221140694`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.3953422129245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9608435417074137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.703899841697414`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.45043092574376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939402286419335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.690122605628147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D1", 
             Association[1 -> {
                Complex[105.3953422129245, 0.9608435417074137], 
                Complex[130.99653808272228`, -19.703899841697414`]}, 2 -> {
                Complex[111.45043092574376`, -1.0939402286419335`], 
                Complex[136.68781879291285`, -21.690122605628147`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.878952410602958, 0.3095668961605609}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"142.43088738729756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12083732434029751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.91042443664614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23233632108243843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "C1", 
             Association[1 -> {
                Complex[142.43088738729756`, 0.12083732434029751`], 
                Complex[113.66233957629902`, -20.405968816918097`]}, 2 -> {
                Complex[184.91042443664614`, -0.23233632108243843`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.64146660608642, 0.30753238028317376`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.20317083740102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12356070149773071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40448191262516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.11415381173683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2370153809705939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "C1", 
             Association[1 -> {
                Complex[143.20317083740102`, 0.12356070149773071`], 
                Complex[114.42383835786643`, -20.40448191262516]}, 2 -> {
                Complex[184.11415381173683`, -0.2370153809705939], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.412060946328717, 0.3054571643933526}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.8418943485418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"183.45688521121167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24124640092127728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.94915336254542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "C1", 
             Association[1 -> {
                Complex[143.8418943485418, 0.1262779516956982], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[183.45688521121167`, -0.24124640092127728`], 
                Complex[152.94915336254542`, -20.990786350067847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-5.189560380943897, 0.30334293223370046`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.403599085715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12903424492994017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.60228208527523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40155927983009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.87977924699527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2452608701483842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.38052772522323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.993153001298854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "C1", 
             Association[1 -> {
                Complex[144.403599085715, 0.12903424492994017`], 
                Complex[115.60228208527523`, -20.40155927983009]}, 2 -> {
                Complex[182.87977924699527`, -0.2452608701483842], 
                Complex[152.38052772522323`, -20.993153001298854`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.973234933353064, 0.30119028696377703`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.91401586419227`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1318524872647501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40005566427453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.3560651176949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24916606948640838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.8654584893039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99537613618962`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "C1", 
             Association[1 -> {
                Complex[144.91401586419227`, 0.1318524872647501], 
                Complex[116.10150054551087`, -20.40005566427453]}, 2 -> {
                Complex[182.3560651176949, -0.24916606948640838`], 
                Complex[151.8654584893039, -20.99537613618962]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.76257821672308, 0.29899926286102185`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.38744700905215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13474786473651384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398501738168576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.8708660927008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.253023818602633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.38906785583268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.99751794736914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "C1", 
             Association[1 -> {
                Complex[145.38744700905215`, 0.13474786473651384`], 
                Complex[116.56359372447044`, -20.398501738168576`]}, 2 -> {
                Complex[181.8708660927008, -0.253023818602633], 
                Complex[151.38906785583268`, -20.99751794736914]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.557215499640472, 0.29676953219523994`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.8328296140851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614972086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.99749565640013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.396886329795848`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.41488879760732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "C1", 
             Association[1 -> {
                Complex[145.8328296140851, 0.13773233614972086`], 
                Complex[116.99749565640013`, -20.396886329795848`]}, 2 -> {
                Complex[181.41488879760732`, -0.25687501967431686`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.356857545618846, 0.2945005047626361}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.25620289167148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.4092417408274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.395199814614813`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.9818553690836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.260749635653941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "C1", 
             Association[1 -> {
                Complex[146.25620289167148`, 0.14081646542056195`], 
                Complex[117.4092417408274, -20.395199814614813`]}, 2 -> {
                Complex[180.9818553690836, -0.260749635653941], 
                Complex[150.51816845485817`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-4.161274521916988, 0.29219138022483704`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.661886117449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173267872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39343319988049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.56727763237527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467147267101754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.1128985493347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "C1", 
             Association[1 -> {
                Complex[146.661886117449, 0.14401032173267872`], 
                Complex[117.80314680030489`, -20.39343319988049]}, 2 -> {
                Complex[180.56727763237527`, -0.26467147267101754`], 
                Complex[150.1128985493347, -21.00381247852693]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.970279996108838, 0.28984117639838103`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.0531060212139`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14732399476906763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.1678042677887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2686607590279984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.005946943311322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "C1", 
             Association[1 -> {
                Complex[147.0531060212139, 0.14732399476906763`], 
                Complex[118.18243252444688`, -20.391577604746043`]}, 2 -> {
                Complex[180.1678042677887, -0.2686607590279984], 
                Complex[149.72290589550488`, -21.005946943311322`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.7837205142229444`, 0.28744874380374674`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.43235893759334`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15076793497771634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.5495896388172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38962392181051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.78084401215676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27273567401803595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "C1", 
             Association[1 -> {
                Complex[147.43235893759334`, 0.15076793497771634`], 
                Complex[118.5495896388172, -20.38962392181051]}, 2 -> {
                Complex[179.78084401215676`, -0.27273567401803595`], 
                Complex[149.34560377406765`, -21.008130280727748`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.601468497370855, 0.2850127715320434}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.80163324655834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1543532116698063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.4043342501828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2769133339514044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "C1", 
             Association[1 -> {
                Complex[147.80163324655834`, 0.1543532116698063], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[179.4043342501828, -0.2769133339514044], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.423417225668198, 0.2825317870631865}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.16255297815067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1580917352471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.0365916440714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2812104825190737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "C1", 
             Association[1 -> {
                Complex[148.16255297815067`, 0.1580917352471046], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[179.0365916440714, -0.2812104825190737], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.249477196497191, 0.28000415143466006`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.51647442884564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16199646966552844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38307483942267`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.67621165990886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.27106658294744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01513037357346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "C1", 
             Association[1 -> {
                Complex[148.51647442884564`, 0.16199646966552844`], 
                Complex[119.59638315362788`, -20.38307483942267]}, 2 -> {
                Complex[178.67621165990886`, -0.2856440165404518], 
                Complex[148.27106658294744`, -21.01513037357346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-3.07957342310902, 0.27742805047084906`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.8645535018631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16608165207978046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.380625047921345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.3219985600101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2902314223138406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "C1", 
             Association[1 -> {
                Complex[148.8645535018631, 0.16608165207978046`], 
                Complex[119.93165197047352`, -20.380625047921345`]}, 2 -> {
                Complex[178.3219985600101, -0.2902314223138406], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.913643398426269, 0.27480148236060464`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.2077941344118`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1703630326001896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868977`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.97291507886953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2949911695233655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "C1", 
             Association[1 -> {
                Complex[149.2077941344118, 0.1703630326001896], 
                Complex[120.26188344631822`, -20.378020317868977`]}, 2 -> {
                Complex[177.97291507886953`, -0.2949911695233655], 
                Complex[147.58883643153155`, -21.020327691813243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.7516355437397473`, 0.27212224157988607`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.54708414211208`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1748581457911621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067412`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.62804519717992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2999430950469064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280479`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "C1", 
             Association[1 -> {
                Complex[149.54708414211208`, 0.1748581457911621], 
                Complex[120.58795576067412`, -20.37524552516941]}, 2 -> {
                Complex[177.62804519717992`, -0.2999430950469064], 
                Complex[147.25482551280479`, -21.023135337553143`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.5935080209634926`, 0.269387898928686}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.88322249644975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17958662591578034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.28656583699845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.026107241897208`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "C1", 
             Association[1 -> {
                Complex[149.88322249644975`, 0.17958662591578034`], 
                Complex[120.91065734905384`, -20.372283703951]}, 2 -> {
                Complex[177.28656583699845`, -0.3051088017421759], 
                Complex[146.9244353952348, -21.026107241897208`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.43922782512413, 0.266595777245916}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.2169406723343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.94772473618167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02926437433764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "C1", 
             Association[1 -> {
                Complex[150.2169406723343, 0.18457057958645484`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[176.94772473618167`, -0.310512094378605], 
                Complex[146.59692493347418`, -21.02926437433764]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.2887700991065807`, 0.2637429221550531}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.54891985610047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18983503235951585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.6108226416958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3161794749411295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03263005304264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "C1", 
             Association[1 -> {
                Complex[150.54891985610047`, 0.18983503235951585`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[176.6108226416958, -0.3161794749411295], 
                Complex[146.27160715472132`, -21.03263005304264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-2.142117630159215, 0.2608260669551734}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.87980527230502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1954084700848582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.275198515501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "C1", 
             Association[1 -> {
                Complex[150.87980527230502`, 0.1954084700848582], 
                Complex[121.86549419514674`, -20.36207123551036]}, 2 -> {
                Complex[176.275198515501, -0.3221407220109508], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.9992605001616204`, 0.2578415904833784}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.21021854920286`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20132350187325002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.9402167996116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3284295838082578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "C1", 
             Association[1 -> {
                Complex[151.21021854920286`, 0.20132350187325002`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[175.9402167996116, -0.3284295838082578], 
                Complex[145.62498679915495`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.8601958709902482`, 0.25478546640979594`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.54076882836094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20761768000812997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.35389772868149`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.60525601100267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727987`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "C1", 
             Association[1 -> {
                Complex[151.54076882836094`, 0.20761768000812997`], 
                Complex[122.49728704083137`, -20.35389772868149]}, 2 -> {
                Complex[175.60525601100267`, -0.33508462216302626`], 
                Complex[145.30245899607772`, -21.044258615727987`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.7249278936632726`, 0.2516532019503843}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.87206319321126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21433452398635636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.26969807427406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.9796518070718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.048759510069537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "C1", 
             Association[1 -> {
                Complex[151.87206319321126`, 0.21433452398635636`], 
                Complex[122.81354255509225`, -20.34930172067202]}, 2 -> {
                Complex[175.26969807427406`, -0.3421502560032738], 
                Complex[144.9796518070718, -21.048759510069537`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.5934677361359724`, 0.24843976334808612`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.20471692148735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22152481262236687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.93291787440944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "C1", 
             Association[1 -> {
                Complex[152.20471692148735`, 0.22152481262236687`], 
                Complex[123.13082758939966`, -20.34430875145043]}, 2 -> {
                Complex[174.93291787440944`, -0.3496780693287902], 
                Complex[144.65596103805998`, -21.053643624569467`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.4658337302736248`, 0.2451394846106962}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.53936404559178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22924823209533307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.4497523973468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.59427253610252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412606`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "C1", 
             Association[1 -> {
                Complex[152.53936404559178`, 0.22924823209533307`], 
                Complex[123.4497523973468, -20.33886609255275]}, 2 -> {
                Complex[174.59427253610252`, -0.35772847232067345`], 
                Complex[144.33076734108204`, -21.058964486412606`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.3420516441901162`, 0.24174595480270764`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.8766687292074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790741`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.25308991417538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36637283877683763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.0034251594934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.064785490731843`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "C1", 
             Association[1 -> {
                Complex[152.8766687292074, 0.23757550254713042`], 
                Complex[123.77095431790741`, -20.332911072573204`]}, 2 -> {
                Complex[174.25308991417538`, -0.36637283877683763`], 
                Complex[144.0034251594934, -21.064785490731843`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.2221550923342142`, 0.23825187751490493`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.2173380411423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24659115703995835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.90865570862832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37569629412710687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.071182443764766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "C1", 
             Association[1 -> {
                Complex[153.2173380411423, 0.24659115703995835`], 
                Complex[124.09510998319796`, -20.32636854350558]}, 2 -> {
                Complex[173.90865570862832`, -0.37569629412710687`], 
                Complex[143.6732504076637, -21.071182443764766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-1.1061861030455822`, 0.23464889374455364`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.5621368394489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.56019848705628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38580140506476973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.33950620148752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078246933699234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "C1", 
             Association[1 -> {
                Complex[153.5621368394489, 0.2563972235666605], 
                Complex[124.42294949324784`, -20.319147517903783`]}, 2 -> {
                Complex[173.56019848705628`, -0.38580140506476973`], 
                Complex[143.33950620148752`, -21.078246933699234`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.9941958725740057, 0.23092735593566946`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.9119056914435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31113663674728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.2068716855101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3968131395799549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "C1", 
             Association[1 -> {
                Complex[153.9119056914435, 0.26711817863125764`], 
                Complex[124.7552734369329, -20.31113663674728]}, 2 -> {
                Complex[173.2068716855101, -0.3968131395799549], 
                Complex[143.00138575722923`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.8862457468667861, 0.22707603575496169`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.26758308493513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27890772560985055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.302197956798476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.84773132990216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40888565081601425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.09485269983952`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "C1", 
             Association[1 -> {
                Complex[154.26758308493513`, 0.27890772560985055`], 
                Complex[125.09297394908012`, -20.302197956798476`]}, 2 -> {
                Complex[172.84773132990216`, -0.40888565081601425`], 
                Complex[142.6579912660793, -21.09485269983952]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.7824084894431798, 0.2230817403157823}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.6302336943276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2919582479968343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.481707712234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4222117350213626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "C1", 
             Association[1 -> {
                Complex[154.6302336943276, 0.2919582479968343], 
                Complex[125.43706147399148`, -20.29215827088692]}, 2 -> {
                Complex[172.481707712234, -0.4222117350213626], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.6827699179614177, 0.21892879931224105`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.00108525660056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30651427855723345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.78869965408623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.28079671874115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.10756846499456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475135913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.115872350288292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "C1", 
             Association[1 -> {
                Complex[155.00108525660056`, 0.30651427855723345`], 
                Complex[125.78869965408623`, -20.28079671874115]}, 2 -> {
                Complex[172.10756846499456`, -0.43703630475135913`], 
                Complex[141.95116473317964`, -21.115872350288292`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.5874310278142849, 0.2145983658974477}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.38157786657638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.72386922299577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4536760563999232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "C1", 
             Association[1 -> {
                Complex[155.38157786657638`, 0.32289216335652754`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[171.72386922299577`, -0.4536760563999232], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.4965107751684406, 0.21006744167185484`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.773431537362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34150958252322494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.32888602568033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47254899400334877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "C1", 
             Association[1 -> {
                Complex[155.773431537362, 0.34150958252322494`], 
                Complex[126.52034552601548`, -20.252868457449622`]}, 2 -> {
                Complex[171.32888602568033`, -0.47254899400334877`], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.4101497762042306, 0.20530748044725275`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.1787412727927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3629313245006883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.92052021219553`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614487433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "C1", 
             Association[1 -> {
                Complex[156.1787412727927, 0.3629313245006883], 
                Complex[126.90396116486053`, -20.235407072598086`]}, 2 -> {
                Complex[170.92052021219553`, -0.49422020614487433`], 
                Complex[140.81990311379664`, -21.160625877708604`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{-0.32851531504476333`, 0.20028232578436597`}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.60011476215269`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.49616069823637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.18108148048887`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "C1", 
             Association[1 -> {
                Complex[156.60011476215269`, 0.3879430012901607], 
                Complex[127.30256352822093`, -20.214723835180777`]}, 2 -> {
                Complex[170.49616069823637`, -0.5194755835198454], 
                Complex[140.41612546346298`, -21.18108148048887]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{-0.25180827887884966`, 0.19494504995786752`}],
            
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.0408782710949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4176752143879963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.71929603487078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.189781145086567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.05247806013978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5494459869149929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.9942910181267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.205789253752098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "C1", 
             Association[1 -> {
                Complex[157.0408782710949, 0.4176752143879963], 
                Complex[127.71929603487078`, -20.189781145086567`]}, 2 -> {
                Complex[170.05247806013978`, -0.5494459869149929], 
                Complex[139.9942910181267, -21.205789253752098`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{-0.18027302904848802`, 0.18923288872871577`}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.5053956369925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45382432603574024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.5851055175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5858280202580739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2363113344938`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "C1", 
             Association[1 -> {
                Complex[157.5053956369925, 0.45382432603574024`], 
                Complex[128.15828301502822`, -20.159017144377493`]}, 2 -> {
                Complex[169.5851055175, -0.5858280202580739], 
                Complex[139.55027237651973`, -21.2363113344938]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{-0.11421191575524352`, 0.18305866870989515`}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.9995820310236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829306903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.08812515159096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6313034612843315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "C1", 
             Association[1 -> {
                Complex[157.9995820310236, 0.49907188829306903`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[169.08812515159096`, -0.6313034612843315], 
                Complex[139.07847426814035`, -21.27512497578065]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.054007432010190023`, 0.1762952685364085}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"158.53176398183555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.1276748901026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"168.55320786440365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.5710167123656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32643079618197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "C1", 
             Association[1 -> {
                Complex[158.53176398183555`, 0.5579501377609449], 
                Complex[129.1276748901026, -20.068393863077308`]}, 2 -> {
                Complex[168.55320786440365`, -0.6904047576732164], 
                Complex[138.5710167123656, -21.32643079618197]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{-0.00015735504009688206`, 0.1687448621233931}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.11415349895574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041312677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.6775233759758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.99655438623824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.96813923983427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368576926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.0163308920829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.39800884938101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "C1", 
             Association[1 -> {
                Complex[159.11415349895574`, 0.6388251041312677], 
                Complex[129.6775233759758, -19.99655438623824]}, 2 -> {
                Complex[167.96813923983427`, -0.7714981368576926], 
                Complex[138.0163308920829, -21.39800884938101]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.046668286171898735`, 0.16007063166798982`}],
            
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.76521705885392`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.759082853797409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.88821086922835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.3144505438764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8919698507580937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.3968867364131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.506084894187325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "C1", 
             Association[1 -> {
                Complex[159.76521705885392`, 0.759082853797409], 
                Complex[130.2921900311733, -19.88821086922835]}, 2 -> {
                Complex[167.3144505438764, -0.8919698507580937], 
                Complex[137.3968867364131, -21.506084894187325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.08554367565830541, 0.1496213806751052}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"160.51100280221908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9608435417074076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.70389984169742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"166.5660915150384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939402286417192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291288`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.69012260562795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "C1", 
             Association[1 -> {
                Complex[160.51100280221908`, 0.9608435417074076], 
                Complex[130.99653808272222`, -19.70389984169742]}, 2 -> {
                Complex[166.5660915150384, -1.0939402286417192`], 
                Complex[136.68781879291288`, -21.69012260562795]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.11529495955654108`, 0.13592468298589974`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"161.35610930103817`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.33740874464973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"165.71846158622145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317955`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"135.88391552140592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "C2", 
             Association[1 -> {
                Complex[161.35610930103817`, 1.3569051651311863`], 
                Complex[131.7957769749429, -19.33740874464973]}, 2 -> {
                Complex[165.71846158622145`, -1.4902074317955], 
                Complex[135.88391552140592`, -22.056334735916565`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.13563617310967907`, 0.11581047353076965`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.09763876574996`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0881973270436873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.4998425166415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.6544084566896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.974456667634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2217012177173117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.73905058908342`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "C2", 
             Association[1 -> {
                Complex[162.09763876574996`, 2.0881973270436873`], 
                Complex[132.4998425166415, -18.6544084566896]}, 2 -> {
                Complex[164.974456667634, -2.2217012177173117`], 
                Complex[135.17523913663766`, -22.73905058908342]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.004222886102638768, 0.024852609531938796`}],
            
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.24044871174357`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.337408744649736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.60280099692714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317952845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.88391552140624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "D2", 
             Association[1 -> {
                Complex[106.24044871174357`, 1.3569051651311739`], 
                Complex[131.7957769749429, -19.337408744649736`]}, 2 -> {
                Complex[110.60280099692714`, -1.4902074317952845`], 
                Complex[135.88391552140624`, -22.056334735916362`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.02456409965571993, 0.004738400076814031}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.9819781764553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0881973270436194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.49984251664148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.65440845668966`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.85879607833935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.221701217717411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.739050589083515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "D2", 
             Association[1 -> {
                Complex[106.9819781764553, 2.0881973270436194`], 
                Complex[132.49984251664148`, -18.65440845668966]}, 2 -> {
                Complex[109.85879607833935`, -2.221701217717411], 
                Complex[135.17523913663763`, -22.739050589083515`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.03840065515061042, -0.02460856126720401}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.38113498587141`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.879670752931702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.45721001861465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532400557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D3", 
             Association[1 -> {
                Complex[107.38113498587141`, 2.9142396485109705`], 
                Complex[132.88189718832854`, -17.879670752931702`]}, 2 -> {
                Complex[109.45721001861465`, -3.0479413532400557`], 
                Complex[134.78862529189132`, -23.513498562864495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.04896568389047218, -0.06278983622889456}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.58249764089271`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.0766455744856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.206794013455227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.25346264300121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.7646664040767535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763843963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.186080440963586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D3", 
             Association[1 -> {
                Complex[107.58249764089271`, 3.6307705575763576`], 
                Complex[133.0766455744856, -17.206794013455227`]}, 2 -> {
                Complex[109.25346264300121`, -3.7646664040767535`], 
                Complex[134.58936763843963`, -24.186080440963586`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.05775479066797118, -0.10852408945782877`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.7013662368456`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.244103960587581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.19282273525405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.630699080753942`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.13225227369334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.4687294463477`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"24.76187553625737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D3", 
             Association[1 -> {
                Complex[107.7013662368456, 4.244103960587581], 
                Complex[133.19282273525405`, -16.630699080753942`]}, 2 -> {
                Complex[109.13225227369334`, -4.378190406750104], 
                Complex[134.4687294463477, -24.76187553625737]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.06542583960802517, -0.16079767352941232`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.78057143660814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.05074675004954`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.916047187939773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "D3", 
             Association[1 -> {
                Complex[107.78057143660814`, 4.781773561001174], 
                Complex[133.27102086156967`, -16.125747324937528`]}, 2 -> {
                Complex[109.05074675004954`, -4.916047187939773], 
                Complex[134.38611694252154`, -25.266522626186067`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.07231769091623619, -0.21886623947146333`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.83770870028388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.263174211991336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.67377847042299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.9913491928679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.397631717588795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.71818212660493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "D3", 
             Association[1 -> {
                Complex[107.83770870028388`, 5.263174211991336], 
                Complex[133.3279803002992, -15.67377847042299]}, 2 -> {
                Complex[108.9913491928679, -5.397631717588795], 
                Complex[134.3247882793695, -25.71818212660493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.0786287602027187, -0.2821662303199588}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.88121526668063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.262765801866918`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.94562101739476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.835759112686365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343982`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D3", 
             Association[1 -> {
                Complex[107.88121526668063`, 5.701120919783156], 
                Complex[133.3717561373341, -15.262765801866918`]}, 2 -> {
                Complex[108.94562101739476`, -5.835759112686365], 
                Complex[134.27668694605626`, -26.128880886343982`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.08448623963371915, -0.3502550648029459}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.91564972566658`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40671477584058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.884495531077587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.9090023559344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239169639445858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.23744518508806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.506832820749022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "D3", 
             Association[1 -> {
                Complex[107.91564972566658`, 6.104353845416767], 
                Complex[133.40671477584058`, -14.884495531077587`]}, 2 -> {
                Complex[108.9090023559344, -6.239169639445858], 
                Complex[134.23744518508806`, -26.506832820749022`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.08997717651396897, -0.4227742774174068}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.94370334554677`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.435442200275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.53312652195004`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.87880072587267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "D3", 
             Association[1 -> {
                Complex[107.94370334554677`, 6.479082403584124], 
                Complex[133.435442200275, -14.53312652195004]}, 2 -> {
                Complex[108.87880072587267`, -6.614072812516715], 
                Complex[134.20447572357537`, -26.857879187158495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.09516413681348013, -0.4994262398510507}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.967075449591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.8533156489355`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.965045479528821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.186328668332603`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "D3", 
             Association[1 -> {
                Complex[107.967075449591, 6.829883346826048], 
                Complex[133.45957631720725`, -14.204350207418504`]}, 2 -> {
                Complex[108.8533156489355, -6.965045479528821], 
                Complex[134.17613942808242`, -27.186328668332603`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.10009382995752958`, -0.5799588549360859}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.98689671384345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.160236693505573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.894888445103899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.83141534951223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380921`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.15134199635162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.495459517152923`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D3", 
             Association[1 -> {
                Complex[107.98689671384345`, 7.160236693505573], 
                Complex[133.48021025962268`, -13.894888445103899`]}, 2 -> {
                Complex[108.83141534951223`, -7.295567749380921], 
                Complex[134.15134199635162`, -27.495459517152923`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.10480219673863189`, -0.6641550936214617}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.00395158132416`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273206`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.8123143369035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1293216354845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.78783159598449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.00395158132416`, 7.472858386883563], 
                Complex[133.49810470509104`, -13.602181478273206`]}, 2 -> {
                Complex[108.8123143369035, -7.60835565160761], 
                Complex[134.1293216354845, -27.78783159598449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.10931758018233495`, -0.75182559330948}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.01880316611171`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.324186402581233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.79544849796953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "D3", 
             Association[1 -> {
                Complex[108.01880316611171`, 7.769914966301744], 
                Complex[133.51380733250917`, -13.324186402581233`]}, 2 -> {
                Complex[108.79544849796953`, -7.905575807831236], 
                Complex[134.10952960183627`, -28.065487910230857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.11366279196940354`, -0.8428032649744512}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.03186731148087`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.05316704921159`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.78040103598128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.188988914036557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.330089398863645`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.03186731148087`, 8.05316704921159], 
                Complex[133.52772377923588`, -13.059242375813357`]}, 2 -> {
                Complex[108.78040103598128`, -8.188988914036557], 
                Complex[134.09155924078232`, -28.330089398863645`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.11785650988827001`, -0.936939262937015}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.0434585247249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.324068243739198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175148`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.76685653301915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.460048653363888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.07510189390769`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.583007906385827`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.0434585247249, 8.324068243739198], 
                Complex[133.54016173104085`, -12.805977646175148`]}, 2 -> {
                Complex[108.76685653301915`, -8.460048653363888], 
                Complex[134.07510189390769`, -28.583007906385827`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.12191425279124246`, -1.0340999063351095`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.05381957099668`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.58383520750421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.563243670423079`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.75457135356359`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493511`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.05381957099668`, 8.58383520750421], 
                Complex[133.55135937730103`, -12.563243670423079`]}, 2 -> {
                Complex[108.75457135356359`, -8.719971755138769], 
                Complex[134.05991844116494`, -28.82539206493511]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1258490791060467, -1.1341642824443934`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.0631411673518`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.833498461149432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.74335394807592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.0631411673518, 8.833498461149432], 
                Complex[133.56150438018216`, -12.330067310220024`]}, 2 -> {
                Complex[108.74335394807592`, -8.96978880859594], 
                Complex[134.04582032924358`, -29.058215098144675`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.12967209889427522`, -1.237022349572614}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.07157546049427`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.07394002099248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863516`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.105615415604044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.73305137305235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0326565653045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.282310237876374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "D3", 
             Association[1 -> {
                Complex[108.07157546049427`, 9.07394002099248], 
                Complex[133.57074687863516`, -12.105615415604044`]}, 2 -> {
                Complex[108.73305137305235`, -9.210381895712354], 
                Complex[134.0326565653045, -29.282310237876374`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1333928568022884, -1.3425734132744047`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.07924547805123`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503111`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.72353983770584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.442512981808122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.02030458027298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "D3", 
             Association[1 -> {
                Complex[108.07924547805123`, 9.305921789460674], 
                Complex[133.57920862299494`, -11.889168097503111`]}, 2 -> {
                Complex[108.72353983770584`, -9.442512981808122], 
                Complex[134.02030458027298`, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.13701962353238173`, -1.4507248864640783`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.08625189994662`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034468`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.71471793069901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "D3", 
             Association[1 -> {
                Complex[108.08625189994662`, 9.530107327827563], 
                Complex[133.58698953054267`, -11.680098224034468`]}, 2 -> {
                Complex[108.71471793069901`, -9.666845688440555], 
                Complex[134.00866367132147`, -29.707103947727518`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.14055962116682963`, -1.5613912688152602`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09267800281762`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.70650167396278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.88396223817544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.90898013440613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.09267800281762`, 9.747078800841289], 
                Complex[133.59417248038324`, -11.477855458956304`]}, 2 -> {
                Complex[108.70650167396278`, -9.88396223817544], 
                Complex[133.99765020516938`, -29.90898013440613]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.14401919979289346`, -1.6744932979244869`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09859333213129`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.957350339052214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224437`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.69882084894036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.094376817050051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.10451221302891`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.09859333213129`, 9.957350339052214], 
                Complex[133.60082688045318`, -11.281953671224437`]}, 2 -> {
                Complex[108.69882084894036`, -10.094376817050051`], 
                Complex[133.9871940493811, -30.10451221302891]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1474039776890379, -1.7899572367170542`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.10405647120578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60701136175388`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.091960884780205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.69161622603707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.29854623837406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9772358765518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.294132227130056`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "D3", 
             Association[1 -> {
                Complex[108.10405647120578`, 10.161378702488461`], 
                Complex[133.60701136175388`, -11.091960884780205`]}, 2 -> {
                Complex[108.69161622603707`, -10.29854623837406], 
                Complex[133.9772358765518, -30.294132227130056`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.15071895384997447`, -1.907714270156859}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.10911715811447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.359571883156988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.90749116899828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.68483744629073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.496878545347792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.96772509969583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.10911715811447`, 10.359571883156988`], 
                Complex[133.61277584148843`, -10.90749116899828]}, 2 -> {
                Complex[108.68483744629073`, -10.496878545347792`], 
                Complex[133.96772509969583`, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.15396859923393436`, -2.027699990559107}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.11381792433696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.55229611340583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.67844138138928`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.689740019533177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878897`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "D3", 
             Association[1 -> {
                Complex[108.11381792433696`, 10.55229611340583], 
                Complex[133.6181631227231, -10.728198030417946`]}, 2 -> {
                Complex[108.67844138138928`, -10.689740019533177`], 
                Complex[133.9586182712075, -30.657140604878897`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.15715693144747434`, -2.149853955406389}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.11819537768511`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.553768979221006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6723908495012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.11819537768511`, 10.739881627157581`], 
                Complex[133.62321014884253`, -10.553768979221006`]}, 2 -> {
                Complex[108.6723908495012, -10.877460942190025`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.16028757639591618`, -2.2741193050083286`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12228121721019`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6279489975554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.383921024629737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.66665359920384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.00065163185658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.12228121721019`, 10.922627435195428`], 
                Complex[133.6279489975554, -10.383921024629737`]}, 2 -> {
                Complex[108.66665359920384`, -11.060340369657368`], 
                Complex[133.94147109188316`, -31.00065163185658]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.16336381957390245`, -2.400442429949022}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12610304377894`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.100805313420322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6324076760703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.218396911961497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.66120149781838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.238650121699813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.165788586540444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.12610304377894`, 11.100805313420322`], 
                Complex[133.6324076760703, -10.218396911961497`]}, 2 -> {
                Complex[108.66120149781838`, -11.238650121699813`], 
                Complex[133.93336948207866`, -31.165788586540444`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.16638864904527395`, -2.5287726802605572`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12968501316938`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.274663157243602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.056961957121118`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.65600987729266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.32683367761164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.12968501316938`, 11.274663157243602`], 
                Complex[133.6366107628227, -10.056961957121118`]}, 2 -> {
                Complex[108.65600987729266`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.32683367761164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.16936479169851282`, -2.6590621098032443`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13304836657493`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.444427821247727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.899401366335299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.65105700273918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.582531307820613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91798402862457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.48400175150009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "D3", 
             Association[1 -> {
                Complex[108.13304836657493`, 11.444427821247727`], 
                Complex[133.64057992958777`, -9.899401366335299]}, 2 -> {
                Complex[108.65105700273918`, -11.582531307820613`], 
                Complex[133.91798402862457`, -31.48400175150009]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.17229474402083156`, -2.7912652505388955`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13621186478589`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.61030753764554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028418`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.64632363735394`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "D3", 
             Association[1 -> {
                Complex[108.13621186478589`, 11.61030753764554], 
                Complex[133.64433436948315`, -9.745517953028418]}, 2 -> {
                Complex[108.64632363735394`, -11.748537908691581`], 
                Complex[133.91065826653704`, -31.637490045704617`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.17518079836884226`, -2.9253389123337055`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13919214603666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.772493987613071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.64179268372514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.910849657658387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "D3", 
             Association[1 -> {
                Complex[108.13919214603666`, 11.772493987613071`], 
                Complex[133.64789115029092`, -9.595130182053303]}, 2 -> {
                Complex[108.64179268372514`, -11.910849657658387`], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.17802506551518604`, -3.0612420046830593`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14200402286717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.93116408463893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6374488861765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.069643504773634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.934139663861124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.14200402286717`, 11.93116408463893], 
                Complex[133.65126550803504`, -9.448070485548417]}, 2 -> {
                Complex[108.6374488861765, -12.069643504773634`], 
                Complex[133.89665253982204`, -31.934139663861124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.18082949409705407`, -3.198935377355994}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14466072990164`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581651`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6332785822411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.22508317408877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.077623707476064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.14466072990164`, 12.086481517469753`], 
                Complex[133.65447109241086`, -9.304183805581651]}, 2 -> {
                Complex[108.6332785822411, -12.22508317408877], 
                Complex[133.88994274008317`, -32.077623707476064`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1835958874695507, -3.338381677446076}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14717413184216`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.62926949396352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803171`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "D3", 
             Association[1 -> {
                Complex[108.14717413184216`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[108.62926949396352`, -12.377320504803171`], 
                Complex[133.8834108897335, -32.21807613513112]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.18632591837581458`, -3.479545220712744}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.149554899004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437188`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.62541055170084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "D3", 
             Association[1 -> {
                Complex[108.149554899004, 12.387654897960454`], 
                Complex[133.66042381437188`, -9.025364372558764]}, 2 -> {
                Complex[108.62541055170084`, -12.526496621998469`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.18902114176913187`, -3.6223918754222098`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15181265620579`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.533783342972374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.89017343085747`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6216917446064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.67274296276216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.15181265620579`, 12.533783342972374`], 
                Complex[133.6631920229149, -8.89017343085747]}, 2 -> {
                Complex[108.6216917446064, -12.67274296276216], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.19168300606327193`, -3.766888957164678}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15395610965969`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6181039931489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.15395610965969`, 12.677106047334805`], 
                Complex[133.66583387467648`, -8.757637305564261]}, 2 -> {
                Complex[108.6181039931489, -12.816182179005445`], 
                Complex[133.86477325877706`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.19431286304055106`, -3.9130051333460614`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15599315559707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.81773764516678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678282`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6146390399284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.956928934660262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.15599315559707`, 12.81773764516678], 
                Complex[133.66835762313934`, -8.627647360678282]}, 2 -> {
                Complex[108.6146390399284, -12.956928934660262`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.19691197660773696`, -4.060710336236788}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15793097365344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.50010185305129`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.61128935576417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.095090612015015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "D3", 
             Association[1 -> {
                Complex[108.15793097365344`, 12.955785489901633`], 
                Complex[133.67077079273932`, -8.50010185305129]}, 2 -> {
                Complex[108.61128935576417`, -13.095090612015015`], 
                Complex[133.8530533114799, -32.87924061335593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.19948153055963758`, -4.209975683614427}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15977610747193`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.60804805859196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.00401845710657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.15977610747193`, 13.091350282096835`], 
                Complex[133.67308025959395`, -8.374905338778808]}, 2 -> {
                Complex[108.60804805859196`, -13.230767939566041`], 
                Complex[133.84738105530036`, -33.00401845710657]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.20202263548404176`, -4.3607734061666505`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16153453454044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6752923215574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.25196814386352`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.60490884315497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.364055551814683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.16153453454044`, 13.224526629192964`], 
                Complex[133.6752923215574, -8.25196814386352]}, 2 -> {
                Complex[108.60490884315497`, -13.364055551814683`], 
                Complex[133.8418248696247, -33.12653484477617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2045363349210163, -4.513076780930337}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16321172691777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.355403546045842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6018659198306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.49504248983662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "D3", 
             Association[1 -> {
                Complex[108.16321172691777`, 13.355403546045842`], 
                Complex[133.67741275923174`, -8.131205890824077]}, 2 -> {
                Complex[108.6018659198306, -13.49504248983662], 
                Complex[133.83637862409032`, -33.24687418902981]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.20702361087296595`, -4.66686007013551}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16481270421882`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5989139612213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.623812650126247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.36511602955785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "D3", 
             Association[1 -> {
                Complex[108.16481270421882`, 13.484064903736146`], 
                Complex[133.67944688928384`, -8.012539074167394]}, 2 -> {
                Complex[108.5989139612213, -13.623812650126247`], 
                Complex[133.83103666267402`, -33.36511602955785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.20948538874719702`, -4.822098464901991}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16634207999647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.59604805537121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.481335414820634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "D3", 
             Association[1 -> {
                Complex[108.16634207999647`, 13.610589833057873`], 
                Complex[133.68139961119047`, -7.895892678682287]}, 2 -> {
                Complex[108.59604805537121`, -13.750445188118125`], 
                Complex[133.82579375652693`, -33.481335414820634`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21192254180002124`, -4.978768033304188}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16780410246909`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.73505308817024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6832754483489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.781195835377176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.59326366465744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82064506246513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.595603246147455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.16780410246909`, 13.73505308817024], 
                Complex[133.6832754483489, -7.781195835377176]}, 2 -> {
                Complex[108.59326366465744`, -13.875014881870271`], 
                Complex[133.82064506246513`, -33.595603246147455`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21433589514322193`, -5.136845672377163}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16920269038908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610141`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5905565895598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.997592460624652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.707986588641326`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.16920269038908`, 13.857525375128356`], 
                Complex[133.68507858433873`, -7.668381510610141]}, 2 -> {
                Complex[108.5905565895598, -13.997592460624652`], 
                Complex[133.81558608632903`, -33.707986588641326`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21672622936387143`, -5.296309063687721}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17054146472118`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6868128949976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.557386224570173`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58792293663865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.118244902313034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81061265054748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.818548952730794`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.17054146472118`, 13.978073649360802`], 
                Complex[133.6868128949976, -7.557386224570173]}, 2 -> {
                Complex[108.58792293663865`, -14.118244902313034`], 
                Complex[133.81061265054748`, -33.818548952730794`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21909428380237728`, -5.457136632136695}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17182377669673`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.448149795783658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58535909015445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.17182377669673`, 14.096761385616217`], 
                Complex[133.68848197687106`, -7.448149795783658]}, 2 -> {
                Complex[108.58535909015445`, -14.237035703530257`], 
                Complex[133.80572086534596`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.22144075952706999`, -5.619307507696718}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1730527327209`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.213648823436003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.340615108758886`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58286168684978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.354025125032765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.1730527327209, 14.213648823436003`], 
                Complex[133.69008917251034`, -7.340615108758886]}, 2 -> {
                Complex[108.58286168684978`, -14.354025125032765`], 
                Complex[133.80090710312302`, -34.03444852404852]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.22376632203935287`, -5.782801489821686}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17423121654305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58042759348385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.796167975588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.13989716530638`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.17423121654305`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[108.58042759348385`, -14.469270415426752`], 
                Complex[133.796167975588, -34.13989716530638]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.22607160373848956`, -5.947599014293189}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17536190903549`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.57805388677225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.24374810132099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.17536190903549`, 14.442248908399579`], 
                Complex[133.69313013823356`, -7.130436575951704]}, 2 -> {
                Complex[108.57805388677225`, -14.582826015372698`], 
                Complex[133.7915003133146, -34.24374810132099]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2283572061706991, -6.11368112229334}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17644730588044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.554067776191946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5757378354325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.694743744345217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78690114741266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "D3", 
             Association[1 -> {
                Complex[108.17644730588044`, 14.554067776191946`], 
                Complex[133.69456951471145`, -7.027692013672599]}, 2 -> {
                Complex[108.5757378354325, -14.694743744345217`], 
                Complex[133.78690114741266`, -34.34605047512348]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.23062370208697303`, -6.281029431515847}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17748973342061`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6959582519888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.926447421338382`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.57347688407852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7823676930617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.44685110695745`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.17748973342061`, 14.664299144668318`], 
                Complex[133.6959582519888, -6.926447421338382]}, 2 -> {
                Complex[108.57347688407852`, -14.805072971738818`], 
                Complex[133.7823676930617, -34.44685110695745]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.23287163732754834`, -6.449626109145779}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1784913628932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.772990071771156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5712686387431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.913860773896735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "D3", 
             Association[1 -> {
                Complex[108.1784913628932, 14.772990071771156`], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[108.5712686387431, -14.913860773896735`], 
                Complex[133.77789733468603`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.23510153255094224`, -6.619453846556052}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.179454223239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.880185467237435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6985931278124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.728281700596781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5691108538372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.64412369206375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "D3", 
             Association[1 -> {
                Complex[108.179454223239, 14.880185467237435`], 
                Complex[133.6985931278124, -6.728281700596781]}, 2 -> {
                Complex[108.5691108538372, -15.021152078455044`], 
                Complex[133.7734876125809, -34.64412369206375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2373138848233225, -6.7904958355826075`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18038021265114`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183253`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5670014203799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.1269897972341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76913621082284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.740678951509224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.18038021265114`, 14.985928225471847`], 
                Complex[133.69984356428586`, -6.631277315183253]}, 2 -> {
                Complex[108.5670014203799, -15.1269897972341], 
                Complex[133.76913621082284`, -34.740678951509224`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.23950916908145814`, -6.962735746254733}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18127110900694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.535606143784339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5649383553552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.231414948770265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7648409463208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "D3", 
             Association[1 -> {
                Complex[108.18127110900694`, 15.090259348061178`], 
                Complex[133.70105197999624`, -6.535606143784339]}, 2 -> {
                Complex[108.5649383553552, -15.231414948770265`], 
                Complex[133.7648409463208, -34.83589932329275]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24168783948118744`, -7.136157705867635}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18212857930814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.19321805690089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764478`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5629197920703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.33446677145913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18212857930814`, 15.19321805690089], 
                Complex[133.70222021135814`, -6.441230995764478]}, 2 -> {
                Complex[108.5629197920703, -15.33446677145913], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24385033064226036`, -7.310746279295341}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18295418823847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.294841898799707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010092`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.56094397140522`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.18295418823847`, 15.294841898799707`], 
                Complex[133.7033499865708, -6.348116269010092]}, 2 -> {
                Complex[108.56094397140522`, -15.436182828175927`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24599705879919043`, -7.486486450451405}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18374940593408`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.395166842334245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55900923385818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.536599103145393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.18374940593408`, 15.395166842334245`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[108.55900923385818`, -15.536599103145393`], 
                Complex[133.75227193555398`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24812842286675618`, -7.663363604813004}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18451561505084`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.494227367644926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55711401230226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74818171646749`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.20415291705668`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.18451561505084`, 15.494227367644926`], 
                Complex[133.70550058771096`, -6.165533069493568]}, 2 -> {
                Complex[108.55711401230226`, -15.635750091752186`], 
                Complex[133.74818171646749`, -35.20415291705668]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2502448054271156, -7.841363512931377}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18525411720202`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.0760005419752705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55525682537882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.73366888391076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.29322661291981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.18525411720202`, 15.592056549792124`], 
                Complex[133.70652439769495`, -6.0760005419752705`]}, 2 -> {
                Complex[108.55525682537882`, -15.73366888391076], 
                Complex[133.74413839370672`, -35.29322661291981]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2523465736465482, -8.020472314858761}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18596613883142`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7075157324069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.987600173789712`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5534362714641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.83038724155129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18596613883142`, 15.688686136228501`], 
                Complex[133.7075157324069, -5.987600173789712]}, 2 -> {
                Complex[108.5534362714641, -15.83038724155129], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2544340801266287, -8.200676505427285}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18665283657926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.78414661888746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.900303054034376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5516510231478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.92593567072055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7361862517464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.468001829363644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "D3", 
             Association[1 -> {
                Complex[108.18665283657926`, 15.78414661888746], 
                Complex[133.70847588612014`, -5.900303054034376]}, 2 -> {
                Complex[108.5516510231478, -15.92593567072055], 
                Complex[133.7361862517464, -35.468001829363644`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.25650766369651024`, -8.381962920321296}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18731530219162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54989982217656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "D3", 
             Association[1 -> {
                Complex[108.18731530219162`, 15.878467301338123`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[108.54989982217656`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.25856765015041105`, -8.564318722889137}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18795456701847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.97167636141339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7103074851951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.728908493102022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54818147481403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.113638886891636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "D3", 
             Association[1 -> {
                Complex[108.18795456701847`, 15.97167636141339], 
                Complex[133.7103074851951, -5.728908493102022]}, 2 -> {
                Complex[108.54818147481403`, -16.113638886891636`], 
                Complex[133.72840390066762`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.26061435293559043`, -8.747731391644937}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18857160613997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.644758632851147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54649484757873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "D3", 
             Association[1 -> {
                Complex[108.18857160613997`, 16.063800909678427`], 
                Complex[133.71118119033966`, -5.644758632851147]}, 2 -> {
                Complex[108.54649484757873`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2626480737939687, -8.93218870841477}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18916734215705`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.15486704407236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71202824232208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54483886332335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.29699990520363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7207808416868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18916734215705`, 16.15486704407236], 
                Complex[133.71202824232208`, -5.561607075648972]}, 2 -> {
                Complex[108.54483886332335`, -16.29699990520363], 
                Complex[133.7207808416868, -35.80483537920644]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2646691033621664, -9.117678747085655}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18974264867768`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.244899901024702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54321249762363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.38711678498225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7170260351905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "D3", 
             Association[1 -> {
                Complex[108.18974264867768`, 16.244899901024702`], 
                Complex[133.71284963153286`, -5.479429991022457]}, 2 -> {
                Complex[108.54321249762363`, -16.38711678498225], 
                Complex[133.7170260351905, -35.88654323957749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2666777217321794, -9.30418986291825}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19029835352708`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.333923703320405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7136462989116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.398204415298551`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54161477544838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754885003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.96729817997293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D3", 
             Association[1 -> {
                Complex[108.19029835352708`, 16.333923703320405`], 
                Complex[133.7136462989116, -5.398204415298551]}, 2 -> {
                Complex[108.54161477544838`, -16.476223863094223`], 
                Complex[133.71330754885003`, -35.96729817997293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.26867419897661193`, -9.491710682388241}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19083524170729`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.421961804962734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54004476808421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702874`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.19083524170729`, 16.421961804962734`], 
                Complex[133.71441913905534`, -5.317908209063045]}, 2 -> {
                Complex[108.54004476808421`, -16.564344505422497`], 
                Complex[133.70962432476173`, -36.04712235702874]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2706587956404576, -9.680230093522923}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19135405812926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.509036733260594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53850159029454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.651501250875818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267094`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19135405812926`, 16.509036733260594`], 
                Complex[133.71516900309246`, -5.238520017249023]}, 2 -> {
                Complex[108.53850159029454`, -16.651501250875818`], 
                Complex[133.70597535216768`, -36.12603714267094]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.27263176320283833`, -9.869737236703003}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1918555101365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53698439768804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.737715850917162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7023596646825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.20406316160481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.1918555101365, 16.595170228347317`], 
                Complex[133.71589670134114`, -5.160019231659067]}, 2 -> {
                Complex[108.53698439768804`, -16.737715850917162`], 
                Complex[133.7023596646825, -36.20406316160481]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2745933445100377, -10.060221495901107`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19234026984024`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.716603005773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53549238428282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.823009306709668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69877633772265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.28122032654659`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "D3", 
             Association[1 -> {
                Complex[108.19234026984024`, 16.680383280319464`], 
                Complex[133.716603005773, -5.082385955742662]}, 2 -> {
                Complex[108.53549238428282`, -16.823009306709668`], 
                Complex[133.69877633772265`, -36.28122032654659]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2765437741823291, -10.251672490331057`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19280897628119`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465139`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53402478024628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.907401904057913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.357527871365804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19280897628119`, 16.764696164168562`], 
                Complex[133.71728865229744`, -5.005600971465139]}, 2 -> {
                Complex[108.53402478024628`, -16.907401904057913`], 
                Complex[133.6952244861178, -36.357527871365804`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.27848327899718583`, -10.44408006648349}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19326223743363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53258084979647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.990913246296873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19326223743363`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118652]}, 2 -> {
                Complex[108.53258084979647`, -16.990913246296873`], 
                Complex[133.69170326188944`, -36.43300438228252]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.28041207824884395`, -10.637434290525537`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19370063206468`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53115988925272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.073562285278406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68821185218454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.5076678272615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "D3", 
             Association[1 -> {
                Complex[108.19370063206468`, 16.93069914732912], 
                Complex[133.71860074752377`, -4.854502212938122]}, 2 -> {
                Complex[108.53115988925272`, -17.073562285278406`], 
                Complex[133.68821185218454`, -36.5076678272615]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.28233038408802713`, -10.831725441043279`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19412471146116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52976122522162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.15536735058449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.581535583725454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "D3", 
             Association[1 -> {
                Complex[108.19412471146116`, 17.012426507651814`], 
                Complex[133.7192285060807, -4.780153123396222]}, 2 -> {
                Complex[108.52976122522162`, -17.15536735058449], 
                Complex[133.68474947734978`, -36.581535583725454`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2842384018414066, -11.026944002107953`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19453500103484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997942`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52838421290734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19453500103484`, 17.093328278637614`], 
                Complex[133.71983822997942`, -4.70658164106197]}, 2 -> {
                Complex[108.52838421290734`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2861363303134965, -11.223080656647234`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19493200181606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.17342161683146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7204305038047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.633771506916524`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52702823453782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353259`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19493200181606`, 17.17342161683146], 
                Complex[133.7204305038047, -4.633771506916524]}, 2 -> {
                Complex[108.52702823453782`, -17.31651593099674], 
                Complex[133.67790886901935`, -36.72695074353259]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2880243620712406, -11.420126280104967`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19531619184464`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.252723134903174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52569269789578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19531619184464`, 17.252723134903174`], 
                Complex[133.72100588678245`, -4.561706978028422]}, 2 -> {
                Complex[108.52569269789578`, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2899026837130805, -11.618071934373685`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1956880274665`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.3312489248945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7215649141643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52437703494735`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.474494188608475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6711757983389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.1956880274665, 17.3312489248945], 
                Complex[133.7215649141643, -4.490372805498023]}, 2 -> {
                Complex[108.52437703494735`, -17.474494188608475`], 
                Complex[133.6711757983389, -36.86937802828386]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.29177147612341514`, -11.816908861984686`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19604794454303`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.40901458021521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588028`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52308070056031`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.55233439603628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.9395090861031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D3", 
             Association[1 -> {
                Complex[108.19604794454303`, 17.40901458021521], 
                Complex[133.72210809852083`, -4.419754213588028]}, 2 -> {
                Complex[108.52308070056031`, -17.55233439603628], 
                Complex[133.66784794577546`, -36.9395090861031]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.29363091471284974`, -12.016628480542341`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19639635958045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.486035216469375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52180317130546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.62942898113872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.00893768620429`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19639635958045`, 17.486035216469375`], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[108.52180317130546`, -17.62942898113872], 
                Complex[133.66454505465833`, -37.00893768620429]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.29548116964636506`, -12.217222377389476`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19673367078482`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.56232549118666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52054394433422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.705792610098083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19673367078482`, 17.56232549118666], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[108.52054394433422`, -17.705792610098083`], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2973224060587256, -12.418682304491888`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19706025904894`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.63789962252805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379098`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51930253632736`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.781439509544896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.145742698655766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19706025904894`, 17.63789962252805], 
                Complex[133.72364740379098`, -4.212050853878544]}, 2 -> {
                Complex[108.51930253632736`, -17.781439509544896`], 
                Complex[133.65801181266102`, -37.145742698655766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.29915478425928654`, -12.621000173530486`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1973764888756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.7127714070303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061905`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5180784825091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.856383484307454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294622`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.213145677616154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "D3", 
             Association[1 -> {
                Complex[108.1973764888756, 17.7127714070303], 
                Complex[133.7241319288729, -4.144155620061905]}, 2 -> {
                Complex[108.5180784825091, -17.856383484307454`], 
                Complex[133.65478034294622`, -37.213145677616154`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.300978459925517, -12.8241680511906}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1976827092426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996306`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51687133572213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.1976827092426, 17.786954236448402`], 
                Complex[133.72460287329903`, -4.076908528996306]}, 2 -> {
                Complex[108.51687133572213`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3027935842876559, -13.028178154638468`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19797925441311`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.860461113751516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.010297263090177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51568066555893`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64838505795817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.346016090185714`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "D3", 
             Association[1 -> {
                Complex[108.19797925441311`, 17.860461113751516`], 
                Complex[133.72506063642794`, -4.010297263090177]}, 2 -> {
                Complex[108.51568066555893`, -18.004215870320177`], 
                Complex[133.64838505795817`, -37.346016090185714`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3046003043031362, -13.233022847175544`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19826644469612`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.933304668323515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.944309859257121`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51450605754546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.077129929660614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "D3", 
             Association[1 -> {
                Complex[108.19826644469612`, 17.933304668323515`], 
                Complex[133.72550560195975`, -3.944309859257121]}, 2 -> {
                Complex[108.51450605754546`, -18.077129929660614`], 
                Complex[133.64522023907952`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3063987628226812, -13.438694634061715`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19854458715977`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.005497170415737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8789346951999804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5133471123735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19854458715977`, 18.005497170415737`], 
                Complex[133.72593813870844`, -3.8789346951999804`]}, 2 -> {
                Complex[108.5133471123735, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.30818909874838596`, -13.645186158499385`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19881397630171`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.077050544896363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7263586013282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8141604763620265`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51220344517813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.22101518415878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6389538683734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.540662551100866`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19881397630171`, 18.077050544896363`], 
                Complex[133.7263586013282, -3.8141604763620265`]}, 2 -> {
                Complex[108.51220344517813`, -18.22101518415878], 
                Complex[133.6389538683734, -37.540662551100866`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.30997144718384106`, -13.85249019777034}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19907489467873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.147976384337575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.7499762235063514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51107468485743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208483`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.19907489467873`, 18.147976384337575`], 
                Complex[133.72676733099715`, -3.7499762235063514`]}, 2 -> {
                Complex[108.51107468485743`, -18.292009911552345`], 
                Complex[133.6358514127178, -37.60434783208483]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3117459395770368, -14.060599659518445`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19932761349929`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5099604734313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6327688660871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19932761349929`, 18.21828596147894], 
                Complex[133.72716465606135`, -3.686371260886986]}, 2 -> {
                Complex[108.5099604734313, -18.362387852255672`], 
                Complex[133.6327688660871, -37.66745274304553]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.31351270385655994`, -14.26950757817093}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1995723931808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.287990241102797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.6233352049778063`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50886046543684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.432159978084307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.72998767832449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.1995723931808, 18.287990241102797`], 
                Complex[133.7275508926416, -3.6233352049778063`]}, 2 -> {
                Complex[108.50886046543684`, -18.432159978084307`], 
                Complex[133.62970581322926`, -37.72998767832449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.31527186456133904`, -14.47920711149191}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19980948387447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.357099891355087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72792634520576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.5608579537275844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50777432735788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.50133696407843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.79196275059988`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19980948387447`, 18.357099891355087`], 
                Complex[133.72792634520576`, -3.5608579537275844`]}, 2 -> {
                Complex[108.50777432735788`, -18.50133696407843], 
                Complex[133.62666185240192`, -37.79196275059988]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.31702354296419344`, -14.689691537261904`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20003912596002`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50670173708629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.56992919930402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20003912596002`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[108.50670173708629`, -18.56992919930402], 
                Complex[133.62363659478484`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3187678571898118, -14.900954250077849`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20026155051174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437457`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50564238341306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.637946797159632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62062966392398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.20026155051174`, 18.493576557437457`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[108.50564238341306`, -18.637946797159632`], 
                Complex[133.62062966392398`, -37.91427240958484]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3205049223271885, -15.112988758267633`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20047697973848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.560963521110715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581249`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50459596554721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.70539960521599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6176406952053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "D3", 
             Association[1 -> {
                Complex[108.20047697973848`, 18.560963521110715`], 
                Complex[133.72899087982017`, -3.376682017581249]}, 2 -> {
                Complex[108.50459596554721`, -18.70539960521599], 
                Complex[133.6176406952053, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3222348505373418, -15.325788680914393`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20068562739868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.627795770329772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50356219266067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6146693353564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.0344573662522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "D3", 
             Association[1 -> {
                Complex[108.20068562739868`, 18.627795770329772`], 
                Complex[133.72932602622456`, -3.316344244925606]}, 2 -> {
                Complex[108.50356219266067`, -18.772297214614053`], 
                Complex[133.6146693353564, -38.0344573662522]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.32395775115531933`, -15.539347744985477`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20088769919248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.69408264253407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72965175404684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50254078345752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.093775647619346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.20088769919248`, 18.69408264253407], 
                Complex[133.72965175404684`, -3.25651864598262]}, 2 -> {
                Complex[108.50254078345752`, -18.838648969045263`], 
                Complex[133.61171524197405`, -38.093775647619346`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3256737307887363, -15.75365978256152}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20108339313214`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1971966078757674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50153146576623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60877808307634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.152589369857765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20108339313214`, 18.75983323641723], 
                Complex[133.72996830818997`, -3.1971966078757674`]}, 2 -> {
                Complex[108.50153146576623`, -18.904463973336476`], 
                Complex[133.60877808307634`, -38.152589369857765`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.32738289341136806`, -15.968718728161225`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20127289989236`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.825056420134477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1383697364634457`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.500533976153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.9697511016604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.20127289989236`, 18.825056420134477`], 
                Complex[133.73027592511528`, -3.1383697364634457`]}, 2 -> {
                Complex[108.500533976153, -18.9697511016604], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3290853404525649, -16.184518616157604`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20145640314155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.889760839155507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0800298488845854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49954805955541`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.03451900539132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.268736539794915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "D3", 
             Association[1 -> {
                Complex[108.20145640314155`, 18.889760839155507`], 
                Complex[133.73057483320838`, -3.0800298488845854`]}, 2 -> {
                Complex[108.49954805955541`, -19.03451900539132], 
                Complex[133.60295329038405`, -38.268736539794915`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.33078117088336967`, -16.401053578281907`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20163407985537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.95395492378105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49857346893486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.098776120624542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.3260861674659`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D3", 
             Association[1 -> {
                Complex[108.20163407985537`, 18.95395492378105], 
                Complex[133.7308652531255, -3.0221689664234646`]}, 2 -> {
                Complex[108.49857346893486`, -19.098776120624542`], 
                Complex[133.60006504101256`, -38.3260861674659]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.33247048129814516`, -16.61831784121145}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20180610061372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.01764689634064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.964779307677034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49760996494675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.162530675376825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992765`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20180610061372`, 19.01764689634064], 
                Complex[133.73114739812223`, -2.964779307677034]}, 2 -> {
                Complex[108.49760996494675`, -19.162530675376825`], 
                Complex[133.59719249422423`, -38.38296360992765]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3341533659936431, -16.83630572423766}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20197262988198`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.08084477808771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9078532820094942`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4966573156271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.22579069648413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.43937646664462`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20197262988198`, 19.08084477808771], 
                Complex[133.73142147436542`, -2.9078532820094942`]}, 2 -> {
                Complex[108.4966573156271, -19.22579069648413], 
                Complex[133.59433536417916`, -38.43937646664462]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.33582991704392384`, -17.055011637011138`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2021338262776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.1435563958075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794807`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49571529609509`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.2021338262776, 19.1435563958075], 
                Complex[133.73168768122898`, -2.8513834832794807`]}, 2 -> {
                Complex[108.49571529609509`, -19.288564016212078`], 
                Complex[133.59149337320665`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3375002243727465, -17.274430077360556`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.202289842823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.205789388152027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.795362683826273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49478368827032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.350858278593414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "D3", 
             Association[1 -> {
                Complex[108.202289842823, 19.205789388152027`], 
                Complex[133.73194621157512`, -2.795362683826273]}, 2 -> {
                Complex[108.49478368827032`, -19.350858278593414`], 
                Complex[133.58866625149176`, -38.55083790353878]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3391643758227474, -17.494555629182273`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20244082718541`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.267551211715737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287021123`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49386228060364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.60590078328636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20244082718541`, 19.267551211715737`], 
                Complex[133.73219725202154`, -2.7397838287021123`]}, 2 -> {
                Complex[108.49386228060364`, -19.41268094550608], 
                Complex[133.58585373677664`, -38.60590078328636]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34082245722160565`, -17.71538296039771}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20258692190454`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.684640030138418`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49295086782132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.66052768773749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.20258692190454`, 19.328849146864798`], 
                Complex[133.73244098319515`, -2.684640030138418]}, 2 -> {
                Complex[108.49295086782132`, -19.47403930250476], 
                Complex[133.58305557407587`, -38.66052768773749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3424745524461059, -17.93690682097588}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20272826460884`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73267757997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49204925068156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.534940464417765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.714725350944136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "D3", 
             Association[1 -> {
                Complex[108.20272826460884`, 19.389690303331637`], 
                Complex[133.73267757997374`, -2.6299245622347733`]}, 2 -> {
                Complex[108.49204925068156`, -19.534940464417765`], 
                Complex[133.58027151540554`, -38.714725350944136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34412074348270494`, -18.15912204101864}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20286498822084`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49115723574232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.595391380720887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "D3", 
             Association[1 -> {
                Complex[108.20286498822084`, 19.45008162558661], 
                Complex[133.73290721171554`, -2.5756308558594796`]}, 2 -> {
                Complex[108.49115723574232`, -19.595391380720887`], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34576111048673397`, -18.382023528905716`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20299722115244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.5100298979971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5217524937519045`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4902746351405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.655398840698574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.82185911025591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.20299722115244`, 19.5100298979971], 
                Complex[133.73313004247822`, -2.5217524937519045`]}, 2 -> {
                Complex[108.4902746351405, -19.655398840698574`], 
                Complex[133.57474475168777`, -38.82185911025591]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34739573183861694`, -18.605606269497322`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20312508749056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.569541749784385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4682832058167925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4894012663812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.714969478402878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939812`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20312508749056`, 19.569541749784385`], 
                Complex[133.73334623122685`, -2.4682832058167925`]}, 2 -> {
                Complex[108.4894012663812, -19.714969478402878`], 
                Complex[133.57200158341104`, -38.87480790939812]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34902468419778643`, -18.82986532239262}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20324870717361`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.628623659787674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7335559320325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4152168646016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48853695213684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260374`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20324870717361`, 19.628623659787674`], 
                Complex[133.7335559320325, -2.4152168646016]}, 2 -> {
                Complex[108.48853695213684`, -19.774109777419554`], 
                Complex[133.5692715922459, -38.92735288260374]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.35064804255503645`, -19.054795820240916`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20336819615972`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3625474809482334`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4876815200556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.83282607545025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156517`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.97950002657635`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20336819615972`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.3625474809482334`]}, 2 -> {
                Complex[108.4876815200556, -19.83282607545025], 
                Complex[133.56655456156517`, -38.97950002657635]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3522658802826584, -19.28039296710447}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20348366658654`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.310269199811078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48683480257834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "D3", 
             Association[1 -> {
                Complex[108.20348366658654`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.310269199811078]}, 2 -> {
                Complex[108.48683480257834`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3538782691821609, -19.506652036870456`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20359522692382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.803352366724106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48599663676426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.949011316216147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "D3", 
             Association[1 -> {
                Complex[108.20359522692382`, 19.803352366724106`], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[108.48599663676426`, -19.949011316216147`], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3554852795311092, -19.733568371710163`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20370298211841`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.86077644703169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2068631714772557`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48516686412384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.006492243769536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5584791492266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20370298211841`, 19.86077644703169], 
                Complex[133.73433277630323`, -2.2068631714772557`]}, 2 -> {
                Complex[108.48516686412384`, -20.006492243769536`], 
                Complex[133.5584791492266, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3570869801274341, -19.96113738058409}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20380703373283`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.917800878367114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48434533045962`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.063573147982027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20380703373283`, 19.917800878367114`], 
                Complex[133.73451218992713`, -2.155724349292754]}, 2 -> {
                Complex[108.48434533045962`, -20.063573147982027`], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.35868343833234917`, -20.189354537790823`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20390748007702`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48353188571376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.120259700008994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583597`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20390748007702`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[108.48353188571376`, -20.120259700008994`], 
                Complex[133.55315661583597`, -39.23446901800291]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36027472011184614`, -20.418215381558277`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20400441633439`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.030673339891976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73485417294913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.05454829869176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48272638382235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "D3", 
             Association[1 -> {
                Complex[108.20400441633439`, 20.030673339891976`], 
                Complex[133.73485417294913`, -2.05454829869176]}, 2 -> {
                Complex[108.48272638382235`, -20.176557449202853`], 
                Complex[133.55051310011328`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3618608900765139, -20.64771551267563}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20409793468184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73501698803878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.004500698579303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48192868257608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.23247182662352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "D3", 
             Association[1 -> {
                Complex[108.20409793468184`, 20.086532342147557`], 
                Complex[133.73501698803878`, -2.004500698579303]}, 2 -> {
                Complex[108.48192868257608`, -20.23247182662352], 
                Complex[133.54788117531717`, -39.333867334968325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36344201151990774`, -20.87785059316462}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20418812440447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7351745101014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48113864348676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5452606647034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "D3", 
             Association[1 -> {
                Complex[108.20418812440447`, 20.14201364645422], 
                Complex[133.7351745101014, -1.9548066511051871`]}, 2 -> {
                Complex[108.48113864348676`, -20.288008148422218`], 
                Complex[133.5452606647034, -39.3830324278985]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.365018146455526, -21.10861634498868}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.204275072005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.19712245331401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.905461241186206`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48035613165965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.204275072005, 20.19712245331401], 
                Complex[133.73532685336215`, -1.905461241186206]}, 2 -> {
                Complex[108.48035613165965`, -20.343171619103266`], 
                Complex[133.54265139579024`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3665893556524793, -21.340008548798576`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20435886130839`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47958101567112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39796733467009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.48031909408175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20435886130839`, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608582`]}, 2 -> {
                Complex[108.47958101567112`, -20.39796733467009], 
                Complex[133.54005320021983`, -39.48031909408175]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36815569867002296`, -21.572023042713287`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20443957356183`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.306242837557605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849098944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47881316745149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.452400285659856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "D3", 
             Association[1 -> {
                Complex[108.20443957356183`, 20.306242837557605`], 
                Complex[133.73561644435446`, -1.8077971849098944`]}, 2 -> {
                Complex[108.47881316745149`, -20.452400285659856`], 
                Complex[133.53746591362486`, -39.52845020484534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36971723389081035`, -21.80465572113478}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20451728753017`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47805246217267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.50647536007101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.57624602845285`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D3", 
             Association[1 -> {
                Complex[108.20451728753017`, 20.360264285794972`], 
                Complex[133.73575390485038`, -1.7594692110781693`]}, 2 -> {
                Complex[108.47805246217267`, -20.50647536007101], 
                Complex[133.53488937550063`, -39.57624602845285]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37127401855261155`, -22.037902533595712`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20459207958739`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931499`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47729877814062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.560197346190265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.62371109181686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20459207958739`, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931499`]}, 2 -> {
                Complex[108.47729877814062`, -20.560197346190265`], 
                Complex[133.53232342908268`, -39.62371109181686]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3728261087797762, -22.271759483638604`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20466402380387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763471`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47655199669187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5297679212286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20466402380387`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763471`]}, 2 -> {
                Complex[108.47655199669187`, -20.613570935319654`], 
                Complex[133.5297679212286, -39.67084982986853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3743735596126214, -22.50622262772579}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20473319203012`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7361381620127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47581200209461`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.66660072441222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658806003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20473319203012`, 20.52023078674261], 
                Complex[133.7361381620127, -1.6164475267435492`]}, 2 -> {
                Complex[108.47581200209461`, -20.66660072441222], 
                Complex[133.527222702305, -39.71766658806003]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37591642503662115`, -22.741288074178605`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20479965397669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47507868145351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.719291218615805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52468762607876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.76416562477972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "D3", 
             Association[1 -> {
                Complex[108.20479965397669`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[108.47507868145351`, -20.719291218615805`], 
                Complex[133.52468762607876`, -39.76416562477972]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37745475801023076`, -22.97695198214534}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20486347729089`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.62517263025513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47435192461855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "D3", 
             Association[1 -> {
                Complex[108.20486347729089`, 20.62517263025513], 
                Complex[133.73637185511262`, -1.5226917500597814`]}, 2 -> {
                Complex[108.47435192461855`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37898861049154675`, -23.21321056059665}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20492472763014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.67714604460236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73648223230828`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4762789595872334`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47363162409722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.82367189859418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5196473331636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.8562271459694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "D3", 
             Association[1 -> {
                Complex[108.20492472763014`, 20.67714604460236], 
                Complex[133.73648223230828`, -1.4762789595872334`]}, 2 -> {
                Complex[108.47363162409722`, -20.82367189859418], 
                Complex[133.5196473331636, -39.8562271459694]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3805180334648526, -23.450060067347433`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20498346873225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.728793469886888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222482`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47291767497042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.87537065735924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5171418400885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.90179773251957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "D3", 
             Association[1 -> {
                Complex[108.20498346873225`, 20.728793469886888`], 
                Complex[133.7365884127948, -1.4301708674222482`]}, 2 -> {
                Complex[108.47291767497042`, -20.87537065735924], 
                Complex[133.5171418400885, -39.90179773251957]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38204307696543083`, -23.68749680810474}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20503976248285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.78011906446158`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7366904808514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.384363546521321`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47220997481152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.926747271733447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5146459367488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.94706680604751`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "D3", 
             Association[1 -> {
                Complex[108.20503976248285`, 20.78011906446158], 
                Complex[133.7366904808514, -1.384363546521321]}, 2 -> {
                Complex[108.47220997481152`, -20.926747271733447`], 
                Complex[133.5146459367488, -39.94706680604751]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3835637901039206, -23.925517135540307`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20509366897993`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.338853145910491`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47150842360853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5121594924219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.99203822311736`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "D3", 
             Association[1 -> {
                Complex[108.20509366897993`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.338853145910491]}, 2 -> {
                Complex[108.47150842360853`, -20.977805823117308`], 
                Complex[133.5121594924219, -39.99203822311736]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38508022109024864`, -24.164117448387408`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2051452465958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.88182099570279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714519`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47081292368944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02855031468357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5096823792151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.036715766120224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D3", 
             Association[1 -> {
                Complex[108.2051452465958, 20.88182099570279], 
                Complex[133.73688260585357`, -1.293635888714519]}, 2 -> {
                Complex[108.47081292368944`, -21.02855031468357], 
                Complex[133.5096823792151, -40.036715766120224`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38659241725588345`, -24.40329419056071}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20519455203652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7369728206324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2487080702500926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47012337965012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20519455203652`, 20.9322052560464], 
                Complex[133.7369728206324, -1.2487080702500926`]}, 2 -> {
                Complex[108.47012337965012`, -21.078984673387104`], 
                Complex[133.50721447198237`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3881004250763169, -24.643043850298895`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20524164039881`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9822835369875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803769`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46943969828529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12911275191011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20524164039881`, 20.9822835369875], 
                Complex[133.73705923878367`, -1.2040660561803769`]}, 2 -> {
                Complex[108.46943969828529`, -21.12911275191011], 
                Complex[133.50475564824438`, -40.12520400001159]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3896042901923522, -24.88336295932909}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20528656522481`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.032059615714736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46876178852183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20528656522481`, 21.032059615714736`], 
                Complex[133.7371419342688, -1.1597062807288658`]}, 2 -> {
                Complex[108.46876178852183`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.39110405743048204`, -25.124248092052156`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20532937855462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73722097918034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1156252449499`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46808956135473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.22846511901765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "D3", 
             Association[1 -> {
                Complex[108.20532937855462`, 21.081537198896893`], 
                Complex[133.73722097918034`, -1.1156252449499]}, 2 -> {
                Complex[108.46808956135473`, -21.22846511901765], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3925997708233808, -25.365695864748744`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2053701309766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.130719924447273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4674229297853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "D3", 
             Association[1 -> {
                Complex[108.2053701309766, 21.130719924447273`], 
                Complex[133.73729644380091`, -1.071819515054031]}, 2 -> {
                Complex[108.4674229297853, -21.277696758252308`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.394091473629004, -25.607702934805076`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20540887167593`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4667618087618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "D3", 
             Association[1 -> {
                Complex[108.20540887167593`, 21.179611363233047`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[108.4667618087618, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3955792083494032, -25.850265999957674`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20544564848103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46610611512213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.375288818906036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.34153309171082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "D3", 
             Association[1 -> {
                Complex[108.20544564848103`, 21.228215020730893`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[108.46610611512213`, -21.375288818906036`], 
                Complex[133.49259367239995`, -40.34153309171082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3970630167490583, -26.09338179755696}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20548050790832`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.276534338631635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983291`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46545576753864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.38398750984297`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20548050790832`, 21.276534338631635`], 
                Complex[133.73750203277484`, -0.9420207663983291]}, 2 -> {
                Complex[108.46545576753864`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.38398750984297]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3985429398723852, -26.33704710384877}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20551349520517`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.32457269639543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73756384480689`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8992831695357317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46481068646492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.47174232754069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4877884573571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "D3", 
             Association[1 -> {
                Complex[108.20551349520517`, 21.32457269639543], 
                Complex[133.73756384480689`, -0.8992831695357317]}, 2 -> {
                Complex[108.46481068646492`, -21.47174232754069], 
                Complex[133.4877884573571, -40.4261790532468]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4000190180611298, -26.58125873327334}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20554465439125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4641707940845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.519550543179957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.468110858122984`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "D3", 
             Association[1 -> {
                Complex[108.20554465439125`, 21.372333412759417`], 
                Complex[133.73762240273047`, -0.8568046319064742]}, 2 -> {
                Complex[108.4641707940845, -21.519550543179957`], 
                Complex[133.4853981881505, -40.468110858122984`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40149129097065384`, -26.826013537781037`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2055740282982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.41981974719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7376777670912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8145820782986526`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4635360142614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.56708410244112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48301600828688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.509786004466065`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.2055740282982, 21.41981974719948], 
                Complex[133.7376777670912, -0.8145820782986526]}, 2 -> {
                Complex[108.4635360142614, -21.56708410244112], 
                Complex[133.48301600828688`, -40.509786004466065`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40295979758610656`, -27.071308406164956`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20560165860788`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.46703490134794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003713`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46290627249242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20560165860788`, 21.46703490134794], 
                Complex[133.73772999698096`, -0.7726124883003713]}, 2 -> {
                Complex[108.46290627249242`, -21.61434620967062], 
                Complex[133.48064181814095`, -40.55120751741088]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4044245762382843, -27.317140263408923`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2056275858894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.513982020369063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.462281495861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.66134001270741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.2056275858894, 21.513982020369063`], 
                Complex[133.73777915008168`, -0.7308928949944189]}, 2 -> {
                Complex[108.462281495861, -21.66134001270741], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40588566461849496`, -27.563506070051293`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20565184963387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927808`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46166161299293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.708068604217775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.6333014771445`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "D3", 
             Association[1 -> {
                Complex[108.20565184963387`, 21.560664194292517`], 
                Complex[133.73782528270675`, -0.6894203836927808]}, 2 -> {
                Complex[108.46166161299293`, -21.708068604217775`], 
                Complex[133.47591701822185`, -40.6333014771445]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40734309979347927`, -27.810402821563493`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20567448828915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4610465540133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.673979711466146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "D3", 
             Association[1 -> {
                Complex[108.20567448828915`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[108.4610465540133, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.673979711466146`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40879691821953656`, -28.057827547743443`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20569553929232`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4604362505051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.800742255195576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.7144158898782`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20569553929232`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[108.4604362505051, -21.800742255195576`], 
                Complex[133.47122302955884`, -40.7144158898782]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41024715575650816`, -28.30577731212275}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20571503910132`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45983063546929`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.84669323560172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.75461278205018`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20571503910132`, 21.699151145685974`], 
                Complex[133.73794610118625`, -0.5664569528154004]}, 2 -> {
                Complex[108.45983063546929`, -21.84669323560172], 
                Complex[133.46888736024792`, -40.75461278205018]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41169384768122086`, -28.554249211387702`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20573302322543`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45922964328606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20573302322543`, 21.74480338135634], 
                Complex[133.73798068907433`, -0.5259446249758852]}, 2 -> {
                Complex[108.45922964328606`, -21.89239084876426], 
                Complex[133.46655912218745`, -40.79457311007124]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4131370287004188, -28.80324037481374}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20574952625452`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.790205339072944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45863320967749`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46423822839947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.83429954954243`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "D3", 
             Association[1 -> {
                Complex[108.20574952625452`, 21.790205339072944`], 
                Complex[133.73801251890455`, -0.4856655473715854]}, 2 -> {
                Complex[108.45863320967749`, -21.937837930174453`], 
                Complex[133.46423822839947`, -40.83429954954243]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41457673296380904`, -29.052747963712676`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20576458188737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45804127167143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "D3", 
             Association[1 -> {
                Complex[108.20576458188737`, 21.835359803960372`], 
                Complex[133.73804163958545`, -0.4456170941100197]}, 2 -> {
                Complex[108.45804127167143`, -21.983037267377462`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.416012994075885, -29.302769170892503`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20577822295887`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836444038`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45745376756668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4596181338099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.9130612391335`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "D3", 
             Association[1 -> {
                Complex[108.20577822295887`, 21.880269514316595`], 
                Complex[133.73806809891306`, -0.4057966836444038]}, 2 -> {
                Complex[108.45745376756668`, -22.027991601058005`], 
                Complex[133.4596181338099, -40.9130612391335]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4174458451085741, -29.5533012201294}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2057904814664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.924937162667213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360265`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.36620177777332685`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4568706368991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.07270362609541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "D3", 
             Association[1 -> {
                Complex[108.2057904814664, 21.924937162667213`], 
                Complex[133.73809194360265`, -0.36620177777332685`]}, 2 -> {
                Complex[108.4568706368991, -22.07270362609541], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4188753186122085, -29.804341365651645`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20580138859481`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.969365396789907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381132193189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3268298806687788`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45629182040908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.11717599258868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20580138859481`, 21.969365396789907`], 
                Complex[133.7381132193189, -0.3268298806687788]}, 2 -> {
                Complex[108.45629182040908`, -22.11717599258868], 
                Complex[133.45502641240844`, -40.99091836543067]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.42030144662757607`, -30.0558868916351}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581097474138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.013556820710516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070587`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793104337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45571726000996`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.161411306852976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.029513941672306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D3", 
             Association[1 -> {
                Complex[108.20581097474138`, 22.013556820710516`], 
                Complex[133.73813197070587`, -0.28767853793104337`]}, 2 -> {
                Complex[108.45571726000996`, -22.161411306852976`], 
                Complex[133.45274099074845`, -41.029513941672306`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4217242606961804, -30.307935111709565`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581926953896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.057513995670746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24874533567058066`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45514689875739`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.06789076406041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D3", 
             Association[1 -> {
                Complex[108.20581926953896`, 22.057513995670746`], 
                Complex[133.73814824141513`, -0.24874533567058066`]}, 2 -> {
                Complex[108.45514689875739`, -22.205412132388137`], 
                Complex[133.45046242420474`, -41.06789076406041]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4231437918715244, -30.5604833684765}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20582630187882`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381620741335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21002789961487878`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4545806808199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085485`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20582630187882`, 22.101239441069584`], 
                Complex[133.7381620741335, -0.21002789961487878`]}, 2 -> {
                Complex[108.4545806808199, -22.249180990820513`], 
                Complex[133.44819063634748`, -41.10605121085485]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4245600707294557, -30.813529033036893`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058320999327`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.144735635378424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45401855145008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.29272036281873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44592555210812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.2058320999327, 22.144735635378424`], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[108.45401855145008`, -22.29272036281873], 
                Complex[133.44592555210812`, -41.14399762152054]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.42597312737788684`, -31.067069504529787`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20583669117387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.188005017031276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.133231021927255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45346045695712`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20583669117387`, 22.188005017031276`], 
                Complex[133.73818259167945`, -0.133231021927255]}, 2 -> {
                Complex[108.45346045695712`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4273829914674536, -31.32110220968049}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584010239766`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937909`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4529063446797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.37912037071832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.21925750339875`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "D3", 
             Association[1 -> {
                Complex[108.20584010239766`, 22.231049985290603`], 
                Complex[133.73818935729176`, -0.09514702213937909]}, 2 -> {
                Complex[108.4529063446797, -22.37912037071832], 
                Complex[133.44141520081953`, -41.21925750339875]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.42878969220029717`, -31.57562460235873}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584235974113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.273872901089774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819384653146`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.05726967062376076`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4523561629603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.421985771063884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "D3", 
             Association[1 -> {
                Complex[108.20584235974113`, 22.273872901089774`], 
                Complex[133.73819384653146`, -0.05726967062376076]}, 2 -> {
                Complex[108.4523561629603, -22.421985771063884`], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43019325833975586`, -31.830634163146332`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584348870231`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633644618`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45180986111974`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.464631215526794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.293688381063454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "D3", 
             Association[1 -> {
                Complex[108.20584348870231`, 22.316476087852752`], 
                Complex[133.73819609764354`, -0.019596778633644618`]}, 2 -> {
                Complex[108.45180986111974`, -22.464631215526794`], 
                Complex[133.4369307957903, -41.293688381063454`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4315937182196876, -32.08612839891387}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584351415843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.01787380782837289`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45126738943297`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.507058992873564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900828`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "D3", 
             Association[1 -> {
                Complex[108.20584351415843`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.01787380782837289]}, 2 -> {
                Complex[108.45126738943297`, -22.507058992873564`], 
                Complex[133.43469814900828`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4329910997529396, -32.342104842406556`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584246038388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.401032385184138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874687431`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45072869910537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43247178224317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.36730765692627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "D3", 
             Association[1 -> {
                Complex[108.20584246038388`, 22.401032385184138`], 
                Complex[133.73819403439737`, 0.05514420874687431]}, 2 -> {
                Complex[108.45072869910537`, -22.549271355908413`], 
                Complex[133.43247178224317`, -41.36730765692627]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.434385430440102, -32.59856105183866}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584035106731`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45019374224961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.591270522229657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.40381823277538`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "D3", 
             Association[1 -> {
                Complex[108.20584035106731`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[108.45019374224961`, -22.591270522229657`], 
                Complex[133.43025162908577`, -41.40381823277538]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4357767373782053, -32.855494610496564`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058372093284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.48473674427653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381834575462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12909276811101833`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44966247186406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4280376242509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D3", 
             Association[1 -> {
                Complex[108.2058372093284, 22.48473674427653], 
                Complex[133.7381834575462, 0.12909276811101833`]}, 2 -> {
                Complex[108.44966247186406`, -22.633058674966136`], 
                Complex[133.4280376242509, -41.44013218836733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43716504726833705`, -33.11290312635019}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20583305773388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817506382267`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1657750028210252`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44913484181036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.67463796349433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4258297035504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.47625154943294`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20583305773388`, 22.526274879059084`], 
                Complex[133.73817506382267`, 0.1657750028210252]}, 2 -> {
                Complex[108.44913484181036`, -22.67463796349433], 
                Complex[133.4258297035504, -41.47625154943294]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43855038642402633`, -33.37078423167215}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20582791831282`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.5676064808745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500857`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581329`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4486108067934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.7160105041369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20582791831282`, 22.5676064808745], 
                Complex[133.73816464500857`, 0.2022652058581329]}, 2 -> {
                Complex[108.4486108067934, -22.7160105041369], 
                Complex[133.42362780386904`, -41.51217831040795]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4399327807789746, -33.62913558266511}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058218125723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.60873363177336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2385653375287191`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44809032234028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.54791443507824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.2058218125723, 22.60873363177336], 
                Complex[133.73815223405947`, 0.2385653375287191]}, 2 -> {
                Complex[108.44809032234028`, -22.757178380842795`], 
                Complex[133.42143186313933`, -41.54791443507824]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4413122558945304, -33.887954859096624`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581476151133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.64965838211989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813786325204`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.27467732815634704`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44757334478123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4192418203182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "D3", 
             Association[1 -> {
                Complex[108.20581476151133`, 22.64965838211989], 
                Complex[133.73813786325204`, 0.27467732815634704`]}, 2 -> {
                Complex[108.44757334478123`, -22.798143645850324`], 
                Complex[133.4192418203182, -41.58346185720893]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.44268883696693706`, -34.147239763941485`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20580678563522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.690382751237316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381215642015`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44705983123023`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.838908320332706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4170576153638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.61882248115683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "D3", 
             Association[1 -> {
                Complex[108.20580678563522`, 22.690382751237316`], 
                Complex[133.7381215642015, 0.3106030786938945]}, 2 -> {
                Complex[108.44705983123023`, -22.838908320332706`], 
                Complex[133.4170576153638, -41.61882248115683]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4440625488348928, -34.4069880230313}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2057979049692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.730908728036784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73810336787855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3463444613199158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44654973956648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.65399818246753`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "D3", 
             Association[1 -> {
                Complex[108.2057979049692, 22.730908728036784`], 
                Complex[133.73810336787855`, 0.3463444613199158]}, 2 -> {
                Complex[108.44654973956648`, -22.879474395027522`], 
                Complex[133.41487918921305`, -41.65399818246753]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.44543341598620145`, -34.66719738471119}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20578813907149`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.77123827163027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38190332001997973`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44604302841654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830849942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.68899080845722`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20578813907149`, 22.77123827163027], 
                Complex[133.7380833046258, 0.38190332001997973`]}, 2 -> {
                Complex[108.44604302841654`, -22.919843830849942`], 
                Complex[133.41270648376, -41.68899080845722]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4468014625647925, -34.9278656195033}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20577750704612`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.811373311928055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.41728147115322045`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44553965713682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20577750704612`, 22.811373311928055`], 
                Complex[133.73806140417352`, 0.41728147115322045`]}, 2 -> {
                Complex[108.44553965713682`, -22.960018559490663`], 
                Complex[133.41053944183454`, -41.72380217877986]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4481667123772297, -35.18899051977725}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20576602755536`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.851315750221183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.45248070400472074`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44503958579652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.000000483998686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "D3", 
             Association[1 -> {
                Complex[108.20576602755536`, 22.851315750221183`], 
                Complex[133.73803769565515`, 0.45248070400472074`]}, 2 -> {
                Complex[108.44503958579652`, -23.000000483998686`], 
                Complex[133.40837800718194`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.44952918889953253`, -35.45056989942684}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20575371883149`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.89106745974935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4875027813239967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4445427751615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.039791479349624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40622212444285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.792888296032174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "D3", 
             Association[1 -> {
                Complex[108.20575371883149`, 22.89106745974935], 
                Complex[133.7380122076221, 0.4875027813239967]}, 2 -> {
                Complex[108.4445427751615, -23.039791479349624`], 
                Complex[133.40622212444285`, -41.792888296032174`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4508889152830591, -35.71260159355341}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20574059868858`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.930630286254683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44404918667772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.079393392999783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40407173913366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.827166548865776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20574059868858`, 22.930630286254683`], 
                Complex[133.73798496805836`, 0.5223494398501387]}, 2 -> {
                Complex[108.44404918667772`, -23.079393392999783`], 
                Complex[133.40407173913366`, -41.827166548865776`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.45224591436129913`, -35.97508345815531}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20572668453359`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.970006048521853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44355878245624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.118808045426714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40192679762777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.86127055887853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20572668453359`, 22.970006048521853`], 
                Complex[133.73795600439445`, 0.5570223908239633]}, 2 -> {
                Complex[108.44355878245624`, -23.118808045426714`], 
                Complex[133.40192679762777`, -41.86127055887853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4536002086550468, -36.23801336982345}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20571199337722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874326`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44307152525788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.15803723065624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.895202015436034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20571199337722`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874326]}, 2 -> {
                Complex[108.44307152525788`, -23.15803723065624], 
                Complex[133.39978724713725`, -41.895202015436034`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4549518203791081, -36.50138922544288}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20569654184456`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.048203523840755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44258737847856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.19708271677684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335968`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "D3", 
             Association[1 -> {
                Complex[108.20569654184456`, 23.048203523840755`], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[108.44258737847856`, -23.19708271677684], 
                Complex[133.39765303569476`, -41.92896258335968]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4563007714478431, -36.76520894189998}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20568034618515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508832`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.660015738769026`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44210630613502`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340243`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "D3", 
             Association[1 -> {
                Complex[108.20568034618515`, 23.087028744351482`], 
                Complex[133.73785903508832`, 0.660015738769026]}, 2 -> {
                Complex[108.44210630613502`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340243]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4576470834803956, -37.02947045579555}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20566342228294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.12567391653265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378234387284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6940104792034738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44162827285093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.995977592713125`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20566342228294`, 23.12567391653265], 
                Complex[133.7378234387284, 0.6940104792034738]}, 2 -> {
                Complex[108.44162827285093`, -23.27462953735594], 
                Complex[133.39340042608347`, -41.995977592713125`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.45899077780654807`, -37.29417172316319}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20564578566592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73778624758228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7278397028767003`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44115324384377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.029235245289854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20564578566592`, 23.164140732031164`], 
                Complex[133.73778624758228`, 0.7278397028767003]}, 2 -> {
                Complex[108.44115324384377`, -23.313134282759336`], 
                Complex[133.39128192792896`, -42.029235245289854`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4603318754720078, -37.559310719193086`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20562745151531`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.20243085851121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44068118491076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.351462151887336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3891685688179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.06232843242164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20562745151531`, 23.20243085851121], 
                Complex[133.73774748603228`, 0.7615049781131944]}, 2 -> {
                Complex[108.44068118491076`, -23.351462151887336`], 
                Complex[133.3891685688179, -42.06232843242164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4616703972435232, -37.824885437961264`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20560843467463`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010909`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44021206241757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.389614790429448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "D3", 
             Association[1 -> {
                Complex[108.20560843467463`, 23.24054594010909], 
                Complex[133.73770717799474`, 0.7950078509907854]}, 2 -> {
                Complex[108.44021206241757`, -23.389614790429448`], 
                Complex[133.3870603006344, -42.095258703120905`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4630063636141415, -38.090893892163635`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2055887496584`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.27848759787728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.828349845761597`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.43974584328434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "D3", 
             Association[1 -> {
                Complex[108.2055887496584, 23.27848759787728], 
                Complex[133.73766534693092`, 0.828349845761597]}, 2 -> {
                Complex[108.43974584328434`, -23.427593820972138`], 
                Complex[133.38495707598474`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4643397948079553, -38.3573341128553}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20556841066069`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.31625743021801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.43928249497475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.46540084343349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240324`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "D3", 
             Association[1 -> {
                Complex[108.20556841066069`, 23.31625743021801], 
                Complex[133.73762201585797`, 0.8615324652630925]}, 2 -> {
                Complex[108.43928249497475`, -23.46540084343349], 
                Complex[133.38285884818345`, -42.16063658240324]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.14947272860459798`, 0.0864635121867516}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.49679557516603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.87967075293174`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.57287060790918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532399953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "C3", 
             Association[1 -> {
                Complex[162.49679557516603`, 2.9142396485109336`], 
                Complex[132.88189718832854`, -17.87967075293174]}, 2 -> {
                Complex[164.57287060790918`, -3.0479413532399953`], 
                Complex[134.78862529189124`, -23.513498562864434`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1600377573443887, 0.048282237225062835`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.69815823018737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.07664557448564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.20679401345527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.3691232322966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.76466640407678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763844034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.18608044096362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "C3", 
             Association[1 -> {
                Complex[162.69815823018737`, 3.6307705575763123`], 
                Complex[133.07664557448564`, -17.20679401345527]}, 2 -> {
                Complex[164.3691232322966, -3.76466640407678], 
                Complex[134.58936763844034`, -24.18608044096362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.16882686412194453`, 0.0025479839961339568`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.81702682614014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.244103960587594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.192822735254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.630699080753924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.24791286298796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.46872944634774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.76187553625734`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "C3", 
             Association[1 -> {
                Complex[162.81702682614014`, 4.244103960587594], 
                Complex[133.192822735254, -16.630699080753924`]}, 2 -> {
                Complex[164.24791286298796`, -4.378190406750068], 
                Complex[134.46872944634774`, -24.76187553625734]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1764979130619559, -0.04972560007545493}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.89623202590275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.166407339344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.916047187939833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "C3", 
             Association[1 -> {
                Complex[162.89623202590275`, 4.781773561001189], 
                Complex[133.27102086156964`, -16.125747324937514`]}, 2 -> {
                Complex[164.166407339344, -4.916047187939833], 
                Complex[134.38611694252143`, -25.266522626186124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.18338976437019533`, -0.10779416601750416`}],
            
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.9533692895785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.26317421199133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.673778470422995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.10700978216263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.397631717588651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.718182126604795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "C3", 
             Association[1 -> {
                Complex[162.9533692895785, 5.26317421199133], 
                Complex[133.3279803002992, -15.673778470422995`]}, 2 -> {
                Complex[164.10700978216263`, -5.397631717588651], 
                Complex[134.3247882793696, -25.718182126604795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.18970083365667784`, -0.17109415686599608`}],
            
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.99687585597522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.26276580186694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.06128160668933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.83575911268632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343943`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "C3", 
             Association[1 -> {
                Complex[162.99687585597522`, 5.701120919783133], 
                Complex[133.3717561373341, -15.26276580186694]}, 2 -> {
                Complex[164.06128160668933`, -5.83575911268632], 
                Complex[134.27668694605623`, -26.128880886343943`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.19555831308773514`, -0.2391829913489885}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.03131031496125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4067147758406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.884495531077516`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.02466294522884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.239169639445748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.2374451850879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.506832820748922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "C3", 
             Association[1 -> {
                Complex[163.03131031496125`, 6.104353845416841], 
                Complex[133.4067147758406, -14.884495531077516`]}, 2 -> {
                Complex[164.02466294522884`, -6.239169639445748], 
                Complex[134.2374451850879, -26.506832820748922`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2010492499679281, -0.31170220396345116`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.05936393484134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43544220027496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.533126521950006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.99446131516729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "C3", 
             Association[1 -> {
                Complex[163.05936393484134`, 6.479082403584161], 
                Complex[133.43544220027496`, -14.533126521950006`]}, 2 -> {
                Complex[163.99446131516729`, -6.614072812516706], 
                Complex[134.20447572357537`, -26.857879187158492`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.20623621026741085`, -0.3883541663970844}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.0827360388856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.96897623823008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.96504547952883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.18632866833261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "C3", 
             Association[1 -> {
                Complex[163.0827360388856, 6.829883346826038], 
                Complex[133.45957631720722`, -14.204350207418514`]}, 2 -> {
                Complex[163.96897623823008`, -6.96504547952883], 
                Complex[134.17613942808237`, -27.18632866833261]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21116590341148872`, -0.4688867814821356}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.10255730313813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.1602366935056825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.8948884451038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.94707593880682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1513419963516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49545951715293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.10255730313813`, 7.1602366935056825`], 
                Complex[133.48021025962274`, -13.8948884451038]}, 2 -> {
                Complex[163.94707593880682`, -7.295567749380924], 
                Complex[134.1513419963516, -27.49545951715293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.21587427019259103`, -0.5530830201675043}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.11961217061838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.9279749261981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.12932163548447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.78783159598447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.11961217061838`, 7.472858386883269], 
                Complex[133.49810470509067`, -13.602181478273478`]}, 2 -> {
                Complex[163.9279749261981, -7.60835565160759], 
                Complex[134.12932163548447`, -27.78783159598447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2203896536362941, -0.6407535198555137}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.13446375540627`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.32418640258124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.91110908726415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "C3", 
             Association[1 -> {
                Complex[163.13446375540627`, 7.769914966301738], 
                Complex[133.51380733250912`, -13.32418640258124]}, 2 -> {
                Complex[163.91110908726415`, -7.905575807831239], 
                Complex[134.10952960183627`, -28.065487910230864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.22473486542336268`, -0.7317311915204956}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1475279007755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.053167049211595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8960616252759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.188988914036532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.33008939886362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.1475279007755, 8.053167049211595], 
                Complex[133.52772377923588`, -13.059242375813348`]}, 2 -> {
                Complex[163.8960616252759, -8.188988914036532], 
                Complex[134.09155924078232`, -28.33008939886362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.22892858334225757`, -0.8258671894830505}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.15911911401952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.3240682437392`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8825171223138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.460048653363897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0751018939077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.583007906385838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.15911911401952`, 8.3240682437392], 
                Complex[133.54016173104085`, -12.805977646175146`]}, 2 -> {
                Complex[163.8825171223138, -8.460048653363897], 
                Complex[134.0751018939077, -28.583007906385838`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2329863262452016, -0.9230278328811485}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1694801602913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.583835207504208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.56324367042308`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.87023194285814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.1694801602913, 8.583835207504208], 
                Complex[133.55135937730103`, -12.56324367042308]}, 2 -> {
                Complex[163.87023194285814`, -8.719971755138737], 
                Complex[134.05991844116488`, -28.82539206493508]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.236921152559949, -1.0230922089904324`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.17880175664644`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.833498461149421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.85901453737054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.17880175664644`, 8.833498461149421], 
                Complex[133.56150438018219`, -12.330067310220034`]}, 2 -> {
                Complex[163.85901453737054`, -8.96978880859587], 
                Complex[134.04582032924358`, -29.058215098144608`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24074417234820594`, -1.1259502761186442`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.18723604978868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.073940020992653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.10561541560388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.84871196234698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.03265656530453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.28231023787636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "C3", 
             Association[1 -> {
                Complex[163.18723604978868`, 9.073940020992653], 
                Complex[133.57074687863496`, -12.10561541560388]}, 2 -> {
                Complex[163.84871196234698`, -9.210381895712343], 
                Complex[134.03265656530453`, -29.28231023787636]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2444649302563328, -1.2315013398204437`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.19490606734587`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8392004270005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.44251298180812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.020304580273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "C3", 
             Association[1 -> {
                Complex[163.19490606734587`, 9.305921789460667], 
                Complex[133.57920862299497`, -11.889168097503115`]}, 2 -> {
                Complex[163.8392004270005, -9.44251298180812], 
                Complex[134.020304580273, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.24809169698631245`, -1.3396528130101173`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20191248924124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.83037851999364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "C3", 
             Association[1 -> {
                Complex[163.20191248924124`, 9.530107327827569], 
                Complex[133.58698953054267`, -11.680098224034463`]}, 2 -> {
                Complex[163.83037851999364`, -9.666845688440565], 
                Complex[134.00866367132147`, -29.707103947727525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.25163169462078877`, -1.450319195361294}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20833859211223`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956242`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8221622632574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.883962238175444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.908980134406136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.20833859211223`, 9.747078800841354], 
                Complex[133.59417248038324`, -11.477855458956242`]}, 2 -> {
                Complex[163.8221622632574, -9.883962238175444], 
                Complex[133.99765020516938`, -29.908980134406136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2550912732468242, -1.5634212244705152`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2142539214259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.957350339052207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.81448143823496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.09437681705006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.104512213028926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.2142539214259, 9.957350339052207], 
                Complex[133.60082688045318`, -11.281953671224448`]}, 2 -> {
                Complex[163.81448143823496`, -10.09437681705006], 
                Complex[133.9871940493811, -30.104512213028926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.25847605114302546`, -1.6788851632630968`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.21971706050041`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6070113617539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.091960884780269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80727681533168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.298546238374051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.97723587655176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.294132227130046`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "C3", 
             Association[1 -> {
                Complex[163.21971706050041`, 10.161378702488394`], 
                Complex[133.6070113617539, -11.091960884780269`]}, 2 -> {
                Complex[163.80727681533168`, -10.298546238374051`], 
                Complex[133.97723587655176`, -30.294132227130046`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2617910273039336, -1.796642196702898}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2247777474091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.359571883156995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.907491168998273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80049803558532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.49687854534779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9677250996958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.2247777474091, 10.359571883156995`], 
                Complex[133.61277584148843`, -10.907491168998273`]}, 2 -> {
                Complex[163.80049803558532`, -10.49687854534779], 
                Complex[133.9677250996958, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.26504067268795034`, -1.9166279171051512`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.22947851363165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.552296113405845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7941019706839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.689740019533176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878894`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "C3", 
             Association[1 -> {
                Complex[163.22947851363165`, 10.552296113405845`], 
                Complex[133.6181631227232, -10.728198030417936`]}, 2 -> {
                Complex[163.7941019706839, -10.689740019533176`], 
                Complex[133.9586182712075, -30.657140604878894`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2682290049014619, -2.0387818819524335`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23385596697975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.55376897922101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7880514387958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.23385596697975`, 10.739881627157578`], 
                Complex[133.62321014884253`, -10.55376897922101]}, 2 -> {
                Complex[163.7880514387958, -10.877460942190032`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2713596498498469, -2.163047231554368}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23794180650475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62794899755536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.383921024629705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.78231418849845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.000651631856574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.23794180650475`, 10.922627435195468`], 
                Complex[133.62794899755536`, -10.383921024629705`]}, 2 -> {
                Complex[163.78231418849845`, -11.060340369657364`], 
                Complex[133.94147109188316`, -31.000651631856574`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.27443589302789, -2.289370356495063}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2417636330736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.100805313420308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63240767607033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.218396911961511`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.776862087113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.238650121699811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.16578858654045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2417636330736, 11.100805313420308`], 
                Complex[133.63240767607033`, -10.218396911961511`]}, 2 -> {
                Complex[163.776862087113, -11.238650121699811`], 
                Complex[133.93336948207866`, -31.16578858654045]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2774607224992615, -2.417700606806602}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.245345602464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.274663157243593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.05696195712113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.77167046658727`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.326833677611646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.245345602464, 11.274663157243593`], 
                Complex[133.6366107628227, -10.05696195712113]}, 2 -> {
                Complex[163.77167046658727`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.326833677611646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.28043686515247196`, -2.5479900363492836`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2487089558695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.444427821247759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.89940136633527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7667175920338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.582531307820627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9179840286246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.484001751500106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "C3", 
             Association[1 -> {
                Complex[163.2487089558695, 11.444427821247759`], 
                Complex[133.64057992958772`, -9.89940136633527]}, 2 -> {
                Complex[163.7667175920338, -11.582531307820627`], 
                Complex[133.9179840286246, -31.484001751500106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2833668174748191, -2.68019317708494}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2518724540805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.610307537645536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7619842266485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "C3", 
             Association[1 -> {
                Complex[163.2518724540805, 11.610307537645536`], 
                Complex[133.64433436948318`, -9.745517953028422]}, 2 -> {
                Complex[163.7619842266485, -11.748537908691581`], 
                Complex[133.91065826653698`, -31.637490045704613`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2862528718228014, -2.814266838879752}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.25485273533127`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.77249398761309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75745327301976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.91084965765839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "C3", 
             Association[1 -> {
                Complex[163.25485273533127`, 11.77249398761309], 
                Complex[133.64789115029092`, -9.595130182053287]}, 2 -> {
                Complex[163.75745327301976`, -11.91084965765839], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2890971389691452, -2.950169931229104}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2576646121618`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.931164084638935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548408`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75310947547112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.069643504773667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.93413966386116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2576646121618, 11.931164084638935`], 
                Complex[133.65126550803504`, -9.448070485548408]}, 2 -> {
                Complex[163.75310947547112`, -12.069643504773667`], 
                Complex[133.89665253982204`, -31.93413966386116]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2919015675509848, -3.08786330390203}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26032131919624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7489391715357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.225083174088782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.07762370747607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.26032131919624`, 12.086481517469739`], 
                Complex[133.65447109241083`, -9.304183805581669]}, 2 -> {
                Complex[163.7489391715357, -12.225083174088782`], 
                Complex[133.88994274008314`, -32.07762370747607]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2946679609234814, -3.2273096039921207`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26283472113678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74493008325814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "C3", 
             Association[1 -> {
                Complex[163.26283472113678`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[163.74493008325814`, -12.377320504803174`], 
                Complex[133.8834108897335, -32.21807613513113]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2973979918297737, -3.3684731472587885`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2652154882986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74107114099544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "C3", 
             Association[1 -> {
                Complex[163.2652154882986, 12.387654897960461`], 
                Complex[133.66042381437185`, -9.025364372558757]}, 2 -> {
                Complex[163.74107114099544`, -12.526496621998465`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.30009321522311944`, -3.5113198019682437`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2674732455004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.533783342972365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.890173430857475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73735233390101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.672742962762172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.2674732455004, 12.533783342972365`], 
                Complex[133.6631920229149, -8.890173430857475]}, 2 -> {
                Complex[163.73735233390101`, -12.672742962762172`], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3027550795172311, -3.655816883710712}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26961669895428`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7337645824435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.26961669895428`, 12.677106047334807`], 
                Complex[133.66583387467648`, -8.757637305564256]}, 2 -> {
                Complex[163.7337645824435, -12.816182179005438`], 
                Complex[133.86477325877703`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.30538493649445336`, -3.8019330598921024`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27165374489172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.817737645166858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678214`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73029962922303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.956928934660269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.27165374489172`, 12.817737645166858`], 
                Complex[133.66835762313937`, -8.627647360678214]}, 2 -> {
                Complex[163.73029962922303`, -12.956928934660269`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3079840500616961, -3.9496382627828255`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27359156294804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.500101853051339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7269499450588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.095090612015007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "C3", 
             Association[1 -> {
                Complex[163.27359156294804`, 12.955785489901578`], 
                Complex[133.67077079273932`, -8.500101853051339]}, 2 -> {
                Complex[163.7269499450588, -13.095090612015007`], 
                Complex[133.8530533114799, -32.87924061335592]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.31055360401362514`, -4.098903610160464}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27543669676655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.72370864788658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.004018457106575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.27543669676655`, 13.091350282096839`], 
                Complex[133.67308025959395`, -8.374905338778804]}, 2 -> {
                Complex[163.72370864788658`, -13.230767939566048`], 
                Complex[133.84738105530036`, -33.004018457106575`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3130947089380293, -4.249701332712688}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27719512383507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67529232155744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.251968143863518`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7205694324496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.364055551814676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477616`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.27719512383507`, 13.224526629192962`], 
                Complex[133.67529232155744`, -8.251968143863518]}, 2 -> {
                Complex[163.7205694324496, -13.364055551814676`], 
                Complex[133.8418248696247, -33.12653484477616]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.315608408374947, -4.402004707476376}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2788723162124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.35540354604583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71752650912524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.495042489836637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902983`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "C3", 
             Association[1 -> {
                Complex[163.2788723162124, 13.35540354604583], 
                Complex[133.67741275923174`, -8.131205890824086]}, 2 -> {
                Complex[163.71752650912524`, -13.495042489836637`], 
                Complex[133.83637862409034`, -33.24687418902983]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3180956843269251, -4.555787996681541}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28047329351344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167398`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71457455051592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.623812650126242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.365116029557846`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "C3", 
             Association[1 -> {
                Complex[163.28047329351344`, 13.484064903736138`], 
                Complex[133.67944688928384`, -8.012539074167398]}, 2 -> {
                Complex[163.71457455051592`, -13.623812650126242`], 
                Complex[133.83103666267402`, -33.365116029557846`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3205574622010993, -4.711026391448023}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28200266929107`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71170864466583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.48133541482063`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "C3", 
             Association[1 -> {
                Complex[163.28200266929107`, 13.610589833057865`], 
                Complex[133.68139961119044`, -7.895892678682291]}, 2 -> {
                Complex[163.71170864466583`, -13.750445188118116`], 
                Complex[133.82579375652693`, -33.48133541482063]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3229946152540088, -4.867695959850229}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2834646917637`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.735053088170234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68327544834887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.781195835377185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70892425395203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8206450624651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.59560324614746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2834646917637, 13.735053088170234`], 
                Complex[133.68327544834887`, -7.781195835377185]}, 2 -> {
                Complex[163.70892425395203`, -13.875014881870271`], 
                Complex[133.8206450624651, -33.59560324614746]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3254079685972095, -5.025773598923212}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28486327968363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70621717885442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.997592460624668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.70798658864134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.28486327968363`, 13.857525375128327`], 
                Complex[133.68507858433867`, -7.668381510610166]}, 2 -> {
                Complex[163.70621717885442`, -13.997592460624668`], 
                Complex[133.81558608632903`, -33.70798658864134]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.32779830281783057`, -5.18523699023376}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2862020540158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68681289499762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.55738622457017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7035835259332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.118244902313043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8106126505474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.81854895273081`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2862020540158, 13.978073649360802`], 
                Complex[133.68681289499762`, -7.55738622457017]}, 2 -> {
                Complex[163.7035835259332, -14.118244902313043`], 
                Complex[133.8106126505474, -33.81854895273081]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.330166357256308, -5.346064558682746}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28748436599128`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.4481497957836655`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70101967944905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.28748436599128`, 14.096761385616206`], 
                Complex[133.68848197687097`, -7.4481497957836655`]}, 2 -> {
                Complex[163.70101967944905`, -14.237035703530262`], 
                Complex[133.80572086534593`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3325128329810007, -5.508235434242755}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28871332201555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.21364882343601`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.3406151087588825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69852227614442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.35402512503277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.28871332201555`, 14.21364882343601], 
                Complex[133.69008917251037`, -7.3406151087588825`]}, 2 -> {
                Complex[163.69852227614442`, -14.35402512503277], 
                Complex[133.80090710312305`, -34.03444852404853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.33483839549334043`, -5.6717294163677305`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28989180583767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69608818277845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.79616797558796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.13989716530639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.28989180583767`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[163.69608818277845`, -14.469270415426754`], 
                Complex[133.79616797558796`, -34.13989716530639]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3371436771924203, -5.836526940839223}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29102249833014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69371447606676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.243748101320996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.29102249833014`, 14.442248908399693`], 
                Complex[133.69313013823358`, -7.130436575951601]}, 2 -> {
                Complex[163.69371447606676`, -14.582826015372707`], 
                Complex[133.7915003133145, -34.243748101320996`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.33942927962465824`, -6.002609048839373}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2921078951751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.554067776191998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672555`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69139842472714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.694743744345221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7869011474127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "C3", 
             Association[1 -> {
                Complex[163.2921078951751, 14.554067776191998`], 
                Complex[133.69456951471147`, -7.027692013672555]}, 2 -> {
                Complex[163.69139842472714`, -14.694743744345221`], 
                Complex[133.7869011474127, -34.34605047512348]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34169577554093217`, -6.169957358061877}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29315032271526`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69595825198883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.926447421338327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68913747337317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78236769306173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.446851106957446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.29315032271526`, 14.664299144668377`], 
                Complex[133.69595825198883`, -6.926447421338327]}, 2 -> {
                Complex[163.68913747337317`, -14.805072971738813`], 
                Complex[133.78236769306173`, -34.446851106957446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34394371078147906`, -6.33855403569183}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2941519521878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.77299007177116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68692922803774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.913860773896733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "C3", 
             Association[1 -> {
                Complex[163.2941519521878, 14.77299007177116], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[163.68692922803774`, -14.913860773896733`], 
                Complex[133.77789733468606`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3461736060049014, -6.508381773102096}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29511481253365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.88018546723748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69859312781242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.728281700596741`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6847714431318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644123692063744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "C3", 
             Association[1 -> {
                Complex[163.29511481253365`, 14.88018546723748], 
                Complex[133.69859312781242`, -6.728281700596741]}, 2 -> {
                Complex[163.6847714431318, -15.021152078455035`], 
                Complex[133.7734876125809, -34.644123692063744`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.34838595827731006`, -6.679423762128641}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29604080194576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183247`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6826620096745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.126989797234097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7691362108228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.74067895150922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.29604080194576`, 14.985928225471852`], 
                Complex[133.69984356428586`, -6.631277315183247]}, 2 -> {
                Complex[163.6826620096745, -15.126989797234097`], 
                Complex[133.7691362108228, -34.74067895150922]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3505812425354457, -6.85166367280077}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29693169830156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.5356061437843405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68059894464983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.231414948770267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76484094632082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "C3", 
             Association[1 -> {
                Complex[163.29693169830156`, 15.090259348061176`], 
                Complex[133.70105197999624`, -6.5356061437843405`]}, 2 -> {
                Complex[163.68059894464983`, -15.231414948770267`], 
                Complex[133.76484094632082`, -34.83589932329275]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3527599129352034, -7.025085632413676}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29778916860275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.193218056900896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67858038136492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.334466771459132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.29778916860275`, 15.193218056900896`], 
                Complex[133.70222021135814`, -6.441230995764474]}, 2 -> {
                Complex[163.67858038136492`, -15.334466771459132`], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3549224040961911, -7.199674205841381}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2986147775331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.29484189879971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67660456069984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.2986147775331, 15.29484189879971], 
                Complex[133.7033499865708, -6.348116269010088]}, 2 -> {
                Complex[163.67660456069984`, -15.436182828175923`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.357069132253178, -7.375414376997453}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2994099952287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.395166842334241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67466982315278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.53659910314539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2994099952287, 15.395166842334241`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[163.67466982315278`, -15.53659910314539], 
                Complex[133.75227193555395`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3592004963206869, -7.552291531359044}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3001762043455`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.494227367644923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67277460159679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7481817164674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.204152917056646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.3001762043455, 15.494227367644923`], 
                Complex[133.70550058771101`, -6.165533069493565]}, 2 -> {
                Complex[163.67277460159679`, -15.635750091752156`], 
                Complex[133.7481817164674, -35.204152917056646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36131687888110314`, -7.730291439477428}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30091470649666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769498`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.076000541975269`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67091741467345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.733668883910747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.293226612919796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30091470649666`, 15.592056549792122`], 
                Complex[133.70652439769498`, -6.076000541975269]}, 2 -> {
                Complex[163.67091741467345`, -15.733668883910747`], 
                Complex[133.74413839370675`, -35.293226612919796`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36341864710050736`, -7.909400241404805}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30162672812602`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70751573240688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.987600173789694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6690968607587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.830387241551286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30162672812602`, 15.688686136228515`], 
                Complex[133.70751573240688`, -5.987600173789694]}, 2 -> {
                Complex[163.6690968607587, -15.830387241551286`], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36550615358058786`, -8.089604431973337}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30231342587385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.784146618887455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.9003030540343815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6673116124424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.925935670720543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73618625174637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.46800182936364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "C3", 
             Association[1 -> {
                Complex[163.30231342587385`, 15.784146618887455`], 
                Complex[133.70847588612014`, -5.9003030540343815`]}, 2 -> {
                Complex[163.6673116124424, -15.925935670720543`], 
                Complex[133.73618625174637`, -35.46800182936364]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3675797371504694, -8.270890846867337}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30297589148626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66556041147118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "C3", 
             Association[1 -> {
                Complex[163.30297589148626`, 15.878467301338127`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[163.66556041147118`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3696397236043986, -8.45324664943517}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3036151563131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.971676361413378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71030748519513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.728908493102031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6638420641087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.11363888689164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "C3", 
             Association[1 -> {
                Complex[163.3036151563131, 15.971676361413378`], 
                Complex[133.71030748519513`, -5.728908493102031]}, 2 -> {
                Complex[163.6638420641087, -16.11363888689164], 
                Complex[133.72840390066767`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37168642638952115`, -8.63665931819097}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30423219543457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.64475863285114`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66215543687335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "C3", 
             Association[1 -> {
                Complex[163.30423219543457`, 16.063800909678434`], 
                Complex[133.71118119033963`, -5.64475863285114]}, 2 -> {
                Complex[163.66215543687335`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37372014724792785`, -8.821116634960807}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30482793145168`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.154867044072365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7120282423221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66049945261796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.296999905203638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72078084168677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30482793145168`, 16.154867044072365`], 
                Complex[133.7120282423221, -5.561607075648972]}, 2 -> {
                Complex[163.66049945261796`, -16.296999905203638`], 
                Complex[133.72078084168677`, -35.80483537920644]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37574117681609714`, -9.006606673631692}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30540323797229`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.24489990102471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65887308691825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.387116784982247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71702603519051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "C3", 
             Association[1 -> {
                Complex[163.30540323797229`, 16.24489990102471], 
                Complex[133.71284963153286`, -5.479429991022453]}, 2 -> {
                Complex[163.65887308691825`, -16.387116784982247`], 
                Complex[133.71702603519051`, -35.88654323957749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.37774979518613855`, -9.193117789464297}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3059589428217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.33392370332042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71364629891158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.39820441529854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65727536474287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754884988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.967298179972964`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "C3", 
             Association[1 -> {
                Complex[163.3059589428217, 16.33392370332042], 
                Complex[133.71364629891158`, -5.39820441529854]}, 2 -> {
                Complex[163.65727536474287`, -16.476223863094262`], 
                Complex[133.71330754884988`, -35.967298179972964`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3797462724305711, -9.380638608934282}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3064958310019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.421961804962738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65570535737885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3064958310019, 16.421961804962738`], 
                Complex[133.71441913905537`, -5.317908209063045]}, 2 -> {
                Complex[163.65570535737885`, -16.564344505422593`], 
                Complex[133.70962432476176`, -36.04712235702883]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38173086909447357`, -9.569158020068967}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30701464742387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.5090367332606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249019`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65416217958912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.65150125087593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267105`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30701464742387`, 16.5090367332606], 
                Complex[133.71516900309246`, -5.238520017249019]}, 2 -> {
                Complex[163.65416217958912`, -16.65150125087593], 
                Complex[133.70597535216766`, -36.12603714267105]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38370383665679747`, -9.758665163249036}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30751609943115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6526449869827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.73771585091723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70235966468252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.20406316160487`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30751609943115`, 16.595170228347317`], 
                Complex[133.71589670134117`, -5.160019231659067]}, 2 -> {
                Complex[163.6526449869827, -16.73771585091723], 
                Complex[133.70235966468252`, -36.20406316160487]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.38566541796399684`, -9.949149422447151}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30800085913484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71660300577298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6511529735775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.82300930670975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6987763377227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.28122032654667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "C3", 
             Association[1 -> {
                Complex[163.30800085913484`, 16.680383280319464`], 
                Complex[133.71660300577298`, -5.082385955742662]}, 2 -> {
                Complex[163.6511529735775, -16.82300930670975], 
                Complex[133.6987763377227, -36.28122032654667]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3876158476363451, -10.140600416877097`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30846956557582`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6496853695408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.90740190405787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861177`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.35752787136576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30846956557582`, 16.764696164168555`], 
                Complex[133.71728865229744`, -5.005600971465146]}, 2 -> {
                Complex[163.6496853695408, -16.90740190405787], 
                Complex[133.6952244861177, -36.35752787136576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3895553524512018, -10.333007993029538`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30892282672824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6482414390911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.990913246296902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.30892282672824`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118656]}, 2 -> {
                Complex[163.6482414390911, -16.990913246296902`], 
                Complex[133.69170326188944`, -36.43300438228255]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3914841517028031, -10.526362217071567`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30936122135927`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6468204785474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.073562285278378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6882118521846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50766782726147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "C3", 
             Association[1 -> {
                Complex[163.30936122135927`, 16.93069914732912], 
                Complex[133.71860074752374`, -4.854502212938122]}, 2 -> {
                Complex[163.6468204785474, -17.073562285278378`], 
                Complex[133.6882118521846, -36.50766782726147]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.39340245754195785`, -10.72065336758933}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30978530075578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396218`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64542181451625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.155367350584477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.58153558372544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "C3", 
             Association[1 -> {
                Complex[163.30978530075578`, 17.012426507651817`], 
                Complex[133.7192285060807, -4.780153123396218]}, 2 -> {
                Complex[163.64542181451625`, -17.155367350584477`], 
                Complex[133.68474947734978`, -36.58153558372544]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3953104752953657, -10.915871928653997`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31019559032947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64404480220196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31019559032947`, 17.093328278637614`], 
                Complex[133.71983822997944`, -4.70658164106197]}, 2 -> {
                Complex[163.64404480220196`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.39720840376748406`, -11.112008583193267`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31059259111072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.173421616831476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72043050380475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.633771506916521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64268882383246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353258`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31059259111072`, 17.173421616831476`], 
                Complex[133.72043050380475`, -4.633771506916521]}, 2 -> {
                Complex[163.64268882383246`, -17.31651593099673], 
                Complex[133.67790886901938`, -36.72695074353258]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.39909643552519974`, -11.309054206651014`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31097678113926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.25272313490318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6413532871904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31097678113926`, 17.25272313490318], 
                Complex[133.72100588678245`, -4.561706978028415]}, 2 -> {
                Complex[163.6413532871904, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.40097475716709646`, -11.506999860919729`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3113486167611`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.331248924894496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72156491416428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64003762424196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.47449418860847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67117579833888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3113486167611, 17.331248924894496`], 
                Complex[133.72156491416428`, -4.490372805498023]}, 2 -> {
                Complex[163.64003762424196`, -17.47449418860847], 
                Complex[133.67117579833888`, -36.86937802828386]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4028435495774311, -11.705836788530716`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31170853383765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.409014580215214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63874128985492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.552334396036265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.93950908610309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31170853383765`, 17.409014580215214`], 
                Complex[133.72210809852083`, -4.419754213588025]}, 2 -> {
                Complex[163.63874128985492`, -17.552334396036265`], 
                Complex[133.66784794577543`, -36.93950908610309]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4047029881668373, -11.905556407088374`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31205694887507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.48603521646938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6374637606001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.629428981138844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.008937686204405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31205694887507`, 17.48603521646938], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[163.6374637606001, -17.629428981138844`], 
                Complex[133.66454505465833`, -37.008937686204405`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4065532431003526, -12.10615030393552}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31239426007943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.562325491186662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63620453362884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.70579261009809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31239426007943`, 17.562325491186662`], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[163.63620453362884`, -17.70579261009809], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4083944795127132, -12.307610231037936`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31272084834353`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.637899622528057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878537`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.634963125622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.781439509544892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.14574269865576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31272084834353`, 17.637899622528057`], 
                Complex[133.72364740379095`, -4.212050853878537]}, 2 -> {
                Complex[163.634963125622, -17.781439509544892`], 
                Complex[133.65801181266102`, -37.14574269865576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.410226857713132, -12.50992810007653}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31303707817023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.712771407030306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63373907180392`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.85638348430743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.21314567761614`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "C3", 
             Association[1 -> {
                Complex[163.31303707817023`, 17.712771407030306`], 
                Complex[133.7241319288729, -4.144155620061895]}, 2 -> {
                Complex[163.63373907180392`, -17.85638348430743], 
                Complex[133.65478034294642`, -37.21314567761614]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41205053337941927`, -12.713095977736637`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3133432985372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996313`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63253192501676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.3133432985372, 17.786954236448395`], 
                Complex[133.72460287329903`, -4.076908528996313]}, 2 -> {
                Complex[163.63253192501676`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41386565774164347`, -12.917106081184505`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31363984370773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.86046111375152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.01029726309017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63134125485357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6483850579582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.3460160901857`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "C3", 
             Association[1 -> {
                Complex[163.31363984370773`, 17.86046111375152], 
                Complex[133.72506063642794`, -4.01029726309017]}, 2 -> {
                Complex[163.63134125485357`, -18.004215870320166`], 
                Complex[133.6483850579582, -37.3460160901857]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41567237775709537`, -13.121950773721581`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31392703399072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.93330466832352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9443098592571175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63016664684008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.07712992966061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "C3", 
             Association[1 -> {
                Complex[163.31392703399072`, 17.93330466832352], 
                Complex[133.72550560195975`, -3.9443098592571175`]}, 2 -> {
                Complex[163.63016664684008`, -18.07712992966061], 
                Complex[133.64522023907955`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41747083627664033`, -13.32762256060776}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31420517645438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.00549717041573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870841`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.878934695199984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62900770166812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31420517645438`, 18.00549717041573], 
                Complex[133.72593813870841`, -3.878934695199984]}, 2 -> {
                Complex[163.62900770166812`, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41926117220240194`, -13.534114085045433`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3144745655963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.077050544896366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72635860132817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.814160476362023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62786403447276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.221015184158826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63895386837342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.54066255110091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3144745655963, 18.077050544896366`], 
                Complex[133.72635860132817`, -3.814160476362023]}, 2 -> {
                Complex[163.62786403447276`, -18.221015184158826`], 
                Complex[133.63895386837342`, -37.54066255110091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4210435206378286, -13.741418124316377`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31473548397335`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.14797638433758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.749976223506348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62673527415205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31473548397335`, 18.14797638433758], 
                Complex[133.72676733099715`, -3.749976223506348]}, 2 -> {
                Complex[163.62673527415205`, -18.292009911552334`], 
                Complex[133.6358514127178, -37.60434783208481]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4228180130309675, -13.949527586064503`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31498820279393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62562106272594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63276886608713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31498820279393`, 18.21828596147894], 
                Complex[133.72716465606138`, -3.686371260886986]}, 2 -> {
                Complex[163.62562106272594`, -18.362387852255672`], 
                Complex[133.63276886608713`, -37.66745274304553]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4245847773105191, -14.158435504716968`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3152329824754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.28799024110279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.62333520497781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62452105473145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.43215997808431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322924`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.729987678324505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3152329824754, 18.28799024110279], 
                Complex[133.7275508926416, -3.62333520497781]}, 2 -> {
                Complex[163.62452105473145`, -18.43215997808431], 
                Complex[133.62970581322924`, -37.729987678324505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4263439380152982, -14.368135038037943`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3154700731691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.35709989135509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7279263452058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.5608579537275773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6234349166525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.501336964078423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.791962750599865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.3154700731691, 18.35709989135509], 
                Complex[133.7279263452058, -3.5608579537275773`]}, 2 -> {
                Complex[163.6234349166525, -18.501336964078423`], 
                Complex[133.62666185240195`, -37.791962750599865`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.42809561641809574`, -14.578619463807948`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31569971525462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6223623263809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.569929199304017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31569971525462`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[163.6223623263809, -18.569929199304017`], 
                Complex[133.62363659478487`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.42983993064377096`, -14.7898821766239}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31592213980636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6213029727077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.63794679715963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.620629663924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31592213980636`, 18.493576557437454`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[163.6213029727077, -18.63794679715963], 
                Complex[133.620629663924, -37.91427240958484]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4315769957811761, -15.001916684813681`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31613756903312`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.56096352111073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62025655484186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.705399605215987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61764069520532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "C3", 
             Association[1 -> {
                Complex[163.31613756903312`, 18.56096352111073], 
                Complex[133.72899087982017`, -3.376682017581235]}, 2 -> {
                Complex[163.62025655484186`, -18.705399605215987`], 
                Complex[133.61764069520532`, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43330692399132936`, -15.214716607460433`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3163462166933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.627795770329765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61922278195527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61466933535638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.03445736625228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "C3", 
             Association[1 -> {
                Complex[163.3163462166933, 18.627795770329765`], 
                Complex[133.72932602622453`, -3.316344244925613]}, 2 -> {
                Complex[163.61922278195527`, -18.772297214614134`], 
                Complex[133.61466933535638`, -38.03445736625228]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4350298246093353, -15.428275671531514`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31654828848707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.694082642534067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7296517540468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61820137275217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.09377564761935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31654828848707`, 18.694082642534067`], 
                Complex[133.7296517540468, -3.25651864598262]}, 2 -> {
                Complex[163.61820137275217`, -18.838648969045266`], 
                Complex[133.61171524197408`, -38.09377564761935]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43674580424272386`, -15.642587709107554`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31674398242674`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.197196607875771`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61719205506083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6087780830763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.152589369857864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31674398242674`, 18.75983323641723], 
                Complex[133.72996830818994`, -3.197196607875771]}, 2 -> {
                Complex[163.61719205506083`, -18.904463973336576`], 
                Complex[133.6087780830763, -38.152589369857864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4384549668652988, -15.857646654707265`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31693348918697`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.82505642013447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138369736463453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6161945654476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.969751101660396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31693348918697`, 18.82505642013447], 
                Complex[133.73027592511528`, -3.138369736463453]}, 2 -> {
                Complex[163.6161945654476, -18.969751101660396`], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.44015741390655244`, -16.073446542703625`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31711699243615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.88976083915551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.080029848884582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61520864885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.034519005391328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.26873653979493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "C3", 
             Association[1 -> {
                Complex[163.31711699243615`, 18.88976083915551], 
                Complex[133.73057483320838`, -3.080029848884582]}, 2 -> {
                Complex[163.61520864885, -19.034519005391328`], 
                Complex[133.60295329038402`, -38.26873653979493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4418532443373004, -16.289981504827953`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31729466915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.953954923781044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61423405822947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.09877612062455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.32608616746591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "C3", 
             Association[1 -> {
                Complex[163.31729466915, 18.953954923781044`], 
                Complex[133.7308652531255, -3.0221689664234717`]}, 2 -> {
                Complex[163.61423405822947`, -19.09877612062455], 
                Complex[133.60006504101256`, -38.32608616746591]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4435425547521327, -16.507245767757478`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31746668990834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.017646896340647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9647793076770235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61327055424135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.16253067537683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31746668990834`, 19.017646896340647`], 
                Complex[133.73114739812223`, -2.9647793076770235`]}, 2 -> {
                Complex[163.61327055424135`, -19.16253067537683], 
                Complex[133.59719249422423`, -38.38296360992766]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4452254394476591, -16.725233650783686`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3176332191766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.080844778087723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.90785328200948`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6123179049217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.225790696484122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.4393764666446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3176332191766, 19.080844778087723`], 
                Complex[133.73142147436542`, -2.90785328200948]}, 2 -> {
                Complex[163.6123179049217, -19.225790696484122`], 
                Complex[133.59433536417916`, -38.4393764666446]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4469019904979114, -16.943939563557176`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31779441557222`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.14355639580752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6113758853897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31779441557222`, 19.14355639580752], 
                Complex[133.73168768122898`, -2.8513834832794664`]}, 2 -> {
                Complex[163.6113758853897, -19.288564016212078`], 
                Complex[133.59149337320662`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.44857229782670566`, -17.1633580039066}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31795043211764`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.20578938815203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7953626838262657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6104442775649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.35085827859341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "C3", 
             Association[1 -> {
                Complex[163.31795043211764`, 19.20578938815203], 
                Complex[133.73194621157515`, -2.7953626838262657`]}, 2 -> {
                Complex[163.6104442775649, -19.35085827859341], 
                Complex[133.58866625149176`, -38.55083790353876]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4502364492766781, -17.383483555728322`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31810141648003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.26755121171575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287020946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60952286989846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.605900783286515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31810141648003`, 19.26755121171575], 
                Complex[133.73219725202154`, -2.7397838287020946`]}, 2 -> {
                Complex[163.60952286989846`, -19.41268094550624], 
                Complex[133.58585373677684`, -38.605900783286515`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4518945306755932, -17.60431088694373}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31824751119916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6846400301384143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60861145711593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.6605276877375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31824751119916`, 19.328849146864805`], 
                Complex[133.73244098319515`, -2.6846400301384143`]}, 2 -> {
                Complex[163.60861145711593`, -19.47403930250476], 
                Complex[133.58305557407584`, -38.6605276877375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4535466259000935, -17.82583474752192}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31838885390343`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7326775799737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60770983997617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.53494046441777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.71472535094414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "C3", 
             Association[1 -> {
                Complex[163.31838885390343`, 19.389690303331637`], 
                Complex[133.7326775799737, -2.6299245622347733`]}, 2 -> {
                Complex[163.60770983997617`, -19.53494046441777], 
                Complex[133.58027151540554`, -38.71472535094414]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.45519281693663566`, -18.048049967564697`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31852557751546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60681782503693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.59539138072089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "C3", 
             Association[1 -> {
                Complex[163.31852557751546`, 19.45008162558661], 
                Complex[133.73290721171557`, -2.5756308558594796`]}, 2 -> {
                Complex[163.60681782503693`, -19.59539138072089], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4568331839406931, -18.27095145545175}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3186578104471`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.510029897997104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.521752493751901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60593522443511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.65539884069858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.821859110255915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.3186578104471, 19.510029897997104`], 
                Complex[133.73313004247825`, -2.521752493751901]}, 2 -> {
                Complex[163.60593522443511`, -19.65539884069858], 
                Complex[133.57474475168777`, -38.821859110255915`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4584678052925761, -18.49453419604338}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31878567678518`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.56954174978439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.468283205816789`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6050618556758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.71496947840288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31878567678518`, 19.56954174978439], 
                Complex[133.73334623122685`, -2.468283205816789]}, 2 -> {
                Complex[163.6050618556758, -19.71496947840288], 
                Complex[133.57200158341104`, -38.87480790939813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.46009675765171715`, -18.71879324893866}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3189092964682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.628623659787667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73355593203246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.415216864601611`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60419754143146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3189092964682, 19.628623659787667`], 
                Complex[133.73355593203246`, -2.415216864601611]}, 2 -> {
                Complex[163.60419754143146`, -19.774109777419557`], 
                Complex[133.5692715922459, -38.92735288260375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4617201160089956, -18.943723746786947`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31902878545432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.362547480948237`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6033421093502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.832826075450342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.979500026576446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31902878545432`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.362547480948237]}, 2 -> {
                Complex[163.6033421093502, -19.832826075450342`], 
                Complex[133.56655456156514`, -38.979500026576446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4633379537366175, -19.169320893650518`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31914425588116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3102691998110743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60249539187296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "C3", 
             Association[1 -> {
                Complex[163.31914425588116`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.3102691998110743`]}, 2 -> {
                Complex[163.60249539187296`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4649503426361485, -19.395579963416505`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31925581621843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.80335236672411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60165722605888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.94901131621615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "C3", 
             Association[1 -> {
                Complex[163.31925581621843`, 19.80335236672411], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[163.60165722605888`, -19.94901131621615], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.46655735298509676`, -19.62249629825619}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31936357141305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.860776447031697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.206863171477252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60082745341847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.00649224376953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55847914922663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.31936357141305`, 19.860776447031697`], 
                Complex[133.73433277630326`, -2.206863171477252]}, 2 -> {
                Complex[163.60082745341847`, -20.00649224376953], 
                Complex[133.55847914922663`, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.46815905358139326`, -19.850065307130127`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31946762302746`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.91780087836711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60000591975424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.06357314798203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31946762302746`, 19.91780087836711], 
                Complex[133.73451218992716`, -2.155724349292754]}, 2 -> {
                Complex[163.60000591975424`, -20.06357314798203], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4697555117862799, -20.078282464336866`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31956806937163`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59919247500852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.12025970000922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800312`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31956806937163`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[163.59919247500852`, -20.12025970000922], 
                Complex[133.55315661583612`, -39.23446901800312]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4713467935658053, -20.307143308104315`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.319665005629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.030673339891987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7348541729491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0545482986917456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59838697311696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "C3", 
             Association[1 -> {
                Complex[163.319665005629, 20.030673339891987`], 
                Complex[133.7348541729491, -2.0545482986917456`]}, 2 -> {
                Complex[163.59838697311696`, -20.176557449202846`], 
                Complex[133.55051310011325`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.47293296353050146`, -20.53664343922166}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31975852397647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7350169880388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.00450069857931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5975892718708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232471826623705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "C3", 
             Association[1 -> {
                Complex[163.31975852397647`, 20.086532342147553`], 
                Complex[133.7350169880388, -2.00450069857931]}, 2 -> {
                Complex[163.5975892718708, -20.232471826623705`], 
                Complex[133.54788117531726`, -39.333867334968495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4745140849738669, -20.76677851971066}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31984871369912`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73517451010144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59679923278136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54526066470336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "C3", 
             Association[1 -> {
                Complex[163.31984871369912`, 20.14201364645422], 
                Complex[133.73517451010144`, -1.9548066511051871`]}, 2 -> {
                Complex[163.59679923278136`, -20.288008148422218`], 
                Complex[133.54526066470336`, -39.3830324278985]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.47609021990951356`, -20.99754427153473}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3199356612996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.197122453313998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9054612411862166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59601672095425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3199356612996, 20.197122453313998`], 
                Complex[133.73532685336215`, -1.9054612411862166`]}, 2 -> {
                Complex[163.59601672095425`, -20.343171619103263`], 
                Complex[133.54265139579022`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.47766142910641, -21.228936475344643`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320019450603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59524160496576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.397967334670057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.480319094081715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.320019450603, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608618`]}, 2 -> {
                Complex[163.59524160496576`, -20.397967334670057`], 
                Complex[133.54005320021986`, -39.480319094081715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.47922777212403894`, -21.460950969259333`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32010016285645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.3062428375576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849099015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59447375674608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.45240028565977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "C3", 
             Association[1 -> {
                Complex[163.32010016285645`, 20.3062428375576], 
                Complex[133.73561644435446`, -1.8077971849099015`]}, 2 -> {
                Complex[163.59447375674608`, -20.45240028565977], 
                Complex[133.53746591362483`, -39.52845020484526]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4807893073447695, -21.693583647680835`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32017787682477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5937130514674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.506475360070965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.576246028452815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "C3", 
             Association[1 -> {
                Complex[163.32017787682477`, 20.360264285794972`], 
                Complex[133.73575390485036`, -1.7594692110781658`]}, 2 -> {
                Complex[163.5937130514674, -20.506475360070965`], 
                Complex[133.53488937550074`, -39.576246028452815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4823460920065707, -21.926830460141755`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320252668882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5929593674352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.5601973461902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.6237110918168`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.320252668882, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931463`]}, 2 -> {
                Complex[163.5929593674352, -20.5601973461902], 
                Complex[133.53232342908268`, -39.6237110918168]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4838981822337353, -22.160687410184654`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32032461309848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59221258598674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52976792122885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32032461309848`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763436`]}, 2 -> {
                Complex[163.59221258598674`, -20.613570935319654`], 
                Complex[133.52976792122885`, -39.67084982986853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.48544563306658056`, -22.395150554271826`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32039378132473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73613816201268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59147259138922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.666600724412163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658805997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32039378132473`, 20.52023078674261], 
                Complex[133.73613816201268`, -1.6164475267435492`]}, 2 -> {
                Complex[163.59147259138922`, -20.666600724412163`], 
                Complex[133.527222702305, -39.71766658805997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.48698849849063713`, -22.63021600072466}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32046024327133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59073927074817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.71929121861588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5246876260788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.76416562477979`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "C3", 
             Association[1 -> {
                Complex[163.32046024327133`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[163.59073927074817`, -20.71929121861588], 
                Complex[133.5246876260788, -39.76416562477979]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4885268314641615, -22.865879908691394`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3205240665855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.625172630255136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59001251391317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "C3", 
             Association[1 -> {
                Complex[163.3205240665855, 20.625172630255136`], 
                Complex[133.73637185511262`, -1.5226917500597743`]}, 2 -> {
                Complex[163.59001251391317`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.49006068394544905`, -23.102138487142692`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32058531692476`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.677146044602367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7364822323083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4762789595872228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58929221339187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.823671898594245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51964733316362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.856227145969456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "C3", 
             Association[1 -> {
                Complex[163.32058531692476`, 20.677146044602367`], 
                Complex[133.7364822323083, -1.4762789595872228`]}, 2 -> {
                Complex[163.58929221339187`, -20.823671898594245`], 
                Complex[133.51964733316362`, -39.856227145969456`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4915901069188117, -23.338987993893483`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3206440580269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.728793469886885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58857826426507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.875370657359298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51714184008853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.901797732519626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "C3", 
             Association[1 -> {
                Complex[163.3206440580269, 20.728793469886885`], 
                Complex[133.7365884127948, -1.4301708674222517`]}, 2 -> {
                Complex[163.58857826426507`, -20.875370657359298`], 
                Complex[133.51714184008853`, -39.901797732519626`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.49311515041936155`, -23.576424734650786`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32070035177745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.780119064461577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73669048085137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3843635465213247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5878705641061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.926747271733444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51464593674876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.9470668060475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "C3", 
             Association[1 -> {
                Complex[163.32070035177745`, 20.780119064461577`], 
                Complex[133.73669048085137`, -1.3843635465213247`]}, 2 -> {
                Complex[163.5878705641061, -20.926747271733444`], 
                Complex[133.51464593674876`, -39.9470668060475]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.494635863557965, -23.81444506208636}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32075425827455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3388531459104875`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58716901290316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51215949242192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.99203822311737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "C3", 
             Association[1 -> {
                Complex[163.32075425827455`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.3388531459104875`]}, 2 -> {
                Complex[163.58716901290316`, -20.977805823117315`], 
                Complex[133.51215949242192`, -39.99203822311737]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4961522945442078, -24.05304537493344}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3208058358904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.881820995702782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58647351298407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.028550314683574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50968237921512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.03671576612024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "C3", 
             Association[1 -> {
                Complex[163.3208058358904, 20.881820995702782`], 
                Complex[133.73688260585354`, -1.293635888714526]}, 2 -> {
                Complex[163.58647351298407`, -21.028550314683574`], 
                Complex[133.50968237921512`, -40.03671576612024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.49766449070989943`, -24.29222211710676}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32085514133112`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73697282063236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.248708070250089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58578396894472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.32085514133112`, 20.9322052560464], 
                Complex[133.73697282063236`, -1.248708070250089]}, 2 -> {
                Complex[163.58578396894472`, -21.078984673387104`], 
                Complex[133.50721447198234`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.49917249853027607`, -24.53197177684496}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32090222969342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.982283536987506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5851002875799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.12911275191012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32090222969342`, 20.982283536987506`], 
                Complex[133.73705923878364`, -1.2040660561803698`]}, 2 -> {
                Complex[163.5851002875799, -21.12911275191012], 
                Complex[133.50475564824438`, -40.12520400001161]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.500676363646283, -24.772290885875126`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32094715451944`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.03205961571474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58442237781642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32094715451944`, 21.03205961571474], 
                Complex[133.7371419342688, -1.1597062807288623`]}, 2 -> {
                Complex[163.58442237781642`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5021761308844697, -25.01317601859819}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32098996784921`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7372209791803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1156252449499178`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58375015064937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.228465119017653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "C3", 
             Association[1 -> {
                Complex[163.32098996784921`, 21.081537198896875`], 
                Complex[133.7372209791803, -1.1156252449499178`]}, 2 -> {
                Complex[163.58375015064937`, -21.228465119017653`], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5036718442773116, -25.254623791294794`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32103072027124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.13071992444728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5830835190799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "C3", 
             Association[1 -> {
                Complex[163.32103072027124`, 21.13071992444728], 
                Complex[133.73729644380091`, -1.071819515054024]}, 2 -> {
                Complex[163.5830835190799, -21.277696758252304`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5051635470829916, -25.496630861351118`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32106946097053`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58242239805642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "C3", 
             Association[1 -> {
                Complex[163.32106946097053`, 21.179611363233054`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[163.58242239805642`, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.506651281803334, -25.739193926503706`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32110623777564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58176670441676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.37528881890603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.341533091710815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "C3", 
             Association[1 -> {
                Complex[163.32110623777564`, 21.228215020730886`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[163.58176670441676`, -21.37528881890603], 
                Complex[133.49259367239995`, -40.341533091710815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5081350902029891, -25.982309724102993`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32114109720294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.27653433863163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58111635683326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.383987509842974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32114109720294`, 21.27653433863163], 
                Complex[133.73750203277484`, -0.9420207663983327]}, 2 -> {
                Complex[163.58111635683326`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.383987509842974`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5096150133263728, -26.22597503039481}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3211740844998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.324572696395432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7375638448069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8992831695357282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58047127575952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.471742327540692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48778845735708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "C3", 
             Association[1 -> {
                Complex[163.3211740844998, 21.324572696395432`], 
                Complex[133.7375638448069, -0.8992831695357282]}, 2 -> {
                Complex[163.58047127575952`, -21.471742327540692`], 
                Complex[133.48778845735708`, -40.4261790532468]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.511091091515089, -26.47018665981938}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32120524368585`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57983138337912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.519550543179967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.46811085812299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "C3", 
             Association[1 -> {
                Complex[163.32120524368585`, 21.372333412759414`], 
                Complex[133.73762240273044`, -0.8568046319064777]}, 2 -> {
                Complex[163.57983138337912`, -21.519550543179967`], 
                Complex[133.4853981881505, -40.46811085812299]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5125633644245846, -26.71494146432708}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32123461759284`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.419819747199476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73767776709124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8145820782986561`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57919660355603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.56708410244111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4830160082869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.50978600446605`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.32123461759284`, 21.419819747199476`], 
                Complex[133.73767776709124`, -0.8145820782986561]}, 2 -> {
                Complex[163.57919660355603`, -21.56708410244111], 
                Complex[133.4830160082869, -40.50978600446605]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5140318710400942, -26.96023633271099}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126224790258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.467034901348015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57856686178704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32126224790258`, 21.467034901348015`], 
                Complex[133.73772999698105`, -0.7726124883003074]}, 2 -> {
                Complex[163.57856686178704`, -21.61434620967065], 
                Complex[133.48064181814095`, -40.55120751741091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5154966496921867, -27.206068189954966`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128817518404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.513982020369067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944153`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57794208515563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.661340012707413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32128817518404`, 21.513982020369067`], 
                Complex[133.73777915008168`, -0.7308928949944153]}, 2 -> {
                Complex[163.57794208515563`, -21.661340012707413`], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5169577380723973, -27.452433996597318`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32131243892846`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5773222022874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.70806860421745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.63330147714419`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "C3", 
             Association[1 -> {
                Complex[163.32131243892846`, 21.560664194292514`], 
                Complex[133.73782528270672`, -0.6894203836927915]}, 2 -> {
                Complex[163.5773222022874, -21.70806860421745], 
                Complex[133.47591701822174`, -40.63330147714419]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.51841517324741, -27.69933074810953}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32133507758377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5767071433079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.67397971146615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "C3", 
             Association[1 -> {
                Complex[163.32133507758377`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[163.5767071433079, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.67397971146615]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5198689916735526, -27.946755474289493`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135612858696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57609683979973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.800742255195683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.714415889878296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32135612858696`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[163.57609683979973`, -21.800742255195683`], 
                Complex[133.47122302955884`, -40.714415889878296`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5213192292104958, -28.194705238668774`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137562839594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5754912247639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.846693235601716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.754612782050174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32137562839594`, 21.699151145685878`], 
                Complex[133.73794610118625`, -0.5664569528154928]}, 2 -> {
                Complex[163.5754912247639, -21.846693235601716`], 
                Complex[133.46888736024792`, -40.754612782050174`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5227659211352085, -28.44317713793373}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32139361252007`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758959`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57489023258069`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007123`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32139361252007`, 21.74480338135633], 
                Complex[133.73798068907436`, -0.5259446249758959]}, 2 -> {
                Complex[163.57489023258069`, -21.89239084876425], 
                Complex[133.46655912218745`, -40.79457311007123]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5242091021543211, -28.692168301359782`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32141011554913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.79020533907295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57429379897212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4642382283995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.83429954954242`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "C3", 
             Association[1 -> {
                Complex[163.32141011554913`, 21.79020533907295], 
                Complex[133.73801251890455`, -0.4856655473715783]}, 2 -> {
                Complex[163.57429379897212`, -21.937837930174453`], 
                Complex[133.4642382283995, -40.83429954954242]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5256488064177682, -28.941675890258722`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142517118197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57370186096605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "C3", 
             Association[1 -> {
                Complex[163.32142517118197`, 21.835359803960376`], 
                Complex[133.73804163958545`, -0.4456170941100126]}, 2 -> {
                Complex[163.57370186096605`, -21.983037267377455`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5270850675298726, -29.19169709743854}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143881225352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836443967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57311435686128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.45961813380987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.913061239133484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "C3", 
             Association[1 -> {
                Complex[163.32143881225352`, 21.880269514316595`], 
                Complex[133.73806809891312`, -0.4057966836443967]}, 2 -> {
                Complex[163.57311435686128`, -22.027991601058], 
                Complex[133.45961813380987`, -40.913061239133484`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5285179185625049, -29.442229146675434`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145107076096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.924937162667188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360263`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.36620177777334817`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57253122619372`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.072703626095407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "C3", 
             Association[1 -> {
                Complex[163.32145107076096`, 21.924937162667188`], 
                Complex[133.73809194360263`, -0.36620177777334817`]}, 2 -> {
                Complex[163.57253122619372`, -22.072703626095407`], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5299473920661677, -29.6932692921977}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214619778895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.96936539678994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73811321931896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3268298806687504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5719524097037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.117175992588685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3214619778895, 21.96936539678994], 
                Complex[133.73811321931896`, -0.3268298806687504]}, 2 -> {
                Complex[163.5719524097037, -22.117175992588685`], 
                Complex[133.45502641240844`, -40.99091836543069]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5313735200815637, -29.944814818181143`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321471564036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.01355682071051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070584`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793105047`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57137784930458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.16141130685297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.02951394167229`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "C3", 
             Association[1 -> {
                Complex[163.321471564036, 22.01355682071051], 
                Complex[133.73813197070584`, -0.28767853793105047`]}, 2 -> {
                Complex[163.57137784930458`, -22.16141130685297], 
                Complex[133.45274099074845`, -41.02951394167229]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5327963341500828, -30.196863038255604`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32147985883367`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.05751399567081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141522`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.24874533567052026`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57080748805203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.0678907640604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "C3", 
             Association[1 -> {
                Complex[163.32147985883367`, 22.05751399567081], 
                Complex[133.73814824141522`, -0.24874533567052026`]}, 2 -> {
                Complex[163.57080748805203`, -22.205412132388133`], 
                Complex[133.45046242420474`, -41.0678907640604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5342158653255404, -30.449411295022532`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148689117372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816207413375`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.21002789961483614`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5702412701146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085482`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32148689117372`, 22.101239441069634`], 
                Complex[133.73816207413375`, -0.21002789961483614`]}, 2 -> {
                Complex[163.5702412701146, -22.249180990820484`], 
                Complex[133.44819063634753`, -41.10605121085482]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.535632144183358, -30.702456959582946`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214926892273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.14473563537842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56967914074468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.292720362818727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4459255521081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214926892273, 22.14473563537842], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[163.56967914074468`, -22.292720362818727`], 
                Complex[133.4459255521081, -41.14399762152054]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5370452008318745, -30.955997431075822`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214972804685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.188005017031273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.13323102192725855`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56912104625172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3214972804685, 22.188005017031273`], 
                Complex[133.73818259167945`, -0.13323102192725855`]}, 2 -> {
                Complex[163.56912104625172`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5384550649214412, -31.21003013622651}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150069169228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937554`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56856693397444`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.379120370718276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.219257503398715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "C3", 
             Association[1 -> {
                Complex[163.32150069169228`, 22.231049985290607`], 
                Complex[133.73818935729176`, -0.09514702213937554]}, 2 -> {
                Complex[163.56856693397444`, -22.379120370718276`], 
                Complex[133.44141520081965`, -41.219257503398715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5398617656541995, -31.464552528904765`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150294903576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.27387290108978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381938465315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.05726967062375721`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56801675225492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.42198577106388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "C3", 
             Association[1 -> {
                Complex[163.32150294903576`, 22.27387290108978], 
                Complex[133.7381938465315, -0.05726967062375721]}, 2 -> {
                Complex[163.56801675225492`, -22.42198577106388], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5412653317937435, -31.71956208969237}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150407799693`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633637513`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56747045041436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.4646312155268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.29368838106346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "C3", 
             Association[1 -> {
                Complex[163.32150407799693`, 22.316476087852756`], 
                Complex[133.73819609764354`, -0.019596778633637513`]}, 2 -> {
                Complex[163.56747045041436`, -22.4646312155268], 
                Complex[133.4369307957903, -41.29368838106346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5426657916736184, -31.975056325459914`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150410345304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.017873807828369337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56692797872756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.50705899287356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900826`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "C3", 
             Association[1 -> {
                Complex[163.32150410345304`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.017873807828369337`]}, 2 -> {
                Complex[163.56692797872756`, -22.50705899287356], 
                Complex[133.43469814900826`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5440631732068704, -32.23103276895259}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150304967848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.40103238518414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874688142`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56638928839993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4324717822431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.36730765692628`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "C3", 
             Association[1 -> {
                Complex[163.32150304967848`, 22.40103238518414], 
                Complex[133.73819403439737`, 0.05514420874688142]}, 2 -> {
                Complex[163.56638928839993`, -22.549271355908424`], 
                Complex[133.4324717822431, -41.36730765692628]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5454575038941181, -32.487488978384675`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150094036191`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56585433154422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.59127052222966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.403818232775386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "C3", 
             Association[1 -> {
                Complex[163.32150094036191`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[163.56585433154422`, -22.59127052222966], 
                Complex[133.43025162908577`, -41.403818232775386`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5468488108321929, -32.7444225370426}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149779862297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.484736744276518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818345754614`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.12909276811100767`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5653230611586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42803762425083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "C3", 
             Association[1 -> {
                Complex[163.32149779862297`, 22.484736744276518`], 
                Complex[133.73818345754614`, 0.12909276811100767`]}, 2 -> {
                Complex[163.5653230611586, -22.633058674966136`], 
                Complex[133.42803762425083`, -41.44013218836733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5482371207222962, -33.00183105289622}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149364702843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381750638226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16577500282102164`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56479543110495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.674637963494348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42582970355036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.47625154943295`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32149364702843`, 22.526274879059077`], 
                Complex[133.7381750638226, 0.16577500282102164`]}, 2 -> {
                Complex[163.56479543110495`, -22.674637963494348`], 
                Complex[133.42582970355036`, -41.47625154943295]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.549622459878014, -33.259712158218186`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214885076075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.567606480874492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500862`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.564271396088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.716010504136886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214885076075, 22.567606480874492`], 
                Complex[133.73816464500862`, 0.2022652058581258]}, 2 -> {
                Complex[163.564271396088, -22.716010504136886`], 
                Complex[133.42362780386904`, -41.51217831040793]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5510048542329906, -33.51806350921115}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148240186692`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.608733631773358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.23856533752871556`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56375091163494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.547914435078255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32148240186692`, 22.608733631773358`], 
                Complex[133.73815223405947`, 0.23856533752871556`]}, 2 -> {
                Complex[163.56375091163494`, -22.757178380842813`], 
                Complex[133.42143186313936`, -41.547914435078255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5523843293484896, -33.77688278564266}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321475350806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.649658382119874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381378632521`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27467732815633283`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56323393407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41924182031818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "C3", 
             Association[1 -> {
                Complex[163.321475350806, 22.649658382119874`], 
                Complex[133.7381378632521, 0.27467732815633283`]}, 2 -> {
                Complex[163.56323393407584`, -22.798143645850313`], 
                Complex[133.41924182031818`, -41.58346185720893]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5537609104208678, -34.03616769048753}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32146737492982`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.69038275123732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73812156420146`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5627204205249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.838908320332727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41705761536383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.618822481156855`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "C3", 
             Association[1 -> {
                Complex[163.32146737492982`, 22.69038275123732], 
                Complex[133.73812156420146`, 0.3106030786938945]}, 2 -> {
                Complex[163.5627204205249, -22.838908320332727`], 
                Complex[133.41705761536383`, -41.618822481156855`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5551346222888804, -34.29591594957734}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145849426388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.730908728036773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381033678786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34634446131990515`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56221032886114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.653998182467525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "C3", 
             Association[1 -> {
                Complex[163.32145849426388`, 22.730908728036773`], 
                Complex[133.7381033678786, 0.34634446131990515`]}, 2 -> {
                Complex[163.56221032886114`, -22.879474395027515`], 
                Complex[133.41487918921308`, -41.653998182467525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5565054894401891, -34.55612531125721}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214487283661`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.7712382716304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38190332002009697`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56170361771126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830850002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.68899080845728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214487283661, 22.7712382716304], 
                Complex[133.7380833046258, 0.38190332002009697`]}, 2 -> {
                Complex[163.56170361771126`, -22.919843830850002`], 
                Complex[133.41270648376008`, -41.68899080845728]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5578735360186948, -34.81679354604934}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143809634076`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.81137331192805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4172814711532169`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56120024643147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32143809634076`, 22.81137331192805], 
                Complex[133.73806140417352`, 0.4172814711532169]}, 2 -> {
                Complex[163.56120024643147`, -22.960018559490692`], 
                Complex[133.41053944183457`, -41.72380217877989]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5592387858312173, -35.07791844632328}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142661684998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.85131575022118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4524807040047172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56070017509117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.00000048399869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "C3", 
             Association[1 -> {
                Complex[163.32142661684998`, 22.85131575022118], 
                Complex[133.73803769565515`, 0.4524807040047172]}, 2 -> {
                Complex[163.56070017509117`, -23.00000048399869], 
                Complex[133.40837800718197`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5606012623535201, -35.33949782597289}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214143081261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.891067459749348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48750278132399316`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56020336445604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.039791479349606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4062221244428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.79288829603216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "C3", 
             Association[1 -> {
                Complex[163.3214143081261, 22.891067459749348`], 
                Complex[133.7380122076221, 0.48750278132399316`]}, 2 -> {
                Complex[163.56020336445604`, -23.039791479349606`], 
                Complex[133.4062221244428, -41.79288829603216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5619609887370183, -35.60152952009944}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214011879832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.93063028625468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5597097759723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.07939339299977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4040717391336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.82716654886576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.3214011879832, 22.93063028625468], 
                Complex[133.73798496805838`, 0.5223494398501387]}, 2 -> {
                Complex[163.5597097759723, -23.07939339299977], 
                Complex[133.4040717391336, -41.82716654886576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5633179878152299, -35.86401138470134}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213872738282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.97000604852185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55921937175077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.11880804542669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4019267976277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.86127055887851`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3213872738282, 22.97000604852185], 
                Complex[133.73795600439445`, 0.5570223908239598]}, 2 -> {
                Complex[163.55921937175077`, -23.11880804542669], 
                Complex[133.4019267976277, -41.86127055887851]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5646722821089492, -36.126941296369495`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137258267184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5587321145525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.15803723065625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.89520201543604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32137258267184`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874362]}, 2 -> {
                Complex[163.5587321145525, -23.15803723065625], 
                Complex[133.39978724713728`, -41.89520201543604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5660238938330957, -36.3903171519889}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135713113917`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.04820352384075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55824796777307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.197082716776826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "C3", 
             Association[1 -> {
                Complex[163.32135713113917`, 23.04820352384075], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[163.55824796777307`, -23.197082716776826`], 
                Complex[133.39765303569465`, -41.92896258335967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5673728449018023, -36.65413686844603}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32134093547978`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508835`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6600157387690366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55776689542964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340244`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "C3", 
             Association[1 -> {
                Complex[163.32134093547978`, 23.087028744351493`], 
                Complex[133.73785903508835`, 0.6600157387690366]}, 2 -> {
                Complex[163.55776689542964`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340244]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5687191569343548, -36.9183983823416}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213240115776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.12567391653264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782343872844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6940104792034631`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55728886214564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.99597759271317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.3213240115776, 23.12567391653264], 
                Complex[133.73782343872844`, 0.6940104792034631]}, 2 -> {
                Complex[163.55728886214564`, -23.27462953735598], 
                Complex[133.39340042608356`, -41.99597759271317]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5700628512605073, -37.18309964970923}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32130637496067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7377862475824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7278397028767358`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55681383313836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.02923524528987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32130637496067`, 23.164140732031207`], 
                Complex[133.7377862475824, 0.7278397028767358]}, 2 -> {
                Complex[163.55681383313836`, -23.313134282759357`], 
                Complex[133.39128192792896`, -42.02923524528987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5714039489259954, -37.44823864573913}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128804080997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.2024308585112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5563417742055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.351462151887404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.389168568818`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.062328432421694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32128804080997`, 23.2024308585112], 
                Complex[133.73774748603233`, 0.7615049781131837]}, 2 -> {
                Complex[163.5563417742055, -23.351462151887404`], 
                Complex[133.389168568818, -42.062328432421694`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5727424706974824, -37.7138133645073}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126902396925`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55587265171218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.38961479042947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "C3", 
             Association[1 -> {
                Complex[163.32126902396925`, 23.24054594010908], 
                Complex[133.73770717799474`, 0.7950078509907748]}, 2 -> {
                Complex[163.55587265171218`, -23.38961479042947], 
                Complex[133.3870603006344, -42.095258703120926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5740784370681291, -37.97982181870968}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32124933895304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.278487597877273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8283498457615899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.555406432579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "C3", 
             Association[1 -> {
                Complex[163.32124933895304`, 23.278487597877273`], 
                Complex[133.73766534693092`, 0.8283498457615899]}, 2 -> {
                Complex[163.555406432579, -23.427593820972138`], 
                Complex[133.38495707598477`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5754118682619429, -38.246262039401344`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3212289999553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.316257430218013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55494308426918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.465400843433205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "C3", 
             Association[1 -> {
                Complex[163.3212289999553, 23.316257430218013`], 
                Complex[133.73762201585797`, 0.8615324652630996]}, 2 -> {
                Complex[163.55494308426918`, -23.465400843433205`], 
                Complex[133.38285884818328`, -42.16063658240298]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.13577283982491445`, -0.7127814712321852}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.28874619752557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7971642905074585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570581`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.23691779950178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.18662852277594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "B2", 
             Association[1 -> {
                Complex[98.28874619752557, -4.7971642905074585`], 
                Complex[65.24911579537864, -27.64012489570581]}, 2 -> {
                Complex[109.23691779950178`, 2.18662852277594], 
                Complex[77.64033476497889, -18.555519955729697`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.1968015804875642, -0.6722828605051576}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.53721317940925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745143`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.00291862294868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.3161717918490905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "B2", 
             Association[1 -> {
                Complex[98.53721317940925, -4.913723373745143], 
                Complex[65.55225475967481, -27.752753616885617`]}, 2 -> {
                Complex[109.00291862294868`, 2.3161717918490905`], 
                Complex[77.35779210787567, -18.413383510132928`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.25508760947395154`, -0.6303180569180318}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.78413028654842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.878898314229872`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.77039874007265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.4568600959134304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.07605386722263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.25790704700182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "B2", 
             Association[1 -> {
                Complex[98.78413028654842, -5.041549120388238], 
                Complex[65.85454597323114, -27.878898314229872`]}, 2 -> {
                Complex[108.77039874007265`, 2.4568600959134304`], 
                Complex[77.07605386722263, -18.25790704700182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3106563140629583, -0.5867569878830883}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.02804001157145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.01910818767796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54081619894502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.609059345791207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "B2", 
             Association[1 -> {
                Complex[99.02804001157145, -5.181005750282824], 
                Complex[66.15429146185949, -28.01910818767796]}, 2 -> {
                Complex[108.54081619894502`, 2.609059345791207], 
                Complex[76.79681813580558, -18.08853939018387]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.36355071705577807`, -0.5414670472470513}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.26731766471846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.31579622511974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.7728363828323817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453784`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "B2", 
             Association[1 -> {
                Complex[99.26731766471846, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[108.31579622511974`, 2.7728363828323817`], 
                Complex[76.52200482138215, -17.905070014453784`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.41383292640393216`, -0.4943169257105582}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.50025760773303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.494703423518458`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09704498777202`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.947889052723903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "B2", 
             Association[1 -> {
                Complex[99.50025760773303, -5.494703423518458], 
                Complex[66.73834077690572, -28.342127551799617`]}, 2 -> {
                Complex[108.09704498777202`, 2.947889052723903], 
                Complex[76.25365917077403, -17.707718667136945`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4615844072869117, -0.4451810640085758}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.7251916573151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.88623119627513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050531`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "B2", 
             Association[1 -> {
                Complex[99.7251916573151, -5.667931881684691], 
                Complex[67.01856624754146, -28.52401138363128]}, 2 -> {
                Complex[107.88623119627513`, 3.1335101509494754`], 
                Complex[75.99381453813974, -17.49718747050531]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5069047998440703, -0.39394424236233916`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.94062195496076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.850744106324539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.68485323039285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "B2", 
             Association[1 -> {
                Complex[99.94062195496076, -5.850744106324539], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[107.68485323039285`, 3.3286015323523155`], 
                Complex[75.74433404826092, -17.274654824395935`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.549909263092365, -0.34050569394334196`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.14534197436598`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.041718331746126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.49411813290735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.5317429709640535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "B2", 
             Association[1 -> {
                Complex[100.14534197436598`, -6.041718331746126], 
                Complex[67.54625247327428, -28.92269792171125]}, 2 -> {
                Complex[107.49411813290735`, 3.5317429709640535`], 
                Complex[75.5067619380703, -17.041703592935647`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5907246335021961, -0.2847821678236142}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.33851976726778`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.2392230198151415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.136053013844258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.31485836381162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.741304440227348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.80019492108791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "B2", 
             Association[1 -> {
                Complex[100.33851976726778`, -6.2392230198151415`], 
                Complex[67.79105133862652, -29.136053013844258`]}, 2 -> {
                Complex[107.31485836381162`, 3.741304440227348], 
                Complex[75.28221611377315, -16.80019492108791]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.6294849297314664, -0.22670957473178685`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.51972815298026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663402`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.147501610807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.95557787197075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.552114786374766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "B2", 
             Association[1 -> {
                Complex[100.51972815298026`, -6.441548618274492], 
                Complex[68.02213623225066, -29.356140607663402`]}, 2 -> {
                Complex[107.147501610807, 3.95557787197075], 
                Complex[75.07134191761347, -16.552114786374766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.6663268206695301, -0.1662431502926862}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.68892233695162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.647031679680729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.58099676114603`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.99209317078063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.172901275980765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "B2", 
             Association[1 -> {
                Complex[100.68892233695162`, -6.647031679680729], 
                Complex[68.23931794822644, -29.58099676114603]}, 2 -> {
                Complex[106.99209317078063`, 4.172901275980765], 
                Complex[74.87432868509478, -16.299425400573043`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.02470076637099794, -0.6017093977782277}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.17308560823099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.79716429050747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.121257210207155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.1866285227759508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729686`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A2", 
             Association[1 -> {
                Complex[43.17308560823099, -4.79716429050747], 
                Complex[65.24911579537869, -27.64012489570582]}, 2 -> {
                Complex[54.121257210207155`, 2.1866285227759508`], 
                Complex[77.64033476497889, -18.555519955729686`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.08572950703357662, -0.561210787051202}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.42155259011466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.88725803365406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.316171791849095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A2", 
             Association[1 -> {
                Complex[43.42155259011466, -4.913723373745142], 
                Complex[65.55225475967484, -27.752753616885613`]}, 2 -> {
                Complex[53.88725803365406, 2.316171791849095], 
                Complex[77.35779210787565, -18.413383510132924`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.14401553601994976`, -0.5192459834640708}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.6684696972538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87889831422985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.654738150778094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.45686009591344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.0760538672227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.257907047001805`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A2", 
             Association[1 -> {
                Complex[43.6684696972538, -5.041549120388218], 
                Complex[65.85454597323113, -27.87889831422985]}, 2 -> {
                Complex[53.654738150778094`, 2.45686009591344], 
                Complex[77.0760538672227, -18.257907047001805`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.19958424060898494`, -0.47568491442913086`}],
            
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.91237942227682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.019108187677965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.42515560965041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.609059345791205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A2", 
             Association[1 -> {
                Complex[43.91237942227682, -5.181005750282827], 
                Complex[66.15429146185946, -28.019108187677965`]}, 2 -> {
                Complex[53.42515560965041, 2.609059345791205], 
                Complex[76.79681813580557, -18.08853939018387]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.2524786436017905, -0.43039497379308855`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.15165707542385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.20013563582517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.7728363828323297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453845`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "A2", 
             Association[1 -> {
                Complex[44.15165707542385, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[53.20013563582517, 2.7728363828323297`], 
                Complex[76.52200482138221, -17.905070014453845`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3027608529499588, -0.38324485225660254`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.38459701843839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4947034235184535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799614`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.98138439847741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.947889052723883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A2", 
             Association[1 -> {
                Complex[44.38459701843839, -5.4947034235184535`], 
                Complex[66.73834077690567, -28.342127551799614`]}, 2 -> {
                Complex[52.98138439847741, 2.947889052723883], 
                Complex[76.25365917077403, -17.707718667136962`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           
           TooltipBox[PointBox[{0.35051233383292413`, -0.33410899055461485`}],
            
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.60953106802053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363132`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.770570606980506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050529`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A2", 
             Association[1 -> {
                Complex[44.60953106802053, -5.667931881684722], 
                Complex[67.01856624754153, -28.52401138363132]}, 2 -> {
                Complex[52.770570606980506`, 3.1335101509494954`], 
                Complex[75.99381453813973, -17.49718747050529]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.3958327263900969, -0.2828721689083906}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.82496136566615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.8507441063245365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.569192641098226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "A2", 
             Association[1 -> {
                Complex[44.82496136566615, -5.8507441063245365`], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[52.569192641098226`, 3.3286015323523053`], 
                Complex[75.74433404826091, -17.274654824395945`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.43883718963846263`, -0.2294336204893881}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.02968138507134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.041718331746136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.37845754361273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.5317429709640207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935683`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "A2", 
             Association[1 -> {
                Complex[45.02968138507134, -6.041718331746136], 
                Complex[67.54625247327425, -28.92269792171126]}, 2 -> {
                Complex[52.37845754361273, 3.5317429709640207`], 
                Complex[75.5067619380703, -17.041703592935683`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.4796525600482511, -0.173710094369655}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.22285917797315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239223019815121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.13605301384424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.199197774517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.7413044402273425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.800194921087922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A2", 
             Association[1 -> {
                Complex[45.22285917797315, -6.239223019815121], 
                Complex[67.79105133862647, -29.13605301384424]}, 2 -> {
                Complex[52.199197774517, 3.7413044402273425`], 
                Complex[75.28221611377315, -16.800194921087922`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5184128562775072, -0.1156375012778259}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.404067563685665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663413`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.03184102151237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.9555778719707466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.55211478637477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A2", 
             Association[1 -> {
                Complex[45.404067563685665`, -6.441548618274501], 
                Complex[68.02213623225067, -29.356140607663413`]}, 2 -> {
                Complex[52.03184102151237, 3.9555778719707466`], 
                Complex[75.07134191761345, -16.55211478637477]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5552547472155709, -0.055171076838728794`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.57326174765701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.64703167968071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.580996761146004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.87643258148602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.172901275980756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A2", 
             Association[1 -> {
                Complex[45.57326174765701, -6.64703167968071], 
                Complex[68.23931794822644, -29.580996761146004`]}, 2 -> {
                Complex[51.87643258148602, 4.172901275980756], 
                Complex[74.87432868509478, -16.299425400573057`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.5903135136918252, 0.007715724253527512}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.730718127418484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.73269655459702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.391754775223062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.04394673660354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A3", 
             Association[1 -> {
                Complex[45.730718127418484`, -6.854150896006849], 
                Complex[68.44279858874026, -29.808799798905298`]}, 2 -> {
                Complex[51.73269655459702, 4.391754775223062], 
                Complex[74.69097444463986, -16.04394673660354]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.6237198366388554, 0.07303322136307422}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.87695378596401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.037946713787587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.600116350932254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "A3", 
             Association[1 -> {
                Complex[45.87695378596401, -7.061586259363513], 
                Complex[68.63308108602179, -30.037946713787587`]}, 2 -> {
                Complex[51.600116350932254`, 4.610819767164111], 
                Complex[74.52077639558696, -15.787280126334567`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.6555975264614489, 0.14077797037933415`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.012644400278134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.478016782014386`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.829003095065925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.3630260491026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "A3", 
             Association[1 -> {
                Complex[46.012644400278134`, -7.268243232709627], 
                Complex[68.81087406136677, -30.267088315852067`]}, 2 -> {
                Complex[51.478016782014386`, 4.829003095065925], 
                Complex[74.3630260491026, -15.530773111018974`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.6860621379798744, 0.21093533957876254`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.1385523728934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.473250095934392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818545`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.36563592928112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.045434394635397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.21689441876435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A3", 
             Association[1 -> {
                Complex[46.1385523728934, -7.473250095934392], 
                Complex[68.97700663449255, -30.495131845818545`]}, 2 -> {
                Complex[51.36563592928112, 5.045434394635397], 
                Complex[74.21689441876435, -15.275516827279347`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7152203181601635, 0.2834819494647576}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.25547057364814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.67593833538152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.72122229359378`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.26218140236398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.259446484100554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.08150010532468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029509`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A3", 
             Association[1 -> {
                Complex[46.25547057364814, -7.67593833538152], 
                Complex[69.13236033871479, -30.72122229359378]}, 2 -> {
                Complex[51.26218140236398, 5.259446484100554], 
                Complex[74.08150010532468, -15.022364688029509`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7431697018025716, 0.3583878343260718}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.36418227688922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.875814674529089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.94471254171957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.166870401922736`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489209`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A3", 
             Association[1 -> {
                Complex[46.36418227688922, -7.875814674529089], 
                Complex[69.27781951812032, -30.94471254171957]}, 2 -> {
                Complex[51.166870401922736`, 5.470547395427036], 
                Complex[73.95595889948115, -14.771962238489209`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7699991809169262, 0.43561826775259327`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.465435189789666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737157`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.07895569136514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.678390200428087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.8394169010038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "A3", 
             Association[1 -> {
                Complex[46.465435189789666`, -8.07253089957758], 
                Complex[69.41423820838506, -31.16512977737157]}, 2 -> {
                Complex[51.07895569136514, 5.678390200428087], 
                Complex[73.8394169010038, -14.524780743662301`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7957894044969578, 0.5151352503396076}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.55992646557226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.265855214912738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.99774058366105`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.882744366735128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.281149844042137`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "A3", 
             Association[1 -> {
                Complex[46.55992646557226, -8.265855214912738], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[50.99774058366105, 5.882744366735128], 
                Complex[73.73107052942778, -14.281149844042137`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8206134013774147, 0.5968986891273307}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.64829561564561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.455646996018187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.59553293132246`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.92258602924393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.083470511204362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.6301769260447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846566`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "A3", 
             Association[1 -> {
                Complex[46.64829561564561, -8.455646996018187], 
                Complex[69.66310826637462, -31.59553293132246]}, 2 -> {
                Complex[50.92258602924393, 6.083470511204362], 
                Complex[73.6301769260447, -14.041286825846566`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8445372514866989, 0.6808673120301005}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.73112272554318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.641835576592952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.80516872809565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.85291240010994`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.280499187514896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A3", 
             Association[1 -> {
                Complex[46.73112272554318, -8.641835576592952], 
                Complex[69.77698109299793, -31.80516872809565]}, 2 -> {
                Complex[50.85291240010994, 6.280499187514896], 
                Complex[73.53605776440253, -13.805321546316236`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8676207568936576, 0.7669993633104202}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.80892999564075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.82440299828263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.010985835765666`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.788197949138606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.4480988144794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041144`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A3", 
             Association[1 -> {
                Complex[46.80892999564075, -8.82440299828263], 
                Complex[69.88465297350923, -32.010985835765666`]}, 2 -> {
                Complex[50.788197949138606`, 6.473813636367646], 
                Complex[73.4480988144794, -13.573316941041144`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8899180832778342, 0.8552531230888292}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.882185196050116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.72797535523715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.6634360796057495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "A3", 
             Association[1 -> {
                Complex[46.882185196050116`, -9.003370304344577], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[50.72797535523715, 6.6634360796057495`], 
                Complex[73.36574696131454, -13.345285495813705`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9114783558124628, 0.9455872882353109}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.951306082313856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.671827307684104`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250492988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A3", 
             Association[1 -> {
                Complex[46.951306082313856`, -9.178786832849886], 
                Complex[70.08355015001808, -32.41114577568788]}, 2 -> {
                Complex[50.671827307684104`, 6.849417013859745], 
                Complex[73.2885058483752, -13.121202250492988`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9323462022779552, 1.0379612456771223`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.016665157888184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.350721960698461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.1757166401882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.60556303669796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.61938174368467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.031826954994077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.016665157888184`, -9.350721960698461], 
                Complex[70.1757166401882, -32.60556303669796]}, 2 -> {
                Complex[50.61938174368467, 7.031826954994077], 
                Complex[73.21593091512594, -12.901014934479544`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9525622417776844, 1.1323352631745802`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.078594407914174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.79629250746041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.570307114637814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.1476243120753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.078594407914174`, -9.519258803308224], 
                Complex[70.26357461989492, -32.79629250746041]}, 2 -> {
                Complex[50.570307114637814`, 7.210750138216329], 
                Complex[73.1476243120753, -12.684651789041993`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9721635207306605, 1.2286706173892004`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.13738978959499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.68448944959141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.983418096522826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.52430789579726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.386279753462804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.13738978959499, -9.68448944959141], 
                Complex[70.34748028709403, -32.983418096522826`]}, 2 -> {
                Complex[50.52430789579726, 7.386279753462804], 
                Complex[73.08322998054211, -12.472027556181573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9911838996205518, 1.32692967471597}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.19331536912255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.846511388382378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.1670326786391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.48112044938315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.558514372224588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.26304803157383`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "A3", 
             Association[1 -> {
                Complex[47.19331536912255, -9.846511388382378], 
                Complex[70.42775264717702, -33.1670326786391]}, 2 -> {
                Complex[50.48112044938315, 7.558514372224588], 
                Complex[73.02242905463167, -12.26304803157383]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0096543948321823`, 1.4270759368368466`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.24660706078816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.00542485182525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771441998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654395`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.44050928550963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.727555291323419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "A3", 
             Association[1 -> {
                Complex[47.24660706078816, -10.00542485182525], 
                Complex[70.50467771441998, -33.34723465654395]}, 2 -> {
                Complex[50.44050928550963, 7.727555291323419], 
                Complex[72.96493565975211, -12.057613502401406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0276034801653964`, 1.5290740601688793`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.29747596348612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.161330860116289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.524125383471365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.402263725719145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "A3", 
             Association[1 -> {
                Complex[47.29747596348612, -10.161330860116289`], 
                Complex[70.57851229402165, -33.524125383471365`]}, 2 -> {
                Complex[50.402263725719145`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452313`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0450573525308755`, 1.6328898562067735`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.34611131233811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.69780724710277`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.36619495139631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.056463649045714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "A3", 
             Association[1 -> {
                Complex[47.34611131233811, -10.314329800105746`], 
                Complex[70.64948735230315, -33.69780724710277]}, 2 -> {
                Complex[50.36619495139631, 8.056463649045714], 
                Complex[72.85887064064234, -11.656967837798806`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0620401660549987`, 1.7384902780777303`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.39268307483162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.464520408616714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.86838226002102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.3321334076672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.2165322541574`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.8098602198848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597864`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "A3", 
             Association[1 -> {
                Complex[47.39268307483162, -10.464520408616714`], 
                Complex[70.71781099948186, -33.86838226002102]}, 2 -> {
                Complex[50.3321334076672, 8.2165322541574], 
                Complex[72.8098602198848, -11.46154977597864]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0785742384532284`, 1.8458433973321728`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.4373442258159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.611999061422935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.03595103690155`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.29992652844131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.373807765588333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.269265288448755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "A3", 
             Association[1 -> {
                Complex[47.4373442258159, -10.611999061422935`], 
                Complex[70.78367111767889, -34.03595103690155]}, 2 -> {
                Complex[50.29992652844131, 8.373807765588333], 
                Complex[72.76327412626179, -11.269265288448755`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.094680233130802, 1.9549183740042064`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.48023273663557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.75685929217107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.84723766978762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.20061206617882`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.26943674731541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.52838469724979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A3", 
             Association[1 -> {
                Complex[47.48023273663557, -10.75685929217107], 
                Complex[70.84723766978762, -34.20061206617882]}, 2 -> {
                Complex[50.26943674731541, 8.52838469724979], 
                Complex[72.71894253702615, -11.080014668572227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1103773200755143`, 2.0656854222189622`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.52147331234387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.89919148351823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.90866472468208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.24053976039788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.680354396213662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.52147331234387, -10.89919148351823], 
                Complex[70.90866472468208, -34.36246120528307]}, 2 -> {
                Complex[50.24053976039788, 8.680354396213662], 
                Complex[72.67671152345633, -10.893700858042976`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1256833182308696`, 2.1781157730480274`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.561178908409175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.21312300963941`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.829804862450947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159116`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.561178908409175`, -11.039082686546374`], 
                Complex[70.96809223235843, -34.52159134503682]}, 2 -> {
                Complex[50.21312300963941, 8.829804862450947], 
                Complex[72.6364412756889, -10.710229782159116`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1406148217004528`, 2.2921816358766023`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.59945205528385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.17661653505851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.1870843583013`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.9768206634439`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.59945205528385, -11.17661653505851], 
                Complex[71.02564757984514, -34.67809220149987]}, 2 -> {
                Complex[50.1870843583013, 8.9768206634439], 
                Complex[72.59800454678344, -10.529510557655934`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.155187311825614, 2.4078561592124643`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.636386016039125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.16233093335741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.121482918322886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "A3", 
             Association[1 -> {
                Complex[47.636386016039125`, -11.311873229407055`], 
                Complex[71.08144695562096, -34.83205020330796]}, 2 -> {
                Complex[50.16233093335741, 9.121482918322886], 
                Complex[72.56128528828063, -10.351455605052497`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1694152569120746`, 2.525113391615095}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.672065799209136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.983548450042505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.138778112686914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.26386933231359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.175980689974885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "A3", 
             Association[1 -> {
                Complex[47.672065799209136`, -11.444929570640568`], 
                Complex[71.13559654715354, -34.983548450042505`]}, 2 -> {
                Complex[50.138778112686914`, 9.26386933231359], 
                Complex[72.52617745264078, -10.175980689974885`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1833122011420585`, 2.6439282432314855`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.70656904615111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.575859030428859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.13266672291677`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.116348637750534`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.40405426695551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.003004912170228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "A3", 
             Association[1 -> {
                Complex[47.70656904615111, -11.575859030428859`], 
                Complex[71.18819359319453, -35.13266672291677]}, 2 -> {
                Complex[50.116348637750534`, 9.40405426695551], 
                Complex[72.49258394092674, -10.003004912170228`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1968908440055515`, 2.764276448281205}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.73996680966804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.704731845790777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.27948153347702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.09497183500416`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.542108835115947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "A3", 
             Association[1 -> {
                Complex[47.73996680966804, -11.704731845790777`], 
                Complex[71.23932730972692, -35.27948153347702]}, 2 -> {
                Complex[50.09497183500416, 9.542108835115947], 
                Complex[72.46041567683548, -9.832450656512503]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2101631114055067`, 2.8861345287240816`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.77232423836924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.831615130363643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.4240661994061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.07458293157423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.678101012538281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A3", 
             Association[1 -> {
                Complex[47.77232423836924, -11.831615130363643`], 
                Complex[71.28907970599505, -35.4240661994061]}, 2 -> {
                Complex[50.07458293157423, 9.678101012538281], 
                Complex[72.42959079064792, -9.664243516913515]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2231402194385765`, 3.0094797592618843`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.80370117925396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.956572996022805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.56649093911878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.05512245271003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40003389885213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "A3", 
             Association[1 -> {
                Complex[47.80370117925396, -11.956572996022805`], 
                Complex[71.33752630486225, -35.56649093911878]}, 2 -> {
                Complex[50.05512245271003, 9.812095759734234], 
                Complex[72.40003389885213, -9.498312201447764]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2358327317210893`, 3.1342901337645372`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.834152709273475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.706822978841465`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.036535690257004`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.944155149605944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.33458842500021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "A3", 
             Association[1 -> {
                Complex[47.834152709273475`, -12.079666680238098`], 
                Complex[71.38473677982421, -35.706822978841465`]}, 2 -> {
                Complex[50.036535690257004`, 9.944155149605944], 
                Complex[72.37167546711125, -9.33458842500021]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2482506110152798`, 3.2605443331656367`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.86372960513274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.20095467575531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.845126667405935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.01877223289047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.074338497386961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.86372960513274, -12.20095467575531], 
                Complex[71.43077551933807, -35.845126667405935`]}, 2 -> {
                Complex[50.01877223289047, 10.074338497386961`], 
                Complex[72.34445124591687, -9.173006794205872]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2604032658140483`, 3.388221694838929}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.892478759305945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.00178555013501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.202702490405663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267268`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.892478759305945`, -12.320492860106404`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[50.00178555013501, 10.202702490405663`], 
                Complex[72.31830176971437, -9.013504688267268]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2722995924563207`, 3.5173021834427054`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.92044354913625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.438334623148688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.5195718702971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.98553262329957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.329301315871618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29317191153511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.85602213832465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.92044354913625, -12.438334623148688`], 
                Complex[71.5195718702971, -36.11589271440042]}, 2 -> {
                Complex[49.98553262329957, 10.329301315871618`], 
                Complex[72.29317191153511, -8.85602213832465]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2839480132739425`, 3.647766363202148}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.947664164943085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.554530991361462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.969973617404506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.45418678541366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "A3", 
             Association[1 -> {
                Complex[47.947664164943085`, -12.554530991361462`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[49.969973617404506`, 10.45418678541366], 
                Complex[72.26901048624575, -8.700501707354443]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.295356511207686, 3.7795953715872255`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.97417790224991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.66913074802967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.6043424637563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.37925086296772`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.955071588988176`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.577408455499175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033514`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "A3", 
             Association[1 -> {
                Complex[47.97417790224991, -12.66913074802967], 
                Complex[71.6043424637563, -36.37925086296772]}, 2 -> {
                Complex[49.955071588988176`, 10.577408455499175`], 
                Complex[72.24576989645067, -8.546888372033514]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3065326612746588`, 3.912770894335644}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.00001942255101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50828567419364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.94079222537401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.699013743166008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594679`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.00001942255101, -12.782180548745712`], 
                Complex[71.64533551387005, -36.50828567419364]}, 2 -> {
                Complex[49.94079222537401, 10.699013743166008`], 
                Complex[72.22340581587778, -8.395129407594679]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3174836592245356`, 4.047275141765628}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.02522098644102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.893725031887865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.635624466775916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.92710361157446`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.8190480367257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.02522098644102, -12.893725031887865`], 
                Complex[71.68545669700364, -36.635624466775916`]}, 2 -> {
                Complex[49.92710361157446, 10.8190480367257], 
                Complex[72.20187690576324, -8.245174276383164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3282163476798559`, 4.183090826319688}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.04981266242253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.00380692390271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.76131474751435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.9139760215171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.93755480126541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.096974520583906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.04981266242253, -13.00380692390271], 
                Complex[71.72474475596931, -36.76131474751435]}, 2 -> {
                Complex[49.9139760215171, 10.93755480126541], 
                Complex[72.18114456033722, -8.096974520583906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.338737240020535, 4.320201141280055}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.073822514268066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.112467139344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.88540205861425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.901381730715414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.950483659405908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "A3", 
             Association[1 -> {
                Complex[48.073822514268066`, -13.112467139344405`], 
                Complex[71.76323592906267, -36.88540205861425]}, 2 -> {
                Complex[49.901381730715414`, 11.054575678901632`], 
                Complex[72.16117267801965, -7.950483659405908]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3490525422431858`, 4.45858974059605}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.097276769439844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.88929484788194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.170150583829274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.805657090873341`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "A3", 
             Association[1 -> {
                Complex[48.097276769439844`, -13.219744875714255`], 
                Complex[71.80096415610163, -37.00793007567815]}, 2 -> {
                Complex[49.88929484788194, 11.170150583829274`], 
                Complex[72.1419274553698, -7.805657090873341]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3591681729981104`, 4.598240719764654}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.12019997074639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.12894070104982`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.8776911633041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.28431779227576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "A3", 
             Association[1 -> {
                Complex[48.12019997074639, -13.325677703210104`], 
                Complex[71.83796126429178, -37.12894070104982]}, 2 -> {
                Complex[49.8776911633041, 11.28431779227576], 
                Complex[72.1233772012094, -7.662451998269178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3690897819836323`, 4.739138597707084}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.142615113138476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.430301649540363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.248474152540204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.86654801208047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.397114027514972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "A3", 
             Association[1 -> {
                Complex[48.142615113138476`, -13.430301649540363`], 
                Complex[71.8742571361754, -37.248474152540204`]}, 2 -> {
                Complex[49.86654801208047, 11.397114027514972`], 
                Complex[72.10549216866305, -7.520827261201417]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3788227668582493`, 4.881268299586154}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.16454376730663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.533651279988442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.366569047621205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.85584415055513`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.508574540127224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.38074337120608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.16454376730663, -13.533651279988442`], 
                Complex[71.90987986163972, -37.366569047621205`]}, 2 -> {
                Complex[49.85584415055513, 11.508574540127224`], 
                Complex[72.08824440313957, -7.38074337120608]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3883722888118513`, 5.024615140511219}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.186006191536734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.63575977293281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94485587571889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.84555964449377`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0716076045205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A3", 
             Association[1 -> {
                Complex[48.186006191536734`, -13.63575977293281], 
                Complex[71.94485587571889, -37.483262483211874`]}, 2 -> {
                Complex[49.84555964449377, 11.618733183710322`], 
                Complex[72.0716076045205, -7.242162351762072]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3977432869232302`, 5.169164810080449}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.20702143310045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.736658991038883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.83567576772439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A3", 
             Association[1 -> {
                Complex[48.20702143310045, -13.736658991038883`], 
                Complex[71.97921008371291, -37.59859011120972]}, 2 -> {
                Complex[49.83567576772439, 11.727622486258118`], 
                Complex[72.05555700203159, -7.105047682565447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4069404914154404`, 5.314903357711966}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.22760742030328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.836379548343533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.82617491012043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.22760742030328, -13.836379548343533`], 
                Complex[72.01296597496555, -37.712586209936944`]}, 2 -> {
                Complex[49.82617491012043, 11.835273717427539`], 
                Complex[72.04006924045628, -6.969364227892692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4159684359111822`, 5.461817178718537}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.24778104617793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.934950873453174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.81704049393779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.835078168871881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.24778104617793, -13.934950873453174`], 
                Complex[72.04614572648373, -37.82528375168293]}, 2 -> {
                Complex[49.81704049393779, 11.941716951915161`], 
                Complex[72.02512227650753, -6.835078168871881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.424831468777242, 5.609893001082423}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.2675582446947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.032401269072565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07877029744378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.93671446652881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.80825689763537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.046981129160331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.2675582446947, -14.032401269072565`], 
                Complex[72.07877029744378, -37.93671446652881]}, 2 -> {
                Complex[49.80825689763537, 12.046981129160331`], 
                Complex[72.01069528431421, -6.702156939475872]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4335337636395735`, 5.759117872890208}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.28695406025804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.12875796807638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1108595155086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.04690890264222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.79980938640803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.151094109587378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "A3", 
             Association[1 -> {
                Complex[48.28695406025804, -14.12875796807638], 
                Complex[72.1108595155086, -38.04690890264222]}, 2 -> {
                Complex[49.79980938640803, 12.151094109587378`], 
                Complex[71.99676856909558, -6.570569166048992]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4420793291409382`, 5.909479150388783}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.305982711170586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.155896483227494`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.791684048752806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.983323488207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181978`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "A3", 
             Association[1 -> {
                Complex[48.305982711170586`, -14.22404718632718], 
                Complex[72.14243215577531, -38.155896483227494`]}, 2 -> {
                Complex[49.791684048752806`, 12.254082727590417`], 
                Complex[71.983323488207, -6.440284610181978]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.450472018007062, 6.0609644866270145`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.32465764766804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.31829417243562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.783867738463265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.35597284145664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.31127411475293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "A3", 
             Association[1 -> {
                Complex[48.32465764766804, -14.31829417243562], 
                Complex[72.17350601308073, -38.263705560313795`]}, 2 -> {
                Complex[49.783867738463265`, 12.35597284145664], 
                Complex[71.97034237882725, -6.31127411475293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.458715535479513, 6.213561820648909}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.342991605060675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.411523254649312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.776348021517336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "A3", 
             Association[1 -> {
                Complex[48.342991605060675`, -14.411523254649312`], 
                Complex[72.20409796831112, -38.37036346555746]}, 2 -> {
                Complex[49.776348021517336`, 12.456789380414614`], 
                Complex[71.95780849164257, -6.183509552957572]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.466813447168505, 6.367259367206749}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.360996652457885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.503757885046658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.769113127381615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.556556388984413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "A3", 
             Association[1 -> {
                Complex[48.360996652457885`, -14.503757885046658`], 
                Complex[72.23422404929191, -38.47589655822829]}, 2 -> {
                Complex[49.769113127381615`, 12.556556388984413`], 
                Complex[71.94570592995045, -6.056963780158599]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.474769186373834, 6.522045606964394}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.37868423749987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.595020681203493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054337`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.76215190430832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.655297068796713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9340195936706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391596`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "A3", 
             Association[1 -> {
                Complex[48.37868423749987, -14.595020681203493`], 
                Complex[72.2638994867713, -38.58033027054337]}, 2 -> {
                Complex[49.76215190430832, 12.655297068796713`], 
                Complex[71.9340195936706, -5.931610588391596]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4825860609165602`, 6.677909277162623}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.39606522747497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.685333465489398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.75545377824624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.753033818038535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A3", 
             Association[1 -> {
                Complex[48.39606522747497, -14.685333465489398`], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[49.75545377824624, 12.753033818038535`], 
                Complex[71.92273512780362, -5.807424663371904]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.490267259521488, 6.834839362720814}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.41314994716061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.77471730214245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.785996902375146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.74900871502786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.849788268674175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.91183887492751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.41314994716061, -14.77471730214245], 
                Complex[72.32195567400862, -38.785996902375146`]}, 2 -> {
                Complex[49.74900871502786, 12.849788268674175`], 
                Complex[71.91183887492751, -5.684381543854791]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4978158577852838`, 6.992825087749708}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.42994821369015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.86319253226119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.8872764249728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7428071855302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.945581321580041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209822`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.42994821369015, -14.86319253226119], 
                Complex[72.35036334387817, -38.8872764249728]}, 2 -> {
                Complex[49.7428071855302, 12.945581321580041`], 
                Complex[71.90131783136438, -5.562457583209822]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5052348237633169`, 7.151855907452969}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.446469368716585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.950778806844472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73684013353857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.040433179724607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.446469368716585`, -14.950778806844472`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[49.73684013353857, 13.040433179724607`], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5125270232037735`, 7.3119215003953855`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.46272230811621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.037495118001443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.08683856553305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73109894607003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.134363379515118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "A3", 
             Association[1 -> {
                Complex[48.46272230811621, -15.037495118001443`], 
                Complex[72.40600046967194, -39.08683856553305]}, 2 -> {
                Complex[49.73109894607003, 13.134363379515118`], 
                Complex[71.88135238627332, -5.321876408978639]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5196952244566688`, 7.473011761118059}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.47871550945055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.123359828445732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72557542593836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.227390820426002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "A3", 
             Association[1 -> {
                Complex[48.47871550945055, -15.123359828445732`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[49.72557542593836, 13.227390820426002`], 
                Complex[71.8718848966287, -5.203175657776082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5267421030816166`, 7.635116793080947}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.494457057382995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.20839069938103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72026176636399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.31953379301555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.08550692685011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "A3", 
             Association[1 -> {
                Complex[48.494457057382995`, -15.20839069938103], 
                Complex[72.46014358718853, -39.28254398107672]}, 2 -> {
                Complex[49.72026176636399, 13.31953379301555], 
                Complex[71.86274637325921, -5.08550692685011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5336702461768397`, 7.798226901915633}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.50995466722706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.292604916877659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7151505274519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.410810005430928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A3", 
             Association[1 -> {
                Complex[48.50995466722706, -15.292604916877659`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[49.7151505274519, 13.410810005430928`], 
                Complex[71.85392653085567, -4.968850134912987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5404821564495421`, 7.9623325889713}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.52521570678645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.376019116833605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.710234614377775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.52521570678645, -15.376019116833605`], 
                Complex[72.51287796992378, -39.47455031651175]}, 2 -> {
                Complex[49.710234614377775`, 13.501236608494983`], 
                Complex[71.84541553560709, -4.853185824347898]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5471802560469996`, 8.127424545138155}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.54024721663022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70550725713841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.590830219461864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7384951349874775`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "A3", 
             Association[1 -> {
                Complex[48.54024721663022, -15.458649408607112`], 
                Complex[72.53874152941212, -39.56921287503744]}, 2 -> {
                Complex[49.70550725713841, 13.590830219461864`], 
                Complex[71.83720397946203, -4.7384951349874775`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5537668901644963`, 8.293493644934}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.55505592893432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.540511397402028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70096199173561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.679606944523012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "A3", 
             Association[1 -> {
                Complex[48.55505592893432, -15.540511397402028`], 
                Complex[72.56428164388791, -39.66300535954416]}, 2 -> {
                Complex[49.70096199173561, 13.679606944523012`], 
                Complex[71.82928285617803, -4.624759779245359]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5602443304462525`, 8.460530940839796}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.56964828500726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.621620205482065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.75594483692522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69659264267576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.767582400139355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8216435390141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.511962018521162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.56964828500726, -15.621620205482065`], 
                Complex[72.58950706494943, -39.75594483692522]}, 2 -> {
                Complex[49.69659264267576, 13.767582400139355`], 
                Complex[71.8216435390141, -4.511962018521162]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5666147781940651`, 8.628527657871523}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.5840304516069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.701990492284674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.848047855290424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69239330667786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.854771733270828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.81427775993448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803735`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.5840304516069, -15.701990492284674`], 
                Complex[72.61442618498417, -39.848047855290424`]}, 2 -> {
                Complex[49.69239330667786, 13.854771733270828`], 
                Complex[71.81427775993448, -4.400084640803735]}]}, "Tooltip"]& 
           ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5728803673960385`, 8.797475188375756}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.59820833614577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.939330465113585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68835833749281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.941189640569323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.59820833614577, -15.781636473500773`], 
                Complex[72.63904705657157, -39.939330465113585`]}, 2 -> {
                Complex[49.68835833749281, 13.941189640569323`], 
                Complex[71.80717759020362, -4.289110939402672]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.579043167588324, 8.967365087038118}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.612187600873085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.860571939182236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.029808239319934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68448233174574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.026850386597047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742367`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "A3", 
             Association[1 -> {
                Complex[48.612187600873085`, -15.860571939182236`], 
                Complex[72.66337741060343, -40.029808239319934`]}, 2 -> {
                Complex[49.68448233174574, 14.026850386597047`], 
                Complex[71.80033542226364, -4.179024692742367]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5851051865607815`, 9.138189066093375}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.625973676114015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.938810270934708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.680760115720915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.111767821127955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.069810145157128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "A3", 
             Association[1 -> {
                Complex[48.625973676114015`, -15.938810270934708`], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[49.680760115720915`, 14.111767821127955`], 
                Complex[71.79374395279486, -4.069810145157128]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5910683729165385`, 9.309938990727161}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.63957177263898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.67718673301603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A3", 
             Association[1 -> {
                Complex[48.63957177263898, -16.016364458249825`], 
                Complex[72.71119598166317, -40.208409298430595`]}, 2 -> {
                Complex[49.67718673301603, 14.195955395586383`], 
                Complex[71.78739616686877, -3.9614519886295856`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5969346184956947`, 9.482606874659808}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.65298689323024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.09324711402706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.296561508588134`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.6737574329993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.279426178673182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A3", 
             Association[1 -> {
                Complex[48.65298689323024, -16.09324711402706], 
                Complex[72.73469819909567, -40.296561508588134`]}, 2 -> {
                Complex[49.6737574329993, 14.279426178673182`], 
                Complex[71.78128532311126, -3.853935345418625]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6027057606712845`, 9.656184875903442}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.666223843506465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.670467660008306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.362192871226501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.666223843506465`, -16.169470489332475`], 
                Complex[72.75793792851876, -40.38396676731901]}, 2 -> {
                Complex[49.670467660008306`, 14.362192871226501`], 
                Complex[71.77540493979987, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.608383584526507, 9.830665292683701}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.67928724206044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.24504648743809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.7809215257996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.47063852810008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66731304323485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.444267820361429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.641369140955806`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "A3", 
             Association[1 -> {
                Complex[48.67928724206044, -16.24504648743809], 
                Complex[72.7809215257996, -40.47063852810008]}, 2 -> {
                Complex[49.66731304323485, 14.444267820361429`], 
                Complex[71.76974878182652, -3.641369140955806]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6139698249192094`, 10.006040559518095`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.692181529961914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80365511190739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66428938724529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "A3", 
             Association[1 -> {
                Complex[48.692181529961914`, -16.31998667718374], 
                Complex[72.80365511190739, -40.556589868302694`]}, 2 -> {
                Complex[49.66428938724529, 14.525663032929627`], 
                Complex[71.76431084846256, -3.536291830717447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6194661684424432`, 10.18230324344362}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.70491097967126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.394302305698698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.641833503377605`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66139266308925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.75908536186752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.43200050653909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "A3", 
             Association[1 -> {
                Complex[48.70491097967126, -16.394302305698698`], 
                Complex[72.82614458440335, -40.641833503377605`]}, 2 -> {
                Complex[49.66139266308925, 14.606390188337485`], 
                Complex[71.75908536186752, -3.43200050653909]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7013855871457844, -0.10335634920044409`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.84637871671309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905323`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.84835714389165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.391754775223033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.043946736603573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "B3", 
             Association[1 -> {
                Complex[100.84637871671309`, -6.854150896006872], 
                Complex[68.44279858874026, -29.808799798905323`]}, 2 -> {
                Complex[106.84835714389165`, 4.391754775223033], 
                Complex[74.69097444463986, -16.043946736603573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7347919100927862, -0.03803885209089383}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.9926143752586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.03794671378757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.71577694022685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334501`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "B3", 
             Association[1 -> {
                Complex[100.9926143752586, -7.061586259363489], 
                Complex[68.63308108602176, -30.03794671378757]}, 2 -> {
                Complex[106.71577694022685`, 4.610819767164167], 
                Complex[74.52077639558694, -15.787280126334501`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7666695999153796, 0.029705896925383862`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.12830498957274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.593677371309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.829003095065927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.36302604910259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018968`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "B3", 
             Association[1 -> {
                Complex[101.12830498957274`, -7.268243232709611], 
                Complex[68.81087406136675, -30.267088315852057`]}, 2 -> {
                Complex[106.593677371309, 4.829003095065927], 
                Complex[74.36302604910259, -15.530773111018968`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.7971342114338194, 0.09986326612481047}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.25421296218802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.473250095934386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818538`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.48129651857575`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.0454343946354`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"74.21689441876437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279343`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "B3", 
             Association[1 -> {
                Complex[101.25421296218802`, -7.473250095934386], 
                Complex[68.97700663449254, -30.495131845818538`]}, 2 -> {
                Complex[106.48129651857575`, 5.0454343946354], 
                Complex[74.21689441876437, -15.275516827279343`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8262923916141369, 0.17240987601080018`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.37113116294276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.675938335381521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.721222293593776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.37784199165861`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.259446484100549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.0815001053247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "B3", 
             Association[1 -> {
                Complex[101.37113116294276`, -7.675938335381521], 
                Complex[69.13236033871479, -30.721222293593776`]}, 2 -> {
                Complex[106.37784199165861`, 5.259446484100549], 
                Complex[74.0815001053247, -15.022364688029517`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.8542417752565734, 0.24731576087210552`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.47984286618383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.87581467452907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.944712541719554`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.28253099121734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "B3", 
             Association[1 -> {
                Complex[101.47984286618383`, -7.87581467452907], 
                Complex[69.27781951812031, -30.944712541719554`]}, 2 -> {
                Complex[106.28253099121734`, 5.470547395427035], 
                Complex[73.95595889948112, -14.771962238489207`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.881071254370857, 0.32454619429861986`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.58109577908431`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737158`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.19461628065974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.678390200428089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.83941690100377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "B3", 
             Association[1 -> {
                Complex[101.58109577908431`, -8.07253089957759], 
                Complex[69.41423820838509, -31.16512977737158]}, 2 -> {
                Complex[106.19461628065974`, 5.678390200428089], 
                Complex[73.83941690100377, -14.524780743662296`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9068614779509312, 0.40406317688564486`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.67558705486688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.265855214912735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.11340117295566`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.8827443667351345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.28114984404213`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "B3", 
             Association[1 -> {
                Complex[101.67558705486688`, -8.265855214912735], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[106.11340117295566`, 5.8827443667351345`], 
                Complex[73.73107052942778, -14.28114984404213]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9316854748313455, 0.48582661567337326`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.76395620494021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.455646996018173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.595532931322452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.03824661853852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.083470511204354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.63017692604467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "B3", 
             Association[1 -> {
                Complex[101.76395620494021`, -8.455646996018173], 
                Complex[69.66310826637459, -31.595532931322452`]}, 2 -> {
                Complex[106.03824661853852`, 6.083470511204354], 
                Complex[73.63017692604467, -14.041286825846576`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.9556093249406723, 0.5697952385761467}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.84678331483764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.64183557659289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.805168728095598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.96857298940456`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.280499187514917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316211`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "B3", 
             Association[1 -> {
                Complex[101.84678331483764`, -8.64183557659289], 
                Complex[69.77698109299774, -31.805168728095598`]}, 2 -> {
                Complex[105.96857298940456`, 6.280499187514917], 
                Complex[73.53605776440253, -13.805321546316211`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{0.978692830347631, 0.6559272898564539}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.92459058493533`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.824402998282594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.01098583576563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.90385853843323`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.44809881447938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "B3", 
             Association[1 -> {
                Complex[101.92459058493533`, -8.824402998282594], 
                Complex[69.88465297350919, -32.01098583576563]}, 2 -> {
                Complex[105.90385853843323`, 6.473813636367659], 
                Complex[73.44809881447938, -13.573316941041124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0009901567317934`, 0.74418104963487}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.99784578534474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.84363594453177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.66343607960575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813707`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "B3", 
             Association[1 -> {
                Complex[101.99784578534474`, -9.003370304344582], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[105.84363594453177`, 6.66343607960575], 
                Complex[73.36574696131454, -13.345285495813707`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0225504292664078`, 0.8345152147813588}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.06696667160847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568787`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.78748789697872`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "B3", 
             Association[1 -> {
                Complex[102.06696667160847`, -9.178786832849873], 
                Complex[70.08355015001808, -32.41114577568787]}, 2 -> {
                Complex[105.78748789697872`, 6.849417013859737], 
                Complex[73.2885058483752, -13.121202250493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0434182757319002`, 0.9268891722231543}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.13232574718282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.35072196069847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.17571664018823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.605563036697966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.73504233297929`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.0318269549940675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479555`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.13232574718282`, -9.35072196069847], 
                Complex[70.17571664018823, -32.605563036697966`]}, 2 -> {
                Complex[105.73504233297929`, 7.0318269549940675`], 
                Complex[73.21593091512594, -12.901014934479555`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0636343152316294`, 1.0212631897206192`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.19425499720877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.796292507460386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.68596770393243`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.14762431207531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "B3", 
             Association[1 -> {
                Complex[102.19425499720877`, -9.519258803308206], 
                Complex[70.26357461989491, -32.796292507460386`]}, 2 -> {
                Complex[105.68596770393243`, 7.210750138216341], 
                Complex[73.14762431207531, -12.684651789041983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.0832355941846339`, 1.1175985439352305`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.25305037888961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.684489449591425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.98341809652284`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.63996848509186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.386279753462805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181569`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "B3", 
             Association[1 -> {
                Complex[102.25305037888961`, -9.684489449591425], 
                Complex[70.34748028709403, -32.98341809652284]}, 2 -> {
                Complex[105.63996848509186`, 7.386279753462805], 
                Complex[73.08322998054209, -12.472027556181569`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1022559730745252`, 1.2158576012619966`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.30897595841716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.846511388382389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.167032678639124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.59678103867778`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.558514372224577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.263048031573847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "B3", 
             Association[1 -> {
                Complex[102.30897595841716`, -9.846511388382389], 
                Complex[70.42775264717703, -33.167032678639124`]}, 2 -> {
                Complex[105.59678103867778`, 7.558514372224577], 
                Complex[73.02242905463169, -12.263048031573847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.12072646828617, 1.3160038633828928`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.3622676500828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.005424851825339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771442001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654403`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.55616987480424`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.72755529132343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401399`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "B3", 
             Association[1 -> {
                Complex[102.3622676500828, -10.005424851825339`], 
                Complex[70.50467771442001, -33.34723465654403]}, 2 -> {
                Complex[105.55616987480424`, 7.72755529132343], 
                Complex[72.96493565975211, -12.057613502401399`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1386755536193556`, 1.4180019867149147`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.41313655278073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.161330860116296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.52412538347138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.51792431501376`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "B3", 
             Association[1 -> {
                Complex[102.41313655278073`, -10.161330860116296`], 
                Complex[70.57851229402164, -33.52412538347138]}, 2 -> {
                Complex[105.51792431501376`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452317`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1561294259848205`, 1.5218177827528179`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.4617719016327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.697807247102766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.48185554069093`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.056463649045723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "B3", 
             Association[1 -> {
                Complex[102.4617719016327, -10.314329800105732`], 
                Complex[70.64948735230314, -33.697807247102766`]}, 2 -> {
                Complex[105.48185554069093`, 8.056463649045723], 
                Complex[72.85887064064235, -11.656967837798797`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.173112239508958, 1.6274182046237675`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.50834366412629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.464520408616728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.868382260021036`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.44779399696195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.216532254157382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80986021988497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597865`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "B3", 
             Association[1 -> {
                Complex[102.50834366412629`, -10.464520408616728`], 
                Complex[70.71781099948191, -33.868382260021036`]}, 2 -> {
                Complex[105.44779399696195`, 8.216532254157382], 
                Complex[72.80986021988497, -11.46154977597865]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.1896463119071734`, 1.7347713238782208`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.55300481511051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.611999061422951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.035951036901565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.41558711773592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.373807765588328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.26926528844876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "B3", 
             Association[1 -> {
                Complex[102.55300481511051`, -10.611999061422951`], 
                Complex[70.78367111767889, -34.035951036901565`]}, 2 -> {
                Complex[105.41558711773592`, 8.373807765588328], 
                Complex[72.76327412626178, -11.26926528844876]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2057523065847613`, 1.8438463005502455`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.59589332593018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.756859292171079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.8472376697876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.200612066178834`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.38509733661003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.528384697249784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "B3", 
             Association[1 -> {
                Complex[102.59589332593018`, -10.756859292171079`], 
                Complex[70.8472376697876, -34.200612066178834`]}, 2 -> {
                Complex[105.38509733661003`, 8.528384697249784], 
                Complex[72.71894253702615, -11.080014668572236`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2214493935294735`, 1.9546133487650101`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.6371339016385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.899191483518226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.9086647246821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.35620034969249`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.680354396213673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.6371339016385, -10.899191483518226`], 
                Complex[70.9086647246821, -34.36246120528307]}, 2 -> {
                Complex[105.35620034969249`, 8.680354396213673], 
                Complex[72.67671152345633, -10.893700858042966`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2367553916848857`, 2.0670436995940578`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.67683949770378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503681`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.32878359893402`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.829804862450937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "B3", 
             Association[1 -> {
                Complex[102.67683949770378`, -11.039082686546374`], 
                Complex[70.96809223235842, -34.52159134503681]}, 2 -> {
                Complex[105.32878359893402`, 8.829804862450937], 
                Complex[72.6364412756889, -10.710229782159127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2516868951543694`, 2.1811095624226415`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.71511264457845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.17661653505849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.30274494759591`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.97682066344391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655918`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "B3", 
             Association[1 -> {
                Complex[102.71511264457845`, -11.17661653505849], 
                Complex[71.02564757984513, -34.67809220149985]}, 2 -> {
                Complex[105.30274494759591`, 8.97682066344391], 
                Complex[72.59800454678344, -10.529510557655918`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2662593852795732`, 2.2967840857584947`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.75204660533373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330794`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.27799152265212`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.121482918322894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052479`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "B3", 
             Association[1 -> {
                Complex[102.75204660533373`, -11.311873229407045`], 
                Complex[71.08144695562095, -34.83205020330794]}, 2 -> {
                Complex[105.27799152265212`, 9.121482918322894], 
                Complex[72.56128528828074, -10.351455605052479`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2804873303660196`, 2.4140413181611415`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.78772638850374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.98354845004252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.25443870198153`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.263869332313579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.1759806899749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "B3", 
             Association[1 -> {
                Complex[102.78772638850374`, -11.444929570640575`], 
                Complex[71.13559654715354, -34.98354845004252]}, 2 -> {
                Complex[105.25443870198153`, 9.263869332313579], 
                Complex[72.52617745264078, -10.1759806899749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.2943842745960177`, 2.5328561697775247`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.82222963544572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.575859030428845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.132666722916746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.23200922704517`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.404054266955532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.0030049121702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "B3", 
             Association[1 -> {
                Complex[102.82222963544572`, -11.575859030428845`], 
                Complex[71.18819359319451, -35.132666722916746`]}, 2 -> {
                Complex[105.23200922704517`, 9.404054266955532], 
                Complex[72.49258394092676, -10.0030049121702]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3079629174595249`, 2.653204374827246}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.85562739896264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.704731845790779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.279481533477025`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.21063242429877`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.542108835115934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512519`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "B3", 
             Association[1 -> {
                Complex[102.85562739896264`, -11.704731845790779`], 
                Complex[71.23932730972689, -35.279481533477025`]}, 2 -> {
                Complex[105.21063242429877`, 9.542108835115934], 
                Complex[72.46041567683548, -9.832450656512519]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3212351848594943`, 2.7750624552701226`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.88798482766386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.831615130363632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.424066199406084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.19024352086885`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.678101012538276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913524`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "B3", 
             Association[1 -> {
                Complex[102.88798482766386`, -11.831615130363632`], 
                Complex[71.28907970599505, -35.424066199406084`]}, 2 -> {
                Complex[105.19024352086885`, 9.678101012538276], 
                Complex[72.42959079064792, -9.664243516913524]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3342122928925784`, 2.898407685807927}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.91936176854858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.956572996022798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.566490939118765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.1707830420047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.4000338988522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "B3", 
             Association[1 -> {
                Complex[102.91936176854858`, -11.956572996022798`], 
                Complex[71.33752630486225, -35.566490939118765`]}, 2 -> {
                Complex[105.1707830420047, 9.812095759734257], 
                Complex[72.4000338988522, -9.498312201447733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3469048051750627`, 3.0232180603105783`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.94981329856809`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.70682297884146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.15219627955162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.94415514960595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.3345884250002`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "B3", 
             Association[1 -> {
                Complex[102.94981329856809`, -12.079666680238097`], 
                Complex[71.38473677982421, -35.70682297884146]}, 2 -> {
                Complex[105.15219627955162`, 9.94415514960595], 
                Complex[72.37167546711125, -9.3345884250002]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3593226844692248`, 3.149472259711669}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.97939019442735`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.200954675755309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.84512666740593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.13443282218512`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.074338497386954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205879`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.97939019442735`, -12.200954675755309`], 
                Complex[71.43077551933806, -35.84512666740593]}, 2 -> {
                Complex[105.13443282218512`, 10.074338497386954`], 
                Complex[72.34445124591691, -9.173006794205879]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3714753392679933`, 3.2771496213849685`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.00813934860057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.11744613942963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.202702490405656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.00813934860057`, -12.320492860106407`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[105.11744613942963`, 10.202702490405656`], 
                Complex[72.31830176971438, -9.013504688267279]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3833716659102089`, 3.4062301099887358`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.03610413843087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.43833462314869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.51957187029711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.10119321259418`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.329301315871612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2931719115351`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.856022138324652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.03610413843087`, -12.43833462314869], 
                Complex[71.51957187029711, -36.11589271440042]}, 2 -> {
                Complex[105.10119321259418`, 10.329301315871612`], 
                Complex[72.2931719115351, -8.856022138324652]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.3950200867279017`, 3.536694289748207}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.0633247542377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.554530991361469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.08563420669911`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.454186785413665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354434`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "B3", 
             Association[1 -> {
                Complex[103.0633247542377, -12.554530991361469`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[105.08563420669911`, 10.454186785413665`], 
                Complex[72.26901048624575, -8.700501707354434]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.406428584661631, 3.6685232981332487`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.08983849154451`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.669130748029662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.60434246375627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.379250862967716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.0707321782828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.577408455499183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "B3", 
             Association[1 -> {
                Complex[103.08983849154451`, -12.669130748029662`], 
                Complex[71.60434246375627, -36.379250862967716`]}, 2 -> {
                Complex[105.0707321782828, 10.577408455499183`], 
                Complex[72.24576989645068, -8.546888372033505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4176047347286322`, 3.8016988208816938`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.1156800118456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.508285674193644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.05645281466863`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.699013743166024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.1156800118456, -12.782180548745718`], 
                Complex[71.64533551387001, -36.508285674193644`]}, 2 -> {
                Complex[105.05645281466863`, 10.699013743166024`], 
                Complex[72.22340581587781, -8.395129407594656]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4285557326784948`, 3.936203068311658}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.14088157573562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.893725031887852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.6356244667759`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.04276420086907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.819048036725702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.14088157573562`, -12.893725031887852`], 
                Complex[71.68545669700363, -36.6356244667759]}, 2 -> {
                Complex[105.04276420086907`, 10.819048036725702`], 
                Complex[72.20187690576324, -8.245174276383159]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4392884211338008`, 4.072018752865729}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.16547325171713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.003806923902713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.761314747514355`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.02963661081172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.937554801265406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.09697452058391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.16547325171713`, -13.003806923902713`], 
                Complex[71.72474475596928, -36.761314747514355`]}, 2 -> {
                Complex[105.02963661081172`, 10.937554801265406`], 
                Complex[72.18114456033723, -8.09697452058391]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.44980931347448, 4.209129067826094}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.1894831035627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.11246713934441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.885402058614254`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.01704232001005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.9504836594058705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "B3", 
             Association[1 -> {
                Complex[103.1894831035627, -13.11246713934441], 
                Complex[71.76323592906269, -36.885402058614254`]}, 2 -> {
                Complex[105.01704232001005`, 11.054575678901662`], 
                Complex[72.16117267801967, -7.9504836594058705`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4601246156971734`, 4.347517667142078}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.21293735873446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.00495543717656`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.170150583829281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.80565709087333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "B3", 
             Association[1 -> {
                Complex[103.21293735873446`, -13.219744875714252`], 
                Complex[71.80096415610164, -37.00793007567815]}, 2 -> {
                Complex[105.00495543717656`, 11.170150583829281`], 
                Complex[72.1419274553698, -7.80565709087333]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.4702402464520838`, 4.487168646310694}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.235860560041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.128940701049814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.99335175259871`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.284317792275752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269189`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "B3", 
             Association[1 -> {
                Complex[103.235860560041, -13.325677703210093`], 
                Complex[71.83796126429178, -37.128940701049814`]}, 2 -> {
                Complex[104.99335175259871`, 11.284317792275752`], 
                Complex[72.1233772012094, -7.662451998269189]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.480161855437563, 4.62806652425313}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.2582757024331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.430301649540361`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.24847415254021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.98220860137506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.397114027514961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "B3", 
             Association[1 -> {
                Complex[103.2582757024331, -13.430301649540361`], 
                Complex[71.8742571361754, -37.24847415254021]}, 2 -> {
                Complex[104.98220860137506`, 11.397114027514961`], 
                Complex[72.10549216866303, -7.520827261201424]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.489894840312166, 4.770196226132187}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.28020435660125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.533651279988478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.36656904762125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.97150473984975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.50857454012721`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.380743371206091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.28020435660125`, -13.533651279988478`], 
                Complex[71.90987986163972, -37.36656904762125]}, 2 -> {
                Complex[104.97150473984975`, 11.50857454012721], 
                Complex[72.08824440313957, -7.380743371206091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.499444362265853, 4.91354306705726}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.30166678083135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.635759772932813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9448558757189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.9612202337884`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07160760452052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "B3", 
             Association[1 -> {
                Complex[103.30166678083135`, -13.635759772932813`], 
                Complex[71.9448558757189, -37.483262483211874`]}, 2 -> {
                Complex[104.9612202337884, 11.618733183710313`], 
                Complex[72.07160760452052, -7.242162351762078]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5088153603771894`, 5.05809273662649}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.32268202239507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.736658991038896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.951336357019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "B3", 
             Association[1 -> {
                Complex[103.32268202239507`, -13.736658991038896`], 
                Complex[71.97921008371291, -37.59859011120973]}, 2 -> {
                Complex[104.951336357019, 11.727622486258118`], 
                Complex[72.05555700203158, -7.105047682565443]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5180125648693996`, 5.203831284258003}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.34326800959789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.836379548343551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.941835499415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.34326800959789`, -13.836379548343551`], 
                Complex[72.01296597496555, -37.712586209936966`]}, 2 -> {
                Complex[104.941835499415, 11.835273717427565`], 
                Complex[72.04006924045623, -6.969364227892658]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5270405093651271`, 5.35074510526456}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.36344163547253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.934950873453168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.9327010832324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.8350781688719024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.36344163547253`, -13.934950873453168`], 
                Complex[72.04614572648372, -37.82528375168293]}, 2 -> {
                Complex[104.9327010832324, 11.941716951915144`], 
                Complex[72.02512227650752, -6.8350781688719024`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5359035422312155`, 5.498820927628456}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.38321883398932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.032401269072546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0787702974438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.9367144665288`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.92391748692997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.046981129160319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475888`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.38321883398932`, -14.032401269072546`], 
                Complex[72.0787702974438, -37.9367144665288]}, 2 -> {
                Complex[104.92391748692997`, 12.046981129160319`], 
                Complex[72.01069528431418, -6.702156939475888]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5446058370935185`, 5.648045799436238}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.40261464955266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.128757968076373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.11085951550861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.046908902642215`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.91546997570263`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.151094109587374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "B3", 
             Association[1 -> {
                Complex[103.40261464955266`, -14.128757968076373`], 
                Complex[72.11085951550861, -38.046908902642215`]}, 2 -> {
                Complex[104.91546997570263`, 12.151094109587374`], 
                Complex[71.99676856909556, -6.570569166048996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.553151402594869, 5.798407076934817}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.42164330046519`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.15589648322749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.90734463804742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.98332348820699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181976`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "B3", 
             Association[1 -> {
                Complex[103.42164330046519`, -14.22404718632717], 
                Complex[72.14243215577528, -38.15589648322749]}, 2 -> {
                Complex[104.90734463804742`, 12.254082727590419`], 
                Complex[71.98332348820699, -6.440284610181976]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.561544091461007, 5.949892413173055}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.44031823696265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.318294172435639`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.899528327758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.355972841456682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.311274114752878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "B3", 
             Association[1 -> {
                Complex[103.44031823696265`, -14.318294172435639`], 
                Complex[72.17350601308074, -38.263705560313824`]}, 2 -> {
                Complex[104.899528327758, 12.355972841456682`], 
                Complex[71.97034237882741, -6.311274114752878]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5697876089334437`, 6.102489747194957}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.4586521943553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.411523254649305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555745`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.89200861081196`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957561`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "B3", 
             Association[1 -> {
                Complex[103.4586521943553, -14.411523254649305`], 
                Complex[72.20409796831112, -38.37036346555745]}, 2 -> {
                Complex[104.89200861081196`, 12.456789380414621`], 
                Complex[71.95780849164257, -6.183509552957561]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5778855206224358`, 6.256187293752808}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.4766572417525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.503757885046657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.88477371667624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.55655638898441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "B3", 
             Association[1 -> {
                Complex[103.4766572417525, -14.503757885046657`], 
                Complex[72.23422404929192, -38.47589655822829]}, 2 -> {
                Complex[104.88477371667624`, 12.55655638898441], 
                Complex[71.94570592995045, -6.056963780158602]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5858412598277931`, 6.410973533510424}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.49434482679449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.595020681203478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054336`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.87781249360295`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.655297068796704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.93401959367063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "B3", 
             Association[1 -> {
                Complex[103.49434482679449`, -14.595020681203478`], 
                Complex[72.2638994867713, -38.58033027054336]}, 2 -> {
                Complex[104.87781249360295`, 12.655297068796704`], 
                Complex[71.93401959367063, -5.931610588391608]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.5936581343705194`, 6.566837203708667}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.51172581676958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.6853334654894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.87111436754086`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.753033818038542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371897`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "B3", 
             Association[1 -> {
                Complex[103.51172581676958`, -14.6853334654894], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[104.87111436754086`, 12.753033818038542`], 
                Complex[71.92273512780362, -5.807424663371897]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6013393329754473`, 6.7237672892668545`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.52881053645524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.774717302142461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400863`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.78599690237516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.86466930432246`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.849788268674176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9118388749275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.52881053645524`, -14.774717302142461`], 
                Complex[72.32195567400863, -38.78599690237516]}, 2 -> {
                Complex[104.86466930432246`, 12.849788268674176`], 
                Complex[71.9118388749275, -5.684381543854785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6088879312392572`, 6.881753014295752}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.54560880298476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.863192532261197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.887276424972804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.85846777482483`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.945581321580061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136441`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.54560880298476`, -14.863192532261197`], 
                Complex[72.35036334387817, -38.887276424972804`]}, 2 -> {
                Complex[104.85846777482483`, 12.945581321580061`], 
                Complex[71.90131783136441, -5.562457583209795]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.616306897217276, 7.040783833998995}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.5621299580112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.950778806844474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.85250072283318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.04043317972461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.5621299580112, -14.950778806844474`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[104.85250072283318`, 13.04043317972461], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6235990966577327`, 7.20084942694143}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.57838289741083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.037495118001429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.086838565533036`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.84675953536465`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.134363379515117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "B3", 
             Association[1 -> {
                Complex[103.57838289741083`, -15.037495118001429`], 
                Complex[72.40600046967194, -39.086838565533036`]}, 2 -> {
                Complex[104.84675953536465`, 13.134363379515117`], 
                Complex[71.88135238627333, -5.321876408978637]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6307672979106422`, 7.3619396876640995`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.59437609874517`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.123359828445727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.84123601523297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.227390820426008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "B3", 
             Association[1 -> {
                Complex[103.59437609874517`, -15.123359828445727`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[104.84123601523297`, 13.227390820426008`], 
                Complex[71.8718848966287, -5.203175657776077]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6378141765355616`, 7.524044719626991}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.6101176466776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.208390699381031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107673`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.83592235565861`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.319533793015575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.085506926850082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "B3", 
             Association[1 -> {
                Complex[103.6101176466776, -15.208390699381031`], 
                Complex[72.46014358718851, -39.28254398107673]}, 2 -> {
                Complex[104.83592235565861`, 13.319533793015575`], 
                Complex[71.86274637325923, -5.085506926850082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.644742319630813, 7.687154828461667}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.62561525652167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.292604916877655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.83081111674652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.410810005430926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.62561525652167`, -15.292604916877655`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[104.83081111674652`, 13.410810005430926`], 
                Complex[71.85392653085569, -4.968850134912989]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6515542299035013`, 7.851260515517351}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.64087629608107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.376019116833604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992379`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.82589520367239`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.64087629608107`, -15.376019116833604`], 
                Complex[72.51287796992379, -39.47455031651176]}, 2 -> {
                Complex[104.82589520367239`, 13.501236608494986`], 
                Complex[71.84541553560709, -4.853185824347895]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6582523295009588`, 8.016352471684188}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.65590780592484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941214`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.82116784643303`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.590830219461871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.73849513498747`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "B3", 
             Association[1 -> {
                Complex[103.65590780592484`, -15.458649408607112`], 
                Complex[72.53874152941214, -39.56921287503744]}, 2 -> {
                Complex[104.82116784643303`, 13.590830219461871`], 
                Complex[71.83720397946203, -4.73849513498747]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6648389636184555`, 8.18242157148003}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.67071651822893`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.540511397402026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.81662258103023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.679606944523016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245355`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "B3", 
             Association[1 -> {
                Complex[103.67071651822893`, -15.540511397402026`], 
                Complex[72.56428164388791, -39.66300535954415]}, 2 -> {
                Complex[104.81662258103023`, 13.679606944523016`], 
                Complex[71.82928285617803, -4.624759779245355]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6713164039001975`, 8.349458867385843}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.68530887430188`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.621620205482067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.755944836925224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.81225323197039`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.76758240013934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82164353901412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.5119620185211815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.68530887430188`, -15.621620205482067`], 
                Complex[72.58950706494943, -39.755944836925224`]}, 2 -> {
                Complex[104.81225323197039`, 13.76758240013934], 
                Complex[71.82164353901412, -4.5119620185211815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6776868516479675`, 8.517455584417567}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.69969104090151`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.701990492284681`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.84804785529043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80805389597248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.854771733270837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8142777599345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803723`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.69969104090151`, -15.701990492284681`], 
                Complex[72.61442618498418, -39.84804785529043]}, 2 -> {
                Complex[104.80805389597248`, 13.854771733270837`], 
                Complex[71.8142777599345, -4.400084640803723]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6839524408499977`, 8.686403114921793}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.71386892544038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.93933046511359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80401892678742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.941189640569329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.71386892544038`, -15.781636473500773`], 
                Complex[72.63904705657157, -39.93933046511359]}, 2 -> {
                Complex[104.80401892678742`, 13.941189640569329`], 
                Complex[71.80717759020362, -4.289110939402667]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.6901152410422975`, 8.856293013584159}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7278481901677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.860571939182227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.02980823931992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80014292104036`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.026850386597049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "B3", 
             Association[1 -> {
                Complex[103.7278481901677, -15.860571939182227`], 
                Complex[72.66337741060345, -40.02980823931992]}, 2 -> {
                Complex[104.80014292104036`, 14.026850386597049`], 
                Complex[71.80033542226366, -4.179024692742365]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.696177260014769, 9.02711699263943}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.74163426540862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.93881027093471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.79642070501552`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.11176782112795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.0698101451571365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "B3", 
             Association[1 -> {
                Complex[103.74163426540862`, -15.93881027093471], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[104.79642070501552`, 14.11176782112795], 
                Complex[71.79374395279484, -4.0698101451571365`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.7021404463704977`, 9.198866917273174}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7552323619336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430624`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.79284732231065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295785`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "B3", 
             Association[1 -> {
                Complex[103.7552323619336, -16.016364458249843`], 
                Complex[72.71119598166317, -40.208409298430624`]}, 2 -> {
                Complex[104.79284732231065`, 14.195955395586383`], 
                Complex[71.78739616686879, -3.9614519886295785`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.7080066919496113`, 9.371534801205835}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7686474825249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.093247114027072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.29656150858814`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.78941802229393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.279426178673177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418634`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.7686474825249, -16.093247114027072`], 
                Complex[72.73469819909572, -40.29656150858814]}, 2 -> {
                Complex[104.78941802229393`, 14.279426178673177`], 
                Complex[71.78128532311128, -3.853935345418634]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.713777834125272, 9.54511280244949}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.78188443280105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.7861282493029`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.362192871226487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.78188443280105`, -16.169470489332486`], 
                Complex[72.75793792851871, -40.38396676731904]}, 2 -> {
                Complex[104.7861282493029, 14.362192871226487`], 
                Complex[71.77540493979984, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.7194556579804663`, 9.719593219229745}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.79494783135505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.24504648743812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.78092152579958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.470638528100125`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.78297363252948`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.444267820361425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.6413691409558098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "B3", 
             Association[1 -> {
                Complex[103.79494783135505`, -16.24504648743812], 
                Complex[72.78092152579958, -40.470638528100125`]}, 2 -> {
                Complex[104.78297363252948`, 14.444267820361425`], 
                Complex[71.76974878182654, -3.6413691409558098`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.7250418983731828`, 9.894968486064146}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.80784211925645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.8036551119073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.7799499765399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "B3", 
             Association[1 -> {
                Complex[103.80784211925645`, -16.31998667718373], 
                Complex[72.8036551119073, -40.556589868302694`]}, 2 -> {
                Complex[104.7799499765399, 14.525663032929623`], 
                Complex[71.76431084846254, -3.536291830717447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.005], 
          TagBox[
           TooltipBox[PointBox[{1.7305382418964592`, 10.071231169989654`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.82057156896586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.394302305698687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.6418335033776`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.77705325238387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.7590853618675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4320005065390866`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "B3", 
             Association[1 -> {
                Complex[103.82057156896586`, -16.394302305698687`], 
                Complex[72.82614458440332, -40.6418335033776]}, 2 -> {
                Complex[104.77705325238387`, 14.606390188337485`], 
                Complex[71.7590853618675, -3.4320005065390866`]}]}, 
            "Tooltip"]& ]}}}, 
       {GrayLevel[0.2], Thickness[Tiny], LineBox[{{0, -5}, {0, 10}}]}},
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"Re(\\!\\(\\*SubscriptBox[\\(S\\), \\(1\\)]\\)-\[CapitalOmega] \
\\!\\(\\*SubscriptBox[\\(t\\), \\(1\\)]\\))-Re(\\!\\(\\*SubscriptBox[\\(S\\), \
\\(2\\)]\\)-\[CapitalOmega] \\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
         TraditionalForm], 
        FormBox[
        "\"Im(\\!\\(\\*SubscriptBox[\\(S\\), \\(1\\)]\\)-\[CapitalOmega] \
\\!\\(\\*SubscriptBox[\\(t\\), \\(1\\)]\\))-Im(\\!\\(\\*SubscriptBox[\\(S\\), \
\\(2\\)]\\)-\[CapitalOmega] \\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
         TraditionalForm]},
      ImageSize->{{900}, {900}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-32.48921089704068, -5.49727768712696}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.245615698905056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.546462974510604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.3583570943027`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11658019540031805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A1", 
             Association[1 -> {
                Complex[12.245615698905056`, -11.285995288896373`], 
                Complex[31.494082066597198`, -37.546462974510604`]}, 2 -> {
                Complex[82.3583570943027, 0.11658019540031805`], 
                Complex[108.70582923184111`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-32.09349671692901, -5.433681341367}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.866460671342168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.816178584119385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.10766368142046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.65454606371028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A1", 
             Association[1 -> {
                Complex[12.866460671342168`, -10.816178584119385`], 
                Complex[32.10766368142046, -37.05300319249051]}, 2 -> {
                Complex[81.65454606371028, 0.11776334712026199`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-31.704586653157186`, -5.372449776918645}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.385569221277168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.443606571400114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.62046690403218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.08582224927886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "A1", 
             Association[1 -> {
                Complex[13.385569221277168`, -10.443606571400114`], 
                Complex[32.62046690403218, -36.65624121214425]}, 2 -> {
                Complex[81.08582224927886, 0.11905307061487365`], 
                Complex[107.41258000537293`, -20.41001952735828]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-31.321453687498853`, -5.313159149602601}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.844879609183106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.128345372417396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.074306417344815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.59570734825861`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12040941356394542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A1", 
             Association[1 -> {
                Complex[13.844879609183106`, -10.128345372417396`], 
                Complex[33.074306417344815`, -36.31637452115125]}, 2 -> {
                Complex[80.59570734825861, 0.12040941356394542`], 
                Complex[106.91207211908184`, -20.409835465464518`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.943450473277032`, -5.255540138212494}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.263512998287613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.852138089238336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.48822262138849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.01523037051932`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.15853740070536`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12181511399306792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40960872633279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "A1", 
             Association[1 -> {
                Complex[14.263512998287613`, -9.852138089238336], 
                Complex[33.48822262138849, -36.01523037051932]}, 2 -> {
                Complex[80.15853740070536, 0.12181511399306792`], 
                Complex[106.46447895532776`, -20.40960872633279]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.570120334519938`, -5.1994013782971695`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.652107822673527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.60480138795417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.87279494489345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.74268548695589`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.76008128321261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12326110383985404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.05556643970378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409348870362294`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A1", 
             Association[1 -> {
                Complex[14.652107822673527`, -9.60480138795417], 
                Complex[33.87279494489345, -35.74268548695589]}, 2 -> {
                Complex[79.76008128321261, 0.12326110383985404`], 
                Complex[106.05556643970378`, -20.409348870362294`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.201118717270784`, -5.1445975468436735`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.017310748471408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.379958105911207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.3914778440311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1247420703186469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A1", 
             Association[1 -> {
                Complex[15.017310748471408`, -9.379958105911207], 
                Complex[34.23462400814145, -35.492408387804]}, 2 -> {
                Complex[79.3914778440311, 0.1247420703186469], 
                Complex[105.67647115587602`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.83617369065385, -5.091013266903429}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.363606529112152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.17329625288842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.260123312215754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.04676899384386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12625468557684455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.32123318016059`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408750516874484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "A1", 
             Association[1 -> {
                Complex[15.363606529112152`, -9.17329625288842], 
                Complex[34.57815702977675, -35.260123312215754`]}, 2 -> {
                Complex[79.04676899384386, 0.12625468557684455`], 
                Complex[105.32123318016059`, -20.408750516874484`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.47506357698316, -5.038553965960297}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.694192540187109`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.981735864879811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.906559828007246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.04277989487664`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.72172225527217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1277967777586609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A1", 
             Association[1 -> {
                Complex[15.694192540187109`, -8.981735864879811], 
                Complex[34.906559828007246`, -35.04277989487664]}, 2 -> {
                Complex[78.72172225527217, 0.1277967777586609], 
                Complex[104.98561848841774`, -20.40841808612212]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.11760319400199, -4.987140237632351}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.011444946530013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.802984319586065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.8381102332606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.41320392779194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12936689788169053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40806597206126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "A1", 
             Association[1 -> {
                Complex[16.011444946530013`, -8.802984319586065], 
                Complex[35.22218142009305, -34.8381102332606]}, 2 -> {
                Complex[78.41320392779194, 0.12936689788169053`], 
                Complex[104.66649203468586`, -20.40806597206126]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-28.763634862057778`, -4.9367041456348755`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.31718789840238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.635279208450724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.52682218732508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.11881756413922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13096407459708617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "A1", 
             Association[1 -> {
                Complex[16.31718789840238, -8.635279208450724], 
                Complex[35.52682218732508, -34.644372916323725`]}, 2 -> {
                Complex[78.11881756413922, 0.13096407459708617`], 
                Complex[104.36145617205713`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-28.413022242772556`, -4.887186684238857}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.612858840508633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.47723022998036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.83668223957315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13258766651163573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A1", 
             Association[1 -> {
                Complex[16.612858840508633`, -8.47723022998036], 
                Complex[35.82189847272132, -34.46019571836112]}, 2 -> {
                Complex[77.83668223957315, 0.13258766651163573`], 
                Complex[104.06862888444635`, -20.407307041147234`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-28.06564595641145, -4.838535966689122}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.899615105400063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.327717105231178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.1085486648078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.284474089725364`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.56528975328628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13423726881752882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "A1", 
             Association[1 -> {
                Complex[16.899615105400063`, -8.327717105231178], 
                Complex[36.1085486648078, -34.284474089725364`]}, 2 -> {
                Complex[77.56528975328628, 0.13423726881752882`], 
                Complex[103.78650096169157`, -20.406901625797378`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.721400367522214`, -4.790705892723485}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.17840543589556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.18582098961993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.116302994815634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.30340893094568`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13591265188074694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A1", 
             Association[1 -> {
                Complex[17.17840543589556, -8.18582098961993], 
                Complex[36.38770434340436, -34.116302994815634`]}, 2 -> {
                Complex[77.30340893094568, 0.13591265188074694`], 
                Complex[103.51384028303791`, -20.406479492338008`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.38019116652061, -4.743655143165185}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.4500195893454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.660139598224646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.9549296033411`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.05001933585376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951339305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "A1", 
             Association[1 -> {
                Complex[17.4500195893454, -8.050776840303662], 
                Complex[36.660139598224646`, -33.9549296033411]}, 2 -> {
                Complex[77.05001933585376, 0.13761371951339305`], 
                Complex[103.24962551411932`, -20.406040889030564`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.041933510426674`, -4.697346404749755}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.715123715910405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.921939398858399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.926506185668615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.799719524488225`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.80426404977382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13934047984247463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "A1", 
             Association[1 -> {
                Complex[17.715123715910405`, -7.921939398858399], 
                Complex[36.926506185668615`, -33.799719524488225`]}, 2 -> {
                Complex[76.80426404977382, 0.13934047984247463`], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.706550566766644`, -4.6517457612953965`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.97428620238765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.18735919764107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.65013212317828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.56541522251278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A1", 
             Association[1 -> {
                Complex[17.97428620238765, -7.798758308638237], 
                Complex[37.18735919764107, -33.65013212317828]}, 2 -> {
                Complex[76.56541522251278, 0.14109302450360017`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.37397235476145, -4.606822207779906}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.227996947167636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.44317619593503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.50570209730137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.33284841044511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14287151349532584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "A1", 
             Association[1 -> {
                Complex[18.227996947167636`, -7.680759532183109], 
                Complex[37.44317619593503, -33.50570209730137]}, 2 -> {
                Complex[76.33284841044511, 0.14287151349532584`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.044134810046817`, -4.562547257019681}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.476681999633616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.567531219181608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.694371737074945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.366025475903584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.10602311146744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1446761639763866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A1", 
             Association[1 -> {
                Complex[18.476681999633616`, -7.567531219181608], 
                Complex[37.694371737074945`, -33.366025475903584`]}, 2 -> {
                Complex[76.10602311146744, 0.1446761639763866], 
                Complex[102.26185863012617`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.716979020375305`, -4.5188946173236}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.7207148587158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.458712785360555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.23074880548425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.8844677615424`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187037323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "A1", 
             Association[1 -> {
                Complex[18.7207148587158, -7.458712785360555], 
                Complex[37.94130857631962, -33.23074880548425]}, 2 -> {
                Complex[75.8844677615424, 0.14650724187037323`], 
                Complex[102.02923912251609`, -20.403602844982533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.3924505941045, -4.475839925377928}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.960425318413485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.353986351536103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.18430643425337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.09956067860008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.66776800411328`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1483650555087814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A1", 
             Association[1 -> {
                Complex[18.960425318413485`, -7.353986351536103], 
                Complex[38.18430643425337, -33.09956067860008]}, 2 -> {
                Complex[75.66776800411328, 0.1483650555087814], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.070499133215673`, -4.433360522696326}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.196106481999152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.253069946548066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.42364894442649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.97218501218881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.45555740059443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15024995077914985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A1", 
             Association[1 -> {
                Complex[19.196106481999152`, -7.253069946548066], 
                Complex[38.42364894442649, -32.97218501218881]}, 2 -> {
                Complex[75.45555740059443, 0.15024995077914985`], 
                Complex[101.57804924438945`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.75107778962585, -4.391435266852968}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.428020388516035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.155712048248098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.659589223203085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.848375652574305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.24750998887278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15216230740510475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "A1", 
             Association[1 -> {
                Complex[19.428020388516035`, -7.155712048248098], 
                Complex[38.659589223203085`, -32.848375652574305`]}, 2 -> {
                Complex[75.24750998887278, 0.15216230740510475`], 
                Complex[101.35878495705765`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.434142888604857`, -4.350044370793775}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.656402573483003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.06168715326511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.892354381854474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.04333425978076`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15410253608764446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A1", 
             Association[1 -> {
                Complex[19.656402573483003`, -7.06168715326511], 
                Complex[38.892354381854474`, -32.727912000016886`]}, 2 -> {
                Complex[75.04333425978076, 0.15410253608764446`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.11965360679628, -4.30916926503895}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.88146580099659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.122149216633446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.610595426395264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.84276823492078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15607107631331532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506859`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400745136126783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A1", 
             Association[1 -> {
                Complex[19.88146580099659, -6.970792147471287], 
                Complex[39.122149216633446`, -32.610595426395264`]}, 2 -> {
                Complex[74.84276823492078, 0.15607107631331532`], 
                Complex[100.93145144506859`, -20.400745136126783`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.807571695076838`, -4.268792478719192}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.10340314443287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.3491592528931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.64557540947717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580683946848076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.7228822269972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.4001205101715`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A1", 
             Association[1 -> {
                Complex[20.10340314443287, -6.882843306606507], 
                Complex[39.3491592528931, -32.49624631678466]}, 2 -> {
                Complex[74.64557540947717, 0.1580683946848076], 
                Complex[100.7228822269972, -20.4001205101715]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.497861238541585`, -4.228897536235095}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.322390549817726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.797673797918388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.573553276414586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.38470160682706`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.45154138132087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1600949836664982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A1", 
             Association[1 -> {
                Complex[20.322390549817726`, -6.797673797918388], 
                Complex[39.573553276414586`, -32.38470160682706]}, 2 -> {
                Complex[74.45154138132087, 0.1600949836664982], 
                Complex[100.51741711927747`, -20.399477392046542`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.19048844746747, -4.189468866976496}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.53858898448397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.79548545383973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.27581271779224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.26047102973546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1621513606638985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.3148602374095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.398815388055127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "A1", 
             Association[1 -> {
                Complex[20.53858898448397, -6.715131583883614], 
                Complex[39.79548545383973, -32.27581271779224]}, 2 -> {
                Complex[74.26047102973546, 0.1621513606638985], 
                Complex[100.3148602374095, -20.398815388055127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.885421474306472`, -4.150491726035257}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.752146250400717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.635077651408368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340219`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07218613811635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16423806737529167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39813408035839`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "A1", 
             Association[1 -> {
                Complex[20.752146250400717`, -6.635077651408368], 
                Complex[40.01509712100966, -32.16944381340219]}, 2 -> {
                Complex[74.07218613811635, 0.16423806737529167`], 
                Complex[100.11503259520978`, -20.39813408035839]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.58263025269607, -4.111952124232918}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.963198524196073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.557384506607896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.065470319069306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.88652337816677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936818696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "A1", 
             Association[1 -> {
                Complex[20.963198524196073`, -6.557384506607896], 
                Complex[40.23251830075455, -32.065470319069306`]}, 2 -> {
                Complex[73.88652337816677, 0.16635566936818696`], 
                Complex[99.91777008789096, -20.397433027529207`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.282086355205085`, -4.073836766087403}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.171871672770024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.481934887900368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.447868998641226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.963777656737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.70333259061725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16850475584425448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.72292177174809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A1", 
             Association[1 -> {
                Complex[21.171871672770024`, -6.481934887900368], 
                Complex[40.447868998641226`, -31.963777656737]}, 2 -> {
                Complex[73.70333259061725, 0.16850475584425448`], 
                Complex[99.72292177174809, -20.39671176490144]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.98376286711323, -4.036132994585326}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.378282383376405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.408620659800499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.661260315234074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.864260158083315`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.52247531084704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17068593956353983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A1", 
             Association[1 -> {
                Complex[21.378282383376405`, -6.408620659800499], 
                Complex[40.661260315234074`, -31.864260158083315`]}, 2 -> {
                Complex[73.52247531084704, 0.17068593956353983`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.68763427398533, -3.9988287418178725`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.58253913933037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.76682012623099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34382349807167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1728998569070958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "A1", 
             Association[1 -> {
                Complex[21.58253913933037, -6.337341857243096], 
                Complex[40.87279540575696, -31.76682012623099]}, 2 -> {
                Complex[73.34382349807167, 0.1728998569070958], 
                Complex[99.33992109514008, -20.39520663629768]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.393676361172393`, -3.961912484693128}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.78474306649485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.08257031208464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.671367021850585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.167258434751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1751471680593818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39442172564926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A1", 
             Association[1 -> {
                Complex[21.78474306649485, -6.268005856060312], 
                Complex[41.08257031208464, -31.671367021850585`]}, 2 -> {
                Complex[73.167258434751, 0.1751471680593818], 
                Complex[99.15152035933141, -20.39442172564926]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.10186612367236, -3.925373205064215}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.98498867099265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.577816754044576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.99266976913438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17742855729767226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.9650350042688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39361451553301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "A1", 
             Association[1 -> {
                Complex[21.98498867099265, -6.20052664977852], 
                Complex[41.290674687319935`, -31.577816754044576`]}, 2 -> {
                Complex[72.99266976913438, 0.17742855729767226`], 
                Complex[98.9650350042688, -20.39361451553301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.81218168503001, -3.889200353713644}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.183364484872566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.13482421649645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.497192429524794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.486091059962376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.81995467880073`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17974473337764585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A1", 
             Association[1 -> {
                Complex[22.183364484872566`, -6.13482421649645], 
                Complex[41.497192429524794`, -31.486091059962376`]}, 2 -> {
                Complex[72.81995467880073, 0.17974473337764585`], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.52460222415466, -3.853383817719923}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.379953633499717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.070823962465011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.702202238238115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.396116959927433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.6490171369839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18209643000701964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391930848977243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A1", 
             Association[1 -> {
                Complex[22.379953633499717`, -6.070823962465011], 
                Complex[41.702202238238115`, -31.396116959927433`]}, 2 -> {
                Complex[72.6490171369839, 0.18209643000701964`], 
                Complex[98.59740257849907, -20.391930848977243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.239107909102145`, -3.8179138908009556`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.574834336069365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.008456231284855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.47976726661949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18448440640095548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391053157806226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "A1", 
             Association[1 -> {
                Complex[22.574834336069365`, -6.008456231284855], 
                Complex[41.905778105062396`, -31.30782627713036]}, 2 -> {
                Complex[72.47976726661949, 0.18448440640095548`], 
                Complex[98.41606788851907, -20.391053157806226`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.955679837004457`, -3.7827812462868895`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.76808034873237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.9476558694891155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.31212076958602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18690944791455164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A1", 
             Association[1 -> {
                Complex[22.76808034873237, -5.9476558694891155`], 
                Complex[42.10798974770687, -31.221155212774136`]}, 2 -> {
                Complex[72.31212076958602, 0.18690944791455164`], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.674299979444683`, -3.747976912423253}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.959761358270317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.888361840780239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.14599842066895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18937236674901933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38922278462222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "A1", 
             Association[1 -> {
                Complex[22.959761358270317`, -5.888361840780239], 
                Complex[42.30890299533776, -31.136043969043037`]}, 2 -> {
                Complex[72.14599842066895, 0.18937236674901933`], 
                Complex[98.05793516060473, -20.38922278462222]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.394951132672542`, -3.713492249745922}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.149943332992876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.830516882419161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.98132561745237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19187400272919972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "A1", 
             Association[1 -> {
                Complex[23.149943332992876`, -5.830516882419161], 
                Complex[42.50858013183331, -31.052436413482706`]}, 2 -> {
                Complex[71.98132561745237, 0.19187400272919972`], 
                Complex[97.88098148963748, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.117616872135905`, -3.67931893030301}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.338688836493038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.774067198270846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.970279779373037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.8180319787172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1944152241510169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "A1", 
             Association[1 -> {
                Complex[23.338688836493038`, -5.774067198270846], 
                Complex[42.70708020251328, -30.970279779373037`]}, 2 -> {
                Complex[71.8180319787172, 0.1944152241510169], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.842281510872276`, -3.6454489185281425`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.52605730903988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7189621838426925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.90445928906574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.889524397498597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.65605098505654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1969969286982196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A1", 
             Association[1 -> {
                Complex[23.52605730903988, -5.7189621838426925`], 
                Complex[42.90445928906574, -30.889524397498597`]}, 2 -> {
                Complex[71.65605098505654, 0.1969969286982196], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.5689300613629, -3.6118744535941687`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.712105320680124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.66515417934074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.10077075669193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.49531965635687`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19962004442847947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.385242064287233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A1", 
             Association[1 -> {
                Complex[23.712105320680124`, -5.66515417934074], 
                Complex[43.10077075669193, -30.810123455401047`]}, 2 -> {
                Complex[71.49531965635687, 0.19962004442847947`], 
                Complex[97.35772603163758, -20.385242064287233`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.29754820050191, -3.5785880330967768`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.89688679952995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.61259824734414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.29606547690717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.73203278076685`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.33577826157267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20228553082947315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.1856292938539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "A1", 
             Association[1 -> {
                Complex[23.89688679952995, -5.61259824734414], 
                Complex[43.29606547690717, -30.73203278076685]}, 2 -> {
                Complex[71.33577826157267, 0.20228553082947315`], 
                Complex[97.1856292938539, -20.38417572502943]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.02812223737448, -3.5455823979361014`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.0804532382449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.490392028946715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.655210646076952`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.1773700568739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20499437994616249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "A1", 
             Association[1 -> {
                Complex[24.0804532382449, -5.561251972178108], 
                Complex[43.490392028946715`, -30.655210646076952`]}, 2 -> {
                Complex[71.1773700568739, 0.20499437994616249`], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.760639083576077`, -3.512850518279514}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.262853881242368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.5110752784691694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.6837968823168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.579617592043476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.02004104879211`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20774761758097854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38195178241304`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A1", 
             Association[1 -> {
                Complex[24.262853881242368`, -5.5110752784691694`], 
                Complex[43.6837968823168, -30.579617592043476`]}, 2 -> {
                Complex[71.02004104879211, 0.20774761758097854`], 
                Complex[96.84456714160432, -20.38195178241304]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.49508622583483, -3.4803855805021815`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.444135894902008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.462030266708765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.50521626769631`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.8637397794511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117393`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A1", 
             Association[1 -> {
                Complex[24.444135894902008`, -5.462030266708765], 
                Complex[43.87632456268656, -30.50521626769631]}, 2 -> {
                Complex[70.8637397794511, 0.2105463045690771], 
                Complex[96.6754942074181, -20.38079237117393]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.231451700728176`, -3.4481809750134182`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.624344522673923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.414081063937796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.431971285264723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.7084171313574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21339153813132042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.379600070118972`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A1", 
             Association[1 -> {
                Complex[24.624344522673923`, -5.414081063937796], 
                Complex[44.06801780302345, -30.431971285264723`]}, 2 -> {
                Complex[70.7084171313574, 0.21339153813132042`], 
                Complex[96.50732568207661, -20.379600070118972`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.96972407130601, -3.4162302848870283`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.803523226774285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.367193687912322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.25891768162856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.35984908824372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.554026149556`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21628445330793847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.3400135200408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.378373886270055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "A1", 
             Association[1 -> {
                Complex[24.803523226774285`, -5.367193687912322], 
                Complex[44.25891768162856, -30.35984908824372]}, 2 -> {
                Complex[70.554026149556, 0.21628445330793847`], 
                Complex[96.3400135200408, -20.378373886270055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.709892405456237`, -3.3845272752226805`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.981713817934338`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.321335923317819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.40052187923786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21922622447656767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "A1", 
             Association[1 -> {
                Complex[24.981713817934338`, -5.321335923317819], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[70.40052187923786, 0.21922622447656767`], 
                Complex[96.17351165179056, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.45194625586437, -3.353065883172423}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.158956574486158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.24786121712583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22221806695837287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A1", 
             Association[1 -> {
                Complex[25.158956574486158`, -5.276477208780441], 
                Complex[44.63849414140556, -30.218847270360484`]}, 2 -> {
                Complex[70.24786121712583, 0.22221806695837287`], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.195875641435784`, -3.3218402085738745`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.335290351911958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.232588533576678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.14990866309333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.09600277517207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22526123871674927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "A1", 
             Association[1 -> {
                Complex[25.335290351911958`, -5.232588533576678], 
                Complex[44.82724569242562, -30.14990866309333]}, 2 -> {
                Complex[70.09600277517207, 0.22526123871674927`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.941671030061947`, -3.2908445051367625`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.51075268384907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.01535402652587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.081974676689654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.9449067552762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2283570421533727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.373109088340822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "A1", 
             Association[1 -> {
                Complex[25.51075268384907, -5.189642343075509], 
                Complex[45.01535402652587, -30.081974676689654`]}, 2 -> {
                Complex[69.9449067552762, 0.2283570421533727], 
                Complex[95.67843369946034, -20.373109088340822`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.689323322626525`, -3.260073172135142}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.685379875427014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.147612452062529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.015019304257965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.79453483388642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23150682600686606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3716971966093`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "A1", 
             Association[1 -> {
                Complex[25.685379875427014`, -5.147612452062529], 
                Complex[45.20285365244138, -30.015019304257965`]}, 2 -> {
                Complex[69.79453483388642, 0.23150682600686606`], 
                Complex[95.51474684712201, -20.3716971966093]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.438823838154573`, -3.2295207465618603`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.8592070897119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.389778046984475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.949017787808245`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.64485005547786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23471198735987034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.370244599576857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A1", 
             Association[1 -> {
                Complex[25.8592070897119, -5.106473965194025], 
                Complex[45.389778046984475`, -29.949017787808245`]}, 2 -> {
                Complex[69.64485005547786, 0.23471198735987034`], 
                Complex[95.35166475158147, -20.370244599576857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.19016430002113, -3.1991818957059213`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.03226842794698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.49581673401624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23797397376075155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.368749998403654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A1", 
             Association[1 -> {
                Complex[26.03226842794698, -5.066203203916086], 
                Complex[45.57615973333944, -29.88394654760415]}, 2 -> {
                Complex[69.49581673401624, 0.23797397376075155`], 
                Complex[95.18915044704522, -20.368749998403654`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.94333682314167, -3.1690514101170244`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.20459700420211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.819783117245702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.34740036161425`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546682113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36721204229602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "A1", 
             Association[1 -> {
                Complex[26.20459700420211, -5.026777639259069], 
                Complex[45.76203035396384, -29.819783117245702`]}, 2 -> {
                Complex[69.34740036161425, 0.24129428546682113`], 
                Complex[95.02716811464276, -20.36721204229602]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.698333902074943`, -3.1391241969244934`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.376225014979173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.988175829983501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.19956752367546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24467447781636717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.365629326062496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A1", 
             Association[1 -> {
                Complex[26.376225014979173`, -4.988175829983501], 
                Complex[45.94742073863614, -29.756506083970773`]}, 2 -> {
                Complex[69.19956752367546, 0.24467447781636717`], 
                Complex[94.86568299639735, -20.365629326062496`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.455148399976451`, -3.109395273480745}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.54718380426279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9503773656115`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"46.13236096813211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.05228581989404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2481161637376161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A1", 
             Association[1 -> {
                Complex[26.54718380426279, -4.9503773656115], 
                Complex[46.13236096813211, -29.694095033720565`]}, 2 -> {
                Complex[69.05228581989404, 0.2481161637376161], 
                Complex[94.70466131500459, -20.364000387523564`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.213773538345677`, -3.0798597613018472`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.71750392445519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.91336281392886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.31688043396312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.63253050056466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.90552379054706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.25162101640318657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A1", 
             Association[1 -> {
                Complex[26.71750392445519, -4.91336281392886], 
                Complex[46.31688043396312, -29.63253050056466]}, 2 -> {
                Complex[68.90552379054706, 0.25162101640318657`], 
                Complex[94.54407019885232, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.974202887516057`, -3.0505128802798946`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.88721519359033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.8771136725869555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.501007894566264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.57179392012435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.75925084757176`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2551907720394873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.3838776117713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A1", 
             Association[1 -> {
                Complex[26.88721519359033, -4.8771136725869555`], 
                Complex[46.501007894566264`, -29.57179392012435]}, 2 -> {
                Complex[68.75925084757176, 0.2551907720394873], 
                Complex[94.3838776117713, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.736430357841435`, -3.0213499431438393`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.056346749183458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.841612324474782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.511867586673578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.61343720997206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2588272329011793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "A1", 
             Association[1 -> {
                Complex[27.056346749183458`, -4.841612324474782], 
                Complex[46.684771528299024`, -29.511867586673578`]}, 2 -> {
                Complex[68.61343720997206, 0.2588272329011793], 
                Complex[94.22405228705699, -20.358820702623657`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.500450191538128`, -2.992366350147382}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.22492709903808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.86819898355647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.452734613629456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.46805384314331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2625322704216664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "A1", 
             Association[1 -> {
                Complex[27.22492709903808, -4.806841996564799], 
                Complex[46.86819898355647, -29.452734613629456`]}, 2 -> {
                Complex[68.46805384314331, 0.2625322704216664], 
                Complex[94.06456366534842, -20.35699101364115]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.26625695514327, -2.963557583963391}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.392984169302537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.772786721969353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.32307240174265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2663078285515145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486676`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "A1", 
             Association[1 -> {
                Complex[27.392984169302537`, -4.772786721969353], 
                Complex[47.051317426301225`, -29.394378897177]}, 2 -> {
                Complex[68.32307240174265, 0.2663078285515145], 
                Complex[93.90538183598731, -20.355106834486676`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.03384553255713, -2.9349192047666914`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.56054535004208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.739431304971095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.234153585269965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.336785082799015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.17846517576804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27015592729763743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A1", 
             Association[1 -> {
                Complex[27.56054535004208, -4.739431304971095], 
                Complex[47.234153585269965`, -29.336785082799015`]}, 2 -> {
                Complex[68.17846517576804, 0.27015592729763743`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.803211118636789`, -2.906446845487306}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.727637538568867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.706761288816323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.03420503953862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27407866647716145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.351167453618455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A1", 
             Association[1 -> {
                Complex[27.727637538568867`, -4.706761288816323], 
                Complex[47.41673379509784, -29.279938534507]}, 2 -> {
                Complex[68.03420503953862, 0.27407866647716145`], 
                Complex[93.58782182500669, -20.351167453618455`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.574349213315081`, -2.8781362072179117`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.894287180751792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.674762926083082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.599084037582415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.223825306591664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.89026540329692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2780782297010494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.349108271425646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "A1", 
             Association[1 -> {
                Complex[27.894287180751792`, -4.674762926083082], 
                Complex[47.599084037582415`, -29.223825306591664`]}, 2 -> {
                Complex[67.89026540329692, 0.2780782297010494], 
                Complex[93.42938657992539, -20.349108271425646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.34725561621783, -2.8499830547596368`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.060520310510153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.6434231514550905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.78122998129108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.16843211773069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.74662016717633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.282156888603788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.27114390229022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A1", 
             Association[1 -> {
                Complex[28.060520310510153`, -4.6434231514550905`], 
                Complex[47.78122998129108, -29.16843211773069]}, 2 -> {
                Complex[67.74662016717633, 0.282156888603788], 
                Complex[93.27114390229022, -20.34698662948813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.12192642175826, -2.8219832122920128`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.22636258767924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.113746327310373`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.60324367729916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2863170073368824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "A1", 
             Association[1 -> {
                Complex[28.22636258767924, -4.612729556752129], 
                Complex[47.96319701970124, -29.113746327310373`]}, 2 -> {
                Complex[67.60324367729916, 0.2863170073368824], 
                Complex[93.11306634486286, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.898358014687474`, -2.7941325591524535`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.391839334421146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.582670368083356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834188`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.46011068378857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.342547009636124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A1", 
             Association[1 -> {
                Complex[28.391839334421146`, -4.582670368083356], 
                Complex[48.14501030804771, -29.059755913834188`]}, 2 -> {
                Complex[67.46011068378857, 0.2905610473453296], 
                Complex[92.95512681316393, -20.342547009636124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.676547066083096`, -2.7664270257122823`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.556975570343152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.553234425005791`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.326694799042336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.00644945530591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.31719630049454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29489157244794845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A1", 
             Association[1 -> {
                Complex[28.556975570343152`, -4.553234425005791], 
                Complex[48.326694799042336`, -29.00644945530591]}, 2 -> {
                Complex[67.31719630049454, 0.29489157244794845`], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.456490529760053`, -2.7388625893361542`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.721796046473646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.524411161584021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.9538161114898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.17447596624794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29931125424420046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A1", 
             Association[1 -> {
                Complex[28.721796046473646`, -4.524411161584021], 
                Complex[48.50827527761825, -28.9538161114898]}, 2 -> {
                Complex[67.17447596624794, 0.29931125424420046`], 
                Complex[92.63955496002485, -20.337829663202015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.238185639088748`, -2.711435270412446}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.88632527823729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.68977639484416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.901845607962514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.03192540747014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3038228778721793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A1", 
             Association[1 -> {
                Complex[28.88632527823729, -4.496190589260186], 
                Complex[48.68977639484416, -28.901845607962514`]}, 2 -> {
                Complex[67.03192540747014, 0.3038228778721793], 
                Complex[92.48186983901314, -20.33536045179569]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.02162990420851, -2.6841411284423433`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.050587577562062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.468563281455599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.871222701145584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.850528221884158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.88952060197633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3084293481445193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.332813903268473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "A1", 
             Association[1 -> {
                Complex[29.050587577562062`, -4.468563281455599], 
                Complex[48.871222701145584`, -28.850528221884158`]}, 2 -> {
                Complex[66.88952060197633, 0.3084293481445193], 
                Complex[92.32421706624814, -20.332813903268473`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.806821109624941`, -2.656976258176025}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.21460708424427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.44152035983643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.79985476942697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.7472377438204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31313369609146635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33018712420928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "A1", 
             Association[1 -> {
                Complex[29.21460708424427, -4.44152035983643], 
                Complex[49.05263867896423, -28.79985476942697]}, 2 -> {
                Complex[66.7472377438204, 0.31313369609146635`], 
                Complex[92.16657070129293, -20.33018712420928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.593757312182326`, -2.629936785783782}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.37840779669111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.23404877498035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.7498165948108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.60505320903809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3179390859428899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651893`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "A1", 
             Association[1 -> {
                Complex[29.37840779669111, -4.4150534821866145`], 
                Complex[49.23404877498035, -28.7498165948108]}, 2 -> {
                Complex[66.60505320903809, 0.3179390859428899], 
                Complex[92.00890492013563, -20.327477084651893`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.38243683940241, -2.603018865050693}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.542013602155205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.389154831841678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.46294352215183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.322848822583996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.85119397884918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.324680610124492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A1", 
             Association[1 -> {
                Complex[29.542013602155205`, -4.389154831841678], 
                Complex[49.41547743201958, -28.700405560905736`]}, 2 -> {
                Complex[66.46294352215183, 0.322848822583996], 
                Complex[91.85119397884918, -20.324680610124492`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.172858288183662`, -2.576218673583348}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.705448306571707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.363817108646442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.596949120761906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.651614041371168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.32088532330775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32786635952260046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.321794373139106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A1", 
             Association[1 -> {
                Complex[29.705448306571707`, -4.363817108646442], 
                Complex[49.596949120761906`, -28.651614041371168`]}, 2 -> {
                Complex[66.32088532330775, 0.32786635952260046`], 
                Complex[91.6934121777283, -20.321794373139106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.96502052385543, -2.549532409016802}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.868735664104204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.33903352140945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.60343491431109`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.17885533591951`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3329953074094176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "A1", 
             Association[1 -> {
                Complex[29.868735664104204`, -4.33903352140945], 
                Complex[49.77848837136716, -28.60343491431109]}, 2 -> {
                Complex[66.17885533591951, 0.3329953074094176], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.758922679583286, -2.5229562852100145`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.0318994065037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.960119805130674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.555861557435456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.0368303346989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3382394431566841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "A1", 
             Association[1 -> {
                Complex[30.0318994065037, -4.314797781836445], 
                Complex[49.960119805130674`, -28.555861557435456`]}, 2 -> {
                Complex[66.0368303346989, 0.3382394431566841], 
                Complex[91.37753320535236, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.554564156122666, -2.496486528417938}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.194963272382548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.291104099934118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.141868166281284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.50888784472627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.89478711395589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.312561321201745`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A1", 
             Association[1 -> {
                Complex[30.194963272382548`, -4.291104099934118], 
                Complex[50.141868166281284`, -28.50888784472627]}, 2 -> {
                Complex[65.89478711395589, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.312561321201745`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.351944621919706, -2.4701193734280054`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.35795103650346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.26794718088456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.3237583540324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.46250814461731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.75270245605407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34908927649101035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A1", 
             Association[1 -> {
                Complex[30.35795103650346, -4.26794718088456], 
                Complex[50.3237583540324, -28.46250814461731]}, 2 -> {
                Complex[65.75270245605407, 0.34908927649101035`], 
                Complex[91.0610619442071, -20.30927936589565]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.151064013558923, -2.4438510596483187`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.520886539183877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.24532222340097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.50581545499962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.416717319706727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.6105530999087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3547034506809741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A1", 
             Association[1 -> {
                Complex[30.520886539183877`, -4.24532222340097], 
                Complex[50.50581545499962, -28.416717319706727`]}, 2 -> {
                Complex[65.6105530999087, 0.3547034506809741], 
                Complex[90.90253941775816, -20.305888372154577`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.951922536558712, -2.4176778271346624`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.683793715914877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.22322491958401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.688064776097136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.371510728031744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.46831570941634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36044978922689475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.7437907802159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "A1", 
             Association[1 -> {
                Complex[30.683793715914877`, -4.22322491958401], 
                Complex[50.688064776097136`, -28.371510728031744`]}, 2 -> {
                Complex[65.46831570941634, 0.36044978922689475`], 
                Complex[90.7437907802159, -20.30238387787967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.754520666516932, -2.3915959125426483`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.846696627295138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.201651456308564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.87053187802873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.326884225945257`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.325966841705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3663330618262281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.298761188193378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A1", 
             Association[1 -> {
                Complex[30.846696627295138`, -4.201651456308564], 
                Complex[50.87053187802873, -28.326884225945257`]}, 2 -> {
                Complex[65.325966841705, 0.3663330618262281], 
                Complex[90.58478964962532, -20.298761188193378`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.558859150610026, -2.3656015449910406`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.009619489380988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.180598518180851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.28283417264592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.1834829150937`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3723582748592317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A1", 
             Association[1 -> {
                Complex[31.009619489380988`, -4.180598518180851], 
                Complex[51.05324260949038, -28.28283417264592]}, 2 -> {
                Complex[65.1834829150937, 0.3723582748592317], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.364939009450417, -2.3396909418210683`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.172586704555457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.160063292117314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.236223142205915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.239357436425397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.04084017664968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3785306863932047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "A1", 
             Association[1 -> {
                Complex[31.172586704555457`, -4.160063292117314], 
                Complex[51.236223142205915`, -28.239357436425397`]}, 2 -> {
                Complex[65.04084017664968, 0.3785306863932047], 
                Complex[90.26592313793014, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.172761539307587, -2.313860304236032}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.33562289302192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.89801466922918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3848558223499517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.287133180835255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "A1", 
             Association[1 -> {
                Complex[31.33562289302192, -4.140043473607489], 
                Complex[51.419500006920465`, -28.196451402708604`]}, 2 -> {
                Complex[64.89801466922918, 0.3848558223499517], 
                Complex[90.10600363628704, -20.287133180835255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.982328314700709, -2.288105812804716}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.49875292502993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.603100130481025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.75498219788668`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.391339493943095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "A1", 
             Association[1 -> {
                Complex[31.49875292502993, -4.120537274736596], 
                Complex[51.603100130481025`, -28.154113983977776`]}, 2 -> {
                Complex[64.75498219788668, 0.391339493943095], 
                Complex[89.94572332307655, -20.282985551225515`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.793641191370554, -2.262423622810296}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.662001953945484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.101543434056313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.61171829553294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3979878165032359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.7850542271069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A1", 
             Association[1 -> {
                Complex[31.662001953945484`, -4.101543434056313], 
                Complex[51.78705087413992, -28.112343631685345`]}, 2 -> {
                Complex[64.61171829553294, 0.3979878165032359], 
                Complex[89.7850542271069, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.60670230964103, -2.2368098594262147`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.825395450280787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.083061228407537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277985`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.46819818772052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40480722982158246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.62396793923683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A1", 
             Association[1 -> {
                Complex[31.825395450280787`, -4.083061228407537], 
                Complex[51.97138007322182, -28.071139350277985`]}, 2 -> {
                Complex[64.46819818772052, 0.40480722982158246`], 
                Complex[89.62396793923683, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.421514098181014, -2.2112606126978562`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.988959236804785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.065090486814274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.32439675642944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4118045201569269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.269642077367138`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A1", 
             Association[1 -> {
                Complex[31.988959236804785`, -4.065090486814274], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[64.32439675642944, 0.4118045201569269], 
                Complex[89.46243556940976, -20.269642077367138`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.238079278179278, -2.185771932308567}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.1527195248595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.99042788293637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.18028850272216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.41898684406680864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A1", 
             Association[1 -> {
                Complex[32.1527195248595, -4.047631606586535], 
                Complex[52.34128779806401, -27.99042788293637]}, 2 -> {
                Complex[64.18028850272216, 0.41898684406680864`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.056400867946785, -2.1603398221055095`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.31670295201473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.52692474396548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.95092162957881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.03584750813043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42636175424164896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A1", 
             Association[1 -> {
                Complex[32.31670295201473, -4.030685571788463], 
                Complex[52.52692474396548, -27.95092162957881]}, 2 -> {
                Complex[64.03584750813043, 0.42636175424164896`], 
                Complex[89.13791435011574, -20.259926647201578`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.876482187961557, -2.1349602343598484`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.48093662119898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.7130570769491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.911983357620024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.891047394630874`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4339372275409471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A1", 
             Association[1 -> {
                Complex[32.48093662119898, -4.014253974250843], 
                Complex[52.7130570769491, -27.911983357620024`]}, 2 -> {
                Complex[63.891047394630874`, 0.4339372275409471], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.698326866373847, -2.109629063732683}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.645448141453244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.998339037330256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.89971565632317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87361513171316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.7458612830591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4417216954533841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24948292358025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A1", 
             Association[1 -> {
                Complex[32.645448141453244`, -3.998339037330256], 
                Complex[52.89971565632317, -27.87361513171316]}, 2 -> {
                Complex[63.7458612830591, 0.4417216954533841], 
                Complex[88.81124809301977, -20.24948292358025]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.521938844990224, -2.08434214091624}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.810265670460794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9829436426451004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.086932091046236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.600261749804105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.243966169666688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "A1", 
             Association[1 -> {
                Complex[32.810265670460794`, -3.9829436426451004`], 
                Complex[53.086932091046236`, -27.835819707361438`]}, 2 -> {
                Complex[63.600261749804105`, 0.44972407722861746`], 
                Complex[88.64703191016159, -20.243966169666688`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.347322385758012, -2.0590952259162663`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.97541795901581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.27473879361426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.798600564939377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.45422078161694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45795381595762275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23824012528373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A1", 
             Association[1 -> {
                Complex[32.97541795901581, -3.968071360048478], 
                Complex[53.27473879361426, -27.798600564939377`]}, 2 -> {
                Complex[63.45422078161694, 0.45795381595762275`], 
                Complex[88.48218357926147, -20.23824012528373]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.174482077772204, -2.0338840009390537`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.14093439760302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.953726481132371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.76196194765724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.30770972835797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.466420917911682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23229452138455`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "A1", 
             Association[1 -> {
                Complex[33.14093439760302, -3.953726481132371], 
                Complex[53.46316903677714, -27.76196194765724]}, 2 -> {
                Complex[63.30770972835797, 0.466420917911682], 
                Complex[88.31666948593067, -20.23229452138455]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.003422844830105, -2.008704062842172}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.306845065269485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.939914056596168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.72590890385442`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.16069925349776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4751359954876585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "A1", 
             Association[1 -> {
                Complex[33.306845065269485`, -3.939914056596168], 
                Complex[53.65225701332302, -27.72590890385442]}, 2 -> {
                Complex[63.16069925349776, 0.4751359954876585], 
                Complex[88.15045511884611, -20.226118434741064`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.834149953560505, -1.9835509151043969`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.47318078098145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9266399378561223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.842037899187076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.69044733405728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.01315928217634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4841103141499007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A1", 
             Association[1 -> {
                Complex[33.47318078098145, -3.9266399378561223`], 
                Complex[53.842037899187076`, -27.69044733405728]}, 2 -> {
                Complex[63.01315928217634, 0.4841103141499007], 
                Complex[87.98350500554794, -20.219700235746625`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.666669022156675, -1.9584199592654077`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.63997315766917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.0325479201562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.655584043295313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.86505894661449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49335584380795366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.8157826446966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.21302753118228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "A1", 
             Association[1 -> {
                Complex[33.63997315766917, -3.913910823322055], 
                Complex[54.0325479201562, -27.655584043295313`]}, 2 -> {
                Complex[62.86505894661449, 0.49335584380795366`], 
                Complex[87.8157826446966, -20.21302753118228]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.500986029744887, -1.9333064857805216`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.80725465917451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9017343098237633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.223824422460964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.621326799234737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.71636652866016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5028853151246296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A1", 
             Association[1 -> {
                Complex[33.80725465917451, -3.9017343098237633`], 
                Complex[54.223824422460964`, -27.621326799234737`]}, 2 -> {
                Complex[62.71636652866016, 0.5028853151246296], 
                Complex[87.64725043449562, -20.206087101376106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.3371073264222915`, -1.908205664230099}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.975058660327356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8901189497339574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.415905947563445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.587684396763738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.56704939924091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5127122813126167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.4778695969676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19886483111003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A1", 
             Association[1 -> {
                Complex[33.975058660327356`, -3.8901189497339574`], 
                Complex[54.415905947563445`, -27.587684396763738`]}, 2 -> {
                Complex[62.56704939924091, 0.5127122813126167], 
                Complex[87.4778695969676, -20.19886483111003]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.175039644001416, -1.8831125328162965`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.143419510388775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.879074314407841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.417073954482824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19134563354414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A1", 
             Association[1 -> {
                Complex[34.143419510388775`, -3.879074314407841], 
                Complex[54.60883231147051, -27.554666729749552`]}, 2 -> {
                Complex[62.417073954482824`, 0.5228511860504309], 
                Complex[87.30760009775224, -20.19134563354414]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.014790107500879, -1.8580219870723287`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.312372600109356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8686110646435656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.80264468892042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.5222848707862`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.26640554824476`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5333174382317767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A1", 
             Association[1 -> {
                Complex[34.312372600109356`, -3.8686110646435656`], 
                Complex[54.80264468892042, -27.5222848707862]}, 2 -> {
                Complex[62.26640554824476, 0.5333174382317767], 
                Complex[87.13640056107454, -20.183513366330008`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.856366247423921, -1.8329287677007002`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.48195443266224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49055115986421`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.11500842080698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A1", 
             Association[1 -> {
                Complex[34.48195443266224, -3.8587410289636725`], 
                Complex[54.99738570281197, -27.49055115986421]}, 2 -> {
                Complex[62.11500842080698, 0.5441274943581387], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.699776012871993, -1.807827447447309}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.65220269871858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.193099519263775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.45947930302496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.96284562344401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.555298949494675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A1", 
             Association[1 -> {
                Complex[34.65220269871858, -3.849477290628971], 
                Complex[55.193099519263775`, -27.45947930302496]}, 2 -> {
                Complex[61.96284562344401, 0.555298949494675], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.545027785540228, -1.7827124169069233`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.82315635594019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8408342844230736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.429084482211824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.80987893860578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668506378361227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.157958875303546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "A1", 
             Association[1 -> {
                Complex[34.82315635594019, -3.8408342844230736`], 
                Complex[55.38983194870933, -27.429084482211824`]}, 2 -> {
                Complex[61.80987893860578, 0.5668506378361227], 
                Complex[86.61678591287696, -20.157958875303546`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.3921303946479355`, -1.7575778691429758`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.99485571316776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.58763055344998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.65606879542663`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5788027440763145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "A1", 
             Association[1 -> {
                Complex[34.99485571316776, -3.8328279043933393`], 
                Complex[55.58763055344998, -27.39938347770468]}, 2 -> {
                Complex[61.65606879542663, 0.5788027440763145], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.241093132858161, -1.7324177829899607`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.16734251958135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.501374180284344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "A1", 
             Association[1 -> {
                Complex[35.16734251958135, -3.8254756239037375`], 
                Complex[55.78654476209901, -27.370394804725706`]}, 2 -> {
                Complex[61.501374180284344`, 0.5911769269441449], 
                Complex[86.26489841088478, -20.139004574702856`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.091925773245386, -1.707225904890441}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.34066005910287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.81879662955199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.342138866037867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.345752542137845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.603996456465433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "A1", 
             Association[1 -> {
                Complex[35.34066005910287, -3.81879662955199], 
                Complex[55.98662599135723, -27.342138866037867`]}, 2 -> {
                Complex[61.345752542137845`, 0.603996456465433], 
                Complex[86.08716253043333, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.9446385873712657`, -1.68199572909921}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.5148532502931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8128119707315338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.31463812262956`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.18915969238974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6172863667379076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A1", 
             Association[1 -> {
                Complex[35.5148532502931, -3.8128119707315338`], 
                Complex[56.18792777555814, -27.31463812262956]}, 2 -> {
                Complex[61.18915969238974, 0.6172863667379076], 
                Complex[85.90816108596371, -20.118296161792685`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.799242364533555, -1.6567204760658996`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.68996875196817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.39050590440941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.28791728489552`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.03154969904756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6310736262715524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.107215817279773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "A1", 
             Association[1 -> {
                Complex[35.68996875196817, -3.807544726884647], 
                Complex[56.39050590440941, -27.28791728489552]}, 2 -> {
                Complex[61.03154969904756, 0.6310736262715524], 
                Complex[85.72783819940136, -20.107215817279773`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.6557484322533327`, -1.631393068781625}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.866055074715334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8030201948010105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.262003527092865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.872874775003034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.5461356023026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.095610443428537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A1", 
             Association[1 -> {
                Complex[35.866055074715334`, -3.8030201948010105`], 
                Complex[56.594418569327175`, -27.262003527092865`]}, 2 -> {
                Complex[60.872874775003034`, 0.6453873282550383], 
                Complex[85.5461356023026, -20.095610443428537`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.5141686780691046`, -1.6060061068470048`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.04316269842235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7992660986771667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.799726518711694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.236926728284004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.71308516031326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6602589034686106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.36299248006208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A1", 
             Association[1 -> {
                Complex[36.04316269842235, -3.7992660986771667`], 
                Complex[56.799726518711694`, -27.236926728284004`]}, 2 -> {
                Complex[60.71308516031326, 0.6602589034686106], 
                Complex[85.36299248006208, -20.08344612962457]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.3745155727057607`, -1.5805518379850394`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.22134419584062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7963128260714716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.006493222433235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.212719743482186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.552128998463665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595752`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A1", 
             Association[1 -> {
                Complex[36.22134419584062, -3.7963128260714716`], 
                Complex[57.006493222433235`, -27.212719743482186`]}, 2 -> {
                Complex[60.552128998463665`, 0.6757223589838265], 
                Complex[85.17834530693467, -20.070686076595752`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.236802194687911, -1.555022126684264}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.4006543620702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794193693381184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.389952206722754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.99212767171738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A1", 
             Association[1 -> {
                Complex[36.4006543620702, -3.794193693381184], 
                Complex[57.21478504568002, -27.18941870930894]}, 2 -> {
                Complex[60.389952206722754`, 0.6918145462814401], 
                Complex[84.99212767171738, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.101042256461575, -1.5294084196127038`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.58115034967376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.16706338916731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.22649834088111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7085754629936015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.04321522376426`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "A1", 
             Association[1 -> {
                Complex[36.58115034967376, -3.7929452450428247`], 
                Complex[57.42467143215045, -27.16706338916731]}, 2 -> {
                Complex[60.22649834088111, 0.7085754629936015], 
                Complex[84.80427009410889, -20.04321522376426]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.9672501320875426`, -1.5037017073917376`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.76289180887989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.636225096332794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.145697563752844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.06170845491359`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245878`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A1", 
             Association[1 -> {
                Complex[36.76289180887989, -3.7926075913306474`], 
                Complex[57.636225096332794`, -27.145697563752844`]}, 2 -> {
                Complex[60.06170845491359, 0.7260485931492001], 
                Complex[84.61469983200216, -20.028413405245878`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.8354408865584446`, -1.477892482258861}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.94594103200389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7932247904164975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.84952222428347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.125369473683783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.89552095643557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7442812915903373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.012832972269205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A1", 
             Association[1 -> {
                Complex[36.94594103200389, -3.7932247904164975`], 
                Complex[57.84952222428347, -27.125369473683783`]}, 2 -> {
                Complex[59.89552095643557, 0.7442812915903373], 
                Complex[84.42334068029797, -20.012832972269205`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.7056303067808116`, -1.4519706910786851`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.13036310076835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794845281279751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.106132322164278`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.72787145927004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7633252191523081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "A1", 
             Association[1 -> {
                Complex[37.13036310076835, -3.794845281279751], 
                Complex[58.06464268186045, -27.106132322164278`]}, 2 -> {
                Complex[59.72787145927004, 0.7633252191523081], 
                Complex[84.2301127622816, -19.996417177281284`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.5778349342455513`, -1.4259256830803757`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.31622603461241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.797522375138974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.0880448469234`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.5586926350365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7832368362827162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.97910381148327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "A1", 
             Association[1 -> {
                Complex[37.31622603461241, -3.797522375138974], 
                Complex[58.28167022874946, -27.0880448469234]}, 2 -> {
                Complex[59.5586926350365, 0.7832368362827162], 
                Complex[84.03493231522438, -19.97910381148327]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.452072099382015, -1.3997461516050382`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.503600937288496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8013148143453006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.50069273578578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.38791406646194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8040779640432751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.960824550758474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A1", 
             Association[1 -> {
                Complex[37.503600937288496`, -3.8013148143453006`], 
                Complex[58.50069273578578, -27.07117197223767]}, 2 -> {
                Complex[59.38791406646194, 0.8040779640432751], 
                Complex[83.83771147270659, -19.960824550758474`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.3283599575578293`, -1.3734200690368468`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.692562137998024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.806287409159504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.72180240194932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.05558555368316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.21546210616129`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.941504208943837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A1", 
             Association[1 -> {
                Complex[37.692562137998024`, -3.806287409159504], 
                Complex[58.72180240194932, -27.05558555368316]}, 2 -> {
                Complex[59.21546210616129, 0.8259164229195795], 
                Complex[83.63835804728225, -19.941504208943837`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.2067175266326657`, -1.3469346139626257`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.88318732193246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.9450959659065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.04125974602169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8488267615895433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642382`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A1", 
             Association[1 -> {
                Complex[37.88318732193246, -3.812511764560067], 
                Complex[58.9450959659065, -27.04136523041568]}, 2 -> {
                Complex[59.04125974602169, 0.8488267615895433], 
                Complex[83.43677531861314, -19.921059883642382`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.08716472590838, -1.3202760894555912`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.07555764325092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.820067111231534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.170674904956044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.028599402293732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.86522650415762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8728910898028908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A1", 
             Association[1 -> {
                Complex[38.07555764325092, -3.820067111231534], 
                Complex[59.170674904956044`, -27.028599402293732`]}, 2 -> {
                Complex[58.86522650415762, 0.8728910898028908], 
                Complex[83.23286183421266, -19.899399977259353`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.9697224162240374`, -1.293429831204353}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.26975781110342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.82904125718843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.68727833882761`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318297491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A1", 
             Association[1 -> {
                Complex[38.26975781110342, -3.82904125718843], 
                Complex[59.39864561154835, -27.017386352081296`]}, 2 -> {
                Complex[58.68727833882761, 0.8982000318297491], 
                Complex[83.02651123262952, -19.876423073022412`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.8544124408204894`, -1.2663801040064282`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.46587613610713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.839531679121346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.62911953396363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.50732760190553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9248538195678667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A1", 
             Association[1 -> {
                Complex[38.46587613610713, -3.839531679121346], 
                Complex[59.62911953396363, -27.007835536336128`]}, 2 -> {
                Complex[58.50732760190553, 0.9248538195678667], 
                Complex[82.81761210248663, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.7412576664319346`, -1.2391099849106713`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.66400452045292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8516467755142054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.32528304872727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9529635473601222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A1", 
             Association[1 -> {
                Complex[38.66400452045292, -3.8516467755142054`], 
                Complex[59.86221326295697, -27.000069072431693`]}, 2 -> {
                Complex[58.32528304872727, 0.9529635473601222], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.6302820238401239`, -1.2116012310240976`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.86423836923639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.99422345346926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.141049926719695`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.798400368820353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A1", 
             Association[1 -> {
                Complex[38.86423836923639, -3.865507306847949], 
                Complex[60.09804853982374, -26.99422345346926]}, 2 -> {
                Complex[58.141049926719695`, 0.9826526138400205], 
                Complex[82.39169691847611, -19.798400368820353`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.5215105468322534`, -1.1838341296895951`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.06667639323606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.336752152884166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.990451527552715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.954530172587724`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.01405837961428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "A1", 
             Association[1 -> {
                Complex[39.06667639323606, -3.8812480516973484`], 
                Complex[60.336752152884166`, -26.990451527552715`]}, 2 -> {
                Complex[57.954530172587724`, 1.01405837961428], 
                Complex[82.17443243593527, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.4149694081091937`, -1.1557873283926217`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.271420263643506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8990197110726985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.57845567815663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.988924782863712`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.76562275755487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0473340731366323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.9541229298446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A1", 
             Association[1 -> {
                Complex[39.271420263643506`, -3.8990197110726985`], 
                Complex[60.57845567815663, -26.988924782863712`]}, 2 -> {
                Complex[57.76562275755487, 1.0473340731366323`], 
                Complex[81.9541229298446, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.3106859501730952`, -1.1274376413669849`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.478574066455195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.91899109663922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869384`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.57422423294728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "A1", 
             Association[1 -> {
                Complex[39.478574066455195`, -3.91899109663922], 
                Complex[60.823295005096384`, -26.989835984869384`]}, 2 -> {
                Complex[57.57422423294728, 1.0826509804077706`], 
                Complex[81.73063257333023, -19.70361719945588]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.2086887085344244`, -1.098759829448257}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.68824348743652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9413516409076177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.380229545210106`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1202009565970128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "A1", 
             Association[1 -> {
                Complex[39.68824348743652, -3.9413516409076177`], 
                Complex[61.071409568577636`, -26.993402216234124`]}, 2 -> {
                Complex[57.380229545210106`, 1.1202009565970128`], 
                Complex[81.50382199854218, -19.66742872877372]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.1090074236716987`, -1.0697263492830587`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.900534636598906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.966314268200562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.183533211415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1601992983922518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A1", 
             Association[1 -> {
                Complex[39.900534636598906`, -3.966314268200562], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[57.183533211415, 1.1601992983922518`], 
                Complex[81.27354946300127, -19.628553141047497`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.0116730369831757`, -1.04030706757022}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.11555239258457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9941186626524052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.98403097486453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2028880133377449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A1", 
             Association[1 -> {
                Complex[40.11555239258457, -3.9941186626524052`], 
                Complex[61.57803233510409, -27.009511166504147`]}, 2 -> {
                Complex[56.98403097486453, 1.2028880133377449`], 
                Complex[81.03967255327478, -19.586711092540675`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.9167176644059509, -1.0104689356365544`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.33339811059796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.02264368536371`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.78162209715333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.248539514221569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.54158691366652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A1", 
             Association[1 -> {
                Complex[40.33339811059796, -4.025034961302564], 
                Complex[61.836823766448205`, -27.02264368536371]}, 2 -> {
                Complex[56.78162209715333, 1.248539514221569], 
                Complex[80.80205060892806, -19.54158691366652]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.82417453933855, -0.9801756194190041}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.554166490864645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.059367882777878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.57621248970557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.297460749010085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653356`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A1", 
             Association[1 -> {
                Complex[40.554166490864645`, -4.059367882777878], 
                Complex[62.09945108280152, -27.039620531417192`]}, 2 -> {
                Complex[56.57621248970557, 1.297460749010085], 
                Complex[80.56054810632892, -19.492823467653356`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.7340779138702729, -0.9493870799732953}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.77794134659001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.097461269474217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.060843538677656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.3677189458158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3499977442410382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.3150393131322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A1", 
             Association[1 -> {
                Complex[40.77794134659001, -4.097461269474217], 
                Complex[62.36604010279412, -27.060843538677656`]}, 2 -> {
                Complex[56.3677189458158, 1.3499977442410382`], 
                Complex[80.3150393131322, -19.440016432485955`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.6464629039577261, -0.9180591001727549}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.004789940578746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.139702965144389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.15607480403263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.4065404837842264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A1", 
             Association[1 -> {
                Complex[41.004789940578746`, -4.139702965144389], 
                Complex[62.63670053402378, -27.086768000239154`]}, 2 -> {
                Complex[56.15607480403263, 1.4065404837842264`], 
                Complex[80.06541461134336, -19.382708072431345`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.5613652599694205, -0.8861427546325906}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.23475547996004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.911517481754075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.941237453438774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A1", 
             Association[1 -> {
                Complex[41.23475547996004, -4.186529858286214], 
                Complex[62.911517481754075`, -27.117909237707966`]}, 2 -> {
                Complex[55.941237453438774`, 1.4675279533647856`], 
                Complex[79.81158898845908, -19.320380667492593`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.478821038865469, -0.8535838225878223}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.46784727560741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.238432778015862`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.1548491808301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.72319817424016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.5334530375357749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A1", 
             Association[1 -> {
                Complex[41.46784727560741, -4.238432778015862], 
                Complex[63.19054018060197, -27.1548491808301]}, 2 -> {
                Complex[55.72319817424016, 1.5334530375357749`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.3988661482299847, -0.8203221481835214}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.704028002661694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.295960711667079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.473767240011654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.198242373560767`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.50199487725362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6048667383421007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.1782590109987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "A1", 
             Association[1 -> {
                Complex[41.704028002661694`, -4.295960711667079], 
                Complex[63.473767240011654`, -27.198242373560767`]}, 2 -> {
                Complex[55.50199487725362, 1.6048667383421007`], 
                Complex[79.29118905201918, -19.1782590109987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.3215357257380731, -0.7862909603813755}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.94319747255841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.27772833189304`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6823808689752453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.09707399537825`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "A1", 
             Association[1 -> {
                Complex[41.94319747255841, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[55.27772833189304, 1.6823808689752453`], 
                Complex[79.02468735041018, -19.09707399537825]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.246863311209637, -0.7514161767054528}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.185172401572416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.430391708841174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.307393608507066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.05058239764025`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.7666679393393379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A1", 
             Association[1 -> {
                Complex[42.185172401572416`, -4.430391708841174], 
                Complex[64.05245675580908, -27.307393608507066`]}, 2 -> {
                Complex[55.05058239764025, 1.7666679393393379`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.17487976381707426`, -0.7156157327657127}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.42966192828803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.8208485065926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.8584563892632036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A1", 
             Association[1 -> {
                Complex[42.42966192828803, -4.508691887180884], 
                Complex[64.34746700294596, -27.374846901442822`]}, 2 -> {
                Complex[54.8208485065926, 1.8584563892632036`], 
                Complex[78.47993347130917, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.1056118771944341, -0.6787990041552856}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.67623922739711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.452128400549633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.588954049684325`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A1", 
             Association[1 -> {
                Complex[42.67623922739711, -4.595394633635153], 
                Complex[64.64571326583466, -27.452128400549633`]}, 2 -> {
                Complex[54.588954049684325`, 1.9585186817545792`], 
                Complex[78.20241421183864, -18.803067851298525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.03908065481800804, -0.6408664191814282}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.92431065706729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.94655461858153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.540225454037717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.35549322933975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0676491823619387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.92225618346788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "A1", 
             Association[1 -> {
                Complex[42.92431065706729, -4.691292487824447], 
                Complex[64.94655461858153, -27.540225454037717`]}, 2 -> {
                Complex[54.35549322933975, 2.0676491823619387`], 
                Complex[77.92225618346788, -18.685105090665765`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-32.3781388235867, -5.6083497605809285`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.3612762881997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.5464629745106`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"137.47401768359734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11658019540031624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "B1", 
             Association[1 -> {
                Complex[67.3612762881997, -11.285995288896373`], 
                Complex[31.494082066597223`, -37.5464629745106]}, 2 -> {
                Complex[137.47401768359734`, 0.11658019540031624`], 
                Complex[108.70582923184112`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-31.98242464347506, -5.544753414820963}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.98212126063683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.816178584119356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.1076636814205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249047`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"136.7702066530049`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026251`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "B1", 
             Association[1 -> {
                Complex[67.98212126063683, -10.816178584119356`], 
                Complex[32.1076636814205, -37.05300319249047]}, 2 -> {
                Complex[136.7702066530049, 0.11776334712026251`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-31.593514579703278`, -5.4835218503726075`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.50122981057176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.443606571400164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.620466904032156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65624121214431`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"136.20148283857358`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1190530706148839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537304`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "B1", 
             Association[1 -> {
                Complex[68.50122981057176, -10.443606571400164`], 
                Complex[32.620466904032156`, -36.65624121214431]}, 2 -> {
                Complex[136.20148283857358`, 0.1190530706148839], 
                Complex[107.41258000537304`, -20.41001952735827]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-31.210381614044888`, -5.424231223056562}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.96054019847772`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.128345372417398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.0743064173448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"135.71136793755323`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12040941356394556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "B1", 
             Association[1 -> {
                Complex[68.96054019847772, -10.128345372417398`], 
                Complex[33.0743064173448, -36.31637452115125]}, 2 -> {
                Complex[135.71136793755323`, 0.12040941356394556`], 
                Complex[106.91207211908184`, -20.409835465464514`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.83237839982309, -5.366612211666439}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.37917358758223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.852138089238327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.488222621388495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.01523037051931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"135.27419798999998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12181511399306597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409608726332795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "B1", 
             Association[1 -> {
                Complex[69.37917358758223, -9.852138089238327], 
                Complex[33.488222621388495`, -36.01523037051931]}, 2 -> {
                Complex[135.27419798999998`, 0.12181511399306597`], 
                Complex[106.46447895532776`, -20.409608726332795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.45904826106597, -5.31047345175115}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.7677684119681`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.60480138795413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.8727949448934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.742685486955864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.87574187250723`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1232611038398544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.0555664397038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.409348870362297`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "B1", 
             Association[1 -> {
                Complex[69.7677684119681, -9.60480138795413], 
                Complex[33.8727949448934, -35.742685486955864`]}, 2 -> {
                Complex[134.87574187250723`, 0.1232611038398544], 
                Complex[106.0555664397038, -20.409348870362297`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-30.0900466438168, -5.2556696202976205`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.13297133776604`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.379958105911218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804005`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.50713843332574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12474207031864686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "B1", 
             Association[1 -> {
                Complex[70.13297133776604, -9.379958105911218], 
                Complex[34.23462400814147, -35.492408387804005`]}, 2 -> {
                Complex[134.50713843332574`, 0.12474207031864686`], 
                Complex[105.67647115587604`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.72510161719988, -5.20208534035741}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.47926711840675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173296252888404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.26012331221573`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"134.16242958313848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12625468557684477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.3212331801606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.408750516874488`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "B1", 
             Association[1 -> {
                Complex[70.47926711840675, -9.173296252888404], 
                Complex[34.57815702977672, -35.26012331221573]}, 2 -> {
                Complex[134.16242958313848`, 0.12625468557684477`], 
                Complex[105.3212331801606, -20.408750516874488`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.363991503529203`, -5.1496260394142706`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.80985312948171`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.981735864879765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.90655982800721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.042779894876595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.83738284456678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12779677775874873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841773`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612203`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "B1", 
             Association[1 -> {
                Complex[70.80985312948171, -8.981735864879765], 
                Complex[34.90655982800721, -35.042779894876595`]}, 2 -> {
                Complex[133.83738284456678`, 0.12779677775874873`], 
                Complex[104.98561848841773`, -20.40841808612203]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-29.00653112054803, -5.098212311086311}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.12710553582465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.802984319586114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83811023326065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.5288645170866`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1293668978816943`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468589`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408065972061255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "B1", 
             Association[1 -> {
                Complex[71.12710553582465, -8.802984319586114], 
                Complex[35.22218142009308, -34.83811023326065]}, 2 -> {
                Complex[133.5288645170866, 0.1293668978816943], 
                Complex[104.66649203468589`, -20.408065972061255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-28.652562788603827`, -5.047776219088847}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.432848487697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.63527920845076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.526822187325095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.64437291632376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"133.2344781534338`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1309640745970842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205709`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "B1", 
             Association[1 -> {
                Complex[71.432848487697, -8.63527920845076], 
                Complex[35.526822187325095`, -34.64437291632376]}, 2 -> {
                Complex[133.2344781534338, 0.1309640745970842], 
                Complex[104.36145617205709`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-28.301950169318612`, -4.998258757692817}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.72851942980324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.477230229980366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.95234282886776`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13258766651159287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147277`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "B1", 
             Association[1 -> {
                Complex[71.72851942980324, -8.477230229980366], 
                Complex[35.82189847272132, -34.46019571836113]}, 2 -> {
                Complex[132.95234282886776`, 0.13258766651159287`], 
                Complex[104.06862888444634`, -20.407307041147277`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.9545738829575, -4.949608040143076}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.01527569469468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.327717105231118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.10854866480779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.2844740897253`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.68095034258096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1342372688175216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797385`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "B1", 
             Association[1 -> {
                Complex[72.01527569469468, -8.327717105231118], 
                Complex[36.10854866480779, -34.2844740897253]}, 2 -> {
                Complex[132.68095034258096`, 0.1342372688175216], 
                Complex[103.78650096169163`, -20.406901625797385`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.610328294068257`, -4.901777966177439}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.29406602519018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.185820989619934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.11630299481564`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.41906952024033`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13591265188070087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338054`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "B1", 
             Association[1 -> {
                Complex[72.29406602519018, -8.185820989619934], 
                Complex[36.38770434340436, -34.11630299481564]}, 2 -> {
                Complex[132.41906952024033`, 0.13591265188070087`], 
                Complex[103.51384028303795`, -20.406479492338054`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-27.269119093066667`, -4.85472721661915}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.56568017864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.66013959822463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.95492960334115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"132.1656799251484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951338863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "B1", 
             Association[1 -> {
                Complex[72.56568017864, -8.050776840303698], 
                Complex[36.66013959822463, -33.95492960334115]}, 2 -> {
                Complex[132.1656799251484, 0.13761371951338863`], 
                Complex[103.24962551411933`, -20.406040889030567`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.9308614369727, -4.808418478203722}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.83078430520496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.921939398858431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.92650618566856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.79971952448827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.91992463906843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1393404798424747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "B1", 
             Association[1 -> {
                Complex[72.83078430520496, -7.921939398858431], 
                Complex[36.92650618566856, -33.79971952448827]}, 2 -> {
                Complex[131.91992463906843`, 0.1393404798424747], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.595478493312708`, -4.7628178347493595`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.08994679168227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.187359197641086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.65013212317826`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.6810758118074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "B1", 
             Association[1 -> {
                Complex[73.08994679168227, -7.798758308638223], 
                Complex[37.187359197641086`, -33.65013212317826]}, 2 -> {
                Complex[131.6810758118074, 0.14109302450360203`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-26.262900281307477`, -4.717894281233873}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34365753646222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.443176195934996`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.50570209730139`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.44850899973972`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14287151349532431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "B1", 
             Association[1 -> {
                Complex[73.34365753646222, -7.680759532183109], 
                Complex[37.443176195934996`, -33.50570209730139]}, 2 -> {
                Complex[131.44850899973972`, 0.14287151349532431`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.933062736592884`, -4.673619330473642}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.59234258892822`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.567531219181628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.69437173707493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.36602547590361`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.22168370076204`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1446761639763875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "B1", 
             Association[1 -> {
                Complex[73.59234258892822, -7.567531219181628], 
                Complex[37.69437173707493, -33.36602547590361]}, 2 -> {
                Complex[131.22168370076204`, 0.1446761639763875], 
                Complex[102.26185863012616`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.605906946921355`, -4.629966690777559}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.83637544801043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.4587127853605635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.230748805484254`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"131.000128350837`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187042746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982483`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "B1", 
             Association[1 -> {
                Complex[73.83637544801043, -7.4587127853605635`], 
                Complex[37.94130857631963, -33.230748805484254`]}, 2 -> {
                Complex[131.000128350837, 0.14650724187042746`], 
                Complex[102.02923912251606`, -20.403602844982483`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-25.281378520650545`, -4.586911998831905}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07608590770809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.353986351536106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.184306434253365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.099560678600085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.7834285934079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14836505550878115`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "B1", 
             Association[1 -> {
                Complex[74.07608590770809, -7.353986351536106], 
                Complex[38.184306434253365`, -33.099560678600085`]}, 2 -> {
                Complex[130.7834285934079, 0.14836505550878115`], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.95942705976169, -4.544432596150269}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.31176707129376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.253069946548107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.423648944426496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.97218501218886`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.57121798988905`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15024995077915002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "B1", 
             Association[1 -> {
                Complex[74.31176707129376, -7.253069946548107], 
                Complex[38.423648944426496`, -32.97218501218886]}, 2 -> {
                Complex[130.57121798988905`, 0.15024995077915002`], 
                Complex[101.57804924438946`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.640005716171903`, -4.502507340306927}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.54368097781067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.155712048248091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.65958922320312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.8483756525743`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.36317057816737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1521623074051051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "B1", 
             Association[1 -> {
                Complex[74.54368097781067, -7.155712048248091], 
                Complex[38.65958922320312, -32.8483756525743]}, 2 -> {
                Complex[130.36317057816737`, 0.1521623074051051], 
                Complex[101.35878495705762`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.32307081515084, -4.461116444247727}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.7720631627776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061687153265096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.89235438185443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"130.15899484907538`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15410253608764451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "B1", 
             Association[1 -> {
                Complex[74.7720631627776, -7.061687153265096], 
                Complex[38.89235438185443, -32.727912000016886`]}, 2 -> {
                Complex[130.15899484907538`, 0.15410253608764451`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-24.008581533342333`, -4.420241338492918}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.9971263902912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.12214921663343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.610595426395236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.9584288242154`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1560710763133156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506857`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40074513612678`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "B1", 
             Association[1 -> {
                Complex[74.9971263902912, -6.970792147471257], 
                Complex[39.12214921663343, -32.610595426395236`]}, 2 -> {
                Complex[129.9584288242154, 0.1560710763133156], 
                Complex[100.93145144506857`, -20.40074513612678]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.696499621622873`, -4.379864552173151}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.21906373372748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.34915925289308`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678464`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.76123599877187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15806839468480582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.72288222699729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40012051017151`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "B1", 
             Association[1 -> {
                Complex[75.21906373372748, -6.882843306606486], 
                Complex[39.34915925289308, -32.49624631678464]}, 2 -> {
                Complex[129.76123599877187`, 0.15806839468480582`], 
                Complex[100.72288222699729`, -20.40012051017151]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.386789165087617`, -4.339969609689053}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.43805113911235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.797673797918373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.57355327641459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.38470160682704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.56720197061549`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1600949836664983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "B1", 
             Association[1 -> {
                Complex[75.43805113911235, -6.797673797918373], 
                Complex[39.57355327641459, -32.38470160682704]}, 2 -> {
                Complex[129.56720197061549`, 0.1600949836664983], 
                Complex[100.51741711927747`, -20.399477392046546`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-23.0794163740135, -4.300540940430434}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.6542495737786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.795485453839746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.275812717792256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.37613161903013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16215136066387456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.31486023740956`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39881538805515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "B1", 
             Association[1 -> {
                Complex[75.6542495737786, -6.715131583883629], 
                Complex[39.795485453839746`, -32.275812717792256`]}, 2 -> {
                Complex[129.37613161903013`, 0.16215136066387456`], 
                Complex[100.31486023740956`, -20.39881538805515]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.774349400852525`, -4.261563799489229}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.86780683969536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.635077651408384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100969`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.18784672741097`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1642380673752916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398134080358393`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "B1", 
             Association[1 -> {
                Complex[75.86780683969536, -6.635077651408384], 
                Complex[40.01509712100969, -32.16944381340221]}, 2 -> {
                Complex[129.18784672741097`, 0.1642380673752916], 
                Complex[100.11503259520978`, -20.398134080358393`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.47155817924212, -4.223024197686884}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.07885911349071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.5573845066078915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075458`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.0654703190693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.0021839674614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936822443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789097`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "B1", 
             Association[1 -> {
                Complex[76.07885911349071, -6.5573845066078915`], 
                Complex[40.23251830075458, -32.0654703190693]}, 2 -> {
                Complex[129.0021839674614, 0.16635566936822443`], 
                Complex[99.91777008789097, -20.397433027529168`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-22.17101428175108, -4.18490883954134}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.28753226206464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.481934887900402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.44786899864124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.963777656737037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.81899317991187`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16850475584425478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.7229217717481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "B1", 
             Association[1 -> {
                Complex[76.28753226206464, -6.481934887900402], 
                Complex[40.44786899864124, -31.963777656737037`]}, 2 -> {
                Complex[128.81899317991187`, 0.16850475584425478`], 
                Complex[99.7229217717481, -20.39671176490144]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.872690793659277`, -4.147205068039286}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.49394297267101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.408620659800467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.66126031523404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.864260158083287`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.63813590014166`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17068593956353967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "B1", 
             Association[1 -> {
                Complex[76.49394297267101, -6.408620659800467], 
                Complex[40.66126031523404, -31.864260158083287`]}, 2 -> {
                Complex[128.63813590014166`, 0.17068593956353967`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.576562200531374`, -4.109900815271832}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.69819972862496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243102`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575693`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.766820126231003`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.45948408736626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17289985690709622`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "B1", 
             Association[1 -> {
                Complex[76.69819972862496, -6.337341857243102], 
                Complex[40.87279540575693, -31.766820126231003`]}, 2 -> {
                Complex[128.45948408736626`, 0.17289985690709622`], 
                Complex[99.33992109514007, -20.39520663629768]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-21.28260428771841, -4.072984558147098}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.90040365578946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060299`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.082570312084634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.67136702185057`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.28291902404564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17514716805938169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.394421725649263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "B1", 
             Association[1 -> {
                Complex[76.90040365578946, -6.268005856060299], 
                Complex[41.082570312084634`, -31.67136702185057]}, 2 -> {
                Complex[128.28291902404564`, 0.17514716805938169`], 
                Complex[99.15152035933144, -20.394421725649263`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.9907940502184, -4.036445278518176}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.10064926028727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.57781675404458`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.10833035842901`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17742855729767137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.96503500426881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.393614515533017`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "B1", 
             Association[1 -> {
                Complex[77.10064926028727, -6.20052664977852], 
                Complex[41.290674687319935`, -31.57781675404458]}, 2 -> {
                Complex[128.10833035842901`, 0.17742855729767137`], 
                Complex[98.96503500426881, -20.393614515533017`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.70110961157607, -4.0002724271675945`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.29902507416718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.1348242164964875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.4971924295248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.486091059962416`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.93561526809535`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1797447333776459`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "B1", 
             Association[1 -> {
                Complex[77.29902507416718, -6.1348242164964875`], 
                Complex[41.4971924295248, -31.486091059962416`]}, 2 -> {
                Complex[127.93561526809535`, 0.1797447333776459], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.41353015070067, -3.9644558911738836`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.49561422279432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.070823962465016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.7022022382381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.396116959927443`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.76467772627852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18209643000701933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39193084897724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "B1", 
             Association[1 -> {
                Complex[77.49561422279432, -6.070823962465016], 
                Complex[41.7022022382381, -31.396116959927443`]}, 2 -> {
                Complex[127.76467772627852`, 0.18209643000701933`], 
                Complex[98.59740257849909, -20.39193084897724]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-20.12803583564821, -3.9289859642549305`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.69049492536396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.008456231284885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713039`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.59542785591412`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18448440640095512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39105315780623`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "B1", 
             Association[1 -> {
                Complex[77.69049492536396, -6.008456231284885], 
                Complex[41.905778105062396`, -31.30782627713039]}, 2 -> {
                Complex[127.59542785591412`, 0.18448440640095512`], 
                Complex[98.41606788851908, -20.39105315780623]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.84460776355049, -3.8938533197408307`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.88374093802699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.947655869489128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.42778135888064`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1869094479145506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "B1", 
             Association[1 -> {
                Complex[77.88374093802699, -5.947655869489128], 
                Complex[42.10798974770688, -31.221155212774143`]}, 2 -> {
                Complex[127.42778135888064`, 0.1869094479145506], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.563227905990704`, -3.859048985877203}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.07542194756493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.888361840780238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533777`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043033`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.26165900996357`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18937236674901994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.389222784622216`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "B1", 
             Association[1 -> {
                Complex[78.07542194756493, -5.888361840780238], 
                Complex[42.30890299533777, -31.136043969043033`]}, 2 -> {
                Complex[127.26165900996357`, 0.18937236674901994`], 
                Complex[98.05793516060473, -20.389222784622216`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.283879059218602`, -3.824564323199876}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.26560392228748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.83051688241914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482678`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.09698620674699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1918740027291996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "B1", 
             Association[1 -> {
                Complex[78.26560392228748, -5.83051688241914], 
                Complex[42.50858013183329, -31.052436413482678`]}, 2 -> {
                Complex[127.09698620674699`, 0.1918740027291996], 
                Complex[97.88098148963749, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-19.006544798681947`, -3.7903910037569815`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.45434942578764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7740671982708545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251326`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.97027977937305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.93369256801181`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19441522415101703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "B1", 
             Association[1 -> {
                Complex[78.45434942578764, -5.7740671982708545`], 
                Complex[42.70708020251326, -30.97027977937305]}, 2 -> {
                Complex[126.93369256801181`, 0.19441522415101703`], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.731209437418304`, -3.7565209919821068`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.64171789833449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.718962183842703`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.904459289065734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.88952439749861`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.77171157435116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19699692869821914`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "B1", 
             Association[1 -> {
                Complex[78.64171789833449, -5.718962183842703], 
                Complex[42.904459289065734`, -30.88952439749861]}, 2 -> {
                Complex[126.77171157435116`, 0.19699692869821914`], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.457857987908934`, -3.722946527048124}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.82776590997473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.665154179340725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.1007707566919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.61098024565148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.19962004442848083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163757`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38524206428723`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "B1", 
             Association[1 -> {
                Complex[78.82776590997473, -5.665154179340725], 
                Complex[43.1007707566919, -30.810123455401037`]}, 2 -> {
                Complex[126.61098024565148`, 0.19962004442848083`], 
                Complex[97.35772603163757, -20.38524206428723]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-18.186476127047957`, -3.689660106550727}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.01254738882457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.612598247344149`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.296065476907174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.732032780766865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.45143885086726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20228553082947306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.18562929385388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "B1", 
             Association[1 -> {
                Complex[79.01254738882457, -5.612598247344149], 
                Complex[43.296065476907174`, -30.732032780766865`]}, 2 -> {
                Complex[126.45143885086726`, 0.20228553082947306`], 
                Complex[97.18562929385388, -20.38417572502943]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.917050163920546`, -3.656654471390041}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.19611382753952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.49039202894673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.65521064607696`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.29303064616852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2049943799461619`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "B1", 
             Association[1 -> {
                Complex[79.19611382753952, -5.561251972178114], 
                Complex[43.49039202894673, -30.65521064607696]}, 2 -> {
                Complex[126.29303064616852`, 0.2049943799461619], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.649567010122095`, -3.6239225917334585`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.37851447053697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.5110752784691845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.68379688231679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.5796175920435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.13570163808673`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20774761758097904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.381951782413044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "B1", 
             Association[1 -> {
                Complex[79.37851447053697, -5.5110752784691845`], 
                Complex[43.68379688231679, -30.5796175920435]}, 2 -> {
                Complex[126.13570163808673`, 0.20774761758097904`], 
                Complex[96.84456714160432, -20.381951782413044`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.384014152380896`, -3.591457653956146}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.55979648419662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4620302667087515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.505216267696298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.9794003687457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117392`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "B1", 
             Association[1 -> {
                Complex[79.55979648419662, -5.4620302667087515`], 
                Complex[43.87632456268657, -30.505216267696298`]}, 2 -> {
                Complex[125.9794003687457, 0.2105463045690835], 
                Complex[96.6754942074181, -20.38079237117392]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-17.120379627274243`, -3.5592530484673737`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.74000511196857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.41408106393778`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302349`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.43197128526467`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.82407772065201`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21339153813131853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37960007011897`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "B1", 
             Association[1 -> {
                Complex[79.74000511196857, -5.41408106393778], 
                Complex[44.06801780302349, -30.43197128526467]}, 2 -> {
                Complex[125.82407772065201`, 0.21339153813131853`], 
                Complex[96.50732568207661, -20.37960007011897]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.858651997852075`, -3.527302358340991}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.91918381606891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.367193687912338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.258917681628574`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.359849088243717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.66968673885063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21628445330793863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.34001352004081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37837388627006`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "B1", 
             Association[1 -> {
                Complex[79.91918381606891, -5.367193687912338], 
                Complex[44.258917681628574`, -30.359849088243717`]}, 2 -> {
                Complex[125.66968673885063`, 0.21628445330793863`], 
                Complex[96.34001352004081, -20.37837388627006]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.598820332002273`, -3.4955993486766395`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.09737440722895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321335923317816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.51618246853248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2192262244765668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "B1", 
             Association[1 -> {
                Complex[80.09737440722895, -5.321335923317816], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[125.51618246853248`, 0.2192262244765668], 
                Complex[96.17351165179058, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.34087418241044, -3.464137956626366}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.27461716378079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360477`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.36352180642044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2222180669583733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "B1", 
             Association[1 -> {
                Complex[80.27461716378079, -5.276477208780441], 
                Complex[44.63849414140558, -30.218847270360477`]}, 2 -> {
                Complex[125.36352180642044`, 0.2222180669583733], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-16.084803567981847`, -3.43291228202783}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.45095094120657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.232588533576675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.149908663093328`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.21166336446669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22526123871674955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "B1", 
             Association[1 -> {
                Complex[80.45095094120657, -5.232588533576675], 
                Complex[44.82724569242561, -30.149908663093328`]}, 2 -> {
                Complex[125.21166336446669`, 0.22526123871674955`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.830598956607995`, -3.401916578590727}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.62641327314368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.015354026525884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.08197467668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.0605673445708`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22835704215337221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37310908834082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "B1", 
             Association[1 -> {
                Complex[80.62641327314368, -5.189642343075517], 
                Complex[45.015354026525884`, -30.08197467668967]}, 2 -> {
                Complex[125.0605673445708, 0.22835704215337221`], 
                Complex[95.67843369946033, -20.37310908834082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.578251249172562`, -3.3711452455890956`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.80104046472162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.14761245206253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.01501930425797`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.91019542318102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23150682600686542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.371697196609304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "B1", 
             Association[1 -> {
                Complex[80.80104046472162, -5.14761245206253], 
                Complex[45.20285365244137, -30.01501930425797]}, 2 -> {
                Complex[124.91019542318102`, 0.23150682600686542`], 
                Complex[95.51474684712201, -20.371697196609304`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.32775176470061, -3.3405928200158157`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.97486767900651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194039`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.38977804698447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.94901778780827`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.76051064477248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.23471198735986767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.37024459957686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "B1", 
             Association[1 -> {
                Complex[80.97486767900651, -5.106473965194039], 
                Complex[45.38977804698447, -29.94901778780827]}, 2 -> {
                Complex[124.76051064477248`, 0.23471198735986767`], 
                Complex[95.35166475158147, -20.37024459957686]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-15.079092226567193`, -3.3102539691598643`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.14792901724158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916091`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.61147732331085`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2379739737607506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704521`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36874999840365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "B1", 
             Association[1 -> {
                Complex[81.14792901724158, -5.066203203916091], 
                Complex[45.57615973333942, -29.88394654760416]}, 2 -> {
                Complex[124.61147732331085`, 0.2379739737607506], 
                Complex[95.18915044704521, -20.36874999840365]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.832264749687718`, -3.2801234835709834`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.32025759349672`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.8197831172457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.4630609509089`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546681905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.367212042296025`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "B1", 
             Association[1 -> {
                Complex[81.32025759349672, -5.026777639259071], 
                Complex[45.76203035396384, -29.8197831172457]}, 2 -> {
                Complex[124.4630609509089, 0.24129428546681905`], 
                Complex[95.02716811464279, -20.367212042296025`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.58726182862099, -3.250196270378449}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.49188560427382`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.988175829983487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.31522811297008`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.24467447781636753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3656293260625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "B1", 
             Association[1 -> {
                Complex[81.49188560427382, -4.988175829983487], 
                Complex[45.94742073863617, -29.756506083970756`]}, 2 -> {
                Complex[124.31522811297008`, 0.24467447781636753`], 
                Complex[94.86568299639735, -20.3656293260625]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.344076326522506`, -3.2204673469347074`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.66284439355744`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.950377365611486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.13236096813215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.16794640918864`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.24811616373761602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523568`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "B1", 
             Association[1 -> {
                Complex[81.66284439355744, -4.950377365611486], 
                Complex[46.13236096813215, -29.694095033720544`]}, 2 -> {
                Complex[124.16794640918864`, 0.24811616373761602`], 
                Complex[94.70466131500457, -20.364000387523568`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-14.10270146489176, -3.190931834755815}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.83316451374981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9133628139288374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.316880433963114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.63253050056463`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.02118437984169`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2516210164031831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "B1", 
             Association[1 -> {
                Complex[81.83316451374981, -4.9133628139288374`], 
                Complex[46.316880433963114`, -29.63253050056463]}, 2 -> {
                Complex[124.02118437984169`, 0.2516210164031831], 
                Complex[94.54407019885234, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.86313081406209, -3.1615849537338536`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.00287578288496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.877113672586954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.50100789456628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.571793920124346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.87491143686638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25519077203948826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.38387761177131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "B1", 
             Association[1 -> {
                Complex[82.00287578288496, -4.877113672586954], 
                Complex[46.50100789456628, -29.571793920124346`]}, 2 -> {
                Complex[123.87491143686638`, 0.25519077203948826`], 
                Complex[94.38387761177131, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.625358284387511`, -3.1324220165978107`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.17200733847808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.84161232447478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.51186758667359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.72909779926668`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25882723290117593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623653`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "B1", 
             Association[1 -> {
                Complex[82.17200733847808, -4.84161232447478], 
                Complex[46.684771528299024`, -29.51186758667359]}, 2 -> {
                Complex[123.72909779926668`, 0.25882723290117593`], 
                Complex[94.22405228705699, -20.358820702623653`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.389378118084204`, -3.103438423601325}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.34058768833268`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.868198983556454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.452734613629488`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.58371443243793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2625322704216669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "B1", 
             Association[1 -> {
                Complex[82.34058768833268, -4.806841996564815], 
                Complex[46.868198983556454`, -29.452734613629488`]}, 2 -> {
                Complex[123.58371443243793`, 0.2625322704216669], 
                Complex[94.06456366534843, -20.35699101364115]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-13.155184881689289`, -3.0746296574173484`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.50864475859716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.772786721969363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177013`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.43873299103726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2663078285515105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486673`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "B1", 
             Association[1 -> {
                Complex[82.50864475859716, -4.772786721969363], 
                Complex[47.051317426301225`, -29.394378897177013`]}, 2 -> {
                Complex[123.43873299103726`, 0.2663078285515105], 
                Complex[93.90538183598731, -20.355106834486673`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.922773459103121`, -3.0459912782206273`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.67620593933668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7394313049710854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.23415358526995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.336785082799004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.29412576506266`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27015592729763804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "B1", 
             Association[1 -> {
                Complex[82.67620593933668, -4.7394313049710854`], 
                Complex[47.23415358526995, -29.336785082799004`]}, 2 -> {
                Complex[123.29412576506266`, 0.27015592729763804`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.692139045182836`, -3.01751891894127}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.84329812786348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7067612888163355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507018`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.14986562883324`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2740786664771618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35116745361845`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "B1", 
             Association[1 -> {
                Complex[82.84329812786348, -4.7067612888163355`], 
                Complex[47.41673379509784, -29.279938534507018`]}, 2 -> {
                Complex[123.14986562883324`, 0.2740786664771618], 
                Complex[93.58782182500669, -20.35116745361845]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.463277139861171`, -2.989208280671853}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.0099477700464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.674762926083101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.5990840375824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.223825306591696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.00592599259153`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27807822970104984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34910827142565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "B1", 
             Association[1 -> {
                Complex[83.0099477700464, -4.674762926083101], 
                Complex[47.5990840375824, -29.223825306591696`]}, 2 -> {
                Complex[123.00592599259153`, 0.27807822970104984`], 
                Complex[93.42938657992538, -20.34910827142565]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.236183542763891`, -2.9610551282135975`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.17618089980478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.643423151455099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.7812299812911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.168432117730696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.86228075647094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.28215688860378724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.2711439022902`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "B1", 
             Association[1 -> {
                Complex[83.17618089980478, -4.643423151455099], 
                Complex[47.7812299812911, -29.168432117730696`]}, 2 -> {
                Complex[122.86228075647094`, 0.28215688860378724`], 
                Complex[93.2711439022902, -20.34698662948813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-12.010854348304301`, -2.9330552857459824`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.34202317697387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.11374632731038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.71890426659377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2863170073368831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "B1", 
             Association[1 -> {
                Complex[83.34202317697387, -4.612729556752136], 
                Complex[47.96319701970125, -29.11374632731038]}, 2 -> {
                Complex[122.71890426659377`, 0.2863170073368831], 
                Complex[93.11306634486284, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.787285941233486`, -2.9052046326064054`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.50749992371578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.582670368083347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.5757712730832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34254700963612`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "B1", 
             Association[1 -> {
                Complex[83.50749992371578, -4.582670368083347], 
                Complex[48.14501030804773, -29.059755913834174`]}, 2 -> {
                Complex[122.5757712730832, 0.2905610473453315], 
                Complex[92.95512681316394, -20.34254700963612]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.565474992629115`, -2.8774990991662537`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.67263615963778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.553234425005796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.32669479904236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.006449455305912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.43285688978916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.294891572447947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "B1", 
             Association[1 -> {
                Complex[83.67263615963778, -4.553234425005796], 
                Complex[48.32669479904236, -29.006449455305912`]}, 2 -> {
                Complex[122.43285688978916`, 0.294891572447947], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.345418456306087`, -2.849934662790115}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"83.83745663576826`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.524411161584033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.95381611148981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.29013655554255`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2993112542442012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "B1", 
             Association[1 -> {
                Complex[83.83745663576826, -4.524411161584033], 
                Complex[48.50827527761827, -28.95381611148981]}, 2 -> {
                Complex[122.29013655554255`, 0.2993112542442012], 
                Complex[92.63955496002484, -20.337829663202022`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-11.12711356563481, -2.8225073438663926`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.00198586753189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.689776394844124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.901845607962525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.14758599676475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3038228778721799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "B1", 
             Association[1 -> {
                Complex[84.00198586753189, -4.496190589260192], 
                Complex[48.689776394844124`, -28.901845607962525`]}, 2 -> {
                Complex[122.14758599676475`, 0.3038228778721799], 
                Complex[92.48186983901313, -20.33536045179569]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.910557830754565`, -2.795213201896295}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.16624816685666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.468563281455603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.87122270114558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.85052822188417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.00518119127094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3084293481445214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33281390326847`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "B1", 
             Association[1 -> {
                Complex[84.16624816685666, -4.468563281455603], 
                Complex[48.87122270114558, -28.85052822188417]}, 2 -> {
                Complex[122.00518119127094`, 0.3084293481445214], 
                Complex[92.32421706624812, -20.33281390326847]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.695749036171003`, -2.768048331630007}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.3302676735389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.441520359836423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.799854769426958`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.86289833311504`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31313369609146713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129295`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.330187124209285`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "B1", 
             Association[1 -> {
                Complex[84.3302676735389, -4.441520359836423], 
                Complex[49.05263867896425, -28.799854769426958`]}, 2 -> {
                Complex[121.86289833311504`, 0.31313369609146713`], 
                Complex[92.16657070129295, -20.330187124209285`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.482685238728374`, -2.741008859237739}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.49406838598571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.234048774980316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.74981659481079`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.7207137983327`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31793908594289033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651896`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "B1", 
             Association[1 -> {
                Complex[84.49406838598571, -4.4150534821866065`], 
                Complex[49.234048774980316`, -28.74981659481079]}, 2 -> {
                Complex[121.7207137983327, 0.31793908594289033`], 
                Complex[92.00890492013562, -20.327477084651896`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.271364765948443`, -2.7140909385046466`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.65767419144984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.389154831841693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905757`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.57860411144645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3228488225839969`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.8511939788492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.32468061012449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "B1", 
             Association[1 -> {
                Complex[84.65767419144984, -4.389154831841693], 
                Complex[49.41547743201962, -28.700405560905757`]}, 2 -> {
                Complex[121.57860411144645`, 0.3228488225839969], 
                Complex[91.8511939788492, -20.32468061012449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-10.061786214729674`, -2.6872907470373}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.82110889586633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.363817108646427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.59694912076191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.651614041371154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.43654591260237`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32786635952260024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.32179437313911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "B1", 
             Association[1 -> {
                Complex[84.82110889586633, -4.363817108646427], 
                Complex[49.59694912076191, -28.651614041371154`]}, 2 -> {
                Complex[121.43654591260237`, 0.32786635952260024`], 
                Complex[91.6934121777283, -20.32179437313911]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.853948450401484, -2.6606044824707555`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"84.98439625339881`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.339033521409435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.603434914311087`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.29451592521413`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.33299530740941635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "B1", 
             Association[1 -> {
                Complex[84.98439625339881, -4.339033521409435], 
                Complex[49.77848837136714, -28.603434914311087`]}, 2 -> {
                Complex[121.29451592521413`, 0.33299530740941635`], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.64785060612932, -2.6340283586639752`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.14755999579832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.96011980513068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.55586155743547`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.1524909239935`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33823944315668386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "B1", 
             Association[1 -> {
                Complex[85.14755999579832, -4.314797781836454], 
                Complex[49.96011980513068, -28.55586155743547]}, 2 -> {
                Complex[121.1524909239935, 0.33823944315668386`], 
                Complex[91.37753320535234, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.44349208266872, -2.6075586018718826`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.31062386167716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.291104099934119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.14186816628128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.508887844726274`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.0104477032505`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31256132120175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "B1", 
             Association[1 -> {
                Complex[85.31062386167716, -4.291104099934119], 
                Complex[50.14186816628128, -28.508887844726274`]}, 2 -> {
                Complex[121.0104477032505, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.31256132120175]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.240872548465768, -2.5811914468819626`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.47361162579809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.267947180884556`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.32375835403241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.462508144617296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.86836304534869`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3490892764910097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "B1", 
             Association[1 -> {
                Complex[85.47361162579809, -4.267947180884556], 
                Complex[50.32375835403241, -28.462508144617296`]}, 2 -> {
                Complex[120.86836304534869`, 0.3490892764910097], 
                Complex[91.0610619442071, -20.30927936589565]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-9.039991940104949, -2.5549231331022972`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.63654712847851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.245322223400962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.505815454999635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.416717319706716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.72621368920332`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.35470345068097464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "B1", 
             Association[1 -> {
                Complex[85.63654712847851, -4.245322223400962], 
                Complex[50.505815454999635`, -28.416717319706716`]}, 2 -> {
                Complex[120.72621368920332`, 0.35470345068097464`], 
                Complex[90.90253941775816, -20.305888372154573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.840850463104738, -2.5287499005886267`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.7994543052095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.223224919584004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.68806477609714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.371510728031737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.58397629871097`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36044978922689364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.74379078021592`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "B1", 
             Association[1 -> {
                Complex[85.7994543052095, -4.223224919584004], 
                Complex[50.68806477609714, -28.371510728031737`]}, 2 -> {
                Complex[120.58397629871097`, 0.36044978922689364`], 
                Complex[90.74379078021592, -20.30238387787967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.643448593062994, -2.5026679859966143`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"85.96235721658975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.201651456308553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.870531878028714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.326884225945246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.44162743099962`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36633306182622866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29876118819338`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "B1", 
             Association[1 -> {
                Complex[85.96235721658975, -4.201651456308553], 
                Complex[50.870531878028714`, -28.326884225945246`]}, 2 -> {
                Complex[120.44162743099962`, 0.36633306182622866`], 
                Complex[90.58478964962532, -20.29876118819338]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.44778707715606, -2.4766736184450155`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.1252800786756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.1805985181808465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.282834172645913`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.29914350438833`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37235827485923007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "B1", 
             Association[1 -> {
                Complex[86.1252800786756, -4.1805985181808465`], 
                Complex[51.05324260949037, -28.282834172645913`]}, 2 -> {
                Complex[120.29914350438833`, 0.37235827485923007`], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.253866935996493, -2.4507630152750344`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.28824729385005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.160063292117321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.23622314220589`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.239357436425408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.15650076594429`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37853068639320436`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "B1", 
             Association[1 -> {
                Complex[86.28824729385005, -4.160063292117321], 
                Complex[51.23622314220589, -28.239357436425408`]}, 2 -> {
                Complex[120.15650076594429`, 0.37853068639320436`], 
                Complex[90.26592313793013, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-8.06168946585367, -2.424932377689998}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.45128348231654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.01367525852382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38485582234995075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.28713318083525`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "B1", 
             Association[1 -> {
                Complex[86.45128348231654, -4.140043473607491], 
                Complex[51.419500006920465`, -28.196451402708608`]}, 2 -> {
                Complex[120.01367525852382`, 0.38485582234995075`], 
                Complex[90.10600363628706, -20.28713318083525]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.871256241246764, -2.399177886258664}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.61441351432457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.60310013048105`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.8706427871813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3913394939430957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "B1", 
             Association[1 -> {
                Complex[86.61441351432457, -4.120537274736594], 
                Complex[51.60310013048105, -28.154113983977776`]}, 2 -> {
                Complex[119.8706427871813, 0.3913394939430957], 
                Complex[89.94572332307655, -20.282985551225522`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.682569117916595, -2.373495696264262}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.77766254324008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.1015434340563175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.72737888482756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.397987816503232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.78505422710688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "B1", 
             Association[1 -> {
                Complex[86.77766254324008, -4.1015434340563175`], 
                Complex[51.78705087413991, -28.112343631685352`]}, 2 -> {
                Complex[119.72737888482756`, 0.397987816503232], 
                Complex[89.78505422710688, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.495630236187077, -2.347881932880165}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"86.94105603957541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.083061228407528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322184`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.58385877701511`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4048072298215822`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.6239679392368`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "B1", 
             Association[1 -> {
                Complex[86.94105603957541, -4.083061228407528], 
                Complex[51.97138007322184, -28.071139350277974`]}, 2 -> {
                Complex[119.58385877701511`, 0.4048072298215822], 
                Complex[89.6239679392368, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.310442024727019, -2.322332686151824}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.10461982609941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.065090486814276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.44005734572406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4118045201569235`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26964207736714`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "B1", 
             Association[1 -> {
                Complex[87.10461982609941, -4.065090486814276], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[119.44005734572406`, 0.4118045201569235], 
                Complex[89.46243556940976, -20.26964207736714]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-7.1270072047253255`, -2.296844005762542}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.26838011415413`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.990427882936377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.29594909201677`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41898684406680814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "B1", 
             Association[1 -> {
                Complex[87.26838011415413, -4.047631606586542], 
                Complex[52.34128779806404, -27.990427882936377`]}, 2 -> {
                Complex[119.29594909201677`, 0.41898684406680814`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.945328794492804, -2.2714118955594773`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.43236354130933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.526924743965466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.950921629578826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.15150809742505`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4263617542416488`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "B1", 
             Association[1 -> {
                Complex[87.43236354130933, -4.030685571788468], 
                Complex[52.526924743965466`, -27.950921629578826`]}, 2 -> {
                Complex[119.15150809742505`, 0.4263617542416488], 
                Complex[89.13791435011574, -20.259926647201574`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.765410114507597, -2.2460323078138056`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.5965972104936`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.713057076949106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.91198335762003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.00670798392548`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.43393722754094827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "B1", 
             Association[1 -> {
                Complex[87.5965972104936, -4.014253974250844], 
                Complex[52.713057076949106`, -27.91198335762003]}, 2 -> {
                Complex[119.00670798392548`, 0.43393722754094827`], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.587254792919859, -2.2207011371866456`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.76110873074786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.998339037330249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.899715656323174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.87361513171314`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.86152187235369`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4417216954533863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.249482923580253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "B1", 
             Association[1 -> {
                Complex[87.76110873074786, -3.998339037330249], 
                Complex[52.899715656323174`, -27.87361513171314]}, 2 -> {
                Complex[118.86152187235369`, 0.4417216954533863], 
                Complex[88.81124809301974, -20.249482923580253`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.410866771536243, -2.1954142143702007`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.9259262597554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9829436426451017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.08693209104623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.71592233909871`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24396616966669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "B1", 
             Association[1 -> {
                Complex[87.9259262597554, -3.9829436426451017`], 
                Complex[53.08693209104623, -27.835819707361438`]}, 2 -> {
                Complex[118.71592233909871`, 0.44972407722861857`], 
                Complex[88.64703191016157, -20.24396616966669]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.236250312304032, -2.170167299370229}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.09107854831043`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.274738793614276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.798600564939374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.56988137091156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4579538159576179`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.238240125283728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "B1", 
             Association[1 -> {
                Complex[88.09107854831043, -3.968071360048477], 
                Complex[53.274738793614276`, -27.798600564939374`]}, 2 -> {
                Complex[118.56988137091156`, 0.4579538159576179], 
                Complex[88.48218357926146, -20.238240125283728`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-6.063410004318266, -2.144956074393011}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.25659498689762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9537264811323634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677712`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.761961947657237`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.42337031765258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.46642091791168444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232294521384553`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "B1", 
             Association[1 -> {
                Complex[88.25659498689762, -3.9537264811323634`], 
                Complex[53.46316903677712, -27.761961947657237`]}, 2 -> {
                Complex[118.42337031765258`, 0.46642091791168444`], 
                Complex[88.31666948593069, -20.232294521384553`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.892350771376124, -2.1197761362961187`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.4225056545641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9399140565961543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.725908903854407`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.27635984279239`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4751359954876589`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "B1", 
             Association[1 -> {
                Complex[88.4225056545641, -3.9399140565961543`], 
                Complex[53.65225701332303, -27.725908903854407`]}, 2 -> {
                Complex[118.27635984279239`, 0.4751359954876589], 
                Complex[88.15045511884611, -20.226118434741068`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.72307788010651, -2.0946229885583487`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.58884137027606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.926639937856118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.84203789918707`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.690447334057268`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.12881987147094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48411031414990274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746615`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "B1", 
             Association[1 -> {
                Complex[88.58884137027606, -3.926639937856118], 
                Complex[53.84203789918707, -27.690447334057268`]}, 2 -> {
                Complex[118.12881987147094`, 0.48411031414990274`], 
                Complex[87.98350500554793, -20.219700235746615`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.555596948702709, -2.069492032719363}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.7556337469638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.032547920156205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.655584043295303`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.9807195359091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4933558438079552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.81578264469658`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.213027531182277`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "B1", 
             Association[1 -> {
                Complex[88.7556337469638, -3.913910823322049], 
                Complex[54.032547920156205`, -27.655584043295303`]}, 2 -> {
                Complex[117.9807195359091, 0.4933558438079552], 
                Complex[87.81578264469658, -20.213027531182277`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.389913956290949, -2.04437855923447}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.92291524846912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.901734309823764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.22382442246095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.62132679923474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.83202711795477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5028853151246275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449559`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376102`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "B1", 
             Association[1 -> {
                Complex[88.92291524846912, -3.901734309823764], 
                Complex[54.22382442246095, -27.62132679923474]}, 2 -> {
                Complex[117.83202711795477`, 0.5028853151246275], 
                Complex[87.64725043449559, -20.206087101376102`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.226035252968325, -2.019277737684049}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.09071924962198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8901189497339552`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.41590594756346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.587684396763734`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.68270998853552`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5127122813126174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.47786959696758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.198864831110026`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "B1", 
             Association[1 -> {
                Complex[89.09071924962198, -3.8901189497339552`], 
                Complex[54.41590594756346, -27.587684396763734`]}, 2 -> {
                Complex[117.68270998853552`, 0.5127122813126174], 
                Complex[87.47786959696758, -20.198864831110026`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.063967570547485, -1.9941846062702628`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.25908009968339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8790743144078443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.53273454377744`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775223`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.191345633544127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "B1", 
             Association[1 -> {
                Complex[89.25908009968339, -3.8790743144078443`], 
                Complex[54.60883231147051, -27.554666729749556`]}, 2 -> {
                Complex[117.53273454377744`, 0.5228511860504373], 
                Complex[87.30760009775223, -20.191345633544127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.903718034046884, -1.9690940605263056`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.42803318940396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.868611064643572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.8026446889204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.52228487078621`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.38206613753938`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5333174382317764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "B1", 
             Association[1 -> {
                Complex[89.42803318940396, -3.868611064643572], 
                Complex[54.8026446889204, -27.52228487078621]}, 2 -> {
                Complex[117.38206613753938`, 0.5333174382317764], 
                Complex[87.13640056107454, -20.183513366330004`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.745294173969947, -1.9440008411546559`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.59761502195686`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.490551159864236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.2306690101016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "B1", 
             Association[1 -> {
                Complex[89.59761502195686, -3.8587410289636965`], 
                Complex[54.99738570281199, -27.490551159864236`]}, 2 -> {
                Complex[117.2306690101016, 0.5441274943581388], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.58870393941802, -1.918899520901263}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.76786328801319`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628981`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.19309951926377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.45947930302498`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.07850621273863`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5552989494946718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "B1", 
             Association[1 -> {
                Complex[89.76786328801319, -3.849477290628981], 
                Complex[55.19309951926377, -27.45947930302498]}, 2 -> {
                Complex[117.07850621273863`, 0.5552989494946718], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.433955712086268, -1.8937844903608843`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.93881694523479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.840834284423073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.42908448221182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.92553952790038`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5668506378361231`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.15795887530354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "B1", 
             Association[1 -> {
                Complex[89.93881694523479, -3.840834284423073], 
                Complex[55.38983194870931, -27.42908448221182]}, 2 -> {
                Complex[116.92553952790038`, 0.5668506378361231], 
                Complex[86.61678591287696, -20.15795887530354]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.281058321193962, -1.8686499425969403`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.11051630246236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.587630553449955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.77172938472124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5788027440763157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "B1", 
             Association[1 -> {
                Complex[90.11051630246236, -3.8328279043933358`], 
                Complex[55.587630553449955`, -27.39938347770468]}, 2 -> {
                Complex[116.77172938472124`, 0.5788027440763157], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.130021059404223, -1.8434898564439288`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.28300310887596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725713`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.61703476957895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "B1", 
             Association[1 -> {
                Complex[90.28300310887596, -3.8254756239037446`], 
                Complex[55.78654476209901, -27.370394804725713`]}, 2 -> {
                Complex[116.61703476957895`, 0.5911769269441447], 
                Complex[86.26489841088478, -20.139004574702852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.9808536997913913`, -1.8182979783444038`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.45632064839748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.818796629551993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.34213886603787`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.46141313143245`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6039964564654334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "B1", 
             Association[1 -> {
                Complex[90.45632064839748, -3.818796629551993], 
                Complex[55.98662599135722, -27.34213886603787]}, 2 -> {
                Complex[116.46141313143245`, 0.6039964564654334], 
                Complex[86.08716253043332, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.8335665139173423`, -1.7930678025531746`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.6305138395877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812811970731542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.314638122629567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.30482028168436`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6172863667379066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "B1", 
             Association[1 -> {
                Complex[90.6305138395877, -3.812811970731542], 
                Complex[56.18792777555814, -27.314638122629567`]}, 2 -> {
                Complex[116.30482028168436`, 0.6172863667379066], 
                Complex[85.90816108596373, -20.118296161792674`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.6881702910795817`, -1.767792549519857}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.80562934126279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884641`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.390505904409395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.28791728489551`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.14721028834218`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6310736262715528`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.10721581727977`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "B1", 
             Association[1 -> {
                Complex[90.80562934126279, -3.807544726884641], 
                Complex[56.390505904409395`, -27.28791728489551]}, 2 -> {
                Complex[116.14721028834218`, 0.6310736262715528], 
                Complex[85.72783819940138, -20.10721581727977]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.544676358799388, -1.7424651422355895`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.98171566400995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8030201948010025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.26200352709286`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.98853536429765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.54613560230258`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.09561044342854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "B1", 
             Association[1 -> {
                Complex[90.98171566400995, -3.8030201948010025`], 
                Complex[56.594418569327175`, -27.26200352709286]}, 2 -> {
                Complex[115.98853536429765`, 0.6453873282550378], 
                Complex[85.54613560230258, -20.09561044342854]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.4030966046151243`, -1.7170781803009534`}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.15882328771697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.799266098677166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.7997265187117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.236926728284`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.82874574960789`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6602589034686099`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.3629924800621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "B1", 
             Association[1 -> {
                Complex[91.15882328771697, -3.799266098677166], 
                Complex[56.7997265187117, -27.236926728284]}, 2 -> {
                Complex[115.82874574960789`, 0.6602589034686099], 
                Complex[85.3629924800621, -20.08344612962457]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.26344349925183, -1.6916239114389897`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.33700478513522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.796312826071493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.00649322243323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.212719743482218`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.66778958775829`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595763`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "B1", 
             Association[1 -> {
                Complex[91.33700478513522, -3.796312826071493], 
                Complex[57.00649322243323, -27.212719743482218`]}, 2 -> {
                Complex[115.66778958775829`, 0.6757223589838173], 
                Complex[85.17834530693469, -20.070686076595763`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.1257301212339663`, -1.6660942001382304`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.51631495136485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7941936933811906`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.50561279601737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.9921276717174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "B1", 
             Association[1 -> {
                Complex[91.51631495136485, -3.7941936933811906`], 
                Complex[57.21478504568006, -27.18941870930894]}, 2 -> {
                Complex[115.50561279601737`, 0.6918145462814342], 
                Complex[84.9921276717174, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.9899701830076233`, -1.6404804930666665`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.69681093896838`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.167063389167346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.34215893017573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7085754629936065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.043215223764264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "B1", 
             Association[1 -> {
                Complex[91.69681093896838, -3.7929452450428487`], 
                Complex[57.42467143215047, -27.167063389167346`]}, 2 -> {
                Complex[115.34215893017573`, 0.7085754629936065], 
                Complex[84.80427009410889, -20.043215223764264`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.8561780586335836`, -1.6147737808456915`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.8785523981745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.63622509633278`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.145697563752833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.1773690442082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "B1", 
             Association[1 -> {
                Complex[91.8785523981745, -3.7926075913306416`], 
                Complex[57.63622509633278, -27.145697563752833`]}, 2 -> {
                Complex[115.1773690442082, 0.7260485931492021], 
                Complex[84.61469983200216, -20.028413405245864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.7243688131044714`, -1.5889645557128131`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.0616016212985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.793224790416492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.849522224283454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.12536947368377`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.01118154573018`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7442812915903224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.01283297226922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "B1", 
             Association[1 -> {
                Complex[92.0616016212985, -3.793224790416492], 
                Complex[57.849522224283454`, -27.12536947368377]}, 2 -> {
                Complex[115.01118154573018`, 0.7442812915903224], 
                Complex[84.42334068029797, -20.01283297226922]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.594558233326888, -1.5630427645326497`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.24602369006297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7948452812797524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.10613232216428`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.84353204856465`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7633252191523134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281288`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "B1", 
             Association[1 -> {
                Complex[92.24602369006297, -3.7948452812797524`], 
                Complex[58.06464268186045, -27.10613232216428]}, 2 -> {
                Complex[114.84353204856465`, 0.7633252191523134], 
                Complex[84.2301127622816, -19.996417177281288`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.4667628607915995`, -1.5369977565343242`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.43188662390703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7975223751389713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.088044846923395`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.67435322433113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7832368362827095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.979103811483267`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "B1", 
             Association[1 -> {
                Complex[92.43188662390703, -3.7975223751389713`], 
                Complex[58.28167022874947, -27.088044846923395`]}, 2 -> {
                Complex[114.67435322433113`, 0.7832368362827095], 
                Complex[84.03493231522438, -19.979103811483267`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.341000025928049, -1.5108182250589957`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.6192615265831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8013148143453037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.500692735785776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.50357465575655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8040779640432887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.96082455075846`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "B1", 
             Association[1 -> {
                Complex[92.6192615265831, -3.8013148143453037`], 
                Complex[58.500692735785776`, -27.07117197223767]}, 2 -> {
                Complex[114.50357465575655`, 0.8040779640432887], 
                Complex[83.83771147270657, -19.96082455075846]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.2172878841038774`, -1.4844921424908077`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.80822272729263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.806287409159503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.7218024019493`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.055585553683162`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.3311226954559`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.94150420894384`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "B1", 
             Association[1 -> {
                Complex[92.80822272729263, -3.806287409159503], 
                Complex[58.7218024019493, -27.055585553683162`]}, 2 -> {
                Complex[114.3311226954559, 0.8259164229195777], 
                Complex[83.63835804728225, -19.94150420894384]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.0956454531787565`, -1.4580066874165885`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.99884791122709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.94509596590652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.15692033531631`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8488267615895713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861316`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "B1", 
             Association[1 -> {
                Complex[92.99884791122709, -3.812511764560067], 
                Complex[58.94509596590652, -27.04136523041568]}, 2 -> {
                Complex[114.15692033531631`, 0.8488267615895713], 
                Complex[83.43677531861316, -19.921059883642346`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.9760926524543925`, -1.4313481629095361`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.19121823254554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8200671112315354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.17067490495606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.02859940229373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.98088709345224`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8728910898028918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "B1", 
             Association[1 -> {
                Complex[93.19121823254554, -3.8200671112315354`], 
                Complex[59.17067490495606, -27.02859940229373]}, 2 -> {
                Complex[113.98088709345224`, 0.8728910898028918], 
                Complex[83.23286183421266, -19.899399977259357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.858650342770057, -1.404501904658314}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.38541840039804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8290412571884307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081303`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.8029389281222`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318298158`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022337`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "B1", 
             Association[1 -> {
                Complex[93.38541840039804, -3.8290412571884307`], 
                Complex[59.39864561154836, -27.017386352081303`]}, 2 -> {
                Complex[113.8029389281222, 0.8982000318298158], 
                Complex[83.02651123262949, -19.876423073022337`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.7433403673665515`, -1.3774521774603856`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.58153672540173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8395316791213494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.629119533963625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.62298819120014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9248538195678678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248662`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "B1", 
             Association[1 -> {
                Complex[93.58153672540173, -3.8395316791213494`], 
                Complex[59.629119533963625`, -27.007835536336128`]}, 2 -> {
                Complex[113.62298819120014`, 0.9248538195678678], 
                Complex[82.81761210248662, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.6301855929779328`, -1.3501820583646393`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.77966510974753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.851646775514205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431696`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.44094363802188`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9529635473601243`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "B1", 
             Association[1 -> {
                Complex[93.77966510974753, -3.851646775514205], 
                Complex[59.86221326295695, -27.000069072431696`]}, 2 -> {
                Complex[113.44094363802188`, 0.9529635473601243], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.519209950386122, -1.3226733044780639`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.97989895853101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.994223453469264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.25671051601432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400181`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.79840036882036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "B1", 
             Association[1 -> {
                Complex[93.97989895853101, -3.865507306847951], 
                Complex[60.09804853982375, -26.994223453469264`]}, 2 -> {
                Complex[113.25671051601432`, 0.9826526138400181], 
                Complex[82.39169691847613, -19.79840036882036]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.4104384733783297`, -1.2949062031435525`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.18233698253069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.33675215288419`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.990451527552718`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.07019076188233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.0140583796142788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593526`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "B1", 
             Association[1 -> {
                Complex[94.18233698253069, -3.8812480516973524`], 
                Complex[60.33675215288419, -26.990451527552718`]}, 2 -> {
                Complex[113.07019076188233`, 1.0140583796142788`], 
                Complex[82.17443243593526, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.3038973346552416`, -1.2668594018465862`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.3870808529381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8990197110727025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.578455678156594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.988924782863727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.8812833468495`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.047334073136629`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.95412292984462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "B1", 
             Association[1 -> {
                Complex[94.3870808529381, -3.8990197110727025`], 
                Complex[60.578455678156594`, -26.988924782863727`]}, 2 -> {
                Complex[112.8812833468495, 1.047334073136629], 
                Complex[81.95412292984462, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.1996138767190934`, -1.2385097148209334`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.59423465574982`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.918991096639213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.6898848222419`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333021`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "B1", 
             Association[1 -> {
                Complex[94.59423465574982, -3.918991096639213], 
                Complex[60.823295005096384`, -26.989835984869377`]}, 2 -> {
                Complex[112.6898848222419, 1.0826509804077677`], 
                Complex[81.73063257333021, -19.70361719945588]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.0976166350804795`, -1.2098319029022073`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.80390407673113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.941351640907616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.4958901345047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.120200956597012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "B1", 
             Association[1 -> {
                Complex[94.80390407673113, -3.941351640907616], 
                Complex[61.071409568577614`, -26.993402216234127`]}, 2 -> {
                Complex[112.4958901345047, 1.120200956597012], 
                Complex[81.50382199854216, -19.66742872877372]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.9979353502177253, -1.1807984227370125`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.01619522589353`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.966314268200568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.29919380070963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1601992983922493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300129`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "B1", 
             Association[1 -> {
                Complex[95.01619522589353, -3.966314268200568], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[112.29919380070963`, 1.1601992983922493`], 
                Complex[81.27354946300129, -19.628553141047504`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.9006009635292094, -1.151379141024181}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.2312129818792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.994118662652407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.09969156415914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2028880133377466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540668`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "B1", 
             Association[1 -> {
                Complex[95.2312129818792, -3.994118662652407], 
                Complex[61.57803233510411, -27.009511166504147`]}, 2 -> {
                Complex[112.09969156415914`, 1.2028880133377466`], 
                Complex[81.03967255327478, -19.586711092540668`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.8056455909520202, -1.1215410090904976`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.4490586998926`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.022643685363697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.89728268644794`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2485395142215723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.541586913666517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "B1", 
             Association[1 -> {
                Complex[95.4490586998926, -4.025034961302557], 
                Complex[61.836823766448234`, -27.022643685363697`]}, 2 -> {
                Complex[111.89728268644794`, 1.2485395142215723`], 
                Complex[80.80205060892804, -19.541586913666517`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.7131024658845979, -1.0912476928729562`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.66982708015928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.059367882777882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.69187307900017`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.2974607490100891`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "B1", 
             Association[1 -> {
                Complex[95.66982708015928, -4.059367882777882], 
                Complex[62.09945108280155, -27.039620531417192`]}, 2 -> {
                Complex[111.69187307900017`, 1.2974607490100891`], 
                Complex[80.56054810632891, -19.492823467653352`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.6230058404162782, -1.060459153427258}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.89360193588463`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.09746126947422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.06084353867766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.48337953511042`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3499977442410571`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.31503931313222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "B1", 
             Association[1 -> {
                Complex[95.89360193588463, -4.09746126947422], 
                Complex[62.36604010279414, -27.06084353867766]}, 2 -> {
                Complex[111.48337953511042`, 1.3499977442410571`], 
                Complex[80.31503931313222, -19.440016432485926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.5353908305037953, -1.0291311736267106`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.12045052987338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.139702965144408`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.27173539332722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4065404837842295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "B1", 
             Association[1 -> {
                Complex[96.12045052987338, -4.139702965144408], 
                Complex[62.63670053402381, -27.086768000239168`]}, 2 -> {
                Complex[111.27173539332722`, 1.4065404837842295`], 
                Complex[80.06541461134333, -19.382708072431342`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.45029318651551825`, -0.9972148280865516}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.35041606925469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.91151748175411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.05689804273338`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "B1", 
             Association[1 -> {
                Complex[96.35041606925469, -4.186529858286217], 
                Complex[62.91151748175411, -27.117909237707966`]}, 2 -> {
                Complex[111.05689804273338`, 1.4675279533647945`], 
                Complex[79.81158898845908, -19.320380667492582`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.36774896541147434`, -0.9646558960417779}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.58350786490203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.23843277801587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060198`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.154849180830105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.83885876353477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.5334530375357764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "B1", 
             Association[1 -> {
                Complex[96.58350786490203, -4.23843277801587], 
                Complex[63.19054018060198, -27.154849180830105`]}, 2 -> {
                Complex[110.83885876353477`, 1.5334530375357764`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.28779407477602553`, -0.9313942216374842}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.81968859195634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.295960711667092`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.47376724001169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.19824237356078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.61765546654823`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.6048667383421042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.178259010998698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "B1", 
             Association[1 -> {
                Complex[96.81968859195634, -4.295960711667092], 
                Complex[63.47376724001169, -27.19824237356078]}, 2 -> {
                Complex[110.61765546654823`, 1.6048667383421042`], 
                Complex[79.29118905201918, -19.178259010998698`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.21046365228414238`, -0.8973630338353435}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.05885806185303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.39338892118766`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.6823808689752418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.097073995378256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "B1", 
             Association[1 -> {
                Complex[97.05885806185303, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[110.39338892118766`, 1.6823808689752418`], 
                Complex[79.02468735041019, -19.097073995378256`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.13579123775569207`, -0.8624882501594067}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.30083299086704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.43039170884118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.30739360850707`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.16624298693486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.7666679393393405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "B1", 
             Association[1 -> {
                Complex[97.30083299086704, -4.43039170884118], 
                Complex[64.05245675580909, -27.30739360850707]}, 2 -> {
                Complex[110.16624298693486`, 1.7666679393393405`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.0638076903631009, -0.8266878062196665}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.54532251758266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.93650909588722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.8584563892632038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "B1", 
             Association[1 -> {
                Complex[97.54532251758266, -4.508691887180885], 
                Complex[64.34746700294598, -27.374846901442822`]}, 2 -> {
                Complex[109.93650909588722`, 1.8584563892632038`], 
                Complex[78.47993347130918, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.005460196259525055, -0.7898710776092537}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.79189981669174`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.45212840054961`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.70461463897895`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545757`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298536`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "B1", 
             Association[1 -> {
                Complex[97.79189981669174, -4.595394633635136], 
                Complex[64.64571326583466, -27.45212840054961]}, 2 -> {
                Complex[109.70461463897895`, 1.9585186817545757`], 
                Complex[78.20241421183866, -18.803067851298536`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.07199141863592269, -0.751938492635382}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"B1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.0399712463619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.9465546185815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.54022545403769`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.47115381863438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0676491823619294`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.9222561834679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665772`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "B1", 
             Association[1 -> {
                Complex[98.0399712463619, -4.691292487824421], 
                Complex[64.9465546185815, -27.54022545403769]}, 2 -> {
                Complex[109.47115381863438`, 2.0676491823619294`], 
                Complex[77.9222561834679, -18.685105090665772`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.99002448405696, 0.19849482270659813`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"87.31522679800293`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1208373243402968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629899`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"129.7947638473515`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23233632108243982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "D1", 
             Association[1 -> {
                Complex[87.31522679800293, 0.1208373243402968], 
                Complex[113.66233957629899`, -20.405968816918097`]}, 2 -> {
                Complex[129.7947638473515, -0.23233632108243982`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.752538679540407, 0.19646030682920568`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.08751024810645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12356070149769949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786649`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404481912625194`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.99849322244222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23701538097059474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "D1", 
             Association[1 -> {
                Complex[88.08751024810645, 0.12356070149769949`], 
                Complex[114.42383835786649`, -20.404481912625194`]}, 2 -> {
                Complex[128.99849322244222`, -0.23701538097059474`], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.523133019782662, 0.1943850909393916}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"88.7262337592472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"128.34122462191704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2412464009212765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.9491533625454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99078635006785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "D1", 
             Association[1 -> {
                Complex[88.7262337592472, 0.1262779516956984], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[128.34122462191704`, -0.2412464009212765], 
                Complex[152.9491533625454, -20.99078635006785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.3006324543978565`, 0.1922708587797306}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.28793849642045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1290342449298596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.6022820852753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.401559279830174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.76411865770065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24526087014839051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.3805277252232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.993153001298857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "D1", 
             Association[1 -> {
                Complex[89.28793849642045, 0.1290342449298596], 
                Complex[115.6022820852753, -20.401559279830174`]}, 2 -> {
                Complex[127.76411865770065`, -0.24526087014839051`], 
                Complex[152.3805277252232, -20.993153001298857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.08430700680708, 0.19011821350981606`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"89.79835527489765`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1318524872647502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400055664274525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"127.24040452840023`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24916606948645323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.86545848930385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.995376136189673`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "D1", 
             Association[1 -> {
                Complex[89.79835527489765, 0.1318524872647502], 
                Complex[116.10150054551087`, -20.400055664274525`]}, 2 -> {
                Complex[127.24040452840023`, -0.24916606948645323`], 
                Complex[151.86545848930385`, -20.995376136189673`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.8736502901770535`, 0.18792718940707154`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.27178641975755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13474786473650618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39850173816859`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.75520550340622`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2530238186026314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.3890678558327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.997517947369136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "D1", 
             Association[1 -> {
                Complex[90.27178641975755, 0.13474786473650618`], 
                Complex[116.56359372447045`, -20.39850173816859]}, 2 -> {
                Complex[126.75520550340622`, -0.2530238186026314], 
                Complex[151.3890678558327, -20.997517947369136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.6682875730944176`, 0.1856974587412772}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"90.71716902479046`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614971214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.9974956564001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39688632979586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"126.29922820831268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "D1", 
             Association[1 -> {
                Complex[90.71716902479046, 0.13773233614971214`], 
                Complex[116.9974956564001, -20.39688632979586]}, 2 -> {
                Complex[126.29922820831268`, -0.25687501967431886`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.467929619072834, 0.18342843130866804`}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.14054230237684`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.40924174082738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.395199814614816`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.86619477978897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26074963565394127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "D1", 
             Association[1 -> {
                Complex[91.14054230237684, 0.14081646542056195`], 
                Complex[117.40924174082738`, -20.395199814614816`]}, 2 -> {
                Complex[125.86619477978897`, -0.26074963565394127`], 
                Complex[150.51816845485814`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.272346595370905, 0.18111930677087962`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.54622552815437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173268163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.393433199880487`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.45161704308063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2646714726710176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.11289854933466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "D1", 
             Association[1 -> {
                Complex[91.54622552815437, 0.14401032173268163`], 
                Complex[117.80314680030486`, -20.393433199880487`]}, 2 -> {
                Complex[125.45161704308063`, -0.2646714726710176], 
                Complex[150.11289854933466`, -21.00381247852693]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.081352069562826, 0.1787691029444236}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"91.93744543191927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1473239947690677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"125.05214367849409`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2686607590280033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.00594694331133`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "D1", 
             Association[1 -> {
                Complex[91.93744543191927, 0.1473239947690677], 
                Complex[118.18243252444688`, -20.391577604746047`]}, 2 -> {
                Complex[125.05214367849409`, -0.2686607590280033], 
                Complex[149.72290589550488`, -21.00594694331133]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.8947925876769176`, 0.17637667034979287`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.31669834829874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15076793497771607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.54958963881722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.389623921810514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.66518342286211`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2727356740180505`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727762`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "D1", 
             Association[1 -> {
                Complex[92.31669834829874, 0.15076793497771607`], 
                Complex[118.54958963881722`, -20.389623921810514`]}, 2 -> {
                Complex[124.66518342286211`, -0.2727356740180505], 
                Complex[149.34560377406763`, -21.008130280727762`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.7125405708247854`, 0.17394069807808243`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"92.68597265726372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15435321166980637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"124.28867366088821`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27691333395140566`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "D1", 
             Association[1 -> {
                Complex[92.68597265726372, 0.15435321166980637`], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[124.28867366088821`, -0.27691333395140566`], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.534489299122143, 0.17145971360922374`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.04689238885605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15809173524710415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.92093105477679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2812104825190756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "D1", 
             Association[1 -> {
                Complex[93.04689238885605, 0.15809173524710415`], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[123.92093105477679`, -0.2812104825190756], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.360549269951136, 0.16893207798071153`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.400813839551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16199646966552858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.383074839422665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.56055107061424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.2710665829474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.015130373573463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "D1", 
             Association[1 -> {
                Complex[93.400813839551, 0.16199646966552858`], 
                Complex[119.59638315362787`, -20.383074839422665`]}, 2 -> {
                Complex[123.56055107061424`, -0.2856440165404512], 
                Complex[148.2710665829474, -21.015130373573463`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.1906454965630076`, 0.16635597701688987`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"93.7488929125685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1660816520797815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38062504792134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"123.20633797071547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29023142231384175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "D1", 
             Association[1 -> {
                Complex[93.7488929125685, 0.1660816520797815], 
                Complex[119.93165197047354`, -20.38062504792134]}, 2 -> {
                Complex[123.20633797071547`, -0.29023142231384175`], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.0247154718802847`, 0.16372940890664367`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.0921335451172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17036303260019042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868973`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.8572544895749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2949911695233682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "D1", 
             Association[1 -> {
                Complex[94.0921335451172, 0.17036303260019042`], 
                Complex[120.26188344631822`, -20.378020317868973`]}, 2 -> {
                Complex[122.8572544895749, -0.2949911695233682], 
                Complex[147.58883643153152`, -21.020327691813247`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.862707617193678, 0.16105016812593043`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.43142355281749`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17485814579116116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.51238460788528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29994309504690664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "D1", 
             Association[1 -> {
                Complex[94.43142355281749, 0.17485814579116116`], 
                Complex[120.58795576067415`, -20.37524552516941]}, 2 -> {
                Complex[122.51238460788528`, -0.29994309504690664`], 
                Complex[147.25482551280476`, -21.023135337553146`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.7045800944174516`, 0.1583158254747321}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"94.76756190715511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17958662591578023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"122.17090524770384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.02610724189721`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "D1", 
             Association[1 -> {
                Complex[94.76756190715511, 0.17958662591578023`], 
                Complex[120.91065734905382`, -20.372283703951]}, 2 -> {
                Complex[122.17090524770384`, -0.3051088017421774], 
                Complex[146.9244353952348, -21.02610724189721]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.5502998985781034`, 0.15552370379195501`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.10128008303968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.83206414688705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.029264374337636`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "D1", 
             Association[1 -> {
                Complex[95.10128008303968, 0.18457057958645495`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[121.83206414688705`, -0.310512094378606], 
                Complex[146.59692493347416`, -21.029264374337636`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.399842172560554, 0.1526708487010957}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.43325926680586`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18983503235951749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.49516205240121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3161794749411265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.032630053042638`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "D1", 
             Association[1 -> {
                Complex[95.43325926680586, 0.18983503235951749`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[121.49516205240121`, -0.3161794749411265], 
                Complex[146.27160715472138`, -21.032630053042638`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.253189703613188, 0.14975399350120888`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"95.76414468301044`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1954084700848576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"121.1595379262064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109502`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "D1", 
             Association[1 -> {
                Complex[95.76414468301044, 0.1954084700848576], 
                Complex[121.86549419514678`, -20.36207123551036]}, 2 -> {
                Complex[121.1595379262064, -0.3221407220109502], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.110332573615594, 0.14676951702942276`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.09455795990824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20132350187324985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.82455621031696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32842958380826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915493`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "D1", 
             Association[1 -> {
                Complex[96.09455795990824, 0.20132350187324985`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[120.82455621031696`, -0.32842958380826], 
                Complex[145.62498679915493`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.9712679444441932`, 0.1437133929558403}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.42510823906633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20761768000812972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.353897728681492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.48959542170805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "D1", 
             Association[1 -> {
                Complex[96.42510823906633, 0.20761768000812972`], 
                Complex[122.49728704083137`, -20.353897728681492`]}, 2 -> {
                Complex[120.48959542170805`, -0.33508462216302504`], 
                Complex[145.30245899607772`, -21.044258615727983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.835999967117246, 0.14058112849641802`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"96.75640260391667`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2143345239863567`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509227`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"120.15403748497943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.97965180707178`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.048759510069544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "D1", 
             Association[1 -> {
                Complex[96.75640260391667, 0.2143345239863567], 
                Complex[122.81354255509227`, -20.34930172067202]}, 2 -> {
                Complex[120.15403748497943`, -0.3421502560032759], 
                Complex[144.97965180707178`, -21.048759510069544`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.7045398095899174`, 0.1373676898941234}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.08905633219275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22152481262236726`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.81725728511483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "D1", 
             Association[1 -> {
                Complex[97.08905633219275, 0.22152481262236726`], 
                Complex[123.13082758939967`, -20.34430875145043]}, 2 -> {
                Complex[119.81725728511483`, -0.3496780693287915], 
                Complex[144.65596103805998`, -21.053643624569474`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.5769058037275556`, 0.13406741115674414`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.42370345629718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22924823209533163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.44975239734681`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.47861194680793`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067834`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "D1", 
             Association[1 -> {
                Complex[97.42370345629718, 0.22924823209533163`], 
                Complex[123.44975239734681`, -20.33886609255275]}, 2 -> {
                Complex[119.47861194680793`, -0.35772847232067834`], 
                Complex[144.33076734108207`, -21.058964486412613`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.453123717644118, 0.13067388134875202`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"97.7610081399128`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790742`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"119.13742932488076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.366372838776836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.00342515949336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.064785490731847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "D1", 
             Association[1 -> {
                Complex[97.7610081399128, 0.23757550254713045`], 
                Complex[123.77095431790742`, -20.332911072573207`]}, 2 -> {
                Complex[119.13742932488076`, -0.366372838776836], 
                Complex[144.00342515949336`, -21.064785490731847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.3332271657881734`, 0.12717980406095108`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.10167745184768`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2465911570399597`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.7929951193337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37569629412710553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.07118244376477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "D1", 
             Association[1 -> {
                Complex[98.10167745184768, 0.2465911570399597], 
                Complex[124.09510998319794`, -20.32636854350558]}, 2 -> {
                Complex[118.7929951193337, -0.37569629412710553`], 
                Complex[143.6732504076637, -21.07118244376477]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.217258176499584, 0.12357682029059447`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.44647625015428`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324783`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.44453789776165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3858014050647708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.3395062014875`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.07824693369923`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "D1", 
             Association[1 -> {
                Complex[98.44647625015428, 0.2563972235666608], 
                Complex[124.42294949324783`, -20.319147517903787`]}, 2 -> {
                Complex[118.44453789776165`, -0.3858014050647708], 
                Complex[143.3395062014875, -21.07824693369923]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.1052679460279506`, 0.11985528248170496`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.79624510214889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.311136636747282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"118.09121109621549`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39681313957995207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "D1", 
             Association[1 -> {
                Complex[98.79624510214889, 0.26711817863125653`], 
                Complex[124.7552734369329, -20.311136636747282`]}, 2 -> {
                Complex[118.09121109621549`, -0.39681313957995207`], 
                Complex[143.00138575722926`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.9973178203207596, 0.11600396230100252`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.15192249564048`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27890772560984034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.30219795679849`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.73207074060755`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4088856508160151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.094852699839524`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "D1", 
             Association[1 -> {
                Complex[99.15192249564048, 0.27890772560984034`], 
                Complex[125.09297394908009`, -20.30219795679849]}, 2 -> {
                Complex[117.73207074060755`, -0.4088856508160151], 
                Complex[142.6579912660793, -21.094852699839524`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.8934805628971247, 0.11200966686181069`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.514573105033`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29195824799683273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"117.36604712293936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42221173502136283`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "D1", 
             Association[1 -> {
                Complex[99.514573105033, 0.29195824799683273`], 
                Complex[125.43706147399149`, -20.29215827088692]}, 2 -> {
                Complex[117.36604712293936`, -0.42221173502136283`], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.7938419914153911, 0.10785672585827655`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.88542466730593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3065142785572326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.7886996540862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.280796718741154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.99190787569995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475136285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.1158723502883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "D1", 
             Association[1 -> {
                Complex[99.88542466730593, 0.3065142785572326], 
                Complex[125.7886996540862, -20.280796718741154`]}, 2 -> {
                Complex[116.99190787569995`, -0.43703630475136285`], 
                Complex[141.95116473317964`, -21.1158723502883]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.6985031012682299, 0.10352629244348677`}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.26591727728177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.60820863370117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45367605639991937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "D1", 
             Association[1 -> {
                Complex[100.26591727728177`, 0.32289216335652743`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[116.60820863370117`, -0.45367605639991937`], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.6075828486224282, 0.0989953682178939}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.65777094806738`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34150958252322516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"116.2132254363857`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4725489940033503`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "D1", 
             Association[1 -> {
                Complex[100.65777094806738`, 0.34150958252322516`], 
                Complex[126.52034552601546`, -20.252868457449622`]}, 2 -> {
                Complex[116.2132254363857, -0.4725489940033503], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.521221849658204, 0.0942354069932918}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.06308068349807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3629313245006878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.80485962290086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614478673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "D1", 
             Association[1 -> {
                Complex[101.06308068349807`, 0.3629313245006878], 
                Complex[126.90396116486052`, -20.235407072598086`]}, 2 -> {
                Complex[115.80485962290086`, -0.49422020614478673`], 
                Complex[140.81990311379658`, -21.160625877708522`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.43958738849867984`, 0.08921025233040503}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.48445417285807`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"115.38050010894172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.181081480488864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "D1", 
             Association[1 -> {
                Complex[101.48445417285807`, 0.3879430012901771], 
                Complex[127.30256352822093`, -20.214723835180756`]}, 2 -> {
                Complex[115.38050010894172`, -0.5194755835198392], 
                Complex[140.41612546346295`, -21.181081480488864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.3628803523328088, 0.08387297650391368}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.92521768180029`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41767521438799576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.7192960348708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.18978114508657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.93681747084511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.549445986914998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.99429101812663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2057892537521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "D1", 
             Association[1 -> {
                Complex[101.92521768180029`, 0.41767521438799576`], 
                Complex[127.7192960348708, -20.18978114508657]}, 2 -> {
                Complex[114.93681747084511`, -0.549445986914998], 
                Complex[139.99429101812663`, -21.2057892537521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.2913451025024898, 0.07816081527476726}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.38973504769774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4538243260356928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502808`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"114.46944492820539`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5858280202580782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.236311334493806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "D1", 
             Association[1 -> {
                Complex[102.38973504769774`, 0.4538243260356928], 
                Complex[128.15828301502808`, -20.159017144377533`]}, 2 -> {
                Complex[114.46944492820539`, -0.5858280202580782], 
                Complex[139.55027237651973`, -21.236311334493806`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.2252839892092453, 0.07198659525592888}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.883921441729`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829307003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.97246456229634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.631303461284326`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578064`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "D1", 
             Association[1 -> {
                Complex[102.883921441729, 0.49907188829307003`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[113.97246456229634`, -0.631303461284326], 
                Complex[139.07847426814035`, -21.27512497578064]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.1650795054641776, 0.06522319508245289}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.41610339254098`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.12767489010264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"113.43754727510904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.57101671236563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.326430796181967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "D1", 
             Association[1 -> {
                Complex[103.41610339254098`, 0.5579501377609489], 
                Complex[129.12767489010264`, -20.068393863077308`]}, 2 -> {
                Complex[113.43754727510904`, -0.6904047576732153], 
                Complex[138.57101671236563`, -21.326430796181967`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.11122942849407025`, 0.05767278866942149}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.99849290966137`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041314329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.67752337597602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.99655438623809`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.85247865053964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368577013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.01633089208286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.39800884938102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "D1", 
             Association[1 -> {
                Complex[103.99849290966137`, 0.6388251041314329], 
                Complex[129.67752337597602`, -19.99655438623809]}, 2 -> {
                Complex[112.85247865053964`, -0.7714981368577013], 
                Complex[138.01633089208286`, -21.39800884938102]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.06440378728204621, 0.04899855821403065}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.6495564695593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7590828537974087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.888210869228352`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"112.19878995458203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8919698507578182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.39688673641334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.506084894187065`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "D1", 
             Association[1 -> {
                Complex[104.6495564695593, 0.7590828537974087], 
                Complex[130.2921900311733, -19.888210869228352`]}, 2 -> {
                Complex[112.19878995458203`, -0.8919698507578182], 
                Complex[137.39688673641334`, -21.506084894187065`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           
           TooltipBox[
            PointBox[{-0.025528397795653746`, 0.038549307221140694`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"D1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.3953422129245`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9608435417074137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272228`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.703899841697414`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"111.45043092574376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0939402286419335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.690122605628147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "D1", 
             Association[1 -> {
                Complex[105.3953422129245, 0.9608435417074137], 
                Complex[130.99653808272228`, -19.703899841697414`]}, 2 -> {
                Complex[111.45043092574376`, -1.0939402286419335`], 
                Complex[136.68781879291285`, -21.690122605628147`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.878952410602958, 0.3095668961605609}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"142.43088738729756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12083732434029751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.91042443664614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23233632108243843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "C1", 
             Association[1 -> {
                Complex[142.43088738729756`, 0.12083732434029751`], 
                Complex[113.66233957629902`, -20.405968816918097`]}, 2 -> {
                Complex[184.91042443664614`, -0.23233632108243843`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.64146660608642, 0.30753238028317376`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.20317083740102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12356070149773071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40448191262516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.11415381173683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2370153809705939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "C1", 
             Association[1 -> {
                Complex[143.20317083740102`, 0.12356070149773071`], 
                Complex[114.42383835786643`, -20.40448191262516]}, 2 -> {
                Complex[184.11415381173683`, -0.2370153809705939], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.412060946328717, 0.3054571643933526}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.8418943485418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"183.45688521121167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24124640092127728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.94915336254542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "C1", 
             Association[1 -> {
                Complex[143.8418943485418, 0.1262779516956982], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[183.45688521121167`, -0.24124640092127728`], 
                Complex[152.94915336254542`, -20.990786350067847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-5.189560380943897, 0.30334293223370046`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.403599085715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12903424492994017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.60228208527523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40155927983009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.87977924699527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2452608701483842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.38052772522323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.993153001298854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "C1", 
             Association[1 -> {
                Complex[144.403599085715, 0.12903424492994017`], 
                Complex[115.60228208527523`, -20.40155927983009]}, 2 -> {
                Complex[182.87977924699527`, -0.2452608701483842], 
                Complex[152.38052772522323`, -20.993153001298854`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.973234933353064, 0.30119028696377703`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.91401586419227`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1318524872647501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40005566427453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.3560651176949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24916606948640838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.8654584893039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99537613618962`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "C1", 
             Association[1 -> {
                Complex[144.91401586419227`, 0.1318524872647501], 
                Complex[116.10150054551087`, -20.40005566427453]}, 2 -> {
                Complex[182.3560651176949, -0.24916606948640838`], 
                Complex[151.8654584893039, -20.99537613618962]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.76257821672308, 0.29899926286102185`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.38744700905215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13474786473651384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398501738168576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.8708660927008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.253023818602633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.38906785583268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.99751794736914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "C1", 
             Association[1 -> {
                Complex[145.38744700905215`, 0.13474786473651384`], 
                Complex[116.56359372447044`, -20.398501738168576`]}, 2 -> {
                Complex[181.8708660927008, -0.253023818602633], 
                Complex[151.38906785583268`, -20.99751794736914]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.557215499640472, 0.29676953219523994`}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.8328296140851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614972086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.99749565640013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.396886329795848`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.41488879760732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "C1", 
             Association[1 -> {
                Complex[145.8328296140851, 0.13773233614972086`], 
                Complex[116.99749565640013`, -20.396886329795848`]}, 2 -> {
                Complex[181.41488879760732`, -0.25687501967431686`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.356857545618846, 0.2945005047626361}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.25620289167148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.4092417408274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.395199814614813`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.9818553690836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.260749635653941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "C1", 
             Association[1 -> {
                Complex[146.25620289167148`, 0.14081646542056195`], 
                Complex[117.4092417408274, -20.395199814614813`]}, 2 -> {
                Complex[180.9818553690836, -0.260749635653941], 
                Complex[150.51816845485817`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-4.161274521916988, 0.29219138022483704`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.661886117449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173267872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39343319988049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.56727763237527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467147267101754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.1128985493347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "C1", 
             Association[1 -> {
                Complex[146.661886117449, 0.14401032173267872`], 
                Complex[117.80314680030489`, -20.39343319988049]}, 2 -> {
                Complex[180.56727763237527`, -0.26467147267101754`], 
                Complex[150.1128985493347, -21.00381247852693]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.970279996108838, 0.28984117639838103`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.0531060212139`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14732399476906763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.1678042677887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2686607590279984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.005946943311322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "C1", 
             Association[1 -> {
                Complex[147.0531060212139, 0.14732399476906763`], 
                Complex[118.18243252444688`, -20.391577604746043`]}, 2 -> {
                Complex[180.1678042677887, -0.2686607590279984], 
                Complex[149.72290589550488`, -21.005946943311322`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.7837205142229444`, 0.28744874380374674`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.43235893759334`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15076793497771634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.5495896388172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38962392181051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.78084401215676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27273567401803595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "C1", 
             Association[1 -> {
                Complex[147.43235893759334`, 0.15076793497771634`], 
                Complex[118.5495896388172, -20.38962392181051]}, 2 -> {
                Complex[179.78084401215676`, -0.27273567401803595`], 
                Complex[149.34560377406765`, -21.008130280727748`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.601468497370855, 0.2850127715320434}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.80163324655834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1543532116698063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.4043342501828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2769133339514044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "C1", 
             Association[1 -> {
                Complex[147.80163324655834`, 0.1543532116698063], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[179.4043342501828, -0.2769133339514044], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.423417225668198, 0.2825317870631865}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.16255297815067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1580917352471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.0365916440714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2812104825190737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "C1", 
             Association[1 -> {
                Complex[148.16255297815067`, 0.1580917352471046], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[179.0365916440714, -0.2812104825190737], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.249477196497191, 0.28000415143466006`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.51647442884564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16199646966552844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38307483942267`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.67621165990886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.27106658294744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01513037357346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "C1", 
             Association[1 -> {
                Complex[148.51647442884564`, 0.16199646966552844`], 
                Complex[119.59638315362788`, -20.38307483942267]}, 2 -> {
                Complex[178.67621165990886`, -0.2856440165404518], 
                Complex[148.27106658294744`, -21.01513037357346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-3.07957342310902, 0.27742805047084906`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.8645535018631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16608165207978046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.380625047921345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.3219985600101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2902314223138406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "C1", 
             Association[1 -> {
                Complex[148.8645535018631, 0.16608165207978046`], 
                Complex[119.93165197047352`, -20.380625047921345`]}, 2 -> {
                Complex[178.3219985600101, -0.2902314223138406], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.913643398426269, 0.27480148236060464`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.2077941344118`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1703630326001896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868977`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.97291507886953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2949911695233655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "C1", 
             Association[1 -> {
                Complex[149.2077941344118, 0.1703630326001896], 
                Complex[120.26188344631822`, -20.378020317868977`]}, 2 -> {
                Complex[177.97291507886953`, -0.2949911695233655], 
                Complex[147.58883643153155`, -21.020327691813243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.7516355437397473`, 0.27212224157988607`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.54708414211208`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1748581457911621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067412`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.62804519717992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2999430950469064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280479`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "C1", 
             Association[1 -> {
                Complex[149.54708414211208`, 0.1748581457911621], 
                Complex[120.58795576067412`, -20.37524552516941]}, 2 -> {
                Complex[177.62804519717992`, -0.2999430950469064], 
                Complex[147.25482551280479`, -21.023135337553143`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.5935080209634926`, 0.269387898928686}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.88322249644975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17958662591578034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.28656583699845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.026107241897208`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "C1", 
             Association[1 -> {
                Complex[149.88322249644975`, 0.17958662591578034`], 
                Complex[120.91065734905384`, -20.372283703951]}, 2 -> {
                Complex[177.28656583699845`, -0.3051088017421759], 
                Complex[146.9244353952348, -21.026107241897208`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.43922782512413, 0.266595777245916}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.2169406723343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.94772473618167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02926437433764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "C1", 
             Association[1 -> {
                Complex[150.2169406723343, 0.18457057958645484`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[176.94772473618167`, -0.310512094378605], 
                Complex[146.59692493347418`, -21.02926437433764]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.2887700991065807`, 0.2637429221550531}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.54891985610047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18983503235951585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.6108226416958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3161794749411295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03263005304264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "C1", 
             Association[1 -> {
                Complex[150.54891985610047`, 0.18983503235951585`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[176.6108226416958, -0.3161794749411295], 
                Complex[146.27160715472132`, -21.03263005304264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-2.142117630159215, 0.2608260669551734}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.87980527230502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1954084700848582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.275198515501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "C1", 
             Association[1 -> {
                Complex[150.87980527230502`, 0.1954084700848582], 
                Complex[121.86549419514674`, -20.36207123551036]}, 2 -> {
                Complex[176.275198515501, -0.3221407220109508], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.9992605001616204`, 0.2578415904833784}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.21021854920286`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20132350187325002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.9402167996116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3284295838082578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "C1", 
             Association[1 -> {
                Complex[151.21021854920286`, 0.20132350187325002`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[175.9402167996116, -0.3284295838082578], 
                Complex[145.62498679915495`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.8601958709902482`, 0.25478546640979594`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.54076882836094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20761768000812997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.35389772868149`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.60525601100267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727987`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "C1", 
             Association[1 -> {
                Complex[151.54076882836094`, 0.20761768000812997`], 
                Complex[122.49728704083137`, -20.35389772868149]}, 2 -> {
                Complex[175.60525601100267`, -0.33508462216302626`], 
                Complex[145.30245899607772`, -21.044258615727987`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.7249278936632726`, 0.2516532019503843}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.87206319321126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21433452398635636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.26969807427406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.9796518070718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.048759510069537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "C1", 
             Association[1 -> {
                Complex[151.87206319321126`, 0.21433452398635636`], 
                Complex[122.81354255509225`, -20.34930172067202]}, 2 -> {
                Complex[175.26969807427406`, -0.3421502560032738], 
                Complex[144.9796518070718, -21.048759510069537`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.5934677361359724`, 0.24843976334808612`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.20471692148735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22152481262236687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.93291787440944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "C1", 
             Association[1 -> {
                Complex[152.20471692148735`, 0.22152481262236687`], 
                Complex[123.13082758939966`, -20.34430875145043]}, 2 -> {
                Complex[174.93291787440944`, -0.3496780693287902], 
                Complex[144.65596103805998`, -21.053643624569467`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.4658337302736248`, 0.2451394846106962}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.53936404559178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22924823209533307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.4497523973468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.59427253610252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412606`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "C1", 
             Association[1 -> {
                Complex[152.53936404559178`, 0.22924823209533307`], 
                Complex[123.4497523973468, -20.33886609255275]}, 2 -> {
                Complex[174.59427253610252`, -0.35772847232067345`], 
                Complex[144.33076734108204`, -21.058964486412606`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.3420516441901162`, 0.24174595480270764`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.8766687292074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790741`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.25308991417538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36637283877683763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.0034251594934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.064785490731843`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "C1", 
             Association[1 -> {
                Complex[152.8766687292074, 0.23757550254713042`], 
                Complex[123.77095431790741`, -20.332911072573204`]}, 2 -> {
                Complex[174.25308991417538`, -0.36637283877683763`], 
                Complex[144.0034251594934, -21.064785490731843`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.2221550923342142`, 0.23825187751490493`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.2173380411423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24659115703995835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.90865570862832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37569629412710687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.071182443764766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "C1", 
             Association[1 -> {
                Complex[153.2173380411423, 0.24659115703995835`], 
                Complex[124.09510998319796`, -20.32636854350558]}, 2 -> {
                Complex[173.90865570862832`, -0.37569629412710687`], 
                Complex[143.6732504076637, -21.071182443764766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-1.1061861030455822`, 0.23464889374455364`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.5621368394489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.56019848705628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38580140506476973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.33950620148752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078246933699234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "C1", 
             Association[1 -> {
                Complex[153.5621368394489, 0.2563972235666605], 
                Complex[124.42294949324784`, -20.319147517903783`]}, 2 -> {
                Complex[173.56019848705628`, -0.38580140506476973`], 
                Complex[143.33950620148752`, -21.078246933699234`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.9941958725740057, 0.23092735593566946`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.9119056914435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31113663674728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.2068716855101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3968131395799549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "C1", 
             Association[1 -> {
                Complex[153.9119056914435, 0.26711817863125764`], 
                Complex[124.7552734369329, -20.31113663674728]}, 2 -> {
                Complex[173.2068716855101, -0.3968131395799549], 
                Complex[143.00138575722923`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.8862457468667861, 0.22707603575496169`}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.26758308493513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27890772560985055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.302197956798476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.84773132990216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40888565081601425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.09485269983952`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "C1", 
             Association[1 -> {
                Complex[154.26758308493513`, 0.27890772560985055`], 
                Complex[125.09297394908012`, -20.302197956798476`]}, 2 -> {
                Complex[172.84773132990216`, -0.40888565081601425`], 
                Complex[142.6579912660793, -21.09485269983952]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.7824084894431798, 0.2230817403157823}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.6302336943276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2919582479968343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.481707712234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4222117350213626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "C1", 
             Association[1 -> {
                Complex[154.6302336943276, 0.2919582479968343], 
                Complex[125.43706147399148`, -20.29215827088692]}, 2 -> {
                Complex[172.481707712234, -0.4222117350213626], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.6827699179614177, 0.21892879931224105`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.00108525660056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30651427855723345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.78869965408623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.28079671874115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.10756846499456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475135913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.115872350288292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "C1", 
             Association[1 -> {
                Complex[155.00108525660056`, 0.30651427855723345`], 
                Complex[125.78869965408623`, -20.28079671874115]}, 2 -> {
                Complex[172.10756846499456`, -0.43703630475135913`], 
                Complex[141.95116473317964`, -21.115872350288292`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.5874310278142849, 0.2145983658974477}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.38157786657638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.72386922299577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4536760563999232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "C1", 
             Association[1 -> {
                Complex[155.38157786657638`, 0.32289216335652754`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[171.72386922299577`, -0.4536760563999232], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.4965107751684406, 0.21006744167185484`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.773431537362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34150958252322494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.32888602568033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47254899400334877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "C1", 
             Association[1 -> {
                Complex[155.773431537362, 0.34150958252322494`], 
                Complex[126.52034552601548`, -20.252868457449622`]}, 2 -> {
                Complex[171.32888602568033`, -0.47254899400334877`], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.4101497762042306, 0.20530748044725275`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.1787412727927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3629313245006883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.92052021219553`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614487433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "C1", 
             Association[1 -> {
                Complex[156.1787412727927, 0.3629313245006883], 
                Complex[126.90396116486053`, -20.235407072598086`]}, 2 -> {
                Complex[170.92052021219553`, -0.49422020614487433`], 
                Complex[140.81990311379664`, -21.160625877708604`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{-0.32851531504476333`, 0.20028232578436597`}],
            
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.60011476215269`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.49616069823637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.18108148048887`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "C1", 
             Association[1 -> {
                Complex[156.60011476215269`, 0.3879430012901607], 
                Complex[127.30256352822093`, -20.214723835180777`]}, 2 -> {
                Complex[170.49616069823637`, -0.5194755835198454], 
                Complex[140.41612546346298`, -21.18108148048887]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{-0.25180827887884966`, 0.19494504995786752`}],
            
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.0408782710949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4176752143879963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.71929603487078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.189781145086567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.05247806013978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5494459869149929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.9942910181267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.205789253752098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "C1", 
             Association[1 -> {
                Complex[157.0408782710949, 0.4176752143879963], 
                Complex[127.71929603487078`, -20.189781145086567`]}, 2 -> {
                Complex[170.05247806013978`, -0.5494459869149929], 
                Complex[139.9942910181267, -21.205789253752098`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{-0.18027302904848802`, 0.18923288872871577`}],
            
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.5053956369925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45382432603574024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.5851055175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5858280202580739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2363113344938`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "C1", 
             Association[1 -> {
                Complex[157.5053956369925, 0.45382432603574024`], 
                Complex[128.15828301502822`, -20.159017144377493`]}, 2 -> {
                Complex[169.5851055175, -0.5858280202580739], 
                Complex[139.55027237651973`, -21.2363113344938]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{-0.11421191575524352`, 0.18305866870989515`}],
            
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.9995820310236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829306903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.08812515159096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6313034612843315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "C1", 
             Association[1 -> {
                Complex[157.9995820310236, 0.49907188829306903`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[169.08812515159096`, -0.6313034612843315], 
                Complex[139.07847426814035`, -21.27512497578065]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.054007432010190023`, 0.1762952685364085}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"158.53176398183555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.1276748901026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"168.55320786440365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.5710167123656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32643079618197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "C1", 
             Association[1 -> {
                Complex[158.53176398183555`, 0.5579501377609449], 
                Complex[129.1276748901026, -20.068393863077308`]}, 2 -> {
                Complex[168.55320786440365`, -0.6904047576732164], 
                Complex[138.5710167123656, -21.32643079618197]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{-0.00015735504009688206`, 0.1687448621233931}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.11415349895574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041312677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.6775233759758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.99655438623824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.96813923983427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368576926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.0163308920829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.39800884938101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "C1", 
             Association[1 -> {
                Complex[159.11415349895574`, 0.6388251041312677], 
                Complex[129.6775233759758, -19.99655438623824]}, 2 -> {
                Complex[167.96813923983427`, -0.7714981368576926], 
                Complex[138.0163308920829, -21.39800884938101]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.046668286171898735`, 0.16007063166798982`}],
            
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.76521705885392`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.759082853797409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.88821086922835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.3144505438764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8919698507580937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.3968867364131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.506084894187325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "C1", 
             Association[1 -> {
                Complex[159.76521705885392`, 0.759082853797409], 
                Complex[130.2921900311733, -19.88821086922835]}, 2 -> {
                Complex[167.3144505438764, -0.8919698507580937], 
                Complex[137.3968867364131, -21.506084894187325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.08554367565830541, 0.1496213806751052}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C1\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"160.51100280221908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9608435417074076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.70389984169742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"166.5660915150384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939402286417192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291288`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.69012260562795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "C1", 
             Association[1 -> {
                Complex[160.51100280221908`, 0.9608435417074076], 
                Complex[130.99653808272222`, -19.70389984169742]}, 2 -> {
                Complex[166.5660915150384, -1.0939402286417192`], 
                Complex[136.68781879291288`, -21.69012260562795]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.11529495955654108`, 0.13592468298589974`}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"161.35610930103817`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.33740874464973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"165.71846158622145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317955`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"135.88391552140592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "C2", 
             Association[1 -> {
                Complex[161.35610930103817`, 1.3569051651311863`], 
                Complex[131.7957769749429, -19.33740874464973]}, 2 -> {
                Complex[165.71846158622145`, -1.4902074317955], 
                Complex[135.88391552140592`, -22.056334735916565`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.13563617310967907`, 0.11581047353076965`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.09763876574996`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0881973270436873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.4998425166415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.6544084566896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.974456667634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2217012177173117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.73905058908342`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "C2", 
             Association[1 -> {
                Complex[162.09763876574996`, 2.0881973270436873`], 
                Complex[132.4998425166415, -18.6544084566896]}, 2 -> {
                Complex[164.974456667634, -2.2217012177173117`], 
                Complex[135.17523913663766`, -22.73905058908342]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.004222886102638768, 0.024852609531938796`}],
            
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"D2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.24044871174357`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.337408744649736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"110.60280099692714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317952845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.88391552140624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "D2", 
             Association[1 -> {
                Complex[106.24044871174357`, 1.3569051651311739`], 
                Complex[131.7957769749429, -19.337408744649736`]}, 2 -> {
                Complex[110.60280099692714`, -1.4902074317952845`], 
                Complex[135.88391552140624`, -22.056334735916362`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.02456409965571993, 0.004738400076814031}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"D2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.9819781764553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0881973270436194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.49984251664148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.65440845668966`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.85879607833935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.221701217717411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.739050589083515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "D2", 
             Association[1 -> {
                Complex[106.9819781764553, 2.0881973270436194`], 
                Complex[132.49984251664148`, -18.65440845668966]}, 2 -> {
                Complex[109.85879607833935`, -2.221701217717411], 
                Complex[135.17523913663763`, -22.739050589083515`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.03840065515061042, -0.02460856126720401}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.38113498587141`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.879670752931702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.45721001861465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532400557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "D3", 
             Association[1 -> {
                Complex[107.38113498587141`, 2.9142396485109705`], 
                Complex[132.88189718832854`, -17.879670752931702`]}, 2 -> {
                Complex[109.45721001861465`, -3.0479413532400557`], 
                Complex[134.78862529189132`, -23.513498562864495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.04896568389047218, -0.06278983622889456}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.58249764089271`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.0766455744856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.206794013455227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.25346264300121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.7646664040767535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763843963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.186080440963586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "D3", 
             Association[1 -> {
                Complex[107.58249764089271`, 3.6307705575763576`], 
                Complex[133.0766455744856, -17.206794013455227`]}, 2 -> {
                Complex[109.25346264300121`, -3.7646664040767535`], 
                Complex[134.58936763843963`, -24.186080440963586`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.05775479066797118, -0.10852408945782877`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.7013662368456`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.244103960587581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.19282273525405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.630699080753942`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.13225227369334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.4687294463477`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"24.76187553625737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "D3", 
             Association[1 -> {
                Complex[107.7013662368456, 4.244103960587581], 
                Complex[133.19282273525405`, -16.630699080753942`]}, 2 -> {
                Complex[109.13225227369334`, -4.378190406750104], 
                Complex[134.4687294463477, -24.76187553625737]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.06542583960802517, -0.16079767352941232`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.78057143660814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156967`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.05074675004954`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.916047187939773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "D3", 
             Association[1 -> {
                Complex[107.78057143660814`, 4.781773561001174], 
                Complex[133.27102086156967`, -16.125747324937528`]}, 2 -> {
                Complex[109.05074675004954`, -4.916047187939773], 
                Complex[134.38611694252154`, -25.266522626186067`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.07231769091623619, -0.21886623947146333`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.83770870028388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.263174211991336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.67377847042299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.9913491928679`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.397631717588795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793695`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.71818212660493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "D3", 
             Association[1 -> {
                Complex[107.83770870028388`, 5.263174211991336], 
                Complex[133.3279803002992, -15.67377847042299]}, 2 -> {
                Complex[108.9913491928679, -5.397631717588795], 
                Complex[134.3247882793695, -25.71818212660493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.0786287602027187, -0.2821662303199588}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.88121526668063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.262765801866918`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.94562101739476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.835759112686365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605626`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343982`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "D3", 
             Association[1 -> {
                Complex[107.88121526668063`, 5.701120919783156], 
                Complex[133.3717561373341, -15.262765801866918`]}, 2 -> {
                Complex[108.94562101739476`, -5.835759112686365], 
                Complex[134.27668694605626`, -26.128880886343982`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.08448623963371915, -0.3502550648029459}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.91564972566658`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40671477584058`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.884495531077587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.9090023559344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239169639445858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.23744518508806`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.506832820749022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "D3", 
             Association[1 -> {
                Complex[107.91564972566658`, 6.104353845416767], 
                Complex[133.40671477584058`, -14.884495531077587`]}, 2 -> {
                Complex[108.9090023559344, -6.239169639445858], 
                Complex[134.23744518508806`, -26.506832820749022`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.08997717651396897, -0.4227742774174068}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.94370334554677`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.435442200275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.53312652195004`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.87880072587267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "D3", 
             Association[1 -> {
                Complex[107.94370334554677`, 6.479082403584124], 
                Complex[133.435442200275, -14.53312652195004]}, 2 -> {
                Complex[108.87880072587267`, -6.614072812516715], 
                Complex[134.20447572357537`, -26.857879187158495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.09516413681348013, -0.4994262398510507}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.967075449591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.8533156489355`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.965045479528821`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.186328668332603`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "D3", 
             Association[1 -> {
                Complex[107.967075449591, 6.829883346826048], 
                Complex[133.45957631720725`, -14.204350207418504`]}, 2 -> {
                Complex[108.8533156489355, -6.965045479528821], 
                Complex[134.17613942808242`, -27.186328668332603`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.10009382995752958`, -0.5799588549360859}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.98689671384345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.160236693505573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.894888445103899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.83141534951223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380921`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.15134199635162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.495459517152923`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "D3", 
             Association[1 -> {
                Complex[107.98689671384345`, 7.160236693505573], 
                Complex[133.48021025962268`, -13.894888445103899`]}, 2 -> {
                Complex[108.83141534951223`, -7.295567749380921], 
                Complex[134.15134199635162`, -27.495459517152923`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.10480219673863189`, -0.6641550936214617}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.00395158132416`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273206`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.8123143369035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1293216354845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.78783159598449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.00395158132416`, 7.472858386883563], 
                Complex[133.49810470509104`, -13.602181478273206`]}, 2 -> {
                Complex[108.8123143369035, -7.60835565160761], 
                Complex[134.1293216354845, -27.78783159598449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.10931758018233495`, -0.75182559330948}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.01880316611171`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301744`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.324186402581233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.79544849796953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "D3", 
             Association[1 -> {
                Complex[108.01880316611171`, 7.769914966301744], 
                Complex[133.51380733250917`, -13.324186402581233`]}, 2 -> {
                Complex[108.79544849796953`, -7.905575807831236], 
                Complex[134.10952960183627`, -28.065487910230857`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.11366279196940354`, -0.8428032649744512}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.03186731148087`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.05316704921159`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.78040103598128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.188988914036557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.330089398863645`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.03186731148087`, 8.05316704921159], 
                Complex[133.52772377923588`, -13.059242375813357`]}, 2 -> {
                Complex[108.78040103598128`, -8.188988914036557], 
                Complex[134.09155924078232`, -28.330089398863645`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.11785650988827001`, -0.936939262937015}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.0434585247249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.324068243739198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175148`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.76685653301915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.460048653363888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.07510189390769`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.583007906385827`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.0434585247249, 8.324068243739198], 
                Complex[133.54016173104085`, -12.805977646175148`]}, 2 -> {
                Complex[108.76685653301915`, -8.460048653363888], 
                Complex[134.07510189390769`, -28.583007906385827`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.12191425279124246`, -1.0340999063351095`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.05381957099668`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.58383520750421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.563243670423079`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.75457135356359`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138769`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493511`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.05381957099668`, 8.58383520750421], 
                Complex[133.55135937730103`, -12.563243670423079`]}, 2 -> {
                Complex[108.75457135356359`, -8.719971755138769], 
                Complex[134.05991844116494`, -28.82539206493511]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1258490791060467, -1.1341642824443934`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.0631411673518`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.833498461149432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.74335394807592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.0631411673518, 8.833498461149432], 
                Complex[133.56150438018216`, -12.330067310220024`]}, 2 -> {
                Complex[108.74335394807592`, -8.96978880859594], 
                Complex[134.04582032924358`, -29.058215098144675`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.12967209889427522`, -1.237022349572614}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.07157546049427`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.07394002099248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863516`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.105615415604044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.73305137305235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0326565653045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.282310237876374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "D3", 
             Association[1 -> {
                Complex[108.07157546049427`, 9.07394002099248], 
                Complex[133.57074687863516`, -12.105615415604044`]}, 2 -> {
                Complex[108.73305137305235`, -9.210381895712354], 
                Complex[134.0326565653045, -29.282310237876374`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1333928568022884, -1.3425734132744047`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.07924547805123`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503111`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.72353983770584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.442512981808122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.02030458027298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "D3", 
             Association[1 -> {
                Complex[108.07924547805123`, 9.305921789460674], 
                Complex[133.57920862299494`, -11.889168097503111`]}, 2 -> {
                Complex[108.72353983770584`, -9.442512981808122], 
                Complex[134.02030458027298`, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.13701962353238173`, -1.4507248864640783`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.08625189994662`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034468`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.71471793069901`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "D3", 
             Association[1 -> {
                Complex[108.08625189994662`, 9.530107327827563], 
                Complex[133.58698953054267`, -11.680098224034468`]}, 2 -> {
                Complex[108.71471793069901`, -9.666845688440555], 
                Complex[134.00866367132147`, -29.707103947727518`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.14055962116682963`, -1.5613912688152602`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09267800281762`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.70650167396278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.88396223817544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.90898013440613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.09267800281762`, 9.747078800841289], 
                Complex[133.59417248038324`, -11.477855458956304`]}, 2 -> {
                Complex[108.70650167396278`, -9.88396223817544], 
                Complex[133.99765020516938`, -29.90898013440613]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.14401919979289346`, -1.6744932979244869`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09859333213129`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.957350339052214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224437`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.69882084894036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.094376817050051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.10451221302891`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.09859333213129`, 9.957350339052214], 
                Complex[133.60082688045318`, -11.281953671224437`]}, 2 -> {
                Complex[108.69882084894036`, -10.094376817050051`], 
                Complex[133.9871940493811, -30.10451221302891]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1474039776890379, -1.7899572367170542`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.10405647120578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60701136175388`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.091960884780205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.69161622603707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.29854623837406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9772358765518`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.294132227130056`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "D3", 
             Association[1 -> {
                Complex[108.10405647120578`, 10.161378702488461`], 
                Complex[133.60701136175388`, -11.091960884780205`]}, 2 -> {
                Complex[108.69161622603707`, -10.29854623837406], 
                Complex[133.9772358765518, -30.294132227130056`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.15071895384997447`, -1.907714270156859}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.10911715811447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.359571883156988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.90749116899828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.68483744629073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.496878545347792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.96772509969583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.10911715811447`, 10.359571883156988`], 
                Complex[133.61277584148843`, -10.90749116899828]}, 2 -> {
                Complex[108.68483744629073`, -10.496878545347792`], 
                Complex[133.96772509969583`, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.15396859923393436`, -2.027699990559107}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.11381792433696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.55229611340583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.67844138138928`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.689740019533177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878897`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "D3", 
             Association[1 -> {
                Complex[108.11381792433696`, 10.55229611340583], 
                Complex[133.6181631227231, -10.728198030417946`]}, 2 -> {
                Complex[108.67844138138928`, -10.689740019533177`], 
                Complex[133.9586182712075, -30.657140604878897`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.15715693144747434`, -2.149853955406389}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.11819537768511`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.553768979221006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6723908495012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.11819537768511`, 10.739881627157581`], 
                Complex[133.62321014884253`, -10.553768979221006`]}, 2 -> {
                Complex[108.6723908495012, -10.877460942190025`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.16028757639591618`, -2.2741193050083286`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12228121721019`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6279489975554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.383921024629737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.66665359920384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.00065163185658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.12228121721019`, 10.922627435195428`], 
                Complex[133.6279489975554, -10.383921024629737`]}, 2 -> {
                Complex[108.66665359920384`, -11.060340369657368`], 
                Complex[133.94147109188316`, -31.00065163185658]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.16336381957390245`, -2.400442429949022}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12610304377894`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.100805313420322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6324076760703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.218396911961497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.66120149781838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.238650121699813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.165788586540444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.12610304377894`, 11.100805313420322`], 
                Complex[133.6324076760703, -10.218396911961497`]}, 2 -> {
                Complex[108.66120149781838`, -11.238650121699813`], 
                Complex[133.93336948207866`, -31.165788586540444`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.16638864904527395`, -2.5287726802605572`}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.12968501316938`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.274663157243602`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.056961957121118`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.65600987729266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.32683367761164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.12968501316938`, 11.274663157243602`], 
                Complex[133.6366107628227, -10.056961957121118`]}, 2 -> {
                Complex[108.65600987729266`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.32683367761164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.16936479169851282`, -2.6590621098032443`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13304836657493`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.444427821247727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.899401366335299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.65105700273918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.582531307820613`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91798402862457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.48400175150009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "D3", 
             Association[1 -> {
                Complex[108.13304836657493`, 11.444427821247727`], 
                Complex[133.64057992958777`, -9.899401366335299]}, 2 -> {
                Complex[108.65105700273918`, -11.582531307820613`], 
                Complex[133.91798402862457`, -31.48400175150009]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.17229474402083156`, -2.7912652505388955`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13621186478589`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.61030753764554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028418`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.64632363735394`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "D3", 
             Association[1 -> {
                Complex[108.13621186478589`, 11.61030753764554], 
                Complex[133.64433436948315`, -9.745517953028418]}, 2 -> {
                Complex[108.64632363735394`, -11.748537908691581`], 
                Complex[133.91065826653704`, -31.637490045704617`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.17518079836884226`, -2.9253389123337055`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.13919214603666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.772493987613071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.64179268372514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.910849657658387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "D3", 
             Association[1 -> {
                Complex[108.13919214603666`, 11.772493987613071`], 
                Complex[133.64789115029092`, -9.595130182053303]}, 2 -> {
                Complex[108.64179268372514`, -11.910849657658387`], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.17802506551518604`, -3.0612420046830593`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14200402286717`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.93116408463893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6374488861765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.069643504773634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.934139663861124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.14200402286717`, 11.93116408463893], 
                Complex[133.65126550803504`, -9.448070485548417]}, 2 -> {
                Complex[108.6374488861765, -12.069643504773634`], 
                Complex[133.89665253982204`, -31.934139663861124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.18082949409705407`, -3.198935377355994}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14466072990164`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581651`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6332785822411`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.22508317408877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.077623707476064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.14466072990164`, 12.086481517469753`], 
                Complex[133.65447109241086`, -9.304183805581651]}, 2 -> {
                Complex[108.6332785822411, -12.22508317408877], 
                Complex[133.88994274008317`, -32.077623707476064`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1835958874695507, -3.338381677446076}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.14717413184216`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.62926949396352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803171`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "D3", 
             Association[1 -> {
                Complex[108.14717413184216`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[108.62926949396352`, -12.377320504803171`], 
                Complex[133.8834108897335, -32.21807613513112]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.18632591837581458`, -3.479545220712744}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.149554899004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437188`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.62541055170084`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "D3", 
             Association[1 -> {
                Complex[108.149554899004, 12.387654897960454`], 
                Complex[133.66042381437188`, -9.025364372558764]}, 2 -> {
                Complex[108.62541055170084`, -12.526496621998469`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.18902114176913187`, -3.6223918754222098`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15181265620579`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.533783342972374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.89017343085747`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6216917446064`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.67274296276216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.15181265620579`, 12.533783342972374`], 
                Complex[133.6631920229149, -8.89017343085747]}, 2 -> {
                Complex[108.6216917446064, -12.67274296276216], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.19168300606327193`, -3.766888957164678}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15395610965969`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6181039931489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.15395610965969`, 12.677106047334805`], 
                Complex[133.66583387467648`, -8.757637305564261]}, 2 -> {
                Complex[108.6181039931489, -12.816182179005445`], 
                Complex[133.86477325877706`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.19431286304055106`, -3.9130051333460614`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15599315559707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.81773764516678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313934`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678282`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6146390399284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.956928934660262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.15599315559707`, 12.81773764516678], 
                Complex[133.66835762313934`, -8.627647360678282]}, 2 -> {
                Complex[108.6146390399284, -12.956928934660262`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.19691197660773696`, -4.060710336236788}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15793097365344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.50010185305129`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.61128935576417`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.095090612015015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "D3", 
             Association[1 -> {
                Complex[108.15793097365344`, 12.955785489901633`], 
                Complex[133.67077079273932`, -8.50010185305129]}, 2 -> {
                Complex[108.61128935576417`, -13.095090612015015`], 
                Complex[133.8530533114799, -32.87924061335593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.19948153055963758`, -4.209975683614427}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.15977610747193`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.60804805859196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.00401845710657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.15977610747193`, 13.091350282096835`], 
                Complex[133.67308025959395`, -8.374905338778808]}, 2 -> {
                Complex[108.60804805859196`, -13.230767939566041`], 
                Complex[133.84738105530036`, -33.00401845710657]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.20202263548404176`, -4.3607734061666505`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16153453454044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6752923215574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.25196814386352`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.60490884315497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.364055551814683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.16153453454044`, 13.224526629192964`], 
                Complex[133.6752923215574, -8.25196814386352]}, 2 -> {
                Complex[108.60490884315497`, -13.364055551814683`], 
                Complex[133.8418248696247, -33.12653484477617]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2045363349210163, -4.513076780930337}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16321172691777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.355403546045842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.6018659198306`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.49504248983662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "D3", 
             Association[1 -> {
                Complex[108.16321172691777`, 13.355403546045842`], 
                Complex[133.67741275923174`, -8.131205890824077]}, 2 -> {
                Complex[108.6018659198306, -13.49504248983662], 
                Complex[133.83637862409032`, -33.24687418902981]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.20702361087296595`, -4.66686007013551}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16481270421882`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5989139612213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.623812650126247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.36511602955785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "D3", 
             Association[1 -> {
                Complex[108.16481270421882`, 13.484064903736146`], 
                Complex[133.67944688928384`, -8.012539074167394]}, 2 -> {
                Complex[108.5989139612213, -13.623812650126247`], 
                Complex[133.83103666267402`, -33.36511602955785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.20948538874719702`, -4.822098464901991}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16634207999647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.59604805537121`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118125`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.481335414820634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "D3", 
             Association[1 -> {
                Complex[108.16634207999647`, 13.610589833057873`], 
                Complex[133.68139961119047`, -7.895892678682287]}, 2 -> {
                Complex[108.59604805537121`, -13.750445188118125`], 
                Complex[133.82579375652693`, -33.481335414820634`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21192254180002124`, -4.978768033304188}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16780410246909`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.73505308817024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6832754483489`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.781195835377176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.59326366465744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82064506246513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.595603246147455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.16780410246909`, 13.73505308817024], 
                Complex[133.6832754483489, -7.781195835377176]}, 2 -> {
                Complex[108.59326366465744`, -13.875014881870271`], 
                Complex[133.82064506246513`, -33.595603246147455`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21433589514322193`, -5.136845672377163}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.16920269038908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610141`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5905565895598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.997592460624652`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.707986588641326`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.16920269038908`, 13.857525375128356`], 
                Complex[133.68507858433873`, -7.668381510610141]}, 2 -> {
                Complex[108.5905565895598, -13.997592460624652`], 
                Complex[133.81558608632903`, -33.707986588641326`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21672622936387143`, -5.296309063687721}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17054146472118`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6868128949976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.557386224570173`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58792293663865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.118244902313034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81061265054748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.818548952730794`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.17054146472118`, 13.978073649360802`], 
                Complex[133.6868128949976, -7.557386224570173]}, 2 -> {
                Complex[108.58792293663865`, -14.118244902313034`], 
                Complex[133.81061265054748`, -33.818548952730794`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21909428380237728`, -5.457136632136695}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17182377669673`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.448149795783658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58535909015445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.17182377669673`, 14.096761385616217`], 
                Complex[133.68848197687106`, -7.448149795783658]}, 2 -> {
                Complex[108.58535909015445`, -14.237035703530257`], 
                Complex[133.80572086534596`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.22144075952706999`, -5.619307507696718}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1730527327209`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.213648823436003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.340615108758886`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58286168684978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.354025125032765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.1730527327209, 14.213648823436003`], 
                Complex[133.69008917251034`, -7.340615108758886]}, 2 -> {
                Complex[108.58286168684978`, -14.354025125032765`], 
                Complex[133.80090710312302`, -34.03444852404852]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.22376632203935287`, -5.782801489821686}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17423121654305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.58042759348385`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.796167975588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.13989716530638`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.17423121654305`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[108.58042759348385`, -14.469270415426752`], 
                Complex[133.796167975588, -34.13989716530638]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.22607160373848956`, -5.947599014293189}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17536190903549`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.57805388677225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.24374810132099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.17536190903549`, 14.442248908399579`], 
                Complex[133.69313013823356`, -7.130436575951704]}, 2 -> {
                Complex[108.57805388677225`, -14.582826015372698`], 
                Complex[133.7915003133146, -34.24374810132099]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2283572061706991, -6.11368112229334}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17644730588044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.554067776191946`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5757378354325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.694743744345217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78690114741266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "D3", 
             Association[1 -> {
                Complex[108.17644730588044`, 14.554067776191946`], 
                Complex[133.69456951471145`, -7.027692013672599]}, 2 -> {
                Complex[108.5757378354325, -14.694743744345217`], 
                Complex[133.78690114741266`, -34.34605047512348]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.23062370208697303`, -6.281029431515847}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.17748973342061`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6959582519888`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.926447421338382`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.57347688407852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7823676930617`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.44685110695745`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.17748973342061`, 14.664299144668318`], 
                Complex[133.6959582519888, -6.926447421338382]}, 2 -> {
                Complex[108.57347688407852`, -14.805072971738818`], 
                Complex[133.7823676930617, -34.44685110695745]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.23287163732754834`, -6.449626109145779}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1784913628932`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.772990071771156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5712686387431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.913860773896735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "D3", 
             Association[1 -> {
                Complex[108.1784913628932, 14.772990071771156`], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[108.5712686387431, -14.913860773896735`], 
                Complex[133.77789733468603`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.23510153255094224`, -6.619453846556052}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.179454223239`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.880185467237435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6985931278124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.728281700596781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5691108538372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.64412369206375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "D3", 
             Association[1 -> {
                Complex[108.179454223239, 14.880185467237435`], 
                Complex[133.6985931278124, -6.728281700596781]}, 2 -> {
                Complex[108.5691108538372, -15.021152078455044`], 
                Complex[133.7734876125809, -34.64412369206375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2373138848233225, -6.7904958355826075`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18038021265114`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183253`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5670014203799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.1269897972341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76913621082284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.740678951509224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.18038021265114`, 14.985928225471847`], 
                Complex[133.69984356428586`, -6.631277315183253]}, 2 -> {
                Complex[108.5670014203799, -15.1269897972341], 
                Complex[133.76913621082284`, -34.740678951509224`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.23950916908145814`, -6.962735746254733}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18127110900694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.535606143784339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5649383553552`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.231414948770265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7648409463208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "D3", 
             Association[1 -> {
                Complex[108.18127110900694`, 15.090259348061178`], 
                Complex[133.70105197999624`, -6.535606143784339]}, 2 -> {
                Complex[108.5649383553552, -15.231414948770265`], 
                Complex[133.7648409463208, -34.83589932329275]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24168783948118744`, -7.136157705867635}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18212857930814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.19321805690089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764478`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5629197920703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.33446677145913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18212857930814`, 15.19321805690089], 
                Complex[133.70222021135814`, -6.441230995764478]}, 2 -> {
                Complex[108.5629197920703, -15.33446677145913], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24385033064226036`, -7.310746279295341}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18295418823847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.294841898799707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010092`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.56094397140522`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.18295418823847`, 15.294841898799707`], 
                Complex[133.7033499865708, -6.348116269010092]}, 2 -> {
                Complex[108.56094397140522`, -15.436182828175927`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24599705879919043`, -7.486486450451405}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18374940593408`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.395166842334245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55900923385818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.536599103145393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.18374940593408`, 15.395166842334245`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[108.55900923385818`, -15.536599103145393`], 
                Complex[133.75227193555398`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24812842286675618`, -7.663363604813004}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18451561505084`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.494227367644926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55711401230226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74818171646749`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.20415291705668`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.18451561505084`, 15.494227367644926`], 
                Complex[133.70550058771096`, -6.165533069493568]}, 2 -> {
                Complex[108.55711401230226`, -15.635750091752186`], 
                Complex[133.74818171646749`, -35.20415291705668]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2502448054271156, -7.841363512931377}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18525411720202`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.0760005419752705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.55525682537882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.73366888391076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.29322661291981`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.18525411720202`, 15.592056549792124`], 
                Complex[133.70652439769495`, -6.0760005419752705`]}, 2 -> {
                Complex[108.55525682537882`, -15.73366888391076], 
                Complex[133.74413839370672`, -35.29322661291981]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2523465736465482, -8.020472314858761}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18596613883142`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7075157324069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.987600173789712`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5534362714641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.83038724155129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18596613883142`, 15.688686136228501`], 
                Complex[133.7075157324069, -5.987600173789712]}, 2 -> {
                Complex[108.5534362714641, -15.83038724155129], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2544340801266287, -8.200676505427285}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18665283657926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.78414661888746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.900303054034376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5516510231478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.92593567072055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7361862517464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.468001829363644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "D3", 
             Association[1 -> {
                Complex[108.18665283657926`, 15.78414661888746], 
                Complex[133.70847588612014`, -5.900303054034376]}, 2 -> {
                Complex[108.5516510231478, -15.92593567072055], 
                Complex[133.7361862517464, -35.468001829363644`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.25650766369651024`, -8.381962920321296}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18731530219162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54989982217656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "D3", 
             Association[1 -> {
                Complex[108.18731530219162`, 15.878467301338123`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[108.54989982217656`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.25856765015041105`, -8.564318722889137}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18795456701847`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.97167636141339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7103074851951`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.728908493102022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54818147481403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.113638886891636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "D3", 
             Association[1 -> {
                Complex[108.18795456701847`, 15.97167636141339], 
                Complex[133.7103074851951, -5.728908493102022]}, 2 -> {
                Complex[108.54818147481403`, -16.113638886891636`], 
                Complex[133.72840390066762`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.26061435293559043`, -8.747731391644937}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18857160613997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678427`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.644758632851147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54649484757873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "D3", 
             Association[1 -> {
                Complex[108.18857160613997`, 16.063800909678427`], 
                Complex[133.71118119033966`, -5.644758632851147]}, 2 -> {
                Complex[108.54649484757873`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2626480737939687, -8.93218870841477}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18916734215705`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.15486704407236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71202824232208`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54483886332335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.29699990520363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7207808416868`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.18916734215705`, 16.15486704407236], 
                Complex[133.71202824232208`, -5.561607075648972]}, 2 -> {
                Complex[108.54483886332335`, -16.29699990520363], 
                Complex[133.7207808416868, -35.80483537920644]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2646691033621664, -9.117678747085655}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.18974264867768`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.244899901024702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54321249762363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.38711678498225`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7170260351905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "D3", 
             Association[1 -> {
                Complex[108.18974264867768`, 16.244899901024702`], 
                Complex[133.71284963153286`, -5.479429991022457]}, 2 -> {
                Complex[108.54321249762363`, -16.38711678498225], 
                Complex[133.7170260351905, -35.88654323957749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2666777217321794, -9.30418986291825}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19029835352708`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.333923703320405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7136462989116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.398204415298551`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54161477544838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754885003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.96729817997293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "D3", 
             Association[1 -> {
                Complex[108.19029835352708`, 16.333923703320405`], 
                Complex[133.7136462989116, -5.398204415298551]}, 2 -> {
                Complex[108.54161477544838`, -16.476223863094223`], 
                Complex[133.71330754885003`, -35.96729817997293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.26867419897661193`, -9.491710682388241}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19083524170729`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.421961804962734`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54004476808421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422497`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702874`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.19083524170729`, 16.421961804962734`], 
                Complex[133.71441913905534`, -5.317908209063045]}, 2 -> {
                Complex[108.54004476808421`, -16.564344505422497`], 
                Complex[133.70962432476173`, -36.04712235702874]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2706587956404576, -9.680230093522923}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19135405812926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.509036733260594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53850159029454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.651501250875818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216768`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267094`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19135405812926`, 16.509036733260594`], 
                Complex[133.71516900309246`, -5.238520017249023]}, 2 -> {
                Complex[108.53850159029454`, -16.651501250875818`], 
                Complex[133.70597535216768`, -36.12603714267094]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.27263176320283833`, -9.869737236703003}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1918555101365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53698439768804`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.737715850917162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7023596646825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.20406316160481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.1918555101365, 16.595170228347317`], 
                Complex[133.71589670134114`, -5.160019231659067]}, 2 -> {
                Complex[108.53698439768804`, -16.737715850917162`], 
                Complex[133.7023596646825, -36.20406316160481]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2745933445100377, -10.060221495901107`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19234026984024`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.716603005773`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53549238428282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.823009306709668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69877633772265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.28122032654659`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "D3", 
             Association[1 -> {
                Complex[108.19234026984024`, 16.680383280319464`], 
                Complex[133.716603005773, -5.082385955742662]}, 2 -> {
                Complex[108.53549238428282`, -16.823009306709668`], 
                Complex[133.69877633772265`, -36.28122032654659]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2765437741823291, -10.251672490331057`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19280897628119`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465139`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53402478024628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.907401904057913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.357527871365804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19280897628119`, 16.764696164168562`], 
                Complex[133.71728865229744`, -5.005600971465139]}, 2 -> {
                Complex[108.53402478024628`, -16.907401904057913`], 
                Complex[133.6952244861178, -36.357527871365804`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.27848327899718583`, -10.44408006648349}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19326223743363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53258084979647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.990913246296873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19326223743363`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118652]}, 2 -> {
                Complex[108.53258084979647`, -16.990913246296873`], 
                Complex[133.69170326188944`, -36.43300438228252]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.28041207824884395`, -10.637434290525537`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19370063206468`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.53115988925272`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.073562285278406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68821185218454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.5076678272615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "D3", 
             Association[1 -> {
                Complex[108.19370063206468`, 16.93069914732912], 
                Complex[133.71860074752377`, -4.854502212938122]}, 2 -> {
                Complex[108.53115988925272`, -17.073562285278406`], 
                Complex[133.68821185218454`, -36.5076678272615]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.28233038408802713`, -10.831725441043279`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19412471146116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52976122522162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.15536735058449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.581535583725454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "D3", 
             Association[1 -> {
                Complex[108.19412471146116`, 17.012426507651814`], 
                Complex[133.7192285060807, -4.780153123396222]}, 2 -> {
                Complex[108.52976122522162`, -17.15536735058449], 
                Complex[133.68474947734978`, -36.581535583725454`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2842384018414066, -11.026944002107953`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19453500103484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997942`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52838421290734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19453500103484`, 17.093328278637614`], 
                Complex[133.71983822997942`, -4.70658164106197]}, 2 -> {
                Complex[108.52838421290734`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2861363303134965, -11.223080656647234`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19493200181606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.17342161683146`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7204305038047`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.633771506916524`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52702823453782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353259`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19493200181606`, 17.17342161683146], 
                Complex[133.7204305038047, -4.633771506916524]}, 2 -> {
                Complex[108.52702823453782`, -17.31651593099674], 
                Complex[133.67790886901935`, -36.72695074353259]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2880243620712406, -11.420126280104967`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19531619184464`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.252723134903174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52569269789578`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19531619184464`, 17.252723134903174`], 
                Complex[133.72100588678245`, -4.561706978028422]}, 2 -> {
                Complex[108.52569269789578`, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2899026837130805, -11.618071934373685`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1956880274665`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.3312489248945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7215649141643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52437703494735`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.474494188608475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6711757983389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.1956880274665, 17.3312489248945], 
                Complex[133.7215649141643, -4.490372805498023]}, 2 -> {
                Complex[108.52437703494735`, -17.474494188608475`], 
                Complex[133.6711757983389, -36.86937802828386]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.29177147612341514`, -11.816908861984686`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19604794454303`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.40901458021521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588028`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52308070056031`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.55233439603628`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.9395090861031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "D3", 
             Association[1 -> {
                Complex[108.19604794454303`, 17.40901458021521], 
                Complex[133.72210809852083`, -4.419754213588028]}, 2 -> {
                Complex[108.52308070056031`, -17.55233439603628], 
                Complex[133.66784794577546`, -36.9395090861031]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.29363091471284974`, -12.016628480542341`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19639635958045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.486035216469375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52180317130546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.62942898113872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.00893768620429`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19639635958045`, 17.486035216469375`], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[108.52180317130546`, -17.62942898113872], 
                Complex[133.66454505465833`, -37.00893768620429]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.29548116964636506`, -12.217222377389476`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19673367078482`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.56232549118666`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.52054394433422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.705792610098083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19673367078482`, 17.56232549118666], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[108.52054394433422`, -17.705792610098083`], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2973224060587256, -12.418682304491888`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19706025904894`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.63789962252805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379098`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51930253632736`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.781439509544896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.145742698655766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19706025904894`, 17.63789962252805], 
                Complex[133.72364740379098`, -4.212050853878544]}, 2 -> {
                Complex[108.51930253632736`, -17.781439509544896`], 
                Complex[133.65801181266102`, -37.145742698655766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.29915478425928654`, -12.621000173530486`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1973764888756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.7127714070303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061905`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5180784825091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.856383484307454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294622`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.213145677616154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "D3", 
             Association[1 -> {
                Complex[108.1973764888756, 17.7127714070303], 
                Complex[133.7241319288729, -4.144155620061905]}, 2 -> {
                Complex[108.5180784825091, -17.856383484307454`], 
                Complex[133.65478034294622`, -37.213145677616154`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.300978459925517, -12.8241680511906}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1976827092426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996306`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51687133572213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.1976827092426, 17.786954236448402`], 
                Complex[133.72460287329903`, -4.076908528996306]}, 2 -> {
                Complex[108.51687133572213`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3027935842876559, -13.028178154638468`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19797925441311`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.860461113751516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.010297263090177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51568066555893`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64838505795817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.346016090185714`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "D3", 
             Association[1 -> {
                Complex[108.19797925441311`, 17.860461113751516`], 
                Complex[133.72506063642794`, -4.010297263090177]}, 2 -> {
                Complex[108.51568066555893`, -18.004215870320177`], 
                Complex[133.64838505795817`, -37.346016090185714`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3046003043031362, -13.233022847175544`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19826644469612`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.933304668323515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.944309859257121`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51450605754546`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.077129929660614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "D3", 
             Association[1 -> {
                Complex[108.19826644469612`, 17.933304668323515`], 
                Complex[133.72550560195975`, -3.944309859257121]}, 2 -> {
                Complex[108.51450605754546`, -18.077129929660614`], 
                Complex[133.64522023907952`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3063987628226812, -13.438694634061715`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19854458715977`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.005497170415737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8789346951999804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5133471123735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19854458715977`, 18.005497170415737`], 
                Complex[133.72593813870844`, -3.8789346951999804`]}, 2 -> {
                Complex[108.5133471123735, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.30818909874838596`, -13.645186158499385`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19881397630171`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.077050544896363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7263586013282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8141604763620265`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51220344517813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.22101518415878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6389538683734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.540662551100866`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.19881397630171`, 18.077050544896363`], 
                Complex[133.7263586013282, -3.8141604763620265`]}, 2 -> {
                Complex[108.51220344517813`, -18.22101518415878], 
                Complex[133.6389538683734, -37.540662551100866`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.30997144718384106`, -13.85249019777034}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19907489467873`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.147976384337575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.7499762235063514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.51107468485743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208483`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.19907489467873`, 18.147976384337575`], 
                Complex[133.72676733099715`, -3.7499762235063514`]}, 2 -> {
                Complex[108.51107468485743`, -18.292009911552345`], 
                Complex[133.6358514127178, -37.60434783208483]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3117459395770368, -14.060599659518445`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19932761349929`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.5099604734313`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6327688660871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.19932761349929`, 18.21828596147894], 
                Complex[133.72716465606135`, -3.686371260886986]}, 2 -> {
                Complex[108.5099604734313, -18.362387852255672`], 
                Complex[133.6327688660871, -37.66745274304553]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.31351270385655994`, -14.26950757817093}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.1995723931808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.287990241102797`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.6233352049778063`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50886046543684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.432159978084307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322926`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.72998767832449`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.1995723931808, 18.287990241102797`], 
                Complex[133.7275508926416, -3.6233352049778063`]}, 2 -> {
                Complex[108.50886046543684`, -18.432159978084307`], 
                Complex[133.62970581322926`, -37.72998767832449]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.31527186456133904`, -14.47920711149191}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.19980948387447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.357099891355087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72792634520576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.5608579537275844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50777432735788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.50133696407843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.79196275059988`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "D3", 
             Association[1 -> {
                Complex[108.19980948387447`, 18.357099891355087`], 
                Complex[133.72792634520576`, -3.5608579537275844`]}, 2 -> {
                Complex[108.50777432735788`, -18.50133696407843], 
                Complex[133.62666185240192`, -37.79196275059988]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.31702354296419344`, -14.689691537261904`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20003912596002`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50670173708629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.56992919930402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20003912596002`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[108.50670173708629`, -18.56992919930402], 
                Complex[133.62363659478484`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3187678571898118, -14.900954250077849`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20026155051174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437457`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50564238341306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.637946797159632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62062966392398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.20026155051174`, 18.493576557437457`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[108.50564238341306`, -18.637946797159632`], 
                Complex[133.62062966392398`, -37.91427240958484]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3205049223271885, -15.112988758267633`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20047697973848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.560963521110715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581249`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50459596554721`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.70539960521599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6176406952053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "D3", 
             Association[1 -> {
                Complex[108.20047697973848`, 18.560963521110715`], 
                Complex[133.72899087982017`, -3.376682017581249]}, 2 -> {
                Complex[108.50459596554721`, -18.70539960521599], 
                Complex[133.6176406952053, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3222348505373418, -15.325788680914393`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20068562739868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.627795770329772`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50356219266067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6146693353564`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.0344573662522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "D3", 
             Association[1 -> {
                Complex[108.20068562739868`, 18.627795770329772`], 
                Complex[133.72932602622456`, -3.316344244925606]}, 2 -> {
                Complex[108.50356219266067`, -18.772297214614053`], 
                Complex[133.6146693353564, -38.0344573662522]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.32395775115531933`, -15.539347744985477`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20088769919248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.69408264253407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72965175404684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50254078345752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.093775647619346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.20088769919248`, 18.69408264253407], 
                Complex[133.72965175404684`, -3.25651864598262]}, 2 -> {
                Complex[108.50254078345752`, -18.838648969045263`], 
                Complex[133.61171524197405`, -38.093775647619346`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3256737307887363, -15.75365978256152}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20108339313214`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1971966078757674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.50153146576623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60877808307634`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.152589369857765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20108339313214`, 18.75983323641723], 
                Complex[133.72996830818997`, -3.1971966078757674`]}, 2 -> {
                Complex[108.50153146576623`, -18.904463973336476`], 
                Complex[133.60877808307634`, -38.152589369857765`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.32738289341136806`, -15.968718728161225`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20127289989236`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.825056420134477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.1383697364634457`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.500533976153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.9697511016604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "D3", 
             Association[1 -> {
                Complex[108.20127289989236`, 18.825056420134477`], 
                Complex[133.73027592511528`, -3.1383697364634457`]}, 2 -> {
                Complex[108.500533976153, -18.9697511016604], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3290853404525649, -16.184518616157604`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20145640314155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.889760839155507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0800298488845854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49954805955541`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.03451900539132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.268736539794915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "D3", 
             Association[1 -> {
                Complex[108.20145640314155`, 18.889760839155507`], 
                Complex[133.73057483320838`, -3.0800298488845854`]}, 2 -> {
                Complex[108.49954805955541`, -19.03451900539132], 
                Complex[133.60295329038405`, -38.268736539794915`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.33078117088336967`, -16.401053578281907`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20163407985537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.95395492378105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49857346893486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.098776120624542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.3260861674659`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "D3", 
             Association[1 -> {
                Complex[108.20163407985537`, 18.95395492378105], 
                Complex[133.7308652531255, -3.0221689664234646`]}, 2 -> {
                Complex[108.49857346893486`, -19.098776120624542`], 
                Complex[133.60006504101256`, -38.3260861674659]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.33247048129814516`, -16.61831784121145}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20180610061372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.01764689634064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.964779307677034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49760996494675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.162530675376825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992765`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20180610061372`, 19.01764689634064], 
                Complex[133.73114739812223`, -2.964779307677034]}, 2 -> {
                Complex[108.49760996494675`, -19.162530675376825`], 
                Complex[133.59719249422423`, -38.38296360992765]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3341533659936431, -16.83630572423766}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20197262988198`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.08084477808771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9078532820094942`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4966573156271`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.22579069648413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.43937646664462`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20197262988198`, 19.08084477808771], 
                Complex[133.73142147436542`, -2.9078532820094942`]}, 2 -> {
                Complex[108.4966573156271, -19.22579069648413], 
                Complex[133.59433536417916`, -38.43937646664462]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.33582991704392384`, -17.055011637011138`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2021338262776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.1435563958075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794807`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49571529609509`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "D3", 
             Association[1 -> {
                Complex[108.2021338262776, 19.1435563958075], 
                Complex[133.73168768122898`, -2.8513834832794807`]}, 2 -> {
                Complex[108.49571529609509`, -19.288564016212078`], 
                Complex[133.59149337320665`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3375002243727465, -17.274430077360556`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.202289842823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.205789388152027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.795362683826273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49478368827032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.350858278593414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "D3", 
             Association[1 -> {
                Complex[108.202289842823, 19.205789388152027`], 
                Complex[133.73194621157512`, -2.795362683826273]}, 2 -> {
                Complex[108.49478368827032`, -19.350858278593414`], 
                Complex[133.58866625149176`, -38.55083790353878]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3391643758227474, -17.494555629182273`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20244082718541`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.267551211715737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287021123`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49386228060364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.60590078328636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20244082718541`, 19.267551211715737`], 
                Complex[133.73219725202154`, -2.7397838287021123`]}, 2 -> {
                Complex[108.49386228060364`, -19.41268094550608], 
                Complex[133.58585373677664`, -38.60590078328636]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34082245722160565`, -17.71538296039771}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20258692190454`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.684640030138418`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49295086782132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.66052768773749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "D3", 
             Association[1 -> {
                Complex[108.20258692190454`, 19.328849146864798`], 
                Complex[133.73244098319515`, -2.684640030138418]}, 2 -> {
                Complex[108.49295086782132`, -19.47403930250476], 
                Complex[133.58305557407587`, -38.66052768773749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3424745524461059, -17.93690682097588}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20272826460884`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73267757997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49204925068156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.534940464417765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.714725350944136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "D3", 
             Association[1 -> {
                Complex[108.20272826460884`, 19.389690303331637`], 
                Complex[133.73267757997374`, -2.6299245622347733`]}, 2 -> {
                Complex[108.49204925068156`, -19.534940464417765`], 
                Complex[133.58027151540554`, -38.714725350944136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34412074348270494`, -18.15912204101864}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20286498822084`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.49115723574232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.595391380720887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "D3", 
             Association[1 -> {
                Complex[108.20286498822084`, 19.45008162558661], 
                Complex[133.73290721171554`, -2.5756308558594796`]}, 2 -> {
                Complex[108.49115723574232`, -19.595391380720887`], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34576111048673397`, -18.382023528905716`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20299722115244`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.5100298979971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5217524937519045`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4902746351405`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.655398840698574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.82185911025591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "D3", 
             Association[1 -> {
                Complex[108.20299722115244`, 19.5100298979971], 
                Complex[133.73313004247822`, -2.5217524937519045`]}, 2 -> {
                Complex[108.4902746351405, -19.655398840698574`], 
                Complex[133.57474475168777`, -38.82185911025591]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34739573183861694`, -18.605606269497322`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20312508749056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.569541749784385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.4682832058167925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4894012663812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.714969478402878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939812`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20312508749056`, 19.569541749784385`], 
                Complex[133.73334623122685`, -2.4682832058167925`]}, 2 -> {
                Complex[108.4894012663812, -19.714969478402878`], 
                Complex[133.57200158341104`, -38.87480790939812]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34902468419778643`, -18.82986532239262}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20324870717361`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.628623659787674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7335559320325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.4152168646016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48853695213684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260374`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20324870717361`, 19.628623659787674`], 
                Complex[133.7335559320325, -2.4152168646016]}, 2 -> {
                Complex[108.48853695213684`, -19.774109777419554`], 
                Complex[133.5692715922459, -38.92735288260374]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.35064804255503645`, -19.054795820240916`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20336819615972`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3625474809482334`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4876815200556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.83282607545025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156517`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.97950002657635`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20336819615972`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.3625474809482334`]}, 2 -> {
                Complex[108.4876815200556, -19.83282607545025], 
                Complex[133.56655456156517`, -38.97950002657635]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3522658802826584, -19.28039296710447}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20348366658654`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.310269199811078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48683480257834`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "D3", 
             Association[1 -> {
                Complex[108.20348366658654`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.310269199811078]}, 2 -> {
                Complex[108.48683480257834`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3538782691821609, -19.506652036870456`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20359522692382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.803352366724106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48599663676426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.949011316216147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "D3", 
             Association[1 -> {
                Complex[108.20359522692382`, 19.803352366724106`], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[108.48599663676426`, -19.949011316216147`], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3554852795311092, -19.733568371710163`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20370298211841`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.86077644703169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2068631714772557`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48516686412384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.006492243769536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5584791492266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20370298211841`, 19.86077644703169], 
                Complex[133.73433277630323`, -2.2068631714772557`]}, 2 -> {
                Complex[108.48516686412384`, -20.006492243769536`], 
                Complex[133.5584791492266, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3570869801274341, -19.96113738058409}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20380703373283`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.917800878367114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48434533045962`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.063573147982027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20380703373283`, 19.917800878367114`], 
                Complex[133.73451218992713`, -2.155724349292754]}, 2 -> {
                Complex[108.48434533045962`, -20.063573147982027`], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.35868343833234917`, -20.189354537790823`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20390748007702`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48353188571376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.120259700008994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583597`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20390748007702`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[108.48353188571376`, -20.120259700008994`], 
                Complex[133.55315661583597`, -39.23446901800291]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36027472011184614`, -20.418215381558277`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20400441633439`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.030673339891976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73485417294913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.05454829869176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48272638382235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "D3", 
             Association[1 -> {
                Complex[108.20400441633439`, 20.030673339891976`], 
                Complex[133.73485417294913`, -2.05454829869176]}, 2 -> {
                Complex[108.48272638382235`, -20.176557449202853`], 
                Complex[133.55051310011328`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3618608900765139, -20.64771551267563}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20409793468184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73501698803878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.004500698579303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48192868257608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.23247182662352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "D3", 
             Association[1 -> {
                Complex[108.20409793468184`, 20.086532342147557`], 
                Complex[133.73501698803878`, -2.004500698579303]}, 2 -> {
                Complex[108.48192868257608`, -20.23247182662352], 
                Complex[133.54788117531717`, -39.333867334968325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36344201151990774`, -20.87785059316462}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20418812440447`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7351745101014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48113864348676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5452606647034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "D3", 
             Association[1 -> {
                Complex[108.20418812440447`, 20.14201364645422], 
                Complex[133.7351745101014, -1.9548066511051871`]}, 2 -> {
                Complex[108.48113864348676`, -20.288008148422218`], 
                Complex[133.5452606647034, -39.3830324278985]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.365018146455526, -21.10861634498868}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.204275072005`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.19712245331401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.905461241186206`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.48035613165965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.204275072005, 20.19712245331401], 
                Complex[133.73532685336215`, -1.905461241186206]}, 2 -> {
                Complex[108.48035613165965`, -20.343171619103266`], 
                Complex[133.54265139579024`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3665893556524793, -21.340008548798576`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20435886130839`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47958101567112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39796733467009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.48031909408175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20435886130839`, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608582`]}, 2 -> {
                Complex[108.47958101567112`, -20.39796733467009], 
                Complex[133.54005320021983`, -39.48031909408175]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36815569867002296`, -21.572023042713287`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20443957356183`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.306242837557605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849098944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47881316745149`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.452400285659856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "D3", 
             Association[1 -> {
                Complex[108.20443957356183`, 20.306242837557605`], 
                Complex[133.73561644435446`, -1.8077971849098944`]}, 2 -> {
                Complex[108.47881316745149`, -20.452400285659856`], 
                Complex[133.53746591362486`, -39.52845020484534]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36971723389081035`, -21.80465572113478}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20451728753017`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47805246217267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.50647536007101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.57624602845285`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "D3", 
             Association[1 -> {
                Complex[108.20451728753017`, 20.360264285794972`], 
                Complex[133.73575390485038`, -1.7594692110781693`]}, 2 -> {
                Complex[108.47805246217267`, -20.50647536007101], 
                Complex[133.53488937550063`, -39.57624602845285]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37127401855261155`, -22.037902533595712`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20459207958739`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931499`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47729877814062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.560197346190265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.62371109181686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20459207958739`, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931499`]}, 2 -> {
                Complex[108.47729877814062`, -20.560197346190265`], 
                Complex[133.53232342908268`, -39.62371109181686]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3728261087797762, -22.271759483638604`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20466402380387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763471`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47655199669187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5297679212286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20466402380387`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763471`]}, 2 -> {
                Complex[108.47655199669187`, -20.613570935319654`], 
                Complex[133.5297679212286, -39.67084982986853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3743735596126214, -22.50622262772579}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20473319203012`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7361381620127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47581200209461`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.66660072441222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658806003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20473319203012`, 20.52023078674261], 
                Complex[133.7361381620127, -1.6164475267435492`]}, 2 -> {
                Complex[108.47581200209461`, -20.66660072441222], 
                Complex[133.527222702305, -39.71766658806003]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37591642503662115`, -22.741288074178605`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20479965397669`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47507868145351`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.719291218615805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52468762607876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.76416562477972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "D3", 
             Association[1 -> {
                Complex[108.20479965397669`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[108.47507868145351`, -20.719291218615805`], 
                Complex[133.52468762607876`, -39.76416562477972]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37745475801023076`, -22.97695198214534}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20486347729089`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.62517263025513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47435192461855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "D3", 
             Association[1 -> {
                Complex[108.20486347729089`, 20.62517263025513], 
                Complex[133.73637185511262`, -1.5226917500597814`]}, 2 -> {
                Complex[108.47435192461855`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37898861049154675`, -23.21321056059665}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20492472763014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.67714604460236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73648223230828`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4762789595872334`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47363162409722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.82367189859418`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5196473331636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.8562271459694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "D3", 
             Association[1 -> {
                Complex[108.20492472763014`, 20.67714604460236], 
                Complex[133.73648223230828`, -1.4762789595872334`]}, 2 -> {
                Complex[108.47363162409722`, -20.82367189859418], 
                Complex[133.5196473331636, -39.8562271459694]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3805180334648526, -23.450060067347433`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20498346873225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.728793469886888`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222482`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47291767497042`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.87537065735924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5171418400885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.90179773251957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "D3", 
             Association[1 -> {
                Complex[108.20498346873225`, 20.728793469886888`], 
                Complex[133.7365884127948, -1.4301708674222482`]}, 2 -> {
                Complex[108.47291767497042`, -20.87537065735924], 
                Complex[133.5171418400885, -39.90179773251957]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38204307696543083`, -23.68749680810474}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20503976248285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.78011906446158`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7366904808514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.384363546521321`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47220997481152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.926747271733447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5146459367488`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.94706680604751`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "D3", 
             Association[1 -> {
                Complex[108.20503976248285`, 20.78011906446158], 
                Complex[133.7366904808514, -1.384363546521321]}, 2 -> {
                Complex[108.47220997481152`, -20.926747271733447`], 
                Complex[133.5146459367488, -39.94706680604751]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3835637901039206, -23.925517135540307`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20509366897993`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.338853145910491`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47150842360853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5121594924219`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.99203822311736`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "D3", 
             Association[1 -> {
                Complex[108.20509366897993`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.338853145910491]}, 2 -> {
                Complex[108.47150842360853`, -20.977805823117308`], 
                Complex[133.5121594924219, -39.99203822311736]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38508022109024864`, -24.164117448387408`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2051452465958`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.88182099570279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714519`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47081292368944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02855031468357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5096823792151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.036715766120224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "D3", 
             Association[1 -> {
                Complex[108.2051452465958, 20.88182099570279], 
                Complex[133.73688260585357`, -1.293635888714519]}, 2 -> {
                Complex[108.47081292368944`, -21.02855031468357], 
                Complex[133.5096823792151, -40.036715766120224`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38659241725588345`, -24.40329419056071}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20519455203652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7369728206324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2487080702500926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.47012337965012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20519455203652`, 20.9322052560464], 
                Complex[133.7369728206324, -1.2487080702500926`]}, 2 -> {
                Complex[108.47012337965012`, -21.078984673387104`], 
                Complex[133.50721447198237`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3881004250763169, -24.643043850298895`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20524164039881`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9822835369875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878367`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803769`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46943969828529`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12911275191011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20524164039881`, 20.9822835369875], 
                Complex[133.73705923878367`, -1.2040660561803769`]}, 2 -> {
                Complex[108.46943969828529`, -21.12911275191011], 
                Complex[133.50475564824438`, -40.12520400001159]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3896042901923522, -24.88336295932909}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20528656522481`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.032059615714736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46876178852183`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20528656522481`, 21.032059615714736`], 
                Complex[133.7371419342688, -1.1597062807288658`]}, 2 -> {
                Complex[108.46876178852183`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.39110405743048204`, -25.124248092052156`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20532937855462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73722097918034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1156252449499`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46808956135473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.22846511901765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "D3", 
             Association[1 -> {
                Complex[108.20532937855462`, 21.081537198896893`], 
                Complex[133.73722097918034`, -1.1156252449499]}, 2 -> {
                Complex[108.46808956135473`, -21.22846511901765], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3925997708233808, -25.365695864748744`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2053701309766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.130719924447273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4674229297853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "D3", 
             Association[1 -> {
                Complex[108.2053701309766, 21.130719924447273`], 
                Complex[133.73729644380091`, -1.071819515054031]}, 2 -> {
                Complex[108.4674229297853, -21.277696758252308`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.394091473629004, -25.607702934805076`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20540887167593`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4667618087618`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "D3", 
             Association[1 -> {
                Complex[108.20540887167593`, 21.179611363233047`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[108.4667618087618, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3955792083494032, -25.850265999957674`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20544564848103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730893`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46610611512213`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.375288818906036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.34153309171082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "D3", 
             Association[1 -> {
                Complex[108.20544564848103`, 21.228215020730893`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[108.46610611512213`, -21.375288818906036`], 
                Complex[133.49259367239995`, -40.34153309171082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3970630167490583, -26.09338179755696}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20548050790832`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.276534338631635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983291`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46545576753864`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.38398750984297`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20548050790832`, 21.276534338631635`], 
                Complex[133.73750203277484`, -0.9420207663983291]}, 2 -> {
                Complex[108.46545576753864`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.38398750984297]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3985429398723852, -26.33704710384877}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20551349520517`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.32457269639543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73756384480689`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8992831695357317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46481068646492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.47174232754069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4877884573571`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "D3", 
             Association[1 -> {
                Complex[108.20551349520517`, 21.32457269639543], 
                Complex[133.73756384480689`, -0.8992831695357317]}, 2 -> {
                Complex[108.46481068646492`, -21.47174232754069], 
                Complex[133.4877884573571, -40.4261790532468]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4000190180611298, -26.58125873327334}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20554465439125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273047`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4641707940845`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.519550543179957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.468110858122984`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "D3", 
             Association[1 -> {
                Complex[108.20554465439125`, 21.372333412759417`], 
                Complex[133.73762240273047`, -0.8568046319064742]}, 2 -> {
                Complex[108.4641707940845, -21.519550543179957`], 
                Complex[133.4853981881505, -40.468110858122984`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40149129097065384`, -26.826013537781037`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2055740282982`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.41981974719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7376777670912`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8145820782986526`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4635360142614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.56708410244112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48301600828688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.509786004466065`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.2055740282982, 21.41981974719948], 
                Complex[133.7376777670912, -0.8145820782986526]}, 2 -> {
                Complex[108.4635360142614, -21.56708410244112], 
                Complex[133.48301600828688`, -40.509786004466065`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40295979758610656`, -27.071308406164956`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20560165860788`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.46703490134794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003713`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46290627249242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20560165860788`, 21.46703490134794], 
                Complex[133.73772999698096`, -0.7726124883003713]}, 2 -> {
                Complex[108.46290627249242`, -21.61434620967062], 
                Complex[133.48064181814095`, -40.55120751741088]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4044245762382843, -27.317140263408923`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2056275858894`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.513982020369063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.462281495861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.66134001270741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.2056275858894, 21.513982020369063`], 
                Complex[133.73777915008168`, -0.7308928949944189]}, 2 -> {
                Complex[108.462281495861, -21.66134001270741], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40588566461849496`, -27.563506070051293`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20565184963387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927808`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.46166161299293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.708068604217775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.6333014771445`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "D3", 
             Association[1 -> {
                Complex[108.20565184963387`, 21.560664194292517`], 
                Complex[133.73782528270675`, -0.6894203836927808]}, 2 -> {
                Complex[108.46166161299293`, -21.708068604217775`], 
                Complex[133.47591701822185`, -40.6333014771445]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40734309979347927`, -27.810402821563493`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20567448828915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4610465540133`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.673979711466146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "D3", 
             Association[1 -> {
                Complex[108.20567448828915`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[108.4610465540133, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.673979711466146`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40879691821953656`, -28.057827547743443`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20569553929232`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4604362505051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.800742255195576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.7144158898782`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20569553929232`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[108.4604362505051, -21.800742255195576`], 
                Complex[133.47122302955884`, -40.7144158898782]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41024715575650816`, -28.30577731212275}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20571503910132`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45983063546929`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.84669323560172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.75461278205018`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20571503910132`, 21.699151145685974`], 
                Complex[133.73794610118625`, -0.5664569528154004]}, 2 -> {
                Complex[108.45983063546929`, -21.84669323560172], 
                Complex[133.46888736024792`, -40.75461278205018]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41169384768122086`, -28.554249211387702`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20573302322543`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45922964328606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876426`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20573302322543`, 21.74480338135634], 
                Complex[133.73798068907433`, -0.5259446249758852]}, 2 -> {
                Complex[108.45922964328606`, -21.89239084876426], 
                Complex[133.46655912218745`, -40.79457311007124]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4131370287004188, -28.80324037481374}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20574952625452`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.790205339072944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45863320967749`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46423822839947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.83429954954243`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "D3", 
             Association[1 -> {
                Complex[108.20574952625452`, 21.790205339072944`], 
                Complex[133.73801251890455`, -0.4856655473715854]}, 2 -> {
                Complex[108.45863320967749`, -21.937837930174453`], 
                Complex[133.46423822839947`, -40.83429954954243]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41457673296380904`, -29.052747963712676`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20576458188737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960372`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45804127167143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "D3", 
             Association[1 -> {
                Complex[108.20576458188737`, 21.835359803960372`], 
                Complex[133.73804163958545`, -0.4456170941100197]}, 2 -> {
                Complex[108.45804127167143`, -21.983037267377462`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.416012994075885, -29.302769170892503`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20577822295887`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836444038`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45745376756668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4596181338099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.9130612391335`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "D3", 
             Association[1 -> {
                Complex[108.20577822295887`, 21.880269514316595`], 
                Complex[133.73806809891306`, -0.4057966836444038]}, 2 -> {
                Complex[108.45745376756668`, -22.027991601058005`], 
                Complex[133.4596181338099, -40.9130612391335]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4174458451085741, -29.5533012201294}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2057904814664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.924937162667213`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360265`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.36620177777332685`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4568706368991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.07270362609541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "D3", 
             Association[1 -> {
                Complex[108.2057904814664, 21.924937162667213`], 
                Complex[133.73809194360265`, -0.36620177777332685`]}, 2 -> {
                Complex[108.4568706368991, -22.07270362609541], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4188753186122085, -29.804341365651645`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20580138859481`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.969365396789907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381132193189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3268298806687788`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45629182040908`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.11717599258868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20580138859481`, 21.969365396789907`], 
                Complex[133.7381132193189, -0.3268298806687788]}, 2 -> {
                Complex[108.45629182040908`, -22.11717599258868], 
                Complex[133.45502641240844`, -40.99091836543067]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.42030144662757607`, -30.0558868916351}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581097474138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.013556820710516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070587`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793104337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45571726000996`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.161411306852976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.029513941672306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "D3", 
             Association[1 -> {
                Complex[108.20581097474138`, 22.013556820710516`], 
                Complex[133.73813197070587`, -0.28767853793104337`]}, 2 -> {
                Complex[108.45571726000996`, -22.161411306852976`], 
                Complex[133.45274099074845`, -41.029513941672306`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4217242606961804, -30.307935111709565`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581926953896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.057513995670746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141513`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.24874533567058066`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45514689875739`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388137`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.06789076406041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "D3", 
             Association[1 -> {
                Complex[108.20581926953896`, 22.057513995670746`], 
                Complex[133.73814824141513`, -0.24874533567058066`]}, 2 -> {
                Complex[108.45514689875739`, -22.205412132388137`], 
                Complex[133.45046242420474`, -41.06789076406041]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4231437918715244, -30.5604833684765}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20582630187882`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381620741335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21002789961487878`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4545806808199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085485`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20582630187882`, 22.101239441069584`], 
                Complex[133.7381620741335, -0.21002789961487878`]}, 2 -> {
                Complex[108.4545806808199, -22.249180990820513`], 
                Complex[133.44819063634748`, -41.10605121085485]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4245600707294557, -30.813529033036893`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058320999327`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.144735635378424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45401855145008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.29272036281873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44592555210812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.2058320999327, 22.144735635378424`], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[108.45401855145008`, -22.29272036281873], 
                Complex[133.44592555210812`, -41.14399762152054]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.42597312737788684`, -31.067069504529787`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20583669117387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.188005017031276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.133231021927255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45346045695712`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20583669117387`, 22.188005017031276`], 
                Complex[133.73818259167945`, -0.133231021927255]}, 2 -> {
                Complex[108.45346045695712`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4273829914674536, -31.32110220968049}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584010239766`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937909`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4529063446797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.37912037071832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.21925750339875`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "D3", 
             Association[1 -> {
                Complex[108.20584010239766`, 22.231049985290603`], 
                Complex[133.73818935729176`, -0.09514702213937909]}, 2 -> {
                Complex[108.4529063446797, -22.37912037071832], 
                Complex[133.44141520081953`, -41.21925750339875]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.42878969220029717`, -31.57562460235873}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584235974113`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.273872901089774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819384653146`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.05726967062376076`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4523561629603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.421985771063884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "D3", 
             Association[1 -> {
                Complex[108.20584235974113`, 22.273872901089774`], 
                Complex[133.73819384653146`, -0.05726967062376076]}, 2 -> {
                Complex[108.4523561629603, -22.421985771063884`], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43019325833975586`, -31.830634163146332`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584348870231`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633644618`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45180986111974`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.464631215526794`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.293688381063454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "D3", 
             Association[1 -> {
                Complex[108.20584348870231`, 22.316476087852752`], 
                Complex[133.73819609764354`, -0.019596778633644618`]}, 2 -> {
                Complex[108.45180986111974`, -22.464631215526794`], 
                Complex[133.4369307957903, -41.293688381063454`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4315937182196876, -32.08612839891387}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584351415843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.01787380782837289`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45126738943297`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.507058992873564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900828`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "D3", 
             Association[1 -> {
                Complex[108.20584351415843`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.01787380782837289]}, 2 -> {
                Complex[108.45126738943297`, -22.507058992873564`], 
                Complex[133.43469814900828`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4329910997529396, -32.342104842406556`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584246038388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.401032385184138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874687431`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45072869910537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43247178224317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.36730765692627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "D3", 
             Association[1 -> {
                Complex[108.20584246038388`, 22.401032385184138`], 
                Complex[133.73819403439737`, 0.05514420874687431]}, 2 -> {
                Complex[108.45072869910537`, -22.549271355908413`], 
                Complex[133.43247178224317`, -41.36730765692627]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.434385430440102, -32.59856105183866}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20584035106731`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.45019374224961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.591270522229657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.40381823277538`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "D3", 
             Association[1 -> {
                Complex[108.20584035106731`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[108.45019374224961`, -22.591270522229657`], 
                Complex[133.43025162908577`, -41.40381823277538]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4357767373782053, -32.855494610496564`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058372093284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.48473674427653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381834575462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12909276811101833`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44966247186406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4280376242509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "D3", 
             Association[1 -> {
                Complex[108.2058372093284, 22.48473674427653], 
                Complex[133.7381834575462, 0.12909276811101833`]}, 2 -> {
                Complex[108.44966247186406`, -22.633058674966136`], 
                Complex[133.4280376242509, -41.44013218836733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43716504726833705`, -33.11290312635019}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20583305773388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817506382267`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1657750028210252`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44913484181036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.67463796349433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4258297035504`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.47625154943294`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20583305773388`, 22.526274879059084`], 
                Complex[133.73817506382267`, 0.1657750028210252]}, 2 -> {
                Complex[108.44913484181036`, -22.67463796349433], 
                Complex[133.4258297035504, -41.47625154943294]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43855038642402633`, -33.37078423167215}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20582791831282`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.5676064808745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500857`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581329`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4486108067934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.7160105041369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20582791831282`, 22.5676064808745], 
                Complex[133.73816464500857`, 0.2022652058581329]}, 2 -> {
                Complex[108.4486108067934, -22.7160105041369], 
                Complex[133.42362780386904`, -41.51217831040795]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4399327807789746, -33.62913558266511}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2058218125723`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.60873363177336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2385653375287191`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44809032234028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.54791443507824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.2058218125723, 22.60873363177336], 
                Complex[133.73815223405947`, 0.2385653375287191]}, 2 -> {
                Complex[108.44809032234028`, -22.757178380842795`], 
                Complex[133.42143186313933`, -41.54791443507824]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4413122558945304, -33.887954859096624`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20581476151133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.64965838211989`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813786325204`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.27467732815634704`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44757334478123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850324`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4192418203182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "D3", 
             Association[1 -> {
                Complex[108.20581476151133`, 22.64965838211989], 
                Complex[133.73813786325204`, 0.27467732815634704`]}, 2 -> {
                Complex[108.44757334478123`, -22.798143645850324`], 
                Complex[133.4192418203182, -41.58346185720893]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.44268883696693706`, -34.147239763941485`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20580678563522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.690382751237316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381215642015`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44705983123023`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.838908320332706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4170576153638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.61882248115683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "D3", 
             Association[1 -> {
                Complex[108.20580678563522`, 22.690382751237316`], 
                Complex[133.7381215642015, 0.3106030786938945]}, 2 -> {
                Complex[108.44705983123023`, -22.838908320332706`], 
                Complex[133.4170576153638, -41.61882248115683]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4440625488348928, -34.4069880230313}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2057979049692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.730908728036784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73810336787855`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3463444613199158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44654973956648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027522`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.65399818246753`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "D3", 
             Association[1 -> {
                Complex[108.2057979049692, 22.730908728036784`], 
                Complex[133.73810336787855`, 0.3463444613199158]}, 2 -> {
                Complex[108.44654973956648`, -22.879474395027522`], 
                Complex[133.41487918921305`, -41.65399818246753]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.44543341598620145`, -34.66719738471119}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20578813907149`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.77123827163027`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38190332001997973`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44604302841654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830849942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.68899080845722`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20578813907149`, 22.77123827163027], 
                Complex[133.7380833046258, 0.38190332001997973`]}, 2 -> {
                Complex[108.44604302841654`, -22.919843830849942`], 
                Complex[133.41270648376, -41.68899080845722]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4468014625647925, -34.9278656195033}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20577750704612`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.811373311928055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.41728147115322045`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44553965713682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183454`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20577750704612`, 22.811373311928055`], 
                Complex[133.73806140417352`, 0.41728147115322045`]}, 2 -> {
                Complex[108.44553965713682`, -22.960018559490663`], 
                Complex[133.41053944183454`, -41.72380217877986]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4481667123772297, -35.18899051977725}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20576602755536`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.851315750221183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.45248070400472074`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44503958579652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.000000483998686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "D3", 
             Association[1 -> {
                Complex[108.20576602755536`, 22.851315750221183`], 
                Complex[133.73803769565515`, 0.45248070400472074`]}, 2 -> {
                Complex[108.44503958579652`, -23.000000483998686`], 
                Complex[133.40837800718194`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.44952918889953253`, -35.45056989942684}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20575371883149`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.89106745974935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4875027813239967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.4445427751615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.039791479349624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40622212444285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.792888296032174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "D3", 
             Association[1 -> {
                Complex[108.20575371883149`, 22.89106745974935], 
                Complex[133.7380122076221, 0.4875027813239967]}, 2 -> {
                Complex[108.4445427751615, -23.039791479349624`], 
                Complex[133.40622212444285`, -41.792888296032174`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4508889152830591, -35.71260159355341}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20574059868858`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.930630286254683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805836`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44404918667772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.079393392999783`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40407173913366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.827166548865776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "D3", 
             Association[1 -> {
                Complex[108.20574059868858`, 22.930630286254683`], 
                Complex[133.73798496805836`, 0.5223494398501387]}, 2 -> {
                Complex[108.44404918667772`, -23.079393392999783`], 
                Complex[133.40407173913366`, -41.827166548865776`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.45224591436129913`, -35.97508345815531}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20572668453359`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.970006048521853`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44355878245624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.118808045426714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40192679762777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.86127055887853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20572668453359`, 22.970006048521853`], 
                Complex[133.73795600439445`, 0.5570223908239633]}, 2 -> {
                Complex[108.44355878245624`, -23.118808045426714`], 
                Complex[133.40192679762777`, -41.86127055887853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4536002086550468, -36.23801336982345}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20571199337722`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874326`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44307152525788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.15803723065624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.895202015436034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20571199337722`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874326]}, 2 -> {
                Complex[108.44307152525788`, -23.15803723065624], 
                Complex[133.39978724713725`, -41.895202015436034`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4549518203791081, -36.50138922544288}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20569654184456`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.048203523840755`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44258737847856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.19708271677684`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335968`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "D3", 
             Association[1 -> {
                Complex[108.20569654184456`, 23.048203523840755`], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[108.44258737847856`, -23.19708271677684], 
                Complex[133.39765303569476`, -41.92896258335968]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4563007714478431, -36.76520894189998}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20568034618515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351482`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508832`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.660015738769026`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44210630613502`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340243`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "D3", 
             Association[1 -> {
                Complex[108.20568034618515`, 23.087028744351482`], 
                Complex[133.73785903508832`, 0.660015738769026]}, 2 -> {
                Complex[108.44210630613502`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340243]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4576470834803956, -37.02947045579555}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20566342228294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.12567391653265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378234387284`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6940104792034738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44162827285093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608347`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.995977592713125`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "D3", 
             Association[1 -> {
                Complex[108.20566342228294`, 23.12567391653265], 
                Complex[133.7378234387284, 0.6940104792034738]}, 2 -> {
                Complex[108.44162827285093`, -23.27462953735594], 
                Complex[133.39340042608347`, -41.995977592713125`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.45899077780654807`, -37.29417172316319}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20564578566592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73778624758228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7278397028767003`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44115324384377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.029235245289854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "D3", 
             Association[1 -> {
                Complex[108.20564578566592`, 23.164140732031164`], 
                Complex[133.73778624758228`, 0.7278397028767003]}, 2 -> {
                Complex[108.44115324384377`, -23.313134282759336`], 
                Complex[133.39128192792896`, -42.029235245289854`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4603318754720078, -37.559310719193086`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20562745151531`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.20243085851121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44068118491076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.351462151887336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3891685688179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.06232843242164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "D3", 
             Association[1 -> {
                Complex[108.20562745151531`, 23.20243085851121], 
                Complex[133.73774748603228`, 0.7615049781131944]}, 2 -> {
                Complex[108.44068118491076`, -23.351462151887336`], 
                Complex[133.3891685688179, -42.06232843242164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4616703972435232, -37.824885437961264`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20560843467463`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010909`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.44021206241757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.389614790429448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "D3", 
             Association[1 -> {
                Complex[108.20560843467463`, 23.24054594010909], 
                Complex[133.73770717799474`, 0.7950078509907854]}, 2 -> {
                Complex[108.44021206241757`, -23.389614790429448`], 
                Complex[133.3870603006344, -42.095258703120905`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4630063636141415, -38.090893892163635`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.2055887496584`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.27848759787728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.828349845761597`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.43974584328434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "D3", 
             Association[1 -> {
                Complex[108.2055887496584, 23.27848759787728], 
                Complex[133.73766534693092`, 0.828349845761597]}, 2 -> {
                Complex[108.43974584328434`, -23.427593820972138`], 
                Complex[133.38495707598474`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0.5, 0, 0.5], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4643397948079553, -38.3573341128553}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"D3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.20556841066069`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.31625743021801`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.43928249497475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.46540084343349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240324`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "D3", 
             Association[1 -> {
                Complex[108.20556841066069`, 23.31625743021801], 
                Complex[133.73762201585797`, 0.8615324652630925]}, 2 -> {
                Complex[108.43928249497475`, -23.46540084343349], 
                Complex[133.38285884818345`, -42.16063658240324]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.14947272860459798`, 0.0864635121867516}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.49679557516603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.87967075293174`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.57287060790918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532399953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "C3", 
             Association[1 -> {
                Complex[162.49679557516603`, 2.9142396485109336`], 
                Complex[132.88189718832854`, -17.87967075293174]}, 2 -> {
                Complex[164.57287060790918`, -3.0479413532399953`], 
                Complex[134.78862529189124`, -23.513498562864434`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1600377573443887, 0.048282237225062835`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.69815823018737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.07664557448564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.20679401345527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.3691232322966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.76466640407678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763844034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.18608044096362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "C3", 
             Association[1 -> {
                Complex[162.69815823018737`, 3.6307705575763123`], 
                Complex[133.07664557448564`, -17.20679401345527]}, 2 -> {
                Complex[164.3691232322966, -3.76466640407678], 
                Complex[134.58936763844034`, -24.18608044096362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.16882686412194453`, 0.0025479839961339568`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.81702682614014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.244103960587594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.192822735254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.630699080753924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.24791286298796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.46872944634774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.76187553625734`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "C3", 
             Association[1 -> {
                Complex[162.81702682614014`, 4.244103960587594], 
                Complex[133.192822735254, -16.630699080753924`]}, 2 -> {
                Complex[164.24791286298796`, -4.378190406750068], 
                Complex[134.46872944634774`, -24.76187553625734]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1764979130619559, -0.04972560007545493}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.89623202590275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.166407339344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.916047187939833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "C3", 
             Association[1 -> {
                Complex[162.89623202590275`, 4.781773561001189], 
                Complex[133.27102086156964`, -16.125747324937514`]}, 2 -> {
                Complex[164.166407339344, -4.916047187939833], 
                Complex[134.38611694252143`, -25.266522626186124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.18338976437019533`, -0.10779416601750416`}],
            
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.9533692895785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.26317421199133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.673778470422995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.10700978216263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.397631717588651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.718182126604795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "C3", 
             Association[1 -> {
                Complex[162.9533692895785, 5.26317421199133], 
                Complex[133.3279803002992, -15.673778470422995`]}, 2 -> {
                Complex[164.10700978216263`, -5.397631717588651], 
                Complex[134.3247882793696, -25.718182126604795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.18970083365667784`, -0.17109415686599608`}],
            
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.99687585597522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.26276580186694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.06128160668933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.83575911268632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343943`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "C3", 
             Association[1 -> {
                Complex[162.99687585597522`, 5.701120919783133], 
                Complex[133.3717561373341, -15.26276580186694]}, 2 -> {
                Complex[164.06128160668933`, -5.83575911268632], 
                Complex[134.27668694605623`, -26.128880886343943`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.19555831308773514`, -0.2391829913489885}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.03131031496125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4067147758406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.884495531077516`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.02466294522884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.239169639445748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.2374451850879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.506832820748922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "C3", 
             Association[1 -> {
                Complex[163.03131031496125`, 6.104353845416841], 
                Complex[133.4067147758406, -14.884495531077516`]}, 2 -> {
                Complex[164.02466294522884`, -6.239169639445748], 
                Complex[134.2374451850879, -26.506832820748922`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2010492499679281, -0.31170220396345116`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.05936393484134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43544220027496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.533126521950006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.99446131516729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "C3", 
             Association[1 -> {
                Complex[163.05936393484134`, 6.479082403584161], 
                Complex[133.43544220027496`, -14.533126521950006`]}, 2 -> {
                Complex[163.99446131516729`, -6.614072812516706], 
                Complex[134.20447572357537`, -26.857879187158492`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.20623621026741085`, -0.3883541663970844}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.0827360388856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.96897623823008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.96504547952883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.18632866833261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "C3", 
             Association[1 -> {
                Complex[163.0827360388856, 6.829883346826038], 
                Complex[133.45957631720722`, -14.204350207418514`]}, 2 -> {
                Complex[163.96897623823008`, -6.96504547952883], 
                Complex[134.17613942808237`, -27.18632866833261]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21116590341148872`, -0.4688867814821356}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.10255730313813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.1602366935056825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.8948884451038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.94707593880682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1513419963516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49545951715293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.10255730313813`, 7.1602366935056825`], 
                Complex[133.48021025962274`, -13.8948884451038]}, 2 -> {
                Complex[163.94707593880682`, -7.295567749380924], 
                Complex[134.1513419963516, -27.49545951715293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.21587427019259103`, -0.5530830201675043}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.11961217061838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.9279749261981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.12932163548447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.78783159598447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.11961217061838`, 7.472858386883269], 
                Complex[133.49810470509067`, -13.602181478273478`]}, 2 -> {
                Complex[163.9279749261981, -7.60835565160759], 
                Complex[134.12932163548447`, -27.78783159598447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2203896536362941, -0.6407535198555137}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.13446375540627`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.32418640258124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.91110908726415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "C3", 
             Association[1 -> {
                Complex[163.13446375540627`, 7.769914966301738], 
                Complex[133.51380733250912`, -13.32418640258124]}, 2 -> {
                Complex[163.91110908726415`, -7.905575807831239], 
                Complex[134.10952960183627`, -28.065487910230864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.22473486542336268`, -0.7317311915204956}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1475279007755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.053167049211595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8960616252759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.188988914036532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.33008939886362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.1475279007755, 8.053167049211595], 
                Complex[133.52772377923588`, -13.059242375813348`]}, 2 -> {
                Complex[163.8960616252759, -8.188988914036532], 
                Complex[134.09155924078232`, -28.33008939886362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.22892858334225757`, -0.8258671894830505}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.15911911401952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.3240682437392`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8825171223138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.460048653363897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0751018939077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.583007906385838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.15911911401952`, 8.3240682437392], 
                Complex[133.54016173104085`, -12.805977646175146`]}, 2 -> {
                Complex[163.8825171223138, -8.460048653363897], 
                Complex[134.0751018939077, -28.583007906385838`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2329863262452016, -0.9230278328811485}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1694801602913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.583835207504208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.56324367042308`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.87023194285814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.1694801602913, 8.583835207504208], 
                Complex[133.55135937730103`, -12.56324367042308]}, 2 -> {
                Complex[163.87023194285814`, -8.719971755138737], 
                Complex[134.05991844116488`, -28.82539206493508]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.236921152559949, -1.0230922089904324`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.17880175664644`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.833498461149421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.85901453737054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.17880175664644`, 8.833498461149421], 
                Complex[133.56150438018219`, -12.330067310220034`]}, 2 -> {
                Complex[163.85901453737054`, -8.96978880859587], 
                Complex[134.04582032924358`, -29.058215098144608`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24074417234820594`, -1.1259502761186442`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.18723604978868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.073940020992653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.10561541560388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.84871196234698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.03265656530453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.28231023787636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "C3", 
             Association[1 -> {
                Complex[163.18723604978868`, 9.073940020992653], 
                Complex[133.57074687863496`, -12.10561541560388]}, 2 -> {
                Complex[163.84871196234698`, -9.210381895712343], 
                Complex[134.03265656530453`, -29.28231023787636]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2444649302563328, -1.2315013398204437`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.19490606734587`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8392004270005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.44251298180812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.020304580273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "C3", 
             Association[1 -> {
                Complex[163.19490606734587`, 9.305921789460667], 
                Complex[133.57920862299497`, -11.889168097503115`]}, 2 -> {
                Complex[163.8392004270005, -9.44251298180812], 
                Complex[134.020304580273, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.24809169698631245`, -1.3396528130101173`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20191248924124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.83037851999364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "C3", 
             Association[1 -> {
                Complex[163.20191248924124`, 9.530107327827569], 
                Complex[133.58698953054267`, -11.680098224034463`]}, 2 -> {
                Complex[163.83037851999364`, -9.666845688440565], 
                Complex[134.00866367132147`, -29.707103947727525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.25163169462078877`, -1.450319195361294}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20833859211223`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956242`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8221622632574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.883962238175444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.908980134406136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.20833859211223`, 9.747078800841354], 
                Complex[133.59417248038324`, -11.477855458956242`]}, 2 -> {
                Complex[163.8221622632574, -9.883962238175444], 
                Complex[133.99765020516938`, -29.908980134406136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2550912732468242, -1.5634212244705152`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2142539214259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.957350339052207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.81448143823496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.09437681705006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.104512213028926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.2142539214259, 9.957350339052207], 
                Complex[133.60082688045318`, -11.281953671224448`]}, 2 -> {
                Complex[163.81448143823496`, -10.09437681705006], 
                Complex[133.9871940493811, -30.104512213028926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.25847605114302546`, -1.6788851632630968`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.21971706050041`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6070113617539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.091960884780269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80727681533168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.298546238374051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.97723587655176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.294132227130046`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "C3", 
             Association[1 -> {
                Complex[163.21971706050041`, 10.161378702488394`], 
                Complex[133.6070113617539, -11.091960884780269`]}, 2 -> {
                Complex[163.80727681533168`, -10.298546238374051`], 
                Complex[133.97723587655176`, -30.294132227130046`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2617910273039336, -1.796642196702898}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2247777474091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.359571883156995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.907491168998273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80049803558532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.49687854534779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9677250996958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.2247777474091, 10.359571883156995`], 
                Complex[133.61277584148843`, -10.907491168998273`]}, 2 -> {
                Complex[163.80049803558532`, -10.49687854534779], 
                Complex[133.9677250996958, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.26504067268795034`, -1.9166279171051512`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.22947851363165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.552296113405845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7941019706839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.689740019533176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878894`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "C3", 
             Association[1 -> {
                Complex[163.22947851363165`, 10.552296113405845`], 
                Complex[133.6181631227232, -10.728198030417936`]}, 2 -> {
                Complex[163.7941019706839, -10.689740019533176`], 
                Complex[133.9586182712075, -30.657140604878894`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2682290049014619, -2.0387818819524335`}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23385596697975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.55376897922101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7880514387958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.23385596697975`, 10.739881627157578`], 
                Complex[133.62321014884253`, -10.55376897922101]}, 2 -> {
                Complex[163.7880514387958, -10.877460942190032`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2713596498498469, -2.163047231554368}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23794180650475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62794899755536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.383921024629705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.78231418849845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.000651631856574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.23794180650475`, 10.922627435195468`], 
                Complex[133.62794899755536`, -10.383921024629705`]}, 2 -> {
                Complex[163.78231418849845`, -11.060340369657364`], 
                Complex[133.94147109188316`, -31.000651631856574`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.27443589302789, -2.289370356495063}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2417636330736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.100805313420308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63240767607033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.218396911961511`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.776862087113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.238650121699811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.16578858654045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2417636330736, 11.100805313420308`], 
                Complex[133.63240767607033`, -10.218396911961511`]}, 2 -> {
                Complex[163.776862087113, -11.238650121699811`], 
                Complex[133.93336948207866`, -31.16578858654045]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2774607224992615, -2.417700606806602}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.245345602464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.274663157243593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.05696195712113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.77167046658727`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.326833677611646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.245345602464, 11.274663157243593`], 
                Complex[133.6366107628227, -10.05696195712113]}, 2 -> {
                Complex[163.77167046658727`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.326833677611646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.28043686515247196`, -2.5479900363492836`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2487089558695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.444427821247759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.89940136633527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7667175920338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.582531307820627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9179840286246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.484001751500106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "C3", 
             Association[1 -> {
                Complex[163.2487089558695, 11.444427821247759`], 
                Complex[133.64057992958772`, -9.89940136633527]}, 2 -> {
                Complex[163.7667175920338, -11.582531307820627`], 
                Complex[133.9179840286246, -31.484001751500106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2833668174748191, -2.68019317708494}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2518724540805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.610307537645536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7619842266485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "C3", 
             Association[1 -> {
                Complex[163.2518724540805, 11.610307537645536`], 
                Complex[133.64433436948318`, -9.745517953028422]}, 2 -> {
                Complex[163.7619842266485, -11.748537908691581`], 
                Complex[133.91065826653698`, -31.637490045704613`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2862528718228014, -2.814266838879752}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.25485273533127`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.77249398761309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75745327301976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.91084965765839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "C3", 
             Association[1 -> {
                Complex[163.25485273533127`, 11.77249398761309], 
                Complex[133.64789115029092`, -9.595130182053287]}, 2 -> {
                Complex[163.75745327301976`, -11.91084965765839], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2890971389691452, -2.950169931229104}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2576646121618`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.931164084638935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548408`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75310947547112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.069643504773667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.93413966386116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2576646121618, 11.931164084638935`], 
                Complex[133.65126550803504`, -9.448070485548408]}, 2 -> {
                Complex[163.75310947547112`, -12.069643504773667`], 
                Complex[133.89665253982204`, -31.93413966386116]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2919015675509848, -3.08786330390203}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26032131919624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7489391715357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.225083174088782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.07762370747607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.26032131919624`, 12.086481517469739`], 
                Complex[133.65447109241083`, -9.304183805581669]}, 2 -> {
                Complex[163.7489391715357, -12.225083174088782`], 
                Complex[133.88994274008314`, -32.07762370747607]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2946679609234814, -3.2273096039921207`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26283472113678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74493008325814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "C3", 
             Association[1 -> {
                Complex[163.26283472113678`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[163.74493008325814`, -12.377320504803174`], 
                Complex[133.8834108897335, -32.21807613513113]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2973979918297737, -3.3684731472587885`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2652154882986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74107114099544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "C3", 
             Association[1 -> {
                Complex[163.2652154882986, 12.387654897960461`], 
                Complex[133.66042381437185`, -9.025364372558757]}, 2 -> {
                Complex[163.74107114099544`, -12.526496621998465`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.30009321522311944`, -3.5113198019682437`}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2674732455004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.533783342972365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.890173430857475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73735233390101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.672742962762172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.2674732455004, 12.533783342972365`], 
                Complex[133.6631920229149, -8.890173430857475]}, 2 -> {
                Complex[163.73735233390101`, -12.672742962762172`], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3027550795172311, -3.655816883710712}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26961669895428`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7337645824435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.26961669895428`, 12.677106047334807`], 
                Complex[133.66583387467648`, -8.757637305564256]}, 2 -> {
                Complex[163.7337645824435, -12.816182179005438`], 
                Complex[133.86477325877703`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.30538493649445336`, -3.8019330598921024`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27165374489172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.817737645166858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678214`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73029962922303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.956928934660269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.27165374489172`, 12.817737645166858`], 
                Complex[133.66835762313937`, -8.627647360678214]}, 2 -> {
                Complex[163.73029962922303`, -12.956928934660269`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3079840500616961, -3.9496382627828255`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27359156294804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.500101853051339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7269499450588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.095090612015007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "C3", 
             Association[1 -> {
                Complex[163.27359156294804`, 12.955785489901578`], 
                Complex[133.67077079273932`, -8.500101853051339]}, 2 -> {
                Complex[163.7269499450588, -13.095090612015007`], 
                Complex[133.8530533114799, -32.87924061335592]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.31055360401362514`, -4.098903610160464}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27543669676655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.72370864788658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.004018457106575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.27543669676655`, 13.091350282096839`], 
                Complex[133.67308025959395`, -8.374905338778804]}, 2 -> {
                Complex[163.72370864788658`, -13.230767939566048`], 
                Complex[133.84738105530036`, -33.004018457106575`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3130947089380293, -4.249701332712688}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27719512383507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67529232155744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.251968143863518`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7205694324496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.364055551814676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477616`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.27719512383507`, 13.224526629192962`], 
                Complex[133.67529232155744`, -8.251968143863518]}, 2 -> {
                Complex[163.7205694324496, -13.364055551814676`], 
                Complex[133.8418248696247, -33.12653484477616]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.315608408374947, -4.402004707476376}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2788723162124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.35540354604583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71752650912524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.495042489836637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902983`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "C3", 
             Association[1 -> {
                Complex[163.2788723162124, 13.35540354604583], 
                Complex[133.67741275923174`, -8.131205890824086]}, 2 -> {
                Complex[163.71752650912524`, -13.495042489836637`], 
                Complex[133.83637862409034`, -33.24687418902983]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3180956843269251, -4.555787996681541}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28047329351344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167398`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71457455051592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.623812650126242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.365116029557846`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "C3", 
             Association[1 -> {
                Complex[163.28047329351344`, 13.484064903736138`], 
                Complex[133.67944688928384`, -8.012539074167398]}, 2 -> {
                Complex[163.71457455051592`, -13.623812650126242`], 
                Complex[133.83103666267402`, -33.365116029557846`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3205574622010993, -4.711026391448023}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28200266929107`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71170864466583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.48133541482063`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "C3", 
             Association[1 -> {
                Complex[163.28200266929107`, 13.610589833057865`], 
                Complex[133.68139961119044`, -7.895892678682291]}, 2 -> {
                Complex[163.71170864466583`, -13.750445188118116`], 
                Complex[133.82579375652693`, -33.48133541482063]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3229946152540088, -4.867695959850229}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2834646917637`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.735053088170234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68327544834887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.781195835377185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70892425395203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8206450624651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.59560324614746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2834646917637, 13.735053088170234`], 
                Complex[133.68327544834887`, -7.781195835377185]}, 2 -> {
                Complex[163.70892425395203`, -13.875014881870271`], 
                Complex[133.8206450624651, -33.59560324614746]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3254079685972095, -5.025773598923212}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28486327968363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70621717885442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.997592460624668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.70798658864134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.28486327968363`, 13.857525375128327`], 
                Complex[133.68507858433867`, -7.668381510610166]}, 2 -> {
                Complex[163.70621717885442`, -13.997592460624668`], 
                Complex[133.81558608632903`, -33.70798658864134]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.32779830281783057`, -5.18523699023376}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2862020540158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68681289499762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.55738622457017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7035835259332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.118244902313043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8106126505474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.81854895273081`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2862020540158, 13.978073649360802`], 
                Complex[133.68681289499762`, -7.55738622457017]}, 2 -> {
                Complex[163.7035835259332, -14.118244902313043`], 
                Complex[133.8106126505474, -33.81854895273081]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.330166357256308, -5.346064558682746}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28748436599128`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.4481497957836655`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70101967944905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.28748436599128`, 14.096761385616206`], 
                Complex[133.68848197687097`, -7.4481497957836655`]}, 2 -> {
                Complex[163.70101967944905`, -14.237035703530262`], 
                Complex[133.80572086534593`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3325128329810007, -5.508235434242755}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28871332201555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.21364882343601`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.3406151087588825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69852227614442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.35402512503277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.28871332201555`, 14.21364882343601], 
                Complex[133.69008917251037`, -7.3406151087588825`]}, 2 -> {
                Complex[163.69852227614442`, -14.35402512503277], 
                Complex[133.80090710312305`, -34.03444852404853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.33483839549334043`, -5.6717294163677305`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28989180583767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69608818277845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.79616797558796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.13989716530639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.28989180583767`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[163.69608818277845`, -14.469270415426754`], 
                Complex[133.79616797558796`, -34.13989716530639]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3371436771924203, -5.836526940839223}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29102249833014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69371447606676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.243748101320996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.29102249833014`, 14.442248908399693`], 
                Complex[133.69313013823358`, -7.130436575951601]}, 2 -> {
                Complex[163.69371447606676`, -14.582826015372707`], 
                Complex[133.7915003133145, -34.243748101320996`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.33942927962465824`, -6.002609048839373}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2921078951751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.554067776191998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672555`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69139842472714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.694743744345221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7869011474127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "C3", 
             Association[1 -> {
                Complex[163.2921078951751, 14.554067776191998`], 
                Complex[133.69456951471147`, -7.027692013672555]}, 2 -> {
                Complex[163.69139842472714`, -14.694743744345221`], 
                Complex[133.7869011474127, -34.34605047512348]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34169577554093217`, -6.169957358061877}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29315032271526`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69595825198883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.926447421338327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68913747337317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78236769306173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.446851106957446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.29315032271526`, 14.664299144668377`], 
                Complex[133.69595825198883`, -6.926447421338327]}, 2 -> {
                Complex[163.68913747337317`, -14.805072971738813`], 
                Complex[133.78236769306173`, -34.446851106957446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34394371078147906`, -6.33855403569183}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2941519521878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.77299007177116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68692922803774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.913860773896733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "C3", 
             Association[1 -> {
                Complex[163.2941519521878, 14.77299007177116], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[163.68692922803774`, -14.913860773896733`], 
                Complex[133.77789733468606`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3461736060049014, -6.508381773102096}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29511481253365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.88018546723748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69859312781242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.728281700596741`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6847714431318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644123692063744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "C3", 
             Association[1 -> {
                Complex[163.29511481253365`, 14.88018546723748], 
                Complex[133.69859312781242`, -6.728281700596741]}, 2 -> {
                Complex[163.6847714431318, -15.021152078455035`], 
                Complex[133.7734876125809, -34.644123692063744`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.34838595827731006`, -6.679423762128641}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29604080194576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183247`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6826620096745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.126989797234097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7691362108228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.74067895150922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.29604080194576`, 14.985928225471852`], 
                Complex[133.69984356428586`, -6.631277315183247]}, 2 -> {
                Complex[163.6826620096745, -15.126989797234097`], 
                Complex[133.7691362108228, -34.74067895150922]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3505812425354457, -6.85166367280077}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29693169830156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.5356061437843405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68059894464983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.231414948770267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76484094632082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "C3", 
             Association[1 -> {
                Complex[163.29693169830156`, 15.090259348061176`], 
                Complex[133.70105197999624`, -6.5356061437843405`]}, 2 -> {
                Complex[163.68059894464983`, -15.231414948770267`], 
                Complex[133.76484094632082`, -34.83589932329275]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3527599129352034, -7.025085632413676}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29778916860275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.193218056900896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67858038136492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.334466771459132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.29778916860275`, 15.193218056900896`], 
                Complex[133.70222021135814`, -6.441230995764474]}, 2 -> {
                Complex[163.67858038136492`, -15.334466771459132`], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3549224040961911, -7.199674205841381}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2986147775331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.29484189879971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67660456069984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.2986147775331, 15.29484189879971], 
                Complex[133.7033499865708, -6.348116269010088]}, 2 -> {
                Complex[163.67660456069984`, -15.436182828175923`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.357069132253178, -7.375414376997453}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2994099952287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.395166842334241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67466982315278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.53659910314539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.2994099952287, 15.395166842334241`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[163.67466982315278`, -15.53659910314539], 
                Complex[133.75227193555395`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3592004963206869, -7.552291531359044}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3001762043455`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.494227367644923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67277460159679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7481817164674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.204152917056646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.3001762043455, 15.494227367644923`], 
                Complex[133.70550058771101`, -6.165533069493565]}, 2 -> {
                Complex[163.67277460159679`, -15.635750091752156`], 
                Complex[133.7481817164674, -35.204152917056646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36131687888110314`, -7.730291439477428}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30091470649666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769498`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.076000541975269`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67091741467345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.733668883910747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.293226612919796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30091470649666`, 15.592056549792122`], 
                Complex[133.70652439769498`, -6.076000541975269]}, 2 -> {
                Complex[163.67091741467345`, -15.733668883910747`], 
                Complex[133.74413839370675`, -35.293226612919796`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36341864710050736`, -7.909400241404805}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30162672812602`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70751573240688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.987600173789694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6690968607587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.830387241551286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30162672812602`, 15.688686136228515`], 
                Complex[133.70751573240688`, -5.987600173789694]}, 2 -> {
                Complex[163.6690968607587, -15.830387241551286`], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36550615358058786`, -8.089604431973337}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30231342587385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.784146618887455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.9003030540343815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6673116124424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.925935670720543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73618625174637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.46800182936364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "C3", 
             Association[1 -> {
                Complex[163.30231342587385`, 15.784146618887455`], 
                Complex[133.70847588612014`, -5.9003030540343815`]}, 2 -> {
                Complex[163.6673116124424, -15.925935670720543`], 
                Complex[133.73618625174637`, -35.46800182936364]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3675797371504694, -8.270890846867337}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30297589148626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66556041147118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "C3", 
             Association[1 -> {
                Complex[163.30297589148626`, 15.878467301338127`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[163.66556041147118`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3696397236043986, -8.45324664943517}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3036151563131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.971676361413378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71030748519513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.728908493102031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6638420641087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.11363888689164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "C3", 
             Association[1 -> {
                Complex[163.3036151563131, 15.971676361413378`], 
                Complex[133.71030748519513`, -5.728908493102031]}, 2 -> {
                Complex[163.6638420641087, -16.11363888689164], 
                Complex[133.72840390066767`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37168642638952115`, -8.63665931819097}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30423219543457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.64475863285114`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66215543687335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "C3", 
             Association[1 -> {
                Complex[163.30423219543457`, 16.063800909678434`], 
                Complex[133.71118119033963`, -5.64475863285114]}, 2 -> {
                Complex[163.66215543687335`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37372014724792785`, -8.821116634960807}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30482793145168`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.154867044072365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7120282423221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66049945261796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.296999905203638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72078084168677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30482793145168`, 16.154867044072365`], 
                Complex[133.7120282423221, -5.561607075648972]}, 2 -> {
                Complex[163.66049945261796`, -16.296999905203638`], 
                Complex[133.72078084168677`, -35.80483537920644]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37574117681609714`, -9.006606673631692}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30540323797229`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.24489990102471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65887308691825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.387116784982247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71702603519051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "C3", 
             Association[1 -> {
                Complex[163.30540323797229`, 16.24489990102471], 
                Complex[133.71284963153286`, -5.479429991022453]}, 2 -> {
                Complex[163.65887308691825`, -16.387116784982247`], 
                Complex[133.71702603519051`, -35.88654323957749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.37774979518613855`, -9.193117789464297}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3059589428217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.33392370332042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71364629891158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.39820441529854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65727536474287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754884988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.967298179972964`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "C3", 
             Association[1 -> {
                Complex[163.3059589428217, 16.33392370332042], 
                Complex[133.71364629891158`, -5.39820441529854]}, 2 -> {
                Complex[163.65727536474287`, -16.476223863094262`], 
                Complex[133.71330754884988`, -35.967298179972964`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3797462724305711, -9.380638608934282}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3064958310019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.421961804962738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65570535737885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3064958310019, 16.421961804962738`], 
                Complex[133.71441913905537`, -5.317908209063045]}, 2 -> {
                Complex[163.65570535737885`, -16.564344505422593`], 
                Complex[133.70962432476176`, -36.04712235702883]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38173086909447357`, -9.569158020068967}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30701464742387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.5090367332606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249019`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65416217958912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.65150125087593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267105`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30701464742387`, 16.5090367332606], 
                Complex[133.71516900309246`, -5.238520017249019]}, 2 -> {
                Complex[163.65416217958912`, -16.65150125087593], 
                Complex[133.70597535216766`, -36.12603714267105]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38370383665679747`, -9.758665163249036}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30751609943115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6526449869827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.73771585091723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70235966468252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.20406316160487`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.30751609943115`, 16.595170228347317`], 
                Complex[133.71589670134117`, -5.160019231659067]}, 2 -> {
                Complex[163.6526449869827, -16.73771585091723], 
                Complex[133.70235966468252`, -36.20406316160487]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.38566541796399684`, -9.949149422447151}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30800085913484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71660300577298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6511529735775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.82300930670975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6987763377227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.28122032654667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "C3", 
             Association[1 -> {
                Complex[163.30800085913484`, 16.680383280319464`], 
                Complex[133.71660300577298`, -5.082385955742662]}, 2 -> {
                Complex[163.6511529735775, -16.82300930670975], 
                Complex[133.6987763377227, -36.28122032654667]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3876158476363451, -10.140600416877097`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30846956557582`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6496853695408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.90740190405787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861177`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.35752787136576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.30846956557582`, 16.764696164168555`], 
                Complex[133.71728865229744`, -5.005600971465146]}, 2 -> {
                Complex[163.6496853695408, -16.90740190405787], 
                Complex[133.6952244861177, -36.35752787136576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3895553524512018, -10.333007993029538`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30892282672824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6482414390911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.990913246296902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.30892282672824`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118656]}, 2 -> {
                Complex[163.6482414390911, -16.990913246296902`], 
                Complex[133.69170326188944`, -36.43300438228255]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3914841517028031, -10.526362217071567`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30936122135927`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6468204785474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.073562285278378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6882118521846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50766782726147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "C3", 
             Association[1 -> {
                Complex[163.30936122135927`, 16.93069914732912], 
                Complex[133.71860074752374`, -4.854502212938122]}, 2 -> {
                Complex[163.6468204785474, -17.073562285278378`], 
                Complex[133.6882118521846, -36.50766782726147]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.39340245754195785`, -10.72065336758933}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30978530075578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396218`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64542181451625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.155367350584477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.58153558372544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "C3", 
             Association[1 -> {
                Complex[163.30978530075578`, 17.012426507651817`], 
                Complex[133.7192285060807, -4.780153123396218]}, 2 -> {
                Complex[163.64542181451625`, -17.155367350584477`], 
                Complex[133.68474947734978`, -36.58153558372544]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3953104752953657, -10.915871928653997`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31019559032947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64404480220196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31019559032947`, 17.093328278637614`], 
                Complex[133.71983822997944`, -4.70658164106197]}, 2 -> {
                Complex[163.64404480220196`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.39720840376748406`, -11.112008583193267`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31059259111072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.173421616831476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72043050380475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.633771506916521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64268882383246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353258`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31059259111072`, 17.173421616831476`], 
                Complex[133.72043050380475`, -4.633771506916521]}, 2 -> {
                Complex[163.64268882383246`, -17.31651593099673], 
                Complex[133.67790886901938`, -36.72695074353258]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.39909643552519974`, -11.309054206651014`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31097678113926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.25272313490318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6413532871904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31097678113926`, 17.25272313490318], 
                Complex[133.72100588678245`, -4.561706978028415]}, 2 -> {
                Complex[163.6413532871904, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.40097475716709646`, -11.506999860919729`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3113486167611`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.331248924894496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72156491416428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64003762424196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.47449418860847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67117579833888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3113486167611, 17.331248924894496`], 
                Complex[133.72156491416428`, -4.490372805498023]}, 2 -> {
                Complex[163.64003762424196`, -17.47449418860847], 
                Complex[133.67117579833888`, -36.86937802828386]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4028435495774311, -11.705836788530716`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31170853383765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.409014580215214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63874128985492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.552334396036265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.93950908610309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31170853383765`, 17.409014580215214`], 
                Complex[133.72210809852083`, -4.419754213588025]}, 2 -> {
                Complex[163.63874128985492`, -17.552334396036265`], 
                Complex[133.66784794577543`, -36.93950908610309]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4047029881668373, -11.905556407088374`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31205694887507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.48603521646938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6374637606001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.629428981138844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.008937686204405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31205694887507`, 17.48603521646938], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[163.6374637606001, -17.629428981138844`], 
                Complex[133.66454505465833`, -37.008937686204405`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4065532431003526, -12.10615030393552}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31239426007943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.562325491186662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63620453362884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.70579261009809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31239426007943`, 17.562325491186662`], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[163.63620453362884`, -17.70579261009809], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4083944795127132, -12.307610231037936`}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31272084834353`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.637899622528057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878537`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.634963125622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.781439509544892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.14574269865576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31272084834353`, 17.637899622528057`], 
                Complex[133.72364740379095`, -4.212050853878537]}, 2 -> {
                Complex[163.634963125622, -17.781439509544892`], 
                Complex[133.65801181266102`, -37.14574269865576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.410226857713132, -12.50992810007653}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31303707817023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.712771407030306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63373907180392`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.85638348430743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.21314567761614`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "C3", 
             Association[1 -> {
                Complex[163.31303707817023`, 17.712771407030306`], 
                Complex[133.7241319288729, -4.144155620061895]}, 2 -> {
                Complex[163.63373907180392`, -17.85638348430743], 
                Complex[133.65478034294642`, -37.21314567761614]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41205053337941927`, -12.713095977736637`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3133432985372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996313`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63253192501676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.3133432985372, 17.786954236448395`], 
                Complex[133.72460287329903`, -4.076908528996313]}, 2 -> {
                Complex[163.63253192501676`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41386565774164347`, -12.917106081184505`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31363984370773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.86046111375152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.01029726309017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63134125485357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6483850579582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.3460160901857`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "C3", 
             Association[1 -> {
                Complex[163.31363984370773`, 17.86046111375152], 
                Complex[133.72506063642794`, -4.01029726309017]}, 2 -> {
                Complex[163.63134125485357`, -18.004215870320166`], 
                Complex[133.6483850579582, -37.3460160901857]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41567237775709537`, -13.121950773721581`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31392703399072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.93330466832352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9443098592571175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63016664684008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.07712992966061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "C3", 
             Association[1 -> {
                Complex[163.31392703399072`, 17.93330466832352], 
                Complex[133.72550560195975`, -3.9443098592571175`]}, 2 -> {
                Complex[163.63016664684008`, -18.07712992966061], 
                Complex[133.64522023907955`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41747083627664033`, -13.32762256060776}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31420517645438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.00549717041573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870841`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.878934695199984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62900770166812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31420517645438`, 18.00549717041573], 
                Complex[133.72593813870841`, -3.878934695199984]}, 2 -> {
                Complex[163.62900770166812`, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41926117220240194`, -13.534114085045433`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3144745655963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.077050544896366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72635860132817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.814160476362023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62786403447276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.221015184158826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63895386837342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.54066255110091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3144745655963, 18.077050544896366`], 
                Complex[133.72635860132817`, -3.814160476362023]}, 2 -> {
                Complex[163.62786403447276`, -18.221015184158826`], 
                Complex[133.63895386837342`, -37.54066255110091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4210435206378286, -13.741418124316377`}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31473548397335`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.14797638433758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.749976223506348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62673527415205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31473548397335`, 18.14797638433758], 
                Complex[133.72676733099715`, -3.749976223506348]}, 2 -> {
                Complex[163.62673527415205`, -18.292009911552334`], 
                Complex[133.6358514127178, -37.60434783208481]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4228180130309675, -13.949527586064503`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31498820279393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62562106272594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63276886608713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.31498820279393`, 18.21828596147894], 
                Complex[133.72716465606138`, -3.686371260886986]}, 2 -> {
                Complex[163.62562106272594`, -18.362387852255672`], 
                Complex[133.63276886608713`, -37.66745274304553]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4245847773105191, -14.158435504716968`}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3152329824754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.28799024110279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.62333520497781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62452105473145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.43215997808431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322924`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.729987678324505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3152329824754, 18.28799024110279], 
                Complex[133.7275508926416, -3.62333520497781]}, 2 -> {
                Complex[163.62452105473145`, -18.43215997808431], 
                Complex[133.62970581322924`, -37.729987678324505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4263439380152982, -14.368135038037943`}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3154700731691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.35709989135509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7279263452058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.5608579537275773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6234349166525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.501336964078423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.791962750599865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "C3", 
             Association[1 -> {
                Complex[163.3154700731691, 18.35709989135509], 
                Complex[133.7279263452058, -3.5608579537275773`]}, 2 -> {
                Complex[163.6234349166525, -18.501336964078423`], 
                Complex[133.62666185240195`, -37.791962750599865`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.42809561641809574`, -14.578619463807948`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31569971525462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6223623263809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.569929199304017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31569971525462`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[163.6223623263809, -18.569929199304017`], 
                Complex[133.62363659478487`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.42983993064377096`, -14.7898821766239}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31592213980636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6213029727077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.63794679715963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.620629663924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31592213980636`, 18.493576557437454`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[163.6213029727077, -18.63794679715963], 
                Complex[133.620629663924, -37.91427240958484]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4315769957811761, -15.001916684813681`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31613756903312`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.56096352111073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62025655484186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.705399605215987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61764069520532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "C3", 
             Association[1 -> {
                Complex[163.31613756903312`, 18.56096352111073], 
                Complex[133.72899087982017`, -3.376682017581235]}, 2 -> {
                Complex[163.62025655484186`, -18.705399605215987`], 
                Complex[133.61764069520532`, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43330692399132936`, -15.214716607460433`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3163462166933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.627795770329765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61922278195527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61466933535638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.03445736625228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "C3", 
             Association[1 -> {
                Complex[163.3163462166933, 18.627795770329765`], 
                Complex[133.72932602622453`, -3.316344244925613]}, 2 -> {
                Complex[163.61922278195527`, -18.772297214614134`], 
                Complex[133.61466933535638`, -38.03445736625228]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4350298246093353, -15.428275671531514`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31654828848707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.694082642534067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7296517540468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61820137275217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.09377564761935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31654828848707`, 18.694082642534067`], 
                Complex[133.7296517540468, -3.25651864598262]}, 2 -> {
                Complex[163.61820137275217`, -18.838648969045266`], 
                Complex[133.61171524197408`, -38.09377564761935]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43674580424272386`, -15.642587709107554`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31674398242674`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.197196607875771`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61719205506083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6087780830763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.152589369857864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31674398242674`, 18.75983323641723], 
                Complex[133.72996830818994`, -3.197196607875771]}, 2 -> {
                Complex[163.61719205506083`, -18.904463973336576`], 
                Complex[133.6087780830763, -38.152589369857864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4384549668652988, -15.857646654707265`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31693348918697`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.82505642013447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138369736463453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6161945654476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.969751101660396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31693348918697`, 18.82505642013447], 
                Complex[133.73027592511528`, -3.138369736463453]}, 2 -> {
                Complex[163.6161945654476, -18.969751101660396`], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.44015741390655244`, -16.073446542703625`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31711699243615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.88976083915551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.080029848884582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61520864885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.034519005391328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.26873653979493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "C3", 
             Association[1 -> {
                Complex[163.31711699243615`, 18.88976083915551], 
                Complex[133.73057483320838`, -3.080029848884582]}, 2 -> {
                Complex[163.61520864885, -19.034519005391328`], 
                Complex[133.60295329038402`, -38.26873653979493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4418532443373004, -16.289981504827953`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31729466915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.953954923781044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61423405822947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.09877612062455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.32608616746591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "C3", 
             Association[1 -> {
                Complex[163.31729466915, 18.953954923781044`], 
                Complex[133.7308652531255, -3.0221689664234717`]}, 2 -> {
                Complex[163.61423405822947`, -19.09877612062455], 
                Complex[133.60006504101256`, -38.32608616746591]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4435425547521327, -16.507245767757478`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31746668990834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.017646896340647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9647793076770235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61327055424135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.16253067537683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31746668990834`, 19.017646896340647`], 
                Complex[133.73114739812223`, -2.9647793076770235`]}, 2 -> {
                Complex[163.61327055424135`, -19.16253067537683], 
                Complex[133.59719249422423`, -38.38296360992766]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4452254394476591, -16.725233650783686`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3176332191766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.080844778087723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.90785328200948`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6123179049217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.225790696484122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.4393764666446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3176332191766, 19.080844778087723`], 
                Complex[133.73142147436542`, -2.90785328200948]}, 2 -> {
                Complex[163.6123179049217, -19.225790696484122`], 
                Complex[133.59433536417916`, -38.4393764666446]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4469019904979114, -16.943939563557176`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31779441557222`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.14355639580752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6113758853897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "C3", 
             Association[1 -> {
                Complex[163.31779441557222`, 19.14355639580752], 
                Complex[133.73168768122898`, -2.8513834832794664`]}, 2 -> {
                Complex[163.6113758853897, -19.288564016212078`], 
                Complex[133.59149337320662`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.44857229782670566`, -17.1633580039066}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31795043211764`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.20578938815203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7953626838262657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6104442775649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.35085827859341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "C3", 
             Association[1 -> {
                Complex[163.31795043211764`, 19.20578938815203], 
                Complex[133.73194621157515`, -2.7953626838262657`]}, 2 -> {
                Complex[163.6104442775649, -19.35085827859341], 
                Complex[133.58866625149176`, -38.55083790353876]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4502364492766781, -17.383483555728322`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31810141648003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.26755121171575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287020946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60952286989846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.605900783286515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31810141648003`, 19.26755121171575], 
                Complex[133.73219725202154`, -2.7397838287020946`]}, 2 -> {
                Complex[163.60952286989846`, -19.41268094550624], 
                Complex[133.58585373677684`, -38.605900783286515`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4518945306755932, -17.60431088694373}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31824751119916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6846400301384143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60861145711593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.6605276877375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "C3", 
             Association[1 -> {
                Complex[163.31824751119916`, 19.328849146864805`], 
                Complex[133.73244098319515`, -2.6846400301384143`]}, 2 -> {
                Complex[163.60861145711593`, -19.47403930250476], 
                Complex[133.58305557407584`, -38.6605276877375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4535466259000935, -17.82583474752192}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31838885390343`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7326775799737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60770983997617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.53494046441777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.71472535094414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "C3", 
             Association[1 -> {
                Complex[163.31838885390343`, 19.389690303331637`], 
                Complex[133.7326775799737, -2.6299245622347733`]}, 2 -> {
                Complex[163.60770983997617`, -19.53494046441777], 
                Complex[133.58027151540554`, -38.71472535094414]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.45519281693663566`, -18.048049967564697`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31852557751546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60681782503693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.59539138072089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "C3", 
             Association[1 -> {
                Complex[163.31852557751546`, 19.45008162558661], 
                Complex[133.73290721171557`, -2.5756308558594796`]}, 2 -> {
                Complex[163.60681782503693`, -19.59539138072089], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4568331839406931, -18.27095145545175}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3186578104471`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.510029897997104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.521752493751901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60593522443511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.65539884069858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.821859110255915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "C3", 
             Association[1 -> {
                Complex[163.3186578104471, 19.510029897997104`], 
                Complex[133.73313004247825`, -2.521752493751901]}, 2 -> {
                Complex[163.60593522443511`, -19.65539884069858], 
                Complex[133.57474475168777`, -38.821859110255915`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4584678052925761, -18.49453419604338}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31878567678518`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.56954174978439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.468283205816789`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6050618556758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.71496947840288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31878567678518`, 19.56954174978439], 
                Complex[133.73334623122685`, -2.468283205816789]}, 2 -> {
                Complex[163.6050618556758, -19.71496947840288], 
                Complex[133.57200158341104`, -38.87480790939813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.46009675765171715`, -18.71879324893866}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3189092964682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.628623659787667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73355593203246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.415216864601611`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60419754143146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3189092964682, 19.628623659787667`], 
                Complex[133.73355593203246`, -2.415216864601611]}, 2 -> {
                Complex[163.60419754143146`, -19.774109777419557`], 
                Complex[133.5692715922459, -38.92735288260375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4617201160089956, -18.943723746786947`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31902878545432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.362547480948237`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6033421093502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.832826075450342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.979500026576446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31902878545432`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.362547480948237]}, 2 -> {
                Complex[163.6033421093502, -19.832826075450342`], 
                Complex[133.56655456156514`, -38.979500026576446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4633379537366175, -19.169320893650518`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31914425588116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3102691998110743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60249539187296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "C3", 
             Association[1 -> {
                Complex[163.31914425588116`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.3102691998110743`]}, 2 -> {
                Complex[163.60249539187296`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4649503426361485, -19.395579963416505`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31925581621843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.80335236672411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60165722605888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.94901131621615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "C3", 
             Association[1 -> {
                Complex[163.31925581621843`, 19.80335236672411], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[163.60165722605888`, -19.94901131621615], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.46655735298509676`, -19.62249629825619}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31936357141305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.860776447031697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.206863171477252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60082745341847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.00649224376953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55847914922663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.31936357141305`, 19.860776447031697`], 
                Complex[133.73433277630326`, -2.206863171477252]}, 2 -> {
                Complex[163.60082745341847`, -20.00649224376953], 
                Complex[133.55847914922663`, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.46815905358139326`, -19.850065307130127`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31946762302746`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.91780087836711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60000591975424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.06357314798203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.31946762302746`, 19.91780087836711], 
                Complex[133.73451218992716`, -2.155724349292754]}, 2 -> {
                Complex[163.60000591975424`, -20.06357314798203], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4697555117862799, -20.078282464336866`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31956806937163`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59919247500852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.12025970000922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800312`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.31956806937163`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[163.59919247500852`, -20.12025970000922], 
                Complex[133.55315661583612`, -39.23446901800312]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4713467935658053, -20.307143308104315`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.319665005629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.030673339891987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7348541729491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0545482986917456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59838697311696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "C3", 
             Association[1 -> {
                Complex[163.319665005629, 20.030673339891987`], 
                Complex[133.7348541729491, -2.0545482986917456`]}, 2 -> {
                Complex[163.59838697311696`, -20.176557449202846`], 
                Complex[133.55051310011325`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.47293296353050146`, -20.53664343922166}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31975852397647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7350169880388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.00450069857931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5975892718708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232471826623705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "C3", 
             Association[1 -> {
                Complex[163.31975852397647`, 20.086532342147553`], 
                Complex[133.7350169880388, -2.00450069857931]}, 2 -> {
                Complex[163.5975892718708, -20.232471826623705`], 
                Complex[133.54788117531726`, -39.333867334968495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4745140849738669, -20.76677851971066}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31984871369912`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73517451010144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59679923278136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54526066470336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "C3", 
             Association[1 -> {
                Complex[163.31984871369912`, 20.14201364645422], 
                Complex[133.73517451010144`, -1.9548066511051871`]}, 2 -> {
                Complex[163.59679923278136`, -20.288008148422218`], 
                Complex[133.54526066470336`, -39.3830324278985]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.47609021990951356`, -20.99754427153473}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3199356612996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.197122453313998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9054612411862166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59601672095425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3199356612996, 20.197122453313998`], 
                Complex[133.73532685336215`, -1.9054612411862166`]}, 2 -> {
                Complex[163.59601672095425`, -20.343171619103263`], 
                Complex[133.54265139579022`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.47766142910641, -21.228936475344643`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320019450603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59524160496576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.397967334670057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.480319094081715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.320019450603, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608618`]}, 2 -> {
                Complex[163.59524160496576`, -20.397967334670057`], 
                Complex[133.54005320021986`, -39.480319094081715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.47922777212403894`, -21.460950969259333`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32010016285645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.3062428375576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849099015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59447375674608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.45240028565977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "C3", 
             Association[1 -> {
                Complex[163.32010016285645`, 20.3062428375576], 
                Complex[133.73561644435446`, -1.8077971849099015`]}, 2 -> {
                Complex[163.59447375674608`, -20.45240028565977], 
                Complex[133.53746591362483`, -39.52845020484526]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4807893073447695, -21.693583647680835`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32017787682477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5937130514674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.506475360070965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.576246028452815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "C3", 
             Association[1 -> {
                Complex[163.32017787682477`, 20.360264285794972`], 
                Complex[133.73575390485036`, -1.7594692110781658`]}, 2 -> {
                Complex[163.5937130514674, -20.506475360070965`], 
                Complex[133.53488937550074`, -39.576246028452815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4823460920065707, -21.926830460141755`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320252668882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5929593674352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.5601973461902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.6237110918168`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.320252668882, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931463`]}, 2 -> {
                Complex[163.5929593674352, -20.5601973461902], 
                Complex[133.53232342908268`, -39.6237110918168]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4838981822337353, -22.160687410184654`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32032461309848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59221258598674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52976792122885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32032461309848`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763436`]}, 2 -> {
                Complex[163.59221258598674`, -20.613570935319654`], 
                Complex[133.52976792122885`, -39.67084982986853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.48544563306658056`, -22.395150554271826`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32039378132473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73613816201268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59147259138922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.666600724412163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658805997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32039378132473`, 20.52023078674261], 
                Complex[133.73613816201268`, -1.6164475267435492`]}, 2 -> {
                Complex[163.59147259138922`, -20.666600724412163`], 
                Complex[133.527222702305, -39.71766658805997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.48698849849063713`, -22.63021600072466}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32046024327133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59073927074817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.71929121861588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5246876260788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.76416562477979`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "C3", 
             Association[1 -> {
                Complex[163.32046024327133`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[163.59073927074817`, -20.71929121861588], 
                Complex[133.5246876260788, -39.76416562477979]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4885268314641615, -22.865879908691394`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3205240665855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.625172630255136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59001251391317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "C3", 
             Association[1 -> {
                Complex[163.3205240665855, 20.625172630255136`], 
                Complex[133.73637185511262`, -1.5226917500597743`]}, 2 -> {
                Complex[163.59001251391317`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.49006068394544905`, -23.102138487142692`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32058531692476`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.677146044602367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7364822323083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4762789595872228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58929221339187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.823671898594245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51964733316362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.856227145969456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "C3", 
             Association[1 -> {
                Complex[163.32058531692476`, 20.677146044602367`], 
                Complex[133.7364822323083, -1.4762789595872228`]}, 2 -> {
                Complex[163.58929221339187`, -20.823671898594245`], 
                Complex[133.51964733316362`, -39.856227145969456`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4915901069188117, -23.338987993893483`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3206440580269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.728793469886885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58857826426507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.875370657359298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51714184008853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.901797732519626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "C3", 
             Association[1 -> {
                Complex[163.3206440580269, 20.728793469886885`], 
                Complex[133.7365884127948, -1.4301708674222517`]}, 2 -> {
                Complex[163.58857826426507`, -20.875370657359298`], 
                Complex[133.51714184008853`, -39.901797732519626`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.49311515041936155`, -23.576424734650786`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32070035177745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.780119064461577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73669048085137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3843635465213247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5878705641061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.926747271733444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51464593674876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.9470668060475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "C3", 
             Association[1 -> {
                Complex[163.32070035177745`, 20.780119064461577`], 
                Complex[133.73669048085137`, -1.3843635465213247`]}, 2 -> {
                Complex[163.5878705641061, -20.926747271733444`], 
                Complex[133.51464593674876`, -39.9470668060475]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.494635863557965, -23.81444506208636}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32075425827455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3388531459104875`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58716901290316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51215949242192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.99203822311737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "C3", 
             Association[1 -> {
                Complex[163.32075425827455`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.3388531459104875`]}, 2 -> {
                Complex[163.58716901290316`, -20.977805823117315`], 
                Complex[133.51215949242192`, -39.99203822311737]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4961522945442078, -24.05304537493344}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3208058358904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.881820995702782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58647351298407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.028550314683574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50968237921512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.03671576612024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "C3", 
             Association[1 -> {
                Complex[163.3208058358904, 20.881820995702782`], 
                Complex[133.73688260585354`, -1.293635888714526]}, 2 -> {
                Complex[163.58647351298407`, -21.028550314683574`], 
                Complex[133.50968237921512`, -40.03671576612024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.49766449070989943`, -24.29222211710676}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32085514133112`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73697282063236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.248708070250089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58578396894472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.32085514133112`, 20.9322052560464], 
                Complex[133.73697282063236`, -1.248708070250089]}, 2 -> {
                Complex[163.58578396894472`, -21.078984673387104`], 
                Complex[133.50721447198234`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.49917249853027607`, -24.53197177684496}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32090222969342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.982283536987506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5851002875799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.12911275191012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32090222969342`, 20.982283536987506`], 
                Complex[133.73705923878364`, -1.2040660561803698`]}, 2 -> {
                Complex[163.5851002875799, -21.12911275191012], 
                Complex[133.50475564824438`, -40.12520400001161]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.500676363646283, -24.772290885875126`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32094715451944`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.03205961571474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58442237781642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32094715451944`, 21.03205961571474], 
                Complex[133.7371419342688, -1.1597062807288623`]}, 2 -> {
                Complex[163.58442237781642`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5021761308844697, -25.01317601859819}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32098996784921`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7372209791803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1156252449499178`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58375015064937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.228465119017653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "C3", 
             Association[1 -> {
                Complex[163.32098996784921`, 21.081537198896875`], 
                Complex[133.7372209791803, -1.1156252449499178`]}, 2 -> {
                Complex[163.58375015064937`, -21.228465119017653`], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5036718442773116, -25.254623791294794`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32103072027124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.13071992444728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5830835190799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "C3", 
             Association[1 -> {
                Complex[163.32103072027124`, 21.13071992444728], 
                Complex[133.73729644380091`, -1.071819515054024]}, 2 -> {
                Complex[163.5830835190799, -21.277696758252304`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5051635470829916, -25.496630861351118`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32106946097053`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58242239805642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "C3", 
             Association[1 -> {
                Complex[163.32106946097053`, 21.179611363233054`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[163.58242239805642`, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.506651281803334, -25.739193926503706`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32110623777564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58176670441676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.37528881890603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.341533091710815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "C3", 
             Association[1 -> {
                Complex[163.32110623777564`, 21.228215020730886`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[163.58176670441676`, -21.37528881890603], 
                Complex[133.49259367239995`, -40.341533091710815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5081350902029891, -25.982309724102993`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32114109720294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.27653433863163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58111635683326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.383987509842974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32114109720294`, 21.27653433863163], 
                Complex[133.73750203277484`, -0.9420207663983327]}, 2 -> {
                Complex[163.58111635683326`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.383987509842974`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5096150133263728, -26.22597503039481}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3211740844998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.324572696395432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7375638448069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8992831695357282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58047127575952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.471742327540692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48778845735708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "C3", 
             Association[1 -> {
                Complex[163.3211740844998, 21.324572696395432`], 
                Complex[133.7375638448069, -0.8992831695357282]}, 2 -> {
                Complex[163.58047127575952`, -21.471742327540692`], 
                Complex[133.48778845735708`, -40.4261790532468]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.511091091515089, -26.47018665981938}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32120524368585`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57983138337912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.519550543179967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.46811085812299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "C3", 
             Association[1 -> {
                Complex[163.32120524368585`, 21.372333412759414`], 
                Complex[133.73762240273044`, -0.8568046319064777]}, 2 -> {
                Complex[163.57983138337912`, -21.519550543179967`], 
                Complex[133.4853981881505, -40.46811085812299]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5125633644245846, -26.71494146432708}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32123461759284`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.419819747199476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73767776709124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8145820782986561`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57919660355603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.56708410244111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4830160082869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.50978600446605`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.32123461759284`, 21.419819747199476`], 
                Complex[133.73767776709124`, -0.8145820782986561]}, 2 -> {
                Complex[163.57919660355603`, -21.56708410244111], 
                Complex[133.4830160082869, -40.50978600446605]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5140318710400942, -26.96023633271099}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126224790258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.467034901348015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57856686178704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32126224790258`, 21.467034901348015`], 
                Complex[133.73772999698105`, -0.7726124883003074]}, 2 -> {
                Complex[163.57856686178704`, -21.61434620967065], 
                Complex[133.48064181814095`, -40.55120751741091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5154966496921867, -27.206068189954966`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128817518404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.513982020369067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944153`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57794208515563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.661340012707413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32128817518404`, 21.513982020369067`], 
                Complex[133.73777915008168`, -0.7308928949944153]}, 2 -> {
                Complex[163.57794208515563`, -21.661340012707413`], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5169577380723973, -27.452433996597318`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32131243892846`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5773222022874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.70806860421745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.63330147714419`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "C3", 
             Association[1 -> {
                Complex[163.32131243892846`, 21.560664194292514`], 
                Complex[133.73782528270672`, -0.6894203836927915]}, 2 -> {
                Complex[163.5773222022874, -21.70806860421745], 
                Complex[133.47591701822174`, -40.63330147714419]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.51841517324741, -27.69933074810953}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32133507758377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5767071433079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.67397971146615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "C3", 
             Association[1 -> {
                Complex[163.32133507758377`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[163.5767071433079, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.67397971146615]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5198689916735526, -27.946755474289493`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135612858696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57609683979973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.800742255195683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.714415889878296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32135612858696`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[163.57609683979973`, -21.800742255195683`], 
                Complex[133.47122302955884`, -40.714415889878296`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5213192292104958, -28.194705238668774`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137562839594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5754912247639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.846693235601716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.754612782050174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32137562839594`, 21.699151145685878`], 
                Complex[133.73794610118625`, -0.5664569528154928]}, 2 -> {
                Complex[163.5754912247639, -21.846693235601716`], 
                Complex[133.46888736024792`, -40.754612782050174`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5227659211352085, -28.44317713793373}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32139361252007`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758959`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57489023258069`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007123`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32139361252007`, 21.74480338135633], 
                Complex[133.73798068907436`, -0.5259446249758959]}, 2 -> {
                Complex[163.57489023258069`, -21.89239084876425], 
                Complex[133.46655912218745`, -40.79457311007123]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5242091021543211, -28.692168301359782`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32141011554913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.79020533907295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57429379897212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4642382283995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.83429954954242`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "C3", 
             Association[1 -> {
                Complex[163.32141011554913`, 21.79020533907295], 
                Complex[133.73801251890455`, -0.4856655473715783]}, 2 -> {
                Complex[163.57429379897212`, -21.937837930174453`], 
                Complex[133.4642382283995, -40.83429954954242]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5256488064177682, -28.941675890258722`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142517118197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57370186096605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "C3", 
             Association[1 -> {
                Complex[163.32142517118197`, 21.835359803960376`], 
                Complex[133.73804163958545`, -0.4456170941100126]}, 2 -> {
                Complex[163.57370186096605`, -21.983037267377455`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5270850675298726, -29.19169709743854}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143881225352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836443967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57311435686128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.45961813380987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.913061239133484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "C3", 
             Association[1 -> {
                Complex[163.32143881225352`, 21.880269514316595`], 
                Complex[133.73806809891312`, -0.4057966836443967]}, 2 -> {
                Complex[163.57311435686128`, -22.027991601058], 
                Complex[133.45961813380987`, -40.913061239133484`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5285179185625049, -29.442229146675434`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145107076096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.924937162667188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360263`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.36620177777334817`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57253122619372`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.072703626095407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "C3", 
             Association[1 -> {
                Complex[163.32145107076096`, 21.924937162667188`], 
                Complex[133.73809194360263`, -0.36620177777334817`]}, 2 -> {
                Complex[163.57253122619372`, -22.072703626095407`], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5299473920661677, -29.6932692921977}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214619778895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.96936539678994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73811321931896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3268298806687504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5719524097037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.117175992588685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3214619778895, 21.96936539678994], 
                Complex[133.73811321931896`, -0.3268298806687504]}, 2 -> {
                Complex[163.5719524097037, -22.117175992588685`], 
                Complex[133.45502641240844`, -40.99091836543069]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5313735200815637, -29.944814818181143`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321471564036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.01355682071051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070584`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793105047`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57137784930458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.16141130685297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.02951394167229`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "C3", 
             Association[1 -> {
                Complex[163.321471564036, 22.01355682071051], 
                Complex[133.73813197070584`, -0.28767853793105047`]}, 2 -> {
                Complex[163.57137784930458`, -22.16141130685297], 
                Complex[133.45274099074845`, -41.02951394167229]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5327963341500828, -30.196863038255604`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32147985883367`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.05751399567081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141522`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.24874533567052026`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57080748805203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.0678907640604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "C3", 
             Association[1 -> {
                Complex[163.32147985883367`, 22.05751399567081], 
                Complex[133.73814824141522`, -0.24874533567052026`]}, 2 -> {
                Complex[163.57080748805203`, -22.205412132388133`], 
                Complex[133.45046242420474`, -41.0678907640604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5342158653255404, -30.449411295022532`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148689117372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816207413375`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.21002789961483614`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5702412701146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085482`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32148689117372`, 22.101239441069634`], 
                Complex[133.73816207413375`, -0.21002789961483614`]}, 2 -> {
                Complex[163.5702412701146, -22.249180990820484`], 
                Complex[133.44819063634753`, -41.10605121085482]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.535632144183358, -30.702456959582946`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214926892273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.14473563537842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56967914074468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.292720362818727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4459255521081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214926892273, 22.14473563537842], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[163.56967914074468`, -22.292720362818727`], 
                Complex[133.4459255521081, -41.14399762152054]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5370452008318745, -30.955997431075822`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214972804685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.188005017031273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.13323102192725855`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56912104625172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.3214972804685, 22.188005017031273`], 
                Complex[133.73818259167945`, -0.13323102192725855`]}, 2 -> {
                Complex[163.56912104625172`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5384550649214412, -31.21003013622651}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150069169228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937554`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56856693397444`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.379120370718276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.219257503398715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "C3", 
             Association[1 -> {
                Complex[163.32150069169228`, 22.231049985290607`], 
                Complex[133.73818935729176`, -0.09514702213937554]}, 2 -> {
                Complex[163.56856693397444`, -22.379120370718276`], 
                Complex[133.44141520081965`, -41.219257503398715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5398617656541995, -31.464552528904765`}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150294903576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.27387290108978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381938465315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.05726967062375721`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56801675225492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.42198577106388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "C3", 
             Association[1 -> {
                Complex[163.32150294903576`, 22.27387290108978], 
                Complex[133.7381938465315, -0.05726967062375721]}, 2 -> {
                Complex[163.56801675225492`, -22.42198577106388], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5412653317937435, -31.71956208969237}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150407799693`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633637513`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56747045041436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.4646312155268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.29368838106346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "C3", 
             Association[1 -> {
                Complex[163.32150407799693`, 22.316476087852756`], 
                Complex[133.73819609764354`, -0.019596778633637513`]}, 2 -> {
                Complex[163.56747045041436`, -22.4646312155268], 
                Complex[133.4369307957903, -41.29368838106346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5426657916736184, -31.975056325459914`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150410345304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.017873807828369337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56692797872756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.50705899287356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900826`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "C3", 
             Association[1 -> {
                Complex[163.32150410345304`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.017873807828369337`]}, 2 -> {
                Complex[163.56692797872756`, -22.50705899287356], 
                Complex[133.43469814900826`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5440631732068704, -32.23103276895259}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150304967848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.40103238518414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874688142`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56638928839993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4324717822431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.36730765692628`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "C3", 
             Association[1 -> {
                Complex[163.32150304967848`, 22.40103238518414], 
                Complex[133.73819403439737`, 0.05514420874688142]}, 2 -> {
                Complex[163.56638928839993`, -22.549271355908424`], 
                Complex[133.4324717822431, -41.36730765692628]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5454575038941181, -32.487488978384675`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150094036191`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56585433154422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.59127052222966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.403818232775386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "C3", 
             Association[1 -> {
                Complex[163.32150094036191`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[163.56585433154422`, -22.59127052222966], 
                Complex[133.43025162908577`, -41.403818232775386`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5468488108321929, -32.7444225370426}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149779862297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.484736744276518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818345754614`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.12909276811100767`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5653230611586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42803762425083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "C3", 
             Association[1 -> {
                Complex[163.32149779862297`, 22.484736744276518`], 
                Complex[133.73818345754614`, 0.12909276811100767`]}, 2 -> {
                Complex[163.5653230611586, -22.633058674966136`], 
                Complex[133.42803762425083`, -41.44013218836733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5482371207222962, -33.00183105289622}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149364702843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381750638226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16577500282102164`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56479543110495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.674637963494348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42582970355036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.47625154943295`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.32149364702843`, 22.526274879059077`], 
                Complex[133.7381750638226, 0.16577500282102164`]}, 2 -> {
                Complex[163.56479543110495`, -22.674637963494348`], 
                Complex[133.42582970355036`, -41.47625154943295]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.549622459878014, -33.259712158218186`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214885076075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.567606480874492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500862`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.564271396088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.716010504136886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214885076075, 22.567606480874492`], 
                Complex[133.73816464500862`, 0.2022652058581258]}, 2 -> {
                Complex[163.564271396088, -22.716010504136886`], 
                Complex[133.42362780386904`, -41.51217831040793]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5510048542329906, -33.51806350921115}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148240186692`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.608733631773358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.23856533752871556`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56375091163494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.547914435078255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32148240186692`, 22.608733631773358`], 
                Complex[133.73815223405947`, 0.23856533752871556`]}, 2 -> {
                Complex[163.56375091163494`, -22.757178380842813`], 
                Complex[133.42143186313936`, -41.547914435078255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5523843293484896, -33.77688278564266}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321475350806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.649658382119874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381378632521`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27467732815633283`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56323393407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41924182031818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "C3", 
             Association[1 -> {
                Complex[163.321475350806, 22.649658382119874`], 
                Complex[133.7381378632521, 0.27467732815633283`]}, 2 -> {
                Complex[163.56323393407584`, -22.798143645850313`], 
                Complex[133.41924182031818`, -41.58346185720893]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5537609104208678, -34.03616769048753}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32146737492982`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.69038275123732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73812156420146`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5627204205249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.838908320332727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41705761536383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.618822481156855`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "C3", 
             Association[1 -> {
                Complex[163.32146737492982`, 22.69038275123732], 
                Complex[133.73812156420146`, 0.3106030786938945]}, 2 -> {
                Complex[163.5627204205249, -22.838908320332727`], 
                Complex[133.41705761536383`, -41.618822481156855`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5551346222888804, -34.29591594957734}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145849426388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.730908728036773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381033678786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34634446131990515`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56221032886114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.653998182467525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "C3", 
             Association[1 -> {
                Complex[163.32145849426388`, 22.730908728036773`], 
                Complex[133.7381033678786, 0.34634446131990515`]}, 2 -> {
                Complex[163.56221032886114`, -22.879474395027515`], 
                Complex[133.41487918921308`, -41.653998182467525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5565054894401891, -34.55612531125721}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214487283661`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.7712382716304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38190332002009697`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56170361771126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830850002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.68899080845728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3214487283661, 22.7712382716304], 
                Complex[133.7380833046258, 0.38190332002009697`]}, 2 -> {
                Complex[163.56170361771126`, -22.919843830850002`], 
                Complex[133.41270648376008`, -41.68899080845728]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5578735360186948, -34.81679354604934}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143809634076`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.81137331192805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4172814711532169`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56120024643147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32143809634076`, 22.81137331192805], 
                Complex[133.73806140417352`, 0.4172814711532169]}, 2 -> {
                Complex[163.56120024643147`, -22.960018559490692`], 
                Complex[133.41053944183457`, -41.72380217877989]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5592387858312173, -35.07791844632328}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142661684998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.85131575022118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4524807040047172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56070017509117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.00000048399869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "C3", 
             Association[1 -> {
                Complex[163.32142661684998`, 22.85131575022118], 
                Complex[133.73803769565515`, 0.4524807040047172]}, 2 -> {
                Complex[163.56070017509117`, -23.00000048399869], 
                Complex[133.40837800718197`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5606012623535201, -35.33949782597289}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214143081261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.891067459749348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48750278132399316`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56020336445604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.039791479349606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4062221244428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.79288829603216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "C3", 
             Association[1 -> {
                Complex[163.3214143081261, 22.891067459749348`], 
                Complex[133.7380122076221, 0.48750278132399316`]}, 2 -> {
                Complex[163.56020336445604`, -23.039791479349606`], 
                Complex[133.4062221244428, -41.79288829603216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5619609887370183, -35.60152952009944}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214011879832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.93063028625468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5597097759723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.07939339299977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4040717391336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.82716654886576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "C3", 
             Association[1 -> {
                Complex[163.3214011879832, 22.93063028625468], 
                Complex[133.73798496805838`, 0.5223494398501387]}, 2 -> {
                Complex[163.5597097759723, -23.07939339299977], 
                Complex[133.4040717391336, -41.82716654886576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5633179878152299, -35.86401138470134}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213872738282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.97000604852185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55921937175077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.11880804542669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4019267976277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.86127055887851`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "C3", 
             Association[1 -> {
                Complex[163.3213872738282, 22.97000604852185], 
                Complex[133.73795600439445`, 0.5570223908239598]}, 2 -> {
                Complex[163.55921937175077`, -23.11880804542669], 
                Complex[133.4019267976277, -41.86127055887851]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5646722821089492, -36.126941296369495`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137258267184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5587321145525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.15803723065625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.89520201543604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32137258267184`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874362]}, 2 -> {
                Complex[163.5587321145525, -23.15803723065625], 
                Complex[133.39978724713728`, -41.89520201543604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5660238938330957, -36.3903171519889}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135713113917`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.04820352384075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55824796777307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.197082716776826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "C3", 
             Association[1 -> {
                Complex[163.32135713113917`, 23.04820352384075], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[163.55824796777307`, -23.197082716776826`], 
                Complex[133.39765303569465`, -41.92896258335967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5673728449018023, -36.65413686844603}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32134093547978`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508835`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6600157387690366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55776689542964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340244`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "C3", 
             Association[1 -> {
                Complex[163.32134093547978`, 23.087028744351493`], 
                Complex[133.73785903508835`, 0.6600157387690366]}, 2 -> {
                Complex[163.55776689542964`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340244]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5687191569343548, -36.9183983823416}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213240115776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.12567391653264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782343872844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6940104792034631`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55728886214564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.99597759271317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "C3", 
             Association[1 -> {
                Complex[163.3213240115776, 23.12567391653264], 
                Complex[133.73782343872844`, 0.6940104792034631]}, 2 -> {
                Complex[163.55728886214564`, -23.27462953735598], 
                Complex[133.39340042608356`, -41.99597759271317]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5700628512605073, -37.18309964970923}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32130637496067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7377862475824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7278397028767358`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55681383313836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.02923524528987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "C3", 
             Association[1 -> {
                Complex[163.32130637496067`, 23.164140732031207`], 
                Complex[133.7377862475824, 0.7278397028767358]}, 2 -> {
                Complex[163.55681383313836`, -23.313134282759357`], 
                Complex[133.39128192792896`, -42.02923524528987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5714039489259954, -37.44823864573913}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128804080997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.2024308585112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5563417742055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.351462151887404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.389168568818`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.062328432421694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "C3", 
             Association[1 -> {
                Complex[163.32128804080997`, 23.2024308585112], 
                Complex[133.73774748603233`, 0.7615049781131837]}, 2 -> {
                Complex[163.5563417742055, -23.351462151887404`], 
                Complex[133.389168568818, -42.062328432421694`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5727424706974824, -37.7138133645073}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126902396925`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55587265171218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.38961479042947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "C3", 
             Association[1 -> {
                Complex[163.32126902396925`, 23.24054594010908], 
                Complex[133.73770717799474`, 0.7950078509907748]}, 2 -> {
                Complex[163.55587265171218`, -23.38961479042947], 
                Complex[133.3870603006344, -42.095258703120926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5740784370681291, -37.97982181870968}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32124933895304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.278487597877273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8283498457615899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.555406432579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "C3", 
             Association[1 -> {
                Complex[163.32124933895304`, 23.278487597877273`], 
                Complex[133.73766534693092`, 0.8283498457615899]}, 2 -> {
                Complex[163.555406432579, -23.427593820972138`], 
                Complex[133.38495707598477`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5754118682619429, -38.246262039401344`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3212289999553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.316257430218013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55494308426918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.465400843433205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "C3", 
             Association[1 -> {
                Complex[163.3212289999553, 23.316257430218013`], 
                Complex[133.73762201585797`, 0.8615324652630996]}, 2 -> {
                Complex[163.55494308426918`, -23.465400843433205`], 
                Complex[133.38285884818328`, -42.16063658240298]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.13577283982491445`, -0.7127814712321852}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.28874619752557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7971642905074585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570581`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.23691779950178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.18662852277594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "B2", 
             Association[1 -> {
                Complex[98.28874619752557, -4.7971642905074585`], 
                Complex[65.24911579537864, -27.64012489570581]}, 2 -> {
                Complex[109.23691779950178`, 2.18662852277594], 
                Complex[77.64033476497889, -18.555519955729697`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.1968015804875642, -0.6722828605051576}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.53721317940925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745143`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"109.00291862294868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.3161717918490905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "B2", 
             Association[1 -> {
                Complex[98.53721317940925, -4.913723373745143], 
                Complex[65.55225475967481, -27.752753616885617`]}, 2 -> {
                Complex[109.00291862294868`, 2.3161717918490905`], 
                Complex[77.35779210787567, -18.413383510132928`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.25508760947395154`, -0.6303180569180318}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"98.78413028654842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323114`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.878898314229872`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.77039874007265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.4568600959134304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.07605386722263`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.25790704700182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "B2", 
             Association[1 -> {
                Complex[98.78413028654842, -5.041549120388238], 
                Complex[65.85454597323114, -27.878898314229872`]}, 2 -> {
                Complex[108.77039874007265`, 2.4568600959134304`], 
                Complex[77.07605386722263, -18.25790704700182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3106563140629583, -0.5867569878830883}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.02804001157145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.01910818767796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.54081619894502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.609059345791207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "B2", 
             Association[1 -> {
                Complex[99.02804001157145, -5.181005750282824], 
                Complex[66.15429146185949, -28.01910818767796]}, 2 -> {
                Complex[108.54081619894502`, 2.609059345791207], 
                Complex[76.79681813580558, -18.08853939018387]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.36355071705577807`, -0.5414670472470513}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.26731766471846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.31579622511974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.7728363828323817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138215`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453784`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "B2", 
             Association[1 -> {
                Complex[99.26731766471846, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[108.31579622511974`, 2.7728363828323817`], 
                Complex[76.52200482138215, -17.905070014453784`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.41383292640393216`, -0.4943169257105582}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.50025760773303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.494703423518458`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"108.09704498777202`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.947889052723903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "B2", 
             Association[1 -> {
                Complex[99.50025760773303, -5.494703423518458], 
                Complex[66.73834077690572, -28.342127551799617`]}, 2 -> {
                Complex[108.09704498777202`, 2.947889052723903], 
                Complex[76.25365917077403, -17.707718667136945`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4615844072869117, -0.4451810640085758}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.7251916573151`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684691`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.88623119627513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813974`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050531`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "B2", 
             Association[1 -> {
                Complex[99.7251916573151, -5.667931881684691], 
                Complex[67.01856624754146, -28.52401138363128]}, 2 -> {
                Complex[107.88623119627513`, 3.1335101509494754`], 
                Complex[75.99381453813974, -17.49718747050531]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5069047998440703, -0.39394424236233916`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"99.94062195496076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.850744106324539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.68485323039285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "B2", 
             Association[1 -> {
                Complex[99.94062195496076, -5.850744106324539], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[107.68485323039285`, 3.3286015323523155`], 
                Complex[75.74433404826092, -17.274654824395935`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.549909263092365, -0.34050569394334196`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.14534197436598`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.041718331746126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.49411813290735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.5317429709640535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "B2", 
             Association[1 -> {
                Complex[100.14534197436598`, -6.041718331746126], 
                Complex[67.54625247327428, -28.92269792171125]}, 2 -> {
                Complex[107.49411813290735`, 3.5317429709640535`], 
                Complex[75.5067619380703, -17.041703592935647`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5907246335021961, -0.2847821678236142}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.33851976726778`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.2392230198151415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.136053013844258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.31485836381162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.741304440227348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.80019492108791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "B2", 
             Association[1 -> {
                Complex[100.33851976726778`, -6.2392230198151415`], 
                Complex[67.79105133862652, -29.136053013844258`]}, 2 -> {
                Complex[107.31485836381162`, 3.741304440227348], 
                Complex[75.28221611377315, -16.80019492108791]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.6294849297314664, -0.22670957473178685`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.51972815298026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663402`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"107.147501610807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.95557787197075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.552114786374766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "B2", 
             Association[1 -> {
                Complex[100.51972815298026`, -6.441548618274492], 
                Complex[68.02213623225066, -29.356140607663402`]}, 2 -> {
                Complex[107.147501610807, 3.95557787197075], 
                Complex[75.07134191761347, -16.552114786374766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.6663268206695301, -0.1662431502926862}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"B2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.68892233695162`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.647031679680729`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.58099676114603`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.99209317078063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.172901275980765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "B2", 
             Association[1 -> {
                Complex[100.68892233695162`, -6.647031679680729], 
                Complex[68.23931794822644, -29.58099676114603]}, 2 -> {
                Complex[106.99209317078063`, 4.172901275980765], 
                Complex[74.87432868509478, -16.299425400573043`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.02470076637099794, -0.6017093977782277}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.17308560823099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.79716429050747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.121257210207155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.1866285227759508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729686`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A2", 
             Association[1 -> {
                Complex[43.17308560823099, -4.79716429050747], 
                Complex[65.24911579537869, -27.64012489570582]}, 2 -> {
                Complex[54.121257210207155`, 2.1866285227759508`], 
                Complex[77.64033476497889, -18.555519955729686`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.08572950703357662, -0.561210787051202}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.42155259011466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.88725803365406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.316171791849095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A2", 
             Association[1 -> {
                Complex[43.42155259011466, -4.913723373745142], 
                Complex[65.55225475967484, -27.752753616885613`]}, 2 -> {
                Complex[53.88725803365406, 2.316171791849095], 
                Complex[77.35779210787565, -18.413383510132924`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.14401553601994976`, -0.5192459834640708}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.6684696972538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87889831422985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.654738150778094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.45686009591344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.0760538672227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.257907047001805`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A2", 
             Association[1 -> {
                Complex[43.6684696972538, -5.041549120388218], 
                Complex[65.85454597323113, -27.87889831422985]}, 2 -> {
                Complex[53.654738150778094`, 2.45686009591344], 
                Complex[77.0760538672227, -18.257907047001805`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.19958424060898494`, -0.47568491442913086`}],
            
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.91237942227682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.019108187677965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.42515560965041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.609059345791205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A2", 
             Association[1 -> {
                Complex[43.91237942227682, -5.181005750282827], 
                Complex[66.15429146185946, -28.019108187677965`]}, 2 -> {
                Complex[53.42515560965041, 2.609059345791205], 
                Complex[76.79681813580557, -18.08853939018387]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.2524786436017905, -0.43039497379308855`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.15165707542385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.20013563582517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.7728363828323297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453845`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "A2", 
             Association[1 -> {
                Complex[44.15165707542385, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[53.20013563582517, 2.7728363828323297`], 
                Complex[76.52200482138221, -17.905070014453845`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3027608529499588, -0.38324485225660254`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.38459701843839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4947034235184535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799614`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.98138439847741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.947889052723883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A2", 
             Association[1 -> {
                Complex[44.38459701843839, -5.4947034235184535`], 
                Complex[66.73834077690567, -28.342127551799614`]}, 2 -> {
                Complex[52.98138439847741, 2.947889052723883], 
                Complex[76.25365917077403, -17.707718667136962`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           
           TooltipBox[PointBox[{0.35051233383292413`, -0.33410899055461485`}],
            
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.60953106802053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363132`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.770570606980506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050529`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A2", 
             Association[1 -> {
                Complex[44.60953106802053, -5.667931881684722], 
                Complex[67.01856624754153, -28.52401138363132]}, 2 -> {
                Complex[52.770570606980506`, 3.1335101509494954`], 
                Complex[75.99381453813973, -17.49718747050529]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.3958327263900969, -0.2828721689083906}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.82496136566615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.8507441063245365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.569192641098226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "A2", 
             Association[1 -> {
                Complex[44.82496136566615, -5.8507441063245365`], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[52.569192641098226`, 3.3286015323523053`], 
                Complex[75.74433404826091, -17.274654824395945`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.43883718963846263`, -0.2294336204893881}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.02968138507134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.041718331746136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.37845754361273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.5317429709640207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935683`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "A2", 
             Association[1 -> {
                Complex[45.02968138507134, -6.041718331746136], 
                Complex[67.54625247327425, -28.92269792171126]}, 2 -> {
                Complex[52.37845754361273, 3.5317429709640207`], 
                Complex[75.5067619380703, -17.041703592935683`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.4796525600482511, -0.173710094369655}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.22285917797315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239223019815121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.13605301384424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.199197774517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.7413044402273425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.800194921087922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A2", 
             Association[1 -> {
                Complex[45.22285917797315, -6.239223019815121], 
                Complex[67.79105133862647, -29.13605301384424]}, 2 -> {
                Complex[52.199197774517, 3.7413044402273425`], 
                Complex[75.28221611377315, -16.800194921087922`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5184128562775072, -0.1156375012778259}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.404067563685665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663413`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.03184102151237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.9555778719707466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.55211478637477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A2", 
             Association[1 -> {
                Complex[45.404067563685665`, -6.441548618274501], 
                Complex[68.02213623225067, -29.356140607663413`]}, 2 -> {
                Complex[52.03184102151237, 3.9555778719707466`], 
                Complex[75.07134191761345, -16.55211478637477]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5552547472155709, -0.055171076838728794`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A2\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.57326174765701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.64703167968071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.580996761146004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.87643258148602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.172901275980756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A2", 
             Association[1 -> {
                Complex[45.57326174765701, -6.64703167968071], 
                Complex[68.23931794822644, -29.580996761146004`]}, 2 -> {
                Complex[51.87643258148602, 4.172901275980756], 
                Complex[74.87432868509478, -16.299425400573057`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.5903135136918252, 0.007715724253527512}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.730718127418484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.73269655459702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.391754775223062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.04394673660354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A3", 
             Association[1 -> {
                Complex[45.730718127418484`, -6.854150896006849], 
                Complex[68.44279858874026, -29.808799798905298`]}, 2 -> {
                Complex[51.73269655459702, 4.391754775223062], 
                Complex[74.69097444463986, -16.04394673660354]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.6237198366388554, 0.07303322136307422}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.87695378596401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.037946713787587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.600116350932254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "A3", 
             Association[1 -> {
                Complex[45.87695378596401, -7.061586259363513], 
                Complex[68.63308108602179, -30.037946713787587`]}, 2 -> {
                Complex[51.600116350932254`, 4.610819767164111], 
                Complex[74.52077639558696, -15.787280126334567`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.6555975264614489, 0.14077797037933415`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.012644400278134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.478016782014386`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.829003095065925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.3630260491026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "A3", 
             Association[1 -> {
                Complex[46.012644400278134`, -7.268243232709627], 
                Complex[68.81087406136677, -30.267088315852067`]}, 2 -> {
                Complex[51.478016782014386`, 4.829003095065925], 
                Complex[74.3630260491026, -15.530773111018974`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.6860621379798744, 0.21093533957876254`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.1385523728934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.473250095934392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818545`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.36563592928112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.045434394635397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.21689441876435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A3", 
             Association[1 -> {
                Complex[46.1385523728934, -7.473250095934392], 
                Complex[68.97700663449255, -30.495131845818545`]}, 2 -> {
                Complex[51.36563592928112, 5.045434394635397], 
                Complex[74.21689441876435, -15.275516827279347`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7152203181601635, 0.2834819494647576}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.25547057364814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.67593833538152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.72122229359378`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.26218140236398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.259446484100554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.08150010532468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029509`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A3", 
             Association[1 -> {
                Complex[46.25547057364814, -7.67593833538152], 
                Complex[69.13236033871479, -30.72122229359378]}, 2 -> {
                Complex[51.26218140236398, 5.259446484100554], 
                Complex[74.08150010532468, -15.022364688029509`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7431697018025716, 0.3583878343260718}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.36418227688922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.875814674529089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.94471254171957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.166870401922736`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489209`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A3", 
             Association[1 -> {
                Complex[46.36418227688922, -7.875814674529089], 
                Complex[69.27781951812032, -30.94471254171957]}, 2 -> {
                Complex[51.166870401922736`, 5.470547395427036], 
                Complex[73.95595889948115, -14.771962238489209`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7699991809169262, 0.43561826775259327`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.465435189789666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737157`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.07895569136514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.678390200428087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.8394169010038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "A3", 
             Association[1 -> {
                Complex[46.465435189789666`, -8.07253089957758], 
                Complex[69.41423820838506, -31.16512977737157]}, 2 -> {
                Complex[51.07895569136514, 5.678390200428087], 
                Complex[73.8394169010038, -14.524780743662301`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7957894044969578, 0.5151352503396076}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.55992646557226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.265855214912738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.99774058366105`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.882744366735128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.281149844042137`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "A3", 
             Association[1 -> {
                Complex[46.55992646557226, -8.265855214912738], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[50.99774058366105, 5.882744366735128], 
                Complex[73.73107052942778, -14.281149844042137`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8206134013774147, 0.5968986891273307}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.64829561564561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.455646996018187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.59553293132246`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.92258602924393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.083470511204362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.6301769260447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846566`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "A3", 
             Association[1 -> {
                Complex[46.64829561564561, -8.455646996018187], 
                Complex[69.66310826637462, -31.59553293132246]}, 2 -> {
                Complex[50.92258602924393, 6.083470511204362], 
                Complex[73.6301769260447, -14.041286825846566`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8445372514866989, 0.6808673120301005}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.73112272554318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.641835576592952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.80516872809565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.85291240010994`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.280499187514896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A3", 
             Association[1 -> {
                Complex[46.73112272554318, -8.641835576592952], 
                Complex[69.77698109299793, -31.80516872809565]}, 2 -> {
                Complex[50.85291240010994, 6.280499187514896], 
                Complex[73.53605776440253, -13.805321546316236`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8676207568936576, 0.7669993633104202}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.80892999564075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.82440299828263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.010985835765666`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.788197949138606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.4480988144794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041144`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A3", 
             Association[1 -> {
                Complex[46.80892999564075, -8.82440299828263], 
                Complex[69.88465297350923, -32.010985835765666`]}, 2 -> {
                Complex[50.788197949138606`, 6.473813636367646], 
                Complex[73.4480988144794, -13.573316941041144`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8899180832778342, 0.8552531230888292}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.882185196050116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.72797535523715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.6634360796057495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "A3", 
             Association[1 -> {
                Complex[46.882185196050116`, -9.003370304344577], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[50.72797535523715, 6.6634360796057495`], 
                Complex[73.36574696131454, -13.345285495813705`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9114783558124628, 0.9455872882353109}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.951306082313856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.671827307684104`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250492988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A3", 
             Association[1 -> {
                Complex[46.951306082313856`, -9.178786832849886], 
                Complex[70.08355015001808, -32.41114577568788]}, 2 -> {
                Complex[50.671827307684104`, 6.849417013859745], 
                Complex[73.2885058483752, -13.121202250492988`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9323462022779552, 1.0379612456771223`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.016665157888184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.350721960698461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.1757166401882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.60556303669796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.61938174368467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.031826954994077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.016665157888184`, -9.350721960698461], 
                Complex[70.1757166401882, -32.60556303669796]}, 2 -> {
                Complex[50.61938174368467, 7.031826954994077], 
                Complex[73.21593091512594, -12.901014934479544`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9525622417776844, 1.1323352631745802`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.078594407914174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.79629250746041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.570307114637814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.1476243120753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.078594407914174`, -9.519258803308224], 
                Complex[70.26357461989492, -32.79629250746041]}, 2 -> {
                Complex[50.570307114637814`, 7.210750138216329], 
                Complex[73.1476243120753, -12.684651789041993`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9721635207306605, 1.2286706173892004`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.13738978959499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.68448944959141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.983418096522826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.52430789579726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.386279753462804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.13738978959499, -9.68448944959141], 
                Complex[70.34748028709403, -32.983418096522826`]}, 2 -> {
                Complex[50.52430789579726, 7.386279753462804], 
                Complex[73.08322998054211, -12.472027556181573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9911838996205518, 1.32692967471597}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.19331536912255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.846511388382378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.1670326786391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.48112044938315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.558514372224588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.26304803157383`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "A3", 
             Association[1 -> {
                Complex[47.19331536912255, -9.846511388382378], 
                Complex[70.42775264717702, -33.1670326786391]}, 2 -> {
                Complex[50.48112044938315, 7.558514372224588], 
                Complex[73.02242905463167, -12.26304803157383]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0096543948321823`, 1.4270759368368466`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.24660706078816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.00542485182525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771441998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654395`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.44050928550963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.727555291323419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "A3", 
             Association[1 -> {
                Complex[47.24660706078816, -10.00542485182525], 
                Complex[70.50467771441998, -33.34723465654395]}, 2 -> {
                Complex[50.44050928550963, 7.727555291323419], 
                Complex[72.96493565975211, -12.057613502401406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0276034801653964`, 1.5290740601688793`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.29747596348612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.161330860116289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.524125383471365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.402263725719145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "A3", 
             Association[1 -> {
                Complex[47.29747596348612, -10.161330860116289`], 
                Complex[70.57851229402165, -33.524125383471365`]}, 2 -> {
                Complex[50.402263725719145`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452313`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0450573525308755`, 1.6328898562067735`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.34611131233811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.69780724710277`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.36619495139631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.056463649045714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "A3", 
             Association[1 -> {
                Complex[47.34611131233811, -10.314329800105746`], 
                Complex[70.64948735230315, -33.69780724710277]}, 2 -> {
                Complex[50.36619495139631, 8.056463649045714], 
                Complex[72.85887064064234, -11.656967837798806`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0620401660549987`, 1.7384902780777303`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.39268307483162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.464520408616714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.86838226002102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.3321334076672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.2165322541574`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.8098602198848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597864`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "A3", 
             Association[1 -> {
                Complex[47.39268307483162, -10.464520408616714`], 
                Complex[70.71781099948186, -33.86838226002102]}, 2 -> {
                Complex[50.3321334076672, 8.2165322541574], 
                Complex[72.8098602198848, -11.46154977597864]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0785742384532284`, 1.8458433973321728`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.4373442258159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.611999061422935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.03595103690155`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.29992652844131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.373807765588333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.269265288448755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "A3", 
             Association[1 -> {
                Complex[47.4373442258159, -10.611999061422935`], 
                Complex[70.78367111767889, -34.03595103690155]}, 2 -> {
                Complex[50.29992652844131, 8.373807765588333], 
                Complex[72.76327412626179, -11.269265288448755`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.094680233130802, 1.9549183740042064`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.48023273663557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.75685929217107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.84723766978762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.20061206617882`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.26943674731541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.52838469724979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A3", 
             Association[1 -> {
                Complex[47.48023273663557, -10.75685929217107], 
                Complex[70.84723766978762, -34.20061206617882]}, 2 -> {
                Complex[50.26943674731541, 8.52838469724979], 
                Complex[72.71894253702615, -11.080014668572227`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1103773200755143`, 2.0656854222189622`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.52147331234387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.89919148351823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.90866472468208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.24053976039788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.680354396213662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.52147331234387, -10.89919148351823], 
                Complex[70.90866472468208, -34.36246120528307]}, 2 -> {
                Complex[50.24053976039788, 8.680354396213662], 
                Complex[72.67671152345633, -10.893700858042976`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1256833182308696`, 2.1781157730480274`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.561178908409175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.21312300963941`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.829804862450947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159116`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.561178908409175`, -11.039082686546374`], 
                Complex[70.96809223235843, -34.52159134503682]}, 2 -> {
                Complex[50.21312300963941, 8.829804862450947], 
                Complex[72.6364412756889, -10.710229782159116`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1406148217004528`, 2.2921816358766023`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.59945205528385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.17661653505851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.1870843583013`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.9768206634439`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.59945205528385, -11.17661653505851], 
                Complex[71.02564757984514, -34.67809220149987]}, 2 -> {
                Complex[50.1870843583013, 8.9768206634439], 
                Complex[72.59800454678344, -10.529510557655934`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.155187311825614, 2.4078561592124643`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.636386016039125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.16233093335741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.121482918322886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "A3", 
             Association[1 -> {
                Complex[47.636386016039125`, -11.311873229407055`], 
                Complex[71.08144695562096, -34.83205020330796]}, 2 -> {
                Complex[50.16233093335741, 9.121482918322886], 
                Complex[72.56128528828063, -10.351455605052497`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1694152569120746`, 2.525113391615095}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.672065799209136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.983548450042505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.138778112686914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.26386933231359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.175980689974885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "A3", 
             Association[1 -> {
                Complex[47.672065799209136`, -11.444929570640568`], 
                Complex[71.13559654715354, -34.983548450042505`]}, 2 -> {
                Complex[50.138778112686914`, 9.26386933231359], 
                Complex[72.52617745264078, -10.175980689974885`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1833122011420585`, 2.6439282432314855`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.70656904615111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.575859030428859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.13266672291677`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.116348637750534`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.40405426695551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.003004912170228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "A3", 
             Association[1 -> {
                Complex[47.70656904615111, -11.575859030428859`], 
                Complex[71.18819359319453, -35.13266672291677]}, 2 -> {
                Complex[50.116348637750534`, 9.40405426695551], 
                Complex[72.49258394092674, -10.003004912170228`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1968908440055515`, 2.764276448281205}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.73996680966804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.704731845790777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.27948153347702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.09497183500416`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.542108835115947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "A3", 
             Association[1 -> {
                Complex[47.73996680966804, -11.704731845790777`], 
                Complex[71.23932730972692, -35.27948153347702]}, 2 -> {
                Complex[50.09497183500416, 9.542108835115947], 
                Complex[72.46041567683548, -9.832450656512503]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2101631114055067`, 2.8861345287240816`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.77232423836924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.831615130363643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.4240661994061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.07458293157423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.678101012538281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A3", 
             Association[1 -> {
                Complex[47.77232423836924, -11.831615130363643`], 
                Complex[71.28907970599505, -35.4240661994061]}, 2 -> {
                Complex[50.07458293157423, 9.678101012538281], 
                Complex[72.42959079064792, -9.664243516913515]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2231402194385765`, 3.0094797592618843`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.80370117925396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.956572996022805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.56649093911878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.05512245271003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40003389885213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "A3", 
             Association[1 -> {
                Complex[47.80370117925396, -11.956572996022805`], 
                Complex[71.33752630486225, -35.56649093911878]}, 2 -> {
                Complex[50.05512245271003, 9.812095759734234], 
                Complex[72.40003389885213, -9.498312201447764]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2358327317210893`, 3.1342901337645372`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.834152709273475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.706822978841465`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.036535690257004`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.944155149605944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.33458842500021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "A3", 
             Association[1 -> {
                Complex[47.834152709273475`, -12.079666680238098`], 
                Complex[71.38473677982421, -35.706822978841465`]}, 2 -> {
                Complex[50.036535690257004`, 9.944155149605944], 
                Complex[72.37167546711125, -9.33458842500021]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2482506110152798`, 3.2605443331656367`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.86372960513274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.20095467575531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.845126667405935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.01877223289047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.074338497386961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A3", 
             Association[1 -> {
                Complex[47.86372960513274, -12.20095467575531], 
                Complex[71.43077551933807, -35.845126667405935`]}, 2 -> {
                Complex[50.01877223289047, 10.074338497386961`], 
                Complex[72.34445124591687, -9.173006794205872]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2604032658140483`, 3.388221694838929}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.892478759305945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.00178555013501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.202702490405663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267268`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A3", 
             Association[1 -> {
                Complex[47.892478759305945`, -12.320492860106404`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[50.00178555013501, 10.202702490405663`], 
                Complex[72.31830176971437, -9.013504688267268]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2722995924563207`, 3.5173021834427054`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.92044354913625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.438334623148688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.5195718702971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.98553262329957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.329301315871618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29317191153511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.85602213832465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A3", 
             Association[1 -> {
                Complex[47.92044354913625, -12.438334623148688`], 
                Complex[71.5195718702971, -36.11589271440042]}, 2 -> {
                Complex[49.98553262329957, 10.329301315871618`], 
                Complex[72.29317191153511, -8.85602213832465]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2839480132739425`, 3.647766363202148}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.947664164943085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.554530991361462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.969973617404506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.45418678541366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "A3", 
             Association[1 -> {
                Complex[47.947664164943085`, -12.554530991361462`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[49.969973617404506`, 10.45418678541366], 
                Complex[72.26901048624575, -8.700501707354443]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.295356511207686, 3.7795953715872255`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.97417790224991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.66913074802967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.6043424637563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.37925086296772`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.955071588988176`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.577408455499175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033514`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "A3", 
             Association[1 -> {
                Complex[47.97417790224991, -12.66913074802967], 
                Complex[71.6043424637563, -36.37925086296772]}, 2 -> {
                Complex[49.955071588988176`, 10.577408455499175`], 
                Complex[72.24576989645067, -8.546888372033514]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3065326612746588`, 3.912770894335644}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.00001942255101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50828567419364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.94079222537401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.699013743166008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594679`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.00001942255101, -12.782180548745712`], 
                Complex[71.64533551387005, -36.50828567419364]}, 2 -> {
                Complex[49.94079222537401, 10.699013743166008`], 
                Complex[72.22340581587778, -8.395129407594679]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3174836592245356`, 4.047275141765628}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.02522098644102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.893725031887865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.635624466775916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.92710361157446`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.8190480367257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.02522098644102, -12.893725031887865`], 
                Complex[71.68545669700364, -36.635624466775916`]}, 2 -> {
                Complex[49.92710361157446, 10.8190480367257], 
                Complex[72.20187690576324, -8.245174276383164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3282163476798559`, 4.183090826319688}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.04981266242253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.00380692390271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.76131474751435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.9139760215171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.93755480126541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.096974520583906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.04981266242253, -13.00380692390271], 
                Complex[71.72474475596931, -36.76131474751435]}, 2 -> {
                Complex[49.9139760215171, 10.93755480126541], 
                Complex[72.18114456033722, -8.096974520583906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.338737240020535, 4.320201141280055}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.073822514268066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.112467139344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.88540205861425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.901381730715414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.950483659405908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "A3", 
             Association[1 -> {
                Complex[48.073822514268066`, -13.112467139344405`], 
                Complex[71.76323592906267, -36.88540205861425]}, 2 -> {
                Complex[49.901381730715414`, 11.054575678901632`], 
                Complex[72.16117267801965, -7.950483659405908]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3490525422431858`, 4.45858974059605}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.097276769439844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.88929484788194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.170150583829274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.805657090873341`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "A3", 
             Association[1 -> {
                Complex[48.097276769439844`, -13.219744875714255`], 
                Complex[71.80096415610163, -37.00793007567815]}, 2 -> {
                Complex[49.88929484788194, 11.170150583829274`], 
                Complex[72.1419274553698, -7.805657090873341]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3591681729981104`, 4.598240719764654}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.12019997074639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.12894070104982`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.8776911633041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.28431779227576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "A3", 
             Association[1 -> {
                Complex[48.12019997074639, -13.325677703210104`], 
                Complex[71.83796126429178, -37.12894070104982]}, 2 -> {
                Complex[49.8776911633041, 11.28431779227576], 
                Complex[72.1233772012094, -7.662451998269178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3690897819836323`, 4.739138597707084}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.142615113138476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.430301649540363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.248474152540204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.86654801208047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.397114027514972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "A3", 
             Association[1 -> {
                Complex[48.142615113138476`, -13.430301649540363`], 
                Complex[71.8742571361754, -37.248474152540204`]}, 2 -> {
                Complex[49.86654801208047, 11.397114027514972`], 
                Complex[72.10549216866305, -7.520827261201417]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3788227668582493`, 4.881268299586154}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.16454376730663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.533651279988442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.366569047621205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.85584415055513`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.508574540127224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.38074337120608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.16454376730663, -13.533651279988442`], 
                Complex[71.90987986163972, -37.366569047621205`]}, 2 -> {
                Complex[49.85584415055513, 11.508574540127224`], 
                Complex[72.08824440313957, -7.38074337120608]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3883722888118513`, 5.024615140511219}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.186006191536734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.63575977293281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94485587571889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.84555964449377`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0716076045205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A3", 
             Association[1 -> {
                Complex[48.186006191536734`, -13.63575977293281], 
                Complex[71.94485587571889, -37.483262483211874`]}, 2 -> {
                Complex[49.84555964449377, 11.618733183710322`], 
                Complex[72.0716076045205, -7.242162351762072]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3977432869232302`, 5.169164810080449}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.20702143310045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.736658991038883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.83567576772439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A3", 
             Association[1 -> {
                Complex[48.20702143310045, -13.736658991038883`], 
                Complex[71.97921008371291, -37.59859011120972]}, 2 -> {
                Complex[49.83567576772439, 11.727622486258118`], 
                Complex[72.05555700203159, -7.105047682565447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4069404914154404`, 5.314903357711966}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.22760742030328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.836379548343533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.82617491012043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.22760742030328, -13.836379548343533`], 
                Complex[72.01296597496555, -37.712586209936944`]}, 2 -> {
                Complex[49.82617491012043, 11.835273717427539`], 
                Complex[72.04006924045628, -6.969364227892692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4159684359111822`, 5.461817178718537}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.24778104617793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.934950873453174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.81704049393779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.835078168871881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.24778104617793, -13.934950873453174`], 
                Complex[72.04614572648373, -37.82528375168293]}, 2 -> {
                Complex[49.81704049393779, 11.941716951915161`], 
                Complex[72.02512227650753, -6.835078168871881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.424831468777242, 5.609893001082423}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.2675582446947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.032401269072565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07877029744378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.93671446652881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.80825689763537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.046981129160331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.2675582446947, -14.032401269072565`], 
                Complex[72.07877029744378, -37.93671446652881]}, 2 -> {
                Complex[49.80825689763537, 12.046981129160331`], 
                Complex[72.01069528431421, -6.702156939475872]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4335337636395735`, 5.759117872890208}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.28695406025804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.12875796807638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1108595155086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.04690890264222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.79980938640803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.151094109587378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "A3", 
             Association[1 -> {
                Complex[48.28695406025804, -14.12875796807638], 
                Complex[72.1108595155086, -38.04690890264222]}, 2 -> {
                Complex[49.79980938640803, 12.151094109587378`], 
                Complex[71.99676856909558, -6.570569166048992]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4420793291409382`, 5.909479150388783}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.305982711170586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.155896483227494`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.791684048752806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.983323488207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181978`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "A3", 
             Association[1 -> {
                Complex[48.305982711170586`, -14.22404718632718], 
                Complex[72.14243215577531, -38.155896483227494`]}, 2 -> {
                Complex[49.791684048752806`, 12.254082727590417`], 
                Complex[71.983323488207, -6.440284610181978]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.450472018007062, 6.0609644866270145`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.32465764766804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.31829417243562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.783867738463265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.35597284145664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.31127411475293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "A3", 
             Association[1 -> {
                Complex[48.32465764766804, -14.31829417243562], 
                Complex[72.17350601308073, -38.263705560313795`]}, 2 -> {
                Complex[49.783867738463265`, 12.35597284145664], 
                Complex[71.97034237882725, -6.31127411475293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.458715535479513, 6.213561820648909}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.342991605060675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.411523254649312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.776348021517336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "A3", 
             Association[1 -> {
                Complex[48.342991605060675`, -14.411523254649312`], 
                Complex[72.20409796831112, -38.37036346555746]}, 2 -> {
                Complex[49.776348021517336`, 12.456789380414614`], 
                Complex[71.95780849164257, -6.183509552957572]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.466813447168505, 6.367259367206749}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.360996652457885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.503757885046658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.769113127381615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.556556388984413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "A3", 
             Association[1 -> {
                Complex[48.360996652457885`, -14.503757885046658`], 
                Complex[72.23422404929191, -38.47589655822829]}, 2 -> {
                Complex[49.769113127381615`, 12.556556388984413`], 
                Complex[71.94570592995045, -6.056963780158599]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.474769186373834, 6.522045606964394}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.37868423749987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.595020681203493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054337`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.76215190430832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.655297068796713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9340195936706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391596`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "A3", 
             Association[1 -> {
                Complex[48.37868423749987, -14.595020681203493`], 
                Complex[72.2638994867713, -38.58033027054337]}, 2 -> {
                Complex[49.76215190430832, 12.655297068796713`], 
                Complex[71.9340195936706, -5.931610588391596]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4825860609165602`, 6.677909277162623}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.39606522747497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.685333465489398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.75545377824624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.753033818038535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A3", 
             Association[1 -> {
                Complex[48.39606522747497, -14.685333465489398`], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[49.75545377824624, 12.753033818038535`], 
                Complex[71.92273512780362, -5.807424663371904]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.490267259521488, 6.834839362720814}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.41314994716061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.77471730214245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.785996902375146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.74900871502786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.849788268674175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.91183887492751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.41314994716061, -14.77471730214245], 
                Complex[72.32195567400862, -38.785996902375146`]}, 2 -> {
                Complex[49.74900871502786, 12.849788268674175`], 
                Complex[71.91183887492751, -5.684381543854791]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4978158577852838`, 6.992825087749708}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.42994821369015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.86319253226119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.8872764249728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7428071855302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.945581321580041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209822`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.42994821369015, -14.86319253226119], 
                Complex[72.35036334387817, -38.8872764249728]}, 2 -> {
                Complex[49.7428071855302, 12.945581321580041`], 
                Complex[71.90131783136438, -5.562457583209822]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5052348237633169`, 7.151855907452969}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.446469368716585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.950778806844472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73684013353857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.040433179724607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.446469368716585`, -14.950778806844472`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[49.73684013353857, 13.040433179724607`], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5125270232037735`, 7.3119215003953855`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.46272230811621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.037495118001443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.08683856553305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73109894607003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.134363379515118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "A3", 
             Association[1 -> {
                Complex[48.46272230811621, -15.037495118001443`], 
                Complex[72.40600046967194, -39.08683856553305]}, 2 -> {
                Complex[49.73109894607003, 13.134363379515118`], 
                Complex[71.88135238627332, -5.321876408978639]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5196952244566688`, 7.473011761118059}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.47871550945055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.123359828445732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72557542593836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.227390820426002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "A3", 
             Association[1 -> {
                Complex[48.47871550945055, -15.123359828445732`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[49.72557542593836, 13.227390820426002`], 
                Complex[71.8718848966287, -5.203175657776082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5267421030816166`, 7.635116793080947}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.494457057382995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.20839069938103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72026176636399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.31953379301555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.08550692685011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "A3", 
             Association[1 -> {
                Complex[48.494457057382995`, -15.20839069938103], 
                Complex[72.46014358718853, -39.28254398107672]}, 2 -> {
                Complex[49.72026176636399, 13.31953379301555], 
                Complex[71.86274637325921, -5.08550692685011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5336702461768397`, 7.798226901915633}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.50995466722706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.292604916877659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7151505274519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.410810005430928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A3", 
             Association[1 -> {
                Complex[48.50995466722706, -15.292604916877659`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[49.7151505274519, 13.410810005430928`], 
                Complex[71.85392653085567, -4.968850134912987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5404821564495421`, 7.9623325889713}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.52521570678645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.376019116833605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.710234614377775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.52521570678645, -15.376019116833605`], 
                Complex[72.51287796992378, -39.47455031651175]}, 2 -> {
                Complex[49.710234614377775`, 13.501236608494983`], 
                Complex[71.84541553560709, -4.853185824347898]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5471802560469996`, 8.127424545138155}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.54024721663022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70550725713841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.590830219461864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7384951349874775`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "A3", 
             Association[1 -> {
                Complex[48.54024721663022, -15.458649408607112`], 
                Complex[72.53874152941212, -39.56921287503744]}, 2 -> {
                Complex[49.70550725713841, 13.590830219461864`], 
                Complex[71.83720397946203, -4.7384951349874775`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5537668901644963`, 8.293493644934}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.55505592893432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.540511397402028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70096199173561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.679606944523012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "A3", 
             Association[1 -> {
                Complex[48.55505592893432, -15.540511397402028`], 
                Complex[72.56428164388791, -39.66300535954416]}, 2 -> {
                Complex[49.70096199173561, 13.679606944523012`], 
                Complex[71.82928285617803, -4.624759779245359]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5602443304462525`, 8.460530940839796}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.56964828500726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.621620205482065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.75594483692522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69659264267576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.767582400139355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8216435390141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.511962018521162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A3", 
             Association[1 -> {
                Complex[48.56964828500726, -15.621620205482065`], 
                Complex[72.58950706494943, -39.75594483692522]}, 2 -> {
                Complex[49.69659264267576, 13.767582400139355`], 
                Complex[71.8216435390141, -4.511962018521162]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5666147781940651`, 8.628527657871523}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.5840304516069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.701990492284674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.848047855290424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69239330667786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.854771733270828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.81427775993448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803735`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A3", 
             Association[1 -> {
                Complex[48.5840304516069, -15.701990492284674`], 
                Complex[72.61442618498417, -39.848047855290424`]}, 2 -> {
                Complex[49.69239330667786, 13.854771733270828`], 
                Complex[71.81427775993448, -4.400084640803735]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5728803673960385`, 8.797475188375756}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.59820833614577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.939330465113585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68835833749281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.941189640569323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A3", 
             Association[1 -> {
                Complex[48.59820833614577, -15.781636473500773`], 
                Complex[72.63904705657157, -39.939330465113585`]}, 2 -> {
                Complex[49.68835833749281, 13.941189640569323`], 
                Complex[71.80717759020362, -4.289110939402672]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.579043167588324, 8.967365087038118}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.612187600873085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.860571939182236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.029808239319934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68448233174574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.026850386597047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742367`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "A3", 
             Association[1 -> {
                Complex[48.612187600873085`, -15.860571939182236`], 
                Complex[72.66337741060343, -40.029808239319934`]}, 2 -> {
                Complex[49.68448233174574, 14.026850386597047`], 
                Complex[71.80033542226364, -4.179024692742367]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5851051865607815`, 9.138189066093375}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.625973676114015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.938810270934708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.680760115720915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.111767821127955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.069810145157128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "A3", 
             Association[1 -> {
                Complex[48.625973676114015`, -15.938810270934708`], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[49.680760115720915`, 14.111767821127955`], 
                Complex[71.79374395279486, -4.069810145157128]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5910683729165385`, 9.309938990727161}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.63957177263898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.67718673301603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A3", 
             Association[1 -> {
                Complex[48.63957177263898, -16.016364458249825`], 
                Complex[72.71119598166317, -40.208409298430595`]}, 2 -> {
                Complex[49.67718673301603, 14.195955395586383`], 
                Complex[71.78739616686877, -3.9614519886295856`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5969346184956947`, 9.482606874659808}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.65298689323024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.09324711402706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.296561508588134`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.6737574329993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.279426178673182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A3", 
             Association[1 -> {
                Complex[48.65298689323024, -16.09324711402706], 
                Complex[72.73469819909567, -40.296561508588134`]}, 2 -> {
                Complex[49.6737574329993, 14.279426178673182`], 
                Complex[71.78128532311126, -3.853935345418625]}]}, "Tooltip"]& ]\
}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6027057606712845`, 9.656184875903442}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.666223843506465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.670467660008306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.362192871226501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A3", 
             Association[1 -> {
                Complex[48.666223843506465`, -16.169470489332475`], 
                Complex[72.75793792851876, -40.38396676731901]}, 2 -> {
                Complex[49.670467660008306`, 14.362192871226501`], 
                Complex[71.77540493979987, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.608383584526507, 9.830665292683701}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.67928724206044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.24504648743809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.7809215257996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.47063852810008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66731304323485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.444267820361429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.641369140955806`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "A3", 
             Association[1 -> {
                Complex[48.67928724206044, -16.24504648743809], 
                Complex[72.7809215257996, -40.47063852810008]}, 2 -> {
                Complex[49.66731304323485, 14.444267820361429`], 
                Complex[71.76974878182652, -3.641369140955806]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6139698249192094`, 10.006040559518095`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.692181529961914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80365511190739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66428938724529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "A3", 
             Association[1 -> {
                Complex[48.692181529961914`, -16.31998667718374], 
                Complex[72.80365511190739, -40.556589868302694`]}, 2 -> {
                Complex[49.66428938724529, 14.525663032929627`], 
                Complex[71.76431084846256, -3.536291830717447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6194661684424432`, 10.18230324344362}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.70491097967126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.394302305698698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.641833503377605`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66139266308925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.75908536186752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.43200050653909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "A3", 
             Association[1 -> {
                Complex[48.70491097967126, -16.394302305698698`], 
                Complex[72.82614458440335, -40.641833503377605`]}, 2 -> {
                Complex[49.66139266308925, 14.606390188337485`], 
                Complex[71.75908536186752, -3.43200050653909]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7013855871457844, -0.10335634920044409`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.84637871671309`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905323`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.84835714389165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.391754775223033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.043946736603573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "B3", 
             Association[1 -> {
                Complex[100.84637871671309`, -6.854150896006872], 
                Complex[68.44279858874026, -29.808799798905323`]}, 2 -> {
                Complex[106.84835714389165`, 4.391754775223033], 
                Complex[74.69097444463986, -16.043946736603573`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7347919100927862, -0.03803885209089383}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"100.9926143752586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.03794671378757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.71577694022685`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334501`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "B3", 
             Association[1 -> {
                Complex[100.9926143752586, -7.061586259363489], 
                Complex[68.63308108602176, -30.03794671378757]}, 2 -> {
                Complex[106.71577694022685`, 4.610819767164167], 
                Complex[74.52077639558694, -15.787280126334501`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7666695999153796, 0.029705896925383862`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.12830498957274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709611`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.593677371309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.829003095065927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.36302604910259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018968`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "B3", 
             Association[1 -> {
                Complex[101.12830498957274`, -7.268243232709611], 
                Complex[68.81087406136675, -30.267088315852057`]}, 2 -> {
                Complex[106.593677371309, 4.829003095065927], 
                Complex[74.36302604910259, -15.530773111018968`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.7971342114338194, 0.09986326612481047}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.25421296218802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.473250095934386`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818538`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.48129651857575`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.0454343946354`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"74.21689441876437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279343`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "B3", 
             Association[1 -> {
                Complex[101.25421296218802`, -7.473250095934386], 
                Complex[68.97700663449254, -30.495131845818538`]}, 2 -> {
                Complex[106.48129651857575`, 5.0454343946354], 
                Complex[74.21689441876437, -15.275516827279343`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8262923916141369, 0.17240987601080018`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.37113116294276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.675938335381521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.721222293593776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.37784199165861`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.259446484100549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.0815001053247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "B3", 
             Association[1 -> {
                Complex[101.37113116294276`, -7.675938335381521], 
                Complex[69.13236033871479, -30.721222293593776`]}, 2 -> {
                Complex[106.37784199165861`, 5.259446484100549], 
                Complex[74.0815001053247, -15.022364688029517`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.8542417752565734, 0.24731576087210552`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.47984286618383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.87581467452907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.944712541719554`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.28253099121734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "B3", 
             Association[1 -> {
                Complex[101.47984286618383`, -7.87581467452907], 
                Complex[69.27781951812031, -30.944712541719554`]}, 2 -> {
                Complex[106.28253099121734`, 5.470547395427035], 
                Complex[73.95595889948112, -14.771962238489207`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.881071254370857, 0.32454619429861986`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.58109577908431`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737158`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.19461628065974`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.678390200428089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.83941690100377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "B3", 
             Association[1 -> {
                Complex[101.58109577908431`, -8.07253089957759], 
                Complex[69.41423820838509, -31.16512977737158]}, 2 -> {
                Complex[106.19461628065974`, 5.678390200428089], 
                Complex[73.83941690100377, -14.524780743662296`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9068614779509312, 0.40406317688564486`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.67558705486688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.265855214912735`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.11340117295566`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.8827443667351345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.28114984404213`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "B3", 
             Association[1 -> {
                Complex[101.67558705486688`, -8.265855214912735], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[106.11340117295566`, 5.8827443667351345`], 
                Complex[73.73107052942778, -14.28114984404213]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9316854748313455, 0.48582661567337326`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.76395620494021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.455646996018173`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.595532931322452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"106.03824661853852`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.083470511204354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.63017692604467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "B3", 
             Association[1 -> {
                Complex[101.76395620494021`, -8.455646996018173], 
                Complex[69.66310826637459, -31.595532931322452`]}, 2 -> {
                Complex[106.03824661853852`, 6.083470511204354], 
                Complex[73.63017692604467, -14.041286825846576`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.9556093249406723, 0.5697952385761467}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.84678331483764`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.64183557659289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.805168728095598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.96857298940456`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.280499187514917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316211`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "B3", 
             Association[1 -> {
                Complex[101.84678331483764`, -8.64183557659289], 
                Complex[69.77698109299774, -31.805168728095598`]}, 2 -> {
                Complex[105.96857298940456`, 6.280499187514917], 
                Complex[73.53605776440253, -13.805321546316211`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{0.978692830347631, 0.6559272898564539}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.92459058493533`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.824402998282594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350919`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.01098583576563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.90385853843323`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.44809881447938`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "B3", 
             Association[1 -> {
                Complex[101.92459058493533`, -8.824402998282594], 
                Complex[69.88465297350919, -32.01098583576563]}, 2 -> {
                Complex[105.90385853843323`, 6.473813636367659], 
                Complex[73.44809881447938, -13.573316941041124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0009901567317934`, 0.74418104963487}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"101.99784578534474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.84363594453177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.66343607960575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813707`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "B3", 
             Association[1 -> {
                Complex[101.99784578534474`, -9.003370304344582], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[105.84363594453177`, 6.66343607960575], 
                Complex[73.36574696131454, -13.345285495813707`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0225504292664078`, 0.8345152147813588}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.06696667160847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568787`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.78748789697872`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "B3", 
             Association[1 -> {
                Complex[102.06696667160847`, -9.178786832849873], 
                Complex[70.08355015001808, -32.41114577568787]}, 2 -> {
                Complex[105.78748789697872`, 6.849417013859737], 
                Complex[73.2885058483752, -13.121202250493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0434182757319002`, 0.9268891722231543}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.13232574718282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.35072196069847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.17571664018823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.605563036697966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.73504233297929`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.0318269549940675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479555`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.13232574718282`, -9.35072196069847], 
                Complex[70.17571664018823, -32.605563036697966`]}, 2 -> {
                Complex[105.73504233297929`, 7.0318269549940675`], 
                Complex[73.21593091512594, -12.901014934479555`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0636343152316294`, 1.0212631897206192`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.19425499720877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.796292507460386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.68596770393243`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.14762431207531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "B3", 
             Association[1 -> {
                Complex[102.19425499720877`, -9.519258803308206], 
                Complex[70.26357461989491, -32.796292507460386`]}, 2 -> {
                Complex[105.68596770393243`, 7.210750138216341], 
                Complex[73.14762431207531, -12.684651789041983`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.0832355941846339`, 1.1175985439352305`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.25305037888961`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.684489449591425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.98341809652284`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.63996848509186`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.386279753462805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181569`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "B3", 
             Association[1 -> {
                Complex[102.25305037888961`, -9.684489449591425], 
                Complex[70.34748028709403, -32.98341809652284]}, 2 -> {
                Complex[105.63996848509186`, 7.386279753462805], 
                Complex[73.08322998054209, -12.472027556181569`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1022559730745252`, 1.2158576012619966`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.30897595841716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.846511388382389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.167032678639124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.59678103867778`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.558514372224577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463169`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.263048031573847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "B3", 
             Association[1 -> {
                Complex[102.30897595841716`, -9.846511388382389], 
                Complex[70.42775264717703, -33.167032678639124`]}, 2 -> {
                Complex[105.59678103867778`, 7.558514372224577], 
                Complex[73.02242905463169, -12.263048031573847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.12072646828617, 1.3160038633828928`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.3622676500828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.005424851825339`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771442001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654403`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.55616987480424`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.72755529132343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401399`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "B3", 
             Association[1 -> {
                Complex[102.3622676500828, -10.005424851825339`], 
                Complex[70.50467771442001, -33.34723465654403]}, 2 -> {
                Complex[105.55616987480424`, 7.72755529132343], 
                Complex[72.96493565975211, -12.057613502401399`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1386755536193556`, 1.4180019867149147`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.41313655278073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.161330860116296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.52412538347138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.51792431501376`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "B3", 
             Association[1 -> {
                Complex[102.41313655278073`, -10.161330860116296`], 
                Complex[70.57851229402164, -33.52412538347138]}, 2 -> {
                Complex[105.51792431501376`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452317`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1561294259848205`, 1.5218177827528179`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.4617719016327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.697807247102766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.48185554069093`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.056463649045723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "B3", 
             Association[1 -> {
                Complex[102.4617719016327, -10.314329800105732`], 
                Complex[70.64948735230314, -33.697807247102766`]}, 2 -> {
                Complex[105.48185554069093`, 8.056463649045723], 
                Complex[72.85887064064235, -11.656967837798797`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.173112239508958, 1.6274182046237675`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.50834366412629`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.464520408616728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.868382260021036`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.44779399696195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.216532254157382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80986021988497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597865`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "B3", 
             Association[1 -> {
                Complex[102.50834366412629`, -10.464520408616728`], 
                Complex[70.71781099948191, -33.868382260021036`]}, 2 -> {
                Complex[105.44779399696195`, 8.216532254157382], 
                Complex[72.80986021988497, -11.46154977597865]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.1896463119071734`, 1.7347713238782208`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.55300481511051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.611999061422951`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.035951036901565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.41558711773592`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.373807765588328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.26926528844876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "B3", 
             Association[1 -> {
                Complex[102.55300481511051`, -10.611999061422951`], 
                Complex[70.78367111767889, -34.035951036901565`]}, 2 -> {
                Complex[105.41558711773592`, 8.373807765588328], 
                Complex[72.76327412626178, -11.26926528844876]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2057523065847613`, 1.8438463005502455`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.59589332593018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.756859292171079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.8472376697876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.200612066178834`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.38509733661003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.528384697249784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "B3", 
             Association[1 -> {
                Complex[102.59589332593018`, -10.756859292171079`], 
                Complex[70.8472376697876, -34.200612066178834`]}, 2 -> {
                Complex[105.38509733661003`, 8.528384697249784], 
                Complex[72.71894253702615, -11.080014668572236`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2214493935294735`, 1.9546133487650101`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.6371339016385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.899191483518226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.9086647246821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.35620034969249`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.680354396213673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.6371339016385, -10.899191483518226`], 
                Complex[70.9086647246821, -34.36246120528307]}, 2 -> {
                Complex[105.35620034969249`, 8.680354396213673], 
                Complex[72.67671152345633, -10.893700858042966`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2367553916848857`, 2.0670436995940578`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.67683949770378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503681`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.32878359893402`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.829804862450937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "B3", 
             Association[1 -> {
                Complex[102.67683949770378`, -11.039082686546374`], 
                Complex[70.96809223235842, -34.52159134503681]}, 2 -> {
                Complex[105.32878359893402`, 8.829804862450937], 
                Complex[72.6364412756889, -10.710229782159127`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2516868951543694`, 2.1811095624226415`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.71511264457845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.17661653505849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984513`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.30274494759591`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.97682066344391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655918`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "B3", 
             Association[1 -> {
                Complex[102.71511264457845`, -11.17661653505849], 
                Complex[71.02564757984513, -34.67809220149985]}, 2 -> {
                Complex[105.30274494759591`, 8.97682066344391], 
                Complex[72.59800454678344, -10.529510557655918`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2662593852795732`, 2.2967840857584947`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.75204660533373`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407045`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330794`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.27799152265212`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.121482918322894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052479`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "B3", 
             Association[1 -> {
                Complex[102.75204660533373`, -11.311873229407045`], 
                Complex[71.08144695562095, -34.83205020330794]}, 2 -> {
                Complex[105.27799152265212`, 9.121482918322894], 
                Complex[72.56128528828074, -10.351455605052479`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2804873303660196`, 2.4140413181611415`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.78772638850374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.98354845004252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.25443870198153`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.263869332313579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.1759806899749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "B3", 
             Association[1 -> {
                Complex[102.78772638850374`, -11.444929570640575`], 
                Complex[71.13559654715354, -34.98354845004252]}, 2 -> {
                Complex[105.25443870198153`, 9.263869332313579], 
                Complex[72.52617745264078, -10.1759806899749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.2943842745960177`, 2.5328561697775247`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.82222963544572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.575859030428845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.132666722916746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.23200922704517`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.404054266955532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.0030049121702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "B3", 
             Association[1 -> {
                Complex[102.82222963544572`, -11.575859030428845`], 
                Complex[71.18819359319451, -35.132666722916746`]}, 2 -> {
                Complex[105.23200922704517`, 9.404054266955532], 
                Complex[72.49258394092676, -10.0030049121702]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3079629174595249`, 2.653204374827246}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.85562739896264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.704731845790779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.279481533477025`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.21063242429877`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.542108835115934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512519`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "B3", 
             Association[1 -> {
                Complex[102.85562739896264`, -11.704731845790779`], 
                Complex[71.23932730972689, -35.279481533477025`]}, 2 -> {
                Complex[105.21063242429877`, 9.542108835115934], 
                Complex[72.46041567683548, -9.832450656512519]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3212351848594943`, 2.7750624552701226`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.88798482766386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.831615130363632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.424066199406084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.19024352086885`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.678101012538276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913524`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "B3", 
             Association[1 -> {
                Complex[102.88798482766386`, -11.831615130363632`], 
                Complex[71.28907970599505, -35.424066199406084`]}, 2 -> {
                Complex[105.19024352086885`, 9.678101012538276], 
                Complex[72.42959079064792, -9.664243516913524]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3342122928925784`, 2.898407685807927}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.91936176854858`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.956572996022798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.566490939118765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.1707830420047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.4000338988522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "B3", 
             Association[1 -> {
                Complex[102.91936176854858`, -11.956572996022798`], 
                Complex[71.33752630486225, -35.566490939118765`]}, 2 -> {
                Complex[105.1707830420047, 9.812095759734257], 
                Complex[72.4000338988522, -9.498312201447733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3469048051750627`, 3.0232180603105783`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.94981329856809`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.70682297884146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.15219627955162`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.94415514960595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.3345884250002`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "B3", 
             Association[1 -> {
                Complex[102.94981329856809`, -12.079666680238097`], 
                Complex[71.38473677982421, -35.70682297884146]}, 2 -> {
                Complex[105.15219627955162`, 9.94415514960595], 
                Complex[72.37167546711125, -9.3345884250002]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3593226844692248`, 3.149472259711669}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"102.97939019442735`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.200954675755309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.84512666740593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.13443282218512`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.074338497386954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591691`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205879`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "B3", 
             Association[1 -> {
                Complex[102.97939019442735`, -12.200954675755309`], 
                Complex[71.43077551933806, -35.84512666740593]}, 2 -> {
                Complex[105.13443282218512`, 10.074338497386954`], 
                Complex[72.34445124591691, -9.173006794205879]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3714753392679933`, 3.2771496213849685`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.00813934860057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.11744613942963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.202702490405656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.00813934860057`, -12.320492860106407`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[105.11744613942963`, 10.202702490405656`], 
                Complex[72.31830176971438, -9.013504688267279]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3833716659102089`, 3.4062301099887358`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.03610413843087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.43833462314869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.51957187029711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.10119321259418`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.329301315871612`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2931719115351`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.856022138324652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.03610413843087`, -12.43833462314869], 
                Complex[71.51957187029711, -36.11589271440042]}, 2 -> {
                Complex[105.10119321259418`, 10.329301315871612`], 
                Complex[72.2931719115351, -8.856022138324652]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.3950200867279017`, 3.536694289748207}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.0633247542377`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.554530991361469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.08563420669911`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.454186785413665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354434`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "B3", 
             Association[1 -> {
                Complex[103.0633247542377, -12.554530991361469`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[105.08563420669911`, 10.454186785413665`], 
                Complex[72.26901048624575, -8.700501707354434]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.406428584661631, 3.6685232981332487`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.08983849154451`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.669130748029662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.60434246375627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.379250862967716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.0707321782828`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.577408455499183`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "B3", 
             Association[1 -> {
                Complex[103.08983849154451`, -12.669130748029662`], 
                Complex[71.60434246375627, -36.379250862967716`]}, 2 -> {
                Complex[105.0707321782828, 10.577408455499183`], 
                Complex[72.24576989645068, -8.546888372033505]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4176047347286322`, 3.8016988208816938`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.1156800118456`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.508285674193644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.05645281466863`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.699013743166024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.1156800118456, -12.782180548745718`], 
                Complex[71.64533551387001, -36.508285674193644`]}, 2 -> {
                Complex[105.05645281466863`, 10.699013743166024`], 
                Complex[72.22340581587781, -8.395129407594656]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4285557326784948`, 3.936203068311658}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.14088157573562`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.893725031887852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.6356244667759`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.04276420086907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.819048036725702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.14088157573562`, -12.893725031887852`], 
                Complex[71.68545669700363, -36.6356244667759]}, 2 -> {
                Complex[105.04276420086907`, 10.819048036725702`], 
                Complex[72.20187690576324, -8.245174276383159]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4392884211338008`, 4.072018752865729}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.16547325171713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.003806923902713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.761314747514355`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.02963661081172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.937554801265406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.09697452058391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.16547325171713`, -13.003806923902713`], 
                Complex[71.72474475596928, -36.761314747514355`]}, 2 -> {
                Complex[105.02963661081172`, 10.937554801265406`], 
                Complex[72.18114456033723, -8.09697452058391]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.44980931347448, 4.209129067826094}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.1894831035627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.11246713934441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.885402058614254`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.01704232001005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.9504836594058705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "B3", 
             Association[1 -> {
                Complex[103.1894831035627, -13.11246713934441], 
                Complex[71.76323592906269, -36.885402058614254`]}, 2 -> {
                Complex[105.01704232001005`, 11.054575678901662`], 
                Complex[72.16117267801967, -7.9504836594058705`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4601246156971734`, 4.347517667142078}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.21293735873446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714252`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610164`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"105.00495543717656`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.170150583829281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.80565709087333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "B3", 
             Association[1 -> {
                Complex[103.21293735873446`, -13.219744875714252`], 
                Complex[71.80096415610164, -37.00793007567815]}, 2 -> {
                Complex[105.00495543717656`, 11.170150583829281`], 
                Complex[72.1419274553698, -7.80565709087333]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.4702402464520838`, 4.487168646310694}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.235860560041`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.128940701049814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.99335175259871`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.284317792275752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269189`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "B3", 
             Association[1 -> {
                Complex[103.235860560041, -13.325677703210093`], 
                Complex[71.83796126429178, -37.128940701049814`]}, 2 -> {
                Complex[104.99335175259871`, 11.284317792275752`], 
                Complex[72.1233772012094, -7.662451998269189]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.480161855437563, 4.62806652425313}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.2582757024331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.430301649540361`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.24847415254021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.98220860137506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.397114027514961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866303`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "B3", 
             Association[1 -> {
                Complex[103.2582757024331, -13.430301649540361`], 
                Complex[71.8742571361754, -37.24847415254021]}, 2 -> {
                Complex[104.98220860137506`, 11.397114027514961`], 
                Complex[72.10549216866303, -7.520827261201424]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.489894840312166, 4.770196226132187}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.28020435660125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.533651279988478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.36656904762125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.97150473984975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.50857454012721`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.380743371206091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.28020435660125`, -13.533651279988478`], 
                Complex[71.90987986163972, -37.36656904762125]}, 2 -> {
                Complex[104.97150473984975`, 11.50857454012721], 
                Complex[72.08824440313957, -7.380743371206091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.499444362265853, 4.91354306705726}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.30166678083135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.635759772932813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9448558757189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.9612202337884`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07160760452052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "B3", 
             Association[1 -> {
                Complex[103.30166678083135`, -13.635759772932813`], 
                Complex[71.9448558757189, -37.483262483211874`]}, 2 -> {
                Complex[104.9612202337884, 11.618733183710313`], 
                Complex[72.07160760452052, -7.242162351762078]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5088153603771894`, 5.05809273662649}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.32268202239507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.736658991038896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.951336357019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "B3", 
             Association[1 -> {
                Complex[103.32268202239507`, -13.736658991038896`], 
                Complex[71.97921008371291, -37.59859011120973]}, 2 -> {
                Complex[104.951336357019, 11.727622486258118`], 
                Complex[72.05555700203158, -7.105047682565443]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5180125648693996`, 5.203831284258003}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.34326800959789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.836379548343551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.941835499415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045623`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892658`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.34326800959789`, -13.836379548343551`], 
                Complex[72.01296597496555, -37.712586209936966`]}, 2 -> {
                Complex[104.941835499415, 11.835273717427565`], 
                Complex[72.04006924045623, -6.969364227892658]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5270405093651271`, 5.35074510526456}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.36344163547253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.934950873453168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648372`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.9327010832324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915144`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.8350781688719024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.36344163547253`, -13.934950873453168`], 
                Complex[72.04614572648372, -37.82528375168293]}, 2 -> {
                Complex[104.9327010832324, 11.941716951915144`], 
                Complex[72.02512227650752, -6.8350781688719024`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5359035422312155`, 5.498820927628456}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.38321883398932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.032401269072546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0787702974438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.9367144665288`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.92391748692997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.046981129160319`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475888`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.38321883398932`, -14.032401269072546`], 
                Complex[72.0787702974438, -37.9367144665288]}, 2 -> {
                Complex[104.92391748692997`, 12.046981129160319`], 
                Complex[72.01069528431418, -6.702156939475888]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5446058370935185`, 5.648045799436238}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.40261464955266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.128757968076373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.11085951550861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.046908902642215`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.91546997570263`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.151094109587374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "B3", 
             Association[1 -> {
                Complex[103.40261464955266`, -14.128757968076373`], 
                Complex[72.11085951550861, -38.046908902642215`]}, 2 -> {
                Complex[104.91546997570263`, 12.151094109587374`], 
                Complex[71.99676856909556, -6.570569166048996]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.553151402594869, 5.798407076934817}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.42164330046519`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.15589648322749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.90734463804742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.98332348820699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181976`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "B3", 
             Association[1 -> {
                Complex[103.42164330046519`, -14.22404718632717], 
                Complex[72.14243215577528, -38.15589648322749]}, 2 -> {
                Complex[104.90734463804742`, 12.254082727590419`], 
                Complex[71.98332348820699, -6.440284610181976]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.561544091461007, 5.949892413173055}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.44031823696265`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.318294172435639`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.899528327758`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.355972841456682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.311274114752878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "B3", 
             Association[1 -> {
                Complex[103.44031823696265`, -14.318294172435639`], 
                Complex[72.17350601308074, -38.263705560313824`]}, 2 -> {
                Complex[104.899528327758, 12.355972841456682`], 
                Complex[71.97034237882741, -6.311274114752878]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5697876089334437`, 6.102489747194957}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.4586521943553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.411523254649305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555745`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.89200861081196`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957561`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "B3", 
             Association[1 -> {
                Complex[103.4586521943553, -14.411523254649305`], 
                Complex[72.20409796831112, -38.37036346555745]}, 2 -> {
                Complex[104.89200861081196`, 12.456789380414621`], 
                Complex[71.95780849164257, -6.183509552957561]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5778855206224358`, 6.256187293752808}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.4766572417525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.503757885046657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.88477371667624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.55655638898441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "B3", 
             Association[1 -> {
                Complex[103.4766572417525, -14.503757885046657`], 
                Complex[72.23422404929192, -38.47589655822829]}, 2 -> {
                Complex[104.88477371667624`, 12.55655638898441], 
                Complex[71.94570592995045, -6.056963780158602]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5858412598277931`, 6.410973533510424}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.49434482679449`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.595020681203478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054336`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.87781249360295`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.655297068796704`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.93401959367063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "B3", 
             Association[1 -> {
                Complex[103.49434482679449`, -14.595020681203478`], 
                Complex[72.2638994867713, -38.58033027054336]}, 2 -> {
                Complex[104.87781249360295`, 12.655297068796704`], 
                Complex[71.93401959367063, -5.931610588391608]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.5936581343705194`, 6.566837203708667}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.51172581676958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.6853334654894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.87111436754086`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.753033818038542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371897`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "B3", 
             Association[1 -> {
                Complex[103.51172581676958`, -14.6853334654894], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[104.87111436754086`, 12.753033818038542`], 
                Complex[71.92273512780362, -5.807424663371897]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6013393329754473`, 6.7237672892668545`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.52881053645524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.774717302142461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400863`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.78599690237516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.86466930432246`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.849788268674176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9118388749275`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854785`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.52881053645524`, -14.774717302142461`], 
                Complex[72.32195567400863, -38.78599690237516]}, 2 -> {
                Complex[104.86466930432246`, 12.849788268674176`], 
                Complex[71.9118388749275, -5.684381543854785]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6088879312392572`, 6.881753014295752}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.54560880298476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.863192532261197`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.887276424972804`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.85846777482483`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.945581321580061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136441`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.54560880298476`, -14.863192532261197`], 
                Complex[72.35036334387817, -38.887276424972804`]}, 2 -> {
                Complex[104.85846777482483`, 12.945581321580061`], 
                Complex[71.90131783136441, -5.562457583209795]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.616306897217276, 7.040783833998995}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.5621299580112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.950778806844474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.85250072283318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.04043317972461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.5621299580112, -14.950778806844474`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[104.85250072283318`, 13.04043317972461], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6235990966577327`, 7.20084942694143}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.57838289741083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.037495118001429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.086838565533036`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.84675953536465`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.134363379515117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "B3", 
             Association[1 -> {
                Complex[103.57838289741083`, -15.037495118001429`], 
                Complex[72.40600046967194, -39.086838565533036`]}, 2 -> {
                Complex[104.84675953536465`, 13.134363379515117`], 
                Complex[71.88135238627333, -5.321876408978637]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6307672979106422`, 7.3619396876640995`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.59437609874517`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.123359828445727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.84123601523297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.227390820426008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "B3", 
             Association[1 -> {
                Complex[103.59437609874517`, -15.123359828445727`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[104.84123601523297`, 13.227390820426008`], 
                Complex[71.8718848966287, -5.203175657776077]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6378141765355616`, 7.524044719626991}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.6101176466776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.208390699381031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718851`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107673`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.83592235565861`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.319533793015575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.085506926850082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "B3", 
             Association[1 -> {
                Complex[103.6101176466776, -15.208390699381031`], 
                Complex[72.46014358718851, -39.28254398107673]}, 2 -> {
                Complex[104.83592235565861`, 13.319533793015575`], 
                Complex[71.86274637325923, -5.085506926850082]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.644742319630813, 7.687154828461667}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.62561525652167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.292604916877655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.83081111674652`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.410810005430926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.62561525652167`, -15.292604916877655`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[104.83081111674652`, 13.410810005430926`], 
                Complex[71.85392653085569, -4.968850134912989]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6515542299035013`, 7.851260515517351}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.64087629608107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.376019116833604`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992379`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651176`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.82589520367239`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.64087629608107`, -15.376019116833604`], 
                Complex[72.51287796992379, -39.47455031651176]}, 2 -> {
                Complex[104.82589520367239`, 13.501236608494986`], 
                Complex[71.84541553560709, -4.853185824347895]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6582523295009588`, 8.016352471684188}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.65590780592484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941214`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.82116784643303`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.590830219461871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.73849513498747`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "B3", 
             Association[1 -> {
                Complex[103.65590780592484`, -15.458649408607112`], 
                Complex[72.53874152941214, -39.56921287503744]}, 2 -> {
                Complex[104.82116784643303`, 13.590830219461871`], 
                Complex[71.83720397946203, -4.73849513498747]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6648389636184555`, 8.18242157148003}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.67071651822893`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.540511397402026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.81662258103023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.679606944523016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245355`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "B3", 
             Association[1 -> {
                Complex[103.67071651822893`, -15.540511397402026`], 
                Complex[72.56428164388791, -39.66300535954415]}, 2 -> {
                Complex[104.81662258103023`, 13.679606944523016`], 
                Complex[71.82928285617803, -4.624759779245355]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6713164039001975`, 8.349458867385843}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.68530887430188`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.621620205482067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.755944836925224`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.81225323197039`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.76758240013934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82164353901412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.5119620185211815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "B3", 
             Association[1 -> {
                Complex[103.68530887430188`, -15.621620205482067`], 
                Complex[72.58950706494943, -39.755944836925224`]}, 2 -> {
                Complex[104.81225323197039`, 13.76758240013934], 
                Complex[71.82164353901412, -4.5119620185211815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6776868516479675`, 8.517455584417567}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.69969104090151`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.701990492284681`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.84804785529043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80805389597248`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.854771733270837`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8142777599345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803723`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "B3", 
             Association[1 -> {
                Complex[103.69969104090151`, -15.701990492284681`], 
                Complex[72.61442618498418, -39.84804785529043]}, 2 -> {
                Complex[104.80805389597248`, 13.854771733270837`], 
                Complex[71.8142777599345, -4.400084640803723]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6839524408499977`, 8.686403114921793}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.71386892544038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.93933046511359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80401892678742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.941189640569329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "B3", 
             Association[1 -> {
                Complex[103.71386892544038`, -15.781636473500773`], 
                Complex[72.63904705657157, -39.93933046511359]}, 2 -> {
                Complex[104.80401892678742`, 13.941189640569329`], 
                Complex[71.80717759020362, -4.289110939402667]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.6901152410422975`, 8.856293013584159}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7278481901677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.860571939182227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.02980823931992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.80014292104036`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.026850386597049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226366`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "B3", 
             Association[1 -> {
                Complex[103.7278481901677, -15.860571939182227`], 
                Complex[72.66337741060345, -40.02980823931992]}, 2 -> {
                Complex[104.80014292104036`, 14.026850386597049`], 
                Complex[71.80033542226366, -4.179024692742365]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.696177260014769, 9.02711699263943}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.74163426540862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.93881027093471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.79642070501552`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.11176782112795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.0698101451571365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "B3", 
             Association[1 -> {
                Complex[103.74163426540862`, -15.93881027093471], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[104.79642070501552`, 14.11176782112795], 
                Complex[71.79374395279484, -4.0698101451571365`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.7021404463704977`, 9.198866917273174}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7552323619336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430624`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.79284732231065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295785`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "B3", 
             Association[1 -> {
                Complex[103.7552323619336, -16.016364458249843`], 
                Complex[72.71119598166317, -40.208409298430624`]}, 2 -> {
                Complex[104.79284732231065`, 14.195955395586383`], 
                Complex[71.78739616686879, -3.9614519886295785`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.7080066919496113`, 9.371534801205835}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.7686474825249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.093247114027072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.29656150858814`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.78941802229393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.279426178673177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418634`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "B3", 
             Association[1 -> {
                Complex[103.7686474825249, -16.093247114027072`], 
                Complex[72.73469819909572, -40.29656150858814]}, 2 -> {
                Complex[104.78941802229393`, 14.279426178673177`], 
                Complex[71.78128532311128, -3.853935345418634]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.713777834125272, 9.54511280244949}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.78188443280105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.7861282493029`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.362192871226487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "B3", 
             Association[1 -> {
                Complex[103.78188443280105`, -16.169470489332486`], 
                Complex[72.75793792851871, -40.38396676731904]}, 2 -> {
                Complex[104.7861282493029, 14.362192871226487`], 
                Complex[71.77540493979984, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.7194556579804663`, 9.719593219229745}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.79494783135505`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.24504648743812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.78092152579958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.470638528100125`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.78297363252948`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.444267820361425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182654`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.6413691409558098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "B3", 
             Association[1 -> {
                Complex[103.79494783135505`, -16.24504648743812], 
                Complex[72.78092152579958, -40.470638528100125`]}, 2 -> {
                Complex[104.78297363252948`, 14.444267820361425`], 
                Complex[71.76974878182654, -3.6413691409558098`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.7250418983731828`, 9.894968486064146}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.80784211925645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.8036551119073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.7799499765399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929623`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "B3", 
             Association[1 -> {
                Complex[103.80784211925645`, -16.31998667718373], 
                Complex[72.8036551119073, -40.556589868302694`]}, 2 -> {
                Complex[104.7799499765399, 14.525663032929623`], 
                Complex[71.76431084846254, -3.536291830717447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0, 1], PointSize[0.01], 
          TagBox[
           TooltipBox[PointBox[{1.7305382418964592`, 10.071231169989654`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"B3\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"103.82057156896586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.394302305698687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.6418335033776`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"104.77705325238387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.7590853618675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4320005065390866`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "B3", 
             Association[1 -> {
                Complex[103.82057156896586`, -16.394302305698687`], 
                Complex[72.82614458440332, -40.6418335033776]}, 2 -> {
                Complex[104.77705325238387`, 14.606390188337485`], 
                Complex[71.7590853618675, -3.4320005065390866`]}]}, 
            "Tooltip"]& ]}}}, 
       {GrayLevel[0.2], Thickness[Tiny], LineBox[{{0, -5}, {0, 10}}]}},
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"Re(\\!\\(\\*SubscriptBox[\\(S\\), \\(1\\)]\\)-\[CapitalOmega] \
\\!\\(\\*SubscriptBox[\\(t\\), \\(1\\)]\\))-Re(\\!\\(\\*SubscriptBox[\\(S\\), \
\\(2\\)]\\)-\[CapitalOmega] \\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
         TraditionalForm], 
        FormBox[
        "\"Im(\\!\\(\\*SubscriptBox[\\(S\\), \\(1\\)]\\)-\[CapitalOmega] \
\\!\\(\\*SubscriptBox[\\(t\\), \\(1\\)]\\))-Im(\\!\\(\\*SubscriptBox[\\(S\\), \
\\(2\\)]\\)-\[CapitalOmega] \\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
         TraditionalForm]},
      ImageSize->{{900}, {900}},
      PlotRange->{{-2, 2}, {-2, 2}},
      PlotRangeClipping->True]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Saddle-point per-pair spectrum", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SPAdipole"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"SPAdipole[S,prefactor,\[CapitalOmega],{t,\[Tau]}] returns the \
saddle-point approximation amplitude corresponding to action S[t,t-\[Tau]]-\
\[CapitalOmega]t and the given prefactor.\\n\\nSPAdipole[S,prefactor,\
\[CapitalOmega],\[LeftAssociation]1\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation]] returns the total harmonic-dipole contribution in the \
saddle-point approximation from the specified saddle \
points.\\n\\nSPAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)}\[RightAssociation],transition] uses the given Stokes transition set \
to drop the relevant saddle after the anti-Stokes transition.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info163674213772-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "transitions"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"1.65", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"",
            ","}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"6.3", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", 
              RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ","}], "*)"}], 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"keyColour", "=", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\"\<A\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Black"}], ",", 
            RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<B\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Red"}], ",", 
            RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<C\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<D\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}],
         "\[RightAssociation]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", "Black"}], ",", 
       RowBox[{"\"\<B\>\"", "\[Rule]", "Red"}], ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", "Purple"}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Show", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"keyColour", "[", "index", "]"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", "Gray"}], 
               "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"Tooltip", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Point", "[", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                  RowBox[{"Log10", "[", 
                   RowBox[{
                    SuperscriptBox["10", 
                    RowBox[{"-", "7"}]], "+", 
                    RowBox[{"Norm", "[", "\[IndentingNewLine]", 
                    RowBox[{"SPAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
                    "]"}]}], "]"}]}], "}"}], "\[IndentingNewLine]", "]"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", "index", 
                 ",", 
                 RowBox[{"selection", "[", 
                  RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "}"}]}],
               "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalOmega]", ",", 
             RowBox[{"Keys", "[", 
              RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"index", ",", 
           RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
       "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
      RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", "\"\<harmonic dipole\>\""}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{15.999999999999998`, -6.058871140825799}],
       RowBox[{"{", 
         RowBox[{"15.999999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"12.245615698905056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.546462974510604`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"82.3583570943027`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11658019540031805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {15.999999999999998`, "A", 
        Association[1 -> {
           Complex[12.245615698905056`, -11.285995288896373`], 
           Complex[31.494082066597198`, -37.546462974510604`]}, 2 -> {
           Complex[82.3583570943027, 0.11658019540031805`], 
           Complex[108.70582923184111`, -20.410164695938445`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.099999999999998`, -6.011802555877524}],
       RowBox[{"{", 
         RowBox[{"16.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"12.866460671342168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.816178584119385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.10766368142046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249051`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"81.65454606371028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.099999999999998`, "A", 
        Association[1 -> {
           Complex[12.866460671342168`, -10.816178584119385`], 
           Complex[32.10766368142046, -37.05300319249051]}, 2 -> {
           Complex[81.65454606371028, 0.11776334712026199`], 
           Complex[107.9916707304329, -20.410142957197117`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.2, -5.983083149147442}],
       RowBox[{"{", 
         RowBox[{"16.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"13.385569221277168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.443606571400114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.62046690403218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"81.08582224927886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.2, "A", 
        Association[1 -> {
           Complex[13.385569221277168`, -10.443606571400114`], 
           Complex[32.62046690403218, -36.65624121214425]}, 2 -> {
           Complex[81.08582224927886, 0.11905307061487365`], 
           Complex[107.41258000537293`, -20.41001952735828]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.299999999999997`, -5.9641716071966275`}],
       RowBox[{"{", 
         RowBox[{"16.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"13.844879609183106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.128345372417396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.074306417344815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"80.59570734825861`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12040941356394542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464518`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.299999999999997`, "A", 
        Association[1 -> {
           Complex[13.844879609183106`, -10.128345372417396`], 
           Complex[33.074306417344815`, -36.31637452115125]}, 2 -> {
           Complex[80.59570734825861, 0.12040941356394542`], 
           Complex[106.91207211908184`, -20.409835465464518`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.4, -5.9516316878113775`}],
       RowBox[{"{", 
         RowBox[{"16.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"14.263512998287613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.852138089238336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.48822262138849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.01523037051932`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"80.15853740070536`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12181511399306792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40960872633279`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.4, "A", 
        Association[1 -> {
           Complex[14.263512998287613`, -9.852138089238336], 
           Complex[33.48822262138849, -36.01523037051932]}, 2 -> {
           Complex[80.15853740070536, 0.12181511399306792`], 
           Complex[106.46447895532776`, -20.40960872633279]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.499999999999996`, -5.943537003038906}],
       RowBox[{"{", 
         RowBox[{"16.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"14.652107822673527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.60480138795417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.87279494489345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.74268548695589`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"79.76008128321261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12326110383985404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.05556643970378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409348870362294`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.499999999999996`, "A", 
        Association[1 -> {
           Complex[14.652107822673527`, -9.60480138795417], 
           Complex[33.87279494489345, -35.74268548695589]}, 2 -> {
           Complex[79.76008128321261, 0.12326110383985404`], 
           Complex[106.05556643970378`, -20.409348870362294`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.599999999999998`, -5.938507444516816}],
       RowBox[{"{", 
         RowBox[{"16.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"15.017310748471408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.379958105911207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"79.3914778440311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1247420703186469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.599999999999998`, "A", 
        Association[1 -> {
           Complex[15.017310748471408`, -9.379958105911207], 
           Complex[34.23462400814145, -35.492408387804]}, 2 -> {
           Complex[79.3914778440311, 0.1247420703186469], 
           Complex[105.67647115587602`, -20.409061588827736`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.7, -5.935388226208859}],
       RowBox[{"{", 
         RowBox[{"16.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"15.363606529112152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.17329625288842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.260123312215754`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"79.04676899384386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12625468557684455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.32123318016059`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408750516874484`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.7, "A", 
        Association[1 -> {
           Complex[15.363606529112152`, -9.17329625288842], 
           Complex[34.57815702977675, -35.260123312215754`]}, 2 -> {
           Complex[79.04676899384386, 0.12625468557684455`], 
           Complex[105.32123318016059`, -20.408750516874484`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.799999999999997`, -5.9331582538746295`}],
       RowBox[{"{", 
         RowBox[{"16.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"15.694192540187109`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.981735864879811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.906559828007246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.04277989487664`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"78.72172225527217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1277967777586609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612212`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.799999999999997`, "A", 
        Association[1 -> {
           Complex[15.694192540187109`, -8.981735864879811], 
           Complex[34.906559828007246`, -35.04277989487664]}, 2 -> {
           Complex[78.72172225527217, 0.1277967777586609], 
           Complex[104.98561848841774`, -20.40841808612212]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{16.9, -5.930944784144151}],
       RowBox[{"{", 
         RowBox[{"16.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"16.011444946530013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.802984319586065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.8381102332606`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"78.41320392779194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12936689788169053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40806597206126`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.9, "A", 
        Association[1 -> {
           Complex[16.011444946530013`, -8.802984319586065], 
           Complex[35.22218142009305, -34.8381102332606]}, 2 -> {
           Complex[78.41320392779194, 0.12936689788169053`], 
           Complex[104.66649203468586`, -20.40806597206126]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17., -5.9280875124678705`}],
       RowBox[{"{", 
         RowBox[{"17.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"16.31718789840238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.635279208450724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.52682218732508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"78.11881756413922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13096407459708617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17., "A", 
        Association[1 -> {
           Complex[16.31718789840238, -8.635279208450724], 
           Complex[35.52682218732508, -34.644372916323725`]}, 2 -> {
           Complex[78.11881756413922, 0.13096407459708617`], 
           Complex[104.36145617205713`, -20.40769534844911]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.099999999999998`, -5.924207517275232}],
       RowBox[{"{", 
         RowBox[{"17.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"16.612858840508633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.47723022998036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836112`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"77.83668223957315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13258766651163573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147234`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.099999999999998`, "A", 
        Association[1 -> {
           Complex[16.612858840508633`, -8.47723022998036], 
           Complex[35.82189847272132, -34.46019571836112]}, 2 -> {
           Complex[77.83668223957315, 0.13258766651163573`], 
           Complex[104.06862888444635`, -20.407307041147234`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.2, -5.919242081271416}],
       RowBox[{"{", 
         RowBox[{"17.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"16.899615105400063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.327717105231178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.1085486648078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.284474089725364`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"77.56528975328628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13423726881752882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797378`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.2, "A", 
        Association[1 -> {
           Complex[16.899615105400063`, -8.327717105231178], 
           Complex[36.1085486648078, -34.284474089725364`]}, 2 -> {
           Complex[77.56528975328628, 0.13423726881752882`], 
           Complex[103.78650096169157`, -20.406901625797378`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.299999999999997`, -5.913422992753072}],
       RowBox[{"{", 
         RowBox[{"17.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"17.17840543589556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.18582098961993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.116302994815634`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"77.30340893094568`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13591265188074694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338008`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.299999999999997`, "A", 
        Association[1 -> {
           Complex[17.17840543589556, -8.18582098961993], 
           Complex[36.38770434340436, -34.116302994815634`]}, 2 -> {
           Complex[77.30340893094568, 0.13591265188074694`], 
           Complex[103.51384028303791`, -20.406479492338008`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.4, -5.90720191278963}],
       RowBox[{"{", 
         RowBox[{"17.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"17.4500195893454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.660139598224646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.9549296033411`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"77.05001933585376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951339305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030564`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.4, "A", 
        Association[1 -> {
           Complex[17.4500195893454, -8.050776840303662], 
           Complex[36.660139598224646`, -33.9549296033411]}, 2 -> {
           Complex[77.05001933585376, 0.13761371951339305`], 
           Complex[103.24962551411932`, -20.406040889030564`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.5, -5.901147663489281}],
       RowBox[{"{", 
         RowBox[{"17.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"17.715123715910405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.921939398858399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.926506185668615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.799719524488225`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"76.80426404977382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13934047984247463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.5, "A", 
        Association[1 -> {
           Complex[17.715123715910405`, -7.921939398858399], 
           Complex[36.926506185668615`, -33.799719524488225`]}, 2 -> {
           Complex[76.80426404977382, 0.13934047984247463`], 
           Complex[102.99299887698848`, -20.405585953330533`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.599999999999998`, -5.895845377242692}],
       RowBox[{"{", 
         RowBox[{"17.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"17.97428620238765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.18735919764107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.65013212317828`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"76.56541522251278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.599999999999998`, "A", 
        Association[1 -> {
           Complex[17.97428620238765, -7.798758308638237], 
           Complex[37.18735919764107, -33.65013212317828]}, 2 -> {
           Complex[76.56541522251278, 0.14109302450360017`], 
           Complex[102.74323169131219`, -20.40511473403629]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.7, -5.891817730308461}],
       RowBox[{"{", 
         RowBox[{"17.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"18.227996947167636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.44317619593503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.50570209730137`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"76.33284841044511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14287151349532584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.7, "A", 
        Association[1 -> {
           Complex[18.227996947167636`, -7.680759532183109], 
           Complex[37.44317619593503, -33.50570209730137]}, 2 -> {
           Complex[76.33284841044511, 0.14287151349532584`], 
           Complex[102.49969870626036`, -20.404627207488197`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.799999999999997`, -5.889474043400313}],
       RowBox[{"{", 
         RowBox[{"17.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"18.476681999633616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.567531219181608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.694371737074945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.366025475903584`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"76.10602311146744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1446761639763866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.799999999999997`, "A", 
        Association[1 -> {
           Complex[18.476681999633616`, -7.567531219181608], 
           Complex[37.694371737074945`, -33.366025475903584`]}, 2 -> {
           Complex[76.10602311146744, 0.1446761639763866], 
           Complex[102.26185863012617`, -20.404123289610286`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.9, -5.8890825156237225`}],
       RowBox[{"{", 
         RowBox[{"17.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"18.7207148587158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.458712785360555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.23074880548425`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"75.8844677615424`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187037323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982533`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.9, "A", 
        Association[1 -> {
           Complex[18.7207148587158, -7.458712785360555], 
           Complex[37.94130857631962, -33.23074880548425]}, 2 -> {
           Complex[75.8844677615424, 0.14650724187037323`], 
           Complex[102.02923912251609`, -20.403602844982533`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{17.999999999999996`, -5.890756849407042}],
       RowBox[{"{", 
         RowBox[{"17.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"18.960425318413485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.353986351536103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.18430643425337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.09956067860008`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"75.66776800411328`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1483650555087814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.999999999999996`, "A", 
        Association[1 -> {
           Complex[18.960425318413485`, -7.353986351536103], 
           Complex[38.18430643425337, -33.09956067860008]}, 2 -> {
           Complex[75.66776800411328, 0.1483650555087814], 
           Complex[101.80142506016172`, -20.40306569375059]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.099999999999998`, -5.894449429230231}],
       RowBox[{"{", 
         RowBox[{"18.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"19.196106481999152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.253069946548066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.42364894442649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.97218501218881`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"75.45555740059443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15024995077914985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.099999999999998`, "A", 
        Association[1 -> {
           Complex[19.196106481999152`, -7.253069946548066], 
           Complex[38.42364894442649, -32.97218501218881]}, 2 -> {
           Complex[75.45555740059443, 0.15024995077914985`], 
           Complex[101.57804924438945`, -20.402511616933747`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.2, -5.899946649053208}],
       RowBox[{"{", 
         RowBox[{"18.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"19.428020388516035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.155712048248098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.659589223203085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.848375652574305`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"75.24750998887278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15216230740510475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.2, "A", 
        Association[1 -> {
           Complex[19.428020388516035`, -7.155712048248098], 
           Complex[38.659589223203085`, -32.848375652574305`]}, 2 -> {
           Complex[75.24750998887278, 0.15216230740510475`], 
           Complex[101.35878495705765`, -20.40194036052505]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.299999999999997`, -5.906866466619177}],
       RowBox[{"{", 
         RowBox[{"18.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"19.656402573483003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.06168715326511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.892354381854474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"75.04333425978076`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15410253608764446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.299999999999997`, "A", 
        Association[1 -> {
           Complex[19.656402573483003`, -7.06168715326511], 
           Complex[38.892354381854474`, -32.727912000016886`]}, 2 -> {
           Complex[75.04333425978076, 0.15410253608764446`], 
           Complex[101.14333993482663`, -20.401351638669528`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.399999999999995`, -5.914663173167995}],
       RowBox[{"{", 
         RowBox[{"18.399999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"19.88146580099659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.122149216633446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.610595426395264`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"74.84276823492078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15607107631331532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506859`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400745136126783`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.399999999999995`, "A", 
        Association[1 -> {
           Complex[19.88146580099659, -6.970792147471287], 
           Complex[39.122149216633446`, -32.610595426395264`]}, 2 -> {
           Complex[74.84276823492078, 0.15607107631331532`], 
           Complex[100.93145144506859`, -20.400745136126783`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.499999999999996`, -5.92264897467411}],
       RowBox[{"{", 
         RowBox[{"18.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"20.10340314443287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.3491592528931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678466`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"74.64557540947717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580683946848076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.7228822269972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.4001205101715`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.499999999999996`, "A", 
        Association[1 -> {
           Complex[20.10340314443287, -6.882843306606507], 
           Complex[39.3491592528931, -32.49624631678466]}, 2 -> {
           Complex[74.64557540947717, 0.1580683946848076], 
           Complex[100.7228822269972, -20.4001205101715]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.599999999999998`, -5.930044289374025}],
       RowBox[{"{", 
         RowBox[{"18.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"20.322390549817726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.797673797918388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.573553276414586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.38470160682706`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"74.45154138132087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1600949836664982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046542`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.599999999999998`, "A", 
        Association[1 -> {
           Complex[20.322390549817726`, -6.797673797918388], 
           Complex[39.573553276414586`, -32.38470160682706]}, 2 -> {
           Complex[74.45154138132087, 0.1600949836664982], 
           Complex[100.51741711927747`, -20.399477392046542`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.7, -5.936064980797324}],
       RowBox[{"{", 
         RowBox[{"18.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"20.53858898448397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.79548545383973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.27581271779224`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"74.26047102973546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1621513606638985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.3148602374095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.398815388055127`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.7, "A", 
        Association[1 -> {
           Complex[20.53858898448397, -6.715131583883614], 
           Complex[39.79548545383973, -32.27581271779224]}, 2 -> {
           Complex[74.26047102973546, 0.1621513606638985], 
           Complex[100.3148602374095, -20.398815388055127`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.8, -5.940041640524292}],
       RowBox[{"{", 
         RowBox[{"18.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"20.752146250400717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.635077651408368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340219`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"74.07218613811635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16423806737529167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39813408035839`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.8, "A", 
        Association[1 -> {
           Complex[20.752146250400717`, -6.635077651408368], 
           Complex[40.01509712100966, -32.16944381340219]}, 2 -> {
           Complex[74.07218613811635, 0.16423806737529167`], 
           Complex[100.11503259520978`, -20.39813408035839]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.9, -5.9415455812009945`}],
       RowBox[{"{", 
         RowBox[{"18.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"20.963198524196073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.557384506607896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.065470319069306`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"73.88652337816677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936818696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529207`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.9, "A", 
        Association[1 -> {
           Complex[20.963198524196073`, -6.557384506607896], 
           Complex[40.23251830075455, -32.065470319069306`]}, 2 -> {
           Complex[73.88652337816677, 0.16635566936818696`], 
           Complex[99.91777008789096, -20.397433027529207`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{18.999999999999996`, -5.940480282986906}],
       RowBox[{"{", 
         RowBox[{"18.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"21.171871672770024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.481934887900368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.447868998641226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.963777656737`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"73.70333259061725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16850475584425448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.72292177174809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.999999999999996`, "A", 
        Association[1 -> {
           Complex[21.171871672770024`, -6.481934887900368], 
           Complex[40.447868998641226`, -31.963777656737]}, 2 -> {
           Complex[73.70333259061725, 0.16850475584425448`], 
           Complex[99.72292177174809, -20.39671176490144]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.099999999999998`, -5.9371016039243285`}],
       RowBox[{"{", 
         RowBox[{"19.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"21.378282383376405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.408620659800499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.661260315234074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.864260158083315`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"73.52247531084704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17068593956353983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.099999999999998`, "A", 
        Association[1 -> {
           Complex[21.378282383376405`, -6.408620659800499], 
           Complex[40.661260315234074`, -31.864260158083315`]}, 2 -> {
           Complex[73.52247531084704, 0.17068593956353983`], 
           Complex[99.53034838881473, -20.39596980474617]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.2, -5.931958491951907}],
       RowBox[{"{", 
         RowBox[{"19.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"21.58253913933037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.76682012623099`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"73.34382349807167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1728998569070958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.2, "A", 
        Association[1 -> {
           Complex[21.58253913933037, -6.337341857243096], 
           Complex[40.87279540575696, -31.76682012623099]}, 2 -> {
           Complex[73.34382349807167, 0.1728998569070958], 
           Complex[99.33992109514008, -20.39520663629768]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.299999999999997`, -5.925780306661813}],
       RowBox[{"{", 
         RowBox[{"19.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"21.78474306649485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.08257031208464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.671367021850585`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"73.167258434751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1751471680593818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39442172564926`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.299999999999997`, "A", 
        Association[1 -> {
           Complex[21.78474306649485, -6.268005856060312], 
           Complex[41.08257031208464, -31.671367021850585`]}, 2 -> {
           Complex[73.167258434751, 0.1751471680593818], 
           Complex[99.15152035933141, -20.39442172564926]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.4, -5.919353391502627}],
       RowBox[{"{", 
         RowBox[{"19.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"21.98498867099265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.577816754044576`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.99266976913438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17742855729767226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.9650350042688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39361451553301`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.4, "A", 
        Association[1 -> {
           Complex[21.98498867099265, -6.20052664977852], 
           Complex[41.290674687319935`, -31.577816754044576`]}, 2 -> {
           Complex[72.99266976913438, 0.17742855729767226`], 
           Complex[98.9650350042688, -20.39361451553301]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.499999999999996`, -5.913421412370323}],
       RowBox[{"{", 
         RowBox[{"19.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"22.183364484872566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.13482421649645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.497192429524794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.486091059962376`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.81995467880073`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17974473337764585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.499999999999996`, "A", 
        Association[1 -> {
           Complex[22.183364484872566`, -6.13482421649645], 
           Complex[41.497192429524794`, -31.486091059962376`]}, 2 -> {
           Complex[72.81995467880073, 0.17974473337764585`], 
           Complex[98.78036136984286, -20.39278442499534]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.599999999999998`, -5.908623512965413}],
       RowBox[{"{", 
         RowBox[{"19.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"22.379953633499717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.070823962465011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.702202238238115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.396116959927433`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.6490171369839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18209643000701964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391930848977243`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.599999999999998`, "A", 
        Association[1 -> {
           Complex[22.379953633499717`, -6.070823962465011], 
           Complex[41.702202238238115`, -31.396116959927433`]}, 2 -> {
           Complex[72.6490171369839, 0.18209643000701964`], 
           Complex[98.59740257849907, -20.391930848977243`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.7, -5.905466859299081}],
       RowBox[{"{", 
         RowBox[{"19.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"22.574834336069365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.008456231284855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713036`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.47976726661949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18448440640095548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391053157806226`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.7, "A", 
        Association[1 -> {
           Complex[22.574834336069365`, -6.008456231284855], 
           Complex[41.905778105062396`, -31.30782627713036]}, 2 -> {
           Complex[72.47976726661949, 0.18448440640095548`], 
           Complex[98.41606788851907, -20.391053157806226`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.799999999999997`, -5.904322059655149}],
       RowBox[{"{", 
         RowBox[{"19.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"22.76808034873237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.9476558694891155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774136`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.31212076958602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18690944791455164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.799999999999997`, "A", 
        Association[1 -> {
           Complex[22.76808034873237, -5.9476558694891155`], 
           Complex[42.10798974770687, -31.221155212774136`]}, 2 -> {
           Complex[72.31212076958602, 0.18690944791455164`], 
           Complex[98.23627212250696, -20.390150696605232`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{19.9, -5.9054294682152335`}],
       RowBox[{"{", 
         RowBox[{"19.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"22.959761358270317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.888361840780239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043037`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"72.14599842066895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18937236674901933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38922278462222`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.9, "A", 
        Association[1 -> {
           Complex[22.959761358270317`, -5.888361840780239], 
           Complex[42.30890299533776, -31.136043969043037`]}, 2 -> {
           Complex[72.14599842066895, 0.18937236674901933`], 
           Complex[98.05793516060473, -20.38922278462222]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20., -5.908907319617819}],
       RowBox[{"{", 
         RowBox[{"20.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"23.149943332992876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.830516882419161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482706`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.98132561745237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19187400272919972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20., "A", 
        Association[1 -> {
           Complex[23.149943332992876`, -5.830516882419161], 
           Complex[42.50858013183331, -31.052436413482706`]}, 2 -> {
           Complex[71.98132561745237, 0.19187400272919972`], 
           Complex[97.88098148963748, -20.388268714483253`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.1, -5.914756034681902}],
       RowBox[{"{", 
         RowBox[{"20.1`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"23.338688836493038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.774067198270846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.970279779373037`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.8180319787172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1944152241510169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.1, "A", 
        Association[1 -> {
           Complex[23.338688836493038`, -5.774067198270846], 
           Complex[42.70708020251328, -30.970279779373037`]}, 2 -> {
           Complex[71.8180319787172, 0.1944152241510169], 
           Complex[97.70533980076394, -20.387287751370756`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.199999999999996`, -5.922855768125003}],
       RowBox[{"{", 
         RowBox[{"20.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"23.52605730903988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7189621838426925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.90445928906574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.889524397498597`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.65605098505654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1969969286982196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.199999999999996`, "A", 
        Association[1 -> {
           Complex[23.52605730903988, -5.7189621838426925`], 
           Complex[42.90445928906574, -30.889524397498597`]}, 2 -> {
           Complex[71.65605098505654, 0.1969969286982196], 
           Complex[97.5309426293395, -20.386279132127584`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.299999999999997`, -5.932956441184807}],
       RowBox[{"{", 
         RowBox[{"20.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"23.712105320680124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.66515417934074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.10077075669193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401047`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.49531965635687`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19962004442847947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.385242064287233`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.299999999999997`, "A", 
        Association[1 -> {
           Complex[23.712105320680124`, -5.66515417934074], 
           Complex[43.10077075669193, -30.810123455401047`]}, 2 -> {
           Complex[71.49531965635687, 0.19962004442847947`], 
           Complex[97.35772603163758, -20.385242064287233`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.4, -5.944661802887896}],
       RowBox[{"{", 
         RowBox[{"20.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"23.89688679952995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.61259824734414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.29606547690717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.73203278076685`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.33577826157267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20228553082947315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.1856292938539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.4, "A", 
        Association[1 -> {
           Complex[23.89688679952995, -5.61259824734414], 
           Complex[43.29606547690717, -30.73203278076685]}, 2 -> {
           Complex[71.33577826157267, 0.20228553082947315`], 
           Complex[97.1856292938539, -20.38417572502943]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.5, -5.957412363574071}],
       RowBox[{"{", 
         RowBox[{"20.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.0804532382449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.490392028946715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.655210646076952`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.1773700568739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20499437994616249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.5, "A", 
        Association[1 -> {
           Complex[24.0804532382449, -5.561251972178108], 
           Complex[43.490392028946715`, -30.655210646076952`]}, 2 -> {
           Complex[71.1773700568739, 0.20499437994616249`], 
           Complex[97.0145946694708, -20.38307926005996]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.599999999999994`, -5.970476945355608}],
       RowBox[{"{", 
         RowBox[{"20.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.262853881242368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.5110752784691694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.6837968823168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.579617592043476`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"71.02004104879211`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20774761758097854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38195178241304`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.599999999999994`, "A", 
        Association[1 -> {
           Complex[24.262853881242368`, -5.5110752784691694`], 
           Complex[43.6837968823168, -30.579617592043476`]}, 2 -> {
           Complex[71.02004104879211, 0.20774761758097854`], 
           Complex[96.84456714160432, -20.38195178241304]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.699999999999996`, -5.982968478093198}],
       RowBox[{"{", 
         RowBox[{"20.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.444135894902008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.462030266708765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.50521626769631`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.8637397794511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117393`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.699999999999996`, "A", 
        Association[1 -> {
           Complex[24.444135894902008`, -5.462030266708765], 
           Complex[43.87632456268656, -30.50521626769631]}, 2 -> {
           Complex[70.8637397794511, 0.2105463045690771], 
           Complex[96.6754942074181, -20.38079237117393]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.799999999999997`, -5.9939031276932555`}],
       RowBox[{"{", 
         RowBox[{"20.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.624344522673923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.414081063937796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.431971285264723`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.7084171313574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21339153813132042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.379600070118972`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.799999999999997`, "A", 
        Association[1 -> {
           Complex[24.624344522673923`, -5.414081063937796], 
           Complex[44.06801780302345, -30.431971285264723`]}, 2 -> {
           Complex[70.7084171313574, 0.21339153813132042`], 
           Complex[96.50732568207661, -20.379600070118972`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{20.9, -6.002315871346328}],
       RowBox[{"{", 
         RowBox[{"20.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.803523226774285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.367193687912322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.25891768162856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.35984908824372`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.554026149556`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21628445330793847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.3400135200408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.378373886270055`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.9, "A", 
        Association[1 -> {
           Complex[24.803523226774285`, -5.367193687912322], 
           Complex[44.25891768162856, -30.35984908824372]}, 2 -> {
           Complex[70.554026149556, 0.21628445330793847`], 
           Complex[96.3400135200408, -20.378373886270055`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21., -6.007423395114715}],
       RowBox[{"{", 
         RowBox[{"21.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"24.981713817934338`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.321335923317819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.40052187923786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21922622447656767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21., "A", 
        Association[1 -> {
           Complex[24.981713817934338`, -5.321335923317819], 
           Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
           Complex[70.40052187923786, 0.21922622447656767`], 
           Complex[96.17351165179056, -20.377112788359476`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.099999999999998`, -6.008790838335313}],
       RowBox[{"{", 
         RowBox[{"21.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"25.158956574486158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360484`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.24786121712583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22221806695837287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.099999999999998`, "A", 
        Association[1 -> {
           Complex[25.158956574486158`, -5.276477208780441], 
           Complex[44.63849414140556, -30.218847270360484`]}, 2 -> {
           Complex[70.24786121712583, 0.22221806695837287`], 
           Complex[96.00777583429837, -20.375815705201227`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.2, -6.0064360001300905`}],
       RowBox[{"{", 
         RowBox[{"21.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"25.335290351911958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.232588533576678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.14990866309333`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"70.09600277517207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22526123871674927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.2, "A", 
        Association[1 -> {
           Complex[25.335290351911958`, -5.232588533576678], 
           Complex[44.82724569242562, -30.14990866309333]}, 2 -> {
           Complex[70.09600277517207, 0.22526123871674927`], 
           Complex[95.84276351378436, -20.374481523964015`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.3, -6.000821299416501}],
       RowBox[{"{", 
         RowBox[{"21.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"25.51075268384907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.01535402652587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.081974676689654`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.9449067552762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2283570421533727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.373109088340822`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.3, "A", 
        Association[1 -> {
           Complex[25.51075268384907, -5.189642343075509], 
           Complex[45.01535402652587, -30.081974676689654`]}, 2 -> {
           Complex[69.9449067552762, 0.2283570421533727], 
           Complex[95.67843369946034, -20.373109088340822`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.4, -5.9927377893299}],
       RowBox[{"{", 
         RowBox[{"21.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"25.685379875427014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.147612452062529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.015019304257965`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.79453483388642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23150682600686606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3716971966093`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.4, "A", 
        Association[1 -> {
           Complex[25.685379875427014`, -5.147612452062529], 
           Complex[45.20285365244138, -30.015019304257965`]}, 2 -> {
           Complex[69.79453483388642, 0.23150682600686606`], 
           Complex[95.51474684712201, -20.3716971966093]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.499999999999996`, -5.983136229481887}],
       RowBox[{"{", 
         RowBox[{"21.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"25.8592070897119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.389778046984475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.949017787808245`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.64485005547786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23471198735987034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.370244599576857`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.499999999999996`, "A", 
        Association[1 -> {
           Complex[25.8592070897119, -5.106473965194025], 
           Complex[45.389778046984475`, -29.949017787808245`]}, 2 -> {
           Complex[69.64485005547786, 0.23471198735987034`], 
           Complex[95.35166475158147, -20.370244599576857`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.599999999999998`, -5.972970555462042}],
       RowBox[{"{", 
         RowBox[{"21.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.03226842794698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760415`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.49581673401624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23797397376075155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.368749998403654`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.599999999999998`, "A", 
        Association[1 -> {
           Complex[26.03226842794698, -5.066203203916086], 
           Complex[45.57615973333944, -29.88394654760415]}, 2 -> {
           Complex[69.49581673401624, 0.23797397376075155`], 
           Complex[95.18915044704522, -20.368749998403654`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.7, -5.963092620012544}],
       RowBox[{"{", 
         RowBox[{"21.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.20459700420211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.819783117245702`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.34740036161425`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546682113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36721204229602`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.7, "A", 
        Association[1 -> {
           Complex[26.20459700420211, -5.026777639259069], 
           Complex[45.76203035396384, -29.819783117245702`]}, 2 -> {
           Complex[69.34740036161425, 0.24129428546682113`], 
           Complex[95.02716811464276, -20.36721204229602]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.799999999999997`, -5.954203366794505}],
       RowBox[{"{", 
         RowBox[{"21.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.376225014979173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.988175829983501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970773`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.19956752367546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24467447781636717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.365629326062496`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.799999999999997`, "A", 
        Association[1 -> {
           Complex[26.376225014979173`, -4.988175829983501], 
           Complex[45.94742073863614, -29.756506083970773`]}, 2 -> {
           Complex[69.19956752367546, 0.24467447781636717`], 
           Complex[94.86568299639735, -20.365629326062496`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.899999999999995`, -5.946845756257354}],
       RowBox[{"{", 
         RowBox[{"21.899999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.54718380426279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9503773656115`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"46.13236096813211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720565`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"69.05228581989404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2481161637376161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523564`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.899999999999995`, "A", 
        Association[1 -> {
           Complex[26.54718380426279, -4.9503773656115], 
           Complex[46.13236096813211, -29.694095033720565`]}, 2 -> {
           Complex[69.05228581989404, 0.2481161637376161], 
           Complex[94.70466131500459, -20.364000387523564`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{21.999999999999996`, -5.941420659112044}],
       RowBox[{"{", 
         RowBox[{"21.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.71750392445519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.91336281392886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.31688043396312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.63253050056466`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.90552379054706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.25162101640318657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.999999999999996`, "A", 
        Association[1 -> {
           Complex[26.71750392445519, -4.91336281392886], 
           Complex[46.31688043396312, -29.63253050056466]}, 2 -> {
           Complex[68.90552379054706, 0.25162101640318657`], 
           Complex[94.54407019885232, -20.362323704765814`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.099999999999998`, -5.93821113603826}],
       RowBox[{"{", 
         RowBox[{"22.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"26.88721519359033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.8771136725869555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.501007894566264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.57179392012435`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.75925084757176`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2551907720394873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.3838776117713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.099999999999998`, "A", 
        Association[1 -> {
           Complex[26.88721519359033, -4.8771136725869555`], 
           Complex[46.501007894566264`, -29.57179392012435]}, 2 -> {
           Complex[68.75925084757176, 0.2551907720394873], 
           Complex[94.3838776117713, -20.360597693230243`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.2, -5.937406375098767}],
       RowBox[{"{", 
         RowBox[{"22.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.056346749183458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.841612324474782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.511867586673578`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.61343720997206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2588272329011793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623657`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.2, "A", 
        Association[1 -> {
           Complex[27.056346749183458`, -4.841612324474782], 
           Complex[46.684771528299024`, -29.511867586673578`]}, 2 -> {
           Complex[68.61343720997206, 0.2588272329011793], 
           Complex[94.22405228705699, -20.358820702623657`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.3, -5.9391210356528035`}],
       RowBox[{"{", 
         RowBox[{"22.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.22492709903808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.86819898355647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.452734613629456`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.46805384314331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2625322704216664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.3, "A", 
        Association[1 -> {
           Complex[27.22492709903808, -4.806841996564799], 
           Complex[46.86819898355647, -29.452734613629456`]}, 2 -> {
           Complex[68.46805384314331, 0.2625322704216664], 
           Complex[94.06456366534842, -20.35699101364115]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.4, -5.943408332802917}],
       RowBox[{"{", 
         RowBox[{"22.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.392984169302537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.772786721969353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.32307240174265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2663078285515145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486676`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.4, "A", 
        Association[1 -> {
           Complex[27.392984169302537`, -4.772786721969353], 
           Complex[47.051317426301225`, -29.394378897177]}, 2 -> {
           Complex[68.32307240174265, 0.2663078285515145], 
           Complex[93.90538183598731, -20.355106834486676`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.499999999999996`, -5.9502663363130734`}],
       RowBox[{"{", 
         RowBox[{"22.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.56054535004208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.739431304971095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.234153585269965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.336785082799015`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.17846517576804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27015592729763743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.499999999999996`, "A", 
        Association[1 -> {
           Complex[27.56054535004208, -4.739431304971095], 
           Complex[47.234153585269965`, -29.336785082799015`]}, 2 -> {
           Complex[68.17846517576804, 0.27015592729763743`], 
           Complex[93.7464774815166, -20.353166297177687`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.599999999999998`, -5.959637226621168}],
       RowBox[{"{", 
         RowBox[{"22.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.727637538568867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.706761288816323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"68.03420503953862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27407866647716145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.351167453618455`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.599999999999998`, "A", 
        Association[1 -> {
           Complex[27.727637538568867`, -4.706761288816323], 
           Complex[47.41673379509784, -29.279938534507]}, 2 -> {
           Complex[68.03420503953862, 0.27407866647716145`], 
           Complex[93.58782182500669, -20.351167453618455`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.7, -5.971399099409826}],
       RowBox[{"{", 
         RowBox[{"22.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"27.894287180751792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.674762926083082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.599084037582415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.223825306591664`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.89026540329692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2780782297010494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.349108271425646`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.7, "A", 
        Association[1 -> {
           Complex[27.894287180751792`, -4.674762926083082], 
           Complex[47.599084037582415`, -29.223825306591664`]}, 2 -> {
           Complex[67.89026540329692, 0.2780782297010494], 
           Complex[93.42938657992539, -20.349108271425646`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.799999999999997`, -5.985349697365345}],
       RowBox[{"{", 
         RowBox[{"22.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.060520310510153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.6434231514550905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.78122998129108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.16843211773069`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.74662016717633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.282156888603788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.27114390229022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.799999999999997`, "A", 
        Association[1 -> {
           Complex[28.060520310510153`, -4.6434231514550905`], 
           Complex[47.78122998129108, -29.16843211773069]}, 2 -> {
           Complex[67.74662016717633, 0.282156888603788], 
           Complex[93.27114390229022, -20.34698662948813]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.9, -6.0011815753644795`}],
       RowBox[{"{", 
         RowBox[{"22.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.22636258767924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.113746327310373`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.60324367729916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2863170073368824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.9, "A", 
        Association[1 -> {
           Complex[28.22636258767924, -4.612729556752129], 
           Complex[47.96319701970124, -29.113746327310373`]}, 2 -> {
           Complex[67.60324367729916, 0.2863170073368824], 
           Complex[93.11306634486286, -20.344800313241485`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{22.999999999999996`, -6.018449299101462}],
       RowBox[{"{", 
         RowBox[{"22.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.391839334421146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.582670368083356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834188`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.46011068378857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.342547009636124`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.999999999999996`, "A", 
        Association[1 -> {
           Complex[28.391839334421146`, -4.582670368083356], 
           Complex[48.14501030804771, -29.059755913834188`]}, 2 -> {
           Complex[67.46011068378857, 0.2905610473453296], 
           Complex[92.95512681316393, -20.342547009636124`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.099999999999998`, -6.036532334509598}],
       RowBox[{"{", 
         RowBox[{"23.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.556975570343152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.553234425005791`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.326694799042336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.00644945530591`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.31719630049454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29489157244794845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.099999999999998`, "A", 
        Association[1 -> {
           Complex[28.556975570343152`, -4.553234425005791], 
           Complex[48.326694799042336`, -29.00644945530591]}, 2 -> {
           Complex[67.31719630049454, 0.29489157244794845`], 
           Complex[92.79729852310203, -20.34022430177586]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.199999999999996`, -6.054603533961739}],
       RowBox[{"{", 
         RowBox[{"23.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.721796046473646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.524411161584021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.9538161114898`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.17447596624794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29931125424420046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202015`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.199999999999996`, "A", 
        Association[1 -> {
           Complex[28.721796046473646`, -4.524411161584021], 
           Complex[48.50827527761825, -28.9538161114898]}, 2 -> {
           Complex[67.17447596624794, 0.29931125424420046`], 
           Complex[92.63955496002485, -20.337829663202015`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.299999999999997`, -6.071622941515521}],
       RowBox[{"{", 
         RowBox[{"23.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"28.88632527823729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.68977639484416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.901845607962514`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"67.03192540747014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3038228778721793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.299999999999997`, "A", 
        Association[1 -> {
           Complex[28.88632527823729, -4.496190589260186], 
           Complex[48.68977639484416, -28.901845607962514`]}, 2 -> {
           Complex[67.03192540747014, 0.3038228778721793], 
           Complex[92.48186983901314, -20.33536045179569]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.4, -6.086386673082809}],
       RowBox[{"{", 
         RowBox[{"23.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.050587577562062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.468563281455599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.871222701145584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.850528221884158`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.88952060197633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3084293481445193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.332813903268473`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.4, "A", 
        Association[1 -> {
           Complex[29.050587577562062`, -4.468563281455599], 
           Complex[48.871222701145584`, -28.850528221884158`]}, 2 -> {
           Complex[66.88952060197633, 0.3084293481445193], 
           Complex[92.32421706624814, -20.332813903268473`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.5, -6.097659990753362}],
       RowBox[{"{", 
         RowBox[{"23.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.21460708424427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.44152035983643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.79985476942697`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.7472377438204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31313369609146635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33018712420928`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.5, "A", 
        Association[1 -> {
           Complex[29.21460708424427, -4.44152035983643], 
           Complex[49.05263867896423, -28.79985476942697]}, 2 -> {
           Complex[66.7472377438204, 0.31313369609146635`], 
           Complex[92.16657070129293, -20.33018712420928]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.6, -6.104395944158584}],
       RowBox[{"{", 
         RowBox[{"23.6`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.37840779669111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.23404877498035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.7498165948108`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.60505320903809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3179390859428899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651893`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.6, "A", 
        Association[1 -> {
           Complex[29.37840779669111, -4.4150534821866145`], 
           Complex[49.23404877498035, -28.7498165948108]}, 2 -> {
           Complex[66.60505320903809, 0.3179390859428899], 
           Complex[92.00890492013563, -20.327477084651893`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.699999999999996`, -6.105982868676933}],
       RowBox[{"{", 
         RowBox[{"23.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.542013602155205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.389154831841678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905736`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.46294352215183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.322848822583996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.85119397884918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.324680610124492`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.699999999999996`, "A", 
        Association[1 -> {
           Complex[29.542013602155205`, -4.389154831841678], 
           Complex[49.41547743201958, -28.700405560905736`]}, 2 -> {
           Complex[66.46294352215183, 0.322848822583996], 
           Complex[91.85119397884918, -20.324680610124492`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.799999999999997`, -6.102412391420586}],
       RowBox[{"{", 
         RowBox[{"23.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.705448306571707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.363817108646442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.596949120761906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.651614041371168`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.32088532330775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32786635952260046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.321794373139106`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.799999999999997`, "A", 
        Association[1 -> {
           Complex[29.705448306571707`, -4.363817108646442], 
           Complex[49.596949120761906`, -28.651614041371168`]}, 2 -> {
           Complex[66.32088532330775, 0.32786635952260046`], 
           Complex[91.6934121777283, -20.321794373139106`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{23.9, -6.094276055015946}],
       RowBox[{"{", 
         RowBox[{"23.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"29.868735664104204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.33903352140945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.60343491431109`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.17885533591951`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3329953074094176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.9, "A", 
        Association[1 -> {
           Complex[29.868735664104204`, -4.33903352140945], 
           Complex[49.77848837136716, -28.60343491431109]}, 2 -> {
           Complex[66.17885533591951, 0.3329953074094176], 
           Complex[91.53553382576803, -20.318814884074637`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24., -6.082592343494434}],
       RowBox[{"{", 
         RowBox[{"24.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.0318994065037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.960119805130674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.555861557435456`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"66.0368303346989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3382394431566841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24., "A", 
        Association[1 -> {
           Complex[30.0318994065037, -4.314797781836445], 
           Complex[49.960119805130674`, -28.555861557435456`]}, 2 -> {
           Complex[66.0368303346989, 0.3382394431566841], 
           Complex[91.37753320535236, -20.315738481402835`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.099999999999994`, -6.068558104968078}],
       RowBox[{"{", 
         RowBox[{"24.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.194963272382548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.291104099934118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.141868166281284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.50888784472627`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.89478711395589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.312561321201745`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.099999999999994`, "A", 
        Association[1 -> {
           Complex[30.194963272382548`, -4.291104099934118], 
           Complex[50.141868166281284`, -28.50888784472627]}, 2 -> {
           Complex[65.89478711395589, 0.34360271970474526`], 
           Complex[91.21938453702393, -20.312561321201745`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.199999999999996`, -6.053332127089529}],
       RowBox[{"{", 
         RowBox[{"24.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.35795103650346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.26794718088456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.3237583540324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.46250814461731`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.75270245605407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34908927649101035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.199999999999996`, "A", 
        Association[1 -> {
           Complex[30.35795103650346, -4.26794718088456], 
           Complex[50.3237583540324, -28.46250814461731]}, 2 -> {
           Complex[65.75270245605407, 0.34908927649101035`], 
           Complex[91.0610619442071, -20.30927936589565]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.299999999999997`, -6.037905643654194}],
       RowBox[{"{", 
         RowBox[{"24.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.520886539183877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.24532222340097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.50581545499962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.416717319706727`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.6105530999087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3547034506809741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154577`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.299999999999997`, "A", 
        Association[1 -> {
           Complex[30.520886539183877`, -4.24532222340097], 
           Complex[50.50581545499962, -28.416717319706727`]}, 2 -> {
           Complex[65.6105530999087, 0.3547034506809741], 
           Complex[90.90253941775816, -20.305888372154577`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.4, -6.023056887736619}],
       RowBox[{"{", 
         RowBox[{"24.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.683793715914877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.22322491958401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.688064776097136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.371510728031744`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.46831570941634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36044978922689475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.7437907802159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.4, "A", 
        Association[1 -> {
           Complex[30.683793715914877`, -4.22322491958401], 
           Complex[50.688064776097136`, -28.371510728031744`]}, 2 -> {
           Complex[65.46831570941634, 0.36044978922689475`], 
           Complex[90.7437907802159, -20.30238387787967]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.499999999999996`, -6.00936006144887}],
       RowBox[{"{", 
         RowBox[{"24.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"30.846696627295138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.201651456308564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.87053187802873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.326884225945257`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.325966841705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3663330618262281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.298761188193378`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.499999999999996`, "A", 
        Association[1 -> {
           Complex[30.846696627295138`, -4.201651456308564], 
           Complex[50.87053187802873, -28.326884225945257`]}, 2 -> {
           Complex[65.325966841705, 0.3663330618262281], 
           Complex[90.58478964962532, -20.298761188193378`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.599999999999998`, -5.9972191517721996`}],
       RowBox[{"{", 
         RowBox[{"24.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.009619489380988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.180598518180851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.28283417264592`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.1834829150937`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3723582748592317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.599999999999998`, "A", 
        Association[1 -> {
           Complex[31.009619489380988`, -4.180598518180851], 
           Complex[51.05324260949038, -28.28283417264592]}, 2 -> {
           Complex[65.1834829150937, 0.3723582748592317], 
           Complex[90.42550940280545, -20.29501536034502]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.7, -5.986907324200818}],
       RowBox[{"{", 
         RowBox[{"24.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.172586704555457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.160063292117314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.236223142205915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.239357436425397`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"65.04084017664968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3785306863932047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.7, "A", 
        Association[1 -> {
           Complex[31.172586704555457`, -4.160063292117314], 
           Complex[51.236223142205915`, -28.239357436425397`]}, 2 -> {
           Complex[65.04084017664968, 0.3785306863932047], 
           Complex[90.26592313793014, -20.291141187433084`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.8, -5.978602484680225}],
       RowBox[{"{", 
         RowBox[{"24.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.33562289302192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708604`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.89801466922918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3848558223499517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.287133180835255`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.8, "A", 
        Association[1 -> {
           Complex[31.33562289302192, -4.140043473607489], 
           Complex[51.419500006920465`, -28.196451402708604`]}, 2 -> {
           Complex[64.89801466922918, 0.3848558223499517], 
           Complex[90.10600363628704, -20.287133180835255`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.9, -5.97241584290643}],
       RowBox[{"{", 
         RowBox[{"24.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.49875292502993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.603100130481025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.75498219788668`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.391339493943095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225515`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.9, "A", 
        Association[1 -> {
           Complex[31.49875292502993, -4.120537274736596], 
           Complex[51.603100130481025`, -28.154113983977776`]}, 2 -> {
           Complex[64.75498219788668, 0.391339493943095], 
           Complex[89.94572332307655, -20.282985551225515`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{24.999999999999996`, -5.9684133925013345`}],
       RowBox[{"{", 
         RowBox[{"24.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.662001953945484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.101543434056313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685345`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.61171829553294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3979878165032359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.7850542271069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.999999999999996`, "A", 
        Association[1 -> {
           Complex[31.662001953945484`, -4.101543434056313], 
           Complex[51.78705087413992, -28.112343631685345`]}, 2 -> {
           Complex[64.61171829553294, 0.3979878165032359], 
           Complex[89.7850542271069, -20.278692188044857`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.099999999999998`, -5.9666313864981095`}],
       RowBox[{"{", 
         RowBox[{"25.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.825395450280787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.083061228407537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277985`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.46819818772052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40480722982158246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.62396793923683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.099999999999998`, "A", 
        Association[1 -> {
           Complex[31.825395450280787`, -4.083061228407537], 
           Complex[51.97138007322182, -28.071139350277985`]}, 2 -> {
           Complex[64.46819818772052, 0.40480722982158246`], 
           Complex[89.62396793923683, -20.274246637277333`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.199999999999996`, -5.967087101533331}],
       RowBox[{"{", 
         RowBox[{"25.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"31.988959236804785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.065090486814274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.32439675642944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4118045201569269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.269642077367138`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.199999999999996`, "A", 
        Association[1 -> {
           Complex[31.988959236804785`, -4.065090486814274], 
           Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
           Complex[64.32439675642944, 0.4118045201569269], 
           Complex[89.46243556940976, -20.269642077367138`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.299999999999997`, -5.9697860115385355`}],
       RowBox[{"{", 
         RowBox[{"25.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.1527195248595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.99042788293637`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.18028850272216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.41898684406680864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.299999999999997`, "A", 
        Association[1 -> {
           Complex[32.1527195248595, -4.047631606586535], 
           Complex[52.34128779806401, -27.99042788293637]}, 2 -> {
           Complex[64.18028850272216, 0.41898684406680864`], 
           Complex[89.30042770211665, -20.26487129309376]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.399999999999995`, -5.974726200508385}],
       RowBox[{"{", 
         RowBox[{"25.399999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.31670295201473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.52692474396548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.95092162957881`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"64.03584750813043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42636175424164896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201578`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.399999999999995`, "A", 
        Association[1 -> {
           Complex[32.31670295201473, -4.030685571788463], 
           Complex[52.52692474396548, -27.95092162957881]}, 2 -> {
           Complex[64.03584750813043, 0.42636175424164896`], 
           Complex[89.13791435011574, -20.259926647201578`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.499999999999996`, -5.981900540424588}],
       RowBox[{"{", 
         RowBox[{"25.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.48093662119898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.7130570769491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.911983357620024`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.891047394630874`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4339372275409471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.499999999999996`, "A", 
        Association[1 -> {
           Complex[32.48093662119898, -4.014253974250843], 
           Complex[52.7130570769491, -27.911983357620024`]}, 2 -> {
           Complex[63.891047394630874`, 0.4339372275409471], 
           Complex[88.97486490622836, -20.25480004955709]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.599999999999998`, -5.99129687114047}],
       RowBox[{"{", 
         RowBox[{"25.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.645448141453244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.998339037330256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.89971565632317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87361513171316`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.7458612830591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4417216954533841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24948292358025`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.599999999999998`, "A", 
        Association[1 -> {
           Complex[32.645448141453244`, -3.998339037330256], 
           Complex[52.89971565632317, -27.87361513171316]}, 2 -> {
           Complex[63.7458612830591, 0.4417216954533841], 
           Complex[88.81124809301977, -20.24948292358025]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.7, -6.002896134175796}],
       RowBox[{"{", 
         RowBox[{"25.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.810265670460794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9829436426451004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.086932091046236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.600261749804105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.243966169666688`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.7, "A", 
        Association[1 -> {
           Complex[32.810265670460794`, -3.9829436426451004`], 
           Complex[53.086932091046236`, -27.835819707361438`]}, 2 -> {
           Complex[63.600261749804105`, 0.44972407722861746`], 
           Complex[88.64703191016159, -20.243966169666688`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.799999999999997`, -6.016668106183902}],
       RowBox[{"{", 
         RowBox[{"25.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"32.97541795901581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.27473879361426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.798600564939377`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.45422078161694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45795381595762275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23824012528373`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.799999999999997`, "A", 
        Association[1 -> {
           Complex[32.97541795901581, -3.968071360048478], 
           Complex[53.27473879361426, -27.798600564939377`]}, 2 -> {
           Complex[63.45422078161694, 0.45795381595762275`], 
           Complex[88.48218357926147, -20.23824012528373]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{25.9, -6.032564018752915}],
       RowBox[{"{", 
         RowBox[{"25.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.14093439760302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.953726481132371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.76196194765724`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.30770972835797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.466420917911682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23229452138455`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.9, "A", 
        Association[1 -> {
           Complex[33.14093439760302, -3.953726481132371], 
           Complex[53.46316903677714, -27.76196194765724]}, 2 -> {
           Complex[63.30770972835797, 0.466420917911682], 
           Complex[88.31666948593067, -20.23229452138455]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26., -6.050504912034974}],
       RowBox[{"{", 
         RowBox[{"26.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.306845065269485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.939914056596168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.72590890385442`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.16069925349776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4751359954876585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741064`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26., "A", 
        Association[1 -> {
           Complex[33.306845065269485`, -3.939914056596168], 
           Complex[53.65225701332302, -27.72590890385442]}, 2 -> {
           Complex[63.16069925349776, 0.4751359954876585], 
           Complex[88.15045511884611, -20.226118434741064`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.099999999999998`, -6.070364050718319}],
       RowBox[{"{", 
         RowBox[{"26.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.47318078098145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9266399378561223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.842037899187076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.69044733405728`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"63.01315928217634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4841103141499007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746625`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.099999999999998`, "A", 
        Association[1 -> {
           Complex[33.47318078098145, -3.9266399378561223`], 
           Complex[53.842037899187076`, -27.69044733405728]}, 2 -> {
           Complex[63.01315928217634, 0.4841103141499007], 
           Complex[87.98350500554794, -20.219700235746625`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.2, -6.091941217311784}],
       RowBox[{"{", 
         RowBox[{"26.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.63997315766917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.0325479201562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.655584043295313`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.86505894661449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49335584380795366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.8157826446966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.21302753118228`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.2, "A", 
        Association[1 -> {
           Complex[33.63997315766917, -3.913910823322055], 
           Complex[54.0325479201562, -27.655584043295313`]}, 2 -> {
           Complex[62.86505894661449, 0.49335584380795366`], 
           Complex[87.8157826446966, -20.21302753118228]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.299999999999997`, -6.114926491086043}],
       RowBox[{"{", 
         RowBox[{"26.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.80725465917451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9017343098237633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.223824422460964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.621326799234737`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.71636652866016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5028853151246296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376106`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.299999999999997`, "A", 
        Association[1 -> {
           Complex[33.80725465917451, -3.9017343098237633`], 
           Complex[54.223824422460964`, -27.621326799234737`]}, 2 -> {
           Complex[62.71636652866016, 0.5028853151246296], 
           Complex[87.64725043449562, -20.206087101376106`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.399999999999995`, -6.138851997322265}],
       RowBox[{"{", 
         RowBox[{"26.399999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"33.975058660327356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8901189497339574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.415905947563445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.587684396763738`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.56704939924091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5127122813126167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.4778695969676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19886483111003`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.399999999999995`, "A", 
        Association[1 -> {
           Complex[33.975058660327356`, -3.8901189497339574`], 
           Complex[54.415905947563445`, -27.587684396763738`]}, 2 -> {
           Complex[62.56704939924091, 0.5127122813126167], 
           Complex[87.4778695969676, -20.19886483111003]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.499999999999996`, -6.163033709672638}],
       RowBox[{"{", 
         RowBox[{"26.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.143419510388775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.879074314407841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749552`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.417073954482824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19134563354414`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.499999999999996`, "A", 
        Association[1 -> {
           Complex[34.143419510388775`, -3.879074314407841], 
           Complex[54.60883231147051, -27.554666729749552`]}, 2 -> {
           Complex[62.417073954482824`, 0.5228511860504309], 
           Complex[87.30760009775224, -20.19134563354414]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.599999999999998`, -6.186514414615617}],
       RowBox[{"{", 
         RowBox[{"26.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.312372600109356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8686110646435656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.80264468892042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.5222848707862`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.26640554824476`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5333174382317767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330008`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.599999999999998`, "A", 
        Association[1 -> {
           Complex[34.312372600109356`, -3.8686110646435656`], 
           Complex[54.80264468892042, -27.5222848707862]}, 2 -> {
           Complex[62.26640554824476, 0.5333174382317767], 
           Complex[87.13640056107454, -20.183513366330008`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.699999999999996`, -6.208035909969014}],
       RowBox[{"{", 
         RowBox[{"26.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.48195443266224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49055115986421`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"62.11500842080698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.699999999999996`, "A", 
        Association[1 -> {
           Complex[34.48195443266224, -3.8587410289636725`], 
           Complex[54.99738570281197, -27.49055115986421]}, 2 -> {
           Complex[62.11500842080698, 0.5441274943581387], 
           Complex[86.96422817951265, -20.175350738972366`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.799999999999997`, -6.226090224358992}],
       RowBox[{"{", 
         RowBox[{"26.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.65220269871858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.193099519263775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.45947930302496`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.96284562344401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.555298949494675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.799999999999997`, "A", 
        Association[1 -> {
           Complex[34.65220269871858, -3.849477290628971], 
           Complex[55.193099519263775`, -27.45947930302496]}, 2 -> {
           Complex[61.96284562344401, 0.555298949494675], 
           Complex[86.79103861817467, -20.166839210368295`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{26.9, -6.239106544421606}],
       RowBox[{"{", 
         RowBox[{"26.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.82315635594019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8408342844230736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.429084482211824`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.80987893860578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668506378361227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.157958875303546`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.9, "A", 
        Association[1 -> {
           Complex[34.82315635594019, -3.8408342844230736`], 
           Complex[55.38983194870933, -27.429084482211824`]}, 2 -> {
           Complex[61.80987893860578, 0.5668506378361227], 
           Complex[86.61678591287696, -20.157958875303546`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27., -6.245784651828904}],
       RowBox[{"{", 
         RowBox[{"27.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"34.99485571316776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.58763055344998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.65606879542663`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5788027440763145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27., "A", 
        Association[1 -> {
           Complex[34.99485571316776, -3.8328279043933393`], 
           Complex[55.58763055344998, -27.39938347770468]}, 2 -> {
           Complex[61.65606879542663, 0.5788027440763145], 
           Complex[86.44142236189973, -20.148688338511917`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.1, -6.245472095625256}],
       RowBox[{"{", 
         RowBox[{"27.1`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"35.16734251958135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725706`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.501374180284344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702856`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.1, "A", 
        Association[1 -> {
           Complex[35.16734251958135, -3.8254756239037375`], 
           Complex[55.78654476209901, -27.370394804725706`]}, 2 -> {
           Complex[61.501374180284344`, 0.5911769269441449], 
           Complex[86.26489841088478, -20.139004574702856`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.2, -6.238383365820953}],
       RowBox[{"{", 
         RowBox[{"27.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"35.34066005910287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.81879662955199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.342138866037867`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.345752542137845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.603996456465433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.2, "A", 
        Association[1 -> {
           Complex[35.34066005910287, -3.81879662955199], 
           Complex[55.98662599135723, -27.342138866037867`]}, 2 -> {
           Complex[61.345752542137845`, 0.603996456465433], 
           Complex[86.08716253043333, -20.128882772728787`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.299999999999997`, -6.225515765939542}],
       RowBox[{"{", 
         RowBox[{"27.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"35.5148532502931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8128119707315338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.31463812262956`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.18915969238974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6172863667379076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792685`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.299999999999997`, "A", 
        Association[1 -> {
           Complex[35.5148532502931, -3.8128119707315338`], 
           Complex[56.18792777555814, -27.31463812262956]}, 2 -> {
           Complex[61.18915969238974, 0.6172863667379076], 
           Complex[85.90816108596371, -20.118296161792685`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.4, -6.208318966107456}],
       RowBox[{"{", 
         RowBox[{"27.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"35.68996875196817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.39050590440941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.28791728489552`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"61.03154969904756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6310736262715524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.107215817279773`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.4, "A", 
        Association[1 -> {
           Complex[35.68996875196817, -3.807544726884647], 
           Complex[56.39050590440941, -27.28791728489552]}, 2 -> {
           Complex[61.03154969904756, 0.6310736262715524], 
           Complex[85.72783819940136, -20.107215817279773`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.499999999999993`, -6.18831841354781}],
       RowBox[{"{", 
         RowBox[{"27.499999999999993`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"35.866055074715334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8030201948010105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.262003527092865`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.872874775003034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.5461356023026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.095610443428537`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.499999999999993`, "A", 
        Association[1 -> {
           Complex[35.866055074715334`, -3.8030201948010105`], 
           Complex[56.594418569327175`, -27.262003527092865`]}, 2 -> {
           Complex[60.872874775003034`, 0.6453873282550383], 
           Complex[85.5461356023026, -20.095610443428537`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.599999999999994`, -6.166854055005772}],
       RowBox[{"{", 
         RowBox[{"27.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.04316269842235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7992660986771667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.799726518711694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.236926728284004`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.71308516031326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6602589034686106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.36299248006208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.599999999999994`, "A", 
        Association[1 -> {
           Complex[36.04316269842235, -3.7992660986771667`], 
           Complex[56.799726518711694`, -27.236926728284004`]}, 2 -> {
           Complex[60.71308516031326, 0.6602589034686106], 
           Complex[85.36299248006208, -20.08344612962457]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.699999999999996`, -6.14497120165936}],
       RowBox[{"{", 
         RowBox[{"27.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.22134419584062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7963128260714716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.006493222433235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.212719743482186`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.552128998463665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595752`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.699999999999996`, "A", 
        Association[1 -> {
           Complex[36.22134419584062, -3.7963128260714716`], 
           Complex[57.006493222433235`, -27.212719743482186`]}, 2 -> {
           Complex[60.552128998463665`, 0.6757223589838265], 
           Complex[85.17834530693467, -20.070686076595752`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.799999999999997`, -6.1234191614875995`}],
       RowBox[{"{", 
         RowBox[{"27.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.4006543620702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794193693381184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.389952206722754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.99212767171738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.799999999999997`, "A", 
        Association[1 -> {
           Complex[36.4006543620702, -3.794193693381184], 
           Complex[57.21478504568002, -27.18941870930894]}, 2 -> {
           Complex[60.389952206722754`, 0.6918145462814401], 
           Complex[84.99212767171738, -20.057290288195432`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.9, -6.102700153732991}],
       RowBox[{"{", 
         RowBox[{"27.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.58115034967376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.16706338916731`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.22649834088111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7085754629936015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.04321522376426`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.9, "A", 
        Association[1 -> {
           Complex[36.58115034967376, -3.7929452450428247`], 
           Complex[57.42467143215045, -27.16706338916731]}, 2 -> {
           Complex[60.22649834088111, 0.7085754629936015], 
           Complex[84.80427009410889, -20.04321522376426]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{27.999999999999996`, -6.083129814026744}],
       RowBox[{"{", 
         RowBox[{"27.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.76289180887989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.636225096332794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.145697563752844`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"60.06170845491359`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245878`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.999999999999996`, "A", 
        Association[1 -> {
           Complex[36.76289180887989, -3.7926075913306474`], 
           Complex[57.636225096332794`, -27.145697563752844`]}, 2 -> {
           Complex[60.06170845491359, 0.7260485931492001], 
           Complex[84.61469983200216, -20.028413405245878`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.099999999999998`, -6.064891160614043}],
       RowBox[{"{", 
         RowBox[{"28.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"36.94594103200389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7932247904164975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.84952222428347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.125369473683783`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.89552095643557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7442812915903373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.012832972269205`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.099999999999998`, "A", 
        Association[1 -> {
           Complex[36.94594103200389, -3.7932247904164975`], 
           Complex[57.84952222428347, -27.125369473683783`]}, 2 -> {
           Complex[59.89552095643557, 0.7442812915903373], 
           Complex[84.42334068029797, -20.012832972269205`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.2, -6.048076617050576}],
       RowBox[{"{", 
         RowBox[{"28.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"37.13036310076835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794845281279751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.106132322164278`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.72787145927004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7633252191523081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281284`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.2, "A", 
        Association[1 -> {
           Complex[37.13036310076835, -3.794845281279751], 
           Complex[58.06464268186045, -27.106132322164278`]}, 2 -> {
           Complex[59.72787145927004, 0.7633252191523081], 
           Complex[84.2301127622816, -19.996417177281284`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.3, -6.03271849076245}],
       RowBox[{"{", 
         RowBox[{"28.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"37.31622603461241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.797522375138974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.0880448469234`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.5586926350365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7832368362827162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.97910381148327`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.3, "A", 
        Association[1 -> {
           Complex[37.31622603461241, -3.797522375138974], 
           Complex[58.28167022874946, -27.0880448469234]}, 2 -> {
           Complex[59.5586926350365, 0.7832368362827162], 
           Complex[84.03493231522438, -19.97910381148327]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.399999999999995`, -6.018810193348809}],
       RowBox[{"{", 
         RowBox[{"28.399999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"37.503600937288496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8013148143453006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.50069273578578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.38791406646194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8040779640432751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.960824550758474`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.399999999999995`, "A", 
        Association[1 -> {
           Complex[37.503600937288496`, -3.8013148143453006`], 
           Complex[58.50069273578578, -27.07117197223767]}, 2 -> {
           Complex[59.38791406646194, 0.8040779640432751], 
           Complex[83.83771147270659, -19.960824550758474`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.499999999999996`, -6.006320648020628}],
       RowBox[{"{", 
         RowBox[{"28.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"37.692562137998024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.806287409159504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.72180240194932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.05558555368316`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.21546210616129`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.941504208943837`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.499999999999996`, "A", 
        Association[1 -> {
           Complex[37.692562137998024`, -3.806287409159504], 
           Complex[58.72180240194932, -27.05558555368316]}, 2 -> {
           Complex[59.21546210616129, 0.8259164229195795], 
           Complex[83.63835804728225, -19.941504208943837`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.599999999999998`, -5.995203906971244}],
       RowBox[{"{", 
         RowBox[{"28.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"37.88318732193246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.9450959659065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"59.04125974602169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8488267615895433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642382`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.599999999999998`, "A", 
        Association[1 -> {
           Complex[37.88318732193246, -3.812511764560067], 
           Complex[58.9450959659065, -27.04136523041568]}, 2 -> {
           Complex[59.04125974602169, 0.8488267615895433], 
           Complex[83.43677531861314, -19.921059883642382`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.699999999999996`, -5.985405485592725}],
       RowBox[{"{", 
         RowBox[{"28.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"38.07555764325092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.820067111231534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.170674904956044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.028599402293732`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"58.86522650415762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8728910898028908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259353`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.699999999999996`, "A", 
        Association[1 -> {
           Complex[38.07555764325092, -3.820067111231534], 
           Complex[59.170674904956044`, -27.028599402293732`]}, 2 -> {
           Complex[58.86522650415762, 0.8728910898028908], 
           Complex[83.23286183421266, -19.899399977259353`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.799999999999994`, -5.976866478996161}],
       RowBox[{"{", 
         RowBox[{"28.799999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"38.26975781110342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.82904125718843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081296`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"58.68727833882761`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318297491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022412`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.799999999999994`, "A", 
        Association[1 -> {
           Complex[38.26975781110342, -3.82904125718843], 
           Complex[59.39864561154835, -27.017386352081296`]}, 2 -> {
           Complex[58.68727833882761, 0.8982000318297491], 
           Complex[83.02651123262952, -19.876423073022412`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.899999999999995`, -5.9695261934875194`}],
       RowBox[{"{", 
         RowBox[{"28.899999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"38.46587613610713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.839531679121346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.62911953396363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"58.50732760190553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9248538195678667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.899999999999995`, "A", 
        Association[1 -> {
           Complex[38.46587613610713, -3.839531679121346], 
           Complex[59.62911953396363, -27.007835536336128`]}, 2 -> {
           Complex[58.50732760190553, 0.9248538195678667], 
           Complex[82.81761210248663, -19.852016642377055`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{28.999999999999996`, -5.963323789470528}],
       RowBox[{"{", 
         RowBox[{"28.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"38.66400452045292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8516467755142054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431693`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"58.32528304872727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9529635473601222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.999999999999996`, "A", 
        Association[1 -> {
           Complex[38.66400452045292, -3.8516467755142054`], 
           Complex[59.86221326295697, -27.000069072431693`]}, 2 -> {
           Complex[58.32528304872727, 0.9529635473601222], 
           Complex[82.60604789556439, -19.826055556306983`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.099999999999998`, -5.958199269933873}],
       RowBox[{"{", 
         RowBox[{"29.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"38.86423836923639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.99422345346926`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"58.141049926719695`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.798400368820353`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.099999999999998`, "A", 
        Association[1 -> {
           Complex[38.86423836923639, -3.865507306847949], 
           Complex[60.09804853982374, -26.99422345346926]}, 2 -> {
           Complex[58.141049926719695`, 0.9826526138400205], 
           Complex[82.39169691847611, -19.798400368820353`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.2, -5.954094039125011}],
       RowBox[{"{", 
         RowBox[{"29.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"39.06667639323606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.336752152884166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.990451527552715`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"57.954530172587724`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.01405837961428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.2, "A", 
        Association[1 -> {
           Complex[39.06667639323606, -3.8812480516973484`], 
           Complex[60.336752152884166`, -26.990451527552715`]}, 2 -> {
           Complex[57.954530172587724`, 1.01405837961428], 
           Complex[82.17443243593527, -19.768895336127002`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.299999999999997`, -5.950951182889128}],
       RowBox[{"{", 
         RowBox[{"29.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"39.271420263643506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8990197110726985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.57845567815663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.988924782863712`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"57.76562275755487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0473340731366323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.9541229298446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.299999999999997`, "A", 
        Association[1 -> {
           Complex[39.271420263643506`, -3.8990197110726985`], 
           Complex[60.57845567815663, -26.988924782863712`]}, 2 -> {
           Complex[57.76562275755487, 1.0473340731366323`], 
           Complex[81.9541229298446, -19.737366130066967`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.4, -5.94871557379185}],
       RowBox[{"{", 
         RowBox[{"29.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"39.478574066455195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.91899109663922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869384`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"57.57422423294728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.4, "A", 
        Association[1 -> {
           Complex[39.478574066455195`, -3.91899109663922], 
           Complex[60.823295005096384`, -26.989835984869384`]}, 2 -> {
           Complex[57.57422423294728, 1.0826509804077706`], 
           Complex[81.73063257333023, -19.70361719945588]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.5, -5.947333872549308}],
       RowBox[{"{", 
         RowBox[{"29.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"39.68824348743652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9413516409076177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234124`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"57.380229545210106`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1202009565970128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.5, "A", 
        Association[1 -> {
           Complex[39.68824348743652, -3.9413516409076177`], 
           Complex[61.071409568577636`, -26.993402216234124`]}, 2 -> {
           Complex[57.380229545210106`, 1.1202009565970128`], 
           Complex[81.50382199854218, -19.66742872877372]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.599999999999998`, -5.946754477109811}],
       RowBox[{"{", 
         RowBox[{"29.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"39.900534636598906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.966314268200562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"57.183533211415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1601992983922518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047497`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.599999999999998`, "A", 
        Association[1 -> {
           Complex[39.900534636598906`, -3.966314268200562], 
           Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
           Complex[57.183533211415, 1.1601992983922518`], 
           Complex[81.27354946300127, -19.628553141047497`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.699999999999996`, -5.946927458449443}],
       RowBox[{"{", 
         RowBox[{"29.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"40.11555239258457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9941186626524052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"56.98403097486453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2028880133377449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540675`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.699999999999996`, "A", 
        Association[1 -> {
           Complex[40.11555239258457, -3.9941186626524052`], 
           Complex[61.57803233510409, -27.009511166504147`]}, 2 -> {
           Complex[56.98403097486453, 1.2028880133377449`], 
           Complex[81.03967255327478, -19.586711092540675`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.799999999999997`, -5.947804515471551}],
       RowBox[{"{", 
         RowBox[{"29.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"40.33339811059796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.02264368536371`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"56.78162209715333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.248539514221569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.54158691366652`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.799999999999997`, "A", 
        Association[1 -> {
           Complex[40.33339811059796, -4.025034961302564], 
           Complex[61.836823766448205`, -27.02264368536371]}, 2 -> {
           Complex[56.78162209715333, 1.248539514221569], 
           Complex[80.80205060892806, -19.54158691366652]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.899999999999995`, -5.949338978844817}],
       RowBox[{"{", 
         RowBox[{"29.899999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"40.554166490864645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.059367882777878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"56.57621248970557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.297460749010085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653356`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.899999999999995`, "A", 
        Association[1 -> {
           Complex[40.554166490864645`, -4.059367882777878], 
           Complex[62.09945108280152, -27.039620531417192`]}, 2 -> {
           Complex[56.57621248970557, 1.297460749010085], 
           Complex[80.56054810632892, -19.492823467653356`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{29.999999999999996`, -5.951485894151492}],
       RowBox[{"{", 
         RowBox[{"29.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"40.77794134659001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.097461269474217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.060843538677656`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"56.3677189458158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3499977442410382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.3150393131322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485955`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.999999999999996`, "A", 
        Association[1 -> {
           Complex[40.77794134659001, -4.097461269474217], 
           Complex[62.36604010279412, -27.060843538677656`]}, 2 -> {
           Complex[56.3677189458158, 1.3499977442410382`], 
           Complex[80.3150393131322, -19.440016432485955`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.099999999999998`, -5.95420221749358}],
       RowBox[{"{", 
         RowBox[{"30.099999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"41.004789940578746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.139702965144389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239154`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"56.15607480403263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.4065404837842264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431345`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.099999999999998`, "A", 
        Association[1 -> {
           Complex[41.004789940578746`, -4.139702965144389], 
           Complex[62.63670053402378, -27.086768000239154`]}, 2 -> {
           Complex[56.15607480403263, 1.4065404837842264`], 
           Complex[80.06541461134336, -19.382708072431345`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.199999999999996`, -5.957447160720965}],
       RowBox[{"{", 
         RowBox[{"30.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"41.23475547996004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.911517481754075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"55.941237453438774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492593`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.199999999999996`, "A", 
        Association[1 -> {
           Complex[41.23475547996004, -4.186529858286214], 
           Complex[62.911517481754075`, -27.117909237707966`]}, 2 -> {
           Complex[55.941237453438774`, 1.4675279533647856`], 
           Complex[79.81158898845908, -19.320380667492593`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.299999999999997`, -5.961182727125078}],
       RowBox[{"{", 
         RowBox[{"30.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"41.46784727560741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.238432778015862`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.1548491808301`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"55.72319817424016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.5334530375357749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.299999999999997`, "A", 
        Association[1 -> {
           Complex[41.46784727560741, -4.238432778015862], 
           Complex[63.19054018060197, -27.1548491808301]}, 2 -> {
           Complex[55.72319817424016, 1.5334530375357749`], 
           Complex[79.55351330562608, -19.252449932700852`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.4, -5.965374479017715}],
       RowBox[{"{", 
         RowBox[{"30.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"41.704028002661694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.295960711667079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.473767240011654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.198242373560767`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"55.50199487725362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6048667383421007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.1782590109987`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.4, "A", 
        Association[1 -> {
           Complex[41.704028002661694`, -4.295960711667079], 
           Complex[63.473767240011654`, -27.198242373560767`]}, 2 -> {
           Complex[55.50199487725362, 1.6048667383421007`], 
           Complex[79.29118905201918, -19.1782590109987]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.5, -5.969992571267522}],
       RowBox[{"{", 
         RowBox[{"30.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"41.94319747255841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"55.27772833189304`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6823808689752453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.09707399537825`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.5, "A", 
        Association[1 -> {
           Complex[41.94319747255841, -4.3597234974146355`], 
           Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
           Complex[55.27772833189304, 1.6823808689752453`], 
           Complex[79.02468735041018, -19.09707399537825]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.599999999999998`, -5.975013061668264}],
       RowBox[{"{", 
         RowBox[{"30.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"42.185172401572416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.430391708841174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.307393608507066`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"55.05058239764025`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.7666679393393379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.599999999999998`, "A", 
        Association[1 -> {
           Complex[42.185172401572416`, -4.430391708841174], 
           Complex[64.05245675580908, -27.307393608507066`]}, 2 -> {
           Complex[55.05058239764025, 1.7666679393393379`], 
           Complex[78.75417292510039, -19.00808245833909]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.699999999999996`, -5.980419458037957}],
       RowBox[{"{", 
         RowBox[{"30.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"42.42966192828803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"54.8208485065926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.8584563892632036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.699999999999996`, "A", 
        Association[1 -> {
           Complex[42.42966192828803, -4.508691887180884], 
           Complex[64.34746700294596, -27.374846901442822`]}, 2 -> {
           Complex[54.8208485065926, 1.8584563892632036`], 
           Complex[78.47993347130917, -18.910397152078417`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.799999999999997`, -5.986204367625939}],
       RowBox[{"{", 
         RowBox[{"30.799999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"42.67623922739711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.452128400549633`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"54.588954049684325`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298525`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.799999999999997`, "A", 
        Association[1 -> {
           Complex[42.67623922739711, -4.595394633635153], 
           Complex[64.64571326583466, -27.452128400549633`]}, 2 -> {
           Complex[54.588954049684325`, 1.9585186817545792`], 
           Complex[78.20241421183864, -18.803067851298525`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.9, -5.992370961419108}],
       RowBox[{"{", 
         RowBox[{"30.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"42.92431065706729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.94655461858153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.540225454037717`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"54.35549322933975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0676491823619387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.92225618346788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665765`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.9, "A", 
        Association[1 -> {
           Complex[42.92431065706729, -4.691292487824447], 
           Complex[64.94655461858153, -27.540225454037717`]}, 2 -> {
           Complex[54.35549322933975, 2.0676491823619387`], 
           Complex[77.92225618346788, -18.685105090665765`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{30.999999999999993`, -5.998933750438886}],
       RowBox[{"{", 
         RowBox[{"30.999999999999993`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"43.17308560823099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.79716429050747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570582`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"54.121257210207155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.1866285227759508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729686`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.999999999999993`, "A", 
        Association[1 -> {
           Complex[43.17308560823099, -4.79716429050747], 
           Complex[65.24911579537869, -27.64012489570582]}, 2 -> {
           Complex[54.121257210207155`, 2.1866285227759508`], 
           Complex[77.64033476497889, -18.555519955729686`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.099999999999994`, -6.005917922932756}],
       RowBox[{"{", 
         RowBox[{"31.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"43.42155259011466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885613`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"53.88725803365406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.316171791849095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132924`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.099999999999994`, "A", 
        Association[1 -> {
           Complex[43.42155259011466, -4.913723373745142], 
           Complex[65.55225475967484, -27.752753616885613`]}, 2 -> {
           Complex[53.88725803365406, 2.316171791849095], 
           Complex[77.35779210787565, -18.413383510132924`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.199999999999996`, -6.013356304791173}],
       RowBox[{"{", 
         RowBox[{"31.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"43.6684696972538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87889831422985`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"53.654738150778094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.45686009591344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.0760538672227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.257907047001805`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.199999999999996`, "A", 
        Association[1 -> {
           Complex[43.6684696972538, -5.041549120388218], 
           Complex[65.85454597323113, -27.87889831422985]}, 2 -> {
           Complex[53.654738150778094`, 2.45686009591344], 
           Complex[77.0760538672227, -18.257907047001805`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.299999999999997`, -6.021283058370846}],
       RowBox[{"{", 
         RowBox[{"31.299999999999997`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"43.91237942227682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.019108187677965`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"53.42515560965041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.609059345791205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.299999999999997`, "A", 
        Association[1 -> {
           Complex[43.91237942227682, -5.181005750282827], 
           Complex[66.15429146185946, -28.019108187677965`]}, 2 -> {
           Complex[53.42515560965041, 2.609059345791205], 
           Complex[76.79681813580557, -18.08853939018387]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.4, -6.0297237482281725`}],
       RowBox[{"{", 
         RowBox[{"31.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"44.15165707542385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"53.20013563582517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.7728363828323297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453845`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.4, "A", 
        Association[1 -> {
           Complex[44.15165707542385, -5.332158445526291], 
           Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
           Complex[53.20013563582517, 2.7728363828323297`], 
           Complex[76.52200482138221, -17.905070014453845`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.499999999999996`, -6.038682488921336}],
       RowBox[{"{", 
         RowBox[{"31.499999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"44.38459701843839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4947034235184535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799614`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.98138439847741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.947889052723883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136962`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.499999999999996`, "A", 
        Association[1 -> {
           Complex[44.38459701843839, -5.4947034235184535`], 
           Complex[66.73834077690567, -28.342127551799614`]}, 2 -> {
           Complex[52.98138439847741, 2.947889052723883], 
           Complex[76.25365917077403, -17.707718667136962`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.599999999999998`, -6.048128321915701}],
       RowBox[{"{", 
         RowBox[{"31.599999999999998`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"44.60953106802053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363132`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.770570606980506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050529`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.599999999999998`, "A", 
        Association[1 -> {
           Complex[44.60953106802053, -5.667931881684722], 
           Complex[67.01856624754153, -28.52401138363132]}, 2 -> {
           Complex[52.770570606980506`, 3.1335101509494954`], 
           Complex[75.99381453813973, -17.49718747050529]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.7, -6.057984069176398}],
       RowBox[{"{", 
         RowBox[{"31.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"44.82496136566615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.8507441063245365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.569192641098226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395945`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.7, "A", 
        Association[1 -> {
           Complex[44.82496136566615, -5.8507441063245365`], 
           Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
           Complex[52.569192641098226`, 3.3286015323523053`], 
           Complex[75.74433404826091, -17.274654824395945`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.8, -6.0681208573364245`}],
       RowBox[{"{", 
         RowBox[{"31.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.02968138507134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.041718331746136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171126`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.37845754361273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.5317429709640207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935683`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.8, "A", 
        Association[1 -> {
           Complex[45.02968138507134, -6.041718331746136], 
           Complex[67.54625247327425, -28.92269792171126]}, 2 -> {
           Complex[52.37845754361273, 3.5317429709640207`], 
           Complex[75.5067619380703, -17.041703592935683`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.899999999999995`, -6.078360003387103}],
       RowBox[{"{", 
         RowBox[{"31.899999999999995`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.22285917797315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239223019815121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.13605301384424`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.199197774517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.7413044402273425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.800194921087922`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.899999999999995`, "A", 
        Association[1 -> {
           Complex[45.22285917797315, -6.239223019815121], 
           Complex[67.79105133862647, -29.13605301384424]}, 2 -> {
           Complex[52.199197774517, 3.7413044402273425`], 
           Complex[75.28221611377315, -16.800194921087922`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{31.999999999999996`, -6.08848167572687}],
       RowBox[{"{", 
         RowBox[{"31.999999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.404067563685665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663413`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"52.03184102151237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.9555778719707466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.55211478637477`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.999999999999996`, "A", 
        Association[1 -> {
           Complex[45.404067563685665`, -6.441548618274501], 
           Complex[68.02213623225067, -29.356140607663413`]}, 2 -> {
           Complex[52.03184102151237, 3.9555778719707466`], 
           Complex[75.07134191761345, -16.55211478637477]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.099999999999994`, -6.098237938864388}],
       RowBox[{"{", 
         RowBox[{"32.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.57326174765701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.64703167968071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.580996761146004`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.87643258148602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.172901275980756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573057`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.099999999999994`, "A", 
        Association[1 -> {
           Complex[45.57326174765701, -6.64703167968071], 
           Complex[68.23931794822644, -29.580996761146004`]}, 2 -> {
           Complex[51.87643258148602, 4.172901275980756], 
           Complex[74.87432868509478, -16.299425400573057`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.199999999999996`, -6.206416363551537}],
       RowBox[{"{", 
         RowBox[{"32.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.730718127418484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905298`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.73269655459702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.391754775223062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.04394673660354`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.199999999999996`, "A", 
        Association[1 -> {
           Complex[45.730718127418484`, -6.854150896006849], 
           Complex[68.44279858874026, -29.808799798905298`]}, 2 -> {
           Complex[51.73269655459702, 4.391754775223062], 
           Complex[74.69097444463986, -16.04394673660354]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.3, -6.221008621690028}],
       RowBox[{"{", 
         RowBox[{"32.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"45.87695378596401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.037946713787587`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.600116350932254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334567`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.3, "A", 
        Association[1 -> {
           Complex[45.87695378596401, -7.061586259363513], 
           Complex[68.63308108602179, -30.037946713787587`]}, 2 -> {
           Complex[51.600116350932254`, 4.610819767164111], 
           Complex[74.52077639558696, -15.787280126334567`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.4, -6.236280487019719}],
       RowBox[{"{", 
         RowBox[{"32.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.012644400278134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852067`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.478016782014386`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.829003095065925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.3630260491026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018974`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.4, "A", 
        Association[1 -> {
           Complex[46.012644400278134`, -7.268243232709627], 
           Complex[68.81087406136677, -30.267088315852067`]}, 2 -> {
           Complex[51.478016782014386`, 4.829003095065925], 
           Complex[74.3630260491026, -15.530773111018974`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.49999999999999, -6.252123949662032}],
       RowBox[{"{", 
         RowBox[{"32.49999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.1385523728934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.473250095934392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818545`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.36563592928112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.045434394635397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.21689441876435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279347`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.49999999999999, "A", 
        Association[1 -> {
           Complex[46.1385523728934, -7.473250095934392], 
           Complex[68.97700663449255, -30.495131845818545`]}, 2 -> {
           Complex[51.36563592928112, 5.045434394635397], 
           Complex[74.21689441876435, -15.275516827279347`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.599999999999994`, -6.268444071035216}],
       RowBox[{"{", 
         RowBox[{"32.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.25547057364814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.67593833538152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.72122229359378`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.26218140236398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.259446484100554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.08150010532468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029509`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.599999999999994`, "A", 
        Association[1 -> {
           Complex[46.25547057364814, -7.67593833538152], 
           Complex[69.13236033871479, -30.72122229359378]}, 2 -> {
           Complex[51.26218140236398, 5.259446484100554], 
           Complex[74.08150010532468, -15.022364688029509`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.699999999999996`, -6.285158844495673}],
       RowBox[{"{", 
         RowBox[{"32.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.36418227688922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.875814674529089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.94471254171957`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.166870401922736`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489209`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.699999999999996`, "A", 
        Association[1 -> {
           Complex[46.36418227688922, -7.875814674529089], 
           Complex[69.27781951812032, -30.94471254171957]}, 2 -> {
           Complex[51.166870401922736`, 5.470547395427036], 
           Complex[73.95595889948115, -14.771962238489209`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.8, -6.302197987989391}],
       RowBox[{"{", 
         RowBox[{"32.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.465435189789666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737157`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"51.07895569136514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.678390200428087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.8394169010038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662301`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.8, "A", 
        Association[1 -> {
           Complex[46.465435189789666`, -8.07253089957758], 
           Complex[69.41423820838506, -31.16512977737157]}, 2 -> {
           Complex[51.07895569136514, 5.678390200428087], 
           Complex[73.8394169010038, -14.524780743662301`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{32.9, -6.319501271034918}],
       RowBox[{"{", 
         RowBox[{"32.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.55992646557226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.265855214912738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.99774058366105`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.882744366735128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.281149844042137`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.9, "A", 
        Association[1 -> {
           Complex[46.55992646557226, -8.265855214912738], 
           Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
           Complex[50.99774058366105, 5.882744366735128], 
           Complex[73.73107052942778, -14.281149844042137`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33., -6.337016755757702}],
       RowBox[{"{", 
         RowBox[{"33.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.64829561564561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.455646996018187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.59553293132246`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.92258602924393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.083470511204362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.6301769260447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846566`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33., "A", 
        Association[1 -> {
           Complex[46.64829561564561, -8.455646996018187], 
           Complex[69.66310826637462, -31.59553293132246]}, 2 -> {
           Complex[50.92258602924393, 6.083470511204362], 
           Complex[73.6301769260447, -14.041286825846566`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.099999999999994`, -6.354699159595178}],
       RowBox[{"{", 
         RowBox[{"33.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.73112272554318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.641835576592952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.80516872809565`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.85291240010994`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.280499187514896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316236`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.099999999999994`, "A", 
        Association[1 -> {
           Complex[46.73112272554318, -8.641835576592952], 
           Complex[69.77698109299793, -31.80516872809565]}, 2 -> {
           Complex[50.85291240010994, 6.280499187514896], 
           Complex[73.53605776440253, -13.805321546316236`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.199999999999996`, -6.37250843265049}],
       RowBox[{"{", 
         RowBox[{"33.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.80892999564075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.82440299828263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.010985835765666`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.788197949138606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.4480988144794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041144`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.199999999999996`, "A", 
        Association[1 -> {
           Complex[46.80892999564075, -8.82440299828263], 
           Complex[69.88465297350923, -32.010985835765666`]}, 2 -> {
           Complex[50.788197949138606`, 6.473813636367646], 
           Complex[73.4480988144794, -13.573316941041144`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.3, -6.3904085746978}],
       RowBox[{"{", 
         RowBox[{"33.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.882185196050116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.72797535523715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.6634360796057495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813705`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.3, "A", 
        Association[1 -> {
           Complex[46.882185196050116`, -9.003370304344577], 
           Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
           Complex[50.72797535523715, 6.6634360796057495`], 
           Complex[73.36574696131454, -13.345285495813705`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.39999999999999, -6.408366681073635}],
       RowBox[{"{", 
         RowBox[{"33.39999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"46.951306082313856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568788`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.671827307684104`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250492988`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.39999999999999, "A", 
        Association[1 -> {
           Complex[46.951306082313856`, -9.178786832849886], 
           Complex[70.08355015001808, -32.41114577568788]}, 2 -> {
           Complex[50.671827307684104`, 6.849417013859745], 
           Complex[73.2885058483752, -13.121202250492988`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.49999999999999, -6.426352190849823}],
       RowBox[{"{", 
         RowBox[{"33.49999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.016665157888184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.350721960698461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.1757166401882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.60556303669796`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.61938174368467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.031826954994077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479544`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.49999999999999, "A", 
        Association[1 -> {
           Complex[47.016665157888184`, -9.350721960698461], 
           Complex[70.1757166401882, -32.60556303669796]}, 2 -> {
           Complex[50.61938174368467, 7.031826954994077], 
           Complex[73.21593091512594, -12.901014934479544`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.599999999999994`, -6.444336306080401}],
       RowBox[{"{", 
         RowBox[{"33.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.078594407914174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.79629250746041`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.570307114637814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.1476243120753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041993`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.599999999999994`, "A", 
        Association[1 -> {
           Complex[47.078594407914174`, -9.519258803308224], 
           Complex[70.26357461989492, -32.79629250746041]}, 2 -> {
           Complex[50.570307114637814`, 7.210750138216329], 
           Complex[73.1476243120753, -12.684651789041993`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.699999999999996`, -6.462291552023001}],
       RowBox[{"{", 
         RowBox[{"33.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.13738978959499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.68448944959141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.983418096522826`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.52430789579726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.386279753462804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181573`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.699999999999996`, "A", 
        Association[1 -> {
           Complex[47.13738978959499, -9.68448944959141], 
           Complex[70.34748028709403, -32.983418096522826`]}, 2 -> {
           Complex[50.52430789579726, 7.386279753462804], 
           Complex[73.08322998054211, -12.472027556181573`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.8, -6.480191451815838}],
       RowBox[{"{", 
         RowBox[{"33.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.19331536912255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.846511388382378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.1670326786391`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.48112044938315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.558514372224588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.26304803157383`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.8, "A", 
        Association[1 -> {
           Complex[47.19331536912255, -9.846511388382378], 
           Complex[70.42775264717702, -33.1670326786391]}, 2 -> {
           Complex[50.48112044938315, 7.558514372224588], 
           Complex[73.02242905463167, -12.26304803157383]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{33.9, -6.498010293386255}],
       RowBox[{"{", 
         RowBox[{"33.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.24660706078816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.00542485182525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771441998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654395`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.44050928550963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.727555291323419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401406`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.9, "A", 
        Association[1 -> {
           Complex[47.24660706078816, -10.00542485182525], 
           Complex[70.50467771441998, -33.34723465654395]}, 2 -> {
           Complex[50.44050928550963, 7.727555291323419], 
           Complex[72.96493565975211, -12.057613502401406`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34., -6.5157229705026145`}],
       RowBox[{"{", 
         RowBox[{"34.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.29747596348612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.161330860116289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.524125383471365`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.402263725719145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452313`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34., "A", 
        Association[1 -> {
           Complex[47.29747596348612, -10.161330860116289`], 
           Complex[70.57851229402165, -33.524125383471365`]}, 2 -> {
           Complex[50.402263725719145`, 7.89350457803234], 
           Complex[72.9104931305427, -11.855621324452313`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.1, -6.533304883485762}],
       RowBox[{"{", 
         RowBox[{"34.1`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.34611131233811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.69780724710277`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.36619495139631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.056463649045714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798806`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.1, "A", 
        Association[1 -> {
           Complex[47.34611131233811, -10.314329800105746`], 
           Complex[70.64948735230315, -33.69780724710277]}, 2 -> {
           Complex[50.36619495139631, 8.056463649045714], 
           Complex[72.85887064064234, -11.656967837798806`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.2, -6.550731888060824}],
       RowBox[{"{", 
         RowBox[{"34.2`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.39268307483162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.464520408616714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.86838226002102`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.3321334076672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.2165322541574`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.8098602198848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597864`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.2, "A", 
        Association[1 -> {
           Complex[47.39268307483162, -10.464520408616714`], 
           Complex[70.71781099948186, -33.86838226002102]}, 2 -> {
           Complex[50.3321334076672, 8.2165322541574], 
           Complex[72.8098602198848, -11.46154977597864]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.3, -6.567980283174104}],
       RowBox[{"{", 
         RowBox[{"34.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.4373442258159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.611999061422935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.03595103690155`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.29992652844131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.373807765588333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.269265288448755`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.3, "A", 
        Association[1 -> {
           Complex[47.4373442258159, -10.611999061422935`], 
           Complex[70.78367111767889, -34.03595103690155]}, 2 -> {
           Complex[50.29992652844131, 8.373807765588333], 
           Complex[72.76327412626179, -11.269265288448755`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.39999999999999, -6.5850268303988955`}],
       RowBox[{"{", 
         RowBox[{"34.39999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.48023273663557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.75685929217107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.84723766978762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.20061206617882`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.26943674731541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.52838469724979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572227`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.39999999999999, "A", 
        Association[1 -> {
           Complex[47.48023273663557, -10.75685929217107], 
           Complex[70.84723766978762, -34.20061206617882]}, 2 -> {
           Complex[50.26943674731541, 8.52838469724979], 
           Complex[72.71894253702615, -11.080014668572227`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.49999999999999, -6.60184879889878}],
       RowBox[{"{", 
         RowBox[{"34.49999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.52147331234387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.89919148351823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.90866472468208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.24053976039788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.680354396213662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042976`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.49999999999999, "A", 
        Association[1 -> {
           Complex[47.52147331234387, -10.89919148351823], 
           Complex[70.90866472468208, -34.36246120528307]}, 2 -> {
           Complex[50.24053976039788, 8.680354396213662], 
           Complex[72.67671152345633, -10.893700858042976`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.599999999999994`, -6.618424030897524}],
       RowBox[{"{", 
         RowBox[{"34.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.561178908409175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503682`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.21312300963941`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.829804862450947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159116`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.599999999999994`, "A", 
        Association[1 -> {
           Complex[47.561178908409175`, -11.039082686546374`], 
           Complex[70.96809223235843, -34.52159134503682]}, 2 -> {
           Complex[50.21312300963941, 8.829804862450947], 
           Complex[72.6364412756889, -10.710229782159116`]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.699999999999996`, -6.634731023302237}],
       RowBox[{"{", 
         RowBox[{"34.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.59945205528385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.17661653505851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149987`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.1870843583013`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.9768206634439`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655934`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.699999999999996`, "A", 
        Association[1 -> {
           Complex[47.59945205528385, -11.17661653505851], 
           Complex[71.02564757984514, -34.67809220149987]}, 2 -> {
           Complex[50.1870843583013, 8.9768206634439], 
           Complex[72.59800454678344, -10.529510557655934`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.8, -6.650749021610071}],
       RowBox[{"{", 
         RowBox[{"34.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.636386016039125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330796`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.16233093335741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.121482918322886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052497`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.8, "A", 
        Association[1 -> {
           Complex[47.636386016039125`, -11.311873229407055`], 
           Complex[71.08144695562096, -34.83205020330796]}, 2 -> {
           Complex[50.16233093335741, 9.121482918322886], 
           Complex[72.56128528828063, -10.351455605052497`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{34.9, -6.666458122558316}],
       RowBox[{"{", 
         RowBox[{"34.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.672065799209136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.983548450042505`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.138778112686914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.26386933231359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.175980689974885`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.9, "A", 
        Association[1 -> {
           Complex[47.672065799209136`, -11.444929570640568`], 
           Complex[71.13559654715354, -34.983548450042505`]}, 2 -> {
           Complex[50.138778112686914`, 9.26386933231359], 
           Complex[72.52617745264078, -10.175980689974885`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35., -6.6818393822019155`}],
       RowBox[{"{", 
         RowBox[{"35.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.70656904615111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.575859030428859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.13266672291677`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.116348637750534`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.40405426695551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.003004912170228`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35., "A", 
        Association[1 -> {
           Complex[47.70656904615111, -11.575859030428859`], 
           Complex[71.18819359319453, -35.13266672291677]}, 2 -> {
           Complex[50.116348637750534`, 9.40405426695551], 
           Complex[72.49258394092674, -10.003004912170228`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.1, -6.696874926262897}],
       RowBox[{"{", 
         RowBox[{"35.1`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.73996680966804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.704731845790777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.27948153347702`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.09497183500416`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.542108835115947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512503`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.1, "A", 
        Association[1 -> {
           Complex[47.73996680966804, -11.704731845790777`], 
           Complex[71.23932730972692, -35.27948153347702]}, 2 -> {
           Complex[50.09497183500416, 9.542108835115947], 
           Complex[72.46041567683548, -9.832450656512503]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.199999999999996`, -6.7115480597263115`}],
       RowBox[{"{", 
         RowBox[{"35.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.77232423836924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.831615130363643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.4240661994061`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.07458293157423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.678101012538281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913515`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.199999999999996`, "A", 
        Association[1 -> {
           Complex[47.77232423836924, -11.831615130363643`], 
           Complex[71.28907970599505, -35.4240661994061]}, 2 -> {
           Complex[50.07458293157423, 9.678101012538281], 
           Complex[72.42959079064792, -9.664243516913515]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.3, -6.725843372785029}],
       RowBox[{"{", 
         RowBox[{"35.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.80370117925396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.956572996022805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.56649093911878`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.05512245271003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40003389885213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447764`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.3, "A", 
        Association[1 -> {
           Complex[47.80370117925396, -11.956572996022805`], 
           Complex[71.33752630486225, -35.56649093911878]}, 2 -> {
           Complex[50.05512245271003, 9.812095759734234], 
           Complex[72.40003389885213, -9.498312201447764]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.4, -6.73974684038215}],
       RowBox[{"{", 
         RowBox[{"35.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.834152709273475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.706822978841465`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.036535690257004`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.944155149605944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.33458842500021`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.4, "A", 
        Association[1 -> {
           Complex[47.834152709273475`, -12.079666680238098`], 
           Complex[71.38473677982421, -35.706822978841465`]}, 2 -> {
           Complex[50.036535690257004`, 9.944155149605944], 
           Complex[72.37167546711125, -9.33458842500021]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.49999999999999, -6.753245912781218}],
       RowBox[{"{", 
         RowBox[{"35.49999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.86372960513274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.20095467575531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.845126667405935`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.01877223289047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.074338497386961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205872`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.49999999999999, "A", 
        Association[1 -> {
           Complex[47.86372960513274, -12.20095467575531], 
           Complex[71.43077551933807, -35.845126667405935`]}, 2 -> {
           Complex[50.01877223289047, 10.074338497386961`], 
           Complex[72.34445124591687, -9.173006794205872]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.599999999999994`, -6.766329594821164}],
       RowBox[{"{", 
         RowBox[{"35.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.892478759305945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"50.00178555013501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.202702490405663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267268`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.599999999999994`, "A", 
        Association[1 -> {
           Complex[47.892478759305945`, -12.320492860106404`], 
           Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
           Complex[50.00178555013501, 10.202702490405663`], 
           Complex[72.31830176971437, -9.013504688267268]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.699999999999996`, -6.778988511790082}],
       RowBox[{"{", 
         RowBox[{"35.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.92044354913625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.438334623148688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.5195718702971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.98553262329957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.329301315871618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29317191153511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.85602213832465`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.699999999999996`, "A", 
        Association[1 -> {
           Complex[47.92044354913625, -12.438334623148688`], 
           Complex[71.5195718702971, -36.11589271440042]}, 2 -> {
           Complex[49.98553262329957, 10.329301315871618`], 
           Complex[72.29317191153511, -8.85602213832465]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.8, -6.791214960179992}],
       RowBox[{"{", 
         RowBox[{"35.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.947664164943085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.554530991361462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.969973617404506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.45418678541366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354443`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.8, "A", 
        Association[1 -> {
           Complex[47.947664164943085`, -12.554530991361462`], 
           Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
           Complex[49.969973617404506`, 10.45418678541366], 
           Complex[72.26901048624575, -8.700501707354443]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.9, -6.803002941958665}],
       RowBox[{"{", 
         RowBox[{"35.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"47.97417790224991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.66913074802967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.6043424637563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.37925086296772`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.955071588988176`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.577408455499175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033514`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.9, "A", 
        Association[1 -> {
           Complex[47.97417790224991, -12.66913074802967], 
           Complex[71.6043424637563, -36.37925086296772]}, 2 -> {
           Complex[49.955071588988176`, 10.577408455499175`], 
           Complex[72.24576989645067, -8.546888372033514]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{35.99999999999999, -6.814348181406265}],
       RowBox[{"{", 
         RowBox[{"35.99999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.00001942255101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50828567419364`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.94079222537401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.699013743166008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594679`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.99999999999999, "A", 
        Association[1 -> {
           Complex[48.00001942255101, -12.782180548745712`], 
           Complex[71.64533551387005, -36.50828567419364]}, 2 -> {
           Complex[49.94079222537401, 10.699013743166008`], 
           Complex[72.22340581587778, -8.395129407594679]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.099999999999994`, -6.82524812400145}],
       RowBox[{"{", 
         RowBox[{"36.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.02522098644102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.893725031887865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.635624466775916`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.92710361157446`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.8190480367257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383164`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.099999999999994`, "A", 
        Association[1 -> {
           Complex[48.02522098644102, -12.893725031887865`], 
           Complex[71.68545669700364, -36.635624466775916`]}, 2 -> {
           Complex[49.92710361157446, 10.8190480367257], 
           Complex[72.20187690576324, -8.245174276383164]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.199999999999996`, -6.835701917289622}],
       RowBox[{"{", 
         RowBox[{"36.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.04981266242253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.00380692390271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.76131474751435`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.9139760215171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.93755480126541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.096974520583906`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.199999999999996`, "A", 
        Association[1 -> {
           Complex[48.04981266242253, -13.00380692390271], 
           Complex[71.72474475596931, -36.76131474751435]}, 2 -> {
           Complex[49.9139760215171, 10.93755480126541], 
           Complex[72.18114456033722, -8.096974520583906]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.3, -6.845710374109179}],
       RowBox[{"{", 
         RowBox[{"36.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.073822514268066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.112467139344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.88540205861425`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.901381730715414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.950483659405908`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.3, "A", 
        Association[1 -> {
           Complex[48.073822514268066`, -13.112467139344405`], 
           Complex[71.76323592906267, -36.88540205861425]}, 2 -> {
           Complex[49.901381730715414`, 11.054575678901632`], 
           Complex[72.16117267801965, -7.950483659405908]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.4, -6.855275918973909}],
       RowBox[{"{", 
         RowBox[{"36.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.097276769439844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.88929484788194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.170150583829274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.805657090873341`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.4, "A", 
        Association[1 -> {
           Complex[48.097276769439844`, -13.219744875714255`], 
           Complex[71.80096415610163, -37.00793007567815]}, 2 -> {
           Complex[49.88929484788194, 11.170150583829274`], 
           Complex[72.1419274553698, -7.805657090873341]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.5, -6.864402518795833}],
       RowBox[{"{", 
         RowBox[{"36.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.12019997074639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.12894070104982`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.8776911633041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.28431779227576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269178`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.5, "A", 
        Association[1 -> {
           Complex[48.12019997074639, -13.325677703210104`], 
           Complex[71.83796126429178, -37.12894070104982]}, 2 -> {
           Complex[49.8776911633041, 11.28431779227576], 
           Complex[72.1233772012094, -7.662451998269178]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.6, -6.873095599469501}],
       RowBox[{"{", 
         RowBox[{"36.6`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.142615113138476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.430301649540363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.248474152540204`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.86654801208047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.397114027514972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201417`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.6, "A", 
        Association[1 -> {
           Complex[48.142615113138476`, -13.430301649540363`], 
           Complex[71.8742571361754, -37.248474152540204`]}, 2 -> {
           Complex[49.86654801208047, 11.397114027514972`], 
           Complex[72.10549216866305, -7.520827261201417]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.699999999999996`, -6.881361950115142}],
       RowBox[{"{", 
         RowBox[{"36.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.16454376730663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.533651279988442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.366569047621205`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.85584415055513`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.508574540127224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.38074337120608`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.699999999999996`, "A", 
        Association[1 -> {
           Complex[48.16454376730663, -13.533651279988442`], 
           Complex[71.90987986163972, -37.366569047621205`]}, 2 -> {
           Complex[49.85584415055513, 11.508574540127224`], 
           Complex[72.08824440313957, -7.38074337120608]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.79999999999999, -6.889209616986735}],
       RowBox[{"{", 
         RowBox[{"36.79999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.186006191536734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.63575977293281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94485587571889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.84555964449377`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0716076045205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762072`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.79999999999999, "A", 
        Association[1 -> {
           Complex[48.186006191536734`, -13.63575977293281], 
           Complex[71.94485587571889, -37.483262483211874`]}, 2 -> {
           Complex[49.84555964449377, 11.618733183710322`], 
           Complex[72.0716076045205, -7.242162351762072]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.89999999999999, -6.8966477891879086`}],
       RowBox[{"{", 
         RowBox[{"36.89999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.20702143310045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.736658991038883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120972`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.83567576772439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565447`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.89999999999999, "A", 
        Association[1 -> {
           Complex[48.20702143310045, -13.736658991038883`], 
           Complex[71.97921008371291, -37.59859011120972]}, 2 -> {
           Complex[49.83567576772439, 11.727622486258118`], 
           Complex[72.05555700203159, -7.105047682565447]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{36.99999999999999, -6.903686678403236}],
       RowBox[{"{", 
         RowBox[{"36.99999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.22760742030328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.836379548343533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936944`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.82617491012043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892692`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.99999999999999, "A", 
        Association[1 -> {
           Complex[48.22760742030328, -13.836379548343533`], 
           Complex[72.01296597496555, -37.712586209936944`]}, 2 -> {
           Complex[49.82617491012043, 11.835273717427539`], 
           Complex[72.04006924045628, -6.969364227892692]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.099999999999994`, -6.910337394847749}],
       RowBox[{"{", 
         RowBox[{"37.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.24778104617793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.934950873453174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.81704049393779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.835078168871881`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.099999999999994`, "A", 
        Association[1 -> {
           Complex[48.24778104617793, -13.934950873453174`], 
           Complex[72.04614572648373, -37.82528375168293]}, 2 -> {
           Complex[49.81704049393779, 11.941716951915161`], 
           Complex[72.02512227650753, -6.835078168871881]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.199999999999996`, -6.916611821569266}],
       RowBox[{"{", 
         RowBox[{"37.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.2675582446947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.032401269072565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07877029744378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.93671446652881`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.80825689763537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.046981129160331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475872`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.199999999999996`, "A", 
        Association[1 -> {
           Complex[48.2675582446947, -14.032401269072565`], 
           Complex[72.07877029744378, -37.93671446652881]}, 2 -> {
           Complex[49.80825689763537, 12.046981129160331`], 
           Complex[72.01069528431421, -6.702156939475872]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.3, -6.922522489114502}],
       RowBox[{"{", 
         RowBox[{"37.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.28695406025804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.12875796807638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1108595155086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.04690890264222`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.79980938640803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.151094109587378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048992`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.3, "A", 
        Association[1 -> {
           Complex[48.28695406025804, -14.12875796807638], 
           Complex[72.1108595155086, -38.04690890264222]}, 2 -> {
           Complex[49.79980938640803, 12.151094109587378`], 
           Complex[71.99676856909558, -6.570569166048992]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.4, -6.928082452400581}],
       RowBox[{"{", 
         RowBox[{"37.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.305982711170586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.155896483227494`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.791684048752806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.983323488207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181978`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.4, "A", 
        Association[1 -> {
           Complex[48.305982711170586`, -14.22404718632718], 
           Complex[72.14243215577531, -38.155896483227494`]}, 2 -> {
           Complex[49.791684048752806`, 12.254082727590417`], 
           Complex[71.983323488207, -6.440284610181978]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.5, -6.933305171429416}],
       RowBox[{"{", 
         RowBox[{"37.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.32465764766804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.31829417243562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313795`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.783867738463265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.35597284145664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.31127411475293`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.5, "A", 
        Association[1 -> {
           Complex[48.32465764766804, -14.31829417243562], 
           Complex[72.17350601308073, -38.263705560313795`]}, 2 -> {
           Complex[49.783867738463265`, 12.35597284145664], 
           Complex[71.97034237882725, -6.31127411475293]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.6, -6.938204397254162}],
       RowBox[{"{", 
         RowBox[{"37.6`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.342991605060675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.411523254649312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555746`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.776348021517336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957572`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.6, "A", 
        Association[1 -> {
           Complex[48.342991605060675`, -14.411523254649312`], 
           Complex[72.20409796831112, -38.37036346555746]}, 2 -> {
           Complex[49.776348021517336`, 12.456789380414614`], 
           Complex[71.95780849164257, -6.183509552957572]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.7, -6.942794064365441}],
       RowBox[{"{", 
         RowBox[{"37.7`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.360996652457885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.503757885046658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.769113127381615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.556556388984413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158599`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.7, "A", 
        Association[1 -> {
           Complex[48.360996652457885`, -14.503757885046658`], 
           Complex[72.23422404929191, -38.47589655822829]}, 2 -> {
           Complex[49.769113127381615`, 12.556556388984413`], 
           Complex[71.94570592995045, -6.056963780158599]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.8, -6.947088190419944}],
       RowBox[{"{", 
         RowBox[{"37.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.37868423749987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.595020681203493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054337`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.76215190430832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.655297068796713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9340195936706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391596`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.8, "A", 
        Association[1 -> {
           Complex[48.37868423749987, -14.595020681203493`], 
           Complex[72.2638994867713, -38.58033027054337]}, 2 -> {
           Complex[49.76215190430832, 12.655297068796713`], 
           Complex[71.9340195936706, -5.931610588391596]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.89999999999999, -6.951100783993854}],
       RowBox[{"{", 
         RowBox[{"37.89999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.39606522747497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.685333465489398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.75545377824624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.753033818038535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371904`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.89999999999999, "A", 
        Association[1 -> {
           Complex[48.39606522747497, -14.685333465489398`], 
           Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
           Complex[49.75545377824624, 12.753033818038535`], 
           Complex[71.92273512780362, -5.807424663371904]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{37.99999999999999, -6.954845760815678}],
       RowBox[{"{", 
         RowBox[{"37.99999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.41314994716061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.77471730214245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.785996902375146`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.74900871502786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.849788268674175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.91183887492751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854791`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.99999999999999, "A", 
        Association[1 -> {
           Complex[48.41314994716061, -14.77471730214245], 
           Complex[72.32195567400862, -38.785996902375146`]}, 2 -> {
           Complex[49.74900871502786, 12.849788268674175`], 
           Complex[71.91183887492751, -5.684381543854791]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.099999999999994`, -6.958336868722721}],
       RowBox[{"{", 
         RowBox[{"38.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.42994821369015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.86319253226119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.8872764249728`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.7428071855302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.945581321580041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209822`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.099999999999994`, "A", 
        Association[1 -> {
           Complex[48.42994821369015, -14.86319253226119], 
           Complex[72.35036334387817, -38.8872764249728]}, 2 -> {
           Complex[49.7428071855302, 12.945581321580041`], 
           Complex[71.90131783136438, -5.562457583209822]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.199999999999996`, -6.961587621397066}],
       RowBox[{"{", 
         RowBox[{"38.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.446469368716585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.950778806844472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.73684013353857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.040433179724607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.199999999999996`, "A", 
        Association[1 -> {
           Complex[48.446469368716585`, -14.950778806844472`], 
           Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
           Complex[49.73684013353857, 13.040433179724607`], 
           Complex[71.89115960668768, -5.441629913076676]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.3, -6.964611240772543}],
       RowBox[{"{", 
         RowBox[{"38.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.46272230811621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.037495118001443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.08683856553305`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.73109894607003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.134363379515118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978639`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.3, "A", 
        Association[1 -> {
           Complex[48.46272230811621, -15.037495118001443`], 
           Complex[72.40600046967194, -39.08683856553305]}, 2 -> {
           Complex[49.73109894607003, 13.134363379515118`], 
           Complex[71.88135238627332, -5.321876408978639]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.4, -6.96742060786553}],
       RowBox[{"{", 
         RowBox[{"38.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.47871550945055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.123359828445732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.72557542593836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.227390820426002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776082`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.4, "A", 
        Association[1 -> {
           Complex[48.47871550945055, -15.123359828445732`], 
           Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
           Complex[49.72557542593836, 13.227390820426002`], 
           Complex[71.8718848966287, -5.203175657776082]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.5, -6.970028221669094}],
       RowBox[{"{", 
         RowBox[{"38.5`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.494457057382995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.20839069938103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107672`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.72026176636399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.31953379301555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.08550692685011`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.5, "A", 
        Association[1 -> {
           Complex[48.494457057382995`, -15.20839069938103], 
           Complex[72.46014358718853, -39.28254398107672]}, 2 -> {
           Complex[49.72026176636399, 13.31953379301555], 
           Complex[71.86274637325921, -5.08550692685011]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.599999999999994`, -6.972446165661469}],
       RowBox[{"{", 
         RowBox[{"38.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.50995466722706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.292604916877659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.7151505274519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.410810005430928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912987`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.599999999999994`, "A", 
        Association[1 -> {
           Complex[48.50995466722706, -15.292604916877659`], 
           Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
           Complex[49.7151505274519, 13.410810005430928`], 
           Complex[71.85392653085567, -4.968850134912987]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.699999999999996`, -6.974686081414382}],
       RowBox[{"{", 
         RowBox[{"38.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.52521570678645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.376019116833605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651175`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.710234614377775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347898`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.699999999999996`, "A", 
        Association[1 -> {
           Complex[48.52521570678645, -15.376019116833605`], 
           Complex[72.51287796992378, -39.47455031651175]}, 2 -> {
           Complex[49.710234614377775`, 13.501236608494983`], 
           Complex[71.84541553560709, -4.853185824347898]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.8, -6.9767591487422695`}],
       RowBox[{"{", 
         RowBox[{"38.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.54024721663022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.70550725713841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.590830219461864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7384951349874775`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.8, "A", 
        Association[1 -> {
           Complex[48.54024721663022, -15.458649408607112`], 
           Complex[72.53874152941212, -39.56921287503744]}, 2 -> {
           Complex[49.70550725713841, 13.590830219461864`], 
           Complex[71.83720397946203, -4.7384951349874775`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.9, -6.978676071807614}],
       RowBox[{"{", 
         RowBox[{"38.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.55505592893432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.540511397402028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954416`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.70096199173561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.679606944523012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245359`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.9, "A", 
        Association[1 -> {
           Complex[48.55505592893432, -15.540511397402028`], 
           Complex[72.56428164388791, -39.66300535954416]}, 2 -> {
           Complex[49.70096199173561, 13.679606944523012`], 
           Complex[71.82928285617803, -4.624759779245359]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{38.99999999999999, -6.980447070587838}],
       RowBox[{"{", 
         RowBox[{"38.99999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.56964828500726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.621620205482065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.75594483692522`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.69659264267576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.767582400139355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8216435390141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.511962018521162`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.99999999999999, "A", 
        Association[1 -> {
           Complex[48.56964828500726, -15.621620205482065`], 
           Complex[72.58950706494943, -39.75594483692522]}, 2 -> {
           Complex[49.69659264267576, 13.767582400139355`], 
           Complex[71.8216435390141, -4.511962018521162]}]}, "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.099999999999994`, -6.982081877112903}],
       RowBox[{"{", 
         RowBox[{"39.099999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.5840304516069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.701990492284674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.848047855290424`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.69239330667786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.854771733270828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.81427775993448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803735`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.099999999999994`, "A", 
        Association[1 -> {
           Complex[48.5840304516069, -15.701990492284674`], 
           Complex[72.61442618498417, -39.848047855290424`]}, 2 -> {
           Complex[49.69239330667786, 13.854771733270828`], 
           Complex[71.81427775993448, -4.400084640803735]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.199999999999996`, -6.983589735897486}],
       RowBox[{"{", 
         RowBox[{"39.199999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.59820833614577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.939330465113585`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.68835833749281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.941189640569323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402672`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.199999999999996`, "A", 
        Association[1 -> {
           Complex[48.59820833614577, -15.781636473500773`], 
           Complex[72.63904705657157, -39.939330465113585`]}, 2 -> {
           Complex[49.68835833749281, 13.941189640569323`], 
           Complex[71.80717759020362, -4.289110939402672]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.3, -6.984979408014899}],
       RowBox[{"{", 
         RowBox[{"39.3`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.612187600873085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.860571939182236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.029808239319934`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.68448233174574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.026850386597047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742367`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.3, "A", 
        Association[1 -> {
           Complex[48.612187600873085`, -15.860571939182236`], 
           Complex[72.66337741060343, -40.029808239319934`]}, 2 -> {
           Complex[49.68448233174574, 14.026850386597047`], 
           Complex[71.80033542226364, -4.179024692742367]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.4, -6.986259178289824}],
       RowBox[{"{", 
         RowBox[{"39.4`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.625973676114015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.938810270934708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.680760115720915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.111767821127955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.069810145157128`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.4, "A", 
        Association[1 -> {
           Complex[48.625973676114015`, -15.938810270934708`], 
           Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
           Complex[49.680760115720915`, 14.111767821127955`], 
           Complex[71.79374395279486, -4.069810145157128]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.49999999999999, -6.987436865121347}],
       RowBox[{"{", 
         RowBox[{"39.49999999999999`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.63957177263898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430595`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.67718673301603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295856`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.49999999999999, "A", 
        Association[1 -> {
           Complex[48.63957177263898, -16.016364458249825`], 
           Complex[72.71119598166317, -40.208409298430595`]}, 2 -> {
           Complex[49.67718673301603, 14.195955395586383`], 
           Complex[71.78739616686877, -3.9614519886295856`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.599999999999994`, -6.98851983248525}],
       RowBox[{"{", 
         RowBox[{"39.599999999999994`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.65298689323024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.09324711402706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.296561508588134`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.6737574329993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.279426178673182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418625`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.599999999999994`, "A", 
        Association[1 -> {
           Complex[48.65298689323024, -16.09324711402706], 
           Complex[72.73469819909567, -40.296561508588134`]}, 2 -> {
           Complex[49.6737574329993, 14.279426178673182`], 
           Complex[71.78128532311126, -3.853935345418625]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.699999999999996`, -6.989515003703513}],
       RowBox[{"{", 
         RowBox[{"39.699999999999996`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.666223843506465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731901`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.670467660008306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.362192871226501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.699999999999996`, "A", 
        Association[1 -> {
           Complex[48.666223843506465`, -16.169470489332475`], 
           Complex[72.75793792851876, -40.38396676731901]}, 2 -> {
           Complex[49.670467660008306`, 14.362192871226501`], 
           Complex[71.77540493979987, -3.7472457515262505`]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.8, -6.990428876608445}],
       RowBox[{"{", 
         RowBox[{"39.8`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.67928724206044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.24504648743809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.7809215257996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.47063852810008`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.66731304323485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.444267820361429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.641369140955806`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.8, "A", 
        Association[1 -> {
           Complex[48.67928724206044, -16.24504648743809], 
           Complex[72.7809215257996, -40.47063852810008]}, 2 -> {
           Complex[49.66731304323485, 14.444267820361429`], 
           Complex[71.76974878182652, -3.641369140955806]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{39.9, -6.991267539767795}],
       RowBox[{"{", 
         RowBox[{"39.9`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.692181529961914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80365511190739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.66428938724529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.9, "A", 
        Association[1 -> {
           Complex[48.692181529961914`, -16.31998667718374], 
           Complex[72.80365511190739, -40.556589868302694`]}, 2 -> {
           Complex[49.66428938724529, 14.525663032929627`], 
           Complex[71.76431084846256, -3.536291830717447]}]}, 
       "Tooltip"]& ]}, 
    {GrayLevel[0], 
     TagBox[
      TooltipBox[PointBox[{40., -6.992036689474994}],
       RowBox[{"{", 
         RowBox[{"40.`", ",", "\"A\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"48.70491097967126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.394302305698698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.641833503377605`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"49.66139266308925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.75908536186752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.43200050653909`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {40., "A", 
        Association[1 -> {
           Complex[48.70491097967126, -16.394302305698698`], 
           Complex[72.82614458440335, -40.641833503377605`]}, 2 -> {
           Complex[49.66139266308925, 14.606390188337485`], 
           Complex[71.75908536186752, -3.43200050653909]}]}, "Tooltip"]& ]}}, {
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{15.999999999999998`, -6.061231643225288}],
       RowBox[{"{", 
         RowBox[{"15.999999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"142.43088738729756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12083732434029751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"184.91042443664614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23233632108243843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {15.999999999999998`, "C", 
        Association[1 -> {
           Complex[142.43088738729756`, 0.12083732434029751`], 
           Complex[113.66233957629902`, -20.405968816918097`]}, 2 -> {
           Complex[184.91042443664614`, -0.23233632108243843`], 
           Complex[154.38624653449173`, -20.985063633891325`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.099999999999998`, -6.067984680312568}],
       RowBox[{"{", 
         RowBox[{"16.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"143.20317083740102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12356070149773071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40448191262516`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"184.11415381173683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2370153809705939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.099999999999998`, "C", 
        Association[1 -> {
           Complex[143.20317083740102`, 0.12356070149773071`], 
           Complex[114.42383835786643`, -20.40448191262516]}, 2 -> {
           Complex[184.11415381173683`, -0.2370153809705939], 
           Complex[153.59811008119402`, -20.98816784504015]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.2, -6.099717102502052}],
       RowBox[{"{", 
         RowBox[{"16.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"143.8418943485418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"183.45688521121167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24124640092127728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.94915336254542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.2, "C", 
        Association[1 -> {
           Complex[143.8418943485418, 0.1262779516956982], 
           Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
           Complex[183.45688521121167`, -0.24124640092127728`], 
           Complex[152.94915336254542`, -20.990786350067847`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.299999999999997`, -6.14694223161962}],
       RowBox[{"{", 
         RowBox[{"16.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"144.403599085715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12903424492994017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.60228208527523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40155927983009`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"182.87977924699527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2452608701483842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.38052772522323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.993153001298854`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.299999999999997`, "C", 
        Association[1 -> {
           Complex[144.403599085715, 0.12903424492994017`], 
           Complex[115.60228208527523`, -20.40155927983009]}, 2 -> {
           Complex[182.87977924699527`, -0.2452608701483842], 
           Complex[152.38052772522323`, -20.993153001298854`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.4, -6.202691833803821}],
       RowBox[{"{", 
         RowBox[{"16.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"144.91401586419227`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1318524872647501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40005566427453`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"182.3560651176949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24916606948640838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.8654584893039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99537613618962`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.4, "C", 
        Association[1 -> {
           Complex[144.91401586419227`, 0.1318524872647501], 
           Complex[116.10150054551087`, -20.40005566427453]}, 2 -> {
           Complex[182.3560651176949, -0.24916606948640838`], 
           Complex[151.8654584893039, -20.99537613618962]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.499999999999996`, -6.2548083462587165`}],
       RowBox[{"{", 
         RowBox[{"16.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"145.38744700905215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13474786473651384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398501738168576`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"181.8708660927008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.253023818602633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.38906785583268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.99751794736914`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.499999999999996`, "C", 
        Association[1 -> {
           Complex[145.38744700905215`, 0.13474786473651384`], 
           Complex[116.56359372447044`, -20.398501738168576`]}, 2 -> {
           Complex[181.8708660927008, -0.253023818602633], 
           Complex[151.38906785583268`, -20.99751794736914]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.599999999999998`, -6.281894702889123}],
       RowBox[{"{", 
         RowBox[{"16.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"145.8328296140851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614972086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.99749565640013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.396886329795848`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"181.41488879760732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.599999999999998`, "C", 
        Association[1 -> {
           Complex[145.8328296140851, 0.13773233614972086`], 
           Complex[116.99749565640013`, -20.396886329795848`]}, 2 -> {
           Complex[181.41488879760732`, -0.25687501967431686`], 
           Complex[150.9420631470024, -20.999619278633975`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.7, -6.2657759704285185`}],
       RowBox[{"{", 
         RowBox[{"16.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"146.25620289167148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.4092417408274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.395199814614813`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"180.9818553690836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.260749635653941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.7, "C", 
        Association[1 -> {
           Complex[146.25620289167148`, 0.14081646542056195`], 
           Complex[117.4092417408274, -20.395199814614813`]}, 2 -> {
           Complex[180.9818553690836, -0.260749635653941], 
           Complex[150.51816845485817`, -21.001709724866622`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.799999999999997`, -6.2137948553985325`}],
       RowBox[{"{", 
         RowBox[{"16.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"146.661886117449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173267872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39343319988049`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"180.56727763237527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467147267101754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.1128985493347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.799999999999997`, "C", 
        Association[1 -> {
           Complex[146.661886117449, 0.14401032173267872`], 
           Complex[117.80314680030489`, -20.39343319988049]}, 2 -> {
           Complex[180.56727763237527`, -0.26467147267101754`], 
           Complex[150.1128985493347, -21.00381247852693]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{16.9, -6.147662548120156}],
       RowBox[{"{", 
         RowBox[{"16.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"147.0531060212139`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14732399476906763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746043`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"180.1678042677887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2686607590279984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.005946943311322`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {16.9, "C", 
        Association[1 -> {
           Complex[147.0531060212139, 0.14732399476906763`], 
           Complex[118.18243252444688`, -20.391577604746043`]}, 2 -> {
           Complex[180.1678042677887, -0.2686607590279984], 
           Complex[149.72290589550488`, -21.005946943311322`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17., -6.0819233514031446`}],
       RowBox[{"{", 
         RowBox[{"17.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"147.43235893759334`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15076793497771634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.5495896388172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38962392181051`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"179.78084401215676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27273567401803595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727748`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17., "C", 
        Association[1 -> {
           Complex[147.43235893759334`, 0.15076793497771634`], 
           Complex[118.5495896388172, -20.38962392181051]}, 2 -> {
           Complex[179.78084401215676`, -0.27273567401803595`], 
           Complex[149.34560377406765`, -21.008130280727748`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.099999999999998`, -6.022203758303792}],
       RowBox[{"{", 
         RowBox[{"17.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"147.80163324655834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1543532116698063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"179.4043342501828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2769133339514044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.099999999999998`, "C", 
        Association[1 -> {
           Complex[147.80163324655834`, 0.1543532116698063], 
           Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
           Complex[179.4043342501828, -0.2769133339514044], 
           Complex[148.97893483437798`, -21.01037840309273]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.2, -5.969798924637855}],
       RowBox[{"{", 
         RowBox[{"17.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"148.16255297815067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1580917352471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"179.0365916440714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2812104825190737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.2, "C", 
        Association[1 -> {
           Complex[148.16255297815067`, 0.1580917352471046], 
           Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
           Complex[179.0365916440714, -0.2812104825190737], 
           Complex[148.62122171499408`, -21.012706663233452`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.299999999999997`, -5.9244431594738876`}],
       RowBox[{"{", 
         RowBox[{"17.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"148.51647442884564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16199646966552844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38307483942267`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"178.67621165990886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.27106658294744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01513037357346`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.299999999999997`, "C", 
        Association[1 -> {
           Complex[148.51647442884564`, 0.16199646966552844`], 
           Complex[119.59638315362788`, -20.38307483942267]}, 2 -> {
           Complex[178.67621165990886`, -0.2856440165404518], 
           Complex[148.27106658294744`, -21.01513037357346]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.4, -5.885423177479661}],
       RowBox[{"{", 
         RowBox[{"17.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"148.8645535018631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16608165207978046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.380625047921345`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"178.3219985600101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2902314223138406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.4, "C", 
        Association[1 -> {
           Complex[148.8645535018631, 0.16608165207978046`], 
           Complex[119.93165197047352`, -20.380625047921345`]}, 2 -> {
           Complex[178.3219985600101, -0.2902314223138406], 
           Complex[147.92728115711094`, -21.01766523058927]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.5, -5.851969551313177}],
       RowBox[{"{", 
         RowBox[{"17.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"149.2077941344118`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1703630326001896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868977`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"177.97291507886953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2949911695233655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813243`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.5, "C", 
        Association[1 -> {
           Complex[149.2077941344118, 0.1703630326001896], 
           Complex[120.26188344631822`, -20.378020317868977`]}, 2 -> {
           Complex[177.97291507886953`, -0.2949911695233655], 
           Complex[147.58883643153155`, -21.020327691813243`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.599999999999998`, -5.823379668306027}],
       RowBox[{"{", 
         RowBox[{"17.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"149.54708414211208`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1748581457911621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067412`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"177.62804519717992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2999430950469064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280479`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553143`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.599999999999998`, "C", 
        Association[1 -> {
           Complex[149.54708414211208`, 0.1748581457911621], 
           Complex[120.58795576067412`, -20.37524552516941]}, 2 -> {
           Complex[177.62804519717992`, -0.2999430950469064], 
           Complex[147.25482551280479`, -21.023135337553143`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.7, -5.799045807336628}],
       RowBox[{"{", 
         RowBox[{"17.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"149.88322249644975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17958662591578034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"177.28656583699845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.026107241897208`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.7, "C", 
        Association[1 -> {
           Complex[149.88322249644975`, 0.17958662591578034`], 
           Complex[120.91065734905384`, -20.372283703951]}, 2 -> {
           Complex[177.28656583699845`, -0.3051088017421759], 
           Complex[146.9244353952348, -21.026107241897208`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.799999999999997`, -5.778451499769673}],
       RowBox[{"{", 
         RowBox[{"17.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"150.2169406723343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"176.94772473618167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02926437433764`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.799999999999997`, "C", 
        Association[1 -> {
           Complex[150.2169406723343, 0.18457057958645484`], 
           Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
           Complex[176.94772473618167`, -0.310512094378605], 
           Complex[146.59692493347418`, -21.02926437433764]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.9, -5.761158847926062}],
       RowBox[{"{", 
         RowBox[{"17.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"150.54891985610047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18983503235951585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"176.6108226416958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3161794749411295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03263005304264`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.9, "C", 
        Association[1 -> {
           Complex[150.54891985610047`, 0.18983503235951585`], 
           Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
           Complex[176.6108226416958, -0.3161794749411295], 
           Complex[146.27160715472132`, -21.03263005304264]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{17.999999999999996`, -5.746794719495146}],
       RowBox[{"{", 
         RowBox[{"17.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"150.87980527230502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1954084700848582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"176.275198515501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {17.999999999999996`, "C", 
        Association[1 -> {
           Complex[150.87980527230502`, 0.1954084700848582], 
           Complex[121.86549419514674`, -20.36207123551036]}, 2 -> {
           Complex[176.275198515501, -0.3221407220109508], 
           Complex[145.94783460763009`, -21.03623047285221]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.099999999999998`, -5.7350383326248755`}],
       RowBox[{"{", 
         RowBox[{"18.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"151.21021854920286`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20132350187325002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"175.9402167996116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3284295838082578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.099999999999998`, "C", 
        Association[1 -> {
           Complex[151.21021854920286`, 0.20132350187325002`], 
           Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
           Complex[175.9402167996116, -0.3284295838082578], 
           Complex[145.62498679915495`, -21.04009533540118]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.2, -5.725610787327609}],
       RowBox[{"{", 
         RowBox[{"18.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"151.54076882836094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20761768000812997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.35389772868149`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"175.60525601100267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727987`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.2, "C", 
        Association[1 -> {
           Complex[151.54076882836094`, 0.20761768000812997`], 
           Complex[122.49728704083137`, -20.35389772868149]}, 2 -> {
           Complex[175.60525601100267`, -0.33508462216302626`], 
           Complex[145.30245899607772`, -21.044258615727987`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.299999999999997`, -5.718266425412087}],
       RowBox[{"{", 
         RowBox[{"18.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"151.87206319321126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21433452398635636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"175.26969807427406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.9796518070718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.048759510069537`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.299999999999997`, "C", 
        Association[1 -> {
           Complex[151.87206319321126`, 0.21433452398635636`], 
           Complex[122.81354255509225`, -20.34930172067202]}, 2 -> {
           Complex[175.26969807427406`, -0.3421502560032738], 
           Complex[144.9796518070718, -21.048759510069537`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.399999999999995`, -5.71278570635112}],
       RowBox[{"{", 
         RowBox[{"18.399999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"152.20471692148735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22152481262236687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"174.93291787440944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569467`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.399999999999995`, "C", 
        Association[1 -> {
           Complex[152.20471692148735`, 0.22152481262236687`], 
           Complex[123.13082758939966`, -20.34430875145043]}, 2 -> {
           Complex[174.93291787440944`, -0.3496780693287902], 
           Complex[144.65596103805998`, -21.053643624569467`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.499999999999996`, -5.70896926295221}],
       RowBox[{"{", 
         RowBox[{"18.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"152.53936404559178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22924823209533307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.4497523973468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"174.59427253610252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412606`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.499999999999996`, "C", 
        Association[1 -> {
           Complex[152.53936404559178`, 0.22924823209533307`], 
           Complex[123.4497523973468, -20.33886609255275]}, 2 -> {
           Complex[174.59427253610252`, -0.35772847232067345`], 
           Complex[144.33076734108204`, -21.058964486412606`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.599999999999998`, -5.706632830431101}],
       RowBox[{"{", 
         RowBox[{"18.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"152.8766687292074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790741`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573204`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"174.25308991417538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36637283877683763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.0034251594934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.064785490731843`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.599999999999998`, "C", 
        Association[1 -> {
           Complex[152.8766687292074, 0.23757550254713042`], 
           Complex[123.77095431790741`, -20.332911072573204`]}, 2 -> {
           Complex[174.25308991417538`, -0.36637283877683763`], 
           Complex[144.0034251594934, -21.064785490731843`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.7, -5.705602780513799}],
       RowBox[{"{", 
         RowBox[{"18.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"153.2173380411423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24659115703995835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"173.90865570862832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37569629412710687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.071182443764766`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.7, "C", 
        Association[1 -> {
           Complex[153.2173380411423, 0.24659115703995835`], 
           Complex[124.09510998319796`, -20.32636854350558]}, 2 -> {
           Complex[173.90865570862832`, -0.37569629412710687`], 
           Complex[143.6732504076637, -21.071182443764766`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.8, -5.705712021549816}],
       RowBox[{"{", 
         RowBox[{"18.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"153.5621368394489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903783`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"173.56019848705628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38580140506476973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.33950620148752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078246933699234`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.8, "C", 
        Association[1 -> {
           Complex[153.5621368394489, 0.2563972235666605], 
           Complex[124.42294949324784`, -20.319147517903783`]}, 2 -> {
           Complex[173.56019848705628`, -0.38580140506476973`], 
           Complex[143.33950620148752`, -21.078246933699234`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.9, -5.7067960393951065`}],
       RowBox[{"{", 
         RowBox[{"18.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"153.9119056914435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31113663674728`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"173.2068716855101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3968131395799549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.9, "C", 
        Association[1 -> {
           Complex[153.9119056914435, 0.26711817863125764`], 
           Complex[124.7552734369329, -20.31113663674728]}, 2 -> {
           Complex[173.2068716855101, -0.3968131395799549], 
           Complex[143.00138575722923`, -21.086090869598895`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{18.999999999999996`, -5.708688847491701}],
       RowBox[{"{", 
         RowBox[{"18.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"154.26758308493513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27890772560985055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.302197956798476`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"172.84773132990216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40888565081601425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.09485269983952`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {18.999999999999996`, "C", 
        Association[1 -> {
           Complex[154.26758308493513`, 0.27890772560985055`], 
           Complex[125.09297394908012`, -20.302197956798476`]}, 2 -> {
           Complex[172.84773132990216`, -0.40888565081601425`], 
           Complex[142.6579912660793, -21.09485269983952]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.099999999999998`, -5.711218582023318}],
       RowBox[{"{", 
         RowBox[{"19.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"154.6302336943276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2919582479968343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"172.481707712234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4222117350213626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.099999999999998`, "C", 
        Association[1 -> {
           Complex[154.6302336943276, 0.2919582479968343], 
           Complex[125.43706147399148`, -20.29215827088692]}, 2 -> {
           Complex[172.481707712234, -0.4222117350213626], 
           Complex[142.30830707209702`, -21.104706096794665`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.2, -5.714202408284036}],
       RowBox[{"{", 
         RowBox[{"19.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"155.00108525660056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30651427855723345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.78869965408623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.28079671874115`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"172.10756846499456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475135913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.115872350288292`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.2, "C", 
        Association[1 -> {
           Complex[155.00108525660056`, 0.30651427855723345`], 
           Complex[125.78869965408623`, -20.28079671874115]}, 2 -> {
           Complex[172.10756846499456`, -0.43703630475135913`], 
           Complex[141.95116473317964`, -21.115872350288292`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.299999999999997`, -5.717440277022293}],
       RowBox[{"{", 
         RowBox[{"19.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"155.38157786657638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"171.72386922299577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4536760563999232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.299999999999997`, "C", 
        Association[1 -> {
           Complex[155.38157786657638`, 0.32289216335652754`], 
           Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
           Complex[171.72386922299577`, -0.4536760563999232], 
           Complex[141.58519635758813`, -21.12863849123653]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.4, -5.720706846286295}],
       RowBox[{"{", 
         RowBox[{"19.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"155.773431537362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34150958252322494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"171.32888602568033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47254899400334877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.4, "C", 
        Association[1 -> {
           Complex[155.773431537362, 0.34150958252322494`], 
           Complex[126.52034552601548`, -20.252868457449622`]}, 2 -> {
           Complex[171.32888602568033`, -0.47254899400334877`], 
           Complex[141.2087706796062, -21.143384546932786`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.499999999999996`, -5.723740492634645}],
       RowBox[{"{", 
         RowBox[{"19.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"156.1787412727927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3629313245006883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"170.92052021219553`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614487433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708604`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.499999999999996`, "C", 
        Association[1 -> {
           Complex[156.1787412727927, 0.3629313245006883], 
           Complex[126.90396116486053`, -20.235407072598086`]}, 2 -> {
           Complex[170.92052021219553`, -0.49422020614487433`], 
           Complex[140.81990311379664`, -21.160625877708604`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.599999999999998`, -5.726227634458349}],
       RowBox[{"{", 
         RowBox[{"19.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"156.60011476215269`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180777`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"170.49616069823637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.18108148048887`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.599999999999998`, "C", 
        Association[1 -> {
           Complex[156.60011476215269`, 0.3879430012901607], 
           Complex[127.30256352822093`, -20.214723835180777`]}, 2 -> {
           Complex[170.49616069823637`, -0.5194755835198454], 
           Complex[140.41612546346298`, -21.18108148048887]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.7, -5.727779298372652}],
       RowBox[{"{", 
         RowBox[{"19.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"157.0408782710949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4176752143879963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.71929603487078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.189781145086567`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"170.05247806013978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5494459869149929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.9942910181267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.205789253752098`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.7, "C", 
        Association[1 -> {
           Complex[157.0408782710949, 0.4176752143879963], 
           Complex[127.71929603487078`, -20.189781145086567`]}, 2 -> {
           Complex[170.05247806013978`, -0.5494459869149929], 
           Complex[139.9942910181267, -21.205789253752098`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.799999999999997`, -5.727894407299563}],
       RowBox[{"{", 
         RowBox[{"19.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"157.5053956369925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45382432603574024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377493`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"169.5851055175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5858280202580739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2363113344938`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.799999999999997`, "C", 
        Association[1 -> {
           Complex[157.5053956369925, 0.45382432603574024`], 
           Complex[128.15828301502822`, -20.159017144377493`]}, 2 -> {
           Complex[169.5851055175, -0.5858280202580739], 
           Complex[139.55027237651973`, -21.2363113344938]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{19.9, -5.725899527837187}],
       RowBox[{"{", 
         RowBox[{"19.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"157.9995820310236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829306903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"169.08812515159096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6313034612843315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578065`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {19.9, "C", 
        Association[1 -> {
           Complex[157.9995820310236, 0.49907188829306903`], 
           Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
           Complex[169.08812515159096`, -0.6313034612843315], 
           Complex[139.07847426814035`, -21.27512497578065]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20., -5.720845950715181}],
       RowBox[{"{", 
         RowBox[{"20.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"158.53176398183555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.1276748901026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"168.55320786440365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.5710167123656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32643079618197`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20., "C", 
        Association[1 -> {
           Complex[158.53176398183555`, 0.5579501377609449], 
           Complex[129.1276748901026, -20.068393863077308`]}, 2 -> {
           Complex[168.55320786440365`, -0.6904047576732164], 
           Complex[138.5710167123656, -21.32643079618197]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.1, -5.71133283239896}],
       RowBox[{"{", 
         RowBox[{"20.1`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"159.11415349895574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041312677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.6775233759758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.99655438623824`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"167.96813923983427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368576926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.0163308920829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.39800884938101`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.1, "C", 
        Association[1 -> {
           Complex[159.11415349895574`, 0.6388251041312677], 
           Complex[129.6775233759758, -19.99655438623824]}, 2 -> {
           Complex[167.96813923983427`, -0.7714981368576926], 
           Complex[138.0163308920829, -21.39800884938101]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.199999999999996`, -5.695254812493801}],
       RowBox[{"{", 
         RowBox[{"20.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"159.76521705885392`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.759082853797409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.88821086922835`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"167.3144505438764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8919698507580937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.3968867364131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.506084894187325`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.199999999999996`, "C", 
        Association[1 -> {
           Complex[159.76521705885392`, 0.759082853797409], 
           Complex[130.2921900311733, -19.88821086922835]}, 2 -> {
           Complex[167.3144505438764, -0.8919698507580937], 
           Complex[137.3968867364131, -21.506084894187325`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.299999999999997`, -5.6700893952540445`}],
       RowBox[{"{", 
         RowBox[{"20.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"160.51100280221908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9608435417074076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.70389984169742`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"166.5660915150384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939402286417192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291288`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.69012260562795`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.299999999999997`, "C", 
        Association[1 -> {
           Complex[160.51100280221908`, 0.9608435417074076], 
           Complex[130.99653808272222`, -19.70389984169742]}, 2 -> {
           Complex[166.5660915150384, -1.0939402286417192`], 
           Complex[136.68781879291288`, -21.69012260562795]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.4, -5.641058418937706}],
       RowBox[{"{", 
         RowBox[{"20.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"161.35610930103817`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.33740874464973`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"165.71846158622145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317955`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"135.88391552140592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916565`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.4, "C", 
        Association[1 -> {
           Complex[161.35610930103817`, 1.3569051651311863`], 
           Complex[131.7957769749429, -19.33740874464973]}, 2 -> {
           Complex[165.71846158622145`, -1.4902074317955], 
           Complex[135.88391552140592`, -22.056334735916565`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.5, -5.652991792376542}],
       RowBox[{"{", 
         RowBox[{"20.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.09763876574996`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0881973270436873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.4998425166415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.6544084566896`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.974456667634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2217012177173117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.73905058908342`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.5, "C", 
        Association[1 -> {
           Complex[162.09763876574996`, 2.0881973270436873`], 
           Complex[132.4998425166415, -18.6544084566896]}, 2 -> {
           Complex[164.974456667634, -2.2217012177173117`], 
           Complex[135.17523913663766`, -22.73905058908342]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.599999999999994`, -5.825249344930458}],
       RowBox[{"{", 
         RowBox[{"20.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.49679557516603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.87967075293174`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.57287060790918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532399953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864434`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.599999999999994`, "C", 
        Association[1 -> {
           Complex[162.49679557516603`, 2.9142396485109336`], 
           Complex[132.88189718832854`, -17.87967075293174]}, 2 -> {
           Complex[164.57287060790918`, -3.0479413532399953`], 
           Complex[134.78862529189124`, -23.513498562864434`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.699999999999996`, -5.874202110420369}],
       RowBox[{"{", 
         RowBox[{"20.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.69815823018737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.07664557448564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.20679401345527`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.3691232322966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.76466640407678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763844034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.18608044096362`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.699999999999996`, "C", 
        Association[1 -> {
           Complex[162.69815823018737`, 3.6307705575763123`], 
           Complex[133.07664557448564`, -17.20679401345527]}, 2 -> {
           Complex[164.3691232322966, -3.76466640407678], 
           Complex[134.58936763844034`, -24.18608044096362]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.799999999999997`, -5.915846569341985}],
       RowBox[{"{", 
         RowBox[{"20.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.81702682614014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.244103960587594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.192822735254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.630699080753924`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.24791286298796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.46872944634774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.76187553625734`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.799999999999997`, "C", 
        Association[1 -> {
           Complex[162.81702682614014`, 4.244103960587594], 
           Complex[133.192822735254, -16.630699080753924`]}, 2 -> {
           Complex[164.24791286298796`, -4.378190406750068], 
           Complex[134.46872944634774`, -24.76187553625734]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{20.9, -5.952479620601521}],
       RowBox[{"{", 
         RowBox[{"20.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.89623202590275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937514`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.166407339344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.916047187939833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186124`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {20.9, "C", 
        Association[1 -> {
           Complex[162.89623202590275`, 4.781773561001189], 
           Complex[133.27102086156964`, -16.125747324937514`]}, 2 -> {
           Complex[164.166407339344, -4.916047187939833], 
           Complex[134.38611694252143`, -25.266522626186124`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21., -5.985902417731189}],
       RowBox[{"{", 
         RowBox[{"21.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.9533692895785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.26317421199133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.673778470422995`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.10700978216263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.397631717588651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.718182126604795`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21., "C", 
        Association[1 -> {
           Complex[162.9533692895785, 5.26317421199133], 
           Complex[133.3279803002992, -15.673778470422995`]}, 2 -> {
           Complex[164.10700978216263`, -5.397631717588651], 
           Complex[134.3247882793696, -25.718182126604795`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.099999999999998`, -6.017220595936366}],
       RowBox[{"{", 
         RowBox[{"21.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"162.99687585597522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.26276580186694`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.06128160668933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.83575911268632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343943`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.099999999999998`, "C", 
        Association[1 -> {
           Complex[162.99687585597522`, 5.701120919783133], 
           Complex[133.3717561373341, -15.26276580186694]}, 2 -> {
           Complex[164.06128160668933`, -5.83575911268632], 
           Complex[134.27668694605623`, -26.128880886343943`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.2, -6.047114326074205}],
       RowBox[{"{", 
         RowBox[{"21.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.03131031496125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4067147758406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.884495531077516`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"164.02466294522884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.239169639445748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.2374451850879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.506832820748922`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.2, "C", 
        Association[1 -> {
           Complex[163.03131031496125`, 6.104353845416841], 
           Complex[133.4067147758406, -14.884495531077516`]}, 2 -> {
           Complex[164.02466294522884`, -6.239169639445748], 
           Complex[134.2374451850879, -26.506832820748922`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.3, -6.076015089190307}],
       RowBox[{"{", 
         RowBox[{"21.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.05936393484134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43544220027496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.533126521950006`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.99446131516729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158492`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.3, "C", 
        Association[1 -> {
           Complex[163.05936393484134`, 6.479082403584161], 
           Complex[133.43544220027496`, -14.533126521950006`]}, 2 -> {
           Complex[163.99446131516729`, -6.614072812516706], 
           Complex[134.20447572357537`, -26.857879187158492`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.4, -6.104204540137779}],
       RowBox[{"{", 
         RowBox[{"21.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.0827360388856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418514`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.96897623823008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.96504547952883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.18632866833261`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.4, "C", 
        Association[1 -> {
           Complex[163.0827360388856, 6.829883346826038], 
           Complex[133.45957631720722`, -14.204350207418514`]}, 2 -> {
           Complex[163.96897623823008`, -6.96504547952883], 
           Complex[134.17613942808237`, -27.18632866833261]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.499999999999996`, -6.131870245843}],
       RowBox[{"{", 
         RowBox[{"21.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.10255730313813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.1602366935056825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.8948884451038`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.94707593880682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1513419963516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49545951715293`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.10255730313813`, 7.1602366935056825`], 
           Complex[133.48021025962274`, -13.8948884451038]}, 2 -> {
           Complex[163.94707593880682`, -7.295567749380924], 
           Complex[134.1513419963516, -27.49545951715293]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.599999999999998`, -6.159138267649699}],
       RowBox[{"{", 
         RowBox[{"21.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.11961217061838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273478`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.9279749261981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.12932163548447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.78783159598447`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.11961217061838`, 7.472858386883269], 
           Complex[133.49810470509067`, -13.602181478273478`]}, 2 -> {
           Complex[163.9279749261981, -7.60835565160759], 
           Complex[134.12932163548447`, -27.78783159598447]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.7, -6.186092975273801}],
       RowBox[{"{", 
         RowBox[{"21.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.13446375540627`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.32418640258124`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.91110908726415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230864`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.7, "C", 
        Association[1 -> {
           Complex[163.13446375540627`, 7.769914966301738], 
           Complex[133.51380733250912`, -13.32418640258124]}, 2 -> {
           Complex[163.91110908726415`, -7.905575807831239], 
           Complex[134.10952960183627`, -28.065487910230864`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.799999999999997`, -6.212789550037768}],
       RowBox[{"{", 
         RowBox[{"21.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.1475279007755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.053167049211595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813348`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.8960616252759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.188988914036532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.33008939886362`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.1475279007755, 8.053167049211595], 
           Complex[133.52772377923588`, -13.059242375813348`]}, 2 -> {
           Complex[163.8960616252759, -8.188988914036532], 
           Complex[134.09155924078232`, -28.33008939886362]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.899999999999995`, -6.23926214238019}],
       RowBox[{"{", 
         RowBox[{"21.899999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.15911911401952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.3240682437392`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175146`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.8825171223138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.460048653363897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0751018939077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.583007906385838`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.899999999999995`, "C", 
        Association[1 -> {
           Complex[163.15911911401952`, 8.3240682437392], 
           Complex[133.54016173104085`, -12.805977646175146`]}, 2 -> {
           Complex[163.8825171223138, -8.460048653363897], 
           Complex[134.0751018939077, -28.583007906385838`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{21.999999999999996`, -6.265529356422009}],
       RowBox[{"{", 
         RowBox[{"21.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.1694801602913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.583835207504208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.56324367042308`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.87023194285814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493508`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {21.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.1694801602913, 8.583835207504208], 
           Complex[133.55135937730103`, -12.56324367042308]}, 2 -> {
           Complex[163.87023194285814`, -8.719971755138737], 
           Complex[134.05991844116488`, -28.82539206493508]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.099999999999998`, -6.291598040534169}],
       RowBox[{"{", 
         RowBox[{"22.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.17880175664644`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.833498461149421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220034`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.85901453737054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144608`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.17880175664644`, 8.833498461149421], 
           Complex[133.56150438018219`, -12.330067310220034`]}, 2 -> {
           Complex[163.85901453737054`, -8.96978880859587], 
           Complex[134.04582032924358`, -29.058215098144608`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.2, -6.317465976571192}],
       RowBox[{"{", 
         RowBox[{"22.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.18723604978868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.073940020992653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.10561541560388`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.84871196234698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.03265656530453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.28231023787636`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.2, "C", 
        Association[1 -> {
           Complex[163.18723604978868`, 9.073940020992653], 
           Complex[133.57074687863496`, -12.10561541560388]}, 2 -> {
           Complex[163.84871196234698`, -9.210381895712343], 
           Complex[134.03265656530453`, -29.28231023787636]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.3, -6.343123837847275}],
       RowBox[{"{", 
         RowBox[{"22.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.19490606734587`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503115`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.8392004270005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.44251298180812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.020304580273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.3, "C", 
        Association[1 -> {
           Complex[163.19490606734587`, 9.305921789460667], 
           Complex[133.57920862299497`, -11.889168097503115`]}, 2 -> {
           Complex[163.8392004270005, -9.44251298180812], 
           Complex[134.020304580273, -29.498397451891556`]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.4, -6.368556653507212}],
       RowBox[{"{", 
         RowBox[{"22.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.20191248924124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034463`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.83037851999364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727525`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.4, "C", 
        Association[1 -> {
           Complex[163.20191248924124`, 9.530107327827569], 
           Complex[133.58698953054267`, -11.680098224034463`]}, 2 -> {
           Complex[163.83037851999364`, -9.666845688440565], 
           Complex[134.00866367132147`, -29.707103947727525`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.499999999999996`, -6.393744935797419}],
       RowBox[{"{", 
         RowBox[{"22.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.20833859211223`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956242`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.8221622632574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.883962238175444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.908980134406136`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.20833859211223`, 9.747078800841354], 
           Complex[133.59417248038324`, -11.477855458956242`]}, 2 -> {
           Complex[163.8221622632574, -9.883962238175444], 
           Complex[133.99765020516938`, -29.908980134406136`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.599999999999998`, -6.418665575619495}],
       RowBox[{"{", 
         RowBox[{"22.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2142539214259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.957350339052207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224448`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.81448143823496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.09437681705006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.104512213028926`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.2142539214259, 9.957350339052207], 
           Complex[133.60082688045318`, -11.281953671224448`]}, 2 -> {
           Complex[163.81448143823496`, -10.09437681705006], 
           Complex[133.9871940493811, -30.104512213028926`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.7, -6.44329257866816}],
       RowBox[{"{", 
         RowBox[{"22.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.21971706050041`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6070113617539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.091960884780269`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.80727681533168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.298546238374051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.97723587655176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.294132227130046`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.7, "C", 
        Association[1 -> {
           Complex[163.21971706050041`, 10.161378702488394`], 
           Complex[133.6070113617539, -11.091960884780269`]}, 2 -> {
           Complex[163.80727681533168`, -10.298546238374051`], 
           Complex[133.97723587655176`, -30.294132227130046`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.799999999999997`, -6.467597692468724}],
       RowBox[{"{", 
         RowBox[{"22.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2247777474091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.359571883156995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.907491168998273`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.80049803558532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.49687854534779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9677250996958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.2247777474091, 10.359571883156995`], 
           Complex[133.61277584148843`, -10.907491168998273`]}, 2 -> {
           Complex[163.80049803558532`, -10.49687854534779], 
           Complex[133.9677250996958, -30.478226172360408`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.9, -6.491550959601722}],
       RowBox[{"{", 
         RowBox[{"22.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.22947851363165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.552296113405845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417936`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7941019706839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.689740019533176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878894`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.9, "C", 
        Association[1 -> {
           Complex[163.22947851363165`, 10.552296113405845`], 
           Complex[133.6181631227232, -10.728198030417936`]}, 2 -> {
           Complex[163.7941019706839, -10.689740019533176`], 
           Complex[133.9586182712075, -30.657140604878894`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{22.999999999999996`, -6.515121221818219}],
       RowBox[{"{", 
         RowBox[{"22.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.23385596697975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.55376897922101`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7880514387958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {22.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.23385596697975`, 10.739881627157578`], 
           Complex[133.62321014884253`, -10.55376897922101]}, 2 -> {
           Complex[163.7880514387958, -10.877460942190032`], 
           Complex[133.94987782711803`, -30.8311880749906]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.099999999999998`, -6.53827659205023}],
       RowBox[{"{", 
         RowBox[{"23.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.23794180650475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62794899755536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.383921024629705`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.78231418849845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.000651631856574`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.23794180650475`, 10.922627435195468`], 
           Complex[133.62794899755536`, -10.383921024629705`]}, 2 -> {
           Complex[163.78231418849845`, -11.060340369657364`], 
           Complex[133.94147109188316`, -31.000651631856574`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.199999999999996`, -6.560984905529962}],
       RowBox[{"{", 
         RowBox[{"23.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2417636330736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.100805313420308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63240767607033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.218396911961511`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.776862087113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.238650121699811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.16578858654045`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.2417636330736, 11.100805313420308`], 
           Complex[133.63240767607033`, -10.218396911961511`]}, 2 -> {
           Complex[163.776862087113, -11.238650121699811`], 
           Complex[133.93336948207866`, -31.16578858654045]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.299999999999997`, -6.583214156735538}],
       RowBox[{"{", 
         RowBox[{"23.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.245345602464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.274663157243593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.05696195712113`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.77167046658727`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.326833677611646`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.245345602464, 11.274663157243593`], 
           Complex[133.6366107628227, -10.05696195712113]}, 2 -> {
           Complex[163.77167046658727`, -11.412638135984606`], 
           Complex[133.92554786361376`, -31.326833677611646`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.4, -6.6049329252981455`}],
       RowBox[{"{", 
         RowBox[{"23.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2487089558695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.444427821247759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.89940136633527`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7667175920338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.582531307820627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9179840286246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.484001751500106`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.4, "C", 
        Association[1 -> {
           Complex[163.2487089558695, 11.444427821247759`], 
           Complex[133.64057992958772`, -9.89940136633527]}, 2 -> {
           Complex[163.7667175920338, -11.582531307820627`], 
           Complex[133.9179840286246, -31.484001751500106`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.5, -6.626110791107342}],
       RowBox[{"{", 
         RowBox[{"23.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2518724540805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.610307537645536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028422`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7619842266485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704613`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.5, "C", 
        Association[1 -> {
           Complex[163.2518724540805, 11.610307537645536`], 
           Complex[133.64433436948318`, -9.745517953028422]}, 2 -> {
           Complex[163.7619842266485, -11.748537908691581`], 
           Complex[133.91065826653698`, -31.637490045704613`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.6, -6.646718736509068}],
       RowBox[{"{", 
         RowBox[{"23.6`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.25485273533127`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.77249398761309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053287`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.75745327301976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.91084965765839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.6, "C", 
        Association[1 -> {
           Complex[163.25485273533127`, 11.77249398761309], 
           Complex[133.64789115029092`, -9.595130182053287]}, 2 -> {
           Complex[163.75745327301976`, -11.91084965765839], 
           Complex[133.90355300986815`, -31.787480144641357`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.699999999999996`, -6.666729531642371}],
       RowBox[{"{", 
         RowBox[{"23.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2576646121618`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.931164084638935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548408`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.75310947547112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.069643504773667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.93413966386116`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.2576646121618, 11.931164084638935`], 
           Complex[133.65126550803504`, -9.448070485548408]}, 2 -> {
           Complex[163.75310947547112`, -12.069643504773667`], 
           Complex[133.89665253982204`, -31.93413966386116]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.799999999999997`, -6.686118097584282}],
       RowBox[{"{", 
         RowBox[{"23.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.26032131919624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581669`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7489391715357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.225083174088782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.07762370747607`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.26032131919624`, 12.086481517469739`], 
           Complex[133.65447109241083`, -9.304183805581669]}, 2 -> {
           Complex[163.7489391715357, -12.225083174088782`], 
           Complex[133.88994274008314`, -32.07762370747607]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{23.9, -6.704861841068211}],
       RowBox[{"{", 
         RowBox[{"23.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.26283472113678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.74493008325814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513113`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {23.9, "C", 
        Association[1 -> {
           Complex[163.26283472113678`, 12.238598091201823`], 
           Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
           Complex[163.74493008325814`, -12.377320504803174`], 
           Complex[133.8834108897335, -32.21807613513113]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24., -6.722940954115716}],
       RowBox[{"{", 
         RowBox[{"24.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2652154882986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558757`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.74107114099544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24., "C", 
        Association[1 -> {
           Complex[163.2652154882986, 12.387654897960461`], 
           Complex[133.66042381437185`, -9.025364372558757]}, 2 -> {
           Complex[163.74107114099544`, -12.526496621998465`], 
           Complex[133.87704548813625`, -32.35563066816216]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.099999999999994`, -6.740338671976036}],
       RowBox[{"{", 
         RowBox[{"24.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2674732455004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.533783342972365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.890173430857475`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.73735233390101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.672742962762172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.2674732455004, 12.533783342972365`], 
           Complex[133.6631920229149, -8.890173430857475]}, 2 -> {
           Complex[163.73735233390101`, -12.672742962762172`], 
           Complex[133.87083610610037`, -32.49041185927024]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.199999999999996`, -6.757041483287254}],
       RowBox[{"{", 
         RowBox[{"24.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.26961669895428`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564256`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7337645824435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.26961669895428`, 12.677106047334807`], 
           Complex[133.66583387467648`, -8.757637305564256]}, 2 -> {
           Complex[163.7337645824435, -12.816182179005438`], 
           Complex[133.86477325877703`, -32.622535945802085`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.299999999999997`, -6.773039287322193}],
       RowBox[{"{", 
         RowBox[{"24.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.27165374489172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.817737645166858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678214`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.73029962922303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.956928934660269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.27165374489172`, 12.817737645166858`], 
           Complex[133.66835762313937`, -8.627647360678214]}, 2 -> {
           Complex[163.73029962922303`, -12.956928934660269`], 
           Complex[133.85884829662547`, -32.75211160331618]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.4, -6.788325494501076}],
       RowBox[{"{", 
         RowBox[{"24.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.27359156294804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.500101853051339`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7269499450588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.095090612015007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335592`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.4, "C", 
        Association[1 -> {
           Complex[163.27359156294804`, 12.955785489901578`], 
           Complex[133.67077079273932`, -8.500101853051339]}, 2 -> {
           Complex[163.7269499450588, -13.095090612015007`], 
           Complex[133.8530533114799, -32.87924061335592]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.499999999999996`, -6.802897067958586}],
       RowBox[{"{", 
         RowBox[{"24.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.27543669676655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778804`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.72370864788658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.004018457106575`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.27543669676655`, 13.091350282096839`], 
           Complex[133.67308025959395`, -8.374905338778804]}, 2 -> {
           Complex[163.72370864788658`, -13.230767939566048`], 
           Complex[133.84738105530036`, -33.004018457106575`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.599999999999998`, -6.816754505743258}],
       RowBox[{"{", 
         RowBox[{"24.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.27719512383507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67529232155744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.251968143863518`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7205694324496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.364055551814676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477616`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.27719512383507`, 13.224526629192962`], 
           Complex[133.67529232155744`, -8.251968143863518]}, 2 -> {
           Complex[163.7205694324496, -13.364055551814676`], 
           Complex[133.8418248696247, -33.12653484477616]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.7, -6.82990176508817}],
       RowBox[{"{", 
         RowBox[{"24.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2788723162124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.35540354604583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824086`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.71752650912524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.495042489836637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902983`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.7, "C", 
        Association[1 -> {
           Complex[163.2788723162124, 13.35540354604583], 
           Complex[133.67741275923174`, -8.131205890824086]}, 2 -> {
           Complex[163.71752650912524`, -13.495042489836637`], 
           Complex[133.83637862409034`, -33.24687418902983]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.8, -6.842346132006417}],
       RowBox[{"{", 
         RowBox[{"24.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28047329351344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167398`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.71457455051592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.623812650126242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.365116029557846`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.8, "C", 
        Association[1 -> {
           Complex[163.28047329351344`, 13.484064903736138`], 
           Complex[133.67944688928384`, -8.012539074167398]}, 2 -> {
           Complex[163.71457455051592`, -13.623812650126242`], 
           Complex[133.83103666267402`, -33.365116029557846`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.9, -6.8540980411225725`}],
       RowBox[{"{", 
         RowBox[{"24.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28200266929107`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682291`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.71170864466583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.48133541482063`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.9, "C", 
        Association[1 -> {
           Complex[163.28200266929107`, 13.610589833057865`], 
           Complex[133.68139961119044`, -7.895892678682291]}, 2 -> {
           Complex[163.71170864466583`, -13.750445188118116`], 
           Complex[133.82579375652693`, -33.48133541482063]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{24.999999999999996`, -6.865170852056796}],
       RowBox[{"{", 
         RowBox[{"24.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2834646917637`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.735053088170234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68327544834887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.781195835377185`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.70892425395203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8206450624651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.59560324614746`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {24.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.2834646917637, 13.735053088170234`], 
           Complex[133.68327544834887`, -7.781195835377185]}, 2 -> {
           Complex[163.70892425395203`, -13.875014881870271`], 
           Complex[133.8206450624651, -33.59560324614746]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.099999999999998`, -6.875580589759436}],
       RowBox[{"{", 
         RowBox[{"25.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28486327968363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610166`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.70621717885442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.997592460624668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.70798658864134`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.28486327968363`, 13.857525375128327`], 
           Complex[133.68507858433867`, -7.668381510610166]}, 2 -> {
           Complex[163.70621717885442`, -13.997592460624668`], 
           Complex[133.81558608632903`, -33.70798658864134]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.199999999999996`, -6.885345656905611}],
       RowBox[{"{", 
         RowBox[{"25.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2862020540158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68681289499762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.55738622457017`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.7035835259332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.118244902313043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8106126505474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.81854895273081`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.2862020540158, 13.978073649360802`], 
           Complex[133.68681289499762`, -7.55738622457017]}, 2 -> {
           Complex[163.7035835259332, -14.118244902313043`], 
           Complex[133.8106126505474, -33.81854895273081]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.299999999999997`, -6.89448652678577}],
       RowBox[{"{", 
         RowBox[{"25.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28748436599128`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.4481497957836655`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.70101967944905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.28748436599128`, 14.096761385616206`], 
           Complex[133.68848197687097`, -7.4481497957836655`]}, 2 -> {
           Complex[163.70101967944905`, -14.237035703530262`], 
           Complex[133.80572086534593`, -33.927350549694836`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.399999999999995`, -6.903025425081526}],
       RowBox[{"{", 
         RowBox[{"25.399999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28871332201555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.21364882343601`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.3406151087588825`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.69852227614442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.35402512503277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404853`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.399999999999995`, "C", 
        Association[1 -> {
           Complex[163.28871332201555`, 14.21364882343601], 
           Complex[133.69008917251037`, -7.3406151087588825`]}, 2 -> {
           Complex[163.69852227614442`, -14.35402512503277], 
           Complex[133.80090710312305`, -34.03444852404853]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.499999999999996`, -6.910986008532176}],
       RowBox[{"{", 
         RowBox[{"25.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.28989180583767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.69608818277845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.79616797558796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.13989716530639`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.28989180583767`, 14.328793190818367`], 
           Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
           Complex[163.69608818277845`, -14.469270415426754`], 
           Complex[133.79616797558796`, -34.13989716530639]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.599999999999998`, -6.9183930478307705`}],
       RowBox[{"{", 
         RowBox[{"25.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29102249833014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951601`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.69371447606676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.243748101320996`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.29102249833014`, 14.442248908399693`], 
           Complex[133.69313013823358`, -7.130436575951601]}, 2 -> {
           Complex[163.69371447606676`, -14.582826015372707`], 
           Complex[133.7915003133145, -34.243748101320996`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.7, -6.925272121205421}],
       RowBox[{"{", 
         RowBox[{"25.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2921078951751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.554067776191998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672555`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.69139842472714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.694743744345221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7869011474127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.7, "C", 
        Association[1 -> {
           Complex[163.2921078951751, 14.554067776191998`], 
           Complex[133.69456951471147`, -7.027692013672555]}, 2 -> {
           Complex[163.69139842472714`, -14.694743744345221`], 
           Complex[133.7869011474127, -34.34605047512348]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.799999999999997`, -6.931649324112859}],
       RowBox[{"{", 
         RowBox[{"25.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29315032271526`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69595825198883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.926447421338327`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.68913747337317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78236769306173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.446851106957446`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.29315032271526`, 14.664299144668377`], 
           Complex[133.69595825198883`, -6.926447421338327]}, 2 -> {
           Complex[163.68913747337317`, -14.805072971738813`], 
           Complex[133.78236769306173`, -34.446851106957446`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{25.9, -6.937550999367053}],
       RowBox[{"{", 
         RowBox[{"25.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2941519521878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.77299007177116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.68692922803774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.913860773896733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {25.9, "C", 
        Association[1 -> {
           Complex[163.2941519521878, 14.77299007177116], 
           Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
           Complex[163.68692922803774`, -14.913860773896733`], 
           Complex[133.77789733468606`, -34.54619464299692]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26., -6.943003490909722}],
       RowBox[{"{", 
         RowBox[{"26.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29511481253365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.88018546723748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69859312781242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.728281700596741`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6847714431318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644123692063744`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26., "C", 
        Association[1 -> {
           Complex[163.29511481253365`, 14.88018546723748], 
           Complex[133.69859312781242`, -6.728281700596741]}, 2 -> {
           Complex[163.6847714431318, -15.021152078455035`], 
           Complex[133.7734876125809, -34.644123692063744`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.099999999999998`, -6.948032923355843}],
       RowBox[{"{", 
         RowBox[{"26.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29604080194576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183247`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6826620096745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.126989797234097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7691362108228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.74067895150922`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.29604080194576`, 14.985928225471852`], 
           Complex[133.69984356428586`, -6.631277315183247]}, 2 -> {
           Complex[163.6826620096745, -15.126989797234097`], 
           Complex[133.7691362108228, -34.74067895150922]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.2, -6.952665008458321}],
       RowBox[{"{", 
         RowBox[{"26.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29693169830156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.5356061437843405`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.68059894464983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.231414948770267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76484094632082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.2, "C", 
        Association[1 -> {
           Complex[163.29693169830156`, 15.090259348061176`], 
           Complex[133.70105197999624`, -6.5356061437843405`]}, 2 -> {
           Complex[163.68059894464983`, -15.231414948770267`], 
           Complex[133.76484094632082`, -34.83589932329275]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.299999999999997`, -6.956924878761477}],
       RowBox[{"{", 
         RowBox[{"26.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.29778916860275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.193218056900896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764474`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.67858038136492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.334466771459132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.29778916860275`, 15.193218056900896`], 
           Complex[133.70222021135814`, -6.441230995764474]}, 2 -> {
           Complex[163.67858038136492`, -15.334466771459132`], 
           Complex[133.76059975888245`, -34.92982202117593]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.399999999999995`, -6.960836947971369}],
       RowBox[{"{", 
         RowBox[{"26.399999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2986147775331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.29484189879971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010088`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.67660456069984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.399999999999995`, "C", 
        Association[1 -> {
           Complex[163.2986147775331, 15.29484189879971], 
           Complex[133.7033499865708, -6.348116269010088]}, 2 -> {
           Complex[163.67660456069984`, -15.436182828175923`], 
           Complex[133.75641070218487`, -35.02248266985033]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.499999999999996`, -6.9644247969692445`}],
       RowBox[{"{", 
         RowBox[{"26.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.2994099952287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.395166842334241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.67466982315278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.53659910314539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.2994099952287, 15.395166842334241`], 
           Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
           Complex[163.67466982315278`, -15.53659910314539], 
           Complex[133.75227193555395`, -35.1139153967292]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.599999999999998`, -6.9677110839315555`}],
       RowBox[{"{", 
         RowBox[{"26.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3001762043455`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.494227367644923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493565`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.67277460159679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7481817164674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.204152917056646`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.3001762043455, 15.494227367644923`], 
           Complex[133.70550058771101`, -6.165533069493565]}, 2 -> {
           Complex[163.67277460159679`, -15.635750091752156`], 
           Complex[133.7481817164674, -35.204152917056646`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.699999999999996`, -6.970717476687782}],
       RowBox[{"{", 
         RowBox[{"26.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30091470649666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769498`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.076000541975269`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.67091741467345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.733668883910747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.293226612919796`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.30091470649666`, 15.592056549792122`], 
           Complex[133.70652439769498`, -6.076000541975269]}, 2 -> {
           Complex[163.67091741467345`, -15.733668883910747`], 
           Complex[133.74413839370675`, -35.293226612919796`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.799999999999997`, -6.973464605232962}],
       RowBox[{"{", 
         RowBox[{"26.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30162672812602`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70751573240688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.987600173789694`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6690968607587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.830387241551286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.30162672812602`, 15.688686136228515`], 
           Complex[133.70751573240688`, -5.987600173789694]}, 2 -> {
           Complex[163.6690968607587, -15.830387241551286`], 
           Complex[133.74014040109287`, -35.38116660668967]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{26.9, -6.975972032199774}],
       RowBox[{"{", 
         RowBox[{"26.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30231342587385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.784146618887455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.9003030540343815`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6673116124424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.925935670720543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73618625174637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.46800182936364`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {26.9, "C", 
        Association[1 -> {
           Complex[163.30231342587385`, 15.784146618887455`], 
           Complex[133.70847588612014`, -5.9003030540343815`]}, 2 -> {
           Complex[163.6673116124424, -15.925935670720543`], 
           Complex[133.73618625174637`, -35.46800182936364]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27., -6.978258239068285}],
       RowBox[{"{", 
         RowBox[{"27.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30297589148626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.66556041147118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27., "C", 
        Association[1 -> {
           Complex[163.30297589148626`, 15.878467301338127`], 
           Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
           Complex[163.66556041147118`, -16.02034348874923], 
           Complex[133.73227453282152`, -35.553760084235876`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.1, -6.980340625933153}],
       RowBox[{"{", 
         RowBox[{"27.1`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3036151563131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.971676361413378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71030748519513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.728908493102031`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6638420641087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.11363888689164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.1, "C", 
        Association[1 -> {
           Complex[163.3036151563131, 15.971676361413378`], 
           Complex[133.71030748519513`, -5.728908493102031]}, 2 -> {
           Complex[163.6638420641087, -16.11363888689164], 
           Complex[133.72840390066767`, -35.63846810627997]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.2, -6.982235522742103}],
       RowBox[{"{", 
         RowBox[{"27.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30423219543457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.64475863285114`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.66215543687335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.2, "C", 
        Association[1 -> {
           Complex[163.30423219543457`, 16.063800909678434`], 
           Complex[133.71118119033963`, -5.64475863285114]}, 2 -> {
           Complex[163.66215543687335`, -16.205848988805332`], 
           Complex[133.72457307637754`, -35.72215161759165]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.299999999999997`, -6.983958210051338}],
       RowBox[{"{", 
         RowBox[{"27.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30482793145168`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.154867044072365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7120282423221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.66049945261796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.296999905203638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72078084168677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.30482793145168`, 16.154867044072365`], 
           Complex[133.7120282423221, -5.561607075648972]}, 2 -> {
           Complex[163.66049945261796`, -16.296999905203638`], 
           Complex[133.72078084168677`, -35.80483537920644]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.4, -6.985522947500635}],
       RowBox[{"{", 
         RowBox[{"27.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30540323797229`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.24489990102471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022453`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.65887308691825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.387116784982247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71702603519051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.4, "C", 
        Association[1 -> {
           Complex[163.30540323797229`, 16.24489990102471], 
           Complex[133.71284963153286`, -5.479429991022453]}, 2 -> {
           Complex[163.65887308691825`, -16.387116784982247`], 
           Complex[133.71702603519051`, -35.88654323957749]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.499999999999993`, -6.986943008382346}],
       RowBox[{"{", 
         RowBox[{"27.499999999999993`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3059589428217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.33392370332042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71364629891158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.39820441529854`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.65727536474287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754884988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.967298179972964`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.499999999999993`, "C", 
        Association[1 -> {
           Complex[163.3059589428217, 16.33392370332042], 
           Complex[133.71364629891158`, -5.39820441529854]}, 2 -> {
           Complex[163.65727536474287`, -16.476223863094262`], 
           Complex[133.71330754884988`, -35.967298179972964`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.599999999999994`, -6.988230718856032}],
       RowBox[{"{", 
         RowBox[{"27.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3064958310019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.421961804962738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.65570535737885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702883`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.3064958310019, 16.421961804962738`], 
           Complex[133.71441913905537`, -5.317908209063045]}, 2 -> {
           Complex[163.65570535737885`, -16.564344505422593`], 
           Complex[133.70962432476176`, -36.04712235702883]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.699999999999996`, -6.98939750053692}],
       RowBox[{"{", 
         RowBox[{"27.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30701464742387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.5090367332606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249019`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.65416217958912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.65150125087593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267105`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.30701464742387`, 16.5090367332606], 
           Complex[133.71516900309246`, -5.238520017249019]}, 2 -> {
           Complex[163.65416217958912`, -16.65150125087593], 
           Complex[133.70597535216766`, -36.12603714267105]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.799999999999997`, -6.99045391535693}],
       RowBox[{"{", 
         RowBox[{"27.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30751609943115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6526449869827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.73771585091723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70235966468252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.20406316160487`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.30751609943115`, 16.595170228347317`], 
           Complex[133.71589670134117`, -5.160019231659067]}, 2 -> {
           Complex[163.6526449869827, -16.73771585091723], 
           Complex[133.70235966468252`, -36.20406316160487]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.9, -6.991409711757989}],
       RowBox[{"{", 
         RowBox[{"27.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30800085913484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71660300577298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6511529735775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.82300930670975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6987763377227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.28122032654667`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.9, "C", 
        Association[1 -> {
           Complex[163.30800085913484`, 16.680383280319464`], 
           Complex[133.71660300577298`, -5.082385955742662]}, 2 -> {
           Complex[163.6511529735775, -16.82300930670975], 
           Complex[133.6987763377227, -36.28122032654667]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{27.999999999999996`, -6.992273871426272}],
       RowBox[{"{", 
         RowBox[{"27.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30846956557582`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465146`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6496853695408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.90740190405787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861177`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.35752787136576`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {27.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.30846956557582`, 16.764696164168555`], 
           Complex[133.71728865229744`, -5.005600971465146]}, 2 -> {
           Complex[163.6496853695408, -16.90740190405787], 
           Complex[133.6952244861177, -36.35752787136576]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.099999999999998`, -6.993054655911657}],
       RowBox[{"{", 
         RowBox[{"28.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30892282672824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118656`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6482414390911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.990913246296902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228255`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.30892282672824`, 16.848128472663596`], 
           Complex[133.71795434288214`, -4.929645708118656]}, 2 -> {
           Complex[163.6482414390911, -16.990913246296902`], 
           Complex[133.69170326188944`, -36.43300438228255]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.2, -6.993759652598297}],
       RowBox[{"{", 
         RowBox[{"28.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30936122135927`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6468204785474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.073562285278378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6882118521846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50766782726147`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.2, "C", 
        Association[1 -> {
           Complex[163.30936122135927`, 16.93069914732912], 
           Complex[133.71860074752374`, -4.854502212938122]}, 2 -> {
           Complex[163.6468204785474, -17.073562285278378`], 
           Complex[133.6882118521846, -36.50766782726147]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.3, -6.994395819599885}],
       RowBox[{"{", 
         RowBox[{"28.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.30978530075578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396218`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.64542181451625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.155367350584477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.58153558372544`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.3, "C", 
        Association[1 -> {
           Complex[163.30978530075578`, 17.012426507651817`], 
           Complex[133.7192285060807, -4.780153123396218]}, 2 -> {
           Complex[163.64542181451625`, -17.155367350584477`], 
           Complex[133.68474947734978`, -36.58153558372544]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.399999999999995`, -6.994969529247376}],
       RowBox[{"{", 
         RowBox[{"28.399999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31019559032947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.64404480220196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.399999999999995`, "C", 
        Association[1 -> {
           Complex[163.31019559032947`, 17.093328278637614`], 
           Complex[133.71983822997944`, -4.70658164106197]}, 2 -> {
           Complex[163.64404480220196`, -17.236346177091548`], 
           Complex[133.68131538913536`, -36.65462446470535]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.499999999999996`, -6.995486609918283}],
       RowBox[{"{", 
         RowBox[{"28.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31059259111072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.173421616831476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72043050380475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.633771506916521`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.64268882383246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353258`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.31059259111072`, 17.173421616831476`], 
           Complex[133.72043050380475`, -4.633771506916521]}, 2 -> {
           Complex[163.64268882383246`, -17.31651593099673], 
           Complex[133.67790886901938`, -36.72695074353258]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.599999999999998`, -6.995952386026216}],
       RowBox[{"{", 
         RowBox[{"28.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31097678113926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.25272313490318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028415`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6413532871904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.31097678113926`, 17.25272313490318], 
           Complex[133.72100588678245`, -4.561706978028415]}, 2 -> {
           Complex[163.6413532871904, -17.395893234410227`], 
           Complex[133.6745292266415, -36.79853017717177]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.699999999999996`, -6.9963717160481025`}],
       RowBox[{"{", 
         RowBox[{"28.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3113486167611`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.331248924894496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72156491416428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.64003762424196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.47449418860847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67117579833888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.3113486167611, 17.331248924894496`], 
           Complex[133.72156491416428`, -4.490372805498023]}, 2 -> {
           Complex[163.64003762424196`, -17.47449418860847], 
           Complex[133.67117579833888`, -36.86937802828386]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.799999999999994`, -6.9967490285155485`}],
       RowBox[{"{", 
         RowBox[{"28.799999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31170853383765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.409014580215214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588025`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63874128985492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.552334396036265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.93950908610309`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.799999999999994`, "C", 
        Association[1 -> {
           Complex[163.31170853383765`, 17.409014580215214`], 
           Complex[133.72210809852083`, -4.419754213588025]}, 2 -> {
           Complex[163.63874128985492`, -17.552334396036265`], 
           Complex[133.66784794577543`, -36.93950908610309]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.899999999999995`, -6.9970883559372945`}],
       RowBox[{"{", 
         RowBox[{"28.899999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31205694887507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.48603521646938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6374637606001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.629428981138844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.008937686204405`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.899999999999995`, "C", 
        Association[1 -> {
           Complex[163.31205694887507`, 17.48603521646938], 
           Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
           Complex[163.6374637606001, -17.629428981138844`], 
           Complex[133.66454505465833`, -37.008937686204405`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{28.999999999999996`, -6.9973933666525765`}],
       RowBox[{"{", 
         RowBox[{"28.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31239426007943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.562325491186662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63620453362884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.70579261009809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {28.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.31239426007943`, 17.562325491186662`], 
           Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
           Complex[163.63620453362884`, -17.70579261009809], 
           Complex[133.66126653353433`, -37.07767772923182]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.099999999999998`, -6.997667394641541}],
       RowBox[{"{", 
         RowBox[{"29.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31272084834353`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.637899622528057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878537`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.634963125622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.781439509544892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.14574269865576`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.31272084834353`, 17.637899622528057`], 
           Complex[133.72364740379095`, -4.212050853878537]}, 2 -> {
           Complex[163.634963125622, -17.781439509544892`], 
           Complex[133.65801181266102`, -37.14574269865576]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.2, -6.997913467339556}],
       RowBox[{"{", 
         RowBox[{"29.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31303707817023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.712771407030306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061895`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63373907180392`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.85638348430743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.21314567761614`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.2, "C", 
        Association[1 -> {
           Complex[163.31303707817023`, 17.712771407030306`], 
           Complex[133.7241319288729, -4.144155620061895]}, 2 -> {
           Complex[163.63373907180392`, -17.85638348430743], 
           Complex[133.65478034294642`, -37.21314567761614]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.299999999999997`, -6.998134331518096}],
       RowBox[{"{", 
         RowBox[{"29.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3133432985372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996313`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63253192501676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.3133432985372, 17.786954236448395`], 
           Complex[133.72460287329903`, -4.076908528996313]}, 2 -> {
           Complex[163.63253192501676`, -17.93063793425935], 
           Complex[133.65157159495215`, -37.27989936491177]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.4, -6.998332477306674}],
       RowBox[{"{", 
         RowBox[{"29.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31363984370773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.86046111375152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.01029726309017`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63134125485357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6483850579582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.3460160901857`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.4, "C", 
        Association[1 -> {
           Complex[163.31363984370773`, 17.86046111375152], 
           Complex[133.72506063642794`, -4.01029726309017]}, 2 -> {
           Complex[163.63134125485357`, -18.004215870320166`], 
           Complex[133.6483850579582, -37.3460160901857]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.5, -6.998510160438676}],
       RowBox[{"{", 
         RowBox[{"29.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31392703399072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.93330466832352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9443098592571175`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.63016664684008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.07712992966061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.5, "C", 
        Association[1 -> {
           Complex[163.31392703399072`, 17.93330466832352], 
           Complex[133.72550560195975`, -3.9443098592571175`]}, 2 -> {
           Complex[163.63016664684008`, -18.07712992966061], 
           Complex[133.64522023907955`, -37.411507828356406`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.599999999999998`, -6.998669422809505}],
       RowBox[{"{", 
         RowBox[{"29.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31420517645438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.00549717041573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870841`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.878934695199984`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62900770166812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.31420517645438`, 18.00549717041573], 
           Complex[133.72593813870841`, -3.878934695199984]}, 2 -> {
           Complex[163.62900770166812`, -18.14939239015977], 
           Complex[133.64207666243678`, -37.47638621333928]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.699999999999996`, -6.998812111438651}],
       RowBox[{"{", 
         RowBox[{"29.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3144745655963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.077050544896366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72635860132817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.814160476362023`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62786403447276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.221015184158826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63895386837342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.54066255110091`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.3144745655963, 18.077050544896366`], 
           Complex[133.72635860132817`, -3.814160476362023]}, 2 -> {
           Complex[163.62786403447276`, -18.221015184158826`], 
           Complex[133.63895386837342`, -37.54066255110091]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.799999999999997`, -6.9989398959287}],
       RowBox[{"{", 
         RowBox[{"29.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31473548397335`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.14797638433758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.749976223506348`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62673527415205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208481`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.31473548397335`, 18.14797638433758], 
           Complex[133.72676733099715`, -3.749976223506348]}, 2 -> {
           Complex[163.62673527415205`, -18.292009911552334`], 
           Complex[133.6358514127178, -37.60434783208481]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.899999999999995`, -6.999054284514078}],
       RowBox[{"{", 
         RowBox[{"29.899999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31498820279393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62562106272594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63276886608713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.899999999999995`, "C", 
        Association[1 -> {
           Complex[163.31498820279393`, 18.21828596147894], 
           Complex[133.72716465606138`, -3.686371260886986]}, 2 -> {
           Complex[163.62562106272594`, -18.362387852255672`], 
           Complex[133.63276886608713`, -37.66745274304553]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{29.999999999999996`, -6.999156638791043}],
       RowBox[{"{", 
         RowBox[{"29.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3152329824754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.28799024110279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.62333520497781`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62452105473145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.43215997808431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322924`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.729987678324505`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {29.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.3152329824754, 18.28799024110279], 
           Complex[133.7275508926416, -3.62333520497781]}, 2 -> {
           Complex[163.62452105473145`, -18.43215997808431], 
           Complex[133.62970581322924`, -37.729987678324505`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.099999999999998`, -6.999248187218114}],
       RowBox[{"{", 
         RowBox[{"30.099999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3154700731691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.35709989135509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7279263452058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.5608579537275773`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6234349166525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.501336964078423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.791962750599865`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.099999999999998`, "C", 
        Association[1 -> {
           Complex[163.3154700731691, 18.35709989135509], 
           Complex[133.7279263452058, -3.5608579537275773`]}, 2 -> {
           Complex[163.6234349166525, -18.501336964078423`], 
           Complex[133.62666185240195`, -37.791962750599865`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.199999999999996`, -6.999330037473218}],
       RowBox[{"{", 
         RowBox[{"30.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31569971525462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6223623263809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.569929199304017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.31569971525462`, 18.425625294542865`], 
           Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
           Complex[163.6223623263809, -18.569929199304017`], 
           Complex[133.62363659478487`, -37.85338780113949]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.299999999999997`, -6.999403187750341}],
       RowBox[{"{", 
         RowBox[{"30.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31592213980636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6213029727077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.63794679715963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.620629663924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.31592213980636`, 18.493576557437454`], 
           Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
           Complex[163.6213029727077, -18.63794679715963], 
           Complex[133.620629663924, -37.91427240958484]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.4, -6.999468537074665}],
       RowBox[{"{", 
         RowBox[{"30.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31613756903312`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.56096352111073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581235`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.62025655484186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.705399605215987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61764069520532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.4, "C", 
        Association[1 -> {
           Complex[163.31613756903312`, 18.56096352111073], 
           Complex[133.72899087982017`, -3.376682017581235]}, 2 -> {
           Complex[163.62025655484186`, -18.705399605215987`], 
           Complex[133.61764069520532`, -37.974625903291766`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.5, -6.99952689471113}],
       RowBox[{"{", 
         RowBox[{"30.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3163462166933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.627795770329765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925613`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61922278195527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61466933535638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.03445736625228`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.5, "C", 
        Association[1 -> {
           Complex[163.3163462166933, 18.627795770329765`], 
           Complex[133.72932602622453`, -3.316344244925613]}, 2 -> {
           Complex[163.61922278195527`, -18.772297214614134`], 
           Complex[133.61466933535638`, -38.03445736625228]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.599999999999998`, -6.9995789887372055`}],
       RowBox[{"{", 
         RowBox[{"30.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31654828848707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.694082642534067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7296517540468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61820137275217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.09377564761935`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.31654828848707`, 18.694082642534067`], 
           Complex[133.7296517540468, -3.25651864598262]}, 2 -> {
           Complex[163.61820137275217`, -18.838648969045266`], 
           Complex[133.61171524197408`, -38.09377564761935]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.699999999999996`, -6.999625473846427}],
       RowBox[{"{", 
         RowBox[{"30.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31674398242674`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.197196607875771`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61719205506083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6087780830763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.152589369857864`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.31674398242674`, 18.75983323641723], 
           Complex[133.72996830818994`, -3.197196607875771]}, 2 -> {
           Complex[163.61719205506083`, -18.904463973336576`], 
           Complex[133.6087780830763, -38.152589369857864`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.799999999999997`, -6.999666938445119}],
       RowBox[{"{", 
         RowBox[{"30.799999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31693348918697`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.82505642013447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138369736463453`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6161945654476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.969751101660396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.799999999999997`, "C", 
        Association[1 -> {
           Complex[163.31693348918697`, 18.82505642013447], 
           Complex[133.73027592511528`, -3.138369736463453]}, 2 -> {
           Complex[163.6161945654476, -18.969751101660396`], 
           Complex[133.60585753667738`, -38.210906936538066`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.9, -6.999703911100574}],
       RowBox[{"{", 
         RowBox[{"30.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31711699243615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.88976083915551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.080029848884582`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61520864885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.034519005391328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.26873653979493`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.9, "C", 
        Association[1 -> {
           Complex[163.31711699243615`, 18.88976083915551], 
           Complex[133.73057483320838`, -3.080029848884582]}, 2 -> {
           Complex[163.61520864885, -19.034519005391328`], 
           Complex[133.60295329038402`, -38.26873653979493]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{30.999999999999993`, -6.999736866395001}],
       RowBox[{"{", 
         RowBox[{"30.999999999999993`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31729466915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.953954923781044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234717`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61423405822947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.09877612062455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.32608616746591`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {30.999999999999993`, "C", 
        Association[1 -> {
           Complex[163.31729466915, 18.953954923781044`], 
           Complex[133.7308652531255, -3.0221689664234717`]}, 2 -> {
           Complex[163.61423405822947`, -19.09877612062455], 
           Complex[133.60006504101256`, -38.32608616746591]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.099999999999994`, -6.999766230235693}],
       RowBox[{"{", 
         RowBox[{"31.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31746668990834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.017646896340647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9647793076770235`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.61327055424135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.16253067537683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992766`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.31746668990834`, 19.017646896340647`], 
           Complex[133.73114739812223`, -2.9647793076770235`]}, 2 -> {
           Complex[163.61327055424135`, -19.16253067537683], 
           Complex[133.59719249422423`, -38.38296360992766]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.199999999999996`, -6.999792384668199}],
       RowBox[{"{", 
         RowBox[{"31.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3176332191766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.080844778087723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.90785328200948`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6123179049217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.225790696484122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.4393764666446`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.3176332191766, 19.080844778087723`], 
           Complex[133.73142147436542`, -2.90785328200948]}, 2 -> {
           Complex[163.6123179049217, -19.225790696484122`], 
           Complex[133.59433536417916`, -38.4393764666446]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.299999999999997`, -6.999815672235732}],
       RowBox[{"{", 
         RowBox[{"31.299999999999997`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31779441557222`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.14355639580752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794664`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6113758853897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.299999999999997`, "C", 
        Association[1 -> {
           Complex[163.31779441557222`, 19.14355639580752], 
           Complex[133.73168768122898`, -2.8513834832794664`]}, 2 -> {
           Complex[163.6113758853897, -19.288564016212078`], 
           Complex[133.59149337320662`, -38.49533215244521]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.4, -6.999836399924792}],
       RowBox[{"{", 
         RowBox[{"31.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31795043211764`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.20578938815203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7953626838262657`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6104442775649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.35085827859341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353876`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.4, "C", 
        Association[1 -> {
           Complex[163.31795043211764`, 19.20578938815203], 
           Complex[133.73194621157515`, -2.7953626838262657`]}, 2 -> {
           Complex[163.6104442775649, -19.35085827859341], 
           Complex[133.58866625149176`, -38.55083790353876]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.499999999999996`, -6.999854842733777}],
       RowBox[{"{", 
         RowBox[{"31.499999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31810141648003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.26755121171575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287020946`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60952286989846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.605900783286515`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.499999999999996`, "C", 
        Association[1 -> {
           Complex[163.31810141648003`, 19.26755121171575], 
           Complex[133.73219725202154`, -2.7397838287020946`]}, 2 -> {
           Complex[163.60952286989846`, -19.41268094550624], 
           Complex[133.58585373677684`, -38.605900783286515`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.599999999999998`, -6.999871246898463}],
       RowBox[{"{", 
         RowBox[{"31.599999999999998`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31824751119916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6846400301384143`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60861145711593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.6605276877375`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.599999999999998`, "C", 
        Association[1 -> {
           Complex[163.31824751119916`, 19.328849146864805`], 
           Complex[133.73244098319515`, -2.6846400301384143`]}, 2 -> {
           Complex[163.60861145711593`, -19.47403930250476], 
           Complex[133.58305557407584`, -38.6605276877375]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.7, -6.999885832805462}],
       RowBox[{"{", 
         RowBox[{"31.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31838885390343`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7326775799737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60770983997617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.53494046441777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.71472535094414`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.7, "C", 
        Association[1 -> {
           Complex[163.31838885390343`, 19.389690303331637`], 
           Complex[133.7326775799737, -2.6299245622347733`]}, 2 -> {
           Complex[163.60770983997617`, -19.53494046441777], 
           Complex[133.58027151540554`, -38.71472535094414]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.8, -6.9998987976221665`}],
       RowBox[{"{", 
         RowBox[{"31.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31852557751546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60681782503693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.59539138072089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.8, "C", 
        Association[1 -> {
           Complex[163.31852557751546`, 19.45008162558661], 
           Complex[133.73290721171557`, -2.5756308558594796`]}, 2 -> {
           Complex[163.60681782503693`, -19.59539138072089], 
           Complex[133.57750131952452`, -38.76850035006301]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.899999999999995`, -6.999910317669357}],
       RowBox[{"{", 
         RowBox[{"31.899999999999995`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3186578104471`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.510029897997104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.521752493751901`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60593522443511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.65539884069858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.821859110255915`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.899999999999995`, "C", 
        Association[1 -> {
           Complex[163.3186578104471, 19.510029897997104`], 
           Complex[133.73313004247825`, -2.521752493751901]}, 2 -> {
           Complex[163.60593522443511`, -19.65539884069858], 
           Complex[133.57474475168777`, -38.821859110255915`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{31.999999999999996`, -6.999920550560357}],
       RowBox[{"{", 
         RowBox[{"31.999999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31878567678518`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.56954174978439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.468283205816789`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6050618556758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.71496947840288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939813`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {31.999999999999996`, "C", 
        Association[1 -> {
           Complex[163.31878567678518`, 19.56954174978439], 
           Complex[133.73334623122685`, -2.468283205816789]}, 2 -> {
           Complex[163.6050618556758, -19.71496947840288], 
           Complex[133.57200158341104`, -38.87480790939813]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.099999999999994`, -6.999929637128603}],
       RowBox[{"{", 
         RowBox[{"32.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3189092964682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.628623659787667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73355593203246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.415216864601611`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60419754143146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260375`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.3189092964682, 19.628623659787667`], 
           Complex[133.73355593203246`, -2.415216864601611]}, 2 -> {
           Complex[163.60419754143146`, -19.774109777419557`], 
           Complex[133.5692715922459, -38.92735288260375]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.199999999999996`, -6.999937703163588}],
       RowBox[{"{", 
         RowBox[{"32.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31902878545432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.362547480948237`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.6033421093502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.832826075450342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.979500026576446`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.31902878545432`, 19.687281961044494`], 
           Complex[133.73375929426132`, -2.362547480948237]}, 2 -> {
           Complex[163.6033421093502, -19.832826075450342`], 
           Complex[133.56655456156514`, -38.979500026576446`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.3, -6.999944860973354}],
       RowBox[{"{", 
         RowBox[{"32.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31914425588116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3102691998110743`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60249539187296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.3, "C", 
        Association[1 -> {
           Complex[163.31914425588116`, 19.74552284519583], 
           Complex[133.73395646275486`, -2.3102691998110743`]}, 2 -> {
           Complex[163.60249539187296`, -19.891124568720002`], 
           Complex[133.5638502803574, -39.03125520379385]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.4, -6.999951210790131}],
       RowBox[{"{", 
         RowBox[{"32.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31925581621843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.80335236672411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60165722605888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.94901131621615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.4, "C", 
        Association[1 -> {
           Complex[163.31925581621843`, 19.80335236672411], 
           Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
           Complex[163.60165722605888`, -19.94901131621615], 
           Complex[133.56115854303107`, -39.08262414653326]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.49999999999999, -6.999956842034182}],
       RowBox[{"{", 
         RowBox[{"32.49999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31936357141305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.860776447031697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.206863171477252`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60082745341847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.00649224376953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55847914922663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.49999999999999, "C", 
        Association[1 -> {
           Complex[163.31936357141305`, 19.860776447031697`], 
           Complex[133.73433277630326`, -2.206863171477252]}, 2 -> {
           Complex[163.60082745341847`, -20.00649224376953], 
           Complex[133.55847914922663`, -39.133612460745795`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.599999999999994`, -6.999961834449588}],
       RowBox[{"{", 
         RowBox[{"32.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31946762302746`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.91780087836711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.60000591975424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.06357314798203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.31946762302746`, 19.91780087836711], 
           Complex[133.73451218992716`, -2.155724349292754]}, 2 -> {
           Complex[163.60000591975424`, -20.06357314798203], 
           Complex[133.55581190363702`, -39.18422562978594]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.699999999999996`, -6.999966259124438}],
       RowBox[{"{", 
         RowBox[{"32.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31956806937163`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59919247500852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.12025970000922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800312`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.31956806937163`, 19.97443132760581], 
           Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
           Complex[163.59919247500852`, -20.12025970000922], 
           Complex[133.55315661583612`, -39.23446901800312]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.8, -6.999970179406722}],
       RowBox[{"{", 
         RowBox[{"32.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.319665005629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.030673339891987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7348541729491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0545482986917456`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59838697311696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.8, "C", 
        Association[1 -> {
           Complex[163.319665005629, 20.030673339891987`], 
           Complex[133.7348541729491, -2.0545482986917456`]}, 2 -> {
           Complex[163.59838697311696`, -20.176557449202846`], 
           Complex[133.55051310011325`, -39.28434787420011]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{32.9, -6.999973651726196}],
       RowBox[{"{", 
         RowBox[{"32.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31975852397647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7350169880388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.00450069857931`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5975892718708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232471826623705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968495`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {32.9, "C", 
        Association[1 -> {
           Complex[163.31975852397647`, 20.086532342147553`], 
           Complex[133.7350169880388, -2.00450069857931]}, 2 -> {
           Complex[163.5975892718708, -20.232471826623705`], 
           Complex[133.54788117531726`, -39.333867334968495`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33., -6.999976726331536}],
       RowBox[{"{", 
         RowBox[{"33.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.31984871369912`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73517451010144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59679923278136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54526066470336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33., "C", 
        Association[1 -> {
           Complex[163.31984871369912`, 20.14201364645422], 
           Complex[133.73517451010144`, -1.9548066511051871`]}, 2 -> {
           Complex[163.59679923278136`, -20.288008148422218`], 
           Complex[133.54526066470336`, -39.3830324278985]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.099999999999994`, -6.999979447951171}],
       RowBox[{"{", 
         RowBox[{"33.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3199356612996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.197122453313998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9054612411862166`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59601672095425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.3199356612996, 20.197122453313998`], 
           Complex[133.73532685336215`, -1.9054612411862166`]}, 2 -> {
           Complex[163.59601672095425`, -20.343171619103263`], 
           Complex[133.54265139579022`, -39.43184807467881]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.199999999999996`, -6.99998185638546}],
       RowBox[{"{", 
         RowBox[{"33.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.320019450603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608618`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59524160496576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.397967334670057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.480319094081715`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.320019450603, 20.251863854793616`], 
           Complex[133.73547412881845`, -1.8564596565608618`]}, 2 -> {
           Complex[163.59524160496576`, -20.397967334670057`], 
           Complex[133.54005320021986`, -39.480319094081715`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.3, -6.9999839870370755`}],
       RowBox[{"{", 
         RowBox[{"33.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32010016285645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.3062428375576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849099015`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59447375674608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.45240028565977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484526`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.3, "C", 
        Association[1 -> {
           Complex[163.32010016285645`, 20.3062428375576], 
           Complex[133.73561644435446`, -1.8077971849099015`]}, 2 -> {
           Complex[163.59447375674608`, -20.45240028565977], 
           Complex[133.53746591362483`, -39.52845020484526]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.39999999999999, -6.999985871385845}],
       RowBox[{"{", 
         RowBox[{"33.39999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32017787682477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781658`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5937130514674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.506475360070965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.576246028452815`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.39999999999999, "C", 
        Association[1 -> {
           Complex[163.32017787682477`, 20.360264285794972`], 
           Complex[133.73575390485036`, -1.7594692110781658`]}, 2 -> {
           Complex[163.5937130514674, -20.506475360070965`], 
           Complex[133.53488937550074`, -39.576246028452815`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.49999999999999, -6.999987537413677}],
       RowBox[{"{", 
         RowBox[{"33.49999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.320252668882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931463`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5929593674352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.5601973461902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.6237110918168`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.49999999999999, "C", 
        Association[1 -> {
           Complex[163.320252668882, 20.413932984043882`], 
           Complex[133.7358866122874, -1.7114712143931463`]}, 2 -> {
           Complex[163.5929593674352, -20.5601973461902], 
           Complex[133.53232342908268`, -39.6237110918168]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.599999999999994`, -6.9999890099846525`}],
       RowBox[{"{", 
         RowBox[{"33.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32032461309848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763436`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59221258598674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52976792122885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.32032461309848`, 20.467253619918555`], 
           Complex[133.73601466584807`, -1.6637987660763436`]}, 2 -> {
           Complex[163.59221258598674`, -20.613570935319654`], 
           Complex[133.52976792122885`, -39.67084982986853]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.699999999999996`, -6.999990311184866}],
       RowBox[{"{", 
         RowBox[{"33.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32039378132473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73613816201268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59147259138922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.666600724412163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658805997`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.32039378132473`, 20.52023078674261], 
           Complex[133.73613816201268`, -1.6164475267435492`]}, 2 -> {
           Complex[163.59147259138922`, -20.666600724412163`], 
           Complex[133.527222702305, -39.71766658805997]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.8, -6.999991460626152}],
       RowBox[{"{", 
         RowBox[{"33.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32046024327133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59073927074817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.71929121861588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5246876260788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.76416562477979`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.8, "C", 
        Association[1 -> {
           Complex[163.32046024327133`, 20.57286898609253], 
           Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
           Complex[163.59073927074817`, -20.71929121861588], 
           Complex[133.5246876260788, -39.76416562477979]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{33.9, -6.99999247571742}],
       RowBox[{"{", 
         RowBox[{"33.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3205240665855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.625172630255136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597743`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.59001251391317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {33.9, "C", 
        Association[1 -> {
           Complex[163.3205240665855, 20.625172630255136`], 
           Complex[133.73637185511262`, -1.5226917500597743`]}, 2 -> {
           Complex[163.59001251391317`, -20.771646833732525`], 
           Complex[133.52216254961237`, -39.81035111368739]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34., -6.999993371906956}],
       RowBox[{"{", 
         RowBox[{"34.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32058531692476`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.677146044602367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7364822323083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4762789595872228`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58929221339187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.823671898594245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51964733316362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.856227145969456`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34., "C", 
        Association[1 -> {
           Complex[163.32058531692476`, 20.677146044602367`], 
           Complex[133.7364822323083, -1.4762789595872228`]}, 2 -> {
           Complex[163.58929221339187`, -20.823671898594245`], 
           Complex[133.51964733316362`, -39.856227145969456`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.1, -6.999994162898704}],
       RowBox[{"{", 
         RowBox[{"34.1`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3206440580269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.728793469886885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222517`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58857826426507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.875370657359298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51714184008853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.901797732519626`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.1, "C", 
        Association[1 -> {
           Complex[163.3206440580269, 20.728793469886885`], 
           Complex[133.7365884127948, -1.4301708674222517`]}, 2 -> {
           Complex[163.58857826426507`, -20.875370657359298`], 
           Complex[133.51714184008853`, -39.901797732519626`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.2, -6.99999486084525}],
       RowBox[{"{", 
         RowBox[{"34.2`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32070035177745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.780119064461577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73669048085137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3843635465213247`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5878705641061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.926747271733444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51464593674876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.9470668060475`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.2, "C", 
        Association[1 -> {
           Complex[163.32070035177745`, 20.780119064461577`], 
           Complex[133.73669048085137`, -1.3843635465213247`]}, 2 -> {
           Complex[163.5878705641061, -20.926747271733444`], 
           Complex[133.51464593674876`, -39.9470668060475]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.3, -6.999995476519942}],
       RowBox[{"{", 
         RowBox[{"34.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32075425827455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3388531459104875`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58716901290316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51215949242192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.99203822311737`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.3, "C", 
        Association[1 -> {
           Complex[163.32075425827455`, 20.831126906426018`], 
           Complex[133.7367885185553, -1.3388531459104875`]}, 2 -> {
           Complex[163.58716901290316`, -20.977805823117315`], 
           Complex[133.51215949242192`, -39.99203822311737]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.39999999999999, -6.999996019470352}],
       RowBox[{"{", 
         RowBox[{"34.39999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3208058358904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.881820995702782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714526`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58647351298407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.028550314683574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50968237921512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.03671576612024`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.39999999999999, "C", 
        Association[1 -> {
           Complex[163.3208058358904, 20.881820995702782`], 
           Complex[133.73688260585354`, -1.293635888714526]}, 2 -> {
           Complex[163.58647351298407`, -21.028550314683574`], 
           Complex[133.50968237921512`, -40.03671576612024]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.49999999999999, -6.999996498155038}],
       RowBox[{"{", 
         RowBox[{"34.49999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32085514133112`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73697282063236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.248708070250089`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58578396894472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.49999999999999, "C", 
        Association[1 -> {
           Complex[163.32085514133112`, 20.9322052560464], 
           Complex[133.73697282063236`, -1.248708070250089]}, 2 -> {
           Complex[163.58578396894472`, -21.078984673387104`], 
           Complex[133.50721447198234`, -40.0811031451823]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.599999999999994`, -6.99999692006539}],
       RowBox[{"{", 
         RowBox[{"34.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32090222969342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.982283536987506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803698`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5851002875799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.12911275191012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001161`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.32090222969342`, 20.982283536987506`], 
           Complex[133.73705923878364`, -1.2040660561803698`]}, 2 -> {
           Complex[163.5851002875799, -21.12911275191012], 
           Complex[133.50475564824438`, -40.12520400001161]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.699999999999996`, -6.999997291834125}],
       RowBox[{"{", 
         RowBox[{"34.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32094715451944`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.03205961571474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288623`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58442237781642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.32094715451944`, 21.03205961571474], 
           Complex[133.7371419342688, -1.1597062807288623`]}, 2 -> {
           Complex[163.58442237781642`, -21.178938330545062`], 
           Complex[133.50230578811164`, -40.16902190168558]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.8, -6.999997619331883}],
       RowBox[{"{", 
         RowBox[{"34.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32098996784921`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7372209791803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1156252449499178`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58375015064937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.228465119017653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.8, "C", 
        Association[1 -> {
           Complex[163.32098996784921`, 21.081537198896875`], 
           Complex[133.7372209791803, -1.1156252449499178`]}, 2 -> {
           Complex[163.58375015064937`, -21.228465119017653`], 
           Complex[133.49986477421018`, -40.21256035438178]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{34.9, -6.99999790775318}],
       RowBox[{"{", 
         RowBox[{"34.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32103072027124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.13071992444728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054024`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5830835190799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {34.9, "C", 
        Association[1 -> {
           Complex[163.32103072027124`, 21.13071992444728], 
           Complex[133.73729644380091`, -1.071819515054024]}, 2 -> {
           Complex[163.5830835190799, -21.277696758252304`], 
           Complex[133.4974324916098, -40.25582279705388]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35., -6.9999981616928615`}],
       RowBox[{"{", 
         RowBox[{"35.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32106946097053`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58242239805642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35., "C", 
        Association[1 -> {
           Complex[163.32106946097053`, 21.179611363233054`], 
           Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
           Complex[163.58242239805642`, -21.32663682208221], 
           Complex[133.49500882775536`, -40.29881260505506]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.1, -6.999998385214099}],
       RowBox[{"{", 
         RowBox[{"35.1`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32110623777564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58176670441676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.37528881890603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.341533091710815`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.1, "C", 
        Association[1 -> {
           Complex[163.32110623777564`, 21.228215020730886`], 
           Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
           Complex[163.58176670441676`, -21.37528881890603], 
           Complex[133.49259367239995`, -40.341533091710815`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.199999999999996`, -6.999998581908814}],
       RowBox[{"{", 
         RowBox[{"35.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32114109720294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.27653433863163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983327`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58111635683326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.383987509842974`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.32114109720294`, 21.27653433863163], 
           Complex[133.73750203277484`, -0.9420207663983327]}, 2 -> {
           Complex[163.58111635683326`, -21.423656193293354`], 
           Complex[133.49018691754077`, -40.383987509842974`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.3, -6.999998754951393}],
       RowBox[{"{", 
         RowBox[{"35.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3211740844998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.324572696395432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7375638448069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8992831695357282`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.58047127575952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.471742327540692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48778845735708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.3, "C", 
        Association[1 -> {
           Complex[163.3211740844998, 21.324572696395432`], 
           Complex[133.7375638448069, -0.8992831695357282]}, 2 -> {
           Complex[163.58047127575952`, -21.471742327540692`], 
           Complex[133.48778845735708`, -40.4261790532468]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.4, -6.9999989071463755`}],
       RowBox[{"{", 
         RowBox[{"35.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32120524368585`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064777`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57983138337912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.519550543179967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.46811085812299`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.4, "C", 
        Association[1 -> {
           Complex[163.32120524368585`, 21.372333412759414`], 
           Complex[133.73762240273044`, -0.8568046319064777]}, 2 -> {
           Complex[163.57983138337912`, -21.519550543179967`], 
           Complex[133.4853981881505, -40.46811085812299]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.49999999999999, -6.99999904097082}],
       RowBox[{"{", 
         RowBox[{"35.49999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32123461759284`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.419819747199476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73767776709124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8145820782986561`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57919660355603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.56708410244111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4830160082869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.50978600446605`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.49999999999999, "C", 
        Association[1 -> {
           Complex[163.32123461759284`, 21.419819747199476`], 
           Complex[133.73767776709124`, -0.8145820782986561]}, 2 -> {
           Complex[163.57919660355603`, -21.56708410244111], 
           Complex[133.4830160082869, -40.50978600446605]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.599999999999994`, -6.999999158611898}],
       RowBox[{"{", 
         RowBox[{"35.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32126224790258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.467034901348015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003074`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57856686178704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741091`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.32126224790258`, 21.467034901348015`], 
           Complex[133.73772999698105`, -0.7726124883003074]}, 2 -> {
           Complex[163.57856686178704`, -21.61434620967065], 
           Complex[133.48064181814095`, -40.55120751741091]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.699999999999996`, -6.999999262000254}],
       RowBox[{"{", 
         RowBox[{"35.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32128817518404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.513982020369067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944153`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57794208515563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.661340012707413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.32128817518404`, 21.513982020369067`], 
           Complex[133.73777915008168`, -0.7308928949944153]}, 2 -> {
           Complex[163.57794208515563`, -21.661340012707413`], 
           Complex[133.47827552004196`, -40.592378368538746`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.8, -6.9999993528396045`}],
       RowBox[{"{", 
         RowBox[{"35.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32131243892846`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927915`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5773222022874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.70806860421745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.63330147714419`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.8, "C", 
        Association[1 -> {
           Complex[163.32131243892846`, 21.560664194292514`], 
           Complex[133.73782528270672`, -0.6894203836927915]}, 2 -> {
           Complex[163.5773222022874, -21.70806860421745], 
           Complex[133.47591701822174`, -40.63330147714419]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.9, -6.9999994326329755`}],
       RowBox[{"{", 
         RowBox[{"35.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32133507758377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5767071433079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.67397971146615`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.9, "C", 
        Association[1 -> {
           Complex[163.32133507758377`, 21.60708445930873], 
           Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
           Complex[163.5767071433079, -21.754535022990805`], 
           Complex[133.47356621876492`, -40.67397971146615]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{35.99999999999999, -6.999999502705963}],
       RowBox[{"{", 
         RowBox[{"35.99999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32135612858696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57609683979973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.800742255195683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.714415889878296`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {35.99999999999999, "C", 
        Association[1 -> {
           Complex[163.32135612858696`, 21.653245799025118`], 
           Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
           Complex[163.57609683979973`, -21.800742255195683`], 
           Complex[133.47122302955884`, -40.714415889878296`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.099999999999994`, -6.999999564227353}],
       RowBox[{"{", 
         RowBox[{"36.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32137562839594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154928`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5754912247639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.846693235601716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.754612782050174`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.32137562839594`, 21.699151145685878`], 
           Complex[133.73794610118625`, -0.5664569528154928]}, 2 -> {
           Complex[163.5754912247639, -21.846693235601716`], 
           Complex[133.46888736024792`, -40.754612782050174`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.199999999999996`, -6.999999618227375}],
       RowBox[{"{", 
         RowBox[{"36.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32139361252007`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758959`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57489023258069`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007123`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.32139361252007`, 21.74480338135633], 
           Complex[133.73798068907436`, -0.5259446249758959]}, 2 -> {
           Complex[163.57489023258069`, -21.89239084876425], 
           Complex[133.46655912218745`, -40.79457311007123]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.3, -6.999999665613876}],
       RowBox[{"{", 
         RowBox[{"36.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32141011554913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.79020533907295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715783`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57429379897212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4642382283995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.83429954954242`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.3, "C", 
        Association[1 -> {
           Complex[163.32141011554913`, 21.79020533907295], 
           Complex[133.73801251890455`, -0.4856655473715783]}, 2 -> {
           Complex[163.57429379897212`, -21.937837930174453`], 
           Complex[133.4642382283995, -40.83429954954242]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.4, -6.999999707186639}],
       RowBox[{"{", 
         RowBox[{"36.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32142517118197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100126`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57370186096605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.4, "C", 
        Association[1 -> {
           Complex[163.32142517118197`, 21.835359803960376`], 
           Complex[133.73804163958545`, -0.4456170941100126]}, 2 -> {
           Complex[163.57370186096605`, -21.983037267377455`], 
           Complex[133.46192459353048`, -40.87379473063754]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.5, -6.999999743650046}],
       RowBox[{"{", 
         RowBox[{"36.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32143881225352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836443967`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57311435686128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.45961813380987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.913061239133484`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.5, "C", 
        Association[1 -> {
           Complex[163.32143881225352`, 21.880269514316595`], 
           Complex[133.73806809891312`, -0.4057966836443967]}, 2 -> {
           Complex[163.57311435686128`, -22.027991601058], 
           Complex[133.45961813380987`, -40.913061239133484`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.6, -6.999999775624294}],
       RowBox[{"{", 
         RowBox[{"36.6`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32145107076096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.924937162667188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360263`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36620177777334817`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57253122619372`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.072703626095407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.6, "C", 
        Association[1 -> {
           Complex[163.32145107076096`, 21.924937162667188`], 
           Complex[133.73809194360263`, -0.36620177777334817`]}, 2 -> {
           Complex[163.57253122619372`, -22.072703626095407`], 
           Complex[133.45731876701024`, -40.95210161741164]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.699999999999996`, -6.999999803655304}],
       RowBox[{"{", 
         RowBox[{"36.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214619778895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.96936539678994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73811321931896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3268298806687504`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5719524097037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.117175992588685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543069`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.3214619778895, 21.96936539678994], 
           Complex[133.73811321931896`, -0.3268298806687504]}, 2 -> {
           Complex[163.5719524097037, -22.117175992588685`], 
           Complex[133.45502641240844`, -40.99091836543069]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.79999999999999, -6.999999828223487}],
       RowBox[{"{", 
         RowBox[{"36.79999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.321471564036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.01355682071051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070584`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28767853793105047`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57137784930458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.16141130685297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.02951394167229`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.79999999999999, "C", 
        Association[1 -> {
           Complex[163.321471564036, 22.01355682071051], 
           Complex[133.73813197070584`, -0.28767853793105047`]}, 2 -> {
           Complex[163.57137784930458`, -22.16141130685297], 
           Complex[133.45274099074845`, -41.02951394167229]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.89999999999999, -6.999999849751493}],
       RowBox[{"{", 
         RowBox[{"36.89999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32147985883367`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.05751399567081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141522`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.24874533567052026`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.57080748805203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.0678907640604`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.89999999999999, "C", 
        Association[1 -> {
           Complex[163.32147985883367`, 22.05751399567081], 
           Complex[133.73814824141522`, -0.24874533567052026`]}, 2 -> {
           Complex[163.57080748805203`, -22.205412132388133`], 
           Complex[133.45046242420474`, -41.0678907640604]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{36.99999999999999, -6.999999868611054}],
       RowBox[{"{", 
         RowBox[{"36.99999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32148689117372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816207413375`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.21002789961483614`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5702412701146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085482`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {36.99999999999999, "C", 
        Association[1 -> {
           Complex[163.32148689117372`, 22.101239441069634`], 
           Complex[133.73816207413375`, -0.21002789961483614`]}, 2 -> {
           Complex[163.5702412701146, -22.249180990820484`], 
           Complex[133.44819063634753`, -41.10605121085482]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.099999999999994`, -6.999999885129037}],
       RowBox[{"{", 
         RowBox[{"37.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214926892273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.14473563537842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.17152389424024506`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56967914074468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.292720362818727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4459255521081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.3214926892273, 22.14473563537842], 
           Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
           Complex[163.56967914074468`, -22.292720362818727`], 
           Complex[133.4459255521081, -41.14399762152054]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.199999999999996`, -6.999999899592775}],
       RowBox[{"{", 
         RowBox[{"37.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214972804685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.188005017031273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.13323102192725855`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56912104625172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.3214972804685, 22.188005017031273`], 
           Complex[133.73818259167945`, -0.13323102192725855`]}, 2 -> {
           Complex[163.56912104625172`, -22.33603268898435], 
           Complex[133.4436670977467, -41.18173229757264]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.3, -6.99999991225479}],
       RowBox[{"{", 
         RowBox[{"37.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150069169228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09514702213937554`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56856693397444`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.379120370718276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.219257503398715`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.3, "C", 
        Association[1 -> {
           Complex[163.32150069169228`, 22.231049985290607`], 
           Complex[133.73818935729176`, -0.09514702213937554]}, 2 -> {
           Complex[163.56856693397444`, -22.379120370718276`], 
           Complex[133.44141520081965`, -41.219257503398715`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.4, -6.999999923336948}],
       RowBox[{"{", 
         RowBox[{"37.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150294903576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.27387290108978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381938465315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05726967062375721`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56801675225492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.42198577106388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.4, "C", 
        Association[1 -> {
           Complex[163.32150294903576`, 22.27387290108978], 
           Complex[133.7381938465315, -0.05726967062375721]}, 2 -> {
           Complex[163.56801675225492`, -22.42198577106388], 
           Complex[133.43916979014838`, -41.25657546705884]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.5, -6.999999933034132}],
       RowBox[{"{", 
         RowBox[{"37.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150407799693`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.019596778633637513`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56747045041436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.4646312155268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.29368838106346`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.5, "C", 
        Association[1 -> {
           Complex[163.32150407799693`, 22.316476087852756`], 
           Complex[133.73819609764354`, -0.019596778633637513`]}, 2 -> {
           Complex[163.56747045041436`, -22.4646312155268], 
           Complex[133.4369307957903, -41.29368838106346]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.6, -6.999999941517479}],
       RowBox[{"{", 
         RowBox[{"37.6`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150410345304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.017873807828369337`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56692797872756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.50705899287356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900826`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.6, "C", 
        Association[1 -> {
           Complex[163.32150410345304`, 22.358861832291833`], 
           Complex[133.73819614805504`, 0.017873807828369337`]}, 2 -> {
           Complex[163.56692797872756`, -22.50705899287356], 
           Complex[133.43469814900826`, -41.330598403131276`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.7, -6.999999948937235}],
       RowBox[{"{", 
         RowBox[{"37.7`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150304967848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.40103238518414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.05514420874688142`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56638928839993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4324717822431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.36730765692628`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.7, "C", 
        Association[1 -> {
           Complex[163.32150304967848`, 22.40103238518414], 
           Complex[133.73819403439737`, 0.05514420874688142]}, 2 -> {
           Complex[163.56638928839993`, -22.549271355908424`], 
           Complex[133.4324717822431, -41.36730765692628]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.8, -6.999999955425276}],
       RowBox[{"{", 
         RowBox[{"37.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32150094036191`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.09221651081071514`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56585433154422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.59127052222966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.403818232775386`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.8, "C", 
        Association[1 -> {
           Complex[163.32150094036191`, 22.442989962127523`], 
           Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
           Complex[163.56585433154422`, -22.59127052222966], 
           Complex[133.43025162908577`, -41.403818232775386`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.89999999999999, -6.9999999610973145`}],
       RowBox[{"{", 
         RowBox[{"37.89999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32149779862297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.484736744276518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818345754614`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.12909276811100767`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5653230611586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42803762425083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.89999999999999, "C", 
        Association[1 -> {
           Complex[163.32149779862297`, 22.484736744276518`], 
           Complex[133.73818345754614`, 0.12909276811100767`]}, 2 -> {
           Complex[163.5653230611586, -22.633058674966136`], 
           Complex[133.42803762425083`, -41.44013218836733]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{37.99999999999999, -6.999999966054866}],
       RowBox[{"{", 
         RowBox[{"37.99999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32149364702843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381750638226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.16577500282102164`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56479543110495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.674637963494348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42582970355036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.47625154943295`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {37.99999999999999, "C", 
        Association[1 -> {
           Complex[163.32149364702843`, 22.526274879059077`], 
           Complex[133.7381750638226, 0.16577500282102164`]}, 2 -> {
           Complex[163.56479543110495`, -22.674637963494348`], 
           Complex[133.42582970355036`, -41.47625154943295]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.099999999999994`, -6.9999999703869635`}],
       RowBox[{"{", 
         RowBox[{"38.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214885076075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.567606480874492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500862`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581258`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.564271396088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.716010504136886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040793`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.3214885076075, 22.567606480874492`], 
           Complex[133.73816464500862`, 0.2022652058581258]}, 2 -> {
           Complex[163.564271396088, -22.716010504136886`], 
           Complex[133.42362780386904`, -41.51217831040793]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.199999999999996`, -6.999999974171673}],
       RowBox[{"{", 
         RowBox[{"38.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32148240186692`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.608733631773358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.23856533752871556`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56375091163494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.547914435078255`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.32148240186692`, 22.608733631773358`], 
           Complex[133.73815223405947`, 0.23856533752871556`]}, 2 -> {
           Complex[163.56375091163494`, -22.757178380842813`], 
           Complex[133.42143186313936`, -41.547914435078255`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.3, -6.9999999774774295`}],
       RowBox[{"{", 
         RowBox[{"38.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.321475350806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.649658382119874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381378632521`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.27467732815633283`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56323393407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41924182031818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.3, "C", 
        Association[1 -> {
           Complex[163.321475350806, 22.649658382119874`], 
           Complex[133.7381378632521, 0.27467732815633283`]}, 2 -> {
           Complex[163.56323393407584`, -22.798143645850313`], 
           Complex[133.41924182031818`, -41.58346185720893]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.4, -6.9999999803642075`}],
       RowBox[{"{", 
         RowBox[{"38.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32146737492982`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.69038275123732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73812156420146`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5627204205249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.838908320332727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41705761536383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.618822481156855`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.4, "C", 
        Association[1 -> {
           Complex[163.32146737492982`, 22.69038275123732], 
           Complex[133.73812156420146`, 0.3106030786938945]}, 2 -> {
           Complex[163.5627204205249, -22.838908320332727`], 
           Complex[133.41705761536383`, -41.618822481156855`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.5, -6.999999982884558}],
       RowBox[{"{", 
         RowBox[{"38.5`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32145849426388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.730908728036773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381033678786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.34634446131990515`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56221032886114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.653998182467525`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.5, "C", 
        Association[1 -> {
           Complex[163.32145849426388`, 22.730908728036773`], 
           Complex[133.7381033678786, 0.34634446131990515`]}, 2 -> {
           Complex[163.56221032886114`, -22.879474395027515`], 
           Complex[133.41487918921308`, -41.653998182467525`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.599999999999994`, -6.999999985084512}],
       RowBox[{"{", 
         RowBox[{"38.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214487283661`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.7712382716304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.38190332002009697`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56170361771126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830850002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.68899080845728`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.3214487283661, 22.7712382716304], 
           Complex[133.7380833046258, 0.38190332002009697`]}, 2 -> {
           Complex[163.56170361771126`, -22.919843830850002`], 
           Complex[133.41270648376008`, -41.68899080845728]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.699999999999996`, -6.999999987004383}],
       RowBox[{"{", 
         RowBox[{"38.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32143809634076`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.81137331192805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4172814711532169`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56120024643147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877989`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.32143809634076`, 22.81137331192805], 
           Complex[133.73806140417352`, 0.4172814711532169]}, 2 -> {
           Complex[163.56120024643147`, -22.960018559490692`], 
           Complex[133.41053944183457`, -41.72380217877989]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.8, -6.999999988679468}],
       RowBox[{"{", 
         RowBox[{"38.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32142661684998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.85131575022118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4524807040047172`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56070017509117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.00000048399869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.8, "C", 
        Association[1 -> {
           Complex[163.32142661684998`, 22.85131575022118], 
           Complex[133.73803769565515`, 0.4524807040047172]}, 2 -> {
           Complex[163.56070017509117`, -23.00000048399869], 
           Complex[133.40837800718197`, -41.758434085980085`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.9, -6.999999990140664}],
       RowBox[{"{", 
         RowBox[{"38.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214143081261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.891067459749348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.48750278132399316`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.56020336445604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.039791479349606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4062221244428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.79288829603216`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.9, "C", 
        Association[1 -> {
           Complex[163.3214143081261, 22.891067459749348`], 
           Complex[133.7380122076221, 0.48750278132399316`]}, 2 -> {
           Complex[163.56020336445604`, -23.039791479349606`], 
           Complex[133.4062221244428, -41.79288829603216]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{38.99999999999999, -6.99999999141501}],
       RowBox[{"{", 
         RowBox[{"38.99999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3214011879832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.93063028625468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5597097759723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.07939339299977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4040717391336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.82716654886576`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {38.99999999999999, "C", 
        Association[1 -> {
           Complex[163.3214011879832, 22.93063028625468], 
           Complex[133.73798496805838`, 0.5223494398501387]}, 2 -> {
           Complex[163.5597097759723, -23.07939339299977], 
           Complex[133.4040717391336, -41.82716654886576]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.099999999999994`, -6.9999999925261625`}],
       RowBox[{"{", 
         RowBox[{"39.099999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3213872738282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.97000604852185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239598`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55921937175077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.11880804542669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4019267976277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.86127055887851`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.099999999999994`, "C", 
        Association[1 -> {
           Complex[163.3213872738282, 22.97000604852185], 
           Complex[133.73795600439445`, 0.5570223908239598]}, 2 -> {
           Complex[163.55921937175077`, -23.11880804542669], 
           Complex[133.4019267976277, -41.86127055887851]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.199999999999996`, -6.999999993494815}],
       RowBox[{"{", 
         RowBox[{"39.199999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32137258267184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874362`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5587321145525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.15803723065625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.89520201543604`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.199999999999996`, "C", 
        Association[1 -> {
           Complex[163.32137258267184`, 23.009196538904806`], 
           Complex[133.73792534352103`, 0.5915233204874362]}, 2 -> {
           Complex[163.5587321145525, -23.15803723065625], 
           Complex[133.39978724713728`, -41.89520201543604]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.3, -6.999999994339065}],
       RowBox[{"{", 
         RowBox[{"39.3`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32135713113917`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.04820352384075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55824796777307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.197082716776826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335967`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.3, "C", 
        Association[1 -> {
           Complex[163.32135713113917`, 23.04820352384075], 
           Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
           Complex[163.55824796777307`, -23.197082716776826`], 
           Complex[133.39765303569465`, -41.92896258335967]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.4, -6.9999999950747345`}],
       RowBox[{"{", 
         RowBox[{"39.4`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32134093547978`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508835`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6600157387690366`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55776689542964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340244`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.4, "C", 
        Association[1 -> {
           Complex[163.32134093547978`, 23.087028744351493`], 
           Complex[133.73785903508835`, 0.6600157387690366]}, 2 -> {
           Complex[163.55776689542964`, -23.235946246441227`], 
           Complex[133.39552411213612`, -41.96255390340244]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.49999999999999, -6.999999995715656}],
       RowBox[{"{", 
         RowBox[{"39.49999999999999`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3213240115776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.12567391653264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782343872844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6940104792034631`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55728886214564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.99597759271317`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.49999999999999, "C", 
        Association[1 -> {
           Complex[163.3213240115776, 23.12567391653264], 
           Complex[133.73782343872844`, 0.6940104792034631]}, 2 -> {
           Complex[163.55728886214564`, -23.27462953735598], 
           Complex[133.39340042608356`, -41.99597759271317]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.599999999999994`, -6.999999996273914}],
       RowBox[{"{", 
         RowBox[{"39.599999999999994`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32130637496067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7377862475824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7278397028767358`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55681383313836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.02923524528987`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.599999999999994`, "C", 
        Association[1 -> {
           Complex[163.32130637496067`, 23.164140732031207`], 
           Complex[133.7377862475824, 0.7278397028767358]}, 2 -> {
           Complex[163.55681383313836`, -23.313134282759357`], 
           Complex[133.39128192792896`, -42.02923524528987]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.699999999999996`, -6.999999996760072}],
       RowBox[{"{", 
         RowBox[{"39.699999999999996`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32128804080997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.2024308585112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131837`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.5563417742055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.351462151887404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.389168568818`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.062328432421694`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.699999999999996`, "C", 
        Association[1 -> {
           Complex[163.32128804080997`, 23.2024308585112], 
           Complex[133.73774748603233`, 0.7615049781131837]}, 2 -> {
           Complex[163.5563417742055, -23.351462151887404`], 
           Complex[133.389168568818, -42.062328432421694`]}]}, "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.8, -6.999999997183353}],
       RowBox[{"{", 
         RowBox[{"39.8`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32126902396925`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907748`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55587265171218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.38961479042947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120926`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.8, "C", 
        Association[1 -> {
           Complex[163.32126902396925`, 23.24054594010908], 
           Complex[133.73770717799474`, 0.7950078509907748]}, 2 -> {
           Complex[163.55587265171218`, -23.38961479042947], 
           Complex[133.3870603006344, -42.095258703120926`]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{39.9, -6.999999997551814}],
       RowBox[{"{", 
         RowBox[{"39.9`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.32124933895304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.278487597877273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8283498457615899`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.555406432579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {39.9, "C", 
        Association[1 -> {
           Complex[163.32124933895304`, 23.278487597877273`], 
           Complex[133.73766534693092`, 0.8283498457615899]}, 2 -> {
           Complex[163.555406432579, -23.427593820972138`], 
           Complex[133.38495707598477`, -42.12802758454397]}]}, 
       "Tooltip"]& ]}, 
    {RGBColor[0, 
      NCache[
       Rational[2, 3], 0.6666666666666666], 0], 
     TagBox[
      TooltipBox[PointBox[{40., -6.999999997872491}],
       RowBox[{"{", 
         RowBox[{"40.`", ",", "\"C\"", ",", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"1", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.3212289999553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.316257430218013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630996`", " ", "\[ImaginaryI]"}]}]}],
                    "}"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"163.55494308426918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.465400843433205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240298`", " ", "\[ImaginaryI]"}]}]}], 
                   "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
      Annotation[#, {40., "C", 
        Association[1 -> {
           Complex[163.3212289999553, 23.316257430218013`], 
           Complex[133.73762201585797`, 0.8615324652630996]}, 2 -> {
           Complex[163.55494308426918`, -23.465400843433205`], 
           Complex[133.38285884818328`, -42.16063658240298]}]}, 
       "Tooltip"]& ]}}},
  AspectRatio->NCache[
    Rational[1, 2], 0.5],
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], 
    FormBox["\"harmonic dipole\"", TraditionalForm]},
  ImageSize->800]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Saddle-point total spectrum", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SPAdipole"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"SPAdipole[S,prefactor,\[CapitalOmega],{t,\[Tau]}] returns the \
saddle-point approximation amplitude corresponding to action S[t,t-\[Tau]]-\
\[CapitalOmega]t and the given prefactor.\\n\\nSPAdipole[S,prefactor,\
\[CapitalOmega],\[LeftAssociation]1\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation]] returns the total harmonic-dipole contribution in the \
saddle-point approximation from the specified saddle \
points.\\n\\nSPAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)}\[RightAssociation],transition] uses the given Stokes transition set \
to drop the relevant saddle after the anti-Stokes transition.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info183674213787-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "transitions"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"keyColour", "=", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\"\<A\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Black"}], ",", 
            RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<B\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Red"}], ",", 
            RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<C\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<D\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}],
         "\[RightAssociation]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", "Black"}], ",", 
       RowBox[{"\"\<B\>\"", "\[Rule]", "Red"}], ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", "Purple"}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#1", "/", "\[Omega]"}], ",", 
                SuperscriptBox[
                 RowBox[{"Norm", "[", 
                  RowBox[{"Total", "[", "#2", "]"}], "]"}], "2"]}], "}"}], 
              "&"}], "\[IndentingNewLine]", ",", 
             RowBox[{
              RowBox[{"Query", "[", "Transpose", "]"}], "[", 
              "\[IndentingNewLine]", 
              RowBox[{"MapIndexed", "[", 
               RowBox[{"(*", 
                RowBox[{
                "calculate", " ", "the", " ", "dipole", " ", "for", " ", 
                 "each", " ", "label", " ", "and", " ", "harmonic", " ", 
                 "energy"}], "*)"}], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"With", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"saddles", "=", "#1"}], ",", 
                    RowBox[{"index", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
                    RowBox[{"\[CapitalOmega]", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"SPAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "<", 
                    RowBox[{"transitions", "\[LeftDoubleBracket]", 
                    RowBox[{"index", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    ",", "saddles", ",", 
                    RowBox[{
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"transitions", "\[LeftDoubleBracket]", 
                    RowBox[{"index", ",", "3"}], "\[RightDoubleBracket]"}], 
                    "\[RightDoubleBracket]"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
                  "]"}], "&"}], ",", "selection", ",", 
                RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n_", ",", 
             RowBox[{"d_", "/;", 
              RowBox[{
               RowBox[{"Abs", "[", "d", "]"}], "<", 
               SuperscriptBox["10", 
                RowBox[{"-", "20"}]]}]}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{",", 
           RowBox[{"GridLines", "\[Rule]", "All"}]}], "*)"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], "\[IndentingNewLine]", 
         ",", 
         RowBox[{"ImageSize", "\[Rule]", "700"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
            "\"\<harmonic dipole\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#1", "/", "\[Omega]"}], ",", 
              SuperscriptBox[
               RowBox[{"Norm", "[", 
                RowBox[{"Total", "[", "#2", "]"}], "]"}], "2"]}], "}"}], 
            "&"}], "\[IndentingNewLine]", ",", 
           RowBox[{
            RowBox[{"Query", "[", "Transpose", "]"}], "[", 
            "\[IndentingNewLine]", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{"(*", 
              RowBox[{
              "calculate", " ", "the", " ", "dipole", " ", "for", " ", "each",
                " ", "label", " ", "and", " ", "harmonic", " ", "energy"}], 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"With", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"saddles", "=", "#1"}], ",", 
                   RowBox[{"index", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
                   RowBox[{"\[CapitalOmega]", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"SPAdipole", "[", 
                  RowBox[{
                  "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                   RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                   RowBox[{"transitions", "[", "index", "]"}]}], 
                  "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
                "]"}], "&"}], ",", 
              RowBox[{
               RowBox[{"KeySelect", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    RowBox[{"#", "-", 
                    RowBox[{"Round", "[", 
                    RowBox[{"#", ",", "\[Omega]"}], "]"}]}], "]"}], "<", 
                   RowBox[{"0.05", "\[Omega]"}]}], "&&", 
                  RowBox[{"OddQ", "[", 
                   RowBox[{"Round", "[", 
                    RowBox[{"#", "/", "\[Omega]"}], "]"}], "]"}]}], "&"}], 
                "]"}], "/@", 
               RowBox[{"selection", "\[LeftDoubleBracket]", "All", 
                RowBox[{"(*", 
                 RowBox[{",", 
                  RowBox[{"11", ";;", 
                   RowBox[{"-", "1"}], ";;", "20"}]}], "*)"}], 
                "\[RightDoubleBracket]"}]}], ",", 
              RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{",", 
           RowBox[{"GridLines", "\[Rule]", "All"}]}], "*)"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], "\[IndentingNewLine]", 
         ",", 
         RowBox[{"ImageSize", "\[Rule]", "700"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
            "\"\<harmonic dipole\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {GrayLevel[0], PointSize[0.01388888888888889], AbsoluteThickness[1.6],
          PointBox[CompressedData["
1:eJw1lnlYlOUaxtE0SUdFwXTIINzQkmVWZp/7+yb0qLihiIgQuYAgKgpYYQmC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          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{15.728124999999999`, -43.63975973671347},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"harmonic dipole\"", TraditionalForm], None}, {
         FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-41.44653167389282, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.93054075013613, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.843529373146502`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.763486665472964`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.689378693319245`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.620385821832294`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.555847300694722`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.495222678878285`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.43806426503834, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-41.44653167389282, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.93054075013613, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.843529373146502`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.763486665472964`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.689378693319245`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.620385821832294`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.555847300694722`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.495222678878285`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.43806426503834, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->700,
      Method->{},
      PlotRange->{{16.099999999999998`, 
       39.9}, {-43.338007853165415`, -24.62939107318612}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}]},
    {
     GraphicsBox[{{}, {{}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], PointBox[{{17., -25.67126271166933}, {
          18.999999999999996`, -24.80776952561491}, {
          21., -27.107320619724792`}, {
          22.999999999999996`, -26.208508239934027`}, {
          24.999999999999996`, -26.252263731807115`}, {
          27., -27.774804975407278`}, {
          28.999999999999996`, -26.269833133319334`}, {
          30.999999999999993`, -26.450099240309513`}, {
          33., -28.286726303196108`}, {35., -30.69511535603813}, {
          36.99999999999999, -33.63626283527423}, {
          38.99999999999999, -37.00590078441457}}]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{16.65625, -37.891249020940364`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"harmonic dipole\"", TraditionalForm], None}, {
         FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-36.841361487904734`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.45079940033883, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.04533429223067, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.75765221977888, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.534508668464674`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.35218711167072, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.19803643184346, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.06450503921894, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.946722003562556`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.14821430734479, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.74274919923662, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.45506712678484, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.23192357547063, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.04960201867667, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.89545133884942, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.76191994622489, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.64413691056851, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.84562921435074, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.44016410624258, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.1524820337908, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.92933848247659, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.74701692568263, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.59286624585537, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.45933485323085, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.34155181757447, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.543044121356694`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.13757901324853, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.84989694079675, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.626753389482538`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.444431832688586`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.290281152861326`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.156749760236803`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.03896672458042, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.240459028362647`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.834993920254483`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.547311847802703`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.324168296488494`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.14184673969454, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.98769605986728, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.85416466724276, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.736381631586376`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.937873935368604`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.53240882726044, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.244726754808656`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.021583203494448`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.839261646700493`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.685110966873236`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.551579574248713`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.43379653859233, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.635288842374557`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.229823734266393`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.942141661814613`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.7189981105004, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.536676553706446`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.38252587387919, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.248994481254666`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.131211445598282`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-36.841361487904734`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.45079940033883, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.04533429223067, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.75765221977888, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.534508668464674`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.35218711167072, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.19803643184346, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.06450503921894, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.946722003562556`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.14821430734479, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.74274919923662, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.45506712678484, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.23192357547063, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.04960201867667, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.89545133884942, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.76191994622489, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.64413691056851, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.84562921435074, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.44016410624258, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.1524820337908, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.92933848247659, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.74701692568263, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.59286624585537, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.45933485323085, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.34155181757447, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.543044121356694`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.13757901324853, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.84989694079675, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.626753389482538`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.444431832688586`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.290281152861326`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.156749760236803`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.03896672458042, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.240459028362647`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.834993920254483`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.547311847802703`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.324168296488494`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.14184673969454, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.98769605986728, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.85416466724276, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.736381631586376`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.937873935368604`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.53240882726044, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.244726754808656`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.021583203494448`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.839261646700493`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.685110966873236`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.551579574248713`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.43379653859233, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.635288842374557`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.229823734266393`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.942141661814613`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.7189981105004, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.536676553706446`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.38252587387919, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.248994481254666`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.131211445598282`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->700,
      Method->{},
      PlotRange->{{17., 
       38.99999999999999}, {-37.68357474323678, -24.80776952561491}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Uniform Approximation per-pair spectrum", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "UAdipole"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"UAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation],transition] returns the total harmonic-dipole \
contribution in the uniform approximation from the specified saddle points, \
taking the given Stokes transition set as a reference.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info233674213812-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "transitions"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"1.65", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"",
            ","}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"6.3", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", 
              RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ","}], "*)"}], 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", "Black"}], ",", 
       RowBox[{"\"\<B\>\"", "\[Rule]", "Red"}], ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", "Purple"}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"keyColour", "[", "index", "]"}], "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", "Gray"}], 
                  "}"}]}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Black", "\[Rule]", "Gray"}], ",", 
                  RowBox[{
                   RowBox[{"Darker", "[", "Green", "]"}], "\[Rule]", 
                   RowBox[{"Lighter", "[", "Green", "]"}]}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Tooltip", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Point", "[", "\[IndentingNewLine]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"Log10", "[", 
                    RowBox[{"(*", 
                    RowBox[{
                    SuperscriptBox["10", 
                    RowBox[{"-", "8.5"}]], "+"}], "*)"}], 
                    RowBox[{"Norm", "[", "\[IndentingNewLine]", 
                    RowBox[{"SPAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], "]"}], 
                    "\[IndentingNewLine]", "]"}], "]"}]}], "}"}], 
                  "\[IndentingNewLine]", "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", "index",
                    ",", 
                   RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], 
                  "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"keyColour", "[", "index", "]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", "Gray"}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"Tooltip", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Point", "[", "\[IndentingNewLine]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"Log10", "[", 
                    RowBox[{"(*", 
                    RowBox[{
                    SuperscriptBox["10", 
                    RowBox[{"-", "8.5"}]], "+"}], "*)"}], 
                    RowBox[{"Norm", "[", "\[IndentingNewLine]", 
                    RowBox[{"UAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], "]"}], 
                    "\[IndentingNewLine]", "]"}], "]"}]}], "}"}], 
                  "\[IndentingNewLine]", "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", "index",
                    ",", 
                   RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], 
                  "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[CapitalOmega]", ",", 
               RowBox[{"Keys", "[", 
                RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"index", ",", 
             RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
        RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
        RowBox[{"AspectRatio", "\[Rule]", 
         RowBox[{"1", "/", "1.8"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
           "\"\<harmonic dipole\>\""}], "}"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Automatic", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "8.5"}], ",", 
             RowBox[{"-", "5.6"}]}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
        ",", 
        RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], 
       "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "}"}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{{
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.111691065465595}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.245615698905056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.546462974510604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.3583570943027`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11658019540031805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 
             Association[1 -> {
                Complex[12.245615698905056`, -11.285995288896373`], 
                Complex[31.494082066597198`, -37.546462974510604`]}, 2 -> {
                Complex[82.3583570943027, 0.11658019540031805`], 
                Complex[108.70582923184111`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.120221201675655}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.245615698905056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.285995288896373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"31.494082066597198`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.546462974510604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"82.3583570943027`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11658019540031805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"108.70582923184111`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.410164695938445`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 
             Association[1 -> {
                Complex[12.245615698905056`, -11.285995288896373`], 
                Complex[31.494082066597198`, -37.546462974510604`]}, 2 -> {
                Complex[82.3583570943027, 0.11658019540031805`], 
                Complex[108.70582923184111`, -20.410164695938445`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.058891462329176}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.866460671342168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.816178584119385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.10766368142046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.65454606371028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 
             Association[1 -> {
                Complex[12.866460671342168`, -10.816178584119385`], 
                Complex[32.10766368142046, -37.05300319249051]}, 2 -> {
                Complex[81.65454606371028, 0.11776334712026199`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.067313712364637}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"12.866460671342168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.816178584119385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.10766368142046`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.05300319249051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.65454606371028`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11776334712026199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.9916707304329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.410142957197117`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 
             Association[1 -> {
                Complex[12.866460671342168`, -10.816178584119385`], 
                Complex[32.10766368142046, -37.05300319249051]}, 2 -> {
                Complex[81.65454606371028, 0.11776334712026199`], 
                Complex[107.9916707304329, -20.410142957197117`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.0270010290733955`}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.385569221277168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.443606571400114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.62046690403218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.08582224927886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "A", 
             Association[1 -> {
                Complex[13.385569221277168`, -10.443606571400114`], 
                Complex[32.62046690403218, -36.65624121214425]}, 2 -> {
                Complex[81.08582224927886, 0.11905307061487365`], 
                Complex[107.41258000537293`, -20.41001952735828]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.035354483168751}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.385569221277168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.443606571400114`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"32.62046690403218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.65624121214425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"81.08582224927886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11905307061487365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"107.41258000537293`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.41001952735828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "A", 
             Association[1 -> {
                Complex[13.385569221277168`, -10.443606571400114`], 
                Complex[32.62046690403218, -36.65624121214425]}, 2 -> {
                Complex[81.08582224927886, 0.11905307061487365`], 
                Complex[107.41258000537293`, -20.41001952735828]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.006124662787357}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.844879609183106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.128345372417396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.074306417344815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.59570734825861`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12040941356394542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 
             Association[1 -> {
                Complex[13.844879609183106`, -10.128345372417396`], 
                Complex[33.074306417344815`, -36.31637452115125]}, 2 -> {
                Complex[80.59570734825861, 0.12040941356394542`], 
                Complex[106.91207211908184`, -20.409835465464518`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.014445567426285}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"13.844879609183106`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.128345372417396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.074306417344815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.31637452115125`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.59570734825861`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12040941356394542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.91207211908184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409835465464518`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 
             Association[1 -> {
                Complex[13.844879609183106`, -10.128345372417396`], 
                Complex[33.074306417344815`, -36.31637452115125]}, 2 -> {
                Complex[80.59570734825861, 0.12040941356394542`], 
                Complex[106.91207211908184`, -20.409835465464518`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.4, -5.9923329332226505`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.263512998287613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.852138089238336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.48822262138849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.01523037051932`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.15853740070536`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12181511399306792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40960872633279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "A", 
             Association[1 -> {
                Complex[14.263512998287613`, -9.852138089238336], 
                Complex[33.48822262138849, -36.01523037051932]}, 2 -> {
                Complex[80.15853740070536, 0.12181511399306792`], 
                Complex[106.46447895532776`, -20.40960872633279]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -6.000648023047295}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.263512998287613`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.852138089238336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.48822262138849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.01523037051932`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"80.15853740070536`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12181511399306792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.46447895532776`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40960872633279`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "A", 
             Association[1 -> {
                Complex[14.263512998287613`, -9.852138089238336], 
                Complex[33.48822262138849, -36.01523037051932]}, 2 -> {
                Complex[80.15853740070536, 0.12181511399306792`], 
                Complex[106.46447895532776`, -20.40960872633279]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -5.983451024774748}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.652107822673527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.60480138795417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.87279494489345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.74268548695589`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.76008128321261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12326110383985404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.05556643970378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409348870362294`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 
             Association[1 -> {
                Complex[14.652107822673527`, -9.60480138795417], 
                Complex[33.87279494489345, -35.74268548695589]}, 2 -> {
                Complex[79.76008128321261, 0.12326110383985404`], 
                Complex[106.05556643970378`, -20.409348870362294`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -5.9917734572254835`}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"14.652107822673527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.60480138795417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"33.87279494489345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.74268548695589`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.76008128321261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12326110383985404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"106.05556643970378`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409348870362294`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 
             Association[1 -> {
                Complex[14.652107822673527`, -9.60480138795417], 
                Complex[33.87279494489345, -35.74268548695589]}, 2 -> {
                Complex[79.76008128321261, 0.12326110383985404`], 
                Complex[106.05556643970378`, -20.409348870362294`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.977940374435416}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.017310748471408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.379958105911207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.3914778440311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1247420703186469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 
             Association[1 -> {
                Complex[15.017310748471408`, -9.379958105911207], 
                Complex[34.23462400814145, -35.492408387804]}, 2 -> {
                Complex[79.3914778440311, 0.1247420703186469], 
                Complex[105.67647115587602`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.986266983292059}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.017310748471408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.379958105911207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.23462400814145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.492408387804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.3914778440311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1247420703186469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.67647115587602`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.409061588827736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 
             Association[1 -> {
                Complex[15.017310748471408`, -9.379958105911207], 
                Complex[34.23462400814145, -35.492408387804]}, 2 -> {
                Complex[79.3914778440311, 0.1247420703186469], 
                Complex[105.67647115587602`, -20.409061588827736`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.974525845003835}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.363606529112152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.17329625288842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.260123312215754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.04676899384386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12625468557684455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.32123318016059`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408750516874484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "A", 
             Association[1 -> {
                Complex[15.363606529112152`, -9.17329625288842], 
                Complex[34.57815702977675, -35.260123312215754`]}, 2 -> {
                Complex[79.04676899384386, 0.12625468557684455`], 
                Complex[105.32123318016059`, -20.408750516874484`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.982836172555419}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.363606529112152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.17329625288842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.57815702977675`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.260123312215754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"79.04676899384386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12625468557684455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"105.32123318016059`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.408750516874484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "A", 
             Association[1 -> {
                Complex[15.363606529112152`, -9.17329625288842], 
                Complex[34.57815702977675, -35.260123312215754`]}, 2 -> {
                Complex[79.04676899384386, 0.12625468557684455`], 
                Complex[105.32123318016059`, -20.408750516874484`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.972086169036348}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.694192540187109`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.981735864879811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.906559828007246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.04277989487664`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.72172225527217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1277967777586609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 
             Association[1 -> {
                Complex[15.694192540187109`, -8.981735864879811], 
                Complex[34.906559828007246`, -35.04277989487664]}, 2 -> {
                Complex[78.72172225527217, 0.1277967777586609], 
                Complex[104.98561848841774`, -20.40841808612212]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.980344237818082}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"15.694192540187109`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.981735864879811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"34.906559828007246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.04277989487664`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.72172225527217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1277967777586609`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.98561848841774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40841808612212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 
             Association[1 -> {
                Complex[15.694192540187109`, -8.981735864879811], 
                Complex[34.906559828007246`, -35.04277989487664]}, 2 -> {
                Complex[78.72172225527217, 0.1277967777586609], 
                Complex[104.98561848841774`, -20.40841808612212]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.969665709006678}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.011444946530013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.802984319586065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.8381102332606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.41320392779194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12936689788169053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40806597206126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "A", 
             Association[1 -> {
                Complex[16.011444946530013`, -8.802984319586065], 
                Complex[35.22218142009305, -34.8381102332606]}, 2 -> {
                Complex[78.41320392779194, 0.12936689788169053`], 
                Complex[104.66649203468586`, -20.40806597206126]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.977825325997558}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.011444946530013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.802984319586065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.22218142009305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.8381102332606`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.41320392779194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12936689788169053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.66649203468586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40806597206126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "A", 
             Association[1 -> {
                Complex[16.011444946530013`, -8.802984319586065], 
                Complex[35.22218142009305, -34.8381102332606]}, 2 -> {
                Complex[78.41320392779194, 0.12936689788169053`], 
                Complex[104.66649203468586`, -20.40806597206126]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17., -5.966542942152103}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.31718789840238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.635279208450724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.52682218732508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.11881756413922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13096407459708617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "A", 
             Association[1 -> {
                Complex[16.31718789840238, -8.635279208450724], 
                Complex[35.52682218732508, -34.644372916323725`]}, 2 -> {
                Complex[78.11881756413922, 0.13096407459708617`], 
                Complex[104.36145617205713`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17., -5.9745563061297595`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.31718789840238`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.635279208450724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.52682218732508`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644372916323725`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"78.11881756413922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13096407459708617`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.36145617205713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40769534844911`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "A", 
             Association[1 -> {
                Complex[16.31718789840238, -8.635279208450724], 
                Complex[35.52682218732508, -34.644372916323725`]}, 2 -> {
                Complex[78.11881756413922, 0.13096407459708617`], 
                Complex[104.36145617205713`, -20.40769534844911]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.962305462783897}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.612858840508633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.47723022998036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.83668223957315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13258766651163573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 
             Association[1 -> {
                Complex[16.612858840508633`, -8.47723022998036], 
                Complex[35.82189847272132, -34.46019571836112]}, 2 -> {
                Complex[77.83668223957315, 0.13258766651163573`], 
                Complex[104.06862888444635`, -20.407307041147234`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.970133252934314}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.612858840508633`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.47723022998036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"35.82189847272132`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.46019571836112`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.83668223957315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13258766651163573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"104.06862888444635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.407307041147234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 
             Association[1 -> {
                Complex[16.612858840508633`, -8.47723022998036], 
                Complex[35.82189847272132, -34.46019571836112]}, 2 -> {
                Complex[77.83668223957315, 0.13258766651163573`], 
                Complex[104.06862888444635`, -20.407307041147234`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.9568875917094495`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.899615105400063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.327717105231178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.1085486648078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.284474089725364`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.56528975328628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13423726881752882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "A", 
             Association[1 -> {
                Complex[16.899615105400063`, -8.327717105231178], 
                Complex[36.1085486648078, -34.284474089725364`]}, 2 -> {
                Complex[77.56528975328628, 0.13423726881752882`], 
                Complex[103.78650096169157`, -20.406901625797378`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.964507556170828}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"16.899615105400063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.327717105231178`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.1085486648078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.284474089725364`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.56528975328628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13423726881752882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.78650096169157`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406901625797378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "A", 
             Association[1 -> {
                Complex[16.899615105400063`, -8.327717105231178], 
                Complex[36.1085486648078, -34.284474089725364`]}, 2 -> {
                Complex[77.56528975328628, 0.13423726881752882`], 
                Complex[103.78650096169157`, -20.406901625797378`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.950545415272463}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.17840543589556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.18582098961993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.116302994815634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.30340893094568`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13591265188074694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 
             Association[1 -> {
                Complex[17.17840543589556, -8.18582098961993], 
                Complex[36.38770434340436, -34.116302994815634`]}, 2 -> {
                Complex[77.30340893094568, 0.13591265188074694`], 
                Complex[103.51384028303791`, -20.406479492338008`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.957956796959607}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.17840543589556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.18582098961993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.38770434340436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.116302994815634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.30340893094568`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13591265188074694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.51384028303791`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406479492338008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 
             Association[1 -> {
                Complex[17.17840543589556, -8.18582098961993], 
                Complex[36.38770434340436, -34.116302994815634`]}, 2 -> {
                Complex[77.30340893094568, 0.13591265188074694`], 
                Complex[103.51384028303791`, -20.406479492338008`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.943773490931781}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.4500195893454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.660139598224646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.9549296033411`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.05001933585376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951339305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "A", 
             Association[1 -> {
                Complex[17.4500195893454, -8.050776840303662], 
                Complex[36.660139598224646`, -33.9549296033411]}, 2 -> {
                Complex[77.05001933585376, 0.13761371951339305`], 
                Complex[103.24962551411932`, -20.406040889030564`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.950996404338354}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.4500195893454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.050776840303662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.660139598224646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.9549296033411`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"77.05001933585376`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13761371951339305`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"103.24962551411932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.406040889030564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "A", 
             Association[1 -> {
                Complex[17.4500195893454, -8.050776840303662], 
                Complex[36.660139598224646`, -33.9549296033411]}, 2 -> {
                Complex[77.05001933585376, 0.13761371951339305`], 
                Complex[103.24962551411932`, -20.406040889030564`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.937191348258818}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.715123715910405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.921939398858399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.926506185668615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.799719524488225`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.80426404977382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13934047984247463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "A", 
             Association[1 -> {
                Complex[17.715123715910405`, -7.921939398858399], 
                Complex[36.926506185668615`, -33.799719524488225`]}, 2 -> {
                Complex[76.80426404977382, 0.13934047984247463`], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.944262235275149}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.715123715910405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.921939398858399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"36.926506185668615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.799719524488225`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.80426404977382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13934047984247463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.99299887698848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405585953330533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "A", 
             Association[1 -> {
                Complex[17.715123715910405`, -7.921939398858399], 
                Complex[36.926506185668615`, -33.799719524488225`]}, 2 -> {
                Complex[76.80426404977382, 0.13934047984247463`], 
                Complex[102.99299887698848`, -20.405585953330533`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.931433257993299}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.97428620238765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.18735919764107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.65013212317828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.56541522251278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 
             Association[1 -> {
                Complex[17.97428620238765, -7.798758308638237], 
                Complex[37.18735919764107, -33.65013212317828]}, 2 -> {
                Complex[76.56541522251278, 0.14109302450360017`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.938398552967833}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"17.97428620238765`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.798758308638237`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.18735919764107`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.65013212317828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.56541522251278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14109302450360017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.74323169131219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40511473403629`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 
             Association[1 -> {
                Complex[17.97428620238765, -7.798758308638237], 
                Complex[37.18735919764107, -33.65013212317828]}, 2 -> {
                Complex[76.56541522251278, 0.14109302450360017`], 
                Complex[102.74323169131219`, -20.40511473403629]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.9270633943076545`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.227996947167636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.44317619593503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.50570209730137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.33284841044511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14287151349532584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "A", 
             Association[1 -> {
                Complex[18.227996947167636`, -7.680759532183109], 
                Complex[37.44317619593503, -33.50570209730137]}, 2 -> {
                Complex[76.33284841044511, 0.14287151349532584`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.933973277218298}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.227996947167636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.680759532183109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.44317619593503`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.50570209730137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.33284841044511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14287151349532584`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.49969870626036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404627207488197`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "A", 
             Association[1 -> {
                Complex[18.227996947167636`, -7.680759532183109], 
                Complex[37.44317619593503, -33.50570209730137]}, 2 -> {
                Complex[76.33284841044511, 0.14287151349532584`], 
                Complex[102.49969870626036`, -20.404627207488197`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.924522150187078}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.476681999633616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.567531219181608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.694371737074945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.366025475903584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.10602311146744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1446761639763866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 
             Association[1 -> {
                Complex[18.476681999633616`, -7.567531219181608], 
                Complex[37.694371737074945`, -33.366025475903584`]}, 2 -> {
                Complex[76.10602311146744, 0.1446761639763866], 
                Complex[102.26185863012617`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.9314253714616685`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.476681999633616`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.567531219181608`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.694371737074945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.366025475903584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"76.10602311146744`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1446761639763866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.26185863012617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.404123289610286`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 
             Association[1 -> {
                Complex[18.476681999633616`, -7.567531219181608], 
                Complex[37.694371737074945`, -33.366025475903584`]}, 2 -> {
                Complex[76.10602311146744, 0.1446761639763866], 
                Complex[102.26185863012617`, -20.404123289610286`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.924097731754625}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.7207148587158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.458712785360555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.23074880548425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.8844677615424`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187037323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "A", 
             Association[1 -> {
                Complex[18.7207148587158, -7.458712785360555], 
                Complex[37.94130857631962, -33.23074880548425]}, 2 -> {
                Complex[75.8844677615424, 0.14650724187037323`], 
                Complex[102.02923912251609`, -20.403602844982533`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.931037637639145}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.7207148587158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.458712785360555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"37.94130857631962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.23074880548425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.8844677615424`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14650724187037323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"102.02923912251609`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403602844982533`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "A", 
             Association[1 -> {
                Complex[18.7207148587158, -7.458712785360555], 
                Complex[37.94130857631962, -33.23074880548425]}, 2 -> {
                Complex[75.8844677615424, 0.14650724187037323`], 
                Complex[102.02923912251609`, -20.403602844982533`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.9259129449873384`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.960425318413485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.353986351536103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.18430643425337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.09956067860008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.66776800411328`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1483650555087814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 
             Association[1 -> {
                Complex[18.960425318413485`, -7.353986351536103], 
                Complex[38.18430643425337, -33.09956067860008]}, 2 -> {
                Complex[75.66776800411328, 0.1483650555087814], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.932924335223119}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"18.960425318413485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.353986351536103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.18430643425337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.09956067860008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.66776800411328`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1483650555087814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.80142506016172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40306569375059`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 
             Association[1 -> {
                Complex[18.960425318413485`, -7.353986351536103], 
                Complex[38.18430643425337, -33.09956067860008]}, 2 -> {
                Complex[75.66776800411328, 0.1483650555087814], 
                Complex[101.80142506016172`, -20.40306569375059]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.929918310459491}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.196106481999152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.253069946548066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.42364894442649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.97218501218881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.45555740059443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15024995077914985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 
             Association[1 -> {
                Complex[19.196106481999152`, -7.253069946548066], 
                Complex[38.42364894442649, -32.97218501218881]}, 2 -> {
                Complex[75.45555740059443, 0.15024995077914985`], 
                Complex[101.57804924438945`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.937024622205059}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.196106481999152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.253069946548066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.42364894442649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.97218501218881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.45555740059443`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15024995077914985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.57804924438945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.402511616933747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 
             Association[1 -> {
                Complex[19.196106481999152`, -7.253069946548066], 
                Complex[38.42364894442649, -32.97218501218881]}, 2 -> {
                Complex[75.45555740059443, 0.15024995077914985`], 
                Complex[101.57804924438945`, -20.402511616933747`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.935886560118542}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.428020388516035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.155712048248098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.659589223203085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.848375652574305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.24750998887278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15216230740510475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "A", 
             Association[1 -> {
                Complex[19.428020388516035`, -7.155712048248098], 
                Complex[38.659589223203085`, -32.848375652574305`]}, 2 -> {
                Complex[75.24750998887278, 0.15216230740510475`], 
                Complex[101.35878495705765`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.943096996391617}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.428020388516035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.155712048248098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.659589223203085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.848375652574305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.24750998887278`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15216230740510475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.35878495705765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40194036052505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "A", 
             Association[1 -> {
                Complex[19.428020388516035`, -7.155712048248098], 
                Complex[38.659589223203085`, -32.848375652574305`]}, 2 -> {
                Complex[75.24750998887278, 0.15216230740510475`], 
                Complex[101.35878495705765`, -20.40194036052505]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.943408586040319}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.656402573483003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.06168715326511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.892354381854474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.04333425978076`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15410253608764446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 
             Association[1 -> {
                Complex[19.656402573483003`, -7.06168715326511], 
                Complex[38.892354381854474`, -32.727912000016886`]}, 2 -> {
                Complex[75.04333425978076, 0.15410253608764446`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.950715133899286}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.656402573483003`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.06168715326511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"38.892354381854474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.727912000016886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"75.04333425978076`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15410253608764446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"101.14333993482663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.401351638669528`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 
             Association[1 -> {
                Complex[19.656402573483003`, -7.06168715326511], 
                Complex[38.892354381854474`, -32.727912000016886`]}, 2 -> {
                Complex[75.04333425978076, 0.15410253608764446`], 
                Complex[101.14333993482663`, -20.401351638669528`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.951896438092741}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.88146580099659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.122149216633446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.610595426395264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.84276823492078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15607107631331532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506859`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400745136126783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 
             Association[1 -> {
                Complex[19.88146580099659, -6.970792147471287], 
                Complex[39.122149216633446`, -32.610595426395264`]}, 2 -> {
                Complex[74.84276823492078, 0.15607107631331532`], 
                Complex[100.93145144506859`, -20.400745136126783`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.959271242249092}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"19.88146580099659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.970792147471287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.122149216633446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.610595426395264`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.84276823492078`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.15607107631331532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.93145144506859`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.400745136126783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 
             Association[1 -> {
                Complex[19.88146580099659, -6.970792147471287], 
                Complex[39.122149216633446`, -32.610595426395264`]}, 2 -> {
                Complex[74.84276823492078, 0.15607107631331532`], 
                Complex[100.93145144506859`, -20.400745136126783`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.960604302363524}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.10340314443287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.3491592528931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.64557540947717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580683946848076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.7228822269972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.4001205101715`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 
             Association[1 -> {
                Complex[20.10340314443287, -6.882843306606507], 
                Complex[39.3491592528931, -32.49624631678466]}, 2 -> {
                Complex[74.64557540947717, 0.1580683946848076], 
                Complex[100.7228822269972, -20.4001205101715]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.96799852773867}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.10340314443287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.882843306606507`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.3491592528931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.49624631678466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.64557540947717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580683946848076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.7228822269972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.4001205101715`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 
             Association[1 -> {
                Complex[20.10340314443287, -6.882843306606507], 
                Complex[39.3491592528931, -32.49624631678466]}, 2 -> {
                Complex[74.64557540947717, 0.1580683946848076], 
                Complex[100.7228822269972, -20.4001205101715]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.968681334937229}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.322390549817726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.797673797918388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.573553276414586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.38470160682706`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.45154138132087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1600949836664982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 
             Association[1 -> {
                Complex[20.322390549817726`, -6.797673797918388], 
                Complex[39.573553276414586`, -32.38470160682706]}, 2 -> {
                Complex[74.45154138132087, 0.1600949836664982], 
                Complex[100.51741711927747`, -20.399477392046542`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.976027226524366}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.322390549817726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.797673797918388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.573553276414586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.38470160682706`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.45154138132087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1600949836664982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.51741711927747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.399477392046542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 
             Association[1 -> {
                Complex[20.322390549817726`, -6.797673797918388], 
                Complex[39.573553276414586`, -32.38470160682706]}, 2 -> {
                Complex[74.45154138132087, 0.1600949836664982], 
                Complex[100.51741711927747`, -20.399477392046542`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.975266474077376}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.53858898448397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.79548545383973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.27581271779224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.26047102973546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1621513606638985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.3148602374095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.398815388055127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "A", 
             Association[1 -> {
                Complex[20.53858898448397, -6.715131583883614], 
                Complex[39.79548545383973, -32.27581271779224]}, 2 -> {
                Complex[74.26047102973546, 0.1621513606638985], 
                Complex[100.3148602374095, -20.398815388055127`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.982484258156626}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.53858898448397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.715131583883614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"39.79548545383973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.27581271779224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.26047102973546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1621513606638985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.3148602374095`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.398815388055127`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "A", 
             Association[1 -> {
                Complex[20.53858898448397, -6.715131583883614], 
                Complex[39.79548545383973, -32.27581271779224]}, 2 -> {
                Complex[74.26047102973546, 0.1621513606638985], 
                Complex[100.3148602374095, -20.398815388055127`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.979620674271401}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.752146250400717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.635077651408368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340219`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07218613811635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16423806737529167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39813408035839`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "A", 
             Association[1 -> {
                Complex[20.752146250400717`, -6.635077651408368], 
                Complex[40.01509712100966, -32.16944381340219]}, 2 -> {
                Complex[74.07218613811635, 0.16423806737529167`], 
                Complex[100.11503259520978`, -20.39813408035839]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.986630607053689}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.752146250400717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.635077651408368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.01509712100966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.16944381340219`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"74.07218613811635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16423806737529167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"100.11503259520978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39813408035839`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "A", 
             Association[1 -> {
                Complex[20.752146250400717`, -6.635077651408368], 
                Complex[40.01509712100966, -32.16944381340219]}, 2 -> {
                Complex[74.07218613811635, 0.16423806737529167`], 
                Complex[100.11503259520978`, -20.39813408035839]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.98126838732462}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.963198524196073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.557384506607896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.065470319069306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.88652337816677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936818696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "A", 
             Association[1 -> {
                Complex[20.963198524196073`, -6.557384506607896], 
                Complex[40.23251830075455, -32.065470319069306`]}, 2 -> {
                Complex[73.88652337816677, 0.16635566936818696`], 
                Complex[99.91777008789096, -20.397433027529207`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.988005680116603}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"20.963198524196073`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.557384506607896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.23251830075455`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.065470319069306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.88652337816677`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16635566936818696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.91777008789096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.397433027529207`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "A", 
             Association[1 -> {
                Complex[20.963198524196073`, -6.557384506607896], 
                Complex[40.23251830075455, -32.065470319069306`]}, 2 -> {
                Complex[73.88652337816677, 0.16635566936818696`], 
                Complex[99.91777008789096, -20.397433027529207`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.980101193354219}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.171871672770024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.481934887900368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.447868998641226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.963777656737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.70333259061725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16850475584425448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.72292177174809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 
             Association[1 -> {
                Complex[21.171871672770024`, -6.481934887900368], 
                Complex[40.447868998641226`, -31.963777656737]}, 2 -> {
                Complex[73.70333259061725, 0.16850475584425448`], 
                Complex[99.72292177174809, -20.39671176490144]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.986529155650473}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.171871672770024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.481934887900368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.447868998641226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.963777656737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.70333259061725`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16850475584425448`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.72292177174809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39671176490144`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 
             Association[1 -> {
                Complex[21.171871672770024`, -6.481934887900368], 
                Complex[40.447868998641226`, -31.963777656737]}, 2 -> {
                Complex[73.70333259061725, 0.16850475584425448`], 
                Complex[99.72292177174809, -20.39671176490144]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.976401148832032}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.378282383376405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.408620659800499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.661260315234074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.864260158083315`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.52247531084704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17068593956353983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 
             Association[1 -> {
                Complex[21.378282383376405`, -6.408620659800499], 
                Complex[40.661260315234074`, -31.864260158083315`]}, 2 -> {
                Complex[73.52247531084704, 0.17068593956353983`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.982517821495007}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.378282383376405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.408620659800499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.661260315234074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.864260158083315`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.52247531084704`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17068593956353983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.53034838881473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39596980474617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 
             Association[1 -> {
                Complex[21.378282383376405`, -6.408620659800499], 
                Complex[40.661260315234074`, -31.864260158083315`]}, 2 -> {
                Complex[73.52247531084704, 0.17068593956353983`], 
                Complex[99.53034838881473, -20.39596980474617]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.9707740694646585`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.58253913933037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.76682012623099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34382349807167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1728998569070958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "A", 
             Association[1 -> {
                Complex[21.58253913933037, -6.337341857243096], 
                Complex[40.87279540575696, -31.76682012623099]}, 2 -> {
                Complex[73.34382349807167, 0.1728998569070958], 
                Complex[99.33992109514008, -20.39520663629768]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.976610480370252}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.58253913933037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.337341857243096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"40.87279540575696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.76682012623099`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.34382349807167`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1728998569070958`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.33992109514008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39520663629768`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "A", 
             Association[1 -> {
                Complex[21.58253913933037, -6.337341857243096], 
                Complex[40.87279540575696, -31.76682012623099]}, 2 -> {
                Complex[73.34382349807167, 0.1728998569070958], 
                Complex[99.33992109514008, -20.39520663629768]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.964022741210993}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.78474306649485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.08257031208464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.671367021850585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.167258434751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1751471680593818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39442172564926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 
             Association[1 -> {
                Complex[21.78474306649485, -6.268005856060312], 
                Complex[41.08257031208464, -31.671367021850585`]}, 2 -> {
                Complex[73.167258434751, 0.1751471680593818], 
                Complex[99.15152035933141, -20.39442172564926]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.96963470323678}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.78474306649485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.268005856060312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.08257031208464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.671367021850585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"73.167258434751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1751471680593818`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"99.15152035933141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39442172564926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 
             Association[1 -> {
                Complex[21.78474306649485, -6.268005856060312], 
                Complex[41.08257031208464, -31.671367021850585`]}, 2 -> {
                Complex[73.167258434751, 0.1751471680593818], 
                Complex[99.15152035933141, -20.39442172564926]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.957008982470815}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.98498867099265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.577816754044576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.99266976913438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17742855729767226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.9650350042688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39361451553301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "A", 
             Association[1 -> {
                Complex[21.98498867099265, -6.20052664977852], 
                Complex[41.290674687319935`, -31.577816754044576`]}, 2 -> {
                Complex[72.99266976913438, 0.17742855729767226`], 
                Complex[98.9650350042688, -20.39361451553301]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.962466399677627}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"21.98498867099265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.20052664977852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.290674687319935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.577816754044576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.99266976913438`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17742855729767226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.9650350042688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39361451553301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "A", 
             Association[1 -> {
                Complex[21.98498867099265, -6.20052664977852], 
                Complex[41.290674687319935`, -31.577816754044576`]}, 2 -> {
                Complex[72.99266976913438, 0.17742855729767226`], 
                Complex[98.9650350042688, -20.39361451553301]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.95054369386123}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.183364484872566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.13482421649645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.497192429524794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.486091059962376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.81995467880073`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17974473337764585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 
             Association[1 -> {
                Complex[22.183364484872566`, -6.13482421649645], 
                Complex[41.497192429524794`, -31.486091059962376`]}, 2 -> {
                Complex[72.81995467880073, 0.17974473337764585`], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.9559208775198105`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.183364484872566`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.13482421649645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.497192429524794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.486091059962376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.81995467880073`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17974473337764585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.78036136984286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.39278442499534`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 
             Association[1 -> {
                Complex[22.183364484872566`, -6.13482421649645], 
                Complex[41.497192429524794`, -31.486091059962376`]}, 2 -> {
                Complex[72.81995467880073, 0.17974473337764585`], 
                Complex[98.78036136984286, -20.39278442499534]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.945320210466795}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.379953633499717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.070823962465011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.702202238238115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.396116959927433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.6490171369839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18209643000701964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391930848977243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 
             Association[1 -> {
                Complex[22.379953633499717`, -6.070823962465011], 
                Complex[41.702202238238115`, -31.396116959927433`]}, 2 -> {
                Complex[72.6490171369839, 0.18209643000701964`], 
                Complex[98.59740257849907, -20.391930848977243`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.950688932459547}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.379953633499717`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.070823962465011`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.702202238238115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.396116959927433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.6490171369839`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18209643000701964`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.59740257849907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391930848977243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 
             Association[1 -> {
                Complex[22.379953633499717`, -6.070823962465011], 
                Complex[41.702202238238115`, -31.396116959927433`]}, 2 -> {
                Complex[72.6490171369839, 0.18209643000701964`], 
                Complex[98.59740257849907, -20.391930848977243`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.941886332589634}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.574834336069365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.008456231284855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.47976726661949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18448440640095548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391053157806226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "A", 
             Association[1 -> {
                Complex[22.574834336069365`, -6.008456231284855], 
                Complex[41.905778105062396`, -31.30782627713036]}, 2 -> {
                Complex[72.47976726661949, 0.18448440640095548`], 
                Complex[98.41606788851907, -20.391053157806226`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.947311717430662}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.574834336069365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.008456231284855`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"41.905778105062396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.30782627713036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.47976726661949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18448440640095548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.41606788851907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.391053157806226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "A", 
             Association[1 -> {
                Complex[22.574834336069365`, -6.008456231284855], 
                Complex[41.905778105062396`, -31.30782627713036]}, 2 -> {
                Complex[72.47976726661949, 0.18448440640095548`], 
                Complex[98.41606788851907, -20.391053157806226`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.940641534432248}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.76808034873237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.9476558694891155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.31212076958602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18690944791455164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 
             Association[1 -> {
                Complex[22.76808034873237, -5.9476558694891155`], 
                Complex[42.10798974770687, -31.221155212774136`]}, 2 -> {
                Complex[72.31212076958602, 0.18690944791455164`], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.946180029669843}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.76808034873237`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.9476558694891155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.10798974770687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.221155212774136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.31212076958602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18690944791455164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.23627212250696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.390150696605232`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 
             Association[1 -> {
                Complex[22.76808034873237, -5.9476558694891155`], 
                Complex[42.10798974770687, -31.221155212774136`]}, 2 -> {
                Complex[72.31212076958602, 0.18690944791455164`], 
                Complex[98.23627212250696, -20.390150696605232`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.941845670855905}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.959761358270317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.888361840780239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.14599842066895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18937236674901933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38922278462222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "A", 
             Association[1 -> {
                Complex[22.959761358270317`, -5.888361840780239], 
                Complex[42.30890299533776, -31.136043969043037`]}, 2 -> {
                Complex[72.14599842066895, 0.18937236674901933`], 
                Complex[98.05793516060473, -20.38922278462222]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.947544127744463}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"22.959761358270317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.888361840780239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.30890299533776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.136043969043037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"72.14599842066895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18937236674901933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"98.05793516060473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38922278462222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "A", 
             Association[1 -> {
                Complex[22.959761358270317`, -5.888361840780239], 
                Complex[42.30890299533776, -31.136043969043037`]}, 2 -> {
                Complex[72.14599842066895, 0.18937236674901933`], 
                Complex[98.05793516060473, -20.38922278462222]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20., -5.945629049214791}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.149943332992876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.830516882419161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.98132561745237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19187400272919972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "A", 
             Association[1 -> {
                Complex[23.149943332992876`, -5.830516882419161], 
                Complex[42.50858013183331, -31.052436413482706`]}, 2 -> {
                Complex[71.98132561745237, 0.19187400272919972`], 
                Complex[97.88098148963748, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.951524061321848}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.149943332992876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.830516882419161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.50858013183331`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.052436413482706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.98132561745237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19187400272919972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.88098148963748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.388268714483253`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "A", 
             Association[1 -> {
                Complex[23.149943332992876`, -5.830516882419161], 
                Complex[42.50858013183331, -31.052436413482706`]}, 2 -> {
                Complex[71.98132561745237, 0.19187400272919972`], 
                Complex[97.88098148963748, -20.388268714483253`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.951997613085303}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.338688836493038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.774067198270846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.970279779373037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.8180319787172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1944152241510169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "A", 
             Association[1 -> {
                Complex[23.338688836493038`, -5.774067198270846], 
                Complex[42.70708020251328, -30.970279779373037`]}, 2 -> {
                Complex[71.8180319787172, 0.1944152241510169], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.95811445607895}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.338688836493038`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.774067198270846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.70708020251328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.970279779373037`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.8180319787172`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1944152241510169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.70533980076394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.387287751370756`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "A", 
             Association[1 -> {
                Complex[23.338688836493038`, -5.774067198270846], 
                Complex[42.70708020251328, -30.970279779373037`]}, 2 -> {
                Complex[71.8180319787172, 0.1944152241510169], 
                Complex[97.70533980076394, -20.387287751370756`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.9608299867701025`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.52605730903988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7189621838426925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.90445928906574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.889524397498597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.65605098505654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1969969286982196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 
             Association[1 -> {
                Complex[23.52605730903988, -5.7189621838426925`], 
                Complex[42.90445928906574, -30.889524397498597`]}, 2 -> {
                Complex[71.65605098505654, 0.1969969286982196], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.967180681508079}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.52605730903988`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.7189621838426925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"42.90445928906574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.889524397498597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.65605098505654`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1969969286982196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.5309426293395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.386279132127584`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 
             Association[1 -> {
                Complex[23.52605730903988, -5.7189621838426925`], 
                Complex[42.90445928906574, -30.889524397498597`]}, 2 -> {
                Complex[71.65605098505654, 0.1969969286982196], 
                Complex[97.5309426293395, -20.386279132127584`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.971865436209501}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.712105320680124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.66515417934074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.10077075669193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.49531965635687`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19962004442847947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.385242064287233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 
             Association[1 -> {
                Complex[23.712105320680124`, -5.66515417934074], 
                Complex[43.10077075669193, -30.810123455401047`]}, 2 -> {
                Complex[71.49531965635687, 0.19962004442847947`], 
                Complex[97.35772603163758, -20.385242064287233`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.978445636793318}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.712105320680124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.66515417934074`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.10077075669193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.810123455401047`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.49531965635687`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.19962004442847947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.35772603163758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.385242064287233`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 
             Association[1 -> {
                Complex[23.712105320680124`, -5.66515417934074], 
                Complex[43.10077075669193, -30.810123455401047`]}, 2 -> {
                Complex[71.49531965635687, 0.19962004442847947`], 
                Complex[97.35772603163758, -20.385242064287233`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.984684253013568}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.89688679952995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.61259824734414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.29606547690717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.73203278076685`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.33577826157267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20228553082947315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.1856292938539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "A", 
             Association[1 -> {
                Complex[23.89688679952995, -5.61259824734414], 
                Complex[43.29606547690717, -30.73203278076685]}, 2 -> {
                Complex[71.33577826157267, 0.20228553082947315`], 
                Complex[97.1856292938539, -20.38417572502943]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.99146893887879}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"23.89688679952995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.61259824734414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.29606547690717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.73203278076685`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.33577826157267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20228553082947315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.1856292938539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38417572502943`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "A", 
             Association[1 -> {
                Complex[23.89688679952995, -5.61259824734414], 
                Complex[43.29606547690717, -30.73203278076685]}, 2 -> {
                Complex[71.33577826157267, 0.20228553082947315`], 
                Complex[97.1856292938539, -20.38417572502943]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.998685734240141}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.0804532382449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.490392028946715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.655210646076952`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.1773700568739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20499437994616249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "A", 
             Association[1 -> {
                Complex[24.0804532382449, -5.561251972178108], 
                Complex[43.490392028946715`, -30.655210646076952`]}, 2 -> {
                Complex[71.1773700568739, 0.20499437994616249`], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -6.005624213355374}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.0804532382449`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561251972178108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.490392028946715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.655210646076952`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.1773700568739`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20499437994616249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"97.0145946694708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38307926005996`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "A", 
             Association[1 -> {
                Complex[24.0804532382449, -5.561251972178108], 
                Complex[43.490392028946715`, -30.655210646076952`]}, 2 -> {
                Complex[71.1773700568739, 0.20499437994616249`], 
                Complex[97.0145946694708, -20.38307926005996]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -6.013074632864557}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.262853881242368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.5110752784691694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.6837968823168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.579617592043476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.02004104879211`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20774761758097854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38195178241304`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 
             Association[1 -> {
                Complex[24.262853881242368`, -5.5110752784691694`], 
                Complex[43.6837968823168, -30.579617592043476`]}, 2 -> {
                Complex[71.02004104879211, 0.20774761758097854`], 
                Complex[96.84456714160432, -20.38195178241304]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -6.020086284858756}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.262853881242368`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.5110752784691694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.6837968823168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.579617592043476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"71.02004104879211`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20774761758097854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.84456714160432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38195178241304`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 
             Association[1 -> {
                Complex[24.262853881242368`, -5.5110752784691694`], 
                Complex[43.6837968823168, -30.579617592043476`]}, 2 -> {
                Complex[71.02004104879211, 0.20774761758097854`], 
                Complex[96.84456714160432, -20.38195178241304]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -6.0268741571323}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.444135894902008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.462030266708765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.50521626769631`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.8637397794511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117393`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 
             Association[1 -> {
                Complex[24.444135894902008`, -5.462030266708765], 
                Complex[43.87632456268656, -30.50521626769631]}, 2 -> {
                Complex[70.8637397794511, 0.2105463045690771], 
                Complex[96.6754942074181, -20.38079237117393]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -6.033847597816775}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.444135894902008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.462030266708765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"43.87632456268656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.50521626769631`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.8637397794511`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2105463045690771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.6754942074181`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38079237117393`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 
             Association[1 -> {
                Complex[24.444135894902008`, -5.462030266708765], 
                Complex[43.87632456268656, -30.50521626769631]}, 2 -> {
                Complex[70.8637397794511, 0.2105463045690771], 
                Complex[96.6754942074181, -20.38079237117393]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -6.0389884413466755`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.624344522673923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.414081063937796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.431971285264723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.7084171313574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21339153813132042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.379600070118972`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 
             Association[1 -> {
                Complex[24.624344522673923`, -5.414081063937796], 
                Complex[44.06801780302345, -30.431971285264723`]}, 2 -> {
                Complex[70.7084171313574, 0.21339153813132042`], 
                Complex[96.50732568207661, -20.379600070118972`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -6.045787743386452}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.624344522673923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.414081063937796`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.06801780302345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.431971285264723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.7084171313574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21339153813132042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.50732568207661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.379600070118972`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 
             Association[1 -> {
                Complex[24.624344522673923`, -5.414081063937796], 
                Complex[44.06801780302345, -30.431971285264723`]}, 2 -> {
                Complex[70.7084171313574, 0.21339153813132042`], 
                Complex[96.50732568207661, -20.379600070118972`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.048331444911084}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.803523226774285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.367193687912322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.25891768162856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.35984908824372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.554026149556`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21628445330793847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.3400135200408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.378373886270055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "A", 
             Association[1 -> {
                Complex[24.803523226774285`, -5.367193687912322], 
                Complex[44.25891768162856, -30.35984908824372]}, 2 -> {
                Complex[70.554026149556, 0.21628445330793847`], 
                Complex[96.3400135200408, -20.378373886270055`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.054812289985437}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.803523226774285`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.367193687912322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.25891768162856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.35984908824372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.554026149556`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21628445330793847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.3400135200408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.378373886270055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "A", 
             Association[1 -> {
                Complex[24.803523226774285`, -5.367193687912322], 
                Complex[44.25891768162856, -30.35984908824372]}, 2 -> {
                Complex[70.554026149556, 0.21628445330793847`], 
                Complex[96.3400135200408, -20.378373886270055`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21., -6.054013594831342}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.981713817934338`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.321335923317819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.40052187923786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21922622447656767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "A", 
             Association[1 -> {
                Complex[24.981713817934338`, -5.321335923317819], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[70.40052187923786, 0.21922622447656767`], 
                Complex[96.17351165179056, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21., -6.060048365675968}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"24.981713817934338`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.321335923317819`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.449063748516636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.288817831238717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.40052187923786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.21922622447656767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.17351165179056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.377112788359476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "A", 
             Association[1 -> {
                Complex[24.981713817934338`, -5.321335923317819], 
                Complex[44.449063748516636`, -30.288817831238717`]}, 2 -> {
                Complex[70.40052187923786, 0.21922622447656767`], 
                Complex[96.17351165179056, -20.377112788359476`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.055536163967935}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.158956574486158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.24786121712583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22221806695837287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 
             Association[1 -> {
                Complex[25.158956574486158`, -5.276477208780441], 
                Complex[44.63849414140556, -30.218847270360484`]}, 2 -> {
                Complex[70.24786121712583, 0.22221806695837287`], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.061040899153194}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.158956574486158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.276477208780441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.63849414140556`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.218847270360484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.24786121712583`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22221806695837287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"96.00777583429837`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.375815705201227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 
             Association[1 -> {
                Complex[25.158956574486158`, -5.276477208780441], 
                Complex[44.63849414140556, -30.218847270360484`]}, 2 -> {
                Complex[70.24786121712583, 0.22221806695837287`], 
                Complex[96.00777583429837, -20.375815705201227`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.052914525076065}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.335290351911958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.232588533576678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.14990866309333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.09600277517207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22526123871674927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "A", 
             Association[1 -> {
                Complex[25.335290351911958`, -5.232588533576678], 
                Complex[44.82724569242562, -30.14990866309333]}, 2 -> {
                Complex[70.09600277517207, 0.22526123871674927`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.0578668999215415`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.335290351911958`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.232588533576678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"44.82724569242562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.14990866309333`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"70.09600277517207`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22526123871674927`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.84276351378436`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.374481523964015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "A", 
             Association[1 -> {
                Complex[25.335290351911958`, -5.232588533576678], 
                Complex[44.82724569242562, -30.14990866309333]}, 2 -> {
                Complex[70.09600277517207, 0.22526123871674927`], 
                Complex[95.84276351378436, -20.374481523964015`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.046670141416445}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.51075268384907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.01535402652587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.081974676689654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.9449067552762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2283570421533727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.373109088340822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "A", 
             Association[1 -> {
                Complex[25.51075268384907, -5.189642343075509], 
                Complex[45.01535402652587, -30.081974676689654`]}, 2 -> {
                Complex[69.9449067552762, 0.2283570421533727], 
                Complex[95.67843369946034, -20.373109088340822`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.0511108448103235`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.51075268384907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.189642343075509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.01535402652587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.081974676689654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.9449067552762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2283570421533727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.67843369946034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.373109088340822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "A", 
             Association[1 -> {
                Complex[25.51075268384907, -5.189642343075509], 
                Complex[45.01535402652587, -30.081974676689654`]}, 2 -> {
                Complex[69.9449067552762, 0.2283570421533727], 
                Complex[95.67843369946034, -20.373109088340822`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.037695812979442}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.685379875427014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.147612452062529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.015019304257965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.79453483388642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23150682600686606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3716971966093`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "A", 
             Association[1 -> {
                Complex[25.685379875427014`, -5.147612452062529], 
                Complex[45.20285365244138, -30.015019304257965`]}, 2 -> {
                Complex[69.79453483388642, 0.23150682600686606`], 
                Complex[95.51474684712201, -20.3716971966093]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.041714384474519}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.685379875427014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.147612452062529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.20285365244138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.015019304257965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.79453483388642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23150682600686606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.51474684712201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.3716971966093`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "A", 
             Association[1 -> {
                Complex[25.685379875427014`, -5.147612452062529], 
                Complex[45.20285365244138, -30.015019304257965`]}, 2 -> {
                Complex[69.79453483388642, 0.23150682600686606`], 
                Complex[95.51474684712201, -20.3716971966093]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.027059758309894}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.8592070897119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.389778046984475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.949017787808245`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.64485005547786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23471198735987034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.370244599576857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 
             Association[1 -> {
                Complex[25.8592070897119, -5.106473965194025], 
                Complex[45.389778046984475`, -29.949017787808245`]}, 2 -> {
                Complex[69.64485005547786, 0.23471198735987034`], 
                Complex[95.35166475158147, -20.370244599576857`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.030773025971469}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"25.8592070897119`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.106473965194025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.389778046984475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.949017787808245`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.64485005547786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23471198735987034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.35166475158147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.370244599576857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 
             Association[1 -> {
                Complex[25.8592070897119, -5.106473965194025], 
                Complex[45.389778046984475`, -29.949017787808245`]}, 2 -> {
                Complex[69.64485005547786, 0.23471198735987034`], 
                Complex[95.35166475158147, -20.370244599576857`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.015826040931079}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.03226842794698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.49581673401624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23797397376075155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.368749998403654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 
             Association[1 -> {
                Complex[26.03226842794698, -5.066203203916086], 
                Complex[45.57615973333944, -29.88394654760415]}, 2 -> {
                Complex[69.49581673401624, 0.23797397376075155`], 
                Complex[95.18915044704522, -20.368749998403654`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.01935798603877}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.03226842794698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.066203203916086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.57615973333944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.88394654760415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.49581673401624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23797397376075155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.18915044704522`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.368749998403654`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 
             Association[1 -> {
                Complex[26.03226842794698, -5.066203203916086], 
                Complex[45.57615973333944, -29.88394654760415]}, 2 -> {
                Complex[69.49581673401624, 0.23797397376075155`], 
                Complex[95.18915044704522, -20.368749998403654`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.004936394033389}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.20459700420211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.819783117245702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.34740036161425`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546682113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36721204229602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "A", 
             Association[1 -> {
                Complex[26.20459700420211, -5.026777639259069], 
                Complex[45.76203035396384, -29.819783117245702`]}, 2 -> {
                Complex[69.34740036161425, 0.24129428546682113`], 
                Complex[95.02716811464276, -20.36721204229602]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.008404292153911}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.20459700420211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.026777639259069`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.76203035396384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.819783117245702`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.34740036161425`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24129428546682113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"95.02716811464276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.36721204229602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "A", 
             Association[1 -> {
                Complex[26.20459700420211, -5.026777639259069], 
                Complex[45.76203035396384, -29.819783117245702`]}, 2 -> {
                Complex[69.34740036161425, 0.24129428546682113`], 
                Complex[95.02716811464276, -20.36721204229602]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -5.9951581034145285`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.376225014979173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.988175829983501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.19956752367546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24467447781636717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.365629326062496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 
             Association[1 -> {
                Complex[26.376225014979173`, -4.988175829983501], 
                Complex[45.94742073863614, -29.756506083970773`]}, 2 -> {
                Complex[69.19956752367546, 0.24467447781636717`], 
                Complex[94.86568299639735, -20.365629326062496`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -5.998665482724013}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.376225014979173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.988175829983501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"45.94742073863614`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.756506083970773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.19956752367546`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24467447781636717`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.86568299639735`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.365629326062496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 
             Association[1 -> {
                Complex[26.376225014979173`, -4.988175829983501], 
                Complex[45.94742073863614, -29.756506083970773`]}, 2 -> {
                Complex[69.19956752367546, 0.24467447781636717`], 
                Complex[94.86568299639735, -20.365629326062496`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -5.987079616491665}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.54718380426279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9503773656115`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"46.13236096813211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.05228581989404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2481161637376161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 
             Association[1 -> {
                Complex[26.54718380426279, -4.9503773656115], 
                Complex[46.13236096813211, -29.694095033720565`]}, 2 -> {
                Complex[69.05228581989404, 0.2481161637376161], 
                Complex[94.70466131500459, -20.364000387523564`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -5.9907142764226045`}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.54718380426279`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.9503773656115`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"46.13236096813211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.694095033720565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"69.05228581989404`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2481161637376161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.70466131500459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.364000387523564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 
             Association[1 -> {
                Complex[26.54718380426279, -4.9503773656115], 
                Complex[46.13236096813211, -29.694095033720565`]}, 2 -> {
                Complex[69.05228581989404, 0.2481161637376161], 
                Complex[94.70466131500459, -20.364000387523564`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -5.981131502260973}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.71750392445519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.91336281392886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.31688043396312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.63253050056466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.90552379054706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.25162101640318657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 
             Association[1 -> {
                Complex[26.71750392445519, -4.91336281392886], 
                Complex[46.31688043396312, -29.63253050056466]}, 2 -> {
                Complex[68.90552379054706, 0.25162101640318657`], 
                Complex[94.54407019885232, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -5.984966420533766}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.71750392445519`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.91336281392886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.31688043396312`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.63253050056466`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.90552379054706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.25162101640318657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.54407019885232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.362323704765814`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 
             Association[1 -> {
                Complex[26.71750392445519, -4.91336281392886], 
                Complex[46.31688043396312, -29.63253050056466]}, 2 -> {
                Complex[68.90552379054706, 0.25162101640318657`], 
                Complex[94.54407019885232, -20.362323704765814`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -5.977615913115658}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.88721519359033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.8771136725869555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.501007894566264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.57179392012435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.75925084757176`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2551907720394873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.3838776117713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 
             Association[1 -> {
                Complex[26.88721519359033, -4.8771136725869555`], 
                Complex[46.501007894566264`, -29.57179392012435]}, 2 -> {
                Complex[68.75925084757176, 0.2551907720394873], 
                Complex[94.3838776117713, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -5.981711350202071}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"26.88721519359033`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.8771136725869555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.501007894566264`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.57179392012435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.75925084757176`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2551907720394873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.3838776117713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.360597693230243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 
             Association[1 -> {
                Complex[26.88721519359033, -4.8771136725869555`], 
                Complex[46.501007894566264`, -29.57179392012435]}, 2 -> {
                Complex[68.75925084757176, 0.2551907720394873], 
                Complex[94.3838776117713, -20.360597693230243`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.2, -5.976734796328074}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.056346749183458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.841612324474782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.511867586673578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.61343720997206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2588272329011793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "A", 
             Association[1 -> {
                Complex[27.056346749183458`, -4.841612324474782], 
                Complex[46.684771528299024`, -29.511867586673578`]}, 2 -> {
                Complex[68.61343720997206, 0.2588272329011793], 
                Complex[94.22405228705699, -20.358820702623657`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -5.981140538289592}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.056346749183458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.841612324474782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.684771528299024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.511867586673578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.61343720997206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2588272329011793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.22405228705699`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.358820702623657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "A", 
             Association[1 -> {
                Complex[27.056346749183458`, -4.841612324474782], 
                Complex[46.684771528299024`, -29.511867586673578`]}, 2 -> {
                Complex[68.61343720997206, 0.2588272329011793], 
                Complex[94.22405228705699, -20.358820702623657`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.3, -5.978612330971318}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.22492709903808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.86819898355647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.452734613629456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.46805384314331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2625322704216664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "A", 
             Association[1 -> {
                Complex[27.22492709903808, -4.806841996564799], 
                Complex[46.86819898355647, -29.452734613629456`]}, 2 -> {
                Complex[68.46805384314331, 0.2625322704216664], 
                Complex[94.06456366534842, -20.35699101364115]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -5.9833694829782935`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.22492709903808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.806841996564799`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"46.86819898355647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.452734613629456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.46805384314331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2625322704216664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"94.06456366534842`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.35699101364115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "A", 
             Association[1 -> {
                Complex[27.22492709903808, -4.806841996564799], 
                Complex[46.86819898355647, -29.452734613629456`]}, 2 -> {
                Complex[68.46805384314331, 0.2625322704216664], 
                Complex[94.06456366534842, -20.35699101364115]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.4, -5.983309970605672}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.392984169302537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.772786721969353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.32307240174265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2663078285515145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486676`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "A", 
             Association[1 -> {
                Complex[27.392984169302537`, -4.772786721969353], 
                Complex[47.051317426301225`, -29.394378897177]}, 2 -> {
                Complex[68.32307240174265, 0.2663078285515145], 
                Complex[93.90538183598731, -20.355106834486676`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -5.98845197425325}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.392984169302537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.772786721969353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.051317426301225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.394378897177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.32307240174265`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2663078285515145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.90538183598731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.355106834486676`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "A", 
             Association[1 -> {
                Complex[27.392984169302537`, -4.772786721969353], 
                Complex[47.051317426301225`, -29.394378897177]}, 2 -> {
                Complex[68.32307240174265, 0.2663078285515145], 
                Complex[93.90538183598731, -20.355106834486676`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -5.99083366711814}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.56054535004208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.739431304971095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.234153585269965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.336785082799015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.17846517576804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27015592729763743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 
             Association[1 -> {
                Complex[27.56054535004208, -4.739431304971095], 
                Complex[47.234153585269965`, -29.336785082799015`]}, 2 -> {
                Complex[68.17846517576804, 0.27015592729763743`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -5.996386308146163}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.56054535004208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.739431304971095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.234153585269965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.336785082799015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.17846517576804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27015592729763743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.7464774815166`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.353166297177687`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 
             Association[1 -> {
                Complex[27.56054535004208, -4.739431304971095], 
                Complex[47.234153585269965`, -29.336785082799015`]}, 2 -> {
                Complex[68.17846517576804, 0.27015592729763743`], 
                Complex[93.7464774815166, -20.353166297177687`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.001133037416537}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.727637538568867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.706761288816323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.03420503953862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27407866647716145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.351167453618455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 
             Association[1 -> {
                Complex[27.727637538568867`, -4.706761288816323], 
                Complex[47.41673379509784, -29.279938534507]}, 2 -> {
                Complex[68.03420503953862, 0.27407866647716145`], 
                Complex[93.58782182500669, -20.351167453618455`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.007113191742004}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.727637538568867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.706761288816323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.41673379509784`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.279938534507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"68.03420503953862`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27407866647716145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.58782182500669`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.351167453618455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 
             Association[1 -> {
                Complex[27.727637538568867`, -4.706761288816323], 
                Complex[47.41673379509784, -29.279938534507]}, 2 -> {
                Complex[68.03420503953862, 0.27407866647716145`], 
                Complex[93.58782182500669, -20.351167453618455`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.0140919321099675`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.894287180751792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.674762926083082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.599084037582415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.223825306591664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.89026540329692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2780782297010494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.349108271425646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "A", 
             Association[1 -> {
                Complex[27.894287180751792`, -4.674762926083082], 
                Complex[47.599084037582415`, -29.223825306591664`]}, 2 -> {
                Complex[67.89026540329692, 0.2780782297010494], 
                Complex[93.42938657992539, -20.349108271425646`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.020504714919566}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"27.894287180751792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.674762926083082`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.599084037582415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.223825306591664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.89026540329692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2780782297010494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.42938657992539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.349108271425646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "A", 
             Association[1 -> {
                Complex[27.894287180751792`, -4.674762926083082], 
                Complex[47.599084037582415`, -29.223825306591664`]}, 2 -> {
                Complex[67.89026540329692, 0.2780782297010494], 
                Complex[93.42938657992539, -20.349108271425646`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.029509468842052}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.060520310510153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.6434231514550905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.78122998129108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.16843211773069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.74662016717633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.282156888603788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.27114390229022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 
             Association[1 -> {
                Complex[28.060520310510153`, -4.6434231514550905`], 
                Complex[47.78122998129108, -29.16843211773069]}, 2 -> {
                Complex[67.74662016717633, 0.282156888603788], 
                Complex[93.27114390229022, -20.34698662948813]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.036343357848673}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.060520310510153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.6434231514550905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.78122998129108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.16843211773069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.74662016717633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.282156888603788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.27114390229022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34698662948813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 
             Association[1 -> {
                Complex[28.060520310510153`, -4.6434231514550905`], 
                Complex[47.78122998129108, -29.16843211773069]}, 2 -> {
                Complex[67.74662016717633, 0.282156888603788], 
                Complex[93.27114390229022, -20.34698662948813]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.047070550734331}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.22636258767924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.113746327310373`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.60324367729916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2863170073368824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "A", 
             Association[1 -> {
                Complex[28.22636258767924, -4.612729556752129], 
                Complex[47.96319701970124, -29.113746327310373`]}, 2 -> {
                Complex[67.60324367729916, 0.2863170073368824], 
                Complex[93.11306634486286, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.054290046525747}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.22636258767924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.612729556752129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"47.96319701970124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.113746327310373`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.60324367729916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2863170073368824`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"93.11306634486286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.344800313241485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "A", 
             Association[1 -> {
                Complex[28.22636258767924, -4.612729556752129], 
                Complex[47.96319701970124, -29.113746327310373`]}, 2 -> {
                Complex[67.60324367729916, 0.2863170073368824], 
                Complex[93.11306634486286, -20.344800313241485`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.066305941340505}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.391839334421146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.582670368083356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834188`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.46011068378857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.342547009636124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 
             Association[1 -> {
                Complex[28.391839334421146`, -4.582670368083356], 
                Complex[48.14501030804771, -29.059755913834188`]}, 2 -> {
                Complex[67.46011068378857, 0.2905610473453296], 
                Complex[92.95512681316393, -20.342547009636124`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.07384159912936}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.391839334421146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.582670368083356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.14501030804771`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.059755913834188`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.46011068378857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2905610473453296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.95512681316393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.342547009636124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 
             Association[1 -> {
                Complex[28.391839334421146`, -4.582670368083356], 
                Complex[48.14501030804771, -29.059755913834188`]}, 2 -> {
                Complex[67.46011068378857, 0.2905610473453296], 
                Complex[92.95512681316393, -20.342547009636124`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.086545369751796}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.556975570343152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.553234425005791`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.326694799042336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.00644945530591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.31719630049454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29489157244794845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 
             Association[1 -> {
                Complex[28.556975570343152`, -4.553234425005791], 
                Complex[48.326694799042336`, -29.00644945530591]}, 2 -> {
                Complex[67.31719630049454, 0.29489157244794845`], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.094281936344446}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.556975570343152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.553234425005791`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.326694799042336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.00644945530591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.31719630049454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29489157244794845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.79729852310203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.34022430177586`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 
             Association[1 -> {
                Complex[28.556975570343152`, -4.553234425005791], 
                Complex[48.326694799042336`, -29.00644945530591]}, 2 -> {
                Complex[67.31719630049454, 0.29489157244794845`], 
                Complex[92.79729852310203, -20.34022430177586]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.106874589287909}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.721796046473646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.524411161584021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.9538161114898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.17447596624794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29931125424420046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 
             Association[1 -> {
                Complex[28.721796046473646`, -4.524411161584021], 
                Complex[48.50827527761825, -28.9538161114898]}, 2 -> {
                Complex[67.17447596624794, 0.29931125424420046`], 
                Complex[92.63955496002485, -20.337829663202015`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.1146399649076}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.721796046473646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.524411161584021`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.50827527761825`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.9538161114898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.17447596624794`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.29931125424420046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.63955496002485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.337829663202015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 
             Association[1 -> {
                Complex[28.721796046473646`, -4.524411161584021], 
                Complex[48.50827527761825, -28.9538161114898]}, 2 -> {
                Complex[67.17447596624794, 0.29931125424420046`], 
                Complex[92.63955496002485, -20.337829663202015`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.126119708505802}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.88632527823729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.68977639484416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.901845607962514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.03192540747014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3038228778721793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 
             Association[1 -> {
                Complex[28.88632527823729, -4.496190589260186], 
                Complex[48.68977639484416, -28.901845607962514`]}, 2 -> {
                Complex[67.03192540747014, 0.3038228778721793], 
                Complex[92.48186983901314, -20.33536045179569]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.133680680000596}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"28.88632527823729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.496190589260186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.68977639484416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.901845607962514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"67.03192540747014`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3038228778721793`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.48186983901314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33536045179569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 
             Association[1 -> {
                Complex[28.88632527823729, -4.496190589260186], 
                Complex[48.68977639484416, -28.901845607962514`]}, 2 -> {
                Complex[67.03192540747014, 0.3038228778721793], 
                Complex[92.48186983901314, -20.33536045179569]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.142895887118677}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.050587577562062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.468563281455599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.871222701145584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.850528221884158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.88952060197633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3084293481445193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.332813903268473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "A", 
             Association[1 -> {
                Complex[29.050587577562062`, -4.468563281455599], 
                Complex[48.871222701145584`, -28.850528221884158`]}, 2 -> {
                Complex[66.88952060197633, 0.3084293481445193], 
                Complex[92.32421706624814, -20.332813903268473`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.149969794191678}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.050587577562062`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.468563281455599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"48.871222701145584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.850528221884158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.88952060197633`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3084293481445193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.32421706624814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.332813903268473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "A", 
             Association[1 -> {
                Complex[29.050587577562062`, -4.468563281455599], 
                Complex[48.871222701145584`, -28.850528221884158`]}, 2 -> {
                Complex[66.88952060197633, 0.3084293481445193], 
                Complex[92.32421706624814, -20.332813903268473`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.155759183211922}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.21460708424427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.44152035983643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.79985476942697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.7472377438204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31313369609146635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33018712420928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "A", 
             Association[1 -> {
                Complex[29.21460708424427, -4.44152035983643], 
                Complex[49.05263867896423, -28.79985476942697]}, 2 -> {
                Complex[66.7472377438204, 0.31313369609146635`], 
                Complex[92.16657070129293, -20.33018712420928]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.162049942332851}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.21460708424427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.44152035983643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.05263867896423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.79985476942697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.7472377438204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.31313369609146635`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.16657070129293`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33018712420928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "A", 
             Association[1 -> {
                Complex[29.21460708424427, -4.44152035983643], 
                Complex[49.05263867896423, -28.79985476942697]}, 2 -> {
                Complex[66.7472377438204, 0.31313369609146635`], 
                Complex[92.16657070129293, -20.33018712420928]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.163467921670487}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.37840779669111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.23404877498035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.7498165948108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.60505320903809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3179390859428899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651893`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "A", 
             Association[1 -> {
                Complex[29.37840779669111, -4.4150534821866145`], 
                Complex[49.23404877498035, -28.7498165948108]}, 2 -> {
                Complex[66.60505320903809, 0.3179390859428899], 
                Complex[92.00890492013563, -20.327477084651893`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.168724990793299}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.37840779669111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.4150534821866145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.23404877498035`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.7498165948108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.60505320903809`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3179390859428899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"92.00890492013563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.327477084651893`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "A", 
             Association[1 -> {
                Complex[29.37840779669111, -4.4150534821866145`], 
                Complex[49.23404877498035, -28.7498165948108]}, 2 -> {
                Complex[66.60505320903809, 0.3179390859428899], 
                Complex[92.00890492013563, -20.327477084651893`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.165286550301586}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.542013602155205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.389154831841678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.46294352215183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.322848822583996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.85119397884918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.324680610124492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 
             Association[1 -> {
                Complex[29.542013602155205`, -4.389154831841678], 
                Complex[49.41547743201958, -28.700405560905736`]}, 2 -> {
                Complex[66.46294352215183, 0.322848822583996], 
                Complex[91.85119397884918, -20.324680610124492`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.169367675574608}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.542013602155205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.389154831841678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.41547743201958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.700405560905736`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.46294352215183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.322848822583996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.85119397884918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.324680610124492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 
             Association[1 -> {
                Complex[29.542013602155205`, -4.389154831841678], 
                Complex[49.41547743201958, -28.700405560905736`]}, 2 -> {
                Complex[66.46294352215183, 0.322848822583996], 
                Complex[91.85119397884918, -20.324680610124492`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.161196114403619}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.705448306571707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.363817108646442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.596949120761906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.651614041371168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.32088532330775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32786635952260046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.321794373139106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 
             Association[1 -> {
                Complex[29.705448306571707`, -4.363817108646442], 
                Complex[49.596949120761906`, -28.651614041371168`]}, 2 -> {
                Complex[66.32088532330775, 0.32786635952260046`], 
                Complex[91.6934121777283, -20.321794373139106`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.164103516159735}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.705448306571707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.363817108646442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.596949120761906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.651614041371168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.32088532330775`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32786635952260046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.6934121777283`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.321794373139106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 
             Association[1 -> {
                Complex[29.705448306571707`, -4.363817108646442], 
                Complex[49.596949120761906`, -28.651614041371168`]}, 2 -> {
                Complex[66.32088532330775, 0.32786635952260046`], 
                Complex[91.6934121777283, -20.321794373139106`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.151893022957939}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.868735664104204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.33903352140945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.60343491431109`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.17885533591951`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3329953074094176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "A", 
             Association[1 -> {
                Complex[29.868735664104204`, -4.33903352140945], 
                Complex[49.77848837136716, -28.60343491431109]}, 2 -> {
                Complex[66.17885533591951, 0.3329953074094176], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.153764127084316}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"29.868735664104204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.33903352140945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.77848837136716`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.60343491431109`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.17885533591951`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3329953074094176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.53553382576803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.318814884074637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "A", 
             Association[1 -> {
                Complex[29.868735664104204`, -4.33903352140945], 
                Complex[49.77848837136716, -28.60343491431109]}, 2 -> {
                Complex[66.17885533591951, 0.3329953074094176], 
                Complex[91.53553382576803, -20.318814884074637`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24., -6.138576903754437}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.0318994065037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.960119805130674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.555861557435456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.0368303346989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3382394431566841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "A", 
             Association[1 -> {
                Complex[30.0318994065037, -4.314797781836445], 
                Complex[49.960119805130674`, -28.555861557435456`]}, 2 -> {
                Complex[66.0368303346989, 0.3382394431566841], 
                Complex[91.37753320535236, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24., -6.1396382847790765`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.0318994065037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.314797781836445`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"49.960119805130674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.555861557435456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"66.0368303346989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3382394431566841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.37753320535236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.315738481402835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "A", 
             Association[1 -> {
                Complex[30.0318994065037, -4.314797781836445], 
                Complex[49.960119805130674`, -28.555861557435456`]}, 2 -> {
                Complex[66.0368303346989, 0.3382394431566841], 
                Complex[91.37753320535236, -20.315738481402835`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.12264674861886}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.194963272382548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.291104099934118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.141868166281284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.50888784472627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.89478711395589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.312561321201745`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 
             Association[1 -> {
                Complex[30.194963272382548`, -4.291104099934118], 
                Complex[50.141868166281284`, -28.50888784472627]}, 2 -> {
                Complex[65.89478711395589, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.312561321201745`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.123157952151853}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.194963272382548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.291104099934118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.141868166281284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.50888784472627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.89478711395589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34360271970474526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.21938453702393`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.312561321201745`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 
             Association[1 -> {
                Complex[30.194963272382548`, -4.291104099934118], 
                Complex[50.141868166281284`, -28.50888784472627]}, 2 -> {
                Complex[65.89478711395589, 0.34360271970474526`], 
                Complex[91.21938453702393, -20.312561321201745`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.105440836106487}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.35795103650346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.26794718088456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.3237583540324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.46250814461731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.75270245605407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34908927649101035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 
             Association[1 -> {
                Complex[30.35795103650346, -4.26794718088456], 
                Complex[50.3237583540324, -28.46250814461731]}, 2 -> {
                Complex[65.75270245605407, 0.34908927649101035`], 
                Complex[91.0610619442071, -20.30927936589565]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.105650702773249}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.35795103650346`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.26794718088456`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.3237583540324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.46250814461731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.75270245605407`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34908927649101035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"91.0610619442071`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30927936589565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 
             Association[1 -> {
                Complex[30.35795103650346, -4.26794718088456], 
                Complex[50.3237583540324, -28.46250814461731]}, 2 -> {
                Complex[65.75270245605407, 0.34908927649101035`], 
                Complex[91.0610619442071, -20.30927936589565]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.088086591954413}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.520886539183877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.24532222340097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.50581545499962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.416717319706727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.6105530999087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3547034506809741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 
             Association[1 -> {
                Complex[30.520886539183877`, -4.24532222340097], 
                Complex[50.50581545499962, -28.416717319706727`]}, 2 -> {
                Complex[65.6105530999087, 0.3547034506809741], 
                Complex[90.90253941775816, -20.305888372154577`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.088209764501414}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.520886539183877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.24532222340097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.50581545499962`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.416717319706727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.6105530999087`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3547034506809741`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.90253941775816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.305888372154577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 
             Association[1 -> {
                Complex[30.520886539183877`, -4.24532222340097], 
                Complex[50.50581545499962, -28.416717319706727`]}, 2 -> {
                Complex[65.6105530999087, 0.3547034506809741], 
                Complex[90.90253941775816, -20.305888372154577`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.071453482305021}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.683793715914877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.22322491958401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.688064776097136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.371510728031744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.46831570941634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36044978922689475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.7437907802159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "A", 
             Association[1 -> {
                Complex[30.683793715914877`, -4.22322491958401], 
                Complex[50.688064776097136`, -28.371510728031744`]}, 2 -> {
                Complex[65.46831570941634, 0.36044978922689475`], 
                Complex[90.7437907802159, -20.30238387787967]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.071663577729402}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.683793715914877`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.22322491958401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.688064776097136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.371510728031744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.46831570941634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36044978922689475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.7437907802159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.30238387787967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "A", 
             Association[1 -> {
                Complex[30.683793715914877`, -4.22322491958401], 
                Complex[50.688064776097136`, -28.371510728031744`]}, 2 -> {
                Complex[65.46831570941634, 0.36044978922689475`], 
                Complex[90.7437907802159, -20.30238387787967]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.056170121566888}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.846696627295138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.201651456308564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.87053187802873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.326884225945257`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.325966841705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3663330618262281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.298761188193378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 
             Association[1 -> {
                Complex[30.846696627295138`, -4.201651456308564], 
                Complex[50.87053187802873, -28.326884225945257`]}, 2 -> {
                Complex[65.325966841705, 0.3663330618262281], 
                Complex[90.58478964962532, -20.298761188193378`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.056602632730208}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"30.846696627295138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.201651456308564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"50.87053187802873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.326884225945257`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.325966841705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3663330618262281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.58478964962532`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.298761188193378`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 
             Association[1 -> {
                Complex[30.846696627295138`, -4.201651456308564], 
                Complex[50.87053187802873, -28.326884225945257`]}, 2 -> {
                Complex[65.325966841705, 0.3663330618262281], 
                Complex[90.58478964962532, -20.298761188193378`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -6.042668755481304}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.009619489380988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.180598518180851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.28283417264592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.1834829150937`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3723582748592317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 
             Association[1 -> {
                Complex[31.009619489380988`, -4.180598518180851], 
                Complex[51.05324260949038, -28.28283417264592]}, 2 -> {
                Complex[65.1834829150937, 0.3723582748592317], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -6.043427977689284}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.009619489380988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.180598518180851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.05324260949038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.28283417264592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.1834829150937`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3723582748592317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.42550940280545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.29501536034502`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 
             Association[1 -> {
                Complex[31.009619489380988`, -4.180598518180851], 
                Complex[51.05324260949038, -28.28283417264592]}, 2 -> {
                Complex[65.1834829150937, 0.3723582748592317], 
                Complex[90.42550940280545, -20.29501536034502]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.7, -6.031234141437253}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.172586704555457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.160063292117314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.236223142205915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.239357436425397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.04084017664968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3785306863932047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "A", 
             Association[1 -> {
                Complex[31.172586704555457`, -4.160063292117314], 
                Complex[51.236223142205915`, -28.239357436425397`]}, 2 -> {
                Complex[65.04084017664968, 0.3785306863932047], 
                Complex[90.26592313793014, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -6.032400766994568}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.172586704555457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.160063292117314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.236223142205915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.239357436425397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"65.04084017664968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3785306863932047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.26592313793014`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.291141187433084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "A", 
             Association[1 -> {
                Complex[31.172586704555457`, -4.160063292117314], 
                Complex[51.236223142205915`, -28.239357436425397`]}, 2 -> {
                Complex[65.04084017664968, 0.3785306863932047], 
                Complex[90.26592313793014, -20.291141187433084`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.8, -6.022046266767279}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.33562289302192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.89801466922918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3848558223499517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.287133180835255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "A", 
             Association[1 -> {
                Complex[31.33562289302192, -4.140043473607489], 
                Complex[51.419500006920465`, -28.196451402708604`]}, 2 -> {
                Complex[64.89801466922918, 0.3848558223499517], 
                Complex[90.10600363628704, -20.287133180835255`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -6.023684128463775}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.33562289302192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.140043473607489`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.419500006920465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.196451402708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.89801466922918`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3848558223499517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"90.10600363628704`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.287133180835255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "A", 
             Association[1 -> {
                Complex[31.33562289302192, -4.140043473607489], 
                Complex[51.419500006920465`, -28.196451402708604`]}, 2 -> {
                Complex[64.89801466922918, 0.3848558223499517], 
                Complex[90.10600363628704, -20.287133180835255`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.9, -6.015213838950437}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.49875292502993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.603100130481025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.75498219788668`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.391339493943095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "A", 
             Association[1 -> {
                Complex[31.49875292502993, -4.120537274736596], 
                Complex[51.603100130481025`, -28.154113983977776`]}, 2 -> {
                Complex[64.75498219788668, 0.391339493943095], 
                Complex[89.94572332307655, -20.282985551225515`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -6.017375341541333}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.49875292502993`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.120537274736596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.603100130481025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.154113983977776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.75498219788668`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.391339493943095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.94572332307655`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.282985551225515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "A", 
             Association[1 -> {
                Complex[31.49875292502993, -4.120537274736596], 
                Complex[51.603100130481025`, -28.154113983977776`]}, 2 -> {
                Complex[64.75498219788668, 0.391339493943095], 
                Complex[89.94572332307655, -20.282985551225515`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -6.010798974083132}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.662001953945484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.101543434056313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.61171829553294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3979878165032359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.7850542271069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 
             Association[1 -> {
                Complex[31.662001953945484`, -4.101543434056313], 
                Complex[51.78705087413992, -28.112343631685345`]}, 2 -> {
                Complex[64.61171829553294, 0.3979878165032359], 
                Complex[89.7850542271069, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -6.013529241660264}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.662001953945484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.101543434056313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.78705087413992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.112343631685345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.61171829553294`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3979878165032359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.7850542271069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.278692188044857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 
             Association[1 -> {
                Complex[31.662001953945484`, -4.101543434056313], 
                Complex[51.78705087413992, -28.112343631685345`]}, 2 -> {
                Complex[64.61171829553294, 0.3979878165032359], 
                Complex[89.7850542271069, -20.278692188044857`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -6.008834693419415}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.825395450280787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.083061228407537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277985`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.46819818772052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40480722982158246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.62396793923683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 
             Association[1 -> {
                Complex[31.825395450280787`, -4.083061228407537], 
                Complex[51.97138007322182, -28.071139350277985`]}, 2 -> {
                Complex[64.46819818772052, 0.40480722982158246`], 
                Complex[89.62396793923683, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -6.01217462936887}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.825395450280787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.083061228407537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"51.97138007322182`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.071139350277985`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.46819818772052`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.40480722982158246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.62396793923683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.274246637277333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 
             Association[1 -> {
                Complex[31.825395450280787`, -4.083061228407537], 
                Complex[51.97138007322182, -28.071139350277985`]}, 2 -> {
                Complex[64.46819818772052, 0.40480722982158246`], 
                Complex[89.62396793923683, -20.274246637277333`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -6.009336943398618}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.988959236804785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.065090486814274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.32439675642944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4118045201569269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.269642077367138`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 
             Association[1 -> {
                Complex[31.988959236804785`, -4.065090486814274], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[64.32439675642944, 0.4118045201569269], 
                Complex[89.46243556940976, -20.269642077367138`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -6.0133254157054}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"31.988959236804785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.065090486814274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.156116078303796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.030500713471348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.32439675642944`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4118045201569269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.46243556940976`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.269642077367138`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 
             Association[1 -> {
                Complex[31.988959236804785`, -4.065090486814274], 
                Complex[52.156116078303796`, -28.030500713471348`]}, 2 -> {
                Complex[64.32439675642944, 0.4118045201569269], 
                Complex[89.46243556940976, -20.269642077367138`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -6.012312556389126}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.1527195248595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.99042788293637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.18028850272216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.41898684406680864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 
             Association[1 -> {
                Complex[32.1527195248595, -4.047631606586535], 
                Complex[52.34128779806401, -27.99042788293637]}, 2 -> {
                Complex[64.18028850272216, 0.41898684406680864`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -6.016987873358524}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.1527195248595`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.047631606586535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.34128779806401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.99042788293637`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.18028850272216`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.41898684406680864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.30042770211665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.26487129309376`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 
             Association[1 -> {
                Complex[32.1527195248595, -4.047631606586535], 
                Complex[52.34128779806401, -27.99042788293637]}, 2 -> {
                Complex[64.18028850272216, 0.41898684406680864`], 
                Complex[89.30042770211665, -20.26487129309376]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -6.0177641730544496`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.31670295201473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.52692474396548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.95092162957881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.03584750813043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42636175424164896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 
             Association[1 -> {
                Complex[32.31670295201473, -4.030685571788463], 
                Complex[52.52692474396548, -27.95092162957881]}, 2 -> {
                Complex[64.03584750813043, 0.42636175424164896`], 
                Complex[89.13791435011574, -20.259926647201578`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -6.023164942058854}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.31670295201473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.030685571788463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.52692474396548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.95092162957881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"64.03584750813043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42636175424164896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"89.13791435011574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.259926647201578`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 
             Association[1 -> {
                Complex[32.31670295201473, -4.030685571788463], 
                Complex[52.52692474396548, -27.95092162957881]}, 2 -> {
                Complex[64.03584750813043, 0.42636175424164896`], 
                Complex[89.13791435011574, -20.259926647201578`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -6.025692762939759}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.48093662119898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.7130570769491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.911983357620024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.891047394630874`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4339372275409471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 
             Association[1 -> {
                Complex[32.48093662119898, -4.014253974250843], 
                Complex[52.7130570769491, -27.911983357620024`]}, 2 -> {
                Complex[63.891047394630874`, 0.4339372275409471], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -6.031858138976059}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.48093662119898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.014253974250843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.7130570769491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.911983357620024`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.891047394630874`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4339372275409471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.97486490622836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.25480004955709`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 
             Association[1 -> {
                Complex[32.48093662119898, -4.014253974250843], 
                Complex[52.7130570769491, -27.911983357620024`]}, 2 -> {
                Complex[63.891047394630874`, 0.4339372275409471], 
                Complex[88.97486490622836, -20.25480004955709]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -6.036098026038515}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.645448141453244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.998339037330256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.89971565632317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87361513171316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.7458612830591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4417216954533841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24948292358025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 
             Association[1 -> {
                Complex[32.645448141453244`, -3.998339037330256], 
                Complex[52.89971565632317, -27.87361513171316]}, 2 -> {
                Complex[63.7458612830591, 0.4417216954533841], 
                Complex[88.81124809301977, -20.24948292358025]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -6.043067254142865}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.645448141453244`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.998339037330256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"52.89971565632317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87361513171316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.7458612830591`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4417216954533841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.81124809301977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.24948292358025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 
             Association[1 -> {
                Complex[32.645448141453244`, -3.998339037330256], 
                Complex[52.89971565632317, -27.87361513171316]}, 2 -> {
                Complex[63.7458612830591, 0.4417216954533841], 
                Complex[88.81124809301977, -20.24948292358025]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.048976612838874}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.810265670460794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9829436426451004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.086932091046236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.600261749804105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.243966169666688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "A", 
             Association[1 -> {
                Complex[32.810265670460794`, -3.9829436426451004`], 
                Complex[53.086932091046236`, -27.835819707361438`]}, 2 -> {
                Complex[63.600261749804105`, 0.44972407722861746`], 
                Complex[88.64703191016159, -20.243966169666688`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.056787635865906}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.810265670460794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9829436426451004`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.086932091046236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.835819707361438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.600261749804105`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.44972407722861746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.64703191016159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.243966169666688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "A", 
             Association[1 -> {
                Complex[32.810265670460794`, -3.9829436426451004`], 
                Complex[53.086932091046236`, -27.835819707361438`]}, 2 -> {
                Complex[63.600261749804105`, 0.44972407722861746`], 
                Complex[88.64703191016159, -20.243966169666688`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.064317723280473}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.97541795901581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.27473879361426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.798600564939377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.45422078161694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45795381595762275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23824012528373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 
             Association[1 -> {
                Complex[32.97541795901581, -3.968071360048478], 
                Complex[53.27473879361426, -27.798600564939377`]}, 2 -> {
                Complex[63.45422078161694, 0.45795381595762275`], 
                Complex[88.48218357926147, -20.23824012528373]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.0730044438874815`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"32.97541795901581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.968071360048478`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.27473879361426`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.798600564939377`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.45422078161694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45795381595762275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.48218357926147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23824012528373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 
             Association[1 -> {
                Complex[32.97541795901581, -3.968071360048478], 
                Complex[53.27473879361426, -27.798600564939377`]}, 2 -> {
                Complex[63.45422078161694, 0.45795381595762275`], 
                Complex[88.48218357926147, -20.23824012528373]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.082095186104534}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.14093439760302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.953726481132371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.76196194765724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.30770972835797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.466420917911682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23229452138455`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "A", 
             Association[1 -> {
                Complex[33.14093439760302, -3.953726481132371], 
                Complex[53.46316903677714, -27.76196194765724]}, 2 -> {
                Complex[63.30770972835797, 0.466420917911682], 
                Complex[88.31666948593067, -20.23229452138455]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.0916827125807265`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.14093439760302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.953726481132371`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.46316903677714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.76196194765724`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.30770972835797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.466420917911682`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.31666948593067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.23229452138455`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "A", 
             Association[1 -> {
                Complex[33.14093439760302, -3.953726481132371], 
                Complex[53.46316903677714, -27.76196194765724]}, 2 -> {
                Complex[63.30770972835797, 0.466420917911682], 
                Complex[88.31666948593067, -20.23229452138455]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26., -6.10225452776923}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.306845065269485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.939914056596168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.72590890385442`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.16069925349776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4751359954876585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "A", 
             Association[1 -> {
                Complex[33.306845065269485`, -3.939914056596168], 
                Complex[53.65225701332302, -27.72590890385442]}, 2 -> {
                Complex[63.16069925349776, 0.4751359954876585], 
                Complex[88.15045511884611, -20.226118434741064`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26., -6.112751370865292}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.306845065269485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.939914056596168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.65225701332302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.72590890385442`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.16069925349776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4751359954876585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"88.15045511884611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.226118434741064`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "A", 
             Association[1 -> {
                Complex[33.306845065269485`, -3.939914056596168], 
                Complex[53.65225701332302, -27.72590890385442]}, 2 -> {
                Complex[63.16069925349776, 0.4751359954876585], 
                Complex[88.15045511884611, -20.226118434741064`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.1246927847575305`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.47318078098145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9266399378561223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.842037899187076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.69044733405728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.01315928217634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4841103141499007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 
             Association[1 -> {
                Complex[33.47318078098145, -3.9266399378561223`], 
                Complex[53.842037899187076`, -27.69044733405728]}, 2 -> {
                Complex[63.01315928217634, 0.4841103141499007], 
                Complex[87.98350500554794, -20.219700235746625`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.136078500630648}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.47318078098145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9266399378561223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"53.842037899187076`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.69044733405728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"63.01315928217634`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4841103141499007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.98350500554794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.219700235746625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 
             Association[1 -> {
                Complex[33.47318078098145, -3.9266399378561223`], 
                Complex[53.842037899187076`, -27.69044733405728]}, 2 -> {
                Complex[63.01315928217634, 0.4841103141499007], 
                Complex[87.98350500554794, -20.219700235746625`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.149227954360642}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.63997315766917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.0325479201562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.655584043295313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.86505894661449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49335584380795366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.8157826446966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.21302753118228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "A", 
             Association[1 -> {
                Complex[33.63997315766917, -3.913910823322055], 
                Complex[54.0325479201562, -27.655584043295313`]}, 2 -> {
                Complex[62.86505894661449, 0.49335584380795366`], 
                Complex[87.8157826446966, -20.21302753118228]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.161434221134632}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.63997315766917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.913910823322055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.0325479201562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.655584043295313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.86505894661449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49335584380795366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.8157826446966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.21302753118228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "A", 
             Association[1 -> {
                Complex[33.63997315766917, -3.913910823322055], 
                Complex[54.0325479201562, -27.655584043295313`]}, 2 -> {
                Complex[62.86505894661449, 0.49335584380795366`], 
                Complex[87.8157826446966, -20.21302753118228]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.175554335575692}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.80725465917451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9017343098237633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.223824422460964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.621326799234737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.71636652866016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5028853151246296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 
             Association[1 -> {
                Complex[33.80725465917451, -3.9017343098237633`], 
                Complex[54.223824422460964`, -27.621326799234737`]}, 2 -> {
                Complex[62.71636652866016, 0.5028853151246296], 
                Complex[87.64725043449562, -20.206087101376106`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.1884372071931315`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.80725465917451`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9017343098237633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.223824422460964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.621326799234737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.71636652866016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5028853151246296`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.64725043449562`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.206087101376106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 
             Association[1 -> {
                Complex[33.80725465917451, -3.9017343098237633`], 
                Complex[54.223824422460964`, -27.621326799234737`]}, 2 -> {
                Complex[62.71636652866016, 0.5028853151246296], 
                Complex[87.64725043449562, -20.206087101376106`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.203180527251175}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.975058660327356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8901189497339574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.415905947563445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.587684396763738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.56704939924091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5127122813126167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.4778695969676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19886483111003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 
             Association[1 -> {
                Complex[33.975058660327356`, -3.8901189497339574`], 
                Complex[54.415905947563445`, -27.587684396763738`]}, 2 -> {
                Complex[62.56704939924091, 0.5127122813126167], 
                Complex[87.4778695969676, -20.19886483111003]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.2164824458832895`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"33.975058660327356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8901189497339574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.415905947563445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.587684396763738`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.56704939924091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5127122813126167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.4778695969676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19886483111003`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 
             Association[1 -> {
                Complex[33.975058660327356`, -3.8901189497339574`], 
                Complex[54.415905947563445`, -27.587684396763738`]}, 2 -> {
                Complex[62.56704939924091, 0.5127122813126167], 
                Complex[87.4778695969676, -20.19886483111003]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.231350718032302}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.143419510388775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.879074314407841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.417073954482824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19134563354414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 
             Association[1 -> {
                Complex[34.143419510388775`, -3.879074314407841], 
                Complex[54.60883231147051, -27.554666729749552`]}, 2 -> {
                Complex[62.417073954482824`, 0.5228511860504309], 
                Complex[87.30760009775224, -20.19134563354414]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.244654539839444}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.143419510388775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.879074314407841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.60883231147051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.554666729749552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.417073954482824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5228511860504309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.30760009775224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.19134563354414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 
             Association[1 -> {
                Complex[34.143419510388775`, -3.879074314407841], 
                Complex[54.60883231147051, -27.554666729749552`]}, 2 -> {
                Complex[62.417073954482824`, 0.5228511860504309], 
                Complex[87.30760009775224, -20.19134563354414]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.258961121131592}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.312372600109356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8686110646435656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.80264468892042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.5222848707862`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.26640554824476`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5333174382317767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 
             Association[1 -> {
                Complex[34.312372600109356`, -3.8686110646435656`], 
                Complex[54.80264468892042, -27.5222848707862]}, 2 -> {
                Complex[62.26640554824476, 0.5333174382317767], 
                Complex[87.13640056107454, -20.183513366330008`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.271647653697185}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.312372600109356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8686110646435656`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.80264468892042`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.5222848707862`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.26640554824476`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5333174382317767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"87.13640056107454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.183513366330008`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 
             Association[1 -> {
                Complex[34.312372600109356`, -3.8686110646435656`], 
                Complex[54.80264468892042, -27.5222848707862]}, 2 -> {
                Complex[62.26640554824476, 0.5333174382317767], 
                Complex[87.13640056107454, -20.183513366330008`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.284506534787604}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.48195443266224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49055115986421`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.11500842080698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 
             Association[1 -> {
                Complex[34.48195443266224, -3.8587410289636725`], 
                Complex[54.99738570281197, -27.49055115986421]}, 2 -> {
                Complex[62.11500842080698, 0.5441274943581387], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.295743464131059}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.48195443266224`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8587410289636725`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"54.99738570281197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49055115986421`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"62.11500842080698`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5441274943581387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.96422817951265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.175350738972366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 
             Association[1 -> {
                Complex[34.48195443266224, -3.8587410289636725`], 
                Complex[54.99738570281197, -27.49055115986421]}, 2 -> {
                Complex[62.11500842080698, 0.5441274943581387], 
                Complex[86.96422817951265, -20.175350738972366`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.306124758957822}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.65220269871858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.193099519263775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.45947930302496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.96284562344401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.555298949494675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 
             Association[1 -> {
                Complex[34.65220269871858, -3.849477290628971], 
                Complex[55.193099519263775`, -27.45947930302496]}, 2 -> {
                Complex[61.96284562344401, 0.555298949494675], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.3149314416601205`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.65220269871858`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.849477290628971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.193099519263775`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.45947930302496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.96284562344401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.555298949494675`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.79103861817467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.166839210368295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 
             Association[1 -> {
                Complex[34.65220269871858, -3.849477290628971], 
                Complex[55.193099519263775`, -27.45947930302496]}, 2 -> {
                Complex[61.96284562344401, 0.555298949494675], 
                Complex[86.79103861817467, -20.166839210368295`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.321823196281862}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.82315635594019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8408342844230736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.429084482211824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.80987893860578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668506378361227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.157958875303546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "A", 
             Association[1 -> {
                Complex[34.82315635594019, -3.8408342844230736`], 
                Complex[55.38983194870933, -27.429084482211824`]}, 2 -> {
                Complex[61.80987893860578, 0.5668506378361227], 
                Complex[86.61678591287696, -20.157958875303546`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.327247590721977}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.82315635594019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8408342844230736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.38983194870933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.429084482211824`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.80987893860578`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5668506378361227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.61678591287696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.157958875303546`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "A", 
             Association[1 -> {
                Complex[34.82315635594019, -3.8408342844230736`], 
                Complex[55.38983194870933, -27.429084482211824`]}, 2 -> {
                Complex[61.80987893860578, 0.5668506378361227], 
                Complex[86.61678591287696, -20.157958875303546`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27., -6.329915555887946}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.99485571316776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.58763055344998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.65606879542663`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5788027440763145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "A", 
             Association[1 -> {
                Complex[34.99485571316776, -3.8328279043933393`], 
                Complex[55.58763055344998, -27.39938347770468]}, 2 -> {
                Complex[61.65606879542663, 0.5788027440763145], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27., -6.3312957242168}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"34.99485571316776`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8328279043933393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.58763055344998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.39938347770468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.65606879542663`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5788027440763145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.44142236189973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.148688338511917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "A", 
             Association[1 -> {
                Complex[34.99485571316776, -3.8328279043933393`], 
                Complex[55.58763055344998, -27.39938347770468]}, 2 -> {
                Complex[61.65606879542663, 0.5788027440763145], 
                Complex[86.44142236189973, -20.148688338511917`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.329536218514942}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.16734251958135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.501374180284344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "A", 
             Association[1 -> {
                Complex[35.16734251958135, -3.8254756239037375`], 
                Complex[55.78654476209901, -27.370394804725706`]}, 2 -> {
                Complex[61.501374180284344`, 0.5911769269441449], 
                Complex[86.26489841088478, -20.139004574702856`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.326722608195666}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.16734251958135`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8254756239037375`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.78654476209901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.370394804725706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.501374180284344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5911769269441449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.26489841088478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.139004574702856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "A", 
             Association[1 -> {
                Complex[35.16734251958135, -3.8254756239037375`], 
                Complex[55.78654476209901, -27.370394804725706`]}, 2 -> {
                Complex[61.501374180284344`, 0.5911769269441449], 
                Complex[86.26489841088478, -20.139004574702856`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.320948441335243}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.34066005910287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.81879662955199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.342138866037867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.345752542137845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.603996456465433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "A", 
             Association[1 -> {
                Complex[35.34066005910287, -3.81879662955199], 
                Complex[55.98662599135723, -27.342138866037867`]}, 2 -> {
                Complex[61.345752542137845`, 0.603996456465433], 
                Complex[86.08716253043333, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.314343967336092}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.34066005910287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.81879662955199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"55.98662599135723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.342138866037867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.345752542137845`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.603996456465433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"86.08716253043333`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.128882772728787`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "A", 
             Association[1 -> {
                Complex[35.34066005910287, -3.81879662955199], 
                Complex[55.98662599135723, -27.342138866037867`]}, 2 -> {
                Complex[61.345752542137845`, 0.603996456465433], 
                Complex[86.08716253043333, -20.128882772728787`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.305434145492256}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.5148532502931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8128119707315338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.31463812262956`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.18915969238974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6172863667379076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 
             Association[1 -> {
                Complex[35.5148532502931, -3.8128119707315338`], 
                Complex[56.18792777555814, -27.31463812262956]}, 2 -> {
                Complex[61.18915969238974, 0.6172863667379076], 
                Complex[85.90816108596371, -20.118296161792685`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.295829929845264}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.5148532502931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8128119707315338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.18792777555814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.31463812262956`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.18915969238974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6172863667379076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.90816108596371`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.118296161792685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 
             Association[1 -> {
                Complex[35.5148532502931, -3.8128119707315338`], 
                Complex[56.18792777555814, -27.31463812262956]}, 2 -> {
                Complex[61.18915969238974, 0.6172863667379076], 
                Complex[85.90816108596371, -20.118296161792685`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.2848441099293115`}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.68996875196817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.39050590440941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.28791728489552`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.03154969904756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6310736262715524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.107215817279773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "A", 
             Association[1 -> {
                Complex[35.68996875196817, -3.807544726884647], 
                Complex[56.39050590440941, -27.28791728489552]}, 2 -> {
                Complex[61.03154969904756, 0.6310736262715524], 
                Complex[85.72783819940136, -20.107215817279773`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.273169792641551}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.68996875196817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.807544726884647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.39050590440941`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.28791728489552`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"61.03154969904756`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6310736262715524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.72783819940136`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.107215817279773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "A", 
             Association[1 -> {
                Complex[35.68996875196817, -3.807544726884647], 
                Complex[56.39050590440941, -27.28791728489552]}, 2 -> {
                Complex[61.03154969904756, 0.6310736262715524], 
                Complex[85.72783819940136, -20.107215817279773`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.261093414744471}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.866055074715334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8030201948010105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.262003527092865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.872874775003034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.5461356023026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.095610443428537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 
             Association[1 -> {
                Complex[35.866055074715334`, -3.8030201948010105`], 
                Complex[56.594418569327175`, -27.262003527092865`]}, 2 -> {
                Complex[60.872874775003034`, 0.6453873282550383], 
                Complex[85.5461356023026, -20.095610443428537`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.248216602260605}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"35.866055074715334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8030201948010105`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.594418569327175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.262003527092865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.872874775003034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6453873282550383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.5461356023026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.095610443428537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 
             Association[1 -> {
                Complex[35.866055074715334`, -3.8030201948010105`], 
                Complex[56.594418569327175`, -27.262003527092865`]}, 2 -> {
                Complex[60.872874775003034`, 0.6453873282550383], 
                Complex[85.5461356023026, -20.095610443428537`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.235825235375111}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.04316269842235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7992660986771667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.799726518711694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.236926728284004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.71308516031326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6602589034686106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.36299248006208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 
             Association[1 -> {
                Complex[36.04316269842235, -3.7992660986771667`], 
                Complex[56.799726518711694`, -27.236926728284004`]}, 2 -> {
                Complex[60.71308516031326, 0.6602589034686106], 
                Complex[85.36299248006208, -20.08344612962457]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.222452189850317}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.04316269842235`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7992660986771667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"56.799726518711694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.236926728284004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.71308516031326`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6602589034686106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.36299248006208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.08344612962457`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 
             Association[1 -> {
                Complex[36.04316269842235, -3.7992660986771667`], 
                Complex[56.799726518711694`, -27.236926728284004`]}, 2 -> {
                Complex[60.71308516031326, 0.6602589034686106], 
                Complex[85.36299248006208, -20.08344612962457]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.210284719903818}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.22134419584062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7963128260714716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.006493222433235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.212719743482186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.552128998463665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595752`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 
             Association[1 -> {
                Complex[36.22134419584062, -3.7963128260714716`], 
                Complex[57.006493222433235`, -27.212719743482186`]}, 2 -> {
                Complex[60.552128998463665`, 0.6757223589838265], 
                Complex[85.17834530693467, -20.070686076595752`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.196942705044529}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.22134419584062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7963128260714716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.006493222433235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.212719743482186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.552128998463665`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6757223589838265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"85.17834530693467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.070686076595752`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 
             Association[1 -> {
                Complex[36.22134419584062, -3.7963128260714716`], 
                Complex[57.006493222433235`, -27.212719743482186`]}, 2 -> {
                Complex[60.552128998463665`, 0.6757223589838265], 
                Complex[85.17834530693467, -20.070686076595752`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.185333758645759}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.4006543620702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794193693381184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.389952206722754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.99212767171738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 
             Association[1 -> {
                Complex[36.4006543620702, -3.794193693381184], 
                Complex[57.21478504568002, -27.18941870930894]}, 2 -> {
                Complex[60.389952206722754`, 0.6918145462814401], 
                Complex[84.99212767171738, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.172395404207762}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.4006543620702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794193693381184`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.21478504568002`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.18941870930894`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.389952206722754`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6918145462814401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.99212767171738`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.057290288195432`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 
             Association[1 -> {
                Complex[36.4006543620702, -3.794193693381184], 
                Complex[57.21478504568002, -27.18941870930894]}, 2 -> {
                Complex[60.389952206722754`, 0.6918145462814401], 
                Complex[84.99212767171738, -20.057290288195432`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.161525601565681}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.58115034967376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.16706338916731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.22649834088111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7085754629936015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.04321522376426`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "A", 
             Association[1 -> {
                Complex[36.58115034967376, -3.7929452450428247`], 
                Complex[57.42467143215045, -27.16706338916731]}, 2 -> {
                Complex[60.22649834088111, 0.7085754629936015], 
                Complex[84.80427009410889, -20.04321522376426]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.1492457435489705`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.58115034967376`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7929452450428247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.42467143215045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.16706338916731`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.22649834088111`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7085754629936015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.80427009410889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.04321522376426`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "A", 
             Association[1 -> {
                Complex[36.58115034967376, -3.7929452450428247`], 
                Complex[57.42467143215045, -27.16706338916731]}, 2 -> {
                Complex[60.22649834088111, 0.7085754629936015], 
                Complex[84.80427009410889, -20.04321522376426]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.139188375241847}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.76289180887989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.636225096332794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.145697563752844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.06170845491359`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245878`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 
             Association[1 -> {
                Complex[36.76289180887989, -3.7926075913306474`], 
                Complex[57.636225096332794`, -27.145697563752844`]}, 2 -> {
                Complex[60.06170845491359, 0.7260485931492001], 
                Complex[84.61469983200216, -20.028413405245878`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.127738654190038}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.76289180887989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7926075913306474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.636225096332794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.145697563752844`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"60.06170845491359`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7260485931492001`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.61469983200216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.028413405245878`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 
             Association[1 -> {
                Complex[36.76289180887989, -3.7926075913306474`], 
                Complex[57.636225096332794`, -27.145697563752844`]}, 2 -> {
                Complex[60.06170845491359, 0.7260485931492001], 
                Complex[84.61469983200216, -20.028413405245878`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.1184957691756985`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.94594103200389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7932247904164975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.84952222428347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.125369473683783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.89552095643557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7442812915903373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.012832972269205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 
             Association[1 -> {
                Complex[36.94594103200389, -3.7932247904164975`], 
                Complex[57.84952222428347, -27.125369473683783`]}, 2 -> {
                Complex[59.89552095643557, 0.7442812915903373], 
                Complex[84.42334068029797, -20.012832972269205`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.107992101268634}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"36.94594103200389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7932247904164975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"57.84952222428347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.125369473683783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.89552095643557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7442812915903373`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.42334068029797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.012832972269205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 
             Association[1 -> {
                Complex[36.94594103200389, -3.7932247904164975`], 
                Complex[57.84952222428347, -27.125369473683783`]}, 2 -> {
                Complex[59.89552095643557, 0.7442812915903373], 
                Complex[84.42334068029797, -20.012832972269205`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.099519903007702}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.13036310076835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794845281279751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.106132322164278`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.72787145927004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7633252191523081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "A", 
             Association[1 -> {
                Complex[37.13036310076835, -3.794845281279751], 
                Complex[58.06464268186045, -27.106132322164278`]}, 2 -> {
                Complex[59.72787145927004, 0.7633252191523081], 
                Complex[84.2301127622816, -19.996417177281284`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.090042588970453}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.13036310076835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.794845281279751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.06464268186045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.106132322164278`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.72787145927004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7633252191523081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.2301127622816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.996417177281284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "A", 
             Association[1 -> {
                Complex[37.13036310076835, -3.794845281279751], 
                Complex[58.06464268186045, -27.106132322164278`]}, 2 -> {
                Complex[59.72787145927004, 0.7633252191523081], 
                Complex[84.2301127622816, -19.996417177281284`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.08226832326703}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.31622603461241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.797522375138974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.0880448469234`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.5586926350365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7832368362827162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.97910381148327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "A", 
             Association[1 -> {
                Complex[37.31622603461241, -3.797522375138974], 
                Complex[58.28167022874946, -27.0880448469234]}, 2 -> {
                Complex[59.5586926350365, 0.7832368362827162], 
                Complex[84.03493231522438, -19.97910381148327]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.073876155736778}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.31622603461241`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.797522375138974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.28167022874946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.0880448469234`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.5586926350365`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7832368362827162`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"84.03493231522438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.97910381148327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "A", 
             Association[1 -> {
                Complex[37.31622603461241, -3.797522375138974], 
                Complex[58.28167022874946, -27.0880448469234]}, 2 -> {
                Complex[59.5586926350365, 0.7832368362827162], 
                Complex[84.03493231522438, -19.97910381148327]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.0667088973430205`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.503600937288496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8013148143453006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.50069273578578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.38791406646194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8040779640432751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.960824550758474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 
             Association[1 -> {
                Complex[37.503600937288496`, -3.8013148143453006`], 
                Complex[58.50069273578578, -27.07117197223767]}, 2 -> {
                Complex[59.38791406646194, 0.8040779640432751], 
                Complex[83.83771147270659, -19.960824550758474`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.059448852000758}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.503600937288496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8013148143453006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.50069273578578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.07117197223767`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.38791406646194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8040779640432751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.83771147270659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.960824550758474`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 
             Association[1 -> {
                Complex[37.503600937288496`, -3.8013148143453006`], 
                Complex[58.50069273578578, -27.07117197223767]}, 2 -> {
                Complex[59.38791406646194, 0.8040779640432751], 
                Complex[83.83771147270659, -19.960824550758474`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.052786145022778}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.692562137998024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.806287409159504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.72180240194932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.05558555368316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.21546210616129`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.941504208943837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 
             Association[1 -> {
                Complex[37.692562137998024`, -3.806287409159504], 
                Complex[58.72180240194932, -27.05558555368316]}, 2 -> {
                Complex[59.21546210616129, 0.8259164229195795], 
                Complex[83.63835804728225, -19.941504208943837`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.046699991519239}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.692562137998024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.806287409159504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.72180240194932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.05558555368316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.21546210616129`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8259164229195795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.63835804728225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.941504208943837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 
             Association[1 -> {
                Complex[37.692562137998024`, -3.806287409159504], 
                Complex[58.72180240194932, -27.05558555368316]}, 2 -> {
                Complex[59.21546210616129, 0.8259164229195795], 
                Complex[83.63835804728225, -19.941504208943837`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -6.040431753113092}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.88318732193246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.9450959659065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.04125974602169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8488267615895433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642382`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 
             Association[1 -> {
                Complex[37.88318732193246, -3.812511764560067], 
                Complex[58.9450959659065, -27.04136523041568]}, 2 -> {
                Complex[59.04125974602169, 0.8488267615895433], 
                Complex[83.43677531861314, -19.921059883642382`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -6.035560583297936}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"37.88318732193246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.812511764560067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"58.9450959659065`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.04136523041568`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"59.04125974602169`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8488267615895433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.43677531861314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.921059883642382`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 
             Association[1 -> {
                Complex[37.88318732193246, -3.812511764560067], 
                Complex[58.9450959659065, -27.04136523041568]}, 2 -> {
                Complex[59.04125974602169, 0.8488267615895433], 
                Complex[83.43677531861314, -19.921059883642382`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -6.02957122856221}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.07555764325092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.820067111231534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.170674904956044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.028599402293732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.86522650415762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8728910898028908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 
             Association[1 -> {
                Complex[38.07555764325092, -3.820067111231534], 
                Complex[59.170674904956044`, -27.028599402293732`]}, 2 -> {
                Complex[58.86522650415762, 0.8728910898028908], 
                Complex[83.23286183421266, -19.899399977259353`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -6.025958604629383}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.07555764325092`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.820067111231534`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.170674904956044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.028599402293732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.86522650415762`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8728910898028908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.23286183421266`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.899399977259353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 
             Association[1 -> {
                Complex[38.07555764325092, -3.820067111231534], 
                Complex[59.170674904956044`, -27.028599402293732`]}, 2 -> {
                Complex[58.86522650415762, 0.8728910898028908], 
                Complex[83.23286183421266, -19.899399977259353`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -6.0201280232371115`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.26975781110342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.82904125718843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.68727833882761`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318297491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 
             Association[1 -> {
                Complex[38.26975781110342, -3.82904125718843], 
                Complex[59.39864561154835, -27.017386352081296`]}, 2 -> {
                Complex[58.68727833882761, 0.8982000318297491], 
                Complex[83.02651123262952, -19.876423073022412`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -6.017822225844226}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.26975781110342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.82904125718843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.39864561154835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.017386352081296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.68727833882761`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8982000318297491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"83.02651123262952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.876423073022412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 
             Association[1 -> {
                Complex[38.26975781110342, -3.82904125718843], 
                Complex[59.39864561154835, -27.017386352081296`]}, 2 -> {
                Complex[58.68727833882761, 0.8982000318297491], 
                Complex[83.02651123262952, -19.876423073022412`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -6.012026018205182}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.46587613610713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.839531679121346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.62911953396363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.50732760190553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9248538195678667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 
             Association[1 -> {
                Complex[38.46587613610713, -3.839531679121346], 
                Complex[59.62911953396363, -27.007835536336128`]}, 2 -> {
                Complex[58.50732760190553, 0.9248538195678667], 
                Complex[82.81761210248663, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -6.011081717227609}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.46587613610713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.839531679121346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.62911953396363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.007835536336128`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.50732760190553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9248538195678667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.81761210248663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.852016642377055`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 
             Association[1 -> {
                Complex[38.46587613610713, -3.839531679121346], 
                Complex[59.62911953396363, -27.007835536336128`]}, 2 -> {
                Complex[58.50732760190553, 0.9248538195678667], 
                Complex[82.81761210248663, -19.852016642377055`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -6.00519095154778}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.66400452045292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8516467755142054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.32528304872727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9529635473601222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 
             Association[1 -> {
                Complex[38.66400452045292, -3.8516467755142054`], 
                Complex[59.86221326295697, -27.000069072431693`]}, 2 -> {
                Complex[58.32528304872727, 0.9529635473601222], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -6.005670514242611}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.66400452045292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8516467755142054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"59.86221326295697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.000069072431693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.32528304872727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9529635473601222`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.60604789556439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.826055556306983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 
             Association[1 -> {
                Complex[38.66400452045292, -3.8516467755142054`], 
                Complex[59.86221326295697, -27.000069072431693`]}, 2 -> {
                Complex[58.32528304872727, 0.9529635473601222], 
                Complex[82.60604789556439, -19.826055556306983`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -5.99955117167939}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.86423836923639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.99422345346926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.141049926719695`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.798400368820353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 
             Association[1 -> {
                Complex[38.86423836923639, -3.865507306847949], 
                Complex[60.09804853982374, -26.99422345346926]}, 2 -> {
                Complex[58.141049926719695`, 0.9826526138400205], 
                Complex[82.39169691847611, -19.798400368820353`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -6.001525749974769}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"38.86423836923639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.865507306847949`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.09804853982374`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.99422345346926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"58.141049926719695`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9826526138400205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.39169691847611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.798400368820353`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 
             Association[1 -> {
                Complex[38.86423836923639, -3.865507306847949], 
                Complex[60.09804853982374, -26.99422345346926]}, 2 -> {
                Complex[58.141049926719695`, 0.9826526138400205], 
                Complex[82.39169691847611, -19.798400368820353`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.2, -5.995037965684495}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.06667639323606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.336752152884166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.990451527552715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.954530172587724`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.01405837961428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "A", 
             Association[1 -> {
                Complex[39.06667639323606, -3.8812480516973484`], 
                Complex[60.336752152884166`, -26.990451527552715`]}, 2 -> {
                Complex[57.954530172587724`, 1.01405837961428], 
                Complex[82.17443243593527, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -5.998588454684698}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.06667639323606`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.8812480516973484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.336752152884166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.990451527552715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.954530172587724`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.01405837961428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"82.17443243593527`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.768895336127002`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "A", 
             Association[1 -> {
                Complex[39.06667639323606, -3.8812480516973484`], 
                Complex[60.336752152884166`, -26.990451527552715`]}, 2 -> {
                Complex[57.954530172587724`, 1.01405837961428], 
                Complex[82.17443243593527, -19.768895336127002`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -5.991585626126668}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.271420263643506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8990197110726985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.57845567815663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.988924782863712`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.76562275755487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0473340731366323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.9541229298446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 
             Association[1 -> {
                Complex[39.271420263643506`, -3.8990197110726985`], 
                Complex[60.57845567815663, -26.988924782863712`]}, 2 -> {
                Complex[57.76562275755487, 1.0473340731366323`], 
                Complex[81.9541229298446, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -5.996803551531762}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.271420263643506`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.8990197110726985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.57845567815663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.988924782863712`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.76562275755487`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0473340731366323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.9541229298446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.737366130066967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 
             Association[1 -> {
                Complex[39.271420263643506`, -3.8990197110726985`], 
                Complex[60.57845567815663, -26.988924782863712`]}, 2 -> {
                Complex[57.76562275755487, 1.0473340731366323`], 
                Complex[81.9541229298446, -19.737366130066967`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.4, -5.989131364332501}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.478574066455195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.91899109663922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869384`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.57422423294728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "A", 
             Association[1 -> {
                Complex[39.478574066455195`, -3.91899109663922], 
                Complex[60.823295005096384`, -26.989835984869384`]}, 2 -> {
                Complex[57.57422423294728, 1.0826509804077706`], 
                Complex[81.73063257333023, -19.70361719945588]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -5.996119731566511}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.478574066455195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.91899109663922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"60.823295005096384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.989835984869384`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.57422423294728`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0826509804077706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.73063257333023`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.70361719945588`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "A", 
             Association[1 -> {
                Complex[39.478574066455195`, -3.91899109663922], 
                Complex[60.823295005096384`, -26.989835984869384`]}, 2 -> {
                Complex[57.57422423294728, 1.0826509804077706`], 
                Complex[81.73063257333023, -19.70361719945588]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.5, -5.987615142865541}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.68824348743652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9413516409076177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.380229545210106`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1202009565970128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "A", 
             Association[1 -> {
                Complex[39.68824348743652, -3.9413516409076177`], 
                Complex[61.071409568577636`, -26.993402216234124`]}, 2 -> {
                Complex[57.380229545210106`, 1.1202009565970128`], 
                Complex[81.50382199854218, -19.66742872877372]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -5.99648926124411}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.68824348743652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9413516409076177`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.071409568577636`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.993402216234124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.380229545210106`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.1202009565970128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.50382199854218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.66742872877372`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "A", 
             Association[1 -> {
                Complex[39.68824348743652, -3.9413516409076177`], 
                Complex[61.071409568577636`, -26.993402216234124`]}, 2 -> {
                Complex[57.380229545210106`, 1.1202009565970128`], 
                Complex[81.50382199854218, -19.66742872877372]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -5.986979478009131}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.900534636598906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.966314268200562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.183533211415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1601992983922518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 
             Association[1 -> {
                Complex[39.900534636598906`, -3.966314268200562], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[57.183533211415, 1.1601992983922518`], 
                Complex[81.27354946300127, -19.628553141047497`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -5.997867756316526}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"39.900534636598906`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.966314268200562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.32294118233806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.9998683725834`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"57.183533211415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1601992983922518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.27354946300127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.628553141047497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 
             Association[1 -> {
                Complex[39.900534636598906`, -3.966314268200562], 
                Complex[61.32294118233806, -26.9998683725834]}, 2 -> {
                Complex[57.183533211415, 1.1601992983922518`], 
                Complex[81.27354946300127, -19.628553141047497`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -5.987169250235152}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.11555239258457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9941186626524052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.98403097486453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2028880133377449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 
             Association[1 -> {
                Complex[40.11555239258457, -3.9941186626524052`], 
                Complex[61.57803233510409, -27.009511166504147`]}, 2 -> {
                Complex[56.98403097486453, 1.2028880133377449`], 
                Complex[81.03967255327478, -19.586711092540675`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -6.0002139433519535`}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.11555239258457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9941186626524052`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.57803233510409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.009511166504147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.98403097486453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2028880133377449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"81.03967255327478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.586711092540675`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 
             Association[1 -> {
                Complex[40.11555239258457, -3.9941186626524052`], 
                Complex[61.57803233510409, -27.009511166504147`]}, 2 -> {
                Complex[56.98403097486453, 1.2028880133377449`], 
                Complex[81.03967255327478, -19.586711092540675`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -5.988131554100432}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.33339811059796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.02264368536371`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.78162209715333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.248539514221569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.54158691366652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 
             Association[1 -> {
                Complex[40.33339811059796, -4.025034961302564], 
                Complex[61.836823766448205`, -27.02264368536371]}, 2 -> {
                Complex[56.78162209715333, 1.248539514221569], 
                Complex[80.80205060892806, -19.54158691366652]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -6.003489421937372}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.33339811059796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.025034961302564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"61.836823766448205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.02264368536371`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.78162209715333`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.248539514221569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.80205060892806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.54158691366652`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 
             Association[1 -> {
                Complex[40.33339811059796, -4.025034961302564], 
                Complex[61.836823766448205`, -27.02264368536371]}, 2 -> {
                Complex[56.78162209715333, 1.248539514221569], 
                Complex[80.80205060892806, -19.54158691366652]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -5.989815617040474}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.554166490864645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.059367882777878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.57621248970557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.297460749010085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653356`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 
             Association[1 -> {
                Complex[40.554166490864645`, -4.059367882777878], 
                Complex[62.09945108280152, -27.039620531417192`]}, 2 -> {
                Complex[56.57621248970557, 1.297460749010085], 
                Complex[80.56054810632892, -19.492823467653356`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -6.007658435308865}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.554166490864645`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.059367882777878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.09945108280152`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.039620531417192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.57621248970557`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.297460749010085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.56054810632892`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.492823467653356`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 
             Association[1 -> {
                Complex[40.554166490864645`, -4.059367882777878], 
                Complex[62.09945108280152, -27.039620531417192`]}, 2 -> {
                Complex[56.57621248970557, 1.297460749010085], 
                Complex[80.56054810632892, -19.492823467653356`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -5.992172817963553}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.77794134659001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.097461269474217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.060843538677656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.3677189458158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3499977442410382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.3150393131322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 
             Association[1 -> {
                Complex[40.77794134659001, -4.097461269474217], 
                Complex[62.36604010279412, -27.060843538677656`]}, 2 -> {
                Complex[56.3677189458158, 1.3499977442410382`], 
                Complex[80.3150393131322, -19.440016432485955`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -6.012687653728447}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"40.77794134659001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.097461269474217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.36604010279412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.060843538677656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.3677189458158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3499977442410382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.3150393131322`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.440016432485955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 
             Association[1 -> {
                Complex[40.77794134659001, -4.097461269474217], 
                Complex[62.36604010279412, -27.060843538677656`]}, 2 -> {
                Complex[56.3677189458158, 1.3499977442410382`], 
                Complex[80.3150393131322, -19.440016432485955`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -5.995156840457901}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.004789940578746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.139702965144389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.15607480403263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.4065404837842264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 
             Association[1 -> {
                Complex[41.004789940578746`, -4.139702965144389], 
                Complex[62.63670053402378, -27.086768000239154`]}, 2 -> {
                Complex[56.15607480403263, 1.4065404837842264`], 
                Complex[80.06541461134336, -19.382708072431345`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -6.018545972734932}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.004789940578746`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.139702965144389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.63670053402378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.086768000239154`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"56.15607480403263`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.4065404837842264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"80.06541461134336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.382708072431345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 
             Association[1 -> {
                Complex[41.004789940578746`, -4.139702965144389], 
                Complex[62.63670053402378, -27.086768000239154`]}, 2 -> {
                Complex[56.15607480403263, 1.4065404837842264`], 
                Complex[80.06541461134336, -19.382708072431345`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -5.9987240007401414`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.23475547996004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.911517481754075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.941237453438774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 
             Association[1 -> {
                Complex[41.23475547996004, -4.186529858286214], 
                Complex[62.911517481754075`, -27.117909237707966`]}, 2 -> {
                Complex[55.941237453438774`, 1.4675279533647856`], 
                Complex[79.81158898845908, -19.320380667492593`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -6.0252043270150875`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.23475547996004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.186529858286214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"62.911517481754075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.117909237707966`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.941237453438774`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.4675279533647856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.81158898845908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.320380667492593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 
             Association[1 -> {
                Complex[41.23475547996004, -4.186529858286214], 
                Complex[62.911517481754075`, -27.117909237707966`]}, 2 -> {
                Complex[55.941237453438774`, 1.4675279533647856`], 
                Complex[79.81158898845908, -19.320380667492593`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -6.002833795493931}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.46784727560741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.238432778015862`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.1548491808301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.72319817424016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.5334530375357749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 
             Association[1 -> {
                Complex[41.46784727560741, -4.238432778015862], 
                Complex[63.19054018060197, -27.1548491808301]}, 2 -> {
                Complex[55.72319817424016, 1.5334530375357749`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -6.032635519790195}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.46784727560741`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.238432778015862`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.19054018060197`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.1548491808301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.72319817424016`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.5334530375357749`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.55351330562608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.252449932700852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 
             Association[1 -> {
                Complex[41.46784727560741, -4.238432778015862], 
                Complex[63.19054018060197, -27.1548491808301]}, 2 -> {
                Complex[55.72319817424016, 1.5334530375357749`], 
                Complex[79.55351330562608, -19.252449932700852`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.4, -6.007449716453215}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.704028002661694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.295960711667079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.473767240011654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.198242373560767`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.50199487725362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6048667383421007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.1782590109987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "A", 
             Association[1 -> {
                Complex[41.704028002661694`, -4.295960711667079], 
                Complex[63.473767240011654`, -27.198242373560767`]}, 2 -> {
                Complex[55.50199487725362, 1.6048667383421007`], 
                Complex[79.29118905201918, -19.1782590109987]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -6.040814067108517}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.704028002661694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.295960711667079`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.473767240011654`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.198242373560767`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.50199487725362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6048667383421007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.29118905201918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.1782590109987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "A", 
             Association[1 -> {
                Complex[41.704028002661694`, -4.295960711667079], 
                Complex[63.473767240011654`, -27.198242373560767`]}, 2 -> {
                Complex[55.50199487725362, 1.6048667383421007`], 
                Complex[79.29118905201918, -19.1782590109987]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.5, -6.012540371657154}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.94319747255841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.27772833189304`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6823808689752453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.09707399537825`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "A", 
             Association[1 -> {
                Complex[41.94319747255841, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[55.27772833189304, 1.6823808689752453`], 
                Complex[79.02468735041018, -19.09707399537825]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -6.049716056154195}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"41.94319747255841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.3597234974146355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"63.76112763854415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.24882045091131`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.27772833189304`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.6823808689752453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"79.02468735041018`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.09707399537825`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "A", 
             Association[1 -> {
                Complex[41.94319747255841, -4.3597234974146355`], 
                Complex[63.76112763854415, -27.24882045091131]}, 2 -> {
                Complex[55.27772833189304, 1.6823808689752453`], 
                Complex[79.02468735041018, -19.09707399537825]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -6.018080928921855}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.185172401572416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.430391708841174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.307393608507066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.05058239764025`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.7666679393393379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 
             Association[1 -> {
                Complex[42.185172401572416`, -4.430391708841174], 
                Complex[64.05245675580908, -27.307393608507066`]}, 2 -> {
                Complex[55.05058239764025, 1.7666679393393379`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -6.059319016547905}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.185172401572416`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.430391708841174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.05245675580908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.307393608507066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"55.05058239764025`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.7666679393393379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.75417292510039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.00808245833909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 
             Association[1 -> {
                Complex[42.185172401572416`, -4.430391708841174], 
                Complex[64.05245675580908, -27.307393608507066`]}, 2 -> {
                Complex[55.05058239764025, 1.7666679393393379`], 
                Complex[78.75417292510039, -19.00808245833909]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -6.024054841855345}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.42966192828803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.8208485065926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.8584563892632036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 
             Association[1 -> {
                Complex[42.42966192828803, -4.508691887180884], 
                Complex[64.34746700294596, -27.374846901442822`]}, 2 -> {
                Complex[54.8208485065926, 1.8584563892632036`], 
                Complex[78.47993347130917, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -6.069601803570676}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.42966192828803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.508691887180884`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.34746700294596`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.374846901442822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.8208485065926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.8584563892632036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.47993347130917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.910397152078417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 
             Association[1 -> {
                Complex[42.42966192828803, -4.508691887180884], 
                Complex[64.34746700294596, -27.374846901442822`]}, 2 -> {
                Complex[54.8208485065926, 1.8584563892632036`], 
                Complex[78.47993347130917, -18.910397152078417`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -6.030455715014877}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.67623922739711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.452128400549633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.588954049684325`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 
             Association[1 -> {
                Complex[42.67623922739711, -4.595394633635153], 
                Complex[64.64571326583466, -27.452128400549633`]}, 2 -> {
                Complex[54.588954049684325`, 1.9585186817545792`], 
                Complex[78.20241421183864, -18.803067851298525`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -6.080544492254725}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.67623922739711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.595394633635153`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.64571326583466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.452128400549633`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.588954049684325`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.9585186817545792`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"78.20241421183864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.803067851298525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 
             Association[1 -> {
                Complex[42.67623922739711, -4.595394633635153], 
                Complex[64.64571326583466, -27.452128400549633`]}, 2 -> {
                Complex[54.588954049684325`, 1.9585186817545792`], 
                Complex[78.20241421183864, -18.803067851298525`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.9, -6.03728899475697}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.92431065706729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.94655461858153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.540225454037717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.35549322933975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0676491823619387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.92225618346788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "A", 
             Association[1 -> {
                Complex[42.92431065706729, -4.691292487824447], 
                Complex[64.94655461858153, -27.540225454037717`]}, 2 -> {
                Complex[54.35549322933975, 2.0676491823619387`], 
                Complex[77.92225618346788, -18.685105090665765`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -6.092128281331101}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"42.92431065706729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.691292487824447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"64.94655461858153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.540225454037717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.35549322933975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.0676491823619387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.92225618346788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.685105090665765`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "A", 
             Association[1 -> {
                Complex[42.92431065706729, -4.691292487824447], 
                Complex[64.94655461858153, -27.540225454037717`]}, 2 -> {
                Complex[54.35549322933975, 2.0676491823619387`], 
                Complex[77.92225618346788, -18.685105090665765`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -6.044572930256075}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.17308560823099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.79716429050747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.121257210207155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.1866285227759508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729686`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 
             Association[1 -> {
                Complex[43.17308560823099, -4.79716429050747], 
                Complex[65.24911579537869, -27.64012489570582]}, 2 -> {
                Complex[54.121257210207155`, 2.1866285227759508`], 
                Complex[77.64033476497889, -18.555519955729686`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -6.104335406088259}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.17308560823099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.79716429050747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.24911579537869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.64012489570582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"54.121257210207155`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.1866285227759508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.64033476497889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.555519955729686`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 
             Association[1 -> {
                Complex[43.17308560823099, -4.79716429050747], 
                Complex[65.24911579537869, -27.64012489570582]}, 2 -> {
                Complex[54.121257210207155`, 2.1866285227759508`], 
                Complex[77.64033476497889, -18.555519955729686`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.052337966076383}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.42155259011466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.88725803365406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.316171791849095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 
             Association[1 -> {
                Complex[43.42155259011466, -4.913723373745142], 
                Complex[65.55225475967484, -27.752753616885613`]}, 2 -> {
                Complex[53.88725803365406, 2.316171791849095], 
                Complex[77.35779210787565, -18.413383510132924`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.117149059268341}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.42155259011466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.913723373745142`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.55225475967484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.752753616885613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.88725803365406`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.316171791849095`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.35779210787565`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.413383510132924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 
             Association[1 -> {
                Complex[43.42155259011466, -4.913723373745142], 
                Complex[65.55225475967484, -27.752753616885613`]}, 2 -> {
                Complex[53.88725803365406, 2.316171791849095], 
                Complex[77.35779210787565, -18.413383510132924`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.060623505990949}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.6684696972538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87889831422985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.654738150778094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.45686009591344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.0760538672227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.257907047001805`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 
             Association[1 -> {
                Complex[43.6684696972538, -5.041549120388218], 
                Complex[65.85454597323113, -27.87889831422985]}, 2 -> {
                Complex[53.654738150778094`, 2.45686009591344], 
                Complex[77.0760538672227, -18.257907047001805`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.130553319203434}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.6684696972538`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.041549120388218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"65.85454597323113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.87889831422985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.654738150778094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.45686009591344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"77.0760538672227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.257907047001805`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 
             Association[1 -> {
                Complex[43.6684696972538, -5.041549120388218], 
                Complex[65.85454597323113, -27.87889831422985]}, 2 -> {
                Complex[53.654738150778094`, 2.45686009591344], 
                Complex[77.0760538672227, -18.257907047001805`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.069471024076226}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.91237942227682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.019108187677965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.42515560965041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.609059345791205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 
             Association[1 -> {
                Complex[43.91237942227682, -5.181005750282827], 
                Complex[66.15429146185946, -28.019108187677965`]}, 2 -> {
                Complex[53.42515560965041, 2.609059345791205], 
                Complex[76.79681813580557, -18.08853939018387]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.144533084468132}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"43.91237942227682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.181005750282827`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.15429146185946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.019108187677965`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.42515560965041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.609059345791205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.79681813580557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.08853939018387`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 
             Association[1 -> {
                Complex[43.91237942227682, -5.181005750282827], 
                Complex[66.15429146185946, -28.019108187677965`]}, 2 -> {
                Complex[53.42515560965041, 2.609059345791205], 
                Complex[76.79681813580557, -18.08853939018387]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.078913042752142}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.15165707542385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.20013563582517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.7728363828323297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453845`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "A", 
             Association[1 -> {
                Complex[44.15165707542385, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[53.20013563582517, 2.7728363828323297`], 
                Complex[76.52200482138221, -17.905070014453845`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.1590740143951495`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.15165707542385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.332158445526291`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.44957143807375`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.173591819475575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"53.20013563582517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.7728363828323297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.52200482138221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.905070014453845`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "A", 
             Association[1 -> {
                Complex[44.15165707542385, -5.332158445526291], 
                Complex[66.44957143807375, -28.173591819475575`]}, 2 -> {
                Complex[53.20013563582517, 2.7728363828323297`], 
                Complex[76.52200482138221, -17.905070014453845`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.088958685518673}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.38459701843839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4947034235184535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799614`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.98138439847741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.947889052723883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 
             Association[1 -> {
                Complex[44.38459701843839, -5.4947034235184535`], 
                Complex[66.73834077690567, -28.342127551799614`]}, 2 -> {
                Complex[52.98138439847741, 2.947889052723883], 
                Complex[76.25365917077403, -17.707718667136962`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.1741624748665815`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.38459701843839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.4947034235184535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"66.73834077690567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.342127551799614`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.98138439847741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"2.947889052723883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"76.25365917077403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.707718667136962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 
             Association[1 -> {
                Complex[44.38459701843839, -5.4947034235184535`], 
                Complex[66.73834077690567, -28.342127551799614`]}, 2 -> {
                Complex[52.98138439847741, 2.947889052723883], 
                Complex[76.25365917077403, -17.707718667136962`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.0995781103736615`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.60953106802053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363132`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.770570606980506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050529`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 
             Association[1 -> {
                Complex[44.60953106802053, -5.667931881684722], 
                Complex[67.01856624754153, -28.52401138363132]}, 2 -> {
                Complex[52.770570606980506`, 3.1335101509494954`], 
                Complex[75.99381453813973, -17.49718747050529]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.189785488853875}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.60953106802053`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.667931881684722`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.01856624754153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.52401138363132`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.770570606980506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.1335101509494954`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.99381453813973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.49718747050529`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 
             Association[1 -> {
                Complex[44.60953106802053, -5.667931881684722], 
                Complex[67.01856624754153, -28.52401138363132]}, 2 -> {
                Complex[52.770570606980506`, 3.1335101509494954`], 
                Complex[75.99381453813973, -17.49718747050529]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.110689403212321}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.82496136566615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.8507441063245365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.569192641098226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "A", 
             Association[1 -> {
                Complex[44.82496136566615, -5.8507441063245365`], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[52.569192641098226`, 3.3286015323523053`], 
                Complex[75.74433404826091, -17.274654824395945`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.205930691234468}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"44.82496136566615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.8507441063245365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.28838484995049`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.718063067428552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.569192641098226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.3286015323523053`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.74433404826091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.274654824395945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "A", 
             Association[1 -> {
                Complex[44.82496136566615, -5.8507441063245365`], 
                Complex[67.28838484995049, -28.718063067428552`]}, 2 -> {
                Complex[52.569192641098226`, 3.3286015323523053`], 
                Complex[75.74433404826091, -17.274654824395945`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.1221515412204965`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.02968138507134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.041718331746136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.37845754361273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.5317429709640207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935683`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "A", 
             Association[1 -> {
                Complex[45.02968138507134, -6.041718331746136], 
                Complex[67.54625247327425, -28.92269792171126]}, 2 -> {
                Complex[52.37845754361273, 3.5317429709640207`], 
                Complex[75.5067619380703, -17.041703592935683`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.222586287463025}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.02968138507134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.041718331746136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.54625247327425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.92269792171126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.37845754361273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.5317429709640207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.5067619380703`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.041703592935683`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "A", 
             Association[1 -> {
                Complex[45.02968138507134, -6.041718331746136], 
                Complex[67.54625247327425, -28.92269792171126]}, 2 -> {
                Complex[52.37845754361273, 3.5317429709640207`], 
                Complex[75.5067619380703, -17.041703592935683`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.133765463826828}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.22285917797315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239223019815121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.13605301384424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.199197774517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.7413044402273425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.800194921087922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 
             Association[1 -> {
                Complex[45.22285917797315, -6.239223019815121], 
                Complex[67.79105133862647, -29.13605301384424]}, 2 -> {
                Complex[52.199197774517, 3.7413044402273425`], 
                Complex[75.28221611377315, -16.800194921087922`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.239741015719631}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.22285917797315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.239223019815121`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"67.79105133862647`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.13605301384424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.199197774517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.7413044402273425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.28221611377315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.800194921087922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 
             Association[1 -> {
                Complex[45.22285917797315, -6.239223019815121], 
                Complex[67.79105133862647, -29.13605301384424]}, 2 -> {
                Complex[52.199197774517, 3.7413044402273425`], 
                Complex[75.28221611377315, -16.800194921087922`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.145282816813853}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.404067563685665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663413`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.03184102151237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.9555778719707466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.55211478637477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 
             Association[1 -> {
                Complex[45.404067563685665`, -6.441548618274501], 
                Complex[68.02213623225067, -29.356140607663413`]}, 2 -> {
                Complex[52.03184102151237, 3.9555778719707466`], 
                Complex[75.07134191761345, -16.55211478637477]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.257384112197482}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.404067563685665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441548618274501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.02213623225067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.356140607663413`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"52.03184102151237`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"3.9555778719707466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"75.07134191761345`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.55211478637477`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 
             Association[1 -> {
                Complex[45.404067563685665`, -6.441548618274501], 
                Complex[68.02213623225067, -29.356140607663413`]}, 2 -> {
                Complex[52.03184102151237, 3.9555778719707466`], 
                Complex[75.07134191761345, -16.55211478637477]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.156419921427744}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.57326174765701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.64703167968071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.580996761146004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.87643258148602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.172901275980756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 
             Association[1 -> {
                Complex[45.57326174765701, -6.64703167968071], 
                Complex[68.23931794822644, -29.580996761146004`]}, 2 -> {
                Complex[51.87643258148602, 4.172901275980756], 
                Complex[74.87432868509478, -16.299425400573057`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.275505279228338}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.57326174765701`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.64703167968071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.23931794822644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.580996761146004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.87643258148602`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.172901275980756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.87432868509478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.299425400573057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 
             Association[1 -> {
                Complex[45.57326174765701, -6.64703167968071], 
                Complex[68.23931794822644, -29.580996761146004`]}, 2 -> {
                Complex[51.87643258148602, 4.172901275980756], 
                Complex[74.87432868509478, -16.299425400573057`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.282575863419133}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.730718127418484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.73269655459702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.391754775223062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.04394673660354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 
             Association[1 -> {
                Complex[45.730718127418484`, -6.854150896006849], 
                Complex[68.44279858874026, -29.808799798905298`]}, 2 -> {
                Complex[51.73269655459702, 4.391754775223062], 
                Complex[74.69097444463986, -16.04394673660354]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.294094655975785}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.730718127418484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.854150896006849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.44279858874026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.808799798905298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.73269655459702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"4.391754775223062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.69097444463986`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.04394673660354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 
             Association[1 -> {
                Complex[45.730718127418484`, -6.854150896006849], 
                Complex[68.44279858874026, -29.808799798905298`]}, 2 -> {
                Complex[51.73269655459702, 4.391754775223062], 
                Complex[74.69097444463986, -16.04394673660354]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.300022037000351}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.87695378596401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.037946713787587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.600116350932254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "A", 
             Association[1 -> {
                Complex[45.87695378596401, -7.061586259363513], 
                Complex[68.63308108602179, -30.037946713787587`]}, 2 -> {
                Complex[51.600116350932254`, 4.610819767164111], 
                Complex[74.52077639558696, -15.787280126334567`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.313142791454729}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"45.87695378596401`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.061586259363513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.63308108602179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.037946713787587`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.600116350932254`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.610819767164111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.52077639558696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.787280126334567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "A", 
             Association[1 -> {
                Complex[45.87695378596401, -7.061586259363513], 
                Complex[68.63308108602179, -30.037946713787587`]}, 2 -> {
                Complex[51.600116350932254`, 4.610819767164111], 
                Complex[74.52077639558696, -15.787280126334567`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.318406534617417}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.012644400278134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.478016782014386`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.829003095065925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.3630260491026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "A", 
             Association[1 -> {
                Complex[46.012644400278134`, -7.268243232709627], 
                Complex[68.81087406136677, -30.267088315852067`]}, 2 -> {
                Complex[51.478016782014386`, 4.829003095065925], 
                Complex[74.3630260491026, -15.530773111018974`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.332640619660858}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.012644400278134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.268243232709627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.81087406136677`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.267088315852067`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.478016782014386`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.829003095065925`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.3630260491026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.530773111018974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "A", 
             Association[1 -> {
                Complex[46.012644400278134`, -7.268243232709627], 
                Complex[68.81087406136677, -30.267088315852067`]}, 2 -> {
                Complex[51.478016782014386`, 4.829003095065925], 
                Complex[74.3630260491026, -15.530773111018974`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.337621995666981}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.1385523728934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.473250095934392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818545`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.36563592928112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.045434394635397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.21689441876435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 
             Association[1 -> {
                Complex[46.1385523728934, -7.473250095934392], 
                Complex[68.97700663449255, -30.495131845818545`]}, 2 -> {
                Complex[51.36563592928112, 5.045434394635397], 
                Complex[74.21689441876435, -15.275516827279347`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.352579436616137}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.1385523728934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.473250095934392`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"68.97700663449255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.495131845818545`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.36563592928112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.045434394635397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.21689441876435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.275516827279347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 
             Association[1 -> {
                Complex[46.1385523728934, -7.473250095934392], 
                Complex[68.97700663449255, -30.495131845818545`]}, 2 -> {
                Complex[51.36563592928112, 5.045434394635397], 
                Complex[74.21689441876435, -15.275516827279347`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.357575796104234}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.25547057364814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.67593833538152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.72122229359378`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.26218140236398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.259446484100554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.08150010532468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029509`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 
             Association[1 -> {
                Complex[46.25547057364814, -7.67593833538152], 
                Complex[69.13236033871479, -30.72122229359378]}, 2 -> {
                Complex[51.26218140236398, 5.259446484100554], 
                Complex[74.08150010532468, -15.022364688029509`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.372950879156325}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.25547057364814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.67593833538152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.13236033871479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.72122229359378`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.26218140236398`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.259446484100554`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"74.08150010532468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.022364688029509`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 
             Association[1 -> {
                Complex[46.25547057364814, -7.67593833538152], 
                Complex[69.13236033871479, -30.72122229359378]}, 2 -> {
                Complex[51.26218140236398, 5.259446484100554], 
                Complex[74.08150010532468, -15.022364688029509`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.378190068195225}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.36418227688922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.875814674529089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.94471254171957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.166870401922736`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489209`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 
             Association[1 -> {
                Complex[46.36418227688922, -7.875814674529089], 
                Complex[69.27781951812032, -30.94471254171957]}, 2 -> {
                Complex[51.166870401922736`, 5.470547395427036], 
                Complex[73.95595889948115, -14.771962238489209`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.393746905304457}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.36418227688922`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.875814674529089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.27781951812032`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.94471254171957`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.166870401922736`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.470547395427036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.95595889948115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.771962238489209`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 
             Association[1 -> {
                Complex[46.36418227688922, -7.875814674529089], 
                Complex[69.27781951812032, -30.94471254171957]}, 2 -> {
                Complex[51.166870401922736`, 5.470547395427036], 
                Complex[73.95595889948115, -14.771962238489209`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.399400490552237}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.465435189789666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737157`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.07895569136514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.678390200428087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.8394169010038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "A", 
             Association[1 -> {
                Complex[46.465435189789666`, -8.07253089957758], 
                Complex[69.41423820838506, -31.16512977737157]}, 2 -> {
                Complex[51.07895569136514, 5.678390200428087], 
                Complex[73.8394169010038, -14.524780743662301`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.414959776089656}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.465435189789666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.07253089957758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.41423820838506`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.16512977737157`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"51.07895569136514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.678390200428087`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.8394169010038`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.524780743662301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "A", 
             Association[1 -> {
                Complex[46.465435189789666`, -8.07253089957758], 
                Complex[69.41423820838506, -31.16512977737157]}, 2 -> {
                Complex[51.07895569136514, 5.678390200428087], 
                Complex[73.8394169010038, -14.524780743662301`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.4211545199178115`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.55992646557226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.265855214912738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.99774058366105`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.882744366735128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.281149844042137`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "A", 
             Association[1 -> {
                Complex[46.55992646557226, -8.265855214912738], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[50.99774058366105, 5.882744366735128], 
                Complex[73.73107052942778, -14.281149844042137`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.436582038685122}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.55992646557226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.265855214912738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.54242012602907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.38214283614471`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.99774058366105`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.882744366735128`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.73107052942778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.281149844042137`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "A", 
             Association[1 -> {
                Complex[46.55992646557226, -8.265855214912738], 
                Complex[69.54242012602907, -31.38214283614471]}, 2 -> {
                Complex[50.99774058366105, 5.882744366735128], 
                Complex[73.73107052942778, -14.281149844042137`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33., -6.443409492829423}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.64829561564561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.455646996018187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.59553293132246`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.92258602924393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.083470511204362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.6301769260447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846566`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "A", 
             Association[1 -> {
                Complex[46.64829561564561, -8.455646996018187], 
                Complex[69.66310826637462, -31.59553293132246]}, 2 -> {
                Complex[50.92258602924393, 6.083470511204362], 
                Complex[73.6301769260447, -14.041286825846566`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33., -6.45860651075125}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.64829561564561`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.455646996018187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.66310826637462`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.59553293132246`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.92258602924393`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.083470511204362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.6301769260447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.041286825846566`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "A", 
             Association[1 -> {
                Complex[46.64829561564561, -8.455646996018187], 
                Complex[69.66310826637462, -31.59553293132246]}, 2 -> {
                Complex[50.92258602924393, 6.083470511204362], 
                Complex[73.6301769260447, -14.041286825846566`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.466130834843394}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.73112272554318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.641835576592952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.80516872809565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.85291240010994`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.280499187514896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 
             Association[1 -> {
                Complex[46.73112272554318, -8.641835576592952], 
                Complex[69.77698109299793, -31.80516872809565]}, 2 -> {
                Complex[50.85291240010994, 6.280499187514896], 
                Complex[73.53605776440253, -13.805321546316236`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.481026265881326}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.73112272554318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.641835576592952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.77698109299793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.80516872809565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.85291240010994`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.280499187514896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.53605776440253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.805321546316236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 
             Association[1 -> {
                Complex[46.73112272554318, -8.641835576592952], 
                Complex[69.77698109299793, -31.80516872809565]}, 2 -> {
                Complex[50.85291240010994, 6.280499187514896], 
                Complex[73.53605776440253, -13.805321546316236`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.489290486767805}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.80892999564075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.82440299828263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.010985835765666`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.788197949138606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.4480988144794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041144`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 
             Association[1 -> {
                Complex[46.80892999564075, -8.82440299828263], 
                Complex[69.88465297350923, -32.010985835765666`]}, 2 -> {
                Complex[50.788197949138606`, 6.473813636367646], 
                Complex[73.4480988144794, -13.573316941041144`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.503834620057005}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.80892999564075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.82440299828263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.88465297350923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.010985835765666`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.788197949138606`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.473813636367646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.4480988144794`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.573316941041144`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 
             Association[1 -> {
                Complex[46.80892999564075, -8.82440299828263], 
                Complex[69.88465297350923, -32.010985835765666`]}, 2 -> {
                Complex[50.788197949138606`, 6.473813636367646], 
                Complex[73.4480988144794, -13.573316941041144`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.512865580412156}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.882185196050116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.72797535523715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.6634360796057495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "A", 
             Association[1 -> {
                Complex[46.882185196050116`, -9.003370304344577], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[50.72797535523715, 6.6634360796057495`], 
                Complex[73.36574696131454, -13.345285495813705`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.5270251190297595`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.882185196050116`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.003370304344577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"69.9866771608769`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21297033543326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.72797535523715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.6634360796057495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.36574696131454`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.345285495813705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "A", 
             Association[1 -> {
                Complex[46.882185196050116`, -9.003370304344577], 
                Complex[69.9866771608769, -32.21297033543326]}, 2 -> {
                Complex[50.72797535523715, 6.6634360796057495`], 
                Complex[73.36574696131454, -13.345285495813705`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.536837355201002}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.951306082313856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.671827307684104`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250492988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 
             Association[1 -> {
                Complex[46.951306082313856`, -9.178786832849886], 
                Complex[70.08355015001808, -32.41114577568788]}, 2 -> {
                Complex[50.671827307684104`, 6.849417013859745], 
                Complex[73.2885058483752, -13.121202250492988`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.550591526552399}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"46.951306082313856`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.178786832849886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.08355015001808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.41114577568788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.671827307684104`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.849417013859745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.2885058483752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.121202250492988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 
             Association[1 -> {
                Complex[46.951306082313856`, -9.178786832849886], 
                Complex[70.08355015001808, -32.41114577568788]}, 2 -> {
                Complex[50.671827307684104`, 6.849417013859745], 
                Complex[73.2885058483752, -13.121202250492988`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.56119028821649}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.016665157888184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.350721960698461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.1757166401882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.60556303669796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.61938174368467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.031826954994077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 
             Association[1 -> {
                Complex[47.016665157888184`, -9.350721960698461], 
                Complex[70.1757166401882, -32.60556303669796]}, 2 -> {
                Complex[50.61938174368467, 7.031826954994077], 
                Complex[73.21593091512594, -12.901014934479544`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.574527813391963}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.016665157888184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.350721960698461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.1757166401882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.60556303669796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.61938174368467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.031826954994077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.21593091512594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.901014934479544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 
             Association[1 -> {
                Complex[47.016665157888184`, -9.350721960698461], 
                Complex[70.1757166401882, -32.60556303669796]}, 2 -> {
                Complex[50.61938174368467, 7.031826954994077], 
                Complex[73.21593091512594, -12.901014934479544`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.5859114042316635`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.078594407914174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.79629250746041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.570307114637814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.1476243120753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.078594407914174`, -9.519258803308224], 
                Complex[70.26357461989492, -32.79629250746041]}, 2 -> {
                Complex[50.570307114637814`, 7.210750138216329], 
                Complex[73.1476243120753, -12.684651789041993`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.598828147061497}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.078594407914174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.519258803308224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.26357461989492`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.79629250746041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.570307114637814`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.210750138216329`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.1476243120753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.684651789041993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.078594407914174`, -9.519258803308224], 
                Complex[70.26357461989492, -32.79629250746041]}, 2 -> {
                Complex[50.570307114637814`, 7.210750138216329], 
                Complex[73.1476243120753, -12.684651789041993`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.6109897329143665`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.13738978959499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.68448944959141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.983418096522826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.52430789579726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.386279753462804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.13738978959499, -9.68448944959141], 
                Complex[70.34748028709403, -32.983418096522826`]}, 2 -> {
                Complex[50.52430789579726, 7.386279753462804], 
                Complex[73.08322998054211, -12.472027556181573`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.62348688221421}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.13738978959499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.68448944959141`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.34748028709403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.983418096522826`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.52430789579726`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.386279753462804`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.08322998054211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.472027556181573`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.13738978959499, -9.68448944959141], 
                Complex[70.34748028709403, -32.983418096522826`]}, 2 -> {
                Complex[50.52430789579726, 7.386279753462804], 
                Complex[73.08322998054211, -12.472027556181573`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.636415883974465}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.19331536912255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.846511388382378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.1670326786391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.48112044938315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.558514372224588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.26304803157383`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "A", 
             Association[1 -> {
                Complex[47.19331536912255, -9.846511388382378], 
                Complex[70.42775264717702, -33.1670326786391]}, 2 -> {
                Complex[50.48112044938315, 7.558514372224588], 
                Complex[73.02242905463167, -12.26304803157383]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.648498551648339}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.19331536912255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.846511388382378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.42775264717702`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.1670326786391`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.48112044938315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.558514372224588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"73.02242905463167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.26304803157383`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "A", 
             Association[1 -> {
                Complex[47.19331536912255, -9.846511388382378], 
                Complex[70.42775264717702, -33.1670326786391]}, 2 -> {
                Complex[50.48112044938315, 7.558514372224588], 
                Complex[73.02242905463167, -12.26304803157383]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.662181715591608}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.24660706078816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.00542485182525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771441998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654395`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.44050928550963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.727555291323419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "A", 
             Association[1 -> {
                Complex[47.24660706078816, -10.00542485182525], 
                Complex[70.50467771441998, -33.34723465654395]}, 2 -> {
                Complex[50.44050928550963, 7.727555291323419], 
                Complex[72.96493565975211, -12.057613502401406`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.673857857875899}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.24660706078816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.00542485182525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.50467771441998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.34723465654395`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.44050928550963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"7.727555291323419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.96493565975211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.057613502401406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "A", 
             Association[1 -> {
                Complex[47.24660706078816, -10.00542485182525], 
                Complex[70.50467771441998, -33.34723465654395]}, 2 -> {
                Complex[50.44050928550963, 7.727555291323419], 
                Complex[72.96493565975211, -12.057613502401406`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34., -6.688280075984198}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.29747596348612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.161330860116289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.524125383471365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.402263725719145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "A", 
             Association[1 -> {
                Complex[47.29747596348612, -10.161330860116289`], 
                Complex[70.57851229402165, -33.524125383471365`]}, 2 -> {
                Complex[50.402263725719145`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452313`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34., -6.6995596652126155`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.29747596348612`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.161330860116289`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.57851229402165`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.524125383471365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.402263725719145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.89350457803234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.9104931305427`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.855621324452313`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "A", 
             Association[1 -> {
                Complex[47.29747596348612, -10.161330860116289`], 
                Complex[70.57851229402165, -33.524125383471365`]}, 2 -> {
                Complex[50.402263725719145`, 7.89350457803234], 
                Complex[72.9104931305427, -11.855621324452313`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.714704602015879}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.34611131233811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.69780724710277`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.36619495139631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.056463649045714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "A", 
             Association[1 -> {
                Complex[47.34611131233811, -10.314329800105746`], 
                Complex[70.64948735230315, -33.69780724710277]}, 2 -> {
                Complex[50.36619495139631, 8.056463649045714], 
                Complex[72.85887064064234, -11.656967837798806`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.725598992349869}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.34611131233811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.314329800105746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.64948735230315`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.69780724710277`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.36619495139631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.056463649045714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.85887064064234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.656967837798806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "A", 
             Association[1 -> {
                Complex[47.34611131233811, -10.314329800105746`], 
                Complex[70.64948735230315, -33.69780724710277]}, 2 -> {
                Complex[50.36619495139631, 8.056463649045714], 
                Complex[72.85887064064234, -11.656967837798806`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.74144956213838}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.39268307483162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.464520408616714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.86838226002102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.3321334076672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.2165322541574`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.8098602198848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597864`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "A", 
             Association[1 -> {
                Complex[47.39268307483162, -10.464520408616714`], 
                Complex[70.71781099948186, -33.86838226002102]}, 2 -> {
                Complex[50.3321334076672, 8.2165322541574], 
                Complex[72.8098602198848, -11.46154977597864]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.751971005373259}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.39268307483162`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.464520408616714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.71781099948186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.86838226002102`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.3321334076672`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.2165322541574`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.8098602198848`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.46154977597864`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "A", 
             Association[1 -> {
                Complex[47.39268307483162, -10.464520408616714`], 
                Complex[70.71781099948186, -33.86838226002102]}, 2 -> {
                Complex[50.3321334076672, 8.2165322541574], 
                Complex[72.8098602198848, -11.46154977597864]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.768509733741808}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.4373442258159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.611999061422935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.03595103690155`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.29992652844131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.373807765588333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.269265288448755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "A", 
             Association[1 -> {
                Complex[47.4373442258159, -10.611999061422935`], 
                Complex[70.78367111767889, -34.03595103690155]}, 2 -> {
                Complex[50.29992652844131, 8.373807765588333], 
                Complex[72.76327412626179, -11.269265288448755`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.77867101119499}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.4373442258159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.611999061422935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.78367111767889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.03595103690155`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.29992652844131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.373807765588333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.76327412626179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.269265288448755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "A", 
             Association[1 -> {
                Complex[47.4373442258159, -10.611999061422935`], 
                Complex[70.78367111767889, -34.03595103690155]}, 2 -> {
                Complex[50.29992652844131, 8.373807765588333], 
                Complex[72.76327412626179, -11.269265288448755`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.795880307194897}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.48023273663557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.75685929217107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.84723766978762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.20061206617882`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.26943674731541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.52838469724979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 
             Association[1 -> {
                Complex[47.48023273663557, -10.75685929217107], 
                Complex[70.84723766978762, -34.20061206617882]}, 2 -> {
                Complex[50.26943674731541, 8.52838469724979], 
                Complex[72.71894253702615, -11.080014668572227`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.805694451370385}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.48023273663557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.75685929217107`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.84723766978762`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.20061206617882`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.26943674731541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.52838469724979`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71894253702615`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.080014668572227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 
             Association[1 -> {
                Complex[47.48023273663557, -10.75685929217107], 
                Complex[70.84723766978762, -34.20061206617882]}, 2 -> {
                Complex[50.26943674731541, 8.52838469724979], 
                Complex[72.71894253702615, -11.080014668572227`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.823556810596586}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.52147331234387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.89919148351823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.90866472468208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.24053976039788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.680354396213662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 
             Association[1 -> {
                Complex[47.52147331234387, -10.89919148351823], 
                Complex[70.90866472468208, -34.36246120528307]}, 2 -> {
                Complex[50.24053976039788, 8.680354396213662], 
                Complex[72.67671152345633, -10.893700858042976`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.833036896271207}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.52147331234387`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.89919148351823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.90866472468208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.36246120528307`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.24053976039788`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.680354396213662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.67671152345633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.893700858042976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 
             Association[1 -> {
                Complex[47.52147331234387, -10.89919148351823], 
                Complex[70.90866472468208, -34.36246120528307]}, 2 -> {
                Complex[50.24053976039788, 8.680354396213662], 
                Complex[72.67671152345633, -10.893700858042976`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -6.851535050615374}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.561178908409175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.21312300963941`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.829804862450947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159116`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.561178908409175`, -11.039082686546374`], 
                Complex[70.96809223235843, -34.52159134503682]}, 2 -> {
                Complex[50.21312300963941, 8.829804862450947], 
                Complex[72.6364412756889, -10.710229782159116`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -6.86069403959059}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.561178908409175`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.039082686546374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"70.96809223235843`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.52159134503682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.21312300963941`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.829804862450947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.6364412756889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.710229782159116`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.561178908409175`, -11.039082686546374`], 
                Complex[70.96809223235843, -34.52159134503682]}, 2 -> {
                Complex[50.21312300963941, 8.829804862450947], 
                Complex[72.6364412756889, -10.710229782159116`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -6.879811065843166}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.59945205528385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.17661653505851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.1870843583013`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.9768206634439`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.59945205528385, -11.17661653505851], 
                Complex[71.02564757984514, -34.67809220149987]}, 2 -> {
                Complex[50.1870843583013, 8.9768206634439], 
                Complex[72.59800454678344, -10.529510557655934`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -6.888661693156725}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.59945205528385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.17661653505851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.02564757984514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.67809220149987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.1870843583013`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.9768206634439`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"72.59800454678344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.529510557655934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.59945205528385, -11.17661653505851], 
                Complex[71.02564757984514, -34.67809220149987]}, 2 -> {
                Complex[50.1870843583013, 8.9768206634439], 
                Complex[72.59800454678344, -10.529510557655934`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.8, -6.908381089900704}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.636386016039125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.16233093335741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.121482918322886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "A", 
             Association[1 -> {
                Complex[47.636386016039125`, -11.311873229407055`], 
                Complex[71.08144695562096, -34.83205020330796]}, 2 -> {
                Complex[50.16233093335741, 9.121482918322886], 
                Complex[72.56128528828063, -10.351455605052497`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -6.91693578203401}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.636386016039125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.311873229407055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.08144695562096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.83205020330796`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.16233093335741`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.121482918322886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56128528828063`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.351455605052497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "A", 
             Association[1 -> {
                Complex[47.636386016039125`, -11.311873229407055`], 
                Complex[71.08144695562096, -34.83205020330796]}, 2 -> {
                Complex[50.16233093335741, 9.121482918322886], 
                Complex[72.56128528828063, -10.351455605052497`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{34.9, -6.937241522156761}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.672065799209136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.983548450042505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.138778112686914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.26386933231359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.175980689974885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "A", 
             Association[1 -> {
                Complex[47.672065799209136`, -11.444929570640568`], 
                Complex[71.13559654715354, -34.983548450042505`]}, 2 -> {
                Complex[50.138778112686914`, 9.26386933231359], 
                Complex[72.52617745264078, -10.175980689974885`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -6.945512339892273}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.672065799209136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.444929570640568`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.13559654715354`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.983548450042505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.138778112686914`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.26386933231359`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.52617745264078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.175980689974885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "A", 
             Association[1 -> {
                Complex[47.672065799209136`, -11.444929570640568`], 
                Complex[71.13559654715354, -34.983548450042505`]}, 2 -> {
                Complex[50.138778112686914`, 9.26386933231359], 
                Complex[72.52617745264078, -10.175980689974885`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35., -6.96638890440427}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.70656904615111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.575859030428859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.13266672291677`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.116348637750534`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.40405426695551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.003004912170228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "A", 
             Association[1 -> {
                Complex[47.70656904615111, -11.575859030428859`], 
                Complex[71.18819359319453, -35.13266672291677]}, 2 -> {
                Complex[50.116348637750534`, 9.40405426695551], 
                Complex[72.49258394092674, -10.003004912170228`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35., -6.974387504626086}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.70656904615111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.575859030428859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.18819359319453`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.13266672291677`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.116348637750534`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.40405426695551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.49258394092674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.003004912170228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "A", 
             Association[1 -> {
                Complex[47.70656904615111, -11.575859030428859`], 
                Complex[71.18819359319453, -35.13266672291677]}, 2 -> {
                Complex[50.116348637750534`, 9.40405426695551], 
                Complex[72.49258394092674, -10.003004912170228`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.1, -6.995819902207497}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.73996680966804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.704731845790777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.27948153347702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.09497183500416`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.542108835115947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "A", 
             Association[1 -> {
                Complex[47.73996680966804, -11.704731845790777`], 
                Complex[71.23932730972692, -35.27948153347702]}, 2 -> {
                Complex[50.09497183500416, 9.542108835115947], 
                Complex[72.46041567683548, -9.832450656512503]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -7.003557514207671}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.73996680966804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.704731845790777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.23932730972692`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.27948153347702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.09497183500416`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.542108835115947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46041567683548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.832450656512503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "A", 
             Association[1 -> {
                Complex[47.73996680966804, -11.704731845790777`], 
                Complex[71.23932730972692, -35.27948153347702]}, 2 -> {
                Complex[50.09497183500416, 9.542108835115947], 
                Complex[72.46041567683548, -9.832450656512503]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -7.025531289920055}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.77232423836924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.831615130363643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.4240661994061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.07458293157423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.678101012538281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 
             Association[1 -> {
                Complex[47.77232423836924, -11.831615130363643`], 
                Complex[71.28907970599505, -35.4240661994061]}, 2 -> {
                Complex[50.07458293157423, 9.678101012538281], 
                Complex[72.42959079064792, -9.664243516913515]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -7.033018702758108}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.77232423836924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.831615130363643`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.28907970599505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.4240661994061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.07458293157423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.678101012538281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.42959079064792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.664243516913515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 
             Association[1 -> {
                Complex[47.77232423836924, -11.831615130363643`], 
                Complex[71.28907970599505, -35.4240661994061]}, 2 -> {
                Complex[50.07458293157423, 9.678101012538281], 
                Complex[72.42959079064792, -9.664243516913515]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.3, -7.055519938594428}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.80370117925396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.956572996022805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.56649093911878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.05512245271003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40003389885213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "A", 
             Association[1 -> {
                Complex[47.80370117925396, -11.956572996022805`], 
                Complex[71.33752630486225, -35.56649093911878]}, 2 -> {
                Complex[50.05512245271003, 9.812095759734234], 
                Complex[72.40003389885213, -9.498312201447764]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -7.062767496822789}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.80370117925396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.956572996022805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.33752630486225`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.56649093911878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.05512245271003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.812095759734234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40003389885213`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.498312201447764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "A", 
             Association[1 -> {
                Complex[47.80370117925396, -11.956572996022805`], 
                Complex[71.33752630486225, -35.56649093911878]}, 2 -> {
                Complex[50.05512245271003, 9.812095759734234], 
                Complex[72.40003389885213, -9.498312201447764]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.4, -7.085782806174331}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.834152709273475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.706822978841465`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.036535690257004`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.944155149605944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.33458842500021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "A", 
             Association[1 -> {
                Complex[47.834152709273475`, -12.079666680238098`], 
                Complex[71.38473677982421, -35.706822978841465`]}, 2 -> {
                Complex[50.036535690257004`, 9.944155149605944], 
                Complex[72.37167546711125, -9.33458842500021]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -7.092800411838077}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.834152709273475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.079666680238098`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.38473677982421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.706822978841465`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.036535690257004`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.944155149605944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37167546711125`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.33458842500021`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "A", 
             Association[1 -> {
                Complex[47.834152709273475`, -12.079666680238098`], 
                Complex[71.38473677982421, -35.706822978841465`]}, 2 -> {
                Complex[50.036535690257004`, 9.944155149605944], 
                Complex[72.37167546711125, -9.33458842500021]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -7.116316929493451}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.86372960513274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.20095467575531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.845126667405935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.01877223289047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.074338497386961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 
             Association[1 -> {
                Complex[47.86372960513274, -12.20095467575531], 
                Complex[71.43077551933807, -35.845126667405935`]}, 2 -> {
                Complex[50.01877223289047, 10.074338497386961`], 
                Complex[72.34445124591687, -9.173006794205872]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -7.123114048777092}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.86372960513274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.20095467575531`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.43077551933807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.845126667405935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.01877223289047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.074338497386961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.34445124591687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.173006794205872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 
             Association[1 -> {
                Complex[47.86372960513274, -12.20095467575531], 
                Complex[71.43077551933807, -35.845126667405935`]}, 2 -> {
                Complex[50.01877223289047, 10.074338497386961`], 
                Complex[72.34445124591687, -9.173006794205872]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -7.147119417707032}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.892478759305945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.00178555013501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.202702490405663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267268`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.892478759305945`, -12.320492860106404`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[50.00178555013501, 10.202702490405663`], 
                Complex[72.31830176971437, -9.013504688267268]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -7.15370509096351}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.892478759305945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.320492860106404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.47570212768004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.98146359517152`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"50.00178555013501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.202702490405663`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.31830176971437`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.013504688267268`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 
             Association[1 -> {
                Complex[47.892478759305945`, -12.320492860106404`], 
                Complex[71.47570212768004, -35.98146359517152]}, 2 -> {
                Complex[50.00178555013501, 10.202702490405663`], 
                Complex[72.31830176971437, -9.013504688267268]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -7.178187446862471}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.92044354913625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.438334623148688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.5195718702971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.98553262329957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.329301315871618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29317191153511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.85602213832465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.92044354913625, -12.438334623148688`], 
                Complex[71.5195718702971, -36.11589271440042]}, 2 -> {
                Complex[49.98553262329957, 10.329301315871618`], 
                Complex[72.29317191153511, -8.85602213832465]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -7.184570301042968}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.92044354913625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.438334623148688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.5195718702971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.11589271440042`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.98553262329957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.329301315871618`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29317191153511`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.85602213832465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 
             Association[1 -> {
                Complex[47.92044354913625, -12.438334623148688`], 
                Complex[71.5195718702971, -36.11589271440042]}, 2 -> {
                Complex[49.98553262329957, 10.329301315871618`], 
                Complex[72.29317191153511, -8.85602213832465]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.8, -7.209518255377725}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.947664164943085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.554530991361462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.969973617404506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.45418678541366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "A", 
             Association[1 -> {
                Complex[47.947664164943085`, -12.554530991361462`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[49.969973617404506`, 10.45418678541366], 
                Complex[72.26901048624575, -8.700501707354443]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -7.21570651810255}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.947664164943085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.554530991361462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.56243607054202`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.24847045911044`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.969973617404506`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.45418678541366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.26901048624575`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.700501707354443`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "A", 
             Association[1 -> {
                Complex[47.947664164943085`, -12.554530991361462`], 
                Complex[71.56243607054202, -36.24847045911044]}, 2 -> {
                Complex[49.969973617404506`, 10.45418678541366], 
                Complex[72.26901048624575, -8.700501707354443]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.9, -7.241109140244783}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.97417790224991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.66913074802967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.6043424637563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.37925086296772`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.955071588988176`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.577408455499175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033514`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "A", 
             Association[1 -> {
                Complex[47.97417790224991, -12.66913074802967], 
                Complex[71.6043424637563, -36.37925086296772]}, 2 -> {
                Complex[49.955071588988176`, 10.577408455499175`], 
                Complex[72.24576989645067, -8.546888372033514]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -7.247110654929341}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"47.97417790224991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.66913074802967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.6043424637563`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.37925086296772`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.955071588988176`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.577408455499175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.24576989645067`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.546888372033514`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "A", 
             Association[1 -> {
                Complex[47.97417790224991, -12.66913074802967], 
                Complex[71.6043424637563, -36.37925086296772]}, 2 -> {
                Complex[49.955071588988176`, 10.577408455499175`], 
                Complex[72.24576989645067, -8.546888372033514]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -7.272957453813909}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.00001942255101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50828567419364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.94079222537401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.699013743166008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594679`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 
             Association[1 -> {
                Complex[48.00001942255101, -12.782180548745712`], 
                Complex[71.64533551387005, -36.50828567419364]}, 2 -> {
                Complex[49.94079222537401, 10.699013743166008`], 
                Complex[72.22340581587778, -8.395129407594679]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -7.278779695399862}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.00001942255101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.782180548745712`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.64533551387005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50828567419364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.94079222537401`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.699013743166008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.22340581587778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.395129407594679`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 
             Association[1 -> {
                Complex[48.00001942255101, -12.782180548745712`], 
                Complex[71.64533551387005, -36.50828567419364]}, 2 -> {
                Complex[49.94079222537401, 10.699013743166008`], 
                Complex[72.22340581587778, -8.395129407594679]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -7.305060601044229}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.02522098644102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.893725031887865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.635624466775916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.92710361157446`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.8190480367257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.02522098644102, -12.893725031887865`], 
                Complex[71.68545669700364, -36.635624466775916`]}, 2 -> {
                Complex[49.92710361157446, 10.8190480367257], 
                Complex[72.20187690576324, -8.245174276383164]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -7.310710691992647}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.02522098644102`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.893725031887865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.68545669700364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.635624466775916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.92710361157446`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.8190480367257`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20187690576324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.245174276383164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.02522098644102, -12.893725031887865`], 
                Complex[71.68545669700364, -36.635624466775916`]}, 2 -> {
                Complex[49.92710361157446, 10.8190480367257], 
                Complex[72.20187690576324, -8.245174276383164]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -7.337416037129787}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.04981266242253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.00380692390271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.76131474751435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.9139760215171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.93755480126541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.096974520583906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.04981266242253, -13.00380692390271], 
                Complex[71.72474475596931, -36.76131474751435]}, 2 -> {
                Complex[49.9139760215171, 10.93755480126541], 
                Complex[72.18114456033722, -8.096974520583906]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -7.34290076341676}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.04981266242253`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.00380692390271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.72474475596931`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.76131474751435`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.9139760215171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.93755480126541`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.18114456033722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.096974520583906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.04981266242253, -13.00380692390271], 
                Complex[71.72474475596931, -36.76131474751435]}, 2 -> {
                Complex[49.9139760215171, 10.93755480126541], 
                Complex[72.18114456033722, -8.096974520583906]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.3, -7.3700212654289325`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.073822514268066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.112467139344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.88540205861425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.901381730715414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.950483659405908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "A", 
             Association[1 -> {
                Complex[48.073822514268066`, -13.112467139344405`], 
                Complex[71.76323592906267, -36.88540205861425]}, 2 -> {
                Complex[49.901381730715414`, 11.054575678901632`], 
                Complex[72.16117267801965, -7.950483659405908]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -7.375347092349617}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.073822514268066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.112467139344405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76323592906267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.88540205861425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.901381730715414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.054575678901632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.16117267801965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.950483659405908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "A", 
             Association[1 -> {
                Complex[48.073822514268066`, -13.112467139344405`], 
                Complex[71.76323592906267, -36.88540205861425]}, 2 -> {
                Complex[49.901381730715414`, 11.054575678901632`], 
                Complex[72.16117267801965, -7.950483659405908]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.4, -7.402873835639527}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.097276769439844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.88929484788194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.170150583829274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.805657090873341`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "A", 
             Association[1 -> {
                Complex[48.097276769439844`, -13.219744875714255`], 
                Complex[71.80096415610163, -37.00793007567815]}, 2 -> {
                Complex[49.88929484788194, 11.170150583829274`], 
                Complex[72.1419274553698, -7.805657090873341]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -7.4080469232778885`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.097276769439844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.219744875714255`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80096415610163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.00793007567815`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.88929484788194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.170150583829274`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1419274553698`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.805657090873341`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "A", 
             Association[1 -> {
                Complex[48.097276769439844`, -13.219744875714255`], 
                Complex[71.80096415610163, -37.00793007567815]}, 2 -> {
                Complex[49.88929484788194, 11.170150583829274`], 
                Complex[72.1419274553698, -7.805657090873341]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.5, -7.435971342174077}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.12019997074639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.12894070104982`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.8776911633041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.28431779227576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "A", 
             Association[1 -> {
                Complex[48.12019997074639, -13.325677703210104`], 
                Complex[71.83796126429178, -37.12894070104982]}, 2 -> {
                Complex[49.8776911633041, 11.28431779227576], 
                Complex[72.1233772012094, -7.662451998269178]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -7.44099756043563}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.12019997074639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.325677703210104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83796126429178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.12894070104982`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.8776911633041`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.28431779227576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1233772012094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.662451998269178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "A", 
             Association[1 -> {
                Complex[48.12019997074639, -13.325677703210104`], 
                Complex[71.83796126429178, -37.12894070104982]}, 2 -> {
                Complex[49.8776911633041, 11.28431779227576], 
                Complex[72.1233772012094, -7.662451998269178]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.6, -7.469311422698217}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.142615113138476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.430301649540363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.248474152540204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.86654801208047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.397114027514972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "A", 
             Association[1 -> {
                Complex[48.142615113138476`, -13.430301649540363`], 
                Complex[71.8742571361754, -37.248474152540204`]}, 2 -> {
                Complex[49.86654801208047, 11.397114027514972`], 
                Complex[72.10549216866305, -7.520827261201417]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -7.474196365834283}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.142615113138476`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.430301649540363`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8742571361754`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.248474152540204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.86654801208047`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.397114027514972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.10549216866305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.520827261201417`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "A", 
             Association[1 -> {
                Complex[48.142615113138476`, -13.430301649540363`], 
                Complex[71.8742571361754, -37.248474152540204`]}, 2 -> {
                Complex[49.86654801208047, 11.397114027514972`], 
                Complex[72.10549216866305, -7.520827261201417]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -7.5028917568031925`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.16454376730663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.533651279988442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.366569047621205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.85584415055513`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.508574540127224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.38074337120608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.16454376730663, -13.533651279988442`], 
                Complex[71.90987986163972, -37.366569047621205`]}, 2 -> {
                Complex[49.85584415055513, 11.508574540127224`], 
                Complex[72.08824440313957, -7.38074337120608]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -7.50764075737943}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.16454376730663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.533651279988442`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90987986163972`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.366569047621205`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.85584415055513`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.508574540127224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.08824440313957`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.38074337120608`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.16454376730663, -13.533651279988442`], 
                Complex[71.90987986163972, -37.366569047621205`]}, 2 -> {
                Complex[49.85584415055513, 11.508574540127224`], 
                Complex[72.08824440313957, -7.38074337120608]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -7.5367100647889185`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.186006191536734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.63575977293281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94485587571889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.84555964449377`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0716076045205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 
             Association[1 -> {
                Complex[48.186006191536734`, -13.63575977293281], 
                Complex[71.94485587571889, -37.483262483211874`]}, 2 -> {
                Complex[49.84555964449377, 11.618733183710322`], 
                Complex[72.0716076045205, -7.242162351762072]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -7.541328207069591}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.186006191536734`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.63575977293281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94485587571889`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.483262483211874`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.84555964449377`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.618733183710322`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.0716076045205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.242162351762072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 
             Association[1 -> {
                Complex[48.186006191536734`, -13.63575977293281], 
                Complex[71.94485587571889, -37.483262483211874`]}, 2 -> {
                Complex[49.84555964449377, 11.618733183710322`], 
                Complex[72.0716076045205, -7.242162351762072]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -7.570764106538771}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.20702143310045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.736658991038883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.83567576772439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 
             Association[1 -> {
                Complex[48.20702143310045, -13.736658991038883`], 
                Complex[71.97921008371291, -37.59859011120972]}, 2 -> {
                Complex[49.83567576772439, 11.727622486258118`], 
                Complex[72.05555700203159, -7.105047682565447]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -7.5752562392726315`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.20702143310045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.736658991038883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97921008371291`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.59859011120972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.83567576772439`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.727622486258118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.05555700203159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.105047682565447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 
             Association[1 -> {
                Complex[48.20702143310045, -13.736658991038883`], 
                Complex[71.97921008371291, -37.59859011120972]}, 2 -> {
                Complex[49.83567576772439, 11.727622486258118`], 
                Complex[72.05555700203159, -7.105047682565447]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -7.605051680471024}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.22760742030328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.836379548343533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.82617491012043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 
             Association[1 -> {
                Complex[48.22760742030328, -13.836379548343533`], 
                Complex[72.01296597496555, -37.712586209936944`]}, 2 -> {
                Complex[49.82617491012043, 11.835273717427539`], 
                Complex[72.04006924045628, -6.969364227892692]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -7.60942242907562}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.22760742030328`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.836379548343533`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01296597496555`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.712586209936944`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.82617491012043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.835273717427539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04006924045628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.969364227892692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 
             Association[1 -> {
                Complex[48.22760742030328, -13.836379548343533`], 
                Complex[72.01296597496555, -37.712586209936944`]}, 2 -> {
                Complex[49.82617491012043, 11.835273717427539`], 
                Complex[72.04006924045628, -6.969364227892692]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -7.639570622554803}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.24778104617793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.934950873453174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.81704049393779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.835078168871881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.24778104617793, -13.934950873453174`], 
                Complex[72.04614572648373, -37.82528375168293]}, 2 -> {
                Complex[49.81704049393779, 11.941716951915161`], 
                Complex[72.02512227650753, -6.835078168871881]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -7.643824400704306}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.24778104617793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.934950873453174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.04614572648373`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.82528375168293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.81704049393779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.941716951915161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.02512227650753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.835078168871881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.24778104617793, -13.934950873453174`], 
                Complex[72.04614572648373, -37.82528375168293]}, 2 -> {
                Complex[49.81704049393779, 11.941716951915161`], 
                Complex[72.02512227650753, -6.835078168871881]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -7.674318805380697}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.2675582446947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.032401269072565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07877029744378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.93671446652881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.80825689763537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.046981129160331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.2675582446947, -14.032401269072565`], 
                Complex[72.07877029744378, -37.93671446652881]}, 2 -> {
                Complex[49.80825689763537, 12.046981129160331`], 
                Complex[72.01069528431421, -6.702156939475872]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -7.678459826008452}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.2675582446947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.032401269072565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.07877029744378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.93671446652881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.80825689763537`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.046981129160331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.01069528431421`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.702156939475872`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.2675582446947, -14.032401269072565`], 
                Complex[72.07877029744378, -37.93671446652881]}, 2 -> {
                Complex[49.80825689763537, 12.046981129160331`], 
                Complex[72.01069528431421, -6.702156939475872]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.3, -7.709294137278292}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.28695406025804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.12875796807638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1108595155086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.04690890264222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.79980938640803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.151094109587378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "A", 
             Association[1 -> {
                Complex[48.28695406025804, -14.12875796807638], 
                Complex[72.1108595155086, -38.04690890264222]}, 2 -> {
                Complex[49.79980938640803, 12.151094109587378`], 
                Complex[71.99676856909558, -6.570569166048992]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -7.7133264230097875`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.28695406025804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.12875796807638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.1108595155086`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.04690890264222`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.79980938640803`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.151094109587378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.99676856909558`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.570569166048992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "A", 
             Association[1 -> {
                Complex[48.28695406025804, -14.12875796807638], 
                Complex[72.1108595155086, -38.04690890264222]}, 2 -> {
                Complex[49.79980938640803, 12.151094109587378`], 
                Complex[71.99676856909558, -6.570569166048992]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.4, -7.744494561474098}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.305982711170586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.155896483227494`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.791684048752806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.983323488207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181978`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "A", 
             Association[1 -> {
                Complex[48.305982711170586`, -14.22404718632718], 
                Complex[72.14243215577531, -38.155896483227494`]}, 2 -> {
                Complex[49.791684048752806`, 12.254082727590417`], 
                Complex[71.983323488207, -6.440284610181978]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -7.748421954509174}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.305982711170586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.22404718632718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.14243215577531`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.155896483227494`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.791684048752806`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.254082727590417`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.983323488207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.440284610181978`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "A", 
             Association[1 -> {
                Complex[48.305982711170586`, -14.22404718632718], 
                Complex[72.14243215577531, -38.155896483227494`]}, 2 -> {
                Complex[49.791684048752806`, 12.254082727590417`], 
                Complex[71.983323488207, -6.440284610181978]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.5, -7.7799180552848615`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.32465764766804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.31829417243562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.783867738463265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.35597284145664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.31127411475293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "A", 
             Association[1 -> {
                Complex[48.32465764766804, -14.31829417243562], 
                Complex[72.17350601308073, -38.263705560313795`]}, 2 -> {
                Complex[49.783867738463265`, 12.35597284145664], 
                Complex[71.97034237882725, -6.31127411475293]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -7.783744226750142}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.32465764766804`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.31829417243562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.17350601308073`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.263705560313795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.783867738463265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.35597284145664`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.97034237882725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.31127411475293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "A", 
             Association[1 -> {
                Complex[48.32465764766804, -14.31829417243562], 
                Complex[72.17350601308073, -38.263705560313795`]}, 2 -> {
                Complex[49.783867738463265`, 12.35597284145664], 
                Complex[71.97034237882725, -6.31127411475293]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.6, -7.815562629342031}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.342991605060675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.411523254649312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.776348021517336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "A", 
             Association[1 -> {
                Complex[48.342991605060675`, -14.411523254649312`], 
                Complex[72.20409796831112, -38.37036346555746]}, 2 -> {
                Complex[49.776348021517336`, 12.456789380414614`], 
                Complex[71.95780849164257, -6.183509552957572]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -7.819291088135867}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.342991605060675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.411523254649312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.20409796831112`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.37036346555746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.776348021517336`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.456789380414614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.95780849164257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.183509552957572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "A", 
             Association[1 -> {
                Complex[48.342991605060675`, -14.411523254649312`], 
                Complex[72.20409796831112, -38.37036346555746]}, 2 -> {
                Complex[49.776348021517336`, 12.456789380414614`], 
                Complex[71.95780849164257, -6.183509552957572]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.7, -7.851426326843987}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.360996652457885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.503757885046658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.769113127381615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.556556388984413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "A", 
             Association[1 -> {
                Complex[48.360996652457885`, -14.503757885046658`], 
                Complex[72.23422404929191, -38.47589655822829]}, 2 -> {
                Complex[49.769113127381615`, 12.556556388984413`], 
                Complex[71.94570592995045, -6.056963780158599]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -7.8550604279969685`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.360996652457885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.503757885046658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.23422404929191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.47589655822829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.769113127381615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.556556388984413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.94570592995045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.056963780158599`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "A", 
             Association[1 -> {
                Complex[48.360996652457885`, -14.503757885046658`], 
                Complex[72.23422404929191, -38.47589655822829]}, 2 -> {
                Complex[49.769113127381615`, 12.556556388984413`], 
                Complex[71.94570592995045, -6.056963780158599]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.8, -7.887507222833287}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.37868423749987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.595020681203493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054337`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.76215190430832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.655297068796713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9340195936706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391596`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "A", 
             Association[1 -> {
                Complex[48.37868423749987, -14.595020681203493`], 
                Complex[72.2638994867713, -38.58033027054337]}, 2 -> {
                Complex[49.76215190430832, 12.655297068796713`], 
                Complex[71.9340195936706, -5.931610588391596]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -7.891050175407584}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.37868423749987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.595020681203493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.2638994867713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.58033027054337`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.76215190430832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.655297068796713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.9340195936706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.931610588391596`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "A", 
             Association[1 -> {
                Complex[48.37868423749987, -14.595020681203493`], 
                Complex[72.2638994867713, -38.58033027054337]}, 2 -> {
                Complex[49.76215190430832, 12.655297068796713`], 
                Complex[71.9340195936706, -5.931610588391596]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -7.923803423496699}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.39606522747497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.685333465489398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.75545377824624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.753033818038535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 
             Association[1 -> {
                Complex[48.39606522747497, -14.685333465489398`], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[49.75545377824624, 12.753033818038535`], 
                Complex[71.92273512780362, -5.807424663371904]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -7.927258298047421}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.39606522747497`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.685333465489398`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.29313876595577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.68368915050276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.75545377824624`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.753033818038535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.92273512780362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.807424663371904`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 
             Association[1 -> {
                Complex[48.39606522747497, -14.685333465489398`], 
                Complex[72.29313876595577, -38.68368915050276]}, 2 -> {
                Complex[49.75545377824624, 12.753033818038535`], 
                Complex[71.92273512780362, -5.807424663371904]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -7.960313065486143}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.41314994716061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.77471730214245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.785996902375146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.74900871502786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.849788268674175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.91183887492751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 
             Association[1 -> {
                Complex[48.41314994716061, -14.77471730214245], 
                Complex[72.32195567400862, -38.785996902375146`]}, 2 -> {
                Complex[49.74900871502786, 12.849788268674175`], 
                Complex[71.91183887492751, -5.684381543854791]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -7.9636828011075345`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.41314994716061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.77471730214245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.32195567400862`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.785996902375146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.74900871502786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.849788268674175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.91183887492751`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.684381543854791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 
             Association[1 -> {
                Complex[48.41314994716061, -14.77471730214245], 
                Complex[72.32195567400862, -38.785996902375146`]}, 2 -> {
                Complex[49.74900871502786, 12.849788268674175`], 
                Complex[71.91183887492751, -5.684381543854791]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -7.9970343152589916`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.42994821369015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.86319253226119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.8872764249728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7428071855302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.945581321580041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209822`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.42994821369015, -14.86319253226119], 
                Complex[72.35036334387817, -38.8872764249728]}, 2 -> {
                Complex[49.7428071855302, 12.945581321580041`], 
                Complex[71.90131783136438, -5.562457583209822]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -8.000321726237692}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.42994821369015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.86319253226119`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.35036334387817`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.8872764249728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7428071855302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.945581321580041`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.90131783136438`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.562457583209822`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.42994821369015, -14.86319253226119], 
                Complex[72.35036334387817, -38.8872764249728]}, 2 -> {
                Complex[49.7428071855302, 12.945581321580041`], 
                Complex[71.90131783136438, -5.562457583209822]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -8.033965368436547}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.446469368716585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.950778806844472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73684013353857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.040433179724607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.446469368716585`, -14.950778806844472`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[49.73684013353857, 13.040433179724607`], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -8.03717315053345}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.446469368716585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.950778806844472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.37837429478613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.98754984784761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73684013353857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.040433179724607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.89115960668768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.441629913076676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.446469368716585`, -14.950778806844472`], 
                Complex[72.37837429478613, -38.98754984784761]}, 2 -> {
                Complex[49.73684013353857, 13.040433179724607`], 
                Complex[71.89115960668768, -5.441629913076676]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.3, -8.071104449179531}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.46272230811621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.037495118001443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.08683856553305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73109894607003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.134363379515118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "A", 
             Association[1 -> {
                Complex[48.46272230811621, -15.037495118001443`], 
                Complex[72.40600046967194, -39.08683856553305]}, 2 -> {
                Complex[49.73109894607003, 13.134363379515118`], 
                Complex[71.88135238627332, -5.321876408978639]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -8.074235185560973}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.46272230811621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.037495118001443`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.40600046967194`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.08683856553305`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.73109894607003`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.134363379515118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.88135238627332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.321876408978639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "A", 
             Association[1 -> {
                Complex[48.46272230811621, -15.037495118001443`], 
                Complex[72.40600046967194, -39.08683856553305]}, 2 -> {
                Complex[49.73109894607003, 13.134363379515118`], 
                Complex[71.88135238627332, -5.321876408978639]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.4, -8.108449809579817}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.47871550945055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.123359828445732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72557542593836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.227390820426002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "A", 
             Association[1 -> {
                Complex[48.47871550945055, -15.123359828445732`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[49.72557542593836, 13.227390820426002`], 
                Complex[71.8718848966287, -5.203175657776082]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -8.111505976417941}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.47871550945055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.123359828445732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.43325326985985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.18516326994852`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72557542593836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.227390820426002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8718848966287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.203175657776082`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "A", 
             Association[1 -> {
                Complex[48.47871550945055, -15.123359828445732`], 
                Complex[72.43325326985985, -39.18516326994852]}, 2 -> {
                Complex[49.72557542593836, 13.227390820426002`], 
                Complex[71.8718848966287, -5.203175657776082]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.5, -8.145999729067512}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.494457057382995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.20839069938103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72026176636399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.31953379301555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.08550692685011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "A", 
             Association[1 -> {
                Complex[48.494457057382995`, -15.20839069938103], 
                Complex[72.46014358718853, -39.28254398107672]}, 2 -> {
                Complex[49.72026176636399, 13.31953379301555], 
                Complex[71.86274637325921, -5.08550692685011]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -8.148983700828767}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.494457057382995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.20839069938103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.46014358718853`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.28254398107672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.72026176636399`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.31953379301555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.86274637325921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.08550692685011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "A", 
             Association[1 -> {
                Complex[48.494457057382995`, -15.20839069938103], 
                Complex[72.46014358718853, -39.28254398107672]}, 2 -> {
                Complex[49.72026176636399, 13.31953379301555], 
                Complex[71.86274637325921, -5.08550692685011]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -8.183752513832863}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.50995466722706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.292604916877659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7151505274519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.410810005430928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 
             Association[1 -> {
                Complex[48.50995466722706, -15.292604916877659`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[49.7151505274519, 13.410810005430928`], 
                Complex[71.85392653085567, -4.968850134912987]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -8.186666568272656}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.50995466722706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.292604916877659`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.48668183382003`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.37900007601697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.7151505274519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.410810005430928`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.85392653085567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.968850134912987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 
             Association[1 -> {
                Complex[48.50995466722706, -15.292604916877659`], 
                Complex[72.48668183382003, -39.37900007601697]}, 2 -> {
                Complex[49.7151505274519, 13.410810005430928`], 
                Complex[71.85392653085567, -4.968850134912987]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -8.22170649626235}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.52521570678645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.376019116833605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.710234614377775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.52521570678645, -15.376019116833605`], 
                Complex[72.51287796992378, -39.47455031651175]}, 2 -> {
                Complex[49.710234614377775`, 13.501236608494983`], 
                Complex[71.84541553560709, -4.853185824347898]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -8.224552819142978}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.52521570678645`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.376019116833605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.51287796992378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.47455031651175`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.710234614377775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.501236608494983`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.84541553560709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.853185824347898`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.52521570678645, -15.376019116833605`], 
                Complex[72.51287796992378, -39.47455031651175]}, 2 -> {
                Complex[49.710234614377775`, 13.501236608494983`], 
                Complex[71.84541553560709, -4.853185824347898]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.8, -8.259860034388504}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.54024721663022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70550725713841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.590830219461864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7384951349874775`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "A", 
             Association[1 -> {
                Complex[48.54024721663022, -15.458649408607112`], 
                Complex[72.53874152941212, -39.56921287503744]}, 2 -> {
                Complex[49.70550725713841, 13.590830219461864`], 
                Complex[71.83720397946203, -4.7384951349874775`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -8.262640723936546}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.54024721663022`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.458649408607112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.53874152941212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.56921287503744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70550725713841`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.590830219461864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.83720397946203`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.7384951349874775`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "A", 
             Association[1 -> {
                Complex[48.54024721663022, -15.458649408607112`], 
                Complex[72.53874152941212, -39.56921287503744]}, 2 -> {
                Complex[49.70550725713841, 13.590830219461864`], 
                Complex[71.83720397946203, -4.7384951349874775`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.9, -8.298211511352967}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.55505592893432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.540511397402028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70096199173561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.679606944523012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "A", 
             Association[1 -> {
                Complex[48.55505592893432, -15.540511397402028`], 
                Complex[72.56428164388791, -39.66300535954416]}, 2 -> {
                Complex[49.70096199173561, 13.679606944523012`], 
                Complex[71.82928285617803, -4.624759779245359]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -8.300928582471448}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.55505592893432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.540511397402028`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.56428164388791`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.66300535954416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.70096199173561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.679606944523012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.82928285617803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.624759779245359`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "A", 
             Association[1 -> {
                Complex[48.55505592893432, -15.540511397402028`], 
                Complex[72.56428164388791, -39.66300535954416]}, 2 -> {
                Complex[49.70096199173561, 13.679606944523012`], 
                Complex[71.82928285617803, -4.624759779245359]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -8.33675933488245}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.56964828500726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.621620205482065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.75594483692522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69659264267576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.767582400139355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8216435390141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.511962018521162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 
             Association[1 -> {
                Complex[48.56964828500726, -15.621620205482065`], 
                Complex[72.58950706494943, -39.75594483692522]}, 2 -> {
                Complex[49.69659264267576, 13.767582400139355`], 
                Complex[71.8216435390141, -4.511962018521162]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -8.339414723132242}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.56964828500726`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.621620205482065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.58950706494943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.75594483692522`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69659264267576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.767582400139355`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.8216435390141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.511962018521162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 
             Association[1 -> {
                Complex[48.56964828500726, -15.621620205482065`], 
                Complex[72.58950706494943, -39.75594483692522]}, 2 -> {
                Complex[49.69659264267576, 13.767582400139355`], 
                Complex[71.8216435390141, -4.511962018521162]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -8.37550193677721}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.5840304516069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.701990492284674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.848047855290424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69239330667786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.854771733270828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.81427775993448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803735`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.5840304516069, -15.701990492284674`], 
                Complex[72.61442618498417, -39.848047855290424`]}, 2 -> {
                Complex[49.69239330667786, 13.854771733270828`], 
                Complex[71.81427775993448, -4.400084640803735]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -8.378097502141282}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.5840304516069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.701990492284674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.61442618498417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.848047855290424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.69239330667786`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.854771733270828`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.81427775993448`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.400084640803735`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 
             Association[1 -> {
                Complex[48.5840304516069, -15.701990492284674`], 
                Complex[72.61442618498417, -39.848047855290424`]}, 2 -> {
                Complex[49.69239330667786, 13.854771733270828`], 
                Complex[71.81427775993448, -4.400084640803735]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -8.414437772411656}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.59820833614577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.939330465113585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68835833749281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.941189640569323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.59820833614577, -15.781636473500773`], 
                Complex[72.63904705657157, -39.939330465113585`]}, 2 -> {
                Complex[49.68835833749281, 13.941189640569323`], 
                Complex[71.80717759020362, -4.289110939402672]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -8.41697530285498}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.59820833614577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.781636473500773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.63904705657157`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.939330465113585`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68835833749281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.941189640569323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80717759020362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.289110939402672`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 
             Association[1 -> {
                Complex[48.59820833614577, -15.781636473500773`], 
                Complex[72.63904705657157, -39.939330465113585`]}, 2 -> {
                Complex[49.68835833749281, 13.941189640569323`], 
                Complex[71.80717759020362, -4.289110939402672]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.3, -8.45356532024686}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.612187600873085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.860571939182236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.029808239319934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68448233174574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.026850386597047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742367`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "A", 
             Association[1 -> {
                Complex[48.612187600873085`, -15.860571939182236`], 
                Complex[72.66337741060343, -40.029808239319934`]}, 2 -> {
                Complex[49.68448233174574, 14.026850386597047`], 
                Complex[71.80033542226364, -4.179024692742367]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -8.456046535084063}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.612187600873085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.860571939182236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.66337741060343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.029808239319934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.68448233174574`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.026850386597047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.80033542226364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.179024692742367`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "A", 
             Association[1 -> {
                Complex[48.612187600873085`, -15.860571939182236`], 
                Complex[72.66337741060343, -40.029808239319934`]}, 2 -> {
                Complex[49.68448233174574, 14.026850386597047`], 
                Complex[71.80033542226364, -4.179024692742367]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.4, -8.492883081354607}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.625973676114015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.938810270934708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.680760115720915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.111767821127955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.069810145157128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "A", 
             Association[1 -> {
                Complex[48.625973676114015`, -15.938810270934708`], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[49.680760115720915`, 14.111767821127955`], 
                Complex[71.79374395279486, -4.069810145157128]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -8.495309634436692}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.625973676114015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.938810270934708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.68742467322163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.119496292374684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.680760115720915`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.111767821127955`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.79374395279486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.069810145157128`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "A", 
             Association[1 -> {
                Complex[48.625973676114015`, -15.938810270934708`], 
                Complex[72.68742467322163, -40.119496292374684`]}, 2 -> {
                Complex[49.680760115720915`, 14.111767821127955`], 
                Complex[71.79374395279486, -4.069810145157128]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -8.532389578952746}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.63957177263898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.67718673301603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 
             Association[1 -> {
                Complex[48.63957177263898, -16.016364458249825`], 
                Complex[72.71119598166317, -40.208409298430595`]}, 2 -> {
                Complex[49.67718673301603, 14.195955395586383`], 
                Complex[71.78739616686877, -3.9614519886295856`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -8.534763061683554}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.63957177263898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.016364458249825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.71119598166317`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.208409298430595`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.67718673301603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.195955395586383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78739616686877`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.9614519886295856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 
             Association[1 -> {
                Complex[48.63957177263898, -16.016364458249825`], 
                Complex[72.71119598166317, -40.208409298430595`]}, 2 -> {
                Complex[49.67718673301603, 14.195955395586383`], 
                Complex[71.78739616686877, -3.9614519886295856`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -8.572083357951536}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.65298689323024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.09324711402706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.296561508588134`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.6737574329993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.279426178673182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 
             Association[1 -> {
                Complex[48.65298689323024, -16.09324711402706], 
                Complex[72.73469819909567, -40.296561508588134`]}, 2 -> {
                Complex[49.6737574329993, 14.279426178673182`], 
                Complex[71.78128532311126, -3.853935345418625]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -8.574405302143935}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.65298689323024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.09324711402706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.73469819909567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.296561508588134`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.6737574329993`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.279426178673182`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.78128532311126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.853935345418625`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 
             Association[1 -> {
                Complex[48.65298689323024, -16.09324711402706], 
                Complex[72.73469819909567, -40.296561508588134`]}, 2 -> {
                Complex[49.6737574329993, 14.279426178673182`], 
                Complex[71.78128532311126, -3.853935345418625]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -8.611962984510772}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.666223843506465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.670467660008306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.362192871226501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.666223843506465`, -16.169470489332475`], 
                Complex[72.75793792851876, -40.38396676731901]}, 2 -> {
                Complex[49.670467660008306`, 14.362192871226501`], 
                Complex[71.77540493979987, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -8.614234865091984}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.666223843506465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.169470489332475`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.75793792851876`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.38396676731901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.670467660008306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.362192871226501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.77540493979987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.7472457515262505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 
             Association[1 -> {
                Complex[48.666223843506465`, -16.169470489332475`], 
                Complex[72.75793792851876, -40.38396676731901]}, 2 -> {
                Complex[49.670467660008306`, 14.362192871226501`], 
                Complex[71.77540493979987, -3.7472457515262505`]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.8, -8.652027045607388}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.67928724206044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.24504648743809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.7809215257996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.47063852810008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66731304323485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.444267820361429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.641369140955806`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "A", 
             Association[1 -> {
                Complex[48.67928724206044, -16.24504648743809], 
                Complex[72.7809215257996, -40.47063852810008]}, 2 -> {
                Complex[49.66731304323485, 14.444267820361429`], 
                Complex[71.76974878182652, -3.641369140955806]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -8.654250283182282}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.67928724206044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.24504648743809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.7809215257996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.47063852810008`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66731304323485`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.444267820361429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76974878182652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.641369140955806`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "A", 
             Association[1 -> {
                Complex[48.67928724206044, -16.24504648743809], 
                Complex[72.7809215257996, -40.47063852810008]}, 2 -> {
                Complex[49.66731304323485, 14.444267820361429`], 
                Complex[71.76974878182652, -3.641369140955806]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{39.9, -8.692274148613343}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.692181529961914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80365511190739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66428938724529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "A", 
             Association[1 -> {
                Complex[48.692181529961914`, -16.31998667718374], 
                Complex[72.80365511190739, -40.556589868302694`]}, 2 -> {
                Complex[49.66428938724529, 14.525663032929627`], 
                Complex[71.76431084846256, -3.536291830717447]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -8.694450111893937}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.692181529961914`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.31998667718374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.80365511190739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.556589868302694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66428938724529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.525663032929627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.76431084846256`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.536291830717447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "A", 
             Association[1 -> {
                Complex[48.692181529961914`, -16.31998667718374], 
                Complex[72.80365511190739, -40.556589868302694`]}, 2 -> {
                Complex[49.66428938724529, 14.525663032929627`], 
                Complex[71.76431084846256, -3.536291830717447]}]}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0.5], 
          TagBox[
           TooltipBox[PointBox[{40., -8.73270292088352}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.70491097967126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.394302305698698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.641833503377605`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66139266308925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.75908536186752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.43200050653909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "A", 
             Association[1 -> {
                Complex[48.70491097967126, -16.394302305698698`], 
                Complex[72.82614458440335, -40.641833503377605`]}, 2 -> {
                Complex[49.66139266308925, 14.606390188337485`], 
                Complex[71.75908536186752, -3.43200050653909]}]}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{40., -8.734832928992494}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"48.70491097967126`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.394302305698698`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"72.82614458440335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.641833503377605`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"49.66139266308925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.606390188337485`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"71.75908536186752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.43200050653909`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "A", 
             Association[1 -> {
                Complex[48.70491097967126, -16.394302305698698`], 
                Complex[72.82614458440335, -40.641833503377605`]}, 2 -> {
                Complex[49.66139266308925, 14.606390188337485`], 
                Complex[71.75908536186752, -3.43200050653909]}]}, 
            "Tooltip"]& ]}}}, {{
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.114357784935323}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"142.43088738729756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12083732434029751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.91042443664614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23233632108243843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 
             Association[1 -> {
                Complex[142.43088738729756`, 0.12083732434029751`], 
                Complex[113.66233957629902`, -20.405968816918097`]}, 2 -> {
                Complex[184.91042443664614`, -0.23233632108243843`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.126649670910322}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"142.43088738729756`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12083732434029751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"113.66233957629902`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.405968816918097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.91042443664614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23233632108243843`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"154.38624653449173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.985063633891325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 
             Association[1 -> {
                Complex[142.43088738729756`, 0.12083732434029751`], 
                Complex[113.66233957629902`, -20.405968816918097`]}, 2 -> {
                Complex[184.91042443664614`, -0.23233632108243843`], 
                Complex[154.38624653449173`, -20.985063633891325`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.121997326616481}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.20317083740102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12356070149773071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40448191262516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.11415381173683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2370153809705939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 
             Association[1 -> {
                Complex[143.20317083740102`, 0.12356070149773071`], 
                Complex[114.42383835786643`, -20.40448191262516]}, 2 -> {
                Complex[184.11415381173683`, -0.2370153809705939], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.136666502328691}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.20317083740102`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.12356070149773071`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"114.42383835786643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40448191262516`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"184.11415381173683`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2370153809705939`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"153.59811008119402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.98816784504015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 
             Association[1 -> {
                Complex[143.20317083740102`, 0.12356070149773071`], 
                Complex[114.42383835786643`, -20.40448191262516]}, 2 -> {
                Complex[184.11415381173683`, -0.2370153809705939], 
                Complex[153.59811008119402`, -20.98816784504015]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.158111547504076}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.8418943485418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"183.45688521121167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24124640092127728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.94915336254542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "C", 
             Association[1 -> {
                Complex[143.8418943485418, 0.1262779516956982], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[183.45688521121167`, -0.24124640092127728`], 
                Complex[152.94915336254542`, -20.990786350067847`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.175243243601219}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"143.8418943485418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1262779516956982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.05163809511703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.403027171273084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"183.45688521121167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24124640092127728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.94915336254542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.990786350067847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.2, "C", 
             Association[1 -> {
                Complex[143.8418943485418, 0.1262779516956982], 
                Complex[115.05163809511703`, -20.403027171273084`]}, 2 -> {
                Complex[183.45688521121167`, -0.24124640092127728`], 
                Complex[152.94915336254542`, -20.990786350067847`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.212576468490167}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.403599085715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12903424492994017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.60228208527523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40155927983009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.87977924699527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2452608701483842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.38052772522323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.993153001298854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 
             Association[1 -> {
                Complex[144.403599085715, 0.12903424492994017`], 
                Complex[115.60228208527523`, -20.40155927983009]}, 2 -> {
                Complex[182.87977924699527`, -0.2452608701483842], 
                Complex[152.38052772522323`, -20.993153001298854`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.231657506863557}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.403599085715`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.12903424492994017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"115.60228208527523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40155927983009`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.87977924699527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2452608701483842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"152.38052772522323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.993153001298854`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 
             Association[1 -> {
                Complex[144.403599085715, 0.12903424492994017`], 
                Complex[115.60228208527523`, -20.40155927983009]}, 2 -> {
                Complex[182.87977924699527`, -0.2452608701483842], 
                Complex[152.38052772522323`, -20.993153001298854`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.4, -6.278141051052941}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.91401586419227`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1318524872647501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40005566427453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.3560651176949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24916606948640838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.8654584893039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99537613618962`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "C", 
             Association[1 -> {
                Complex[144.91401586419227`, 0.1318524872647501], 
                Complex[116.10150054551087`, -20.40005566427453]}, 2 -> {
                Complex[182.3560651176949, -0.24916606948640838`], 
                Complex[151.8654584893039, -20.99537613618962]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -6.296874519518189}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"144.91401586419227`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1318524872647501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.10150054551087`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.40005566427453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"182.3560651176949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24916606948640838`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.8654584893039`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.99537613618962`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.4, "C", 
             Association[1 -> {
                Complex[144.91401586419227`, 0.1318524872647501], 
                Complex[116.10150054551087`, -20.40005566427453]}, 2 -> {
                Complex[182.3560651176949, -0.24916606948640838`], 
                Complex[151.8654584893039, -20.99537613618962]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -6.340892671713454}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.38744700905215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13474786473651384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398501738168576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.8708660927008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.253023818602633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.38906785583268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.99751794736914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 
             Association[1 -> {
                Complex[145.38744700905215`, 0.13474786473651384`], 
                Complex[116.56359372447044`, -20.398501738168576`]}, 2 -> {
                Complex[181.8708660927008, -0.253023818602633], 
                Complex[151.38906785583268`, -20.99751794736914]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -6.353241987492898}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.38744700905215`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.13474786473651384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.56359372447044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.398501738168576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.8708660927008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.253023818602633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"151.38906785583268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.99751794736914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 
             Association[1 -> {
                Complex[145.38744700905215`, 0.13474786473651384`], 
                Complex[116.56359372447044`, -20.398501738168576`]}, 2 -> {
                Complex[181.8708660927008, -0.253023818602633], 
                Complex[151.38906785583268`, -20.99751794736914]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -6.37414978691581}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.8328296140851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614972086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.99749565640013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.396886329795848`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.41488879760732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 
             Association[1 -> {
                Complex[145.8328296140851, 0.13773233614972086`], 
                Complex[116.99749565640013`, -20.396886329795848`]}, 2 -> {
                Complex[181.41488879760732`, -0.25687501967431686`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -6.37183961496155}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"145.8328296140851`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.13773233614972086`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"116.99749565640013`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.396886329795848`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"181.41488879760732`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25687501967431686`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.9420631470024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.999619278633975`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 
             Association[1 -> {
                Complex[145.8328296140851, 0.13773233614972086`], 
                Complex[116.99749565640013`, -20.396886329795848`]}, 2 -> {
                Complex[181.41488879760732`, -0.25687501967431686`], 
                Complex[150.9420631470024, -20.999619278633975`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.7, -6.354302156906623}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.25620289167148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.4092417408274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.395199814614813`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.9818553690836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.260749635653941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "C", 
             Association[1 -> {
                Complex[146.25620289167148`, 0.14081646542056195`], 
                Complex[117.4092417408274, -20.395199814614813`]}, 2 -> {
                Complex[180.9818553690836, -0.260749635653941], 
                Complex[150.51816845485817`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -6.336832816063592}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.25620289167148`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14081646542056195`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.4092417408274`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.395199814614813`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.9818553690836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.260749635653941`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.51816845485817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.001709724866622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.7, "C", 
             Association[1 -> {
                Complex[146.25620289167148`, 0.14081646542056195`], 
                Complex[117.4092417408274, -20.395199814614813`]}, 2 -> {
                Complex[180.9818553690836, -0.260749635653941], 
                Complex[150.51816845485817`, -21.001709724866622`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -6.291383091657032}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.661886117449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173267872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39343319988049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.56727763237527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467147267101754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.1128985493347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 
             Association[1 -> {
                Complex[146.661886117449, 0.14401032173267872`], 
                Complex[117.80314680030489`, -20.39343319988049]}, 2 -> {
                Complex[180.56727763237527`, -0.26467147267101754`], 
                Complex[150.1128985493347, -21.00381247852693]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -6.267014497125072}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"146.661886117449`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14401032173267872`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"117.80314680030489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.39343319988049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.56727763237527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467147267101754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"150.1128985493347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.00381247852693`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 
             Association[1 -> {
                Complex[146.661886117449, 0.14401032173267872`], 
                Complex[117.80314680030489`, -20.39343319988049]}, 2 -> {
                Complex[180.56727763237527`, -0.26467147267101754`], 
                Complex[150.1128985493347, -21.00381247852693]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{16.9, -6.2134144151956585`}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.0531060212139`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14732399476906763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.1678042677887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2686607590279984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.005946943311322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "C", 
             Association[1 -> {
                Complex[147.0531060212139, 0.14732399476906763`], 
                Complex[118.18243252444688`, -20.391577604746043`]}, 2 -> {
                Complex[180.1678042677887, -0.2686607590279984], 
                Complex[149.72290589550488`, -21.005946943311322`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -6.188758501227003}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.0531060212139`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.14732399476906763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.18243252444688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.391577604746043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"180.1678042677887`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2686607590279984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.72290589550488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.005946943311322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {16.9, "C", 
             Association[1 -> {
                Complex[147.0531060212139, 0.14732399476906763`], 
                Complex[118.18243252444688`, -20.391577604746043`]}, 2 -> {
                Complex[180.1678042677887, -0.2686607590279984], 
                Complex[149.72290589550488`, -21.005946943311322`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17., -6.137815947748114}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.43235893759334`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15076793497771634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.5495896388172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38962392181051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.78084401215676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27273567401803595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "C", 
             Association[1 -> {
                Complex[147.43235893759334`, 0.15076793497771634`], 
                Complex[118.5495896388172, -20.38962392181051]}, 2 -> {
                Complex[179.78084401215676`, -0.27273567401803595`], 
                Complex[149.34560377406765`, -21.008130280727748`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17., -6.115466799269644}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.43235893759334`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.15076793497771634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.5495896388172`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.38962392181051`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.78084401215676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27273567401803595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"149.34560377406765`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.008130280727748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17., "C", 
             Association[1 -> {
                Complex[147.43235893759334`, 0.15076793497771634`], 
                Complex[118.5495896388172, -20.38962392181051]}, 2 -> {
                Complex[179.78084401215676`, -0.27273567401803595`], 
                Complex[149.34560377406765`, -21.008130280727748`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -6.070499893217296}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.80163324655834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1543532116698063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.4043342501828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2769133339514044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 
             Association[1 -> {
                Complex[147.80163324655834`, 0.1543532116698063], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[179.4043342501828, -0.2769133339514044], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -6.051056781273599}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"147.80163324655834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1543532116698063`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"118.90660034079308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38756256543311`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.4043342501828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2769133339514044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.97893483437798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01037840309273`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 
             Association[1 -> {
                Complex[147.80163324655834`, 0.1543532116698063], 
                Complex[118.90660034079308`, -20.38756256543311]}, 2 -> {
                Complex[179.4043342501828, -0.2769133339514044], 
                Complex[148.97893483437798`, -21.01037840309273]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.2, -6.0123267979536035`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.16255297815067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1580917352471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.0365916440714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2812104825190737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "C", 
             Association[1 -> {
                Complex[148.16255297815067`, 0.1580917352471046], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[179.0365916440714, -0.2812104825190737], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.995725431713007}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.16255297815067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1580917352471046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.25508188284306`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.385383259668895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"179.0365916440714`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2812104825190737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.62122171499408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.012706663233452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.2, "C", 
             Association[1 -> {
                Complex[148.16255297815067`, 0.1580917352471046], 
                Complex[119.25508188284306`, -20.385383259668895`]}, 2 -> {
                Complex[179.0365916440714, -0.2812104825190737], 
                Complex[148.62122171499408`, -21.012706663233452`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.962562716594519}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.51647442884564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16199646966552844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38307483942267`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.67621165990886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.27106658294744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01513037357346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 
             Association[1 -> {
                Complex[148.51647442884564`, 0.16199646966552844`], 
                Complex[119.59638315362788`, -20.38307483942267]}, 2 -> {
                Complex[178.67621165990886`, -0.2856440165404518], 
                Complex[148.27106658294744`, -21.01513037357346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.9485810642634}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.51647442884564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16199646966552844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.59638315362788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.38307483942267`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.67621165990886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2856440165404518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"148.27106658294744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01513037357346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 
             Association[1 -> {
                Complex[148.51647442884564`, 0.16199646966552844`], 
                Complex[119.59638315362788`, -20.38307483942267]}, 2 -> {
                Complex[178.67621165990886`, -0.2856440165404518], 
                Complex[148.27106658294744`, -21.01513037357346]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.920132536238727}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.8645535018631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16608165207978046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.380625047921345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.3219985600101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2902314223138406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "C", 
             Association[1 -> {
                Complex[148.8645535018631, 0.16608165207978046`], 
                Complex[119.93165197047352`, -20.380625047921345`]}, 2 -> {
                Complex[178.3219985600101, -0.2902314223138406], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.908552078508364}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"148.8645535018631`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16608165207978046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"119.93165197047352`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.380625047921345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"178.3219985600101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2902314223138406`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.92728115711094`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.01766523058927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.4, "C", 
             Association[1 -> {
                Complex[148.8645535018631, 0.16608165207978046`], 
                Complex[119.93165197047352`, -20.380625047921345`]}, 2 -> {
                Complex[178.3219985600101, -0.2902314223138406], 
                Complex[147.92728115711094`, -21.01766523058927]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.884008239814516}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.2077941344118`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1703630326001896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868977`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.97291507886953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2949911695233655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "C", 
             Association[1 -> {
                Complex[149.2077941344118, 0.1703630326001896], 
                Complex[120.26188344631822`, -20.378020317868977`]}, 2 -> {
                Complex[177.97291507886953`, -0.2949911695233655], 
                Complex[147.58883643153155`, -21.020327691813243`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.874657629197565}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.2077941344118`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1703630326001896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.26188344631822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.378020317868977`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.97291507886953`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2949911695233655`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.58883643153155`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.020327691813243`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.5, "C", 
             Association[1 -> {
                Complex[149.2077941344118, 0.1703630326001896], 
                Complex[120.26188344631822`, -20.378020317868977`]}, 2 -> {
                Complex[177.97291507886953`, -0.2949911695233655], 
                Complex[147.58883643153155`, -21.020327691813243`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.85330512543261}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.54708414211208`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1748581457911621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067412`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.62804519717992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2999430950469064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280479`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 
             Association[1 -> {
                Complex[149.54708414211208`, 0.1748581457911621], 
                Complex[120.58795576067412`, -20.37524552516941]}, 2 -> {
                Complex[177.62804519717992`, -0.2999430950469064], 
                Complex[147.25482551280479`, -21.023135337553143`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.846066786293519}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.54708414211208`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1748581457911621`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.58795576067412`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.37524552516941`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.62804519717992`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2999430950469064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"147.25482551280479`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.023135337553143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 
             Association[1 -> {
                Complex[149.54708414211208`, 0.1748581457911621], 
                Complex[120.58795576067412`, -20.37524552516941]}, 2 -> {
                Complex[177.62804519717992`, -0.2999430950469064], 
                Complex[147.25482551280479`, -21.023135337553143`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.827286406384365}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.88322249644975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17958662591578034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.28656583699845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.026107241897208`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "C", 
             Association[1 -> {
                Complex[149.88322249644975`, 0.17958662591578034`], 
                Complex[120.91065734905384`, -20.372283703951]}, 2 -> {
                Complex[177.28656583699845`, -0.3051088017421759], 
                Complex[146.9244353952348, -21.026107241897208`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.822092802521342}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"149.88322249644975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.17958662591578034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"120.91065734905384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.372283703951`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"177.28656583699845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3051088017421759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.9244353952348`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.026107241897208`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.7, "C", 
             Association[1 -> {
                Complex[149.88322249644975`, 0.17958662591578034`], 
                Complex[120.91065734905384`, -20.372283703951]}, 2 -> {
                Complex[177.28656583699845`, -0.3051088017421759], 
                Complex[146.9244353952348, -21.026107241897208`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.805342818073902}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.2169406723343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.94772473618167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02926437433764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 
             Association[1 -> {
                Complex[150.2169406723343, 0.18457057958645484`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[176.94772473618167`, -0.310512094378605], 
                Complex[146.59692493347418`, -21.02926437433764]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.8021709895616045`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.2169406723343`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.18457057958645484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.23070814584621`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.369115710228797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.94772473618167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.310512094378605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.59692493347418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.02926437433764`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 
             Association[1 -> {
                Complex[150.2169406723343, 0.18457057958645484`], 
                Complex[121.23070814584621`, -20.369115710228797`]}, 2 -> {
                Complex[176.94772473618167`, -0.310512094378605], 
                Complex[146.59692493347418`, -21.02926437433764]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.7869686179949245`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.54891985610047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18983503235951585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.6108226416958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3161794749411295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03263005304264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "C", 
             Association[1 -> {
                Complex[150.54891985610047`, 0.18983503235951585`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[176.6108226416958, -0.3161794749411295], 
                Complex[146.27160715472132`, -21.03263005304264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.785835575364968}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.54891985610047`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.18983503235951585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.54877666814315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.365719818976572`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.6108226416958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3161794749411295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"146.27160715472132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03263005304264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.9, "C", 
             Association[1 -> {
                Complex[150.54891985610047`, 0.18983503235951585`], 
                Complex[121.54877666814315`, -20.365719818976572`]}, 2 -> {
                Complex[176.6108226416958, -0.3161794749411295], 
                Complex[146.27160715472132`, -21.03263005304264]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.771740211644452}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.87980527230502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1954084700848582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.275198515501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 
             Association[1 -> {
                Complex[150.87980527230502`, 0.1954084700848582], 
                Complex[121.86549419514674`, -20.36207123551036]}, 2 -> {
                Complex[176.275198515501, -0.3221407220109508], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.772699809811426}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"150.87980527230502`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1954084700848582`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"121.86549419514674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.36207123551036`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"176.275198515501`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3221407220109508`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.94783460763009`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.03623047285221`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 
             Association[1 -> {
                Complex[150.87980527230502`, 0.1954084700848582], 
                Complex[121.86549419514674`, -20.36207123551036]}, 2 -> {
                Complex[176.275198515501, -0.3221407220109508], 
                Complex[145.94783460763009`, -21.03623047285221]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.759298641881812}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.21021854920286`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20132350187325002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.9402167996116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3284295838082578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 
             Association[1 -> {
                Complex[151.21021854920286`, 0.20132350187325002`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[175.9402167996116, -0.3284295838082578], 
                Complex[145.62498679915495`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.762439954214316}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.21021854920286`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20132350187325002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.18146695822207`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.358141496563693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.9402167996116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3284295838082578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.62498679915495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.04009533540118`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 
             Association[1 -> {
                Complex[151.21021854920286`, 0.20132350187325002`], 
                Complex[122.18146695822207`, -20.358141496563693`]}, 2 -> {
                Complex[175.9402167996116, -0.3284295838082578], 
                Complex[145.62498679915495`, -21.04009533540118]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.749335639994094}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.54076882836094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20761768000812997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.35389772868149`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.60525601100267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727987`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "C", 
             Association[1 -> {
                Complex[151.54076882836094`, 0.20761768000812997`], 
                Complex[122.49728704083137`, -20.35389772868149]}, 2 -> {
                Complex[175.60525601100267`, -0.33508462216302626`], 
                Complex[145.30245899607772`, -21.044258615727987`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.754782710497428}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.54076882836094`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20761768000812997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.49728704083137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.35389772868149`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.60525601100267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33508462216302626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"145.30245899607772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.044258615727987`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.2, "C", 
             Association[1 -> {
                Complex[151.54076882836094`, 0.20761768000812997`], 
                Complex[122.49728704083137`, -20.35389772868149]}, 2 -> {
                Complex[175.60525601100267`, -0.33508462216302626`], 
                Complex[145.30245899607772`, -21.044258615727987`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.741582565191632}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.87206319321126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21433452398635636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.26969807427406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.9796518070718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.048759510069537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 
             Association[1 -> {
                Complex[151.87206319321126`, 0.21433452398635636`], 
                Complex[122.81354255509225`, -20.34930172067202]}, 2 -> {
                Complex[175.26969807427406`, -0.3421502560032738], 
                Complex[144.9796518070718, -21.048759510069537`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.749495425057917}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"151.87206319321126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21433452398635636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"122.81354255509225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34930172067202`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"175.26969807427406`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3421502560032738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.9796518070718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.048759510069537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 
             Association[1 -> {
                Complex[151.87206319321126`, 0.21433452398635636`], 
                Complex[122.81354255509225`, -20.34930172067202]}, 2 -> {
                Complex[175.26969807427406`, -0.3421502560032738], 
                Complex[144.9796518070718, -21.048759510069537`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.7358015619333464`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.20471692148735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22152481262236687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.93291787440944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 
             Association[1 -> {
                Complex[152.20471692148735`, 0.22152481262236687`], 
                Complex[123.13082758939966`, -20.34430875145043]}, 2 -> {
                Complex[174.93291787440944`, -0.3496780693287902], 
                Complex[144.65596103805998`, -21.053643624569467`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.7463784507206315`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.20471692148735`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22152481262236687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.13082758939966`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.34430875145043`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.93291787440944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3496780693287902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.65596103805998`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.053643624569467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 
             Association[1 -> {
                Complex[152.20471692148735`, 0.22152481262236687`], 
                Complex[123.13082758939966`, -20.34430875145043]}, 2 -> {
                Complex[174.93291787440944`, -0.3496780693287902], 
                Complex[144.65596103805998`, -21.053643624569467`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.731778366313601}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.53936404559178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22924823209533307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.4497523973468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.59427253610252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412606`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 
             Association[1 -> {
                Complex[152.53936404559178`, 0.22924823209533307`], 
                Complex[123.4497523973468, -20.33886609255275]}, 2 -> {
                Complex[174.59427253610252`, -0.35772847232067345`], 
                Complex[144.33076734108204`, -21.058964486412606`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.745259164177222}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.53936404559178`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.22924823209533307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.4497523973468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.33886609255275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.59427253610252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35772847232067345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.33076734108204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.058964486412606`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 
             Association[1 -> {
                Complex[152.53936404559178`, 0.22924823209533307`], 
                Complex[123.4497523973468, -20.33886609255275]}, 2 -> {
                Complex[174.59427253610252`, -0.35772847232067345`], 
                Complex[144.33076734108204`, -21.058964486412606`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.729316301553785}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.8766687292074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790741`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.25308991417538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36637283877683763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.0034251594934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.064785490731843`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 
             Association[1 -> {
                Complex[152.8766687292074, 0.23757550254713042`], 
                Complex[123.77095431790741`, -20.332911072573204`]}, 2 -> {
                Complex[174.25308991417538`, -0.36637283877683763`], 
                Complex[144.0034251594934, -21.064785490731843`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.74598724929385}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"152.8766687292074`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.23757550254713042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"123.77095431790741`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.332911072573204`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"174.25308991417538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36637283877683763`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"144.0034251594934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.064785490731843`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 
             Association[1 -> {
                Complex[152.8766687292074, 0.23757550254713042`], 
                Complex[123.77095431790741`, -20.332911072573204`]}, 2 -> {
                Complex[174.25308991417538`, -0.36637283877683763`], 
                Complex[144.0034251594934, -21.064785490731843`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.728231090644309}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.2173380411423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24659115703995835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.90865570862832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37569629412710687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.071182443764766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "C", 
             Association[1 -> {
                Complex[153.2173380411423, 0.24659115703995835`], 
                Complex[124.09510998319796`, -20.32636854350558]}, 2 -> {
                Complex[173.90865570862832`, -0.37569629412710687`], 
                Complex[143.6732504076637, -21.071182443764766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.748430950488007}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.2173380411423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24659115703995835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.09510998319796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.32636854350558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.90865570862832`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.37569629412710687`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.6732504076637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.071182443764766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.7, "C", 
             Association[1 -> {
                Complex[153.2173380411423, 0.24659115703995835`], 
                Complex[124.09510998319796`, -20.32636854350558]}, 2 -> {
                Complex[173.90865570862832`, -0.37569629412710687`], 
                Complex[143.6732504076637, -21.071182443764766`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.728346175199108}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.5621368394489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.56019848705628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38580140506476973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.33950620148752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078246933699234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "C", 
             Association[1 -> {
                Complex[153.5621368394489, 0.2563972235666605], 
                Complex[124.42294949324784`, -20.319147517903783`]}, 2 -> {
                Complex[173.56019848705628`, -0.38580140506476973`], 
                Complex[143.33950620148752`, -21.078246933699234`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.7524740732408945`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.5621368394489`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2563972235666605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.42294949324784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.319147517903783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.56019848705628`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38580140506476973`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.33950620148752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078246933699234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.8, "C", 
             Association[1 -> {
                Complex[153.5621368394489, 0.2563972235666605], 
                Complex[124.42294949324784`, -20.319147517903783`]}, 2 -> {
                Complex[173.56019848705628`, -0.38580140506476973`], 
                Complex[143.33950620148752`, -21.078246933699234`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.729488263303441}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.9119056914435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31113663674728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.2068716855101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3968131395799549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "C", 
             Association[1 -> {
                Complex[153.9119056914435, 0.26711817863125764`], 
                Complex[124.7552734369329, -20.31113663674728]}, 2 -> {
                Complex[173.2068716855101, -0.3968131395799549], 
                Complex[143.00138575722923`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.758013563800565}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"153.9119056914435`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.26711817863125764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"124.7552734369329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.31113663674728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"173.2068716855101`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3968131395799549`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"143.00138575722923`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.086090869598895`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.9, "C", 
             Association[1 -> {
                Complex[153.9119056914435, 0.26711817863125764`], 
                Complex[124.7552734369329, -20.31113663674728]}, 2 -> {
                Complex[173.2068716855101, -0.3968131395799549], 
                Complex[143.00138575722923`, -21.086090869598895`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.731482835003474}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.26758308493513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27890772560985055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.302197956798476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.84773132990216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40888565081601425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.09485269983952`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 
             Association[1 -> {
                Complex[154.26758308493513`, 0.27890772560985055`], 
                Complex[125.09297394908012`, -20.302197956798476`]}, 2 -> {
                Complex[172.84773132990216`, -0.40888565081601425`], 
                Complex[142.6579912660793, -21.09485269983952]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.764957541139706}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.26758308493513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27890772560985055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.09297394908012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.302197956798476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.84773132990216`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40888565081601425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.6579912660793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.09485269983952`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 
             Association[1 -> {
                Complex[154.26758308493513`, 0.27890772560985055`], 
                Complex[125.09297394908012`, -20.302197956798476`]}, 2 -> {
                Complex[172.84773132990216`, -0.40888565081601425`], 
                Complex[142.6579912660793, -21.09485269983952]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.734149308293719}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.6302336943276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2919582479968343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.481707712234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4222117350213626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 
             Association[1 -> {
                Complex[154.6302336943276, 0.2919582479968343], 
                Complex[125.43706147399148`, -20.29215827088692]}, 2 -> {
                Complex[172.481707712234, -0.4222117350213626], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.7732236847141785`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"154.6302336943276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2919582479968343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.43706147399148`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.29215827088692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.481707712234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4222117350213626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"142.30830707209702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.104706096794665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 
             Association[1 -> {
                Complex[154.6302336943276, 0.2919582479968343], 
                Complex[125.43706147399148`, -20.29215827088692]}, 2 -> {
                Complex[172.481707712234, -0.4222117350213626], 
                Complex[142.30830707209702`, -21.104706096794665`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.737295501188732}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.00108525660056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30651427855723345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.78869965408623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.28079671874115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.10756846499456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475135913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.115872350288292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "C", 
             Association[1 -> {
                Complex[155.00108525660056`, 0.30651427855723345`], 
                Complex[125.78869965408623`, -20.28079671874115]}, 2 -> {
                Complex[172.10756846499456`, -0.43703630475135913`], 
                Complex[141.95116473317964`, -21.115872350288292`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.782737904257979}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.00108525660056`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.30651427855723345`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"125.78869965408623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.28079671874115`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"172.10756846499456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43703630475135913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.95116473317964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.115872350288292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.2, "C", 
             Association[1 -> {
                Complex[155.00108525660056`, 0.30651427855723345`], 
                Complex[125.78869965408623`, -20.28079671874115]}, 2 -> {
                Complex[172.10756846499456`, -0.43703630475135913`], 
                Complex[141.95116473317964`, -21.115872350288292`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.740710896528956}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.38157786657638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.72386922299577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4536760563999232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 
             Association[1 -> {
                Complex[155.38157786657638`, 0.32289216335652754`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[171.72386922299577`, -0.4536760563999232], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.793433234806306}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.38157786657638`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.32289216335652754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.14925194979097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.267826667058625`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.72386922299577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4536760563999232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.58519635758813`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.12863849123653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 
             Association[1 -> {
                Complex[155.38157786657638`, 0.32289216335652754`], 
                Complex[126.14925194979097`, -20.267826667058625`]}, 2 -> {
                Complex[171.72386922299577`, -0.4536760563999232], 
                Complex[141.58519635758813`, -21.12863849123653]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.744157986627902}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.773431537362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34150958252322494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.32888602568033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47254899400334877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "C", 
             Association[1 -> {
                Complex[155.773431537362, 0.34150958252322494`], 
                Complex[126.52034552601548`, -20.252868457449622`]}, 2 -> {
                Complex[171.32888602568033`, -0.47254899400334877`], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.805248912881079}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"155.773431537362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34150958252322494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.52034552601548`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.252868457449622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"171.32888602568033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47254899400334877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"141.2087706796062`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.143384546932786`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.4, "C", 
             Association[1 -> {
                Complex[155.773431537362, 0.34150958252322494`], 
                Complex[126.52034552601548`, -20.252868457449622`]}, 2 -> {
                Complex[171.32888602568033`, -0.47254899400334877`], 
                Complex[141.2087706796062, -21.143384546932786`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.747360570105322}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.1787412727927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3629313245006883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.92052021219553`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614487433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 
             Association[1 -> {
                Complex[156.1787412727927, 0.3629313245006883], 
                Complex[126.90396116486053`, -20.235407072598086`]}, 2 -> {
                Complex[170.92052021219553`, -0.49422020614487433`], 
                Complex[140.81990311379664`, -21.160625877708604`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.818129599408989}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.1787412727927`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3629313245006883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"126.90396116486053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.235407072598086`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.92052021219553`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49422020614487433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.81990311379664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.160625877708604`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 
             Association[1 -> {
                Complex[156.1787412727927, 0.3629313245006883], 
                Complex[126.90396116486053`, -20.235407072598086`]}, 2 -> {
                Complex[170.92052021219553`, -0.49422020614487433`], 
                Complex[140.81990311379664`, -21.160625877708604`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.749987147956513}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.60011476215269`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.49616069823637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.18108148048887`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 
             Association[1 -> {
                Complex[156.60011476215269`, 0.3879430012901607], 
                Complex[127.30256352822093`, -20.214723835180777`]}, 2 -> {
                Complex[170.49616069823637`, -0.5194755835198454], 
                Complex[140.41612546346298`, -21.18108148048887]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.832024722278886}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"156.60011476215269`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3879430012901607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.30256352822093`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.214723835180777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.49616069823637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5194755835198454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"140.41612546346298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.18108148048887`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 
             Association[1 -> {
                Complex[156.60011476215269`, 0.3879430012901607], 
                Complex[127.30256352822093`, -20.214723835180777`]}, 2 -> {
                Complex[170.49616069823637`, -0.5194755835198454], 
                Complex[140.41612546346298`, -21.18108148048887]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.751626230618314}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.0408782710949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4176752143879963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.71929603487078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.189781145086567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.05247806013978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5494459869149929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.9942910181267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.205789253752098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "C", 
             Association[1 -> {
                Complex[157.0408782710949, 0.4176752143879963], 
                Complex[127.71929603487078`, -20.189781145086567`]}, 2 -> {
                Complex[170.05247806013978`, -0.5494459869149929], 
                Complex[139.9942910181267, -21.205789253752098`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.846887917070056}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.0408782710949`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4176752143879963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"127.71929603487078`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.189781145086567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"170.05247806013978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5494459869149929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.9942910181267`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.205789253752098`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.7, "C", 
             Association[1 -> {
                Complex[157.0408782710949, 0.4176752143879963], 
                Complex[127.71929603487078`, -20.189781145086567`]}, 2 -> {
                Complex[170.05247806013978`, -0.5494459869149929], 
                Complex[139.9942910181267, -21.205789253752098`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.751747837789617}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.5053956369925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45382432603574024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.5851055175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5858280202580739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2363113344938`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 
             Association[1 -> {
                Complex[157.5053956369925, 0.45382432603574024`], 
                Complex[128.15828301502822`, -20.159017144377493`]}, 2 -> {
                Complex[169.5851055175, -0.5858280202580739], 
                Complex[139.55027237651973`, -21.2363113344938]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.862676548824924}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.5053956369925`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45382432603574024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.15828301502822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.159017144377493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.5851055175`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5858280202580739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.55027237651973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.2363113344938`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 
             Association[1 -> {
                Complex[157.5053956369925, 0.45382432603574024`], 
                Complex[128.15828301502822`, -20.159017144377493`]}, 2 -> {
                Complex[169.5851055175, -0.5858280202580739], 
                Complex[139.55027237651973`, -21.2363113344938]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.749640598449513}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.9995820310236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829306903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.08812515159096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6313034612843315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "C", 
             Association[1 -> {
                Complex[157.9995820310236, 0.49907188829306903`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[169.08812515159096`, -0.6313034612843315], 
                Complex[139.07847426814035`, -21.27512497578065]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.879351301115521}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"157.9995820310236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.49907188829306903`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"128.62511686893438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.11995484144138`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"169.08812515159096`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6313034612843315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"139.07847426814035`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.27512497578065`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {19.9, "C", 
             Association[1 -> {
                Complex[157.9995820310236, 0.49907188829306903`], 
                Complex[128.62511686893438`, -20.11995484144138]}, 2 -> {
                Complex[169.08812515159096`, -0.6313034612843315], 
                Complex[139.07847426814035`, -21.27512497578065]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20., -5.744304810257932}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"158.53176398183555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.1276748901026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"168.55320786440365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.5710167123656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32643079618197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "C", 
             Association[1 -> {
                Complex[158.53176398183555`, 0.5579501377609449], 
                Complex[129.1276748901026, -20.068393863077308`]}, 2 -> {
                Complex[168.55320786440365`, -0.6904047576732164], 
                Complex[138.5710167123656, -21.32643079618197]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.896875821293352}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"158.53176398183555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5579501377609449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.1276748901026`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.068393863077308`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"168.55320786440365`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6904047576732164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.5710167123656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.32643079618197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20., "C", 
             Association[1 -> {
                Complex[158.53176398183555`, 0.5579501377609449], 
                Complex[129.1276748901026, -20.068393863077308`]}, 2 -> {
                Complex[168.55320786440365`, -0.6904047576732164], 
                Complex[138.5710167123656, -21.32643079618197]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.7342697540382295`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.11415349895574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041312677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.6775233759758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.99655438623824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.96813923983427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368576926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.0163308920829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.39800884938101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "C", 
             Association[1 -> {
                Complex[159.11415349895574`, 0.6388251041312677], 
                Complex[129.6775233759758, -19.99655438623824]}, 2 -> {
                Complex[167.96813923983427`, -0.7714981368576926], 
                Complex[138.0163308920829, -21.39800884938101]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.91521641289314}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.11415349895574`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6388251041312677`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"129.6775233759758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.99655438623824`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.96813923983427`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7714981368576926`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"138.0163308920829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.39800884938101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.1, "C", 
             Association[1 -> {
                Complex[159.11415349895574`, 0.6388251041312677], 
                Complex[129.6775233759758, -19.99655438623824]}, 2 -> {
                Complex[167.96813923983427`, -0.7714981368576926], 
                Complex[138.0163308920829, -21.39800884938101]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.717336548406303}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.76521705885392`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.759082853797409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.88821086922835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.3144505438764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8919698507580937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.3968867364131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.506084894187325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 
             Association[1 -> {
                Complex[159.76521705885392`, 0.759082853797409], 
                Complex[130.2921900311733, -19.88821086922835]}, 2 -> {
                Complex[167.3144505438764, -0.8919698507580937], 
                Complex[137.3968867364131, -21.506084894187325`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.934341767809596}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"159.76521705885392`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.759082853797409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.2921900311733`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.88821086922835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"167.3144505438764`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8919698507580937`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"137.3968867364131`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.506084894187325`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 
             Association[1 -> {
                Complex[159.76521705885392`, 0.759082853797409], 
                Complex[130.2921900311733, -19.88821086922835]}, 2 -> {
                Complex[167.3144505438764, -0.8919698507580937], 
                Complex[137.3968867364131, -21.506084894187325`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.690897681300082}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"160.51100280221908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9608435417074076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.70389984169742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"166.5660915150384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939402286417192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291288`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.69012260562795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 
             Association[1 -> {
                Complex[160.51100280221908`, 0.9608435417074076], 
                Complex[130.99653808272222`, -19.70389984169742]}, 2 -> {
                Complex[166.5660915150384, -1.0939402286417192`], 
                Complex[136.68781879291288`, -21.69012260562795]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.954222732180781}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"160.51100280221908`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.9608435417074076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"130.99653808272222`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.70389984169742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"166.5660915150384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0939402286417192`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"136.68781879291288`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.69012260562795`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 
             Association[1 -> {
                Complex[160.51100280221908`, 0.9608435417074076], 
                Complex[130.99653808272222`, -19.70389984169742]}, 2 -> {
                Complex[166.5660915150384, -1.0939402286417192`], 
                Complex[136.68781879291288`, -21.69012260562795]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.66049064780535}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"161.35610930103817`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.33740874464973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"165.71846158622145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317955`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"135.88391552140592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "C", 
             Association[1 -> {
                Complex[161.35610930103817`, 1.3569051651311863`], 
                Complex[131.7957769749429, -19.33740874464973]}, 2 -> {
                Complex[165.71846158622145`, -1.4902074317955], 
                Complex[135.88391552140592`, -22.056334735916565`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.974832100965992}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"161.35610930103817`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"1.3569051651311863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"131.7957769749429`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.33740874464973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"165.71846158622145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.4902074317955`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"135.88391552140592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.056334735916565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.4, "C", 
             Association[1 -> {
                Complex[161.35610930103817`, 1.3569051651311863`], 
                Complex[131.7957769749429, -19.33740874464973]}, 2 -> {
                Complex[165.71846158622145`, -1.4902074317955], 
                Complex[135.88391552140592`, -22.056334735916565`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.672978023074976}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.09763876574996`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0881973270436873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.4998425166415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.6544084566896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.974456667634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2217012177173117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.73905058908342`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "C", 
             Association[1 -> {
                Complex[162.09763876574996`, 2.0881973270436873`], 
                Complex[132.4998425166415, -18.6544084566896]}, 2 -> {
                Complex[164.974456667634, -2.2217012177173117`], 
                Complex[135.17523913663766`, -22.73905058908342]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.996144437057064}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.09763876574996`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.0881973270436873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.4998425166415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.6544084566896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.974456667634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2217012177173117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"135.17523913663766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.73905058908342`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.5, "C", 
             Association[1 -> {
                Complex[162.09763876574996`, 2.0881973270436873`], 
                Complex[132.4998425166415, -18.6544084566896]}, 2 -> {
                Complex[164.974456667634, -2.2217012177173117`], 
                Complex[135.17523913663766`, -22.73905058908342]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -5.855308484273274}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.49679557516603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.87967075293174`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.57287060790918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532399953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 
             Association[1 -> {
                Complex[162.49679557516603`, 2.9142396485109336`], 
                Complex[132.88189718832854`, -17.87967075293174]}, 2 -> {
                Complex[164.57287060790918`, -3.0479413532399953`], 
                Complex[134.78862529189124`, -23.513498562864434`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -6.018135911451895}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.49679557516603`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"2.9142396485109336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"132.88189718832854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.87967075293174`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.57287060790918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.0479413532399953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.78862529189124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.513498562864434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 
             Association[1 -> {
                Complex[162.49679557516603`, 2.9142396485109336`], 
                Complex[132.88189718832854`, -17.87967075293174]}, 2 -> {
                Complex[164.57287060790918`, -3.0479413532399953`], 
                Complex[134.78862529189124`, -23.513498562864434`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -5.907990791063674}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.69815823018737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.07664557448564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.20679401345527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.3691232322966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.76466640407678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763844034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.18608044096362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 
             Association[1 -> {
                Complex[162.69815823018737`, 3.6307705575763123`], 
                Complex[133.07664557448564`, -17.20679401345527]}, 2 -> {
                Complex[164.3691232322966, -3.76466640407678], 
                Complex[134.58936763844034`, -24.18608044096362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -6.040784161578748}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.69815823018737`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"3.6307705575763123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.07664557448564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.20679401345527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.3691232322966`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.76466640407678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.58936763844034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.18608044096362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 
             Association[1 -> {
                Complex[162.69815823018737`, 3.6307705575763123`], 
                Complex[133.07664557448564`, -17.20679401345527]}, 2 -> {
                Complex[164.3691232322966, -3.76466640407678], 
                Complex[134.58936763844034`, -24.18608044096362]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -5.953185923540125}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.81702682614014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.244103960587594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.192822735254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.630699080753924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.24791286298796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.46872944634774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.76187553625734`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 
             Association[1 -> {
                Complex[162.81702682614014`, 4.244103960587594], 
                Complex[133.192822735254, -16.630699080753924`]}, 2 -> {
                Complex[164.24791286298796`, -4.378190406750068], 
                Complex[134.46872944634774`, -24.76187553625734]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -6.064068165324476}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.81702682614014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.244103960587594`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.192822735254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.630699080753924`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.24791286298796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.378190406750068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.46872944634774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"24.76187553625734`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 
             Association[1 -> {
                Complex[162.81702682614014`, 4.244103960587594], 
                Complex[133.192822735254, -16.630699080753924`]}, 2 -> {
                Complex[164.24791286298796`, -4.378190406750068], 
                Complex[134.46872944634774`, -24.76187553625734]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{20.9, -5.993264264869571}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.89623202590275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.166407339344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.916047187939833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "C", 
             Association[1 -> {
                Complex[162.89623202590275`, 4.781773561001189], 
                Complex[133.27102086156964`, -16.125747324937514`]}, 2 -> {
                Complex[164.166407339344, -4.916047187939833], 
                Complex[134.38611694252143`, -25.266522626186124`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.087968128694962}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.89623202590275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"4.781773561001189`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.27102086156964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.125747324937514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.166407339344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.916047187939833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.38611694252143`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"25.266522626186124`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {20.9, "C", 
             Association[1 -> {
                Complex[162.89623202590275`, 4.781773561001189], 
                Complex[133.27102086156964`, -16.125747324937514`]}, 2 -> {
                Complex[164.166407339344, -4.916047187939833], 
                Complex[134.38611694252143`, -25.266522626186124`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21., -6.030121389101348}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.9533692895785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.26317421199133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.673778470422995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.10700978216263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.397631717588651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.718182126604795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "C", 
             Association[1 -> {
                Complex[162.9533692895785, 5.26317421199133], 
                Complex[133.3279803002992, -15.673778470422995`]}, 2 -> {
                Complex[164.10700978216263`, -5.397631717588651], 
                Complex[134.3247882793696, -25.718182126604795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21., -6.112465385351349}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.9533692895785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"5.26317421199133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3279803002992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.673778470422995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.10700978216263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.397631717588651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.3247882793696`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"25.718182126604795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21., "C", 
             Association[1 -> {
                Complex[162.9533692895785, 5.26317421199133], 
                Complex[133.3279803002992, -15.673778470422995`]}, 2 -> {
                Complex[164.10700978216263`, -5.397631717588651], 
                Complex[134.3247882793696, -25.718182126604795`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.0649343266503095`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.99687585597522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.26276580186694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.06128160668933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.83575911268632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343943`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 
             Association[1 -> {
                Complex[162.99687585597522`, 5.701120919783133], 
                Complex[133.3717561373341, -15.26276580186694]}, 2 -> {
                Complex[164.06128160668933`, -5.83575911268632], 
                Complex[134.27668694605623`, -26.128880886343943`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.137542306525513}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"162.99687585597522`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"5.701120919783133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3717561373341`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.26276580186694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.06128160668933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.83575911268632`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.27668694605623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.128880886343943`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 
             Association[1 -> {
                Complex[162.99687585597522`, 5.701120919783133], 
                Complex[133.3717561373341, -15.26276580186694]}, 2 -> {
                Complex[164.06128160668933`, -5.83575911268632], 
                Complex[134.27668694605623`, -26.128880886343943`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.098436751408497}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.03131031496125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4067147758406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.884495531077516`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.02466294522884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.239169639445748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.2374451850879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.506832820748922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "C", 
             Association[1 -> {
                Complex[163.03131031496125`, 6.104353845416841], 
                Complex[133.4067147758406, -14.884495531077516`]}, 2 -> {
                Complex[164.02466294522884`, -6.239169639445748], 
                Complex[134.2374451850879, -26.506832820748922`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.163182220034956}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.03131031496125`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.104353845416841`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4067147758406`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.884495531077516`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"164.02466294522884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.239169639445748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.2374451850879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"26.506832820748922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.2, "C", 
             Association[1 -> {
                Complex[163.03131031496125`, 6.104353845416841], 
                Complex[133.4067147758406, -14.884495531077516`]}, 2 -> {
                Complex[164.02466294522884`, -6.239169639445748], 
                Complex[134.2374451850879, -26.506832820748922`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.1311024512690615`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.05936393484134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43544220027496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.533126521950006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.99446131516729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "C", 
             Association[1 -> {
                Complex[163.05936393484134`, 6.479082403584161], 
                Complex[133.43544220027496`, -14.533126521950006`]}, 2 -> {
                Complex[163.99446131516729`, -6.614072812516706], 
                Complex[134.20447572357537`, -26.857879187158492`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.189369337299164}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.05936393484134`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"6.479082403584161`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43544220027496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.533126521950006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.99446131516729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.614072812516706`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.20447572357537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"26.857879187158492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.3, "C", 
             Association[1 -> {
                Complex[163.05936393484134`, 6.479082403584161], 
                Complex[133.43544220027496`, -14.533126521950006`]}, 2 -> {
                Complex[163.99446131516729`, -6.614072812516706], 
                Complex[134.20447572357537`, -26.857879187158492`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.163248636585942}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.0827360388856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.96897623823008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.96504547952883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.18632866833261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "C", 
             Association[1 -> {
                Complex[163.0827360388856, 6.829883346826038], 
                Complex[133.45957631720722`, -14.204350207418514`]}, 2 -> {
                Complex[163.96897623823008`, -6.96504547952883], 
                Complex[134.17613942808237`, -27.18632866833261]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.216088687412086}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.0827360388856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"6.829883346826038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45957631720722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.204350207418514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.96897623823008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.96504547952883`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.17613942808237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.18632866833261`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.4, "C", 
             Association[1 -> {
                Complex[163.0827360388856, 6.829883346826038], 
                Complex[133.45957631720722`, -14.204350207418514`]}, 2 -> {
                Complex[163.96897623823008`, -6.96504547952883], 
                Complex[134.17613942808237`, -27.18632866833261]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.195094426568527}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.10255730313813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.1602366935056825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.8948884451038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.94707593880682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1513419963516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49545951715293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.10255730313813`, 7.1602366935056825`], 
                Complex[133.48021025962274`, -13.8948884451038]}, 2 -> {
                Complex[163.94707593880682`, -7.295567749380924], 
                Complex[134.1513419963516, -27.49545951715293]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.243326057454311}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.10255730313813`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.1602366935056825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48021025962274`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.8948884451038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.94707593880682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.295567749380924`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.1513419963516`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"27.49545951715293`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.10255730313813`, 7.1602366935056825`], 
                Complex[133.48021025962274`, -13.8948884451038]}, 2 -> {
                Complex[163.94707593880682`, -7.295567749380924], 
                Complex[134.1513419963516, -27.49545951715293]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.2267951435471645`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.11961217061838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.9279749261981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.12932163548447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.78783159598447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.11961217061838`, 7.472858386883269], 
                Complex[133.49810470509067`, -13.602181478273478`]}, 2 -> {
                Complex[163.9279749261981, -7.60835565160759], 
                Complex[134.12932163548447`, -27.78783159598447]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.271067938337316}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.11961217061838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.472858386883269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49810470509067`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.602181478273478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.9279749261981`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"7.60835565160759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.12932163548447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"27.78783159598447`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.11961217061838`, 7.472858386883269], 
                Complex[133.49810470509067`, -13.602181478273478`]}, 2 -> {
                Complex[163.9279749261981, -7.60835565160759], 
                Complex[134.12932163548447`, -27.78783159598447]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.258463219506627}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.13446375540627`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.32418640258124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.91110908726415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "C", 
             Association[1 -> {
                Complex[163.13446375540627`, 7.769914966301738], 
                Complex[133.51380733250912`, -13.32418640258124]}, 2 -> {
                Complex[163.91110908726415`, -7.905575807831239], 
                Complex[134.10952960183627`, -28.065487910230864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.299301475565323}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.13446375540627`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"7.769914966301738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51380733250912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.32418640258124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.91110908726415`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.905575807831239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.10952960183627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.065487910230864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.7, "C", 
             Association[1 -> {
                Complex[163.13446375540627`, 7.769914966301738], 
                Complex[133.51380733250912`, -13.32418640258124]}, 2 -> {
                Complex[163.91110908726415`, -7.905575807831239], 
                Complex[134.10952960183627`, -28.065487910230864`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -6.290181413943055}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1475279007755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.053167049211595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8960616252759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.188988914036532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.33008939886362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.1475279007755, 8.053167049211595], 
                Complex[133.52772377923588`, -13.059242375813348`]}, 2 -> {
                Complex[163.8960616252759, -8.188988914036532], 
                Complex[134.09155924078232`, -28.33008939886362]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -6.328014424378548}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1475279007755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.053167049211595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52772377923588`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.059242375813348`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8960616252759`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.188988914036532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.09155924078232`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.33008939886362`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.1475279007755, 8.053167049211595], 
                Complex[133.52772377923588`, -13.059242375813348`]}, 2 -> {
                Complex[163.8960616252759, -8.188988914036532], 
                Complex[134.09155924078232`, -28.33008939886362]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -6.32201144709988}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.15911911401952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.3240682437392`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8825171223138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.460048653363897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0751018939077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.583007906385838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.15911911401952`, 8.3240682437392], 
                Complex[133.54016173104085`, -12.805977646175146`]}, 2 -> {
                Complex[163.8825171223138, -8.460048653363897], 
                Complex[134.0751018939077, -28.583007906385838`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -6.357195108810106}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.15911911401952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.3240682437392`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.54016173104085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.805977646175146`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8825171223138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.460048653363897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.0751018939077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"28.583007906385838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.15911911401952`, 8.3240682437392], 
                Complex[133.54016173104085`, -12.805977646175146`]}, 2 -> {
                Complex[163.8825171223138, -8.460048653363897], 
                Complex[134.0751018939077, -28.583007906385838`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -6.353999802674252}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1694801602913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.583835207504208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.56324367042308`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.87023194285814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.1694801602913, 8.583835207504208], 
                Complex[133.55135937730103`, -12.56324367042308]}, 2 -> {
                Complex[163.87023194285814`, -8.719971755138737], 
                Complex[134.05991844116488`, -28.82539206493508]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -6.38683238424585}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.1694801602913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"8.583835207504208`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55135937730103`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.56324367042308`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.87023194285814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.719971755138737`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.05991844116488`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"28.82539206493508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.1694801602913, 8.583835207504208], 
                Complex[133.55135937730103`, -12.56324367042308]}, 2 -> {
                Complex[163.87023194285814`, -8.719971755138737], 
                Complex[134.05991844116488`, -28.82539206493508]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -6.38618172735301}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.17880175664644`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.833498461149421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.85901453737054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.17880175664644`, 8.833498461149421], 
                Complex[133.56150438018219`, -12.330067310220034`]}, 2 -> {
                Complex[163.85901453737054`, -8.96978880859587], 
                Complex[134.04582032924358`, -29.058215098144608`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -6.416915603126845}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.17880175664644`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"8.833498461149421`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56150438018219`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.330067310220034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.85901453737054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.96978880859587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.04582032924358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.058215098144608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.17880175664644`, 8.833498461149421], 
                Complex[133.56150438018219`, -12.330067310220034`]}, 2 -> {
                Complex[163.85901453737054`, -8.96978880859587], 
                Complex[134.04582032924358`, -29.058215098144608`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.2, -6.418584049113368}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.18723604978868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.073940020992653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.10561541560388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.84871196234698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.03265656530453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.28231023787636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "C", 
             Association[1 -> {
                Complex[163.18723604978868`, 9.073940020992653], 
                Complex[133.57074687863496`, -12.10561541560388]}, 2 -> {
                Complex[163.84871196234698`, -9.210381895712343], 
                Complex[134.03265656530453`, -29.28231023787636]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -6.447434583477038}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.18723604978868`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.073940020992653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57074687863496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.10561541560388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.84871196234698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.210381895712343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.03265656530453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.28231023787636`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.2, "C", 
             Association[1 -> {
                Complex[163.18723604978868`, 9.073940020992653], 
                Complex[133.57074687863496`, -12.10561541560388]}, 2 -> {
                Complex[163.84871196234698`, -9.210381895712343], 
                Complex[134.03265656530453`, -29.28231023787636]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.3, -6.451227202234959}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.19490606734587`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8392004270005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.44251298180812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.020304580273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "C", 
             Association[1 -> {
                Complex[163.19490606734587`, 9.305921789460667], 
                Complex[133.57920862299497`, -11.889168097503115`]}, 2 -> {
                Complex[163.8392004270005, -9.44251298180812], 
                Complex[134.020304580273, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -6.478379579975777}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.19490606734587`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.305921789460667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57920862299497`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.889168097503115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8392004270005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.44251298180812`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.020304580273`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"29.498397451891556`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.3, "C", 
             Association[1 -> {
                Complex[163.19490606734587`, 9.305921789460667], 
                Complex[133.57920862299497`, -11.889168097503115`]}, 2 -> {
                Complex[163.8392004270005, -9.44251298180812], 
                Complex[134.020304580273, -29.498397451891556`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.4, -6.484126707625976}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20191248924124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.83037851999364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "C", 
             Association[1 -> {
                Complex[163.20191248924124`, 9.530107327827569], 
                Complex[133.58698953054267`, -11.680098224034463`]}, 2 -> {
                Complex[163.83037851999364`, -9.666845688440565], 
                Complex[134.00866367132147`, -29.707103947727525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -6.509741257327273}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20191248924124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.530107327827569`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58698953054267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.680098224034463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.83037851999364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.666845688440565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"134.00866367132147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.707103947727525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.4, "C", 
             Association[1 -> {
                Complex[163.20191248924124`, 9.530107327827569], 
                Complex[133.58698953054267`, -11.680098224034463`]}, 2 -> {
                Complex[163.83037851999364`, -9.666845688440565], 
                Complex[134.00866367132147`, -29.707103947727525`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -6.517294271680355}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20833859211223`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956242`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8221622632574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.883962238175444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.908980134406136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.20833859211223`, 9.747078800841354], 
                Complex[133.59417248038324`, -11.477855458956242`]}, 2 -> {
                Complex[163.8221622632574, -9.883962238175444], 
                Complex[133.99765020516938`, -29.908980134406136`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -6.541510665707011}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.20833859211223`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"9.747078800841354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59417248038324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.477855458956242`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.8221622632574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"9.883962238175444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.99765020516938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"29.908980134406136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.20833859211223`, 9.747078800841354], 
                Complex[133.59417248038324`, -11.477855458956242`]}, 2 -> {
                Complex[163.8221622632574, -9.883962238175444], 
                Complex[133.99765020516938`, -29.908980134406136`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.550738613188678}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2142539214259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.957350339052207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.81448143823496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.09437681705006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.104512213028926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.2142539214259, 9.957350339052207], 
                Complex[133.60082688045318`, -11.281953671224448`]}, 2 -> {
                Complex[163.81448143823496`, -10.09437681705006], 
                Complex[133.9871940493811, -30.104512213028926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.573679218089691}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2142539214259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"9.957350339052207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60082688045318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.281953671224448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.81448143823496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.09437681705006`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9871940493811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.104512213028926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.2142539214259, 9.957350339052207], 
                Complex[133.60082688045318`, -11.281953671224448`]}, 2 -> {
                Complex[163.81448143823496`, -10.09437681705006], 
                Complex[133.9871940493811, -30.104512213028926`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.58446609325735}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.21971706050041`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6070113617539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.091960884780269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80727681533168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.298546238374051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.97723587655176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.294132227130046`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "C", 
             Association[1 -> {
                Complex[163.21971706050041`, 10.161378702488394`], 
                Complex[133.6070113617539, -11.091960884780269`]}, 2 -> {
                Complex[163.80727681533168`, -10.298546238374051`], 
                Complex[133.97723587655176`, -30.294132227130046`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.606238669284663}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.21971706050041`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.161378702488394`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6070113617539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.091960884780269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80727681533168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.298546238374051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.97723587655176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.294132227130046`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.7, "C", 
             Association[1 -> {
                Complex[163.21971706050041`, 10.161378702488394`], 
                Complex[133.6070113617539, -11.091960884780269`]}, 2 -> {
                Complex[163.80727681533168`, -10.298546238374051`], 
                Complex[133.97723587655176`, -30.294132227130046`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.618481200456312}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2247777474091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.359571883156995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.907491168998273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80049803558532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.49687854534779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9677250996958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.2247777474091, 10.359571883156995`], 
                Complex[133.61277584148843`, -10.907491168998273`]}, 2 -> {
                Complex[163.80049803558532`, -10.49687854534779], 
                Complex[133.9677250996958, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.639181096523442}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2247777474091`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"10.359571883156995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61277584148843`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.907491168998273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.80049803558532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.49687854534779`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9677250996958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.478226172360408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.2247777474091, 10.359571883156995`], 
                Complex[133.61277584148843`, -10.907491168998273`]}, 2 -> {
                Complex[163.80049803558532`, -10.49687854534779], 
                Complex[133.9677250996958, -30.478226172360408`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.652786928171153}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.22947851363165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.552296113405845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7941019706839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.689740019533176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878894`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "C", 
             Association[1 -> {
                Complex[163.22947851363165`, 10.552296113405845`], 
                Complex[133.6181631227232, -10.728198030417936`]}, 2 -> {
                Complex[163.7941019706839, -10.689740019533176`], 
                Complex[133.9586182712075, -30.657140604878894`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.672498881460493}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.22947851363165`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.552296113405845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6181631227232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.728198030417936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7941019706839`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.689740019533176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9586182712075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"30.657140604878894`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.9, "C", 
             Association[1 -> {
                Complex[163.22947851363165`, 10.552296113405845`], 
                Complex[133.6181631227232, -10.728198030417936`]}, 2 -> {
                Complex[163.7941019706839, -10.689740019533176`], 
                Complex[133.9586182712075, -30.657140604878894`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.687385070730719}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23385596697975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.55376897922101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7880514387958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.23385596697975`, 10.739881627157578`], 
                Complex[133.62321014884253`, -10.55376897922101]}, 2 -> {
                Complex[163.7880514387958, -10.877460942190032`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.706184693462844}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23385596697975`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.739881627157578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62321014884253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.55376897922101`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7880514387958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.877460942190032`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94987782711803`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"30.8311880749906`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.23385596697975`, 10.739881627157578`], 
                Complex[133.62321014884253`, -10.55376897922101]}, 2 -> {
                Complex[163.7880514387958, -10.877460942190032`], 
                Complex[133.94987782711803`, -30.8311880749906]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.722276457663826}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23794180650475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62794899755536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.383921024629705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.78231418849845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.000651631856574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.23794180650475`, 10.922627435195468`], 
                Complex[133.62794899755536`, -10.383921024629705`]}, 2 -> {
                Complex[163.78231418849845`, -11.060340369657364`], 
                Complex[133.94147109188316`, -31.000651631856574`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.740231474076883}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.23794180650475`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"10.922627435195468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62794899755536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.383921024629705`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.78231418849845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.060340369657364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.94147109188316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.000651631856574`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.23794180650475`, 10.922627435195468`], 
                Complex[133.62794899755536`, -10.383921024629705`]}, 2 -> {
                Complex[163.78231418849845`, -11.060340369657364`], 
                Complex[133.94147109188316`, -31.000651631856574`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.757461140357251}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2417636330736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.100805313420308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63240767607033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.218396911961511`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.776862087113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.238650121699811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.16578858654045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.2417636330736, 11.100805313420308`], 
                Complex[133.63240767607033`, -10.218396911961511`]}, 2 -> {
                Complex[163.776862087113, -11.238650121699811`], 
                Complex[133.93336948207866`, -31.16578858654045]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.77463242257192}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2417636330736`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.100805313420308`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63240767607033`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"10.218396911961511`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.776862087113`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.238650121699811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.93336948207866`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.16578858654045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.2417636330736, 11.100805313420308`], 
                Complex[133.63240767607033`, -10.218396911961511`]}, 2 -> {
                Complex[163.776862087113, -11.238650121699811`], 
                Complex[133.93336948207866`, -31.16578858654045]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.792938541760388}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.245345602464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.274663157243593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.05696195712113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.77167046658727`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.326833677611646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.245345602464, 11.274663157243593`], 
                Complex[133.6366107628227, -10.05696195712113]}, 2 -> {
                Complex[163.77167046658727`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.326833677611646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.809380982470188}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.245345602464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.274663157243593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6366107628227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"10.05696195712113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.77167046658727`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.412638135984606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.92554786361376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.326833677611646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.245345602464, 11.274663157243593`], 
                Complex[133.6366107628227, -10.05696195712113]}, 2 -> {
                Complex[163.77167046658727`, -11.412638135984606`], 
                Complex[133.92554786361376`, -31.326833677611646`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.828707577160358}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2487089558695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.444427821247759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.89940136633527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7667175920338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.582531307820627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9179840286246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.484001751500106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "C", 
             Association[1 -> {
                Complex[163.2487089558695, 11.444427821247759`], 
                Complex[133.64057992958772`, -9.89940136633527]}, 2 -> {
                Complex[163.7667175920338, -11.582531307820627`], 
                Complex[133.9179840286246, -31.484001751500106`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.84447082898168}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2487089558695`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.444427821247759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64057992958772`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.89940136633527`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7667175920338`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.582531307820627`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.9179840286246`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"31.484001751500106`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.4, "C", 
             Association[1 -> {
                Complex[163.2487089558695, 11.444427821247759`], 
                Complex[133.64057992958772`, -9.89940136633527]}, 2 -> {
                Complex[163.7667175920338, -11.582531307820627`], 
                Complex[133.9179840286246, -31.484001751500106`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.86476675213442}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2518724540805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.610307537645536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7619842266485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "C", 
             Association[1 -> {
                Complex[163.2518724540805, 11.610307537645536`], 
                Complex[133.64433436948318`, -9.745517953028422]}, 2 -> {
                Complex[163.7619842266485, -11.748537908691581`], 
                Complex[133.91065826653698`, -31.637490045704613`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.879895857270167}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2518724540805`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.610307537645536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64433436948318`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.745517953028422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7619842266485`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"11.748537908691581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.91065826653698`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.637490045704613`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.5, "C", 
             Association[1 -> {
                Complex[163.2518724540805, 11.610307537645536`], 
                Complex[133.64433436948318`, -9.745517953028422]}, 2 -> {
                Complex[163.7619842266485, -11.748537908691581`], 
                Complex[133.91065826653698`, -31.637490045704613`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.901114242369347}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.25485273533127`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.77249398761309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75745327301976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.91084965765839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "C", 
             Association[1 -> {
                Complex[163.25485273533127`, 11.77249398761309], 
                Complex[133.64789115029092`, -9.595130182053287]}, 2 -> {
                Complex[163.75745327301976`, -11.91084965765839], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.915650171483727}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.25485273533127`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"11.77249398761309`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64789115029092`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.595130182053287`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75745327301976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"11.91084965765839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.90355300986815`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.787480144641357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.6, "C", 
             Association[1 -> {
                Complex[163.25485273533127`, 11.77249398761309], 
                Complex[133.64789115029092`, -9.595130182053287]}, 2 -> {
                Complex[163.75745327301976`, -11.91084965765839], 
                Complex[133.90355300986815`, -31.787480144641357`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.937747958979329}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2576646121618`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.931164084638935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548408`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75310947547112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.069643504773667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.93413966386116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.2576646121618, 11.931164084638935`], 
                Complex[133.65126550803504`, -9.448070485548408]}, 2 -> {
                Complex[163.75310947547112`, -12.069643504773667`], 
                Complex[133.89665253982204`, -31.93413966386116]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.95172807448937}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2576646121618`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"11.931164084638935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65126550803504`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.448070485548408`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.75310947547112`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.069643504773667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.89665253982204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"31.93413966386116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.2576646121618, 11.931164084638935`], 
                Complex[133.65126550803504`, -9.448070485548408]}, 2 -> {
                Complex[163.75310947547112`, -12.069643504773667`], 
                Complex[133.89665253982204`, -31.93413966386116]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.974665602156329}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26032131919624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7489391715357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.225083174088782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.07762370747607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.26032131919624`, 12.086481517469739`], 
                Complex[133.65447109241083`, -9.304183805581669]}, 2 -> {
                Complex[163.7489391715357, -12.225083174088782`], 
                Complex[133.88994274008314`, -32.07762370747607]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.988124058256871}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26032131919624`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.086481517469739`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65447109241083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.304183805581669`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7489391715357`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.225083174088782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.88994274008314`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.07762370747607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.26032131919624`, 12.086481517469739`], 
                Complex[133.65447109241083`, -9.304183805581669]}, 2 -> {
                Complex[163.7489391715357, -12.225083174088782`], 
                Complex[133.88994274008314`, -32.07762370747607]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{23.9, -7.0118647053805905`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26283472113678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74493008325814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "C", 
             Association[1 -> {
                Complex[163.26283472113678`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[163.74493008325814`, -12.377320504803174`], 
                Complex[133.8834108897335, -32.21807613513113]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -7.024832794842028}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26283472113678`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.238598091201823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65752017313523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.163326327244889`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74493008325814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.377320504803174`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8834108897335`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.21807613513113`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {23.9, "C", 
             Association[1 -> {
                Complex[163.26283472113678`, 12.238598091201823`], 
                Complex[133.65752017313523`, -9.163326327244889]}, 2 -> {
                Complex[163.74493008325814`, -12.377320504803174`], 
                Complex[133.8834108897335, -32.21807613513113]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24., -7.049342671953956}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2652154882986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74107114099544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "C", 
             Association[1 -> {
                Complex[163.2652154882986, 12.387654897960461`], 
                Complex[133.66042381437185`, -9.025364372558757]}, 2 -> {
                Complex[163.74107114099544`, -12.526496621998465`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24., -7.06184912792389}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2652154882986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.387654897960461`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66042381437185`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"9.025364372558757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.74107114099544`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.526496621998465`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87704548813625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.35563066816216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24., "C", 
             Association[1 -> {
                Complex[163.2652154882986, 12.387654897960461`], 
                Complex[133.66042381437185`, -9.025364372558757]}, 2 -> {
                Complex[163.74107114099544`, -12.526496621998465`], 
                Complex[133.87704548813625`, -32.35563066816216]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -7.087096805259865}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2674732455004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.533783342972365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.890173430857475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73735233390101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.672742962762172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.2674732455004, 12.533783342972365`], 
                Complex[133.6631920229149, -8.890173430857475]}, 2 -> {
                Complex[163.73735233390101`, -12.672742962762172`], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -7.099168064854674}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2674732455004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"12.533783342972365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6631920229149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"8.890173430857475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73735233390101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.672742962762172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.87083610610037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.49041185927024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.2674732455004, 12.533783342972365`], 
                Complex[133.6631920229149, -8.890173430857475]}, 2 -> {
                Complex[163.73735233390101`, -12.672742962762172`], 
                Complex[133.87083610610037`, -32.49041185927024]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -7.125124333874397}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26961669895428`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7337645824435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.26961669895428`, 12.677106047334807`], 
                Complex[133.66583387467648`, -8.757637305564256]}, 2 -> {
                Complex[163.7337645824435, -12.816182179005438`], 
                Complex[133.86477325877703`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -7.1367847691845965`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.26961669895428`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.677106047334807`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66583387467648`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.757637305564256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7337645824435`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"12.816182179005438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.86477325877703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.622535945802085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.26961669895428`, 12.677106047334807`], 
                Complex[133.66583387467648`, -8.757637305564256]}, 2 -> {
                Complex[163.7337645824435, -12.816182179005438`], 
                Complex[133.86477325877703`, -32.622535945802085`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -7.163422432433995}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27165374489172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.817737645166858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678214`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73029962922303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.956928934660269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.27165374489172`, 12.817737645166858`], 
                Complex[133.66835762313937`, -8.627647360678214]}, 2 -> {
                Complex[163.73029962922303`, -12.956928934660269`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -7.174694553627089}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27165374489172`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.817737645166858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66835762313937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.627647360678214`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.73029962922303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"12.956928934660269`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.85884829662547`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"32.75211160331618`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.27165374489172`, 12.817737645166858`], 
                Complex[133.66835762313937`, -8.627647360678214]}, 2 -> {
                Complex[163.73029962922303`, -12.956928934660269`], 
                Complex[133.85884829662547`, -32.75211160331618]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.4, -7.201988238993124}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27359156294804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.500101853051339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7269499450588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.095090612015007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "C", 
             Association[1 -> {
                Complex[163.27359156294804`, 12.955785489901578`], 
                Complex[133.67077079273932`, -8.500101853051339]}, 2 -> {
                Complex[163.7269499450588, -13.095090612015007`], 
                Complex[133.8530533114799, -32.87924061335592]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -7.2128928734329065`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27359156294804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"12.955785489901578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67077079273932`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.500101853051339`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7269499450588`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.095090612015007`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8530533114799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"32.87924061335592`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.4, "C", 
             Association[1 -> {
                Complex[163.27359156294804`, 12.955785489901578`], 
                Complex[133.67077079273932`, -8.500101853051339]}, 2 -> {
                Complex[163.7269499450588, -13.095090612015007`], 
                Complex[133.8530533114799, -32.87924061335592]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -7.240818869468365}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27543669676655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.72370864788658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.004018457106575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.27543669676655`, 13.091350282096839`], 
                Complex[133.67308025959395`, -8.374905338778804]}, 2 -> {
                Complex[163.72370864788658`, -13.230767939566048`], 
                Complex[133.84738105530036`, -33.004018457106575`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -7.251375320144199}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27543669676655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.091350282096839`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67308025959395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.374905338778804`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.72370864788658`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.230767939566048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.84738105530036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.004018457106575`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.27543669676655`, 13.091350282096839`], 
                Complex[133.67308025959395`, -8.374905338778804]}, 2 -> {
                Complex[163.72370864788658`, -13.230767939566048`], 
                Complex[133.84738105530036`, -33.004018457106575`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -7.279911429656329}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27719512383507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67529232155744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.251968143863518`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7205694324496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.364055551814676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477616`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.27719512383507`, 13.224526629192962`], 
                Complex[133.67529232155744`, -8.251968143863518]}, 2 -> {
                Complex[163.7205694324496, -13.364055551814676`], 
                Complex[133.8418248696247, -33.12653484477616]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -7.290137615701962}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.27719512383507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.224526629192962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67529232155744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.251968143863518`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7205694324496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"13.364055551814676`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8418248696247`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.12653484477616`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.27719512383507`, 13.224526629192962`], 
                Complex[133.67529232155744`, -8.251968143863518]}, 2 -> {
                Complex[163.7205694324496, -13.364055551814676`], 
                Complex[133.8418248696247, -33.12653484477616]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.7, -7.319263025225589}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2788723162124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.35540354604583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71752650912524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.495042489836637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902983`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "C", 
             Association[1 -> {
                Complex[163.2788723162124, 13.35540354604583], 
                Complex[133.67741275923174`, -8.131205890824086]}, 2 -> {
                Complex[163.71752650912524`, -13.495042489836637`], 
                Complex[133.83637862409034`, -33.24687418902983]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -7.329175606882663}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2788723162124`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.35540354604583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67741275923174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.131205890824086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71752650912524`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.495042489836637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83637862409034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.24687418902983`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.7, "C", 
             Association[1 -> {
                Complex[163.2788723162124, 13.35540354604583], 
                Complex[133.67741275923174`, -8.131205890824086]}, 2 -> {
                Complex[163.71752650912524`, -13.495042489836637`], 
                Complex[133.83637862409034`, -33.24687418902983]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.8, -7.358870770012146}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28047329351344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167398`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71457455051592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.623812650126242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.365116029557846`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "C", 
             Association[1 -> {
                Complex[163.28047329351344`, 13.484064903736138`], 
                Complex[133.67944688928384`, -8.012539074167398]}, 2 -> {
                Complex[163.71457455051592`, -13.623812650126242`], 
                Complex[133.83103666267402`, -33.365116029557846`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -7.368485260041503}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28047329351344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.484064903736138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67944688928384`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"8.012539074167398`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71457455051592`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.623812650126242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.83103666267402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.365116029557846`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.8, "C", 
             Association[1 -> {
                Complex[163.28047329351344`, 13.484064903736138`], 
                Complex[133.67944688928384`, -8.012539074167398]}, 2 -> {
                Complex[163.71457455051592`, -13.623812650126242`], 
                Complex[133.83103666267402`, -33.365116029557846`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.9, -7.39873179289122}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28200266929107`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71170864466583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.48133541482063`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "C", 
             Association[1 -> {
                Complex[163.28200266929107`, 13.610589833057865`], 
                Complex[133.68139961119044`, -7.895892678682291]}, 2 -> {
                Complex[163.71170864466583`, -13.750445188118116`], 
                Complex[133.82579375652693`, -33.48133541482063]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -7.408062656141849}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28200266929107`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.610589833057865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68139961119044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.895892678682291`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.71170864466583`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.750445188118116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.82579375652693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.48133541482063`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.9, "C", 
             Association[1 -> {
                Complex[163.28200266929107`, 13.610589833057865`], 
                Complex[133.68139961119044`, -7.895892678682291]}, 2 -> {
                Complex[163.71170864466583`, -13.750445188118116`], 
                Complex[133.82579375652693`, -33.48133541482063]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -7.43884324345158}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2834646917637`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.735053088170234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68327544834887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.781195835377185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70892425395203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8206450624651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.59560324614746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.2834646917637, 13.735053088170234`], 
                Complex[133.68327544834887`, -7.781195835377185]}, 2 -> {
                Complex[163.70892425395203`, -13.875014881870271`], 
                Complex[133.8206450624651, -33.59560324614746]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -7.44790398605177}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2834646917637`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.735053088170234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68327544834887`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.781195835377185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70892425395203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.875014881870271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8206450624651`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.59560324614746`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.2834646917637, 13.735053088170234`], 
                Complex[133.68327544834887`, -7.781195835377185]}, 2 -> {
                Complex[163.70892425395203`, -13.875014881870271`], 
                Complex[133.8206450624651, -33.59560324614746]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -7.479202296660957}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28486327968363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70621717885442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.997592460624668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.70798658864134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.28486327968363`, 13.857525375128327`], 
                Complex[133.68507858433867`, -7.668381510610166]}, 2 -> {
                Complex[163.70621717885442`, -13.997592460624668`], 
                Complex[133.81558608632903`, -33.70798658864134]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -7.488005546090253}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28486327968363`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"13.857525375128327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68507858433867`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.668381510610166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70621717885442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"13.997592460624668`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.81558608632903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.70798658864134`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.28486327968363`, 13.857525375128327`], 
                Complex[133.68507858433867`, -7.668381510610166]}, 2 -> {
                Complex[163.70621717885442`, -13.997592460624668`], 
                Complex[133.81558608632903`, -33.70798658864134]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -7.519806156679936}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2862020540158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68681289499762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.55738622457017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7035835259332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.118244902313043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8106126505474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.81854895273081`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.2862020540158, 13.978073649360802`], 
                Complex[133.68681289499762`, -7.55738622457017]}, 2 -> {
                Complex[163.7035835259332, -14.118244902313043`], 
                Complex[133.8106126505474, -33.81854895273081]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -7.52836373380689}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2862020540158`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"13.978073649360802`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68681289499762`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.55738622457017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.7035835259332`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"14.118244902313043`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.8106126505474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"33.81854895273081`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.2862020540158, 13.978073649360802`], 
                Complex[133.68681289499762`, -7.55738622457017]}, 2 -> {
                Complex[163.7035835259332, -14.118244902313043`], 
                Complex[133.8106126505474, -33.81854895273081]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -7.560652059956266}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28748436599128`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.4481497957836655`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70101967944905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.28748436599128`, 14.096761385616206`], 
                Complex[133.68848197687097`, -7.4481497957836655`]}, 2 -> {
                Complex[163.70101967944905`, -14.237035703530262`], 
                Complex[133.80572086534593`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -7.568975043980136}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28748436599128`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.096761385616206`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68848197687097`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.4481497957836655`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.70101967944905`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.237035703530262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80572086534593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"33.927350549694836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.28748436599128`, 14.096761385616206`], 
                Complex[133.68848197687097`, -7.4481497957836655`]}, 2 -> {
                Complex[163.70101967944905`, -14.237035703530262`], 
                Complex[133.80572086534593`, -33.927350549694836`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -7.601737277710372}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28871332201555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.21364882343601`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.3406151087588825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69852227614442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.35402512503277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.28871332201555`, 14.21364882343601], 
                Complex[133.69008917251037`, -7.3406151087588825`]}, 2 -> {
                Complex[163.69852227614442`, -14.35402512503277], 
                Complex[133.80090710312305`, -34.03444852404853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -7.609836064820338}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28871332201555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.21364882343601`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69008917251037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.3406151087588825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69852227614442`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.35402512503277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.80090710312305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.03444852404853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.28871332201555`, 14.21364882343601], 
                Complex[133.69008917251037`, -7.3406151087588825`]}, 2 -> {
                Complex[163.69852227614442`, -14.35402512503277], 
                Complex[133.80090710312305`, -34.03444852404853]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -7.643059117905443}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28989180583767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69608818277845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.79616797558796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.13989716530639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.28989180583767`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[163.69608818277845`, -14.469270415426754`], 
                Complex[133.79616797558796`, -34.13989716530639]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -7.6509434743647615`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.28989180583767`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.328793190818367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69163759302495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.234727902251212`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69608818277845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.469270415426754`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.79616797558796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.13989716530639`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.28989180583767`, 14.328793190818367`], 
                Complex[133.69163759302495`, -7.234727902251212]}, 2 -> {
                Complex[163.69608818277845`, -14.469270415426754`], 
                Complex[133.79616797558796`, -34.13989716530639]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -7.684614926780813}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29102249833014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69371447606676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.243748101320996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.29102249833014`, 14.442248908399693`], 
                Complex[133.69313013823358`, -7.130436575951601]}, 2 -> {
                Complex[163.69371447606676`, -14.582826015372707`], 
                Complex[133.7915003133145, -34.243748101320996`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -7.692294037052707}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29102249833014`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.442248908399693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69313013823358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.130436575951601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69371447606676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.582826015372707`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7915003133145`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.243748101320996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.29102249833014`, 14.442248908399693`], 
                Complex[133.69313013823358`, -7.130436575951601]}, 2 -> {
                Complex[163.69371447606676`, -14.582826015372707`], 
                Complex[133.7915003133145, -34.243748101320996`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.7, -7.726402090015374}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2921078951751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.554067776191998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672555`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69139842472714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.694743744345221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7869011474127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "C", 
             Association[1 -> {
                Complex[163.2921078951751, 14.554067776191998`], 
                Complex[133.69456951471147`, -7.027692013672555]}, 2 -> {
                Complex[163.69139842472714`, -14.694743744345221`], 
                Complex[133.7869011474127, -34.34605047512348]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -7.733884600469828}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2921078951751`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.554067776191998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69456951471147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"7.027692013672555`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.69139842472714`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.694743744345221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7869011474127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.34605047512348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.7, "C", 
             Association[1 -> {
                Complex[163.2921078951751, 14.554067776191998`], 
                Complex[133.69456951471147`, -7.027692013672555]}, 2 -> {
                Complex[163.69139842472714`, -14.694743744345221`], 
                Complex[133.7869011474127, -34.34605047512348]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -7.7684180335775155`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29315032271526`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69595825198883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.926447421338327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68913747337317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78236769306173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.446851106957446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.29315032271526`, 14.664299144668377`], 
                Complex[133.69595825198883`, -6.926447421338327]}, 2 -> {
                Complex[163.68913747337317`, -14.805072971738813`], 
                Complex[133.78236769306173`, -34.446851106957446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -7.775712092251396}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29315032271526`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.664299144668377`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69595825198883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.926447421338327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68913747337317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.805072971738813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.78236769306173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.446851106957446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.29315032271526`, 14.664299144668377`], 
                Complex[133.69595825198883`, -6.926447421338327]}, 2 -> {
                Complex[163.68913747337317`, -14.805072971738813`], 
                Complex[133.78236769306173`, -34.446851106957446`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{25.9, -7.810660224309535}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2941519521878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.77299007177116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68692922803774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.913860773896733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "C", 
             Association[1 -> {
                Complex[163.2941519521878, 14.77299007177116], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[163.68692922803774`, -14.913860773896733`], 
                Complex[133.77789733468606`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -7.817773517135004}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2941519521878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"14.77299007177116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69729871711968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.826658178291327`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68692922803774`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"14.913860773896733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.77789733468606`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.54619464299692`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {25.9, "C", 
             Association[1 -> {
                Complex[163.2941519521878, 14.77299007177116], 
                Complex[133.69729871711968`, -6.826658178291327]}, 2 -> {
                Complex[163.68692922803774`, -14.913860773896733`], 
                Complex[133.77789733468606`, -34.54619464299692]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26., -7.8531261702875}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29511481253365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.88018546723748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69859312781242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.728281700596741`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6847714431318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644123692063744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "C", 
             Association[1 -> {
                Complex[163.29511481253365`, 14.88018546723748], 
                Complex[133.69859312781242`, -6.728281700596741]}, 2 -> {
                Complex[163.6847714431318, -15.021152078455035`], 
                Complex[133.7734876125809, -34.644123692063744`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26., -7.860065954154015}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29511481253365`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.88018546723748`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69859312781242`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.728281700596741`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6847714431318`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.021152078455035`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7734876125809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.644123692063744`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26., "C", 
             Association[1 -> {
                Complex[163.29511481253365`, 14.88018546723748], 
                Complex[133.69859312781242`, -6.728281700596741]}, 2 -> {
                Complex[163.6847714431318, -15.021152078455035`], 
                Complex[133.7734876125809, -34.644123692063744`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -7.895813420991175}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29604080194576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183247`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6826620096745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.126989797234097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7691362108228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.74067895150922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.29604080194576`, 14.985928225471852`], 
                Complex[133.69984356428586`, -6.631277315183247]}, 2 -> {
                Complex[163.6826620096745, -15.126989797234097`], 
                Complex[133.7691362108228, -34.74067895150922]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -7.902586553963366}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29604080194576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"14.985928225471852`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69984356428586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.631277315183247`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6826620096745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.126989797234097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7691362108228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"34.74067895150922`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.29604080194576`, 14.985928225471852`], 
                Complex[133.69984356428586`, -6.631277315183247]}, 2 -> {
                Complex[163.6826620096745, -15.126989797234097`], 
                Complex[133.7691362108228, -34.74067895150922]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.2, -7.938719567313965}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29693169830156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.5356061437843405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68059894464983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.231414948770267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76484094632082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "C", 
             Association[1 -> {
                Complex[163.29693169830156`, 15.090259348061176`], 
                Complex[133.70105197999624`, -6.5356061437843405`]}, 2 -> {
                Complex[163.68059894464983`, -15.231414948770267`], 
                Complex[133.76484094632082`, -34.83589932329275]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -7.945332536290345}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29693169830156`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.090259348061176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70105197999624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.5356061437843405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.68059894464983`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.231414948770267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76484094632082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.83589932329275`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.2, "C", 
             Association[1 -> {
                Complex[163.29693169830156`, 15.090259348061176`], 
                Complex[133.70105197999624`, -6.5356061437843405`]}, 2 -> {
                Complex[163.68059894464983`, -15.231414948770267`], 
                Complex[133.76484094632082`, -34.83589932329275]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -7.981842241437994}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29778916860275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.193218056900896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67858038136492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.334466771459132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.29778916860275`, 15.193218056900896`], 
                Complex[133.70222021135814`, -6.441230995764474]}, 2 -> {
                Complex[163.67858038136492`, -15.334466771459132`], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -7.988301187502933}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.29778916860275`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.193218056900896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70222021135814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.441230995764474`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67858038136492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.334466771459132`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.76059975888245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"34.92982202117593`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.29778916860275`, 15.193218056900896`], 
                Complex[133.70222021135814`, -6.441230995764474]}, 2 -> {
                Complex[163.67858038136492`, -15.334466771459132`], 
                Complex[133.76059975888245`, -34.92982202117593]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -8.025179116596247}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2986147775331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.29484189879971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67660456069984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.2986147775331, 15.29484189879971], 
                Complex[133.7033499865708, -6.348116269010088]}, 2 -> {
                Complex[163.67660456069984`, -15.436182828175923`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -8.031489858289316}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2986147775331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.29484189879971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7033499865708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"6.348116269010088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67660456069984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.436182828175923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75641070218487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.02248266985033`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.2986147775331, 15.29484189879971], 
                Complex[133.7033499865708, -6.348116269010088]}, 2 -> {
                Complex[163.67660456069984`, -15.436182828175923`], 
                Complex[133.75641070218487`, -35.02248266985033]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -8.06872790674022}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2994099952287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.395166842334241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67466982315278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.53659910314539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.2994099952287, 15.395166842334241`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[163.67466982315278`, -15.53659910314539], 
                Complex[133.75227193555395`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -8.074895961442207}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.2994099952287`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.395166842334241`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70444293364434`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.256227858155992`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67466982315278`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.53659910314539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.75227193555395`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.1139153967292`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.2994099952287, 15.395166842334241`], 
                Complex[133.70444293364434`, -6.256227858155992]}, 2 -> {
                Complex[163.67466982315278`, -15.53659910314539], 
                Complex[133.75227193555395`, -35.1139153967292]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -8.112486366129085}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3001762043455`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.494227367644923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67277460159679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7481817164674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.204152917056646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.3001762043455, 15.494227367644923`], 
                Complex[133.70550058771101`, -6.165533069493565]}, 2 -> {
                Complex[163.67277460159679`, -15.635750091752156`], 
                Complex[133.7481817164674, -35.204152917056646`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -8.118516969742267}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3001762043455`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.494227367644923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70550058771101`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.165533069493565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67277460159679`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.635750091752156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7481817164674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"35.204152917056646`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.3001762043455, 15.494227367644923`], 
                Complex[133.70550058771101`, -6.165533069493565]}, 2 -> {
                Complex[163.67277460159679`, -15.635750091752156`], 
                Complex[133.7481817164674, -35.204152917056646`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -8.156452288853977}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30091470649666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769498`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.076000541975269`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67091741467345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.733668883910747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.293226612919796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.30091470649666`, 15.592056549792122`], 
                Complex[133.70652439769498`, -6.076000541975269]}, 2 -> {
                Complex[163.67091741467345`, -15.733668883910747`], 
                Complex[133.74413839370675`, -35.293226612919796`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -8.162350413935163}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30091470649666`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.592056549792122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70652439769498`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"6.076000541975269`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.67091741467345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"15.733668883910747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74413839370675`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.293226612919796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.30091470649666`, 15.592056549792122`], 
                Complex[133.70652439769498`, -6.076000541975269]}, 2 -> {
                Complex[163.67091741467345`, -15.733668883910747`], 
                Complex[133.74413839370675`, -35.293226612919796`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -8.200623508309139}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30162672812602`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70751573240688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.987600173789694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6690968607587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.830387241551286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.30162672812602`, 15.688686136228515`], 
                Complex[133.70751573240688`, -5.987600173789694]}, 2 -> {
                Complex[163.6690968607587, -15.830387241551286`], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -8.206393880797238}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30162672812602`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.688686136228515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70751573240688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.987600173789694`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6690968607587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.830387241551286`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.74014040109287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.38116660668967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.30162672812602`, 15.688686136228515`], 
                Complex[133.70751573240688`, -5.987600173789694]}, 2 -> {
                Complex[163.6690968607587, -15.830387241551286`], 
                Complex[133.74014040109287`, -35.38116660668967]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{26.9, -8.244997896619957}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30231342587385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.784146618887455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.9003030540343815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6673116124424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.925935670720543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73618625174637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.46800182936364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "C", 
             Association[1 -> {
                Complex[163.30231342587385`, 15.784146618887455`], 
                Complex[133.70847588612014`, -5.9003030540343815`]}, 2 -> {
                Complex[163.6673116124424, -15.925935670720543`], 
                Complex[133.73618625174637`, -35.46800182936364]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -8.250645011284986}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30231342587385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.784146618887455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70847588612014`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.9003030540343815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6673116124424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"15.925935670720543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73618625174637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.46800182936364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {26.9, "C", 
             Association[1 -> {
                Complex[163.30231342587385`, 15.784146618887455`], 
                Complex[133.70847588612014`, -5.9003030540343815`]}, 2 -> {
                Complex[163.6673116124424, -15.925935670720543`], 
                Complex[133.73618625174637`, -35.46800182936364]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27., -8.289573364036482}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30297589148626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66556041147118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "C", 
             Association[1 -> {
                Complex[163.30297589148626`, 15.878467301338127`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[163.66556041147118`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27., -8.295101498763946}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30297589148626`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"15.878467301338127`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70940608368056`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.814081399060022`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66556041147118`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.02034348874923`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73227453282152`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.553760084235876`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27., "C", 
             Association[1 -> {
                Complex[163.30297589148626`, 15.878467301338127`], 
                Complex[133.70940608368056`, -5.814081399060022]}, 2 -> {
                Complex[163.66556041147118`, -16.02034348874923], 
                Complex[133.73227453282152`, -35.553760084235876`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.1, -8.334347858299896}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3036151563131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.971676361413378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71030748519513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.728908493102031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6638420641087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.11363888689164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "C", 
             Association[1 -> {
                Complex[163.3036151563131, 15.971676361413378`], 
                Complex[133.71030748519513`, -5.728908493102031]}, 2 -> {
                Complex[163.6638420641087, -16.11363888689164], 
                Complex[133.72840390066767`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -8.339761087312834}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3036151563131`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"15.971676361413378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71030748519513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.728908493102031`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6638420641087`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.11363888689164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72840390066767`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.63846810627997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.1, "C", 
             Association[1 -> {
                Complex[163.3036151563131, 15.971676361413378`], 
                Complex[133.71030748519513`, -5.728908493102031]}, 2 -> {
                Complex[163.6638420641087, -16.11363888689164], 
                Complex[133.72840390066767`, -35.63846810627997]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.2, -8.379319363988145}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30423219543457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.64475863285114`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66215543687335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "C", 
             Association[1 -> {
                Complex[163.30423219543457`, 16.063800909678434`], 
                Complex[133.71118119033963`, -5.64475863285114]}, 2 -> {
                Complex[163.66215543687335`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -8.384621570098957}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30423219543457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.063800909678434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71118119033963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.64475863285114`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66215543687335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.205848988805332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72457307637754`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.72215161759165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.2, "C", 
             Association[1 -> {
                Complex[163.30423219543457`, 16.063800909678434`], 
                Complex[133.71118119033963`, -5.64475863285114]}, 2 -> {
                Complex[163.66215543687335`, -16.205848988805332`], 
                Complex[133.72457307637754`, -35.72215161759165]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -8.424485901846293}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30482793145168`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.154867044072365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7120282423221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66049945261796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.296999905203638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72078084168677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.30482793145168`, 16.154867044072365`], 
                Complex[133.7120282423221, -5.561607075648972]}, 2 -> {
                Complex[163.66049945261796`, -16.296999905203638`], 
                Complex[133.72078084168677`, -35.80483537920644]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -8.429680787821319}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30482793145168`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.154867044072365`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7120282423221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"5.561607075648972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.66049945261796`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.296999905203638`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72078084168677`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.80483537920644`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.30482793145168`, 16.154867044072365`], 
                Complex[133.7120282423221, -5.561607075648972]}, 2 -> {
                Complex[163.66049945261796`, -16.296999905203638`], 
                Complex[133.72078084168677`, -35.80483537920644]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.4, -8.469845528106106}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30540323797229`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.24489990102471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65887308691825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.387116784982247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71702603519051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "C", 
             Association[1 -> {
                Complex[163.30540323797229`, 16.24489990102471], 
                Complex[133.71284963153286`, -5.479429991022453]}, 2 -> {
                Complex[163.65887308691825`, -16.387116784982247`], 
                Complex[133.71702603519051`, -35.88654323957749]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -8.474936627217877}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30540323797229`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.24489990102471`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71284963153286`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.479429991022453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65887308691825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.387116784982247`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71702603519051`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.88654323957749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.4, "C", 
             Association[1 -> {
                Complex[163.30540323797229`, 16.24489990102471], 
                Complex[133.71284963153286`, -5.479429991022453]}, 2 -> {
                Complex[163.65887308691825`, -16.387116784982247`], 
                Complex[133.71702603519051`, -35.88654323957749]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -8.515396333798938}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3059589428217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.33392370332042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71364629891158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.39820441529854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65727536474287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754884988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.967298179972964`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 
             Association[1 -> {
                Complex[163.3059589428217, 16.33392370332042], 
                Complex[133.71364629891158`, -5.39820441529854]}, 2 -> {
                Complex[163.65727536474287`, -16.476223863094262`], 
                Complex[133.71330754884988`, -35.967298179972964`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -8.5203870196338}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3059589428217`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.33392370332042`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71364629891158`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.39820441529854`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65727536474287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.476223863094262`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71330754884988`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"35.967298179972964`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 
             Association[1 -> {
                Complex[163.3059589428217, 16.33392370332042], 
                Complex[133.71364629891158`, -5.39820441529854]}, 2 -> {
                Complex[163.65727536474287`, -16.476223863094262`], 
                Complex[133.71330754884988`, -35.967298179972964`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -8.56113644406524}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3064958310019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.421961804962738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65570535737885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.3064958310019, 16.421961804962738`], 
                Complex[133.71441913905537`, -5.317908209063045]}, 2 -> {
                Complex[163.65570535737885`, -16.564344505422593`], 
                Complex[133.70962432476176`, -36.04712235702883]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -8.566029939647594}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3064958310019`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"16.421961804962738`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71441913905537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.317908209063045`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65570535737885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.564344505422593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70962432476176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.04712235702883`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.3064958310019, 16.421961804962738`], 
                Complex[133.71441913905537`, -5.317908209063045]}, 2 -> {
                Complex[163.65570535737885`, -16.564344505422593`], 
                Complex[133.70962432476176`, -36.04712235702883]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -8.607064017463598}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30701464742387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.5090367332606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249019`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65416217958912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.65150125087593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267105`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.30701464742387`, 16.5090367332606], 
                Complex[133.71516900309246`, -5.238520017249019]}, 2 -> {
                Complex[163.65416217958912`, -16.65150125087593], 
                Complex[133.70597535216766`, -36.12603714267105]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -8.61186340375231}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30701464742387`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.5090367332606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71516900309246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.238520017249019`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.65416217958912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"16.65150125087593`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70597535216766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.12603714267105`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.30701464742387`, 16.5090367332606], 
                Complex[133.71516900309246`, -5.238520017249019]}, 2 -> {
                Complex[163.65416217958912`, -16.65150125087593], 
                Complex[133.70597535216766`, -36.12603714267105]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -8.653177245281706}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30751609943115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6526449869827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.73771585091723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70235966468252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.20406316160487`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.30751609943115`, 16.595170228347317`], 
                Complex[133.71589670134117`, -5.160019231659067]}, 2 -> {
                Complex[163.6526449869827, -16.73771585091723], 
                Complex[133.70235966468252`, -36.20406316160487]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -8.657885469089056}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30751609943115`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.595170228347317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71589670134117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.160019231659067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6526449869827`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.73771585091723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.70235966468252`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.20406316160487`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.30751609943115`, 16.595170228347317`], 
                Complex[133.71589670134117`, -5.160019231659067]}, 2 -> {
                Complex[163.6526449869827, -16.73771585091723], 
                Complex[133.70235966468252`, -36.20406316160487]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.9, -8.699474350851398}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30800085913484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71660300577298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6511529735775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.82300930670975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6987763377227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.28122032654667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "C", 
             Association[1 -> {
                Complex[163.30800085913484`, 16.680383280319464`], 
                Complex[133.71660300577298`, -5.082385955742662]}, 2 -> {
                Complex[163.6511529735775, -16.82300930670975], 
                Complex[133.6987763377227, -36.28122032654667]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -8.704094232230338}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30800085913484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.680383280319464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71660300577298`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.082385955742662`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6511529735775`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.82300930670975`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6987763377227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.28122032654667`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.9, "C", 
             Association[1 -> {
                Complex[163.30800085913484`, 16.680383280319464`], 
                Complex[133.71660300577298`, -5.082385955742662]}, 2 -> {
                Complex[163.6511529735775, -16.82300930670975], 
                Complex[133.6987763377227, -36.28122032654667]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -8.745953588869403}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30846956557582`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6496853695408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.90740190405787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861177`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.35752787136576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.30846956557582`, 16.764696164168555`], 
                Complex[133.71728865229744`, -5.005600971465146]}, 2 -> {
                Complex[163.6496853695408, -16.90740190405787], 
                Complex[133.6952244861177, -36.35752787136576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -8.750487828010758}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30846956557582`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.764696164168555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71728865229744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"5.005600971465146`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6496853695408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.90740190405787`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6952244861177`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.35752787136576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.30846956557582`, 16.764696164168555`], 
                Complex[133.71728865229744`, -5.005600971465146]}, 2 -> {
                Complex[163.6496853695408, -16.90740190405787], 
                Complex[133.6952244861177, -36.35752787136576]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -8.792613244725324}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30892282672824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6482414390911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.990913246296902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.30892282672824`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118656]}, 2 -> {
                Complex[163.6482414390911, -16.990913246296902`], 
                Complex[133.69170326188944`, -36.43300438228255]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -8.797064428402882}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30892282672824`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.848128472663596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71795434288214`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.929645708118656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6482414390911`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"16.990913246296902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.69170326188944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.43300438228255`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.30892282672824`, 16.848128472663596`], 
                Complex[133.71795434288214`, -4.929645708118656]}, 2 -> {
                Complex[163.6482414390911, -16.990913246296902`], 
                Complex[133.69170326188944`, -36.43300438228255]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.2, -8.839451633838078}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30936122135927`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6468204785474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.073562285278378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6882118521846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50766782726147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "C", 
             Association[1 -> {
                Complex[163.30936122135927`, 16.93069914732912], 
                Complex[133.71860074752374`, -4.854502212938122]}, 2 -> {
                Complex[163.6468204785474, -17.073562285278378`], 
                Complex[133.6882118521846, -36.50766782726147]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -8.843822241436103}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30936122135927`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"16.93069914732912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71860074752374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.854502212938122`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6468204785474`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.073562285278378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6882118521846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.50766782726147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.2, "C", 
             Association[1 -> {
                Complex[163.30936122135927`, 16.93069914732912], 
                Complex[133.71860074752374`, -4.854502212938122]}, 2 -> {
                Complex[163.6468204785474, -17.073562285278378`], 
                Complex[133.6882118521846, -36.50766782726147]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.3, -8.886467101001685}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30978530075578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396218`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64542181451625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.155367350584477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.58153558372544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "C", 
             Association[1 -> {
                Complex[163.30978530075578`, 17.012426507651817`], 
                Complex[133.7192285060807, -4.780153123396218]}, 2 -> {
                Complex[163.64542181451625`, -17.155367350584477`], 
                Complex[133.68474947734978`, -36.58153558372544]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -8.890759510156453}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.30978530075578`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.012426507651817`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7192285060807`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.780153123396218`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64542181451625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.155367350584477`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68474947734978`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.58153558372544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.3, "C", 
             Association[1 -> {
                Complex[163.30978530075578`, 17.012426507651817`], 
                Complex[133.7192285060807, -4.780153123396218]}, 2 -> {
                Complex[163.64542181451625`, -17.155367350584477`], 
                Complex[133.68474947734978`, -36.58153558372544]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -8.933658019741372}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31019559032947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64404480220196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.31019559032947`, 17.093328278637614`], 
                Complex[133.71983822997944`, -4.70658164106197]}, 2 -> {
                Complex[163.64404480220196`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -8.93787451162554}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31019559032947`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.093328278637614`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.71983822997944`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.70658164106197`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64404480220196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.236346177091548`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.68131538913536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.65462446470535`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 
             Association[1 -> {
                Complex[163.31019559032947`, 17.093328278637614`], 
                Complex[133.71983822997944`, -4.70658164106197]}, 2 -> {
                Complex[163.64404480220196`, -17.236346177091548`], 
                Complex[133.68131538913536`, -36.65462446470535]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -8.981022791680529}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31059259111072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.173421616831476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72043050380475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.633771506916521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64268882383246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353258`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.31059259111072`, 17.173421616831476`], 
                Complex[133.72043050380475`, -4.633771506916521]}, 2 -> {
                Complex[163.64268882383246`, -17.31651593099673], 
                Complex[133.67790886901938`, -36.72695074353258]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -8.985165555956744}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31059259111072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.173421616831476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72043050380475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.633771506916521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64268882383246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.31651593099673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67790886901938`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.72695074353258`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.31059259111072`, 17.173421616831476`], 
                Complex[133.72043050380475`, -4.633771506916521]}, 2 -> {
                Complex[163.64268882383246`, -17.31651593099673], 
                Complex[133.67790886901938`, -36.72695074353258]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -9.028559845919093}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31097678113926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.25272313490318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6413532871904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31097678113926`, 17.25272313490318], 
                Complex[133.72100588678245`, -4.561706978028415]}, 2 -> {
                Complex[163.6413532871904, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -9.032630985386982}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31097678113926`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.25272313490318`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72100588678245`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.561706978028415`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6413532871904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.395893234410227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6745292266415`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"36.79853017717177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31097678113926`, 17.25272313490318], 
                Complex[133.72100588678245`, -4.561706978028415]}, 2 -> {
                Complex[163.6413532871904, -17.395893234410227`], 
                Complex[133.6745292266415, -36.79853017717177]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -9.076267638423746}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3113486167611`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.331248924894496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72156491416428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64003762424196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.47449418860847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67117579833888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3113486167611, 17.331248924894496`], 
                Complex[133.72156491416428`, -4.490372805498023]}, 2 -> {
                Complex[163.64003762424196`, -17.47449418860847], 
                Complex[133.67117579833888`, -36.86937802828386]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -9.080269173382456}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3113486167611`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.331248924894496`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72156491416428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.490372805498023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.64003762424196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.47449418860847`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.67117579833888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.86937802828386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3113486167611, 17.331248924894496`], 
                Complex[133.72156491416428`, -4.490372805498023]}, 2 -> {
                Complex[163.64003762424196`, -17.47449418860847], 
                Complex[133.67117579833888`, -36.86937802828386]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -9.124144651430255}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31170853383765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.409014580215214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63874128985492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.552334396036265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.93950908610309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 
             Association[1 -> {
                Complex[163.31170853383765`, 17.409014580215214`], 
                Complex[133.72210809852083`, -4.419754213588025]}, 2 -> {
                Complex[163.63874128985492`, -17.552334396036265`], 
                Complex[133.66784794577543`, -36.93950908610309]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -9.128078523776832}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31170853383765`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.409014580215214`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72210809852083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.419754213588025`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63874128985492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.552334396036265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66784794577543`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"36.93950908610309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 
             Association[1 -> {
                Complex[163.31170853383765`, 17.409014580215214`], 
                Complex[133.72210809852083`, -4.419754213588025]}, 2 -> {
                Complex[163.63874128985492`, -17.552334396036265`], 
                Complex[133.66784794577543`, -36.93950908610309]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -9.172189392858108}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31205694887507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.48603521646938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6374637606001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.629428981138844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.008937686204405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.31205694887507`, 17.48603521646938], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[163.6374637606001, -17.629428981138844`], 
                Complex[133.66454505465833`, -37.008937686204405`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -9.176057469940426}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31205694887507`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.48603521646938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72263593095124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.349836879963185`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6374637606001`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.629428981138844`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66454505465833`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.008937686204405`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.31205694887507`, 17.48603521646938], 
                Complex[133.72263593095124`, -4.349836879963185]}, 2 -> {
                Complex[163.6374637606001, -17.629428981138844`], 
                Complex[133.66454505465833`, -37.008937686204405`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -9.220400395737649}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31239426007943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.562325491186662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63620453362884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.70579261009809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.31239426007943`, 17.562325491186662`], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[163.63620453362884`, -17.70579261009809], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -9.224204473979018}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31239426007943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.562325491186662`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7231488822148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.280606916968264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63620453362884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.70579261009809`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.66126653353433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.07767772923182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.31239426007943`, 17.562325491186662`], 
                Complex[133.7231488822148, -4.280606916968264]}, 2 -> {
                Complex[163.63620453362884`, -17.70579261009809], 
                Complex[133.66126653353433`, -37.07767772923182]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -9.268776217649743}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31272084834353`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.637899622528057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878537`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.634963125622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.781439509544892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.14574269865576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.31272084834353`, 17.637899622528057`], 
                Complex[133.72364740379095`, -4.212050853878537]}, 2 -> {
                Complex[163.634963125622, -17.781439509544892`], 
                Complex[133.65801181266102`, -37.14574269865576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -9.272518025961007}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31272084834353`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.637899622528057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72364740379095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.212050853878537`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.634963125622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"17.781439509544892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65801181266102`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.14574269865576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.31272084834353`, 17.637899622528057`], 
                Complex[133.72364740379095`, -4.212050853878537]}, 2 -> {
                Complex[163.634963125622, -17.781439509544892`], 
                Complex[133.65801181266102`, -37.14574269865576]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.2, -9.317315440178}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31303707817023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.712771407030306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63373907180392`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.85638348430743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.21314567761614`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "C", 
             Association[1 -> {
                Complex[163.31303707817023`, 17.712771407030306`], 
                Complex[133.7241319288729, -4.144155620061895]}, 2 -> {
                Complex[163.63373907180392`, -17.85638348430743], 
                Complex[133.65478034294642`, -37.21314567761614]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -9.320996643171652}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31303707817023`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.712771407030306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7241319288729`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"4.144155620061895`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63373907180392`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.85638348430743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65478034294642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.21314567761614`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.2, "C", 
             Association[1 -> {
                Complex[163.31303707817023`, 17.712771407030306`], 
                Complex[133.7241319288729, -4.144155620061895]}, 2 -> {
                Complex[163.63373907180392`, -17.85638348430743], 
                Complex[133.65478034294642`, -37.21314567761614]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -9.366016668373526}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3133432985372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996313`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63253192501676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.3133432985372, 17.786954236448395`], 
                Complex[133.72460287329903`, -4.076908528996313]}, 2 -> {
                Complex[163.63253192501676`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -9.369638869393283}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3133432985372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"17.786954236448395`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72460287329903`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.076908528996313`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63253192501676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"17.93063793425935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.65157159495215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.27989936491177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.3133432985372, 17.786954236448395`], 
                Complex[133.72460287329903`, -4.076908528996313]}, 2 -> {
                Complex[163.63253192501676`, -17.93063793425935], 
                Complex[133.65157159495215`, -37.27989936491177]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.4, -9.414878530232153}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31363984370773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.86046111375152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.01029726309017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63134125485357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6483850579582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.3460160901857`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "C", 
             Association[1 -> {
                Complex[163.31363984370773`, 17.86046111375152], 
                Complex[133.72506063642794`, -4.01029726309017]}, 2 -> {
                Complex[163.63134125485357`, -18.004215870320166`], 
                Complex[133.6483850579582, -37.3460160901857]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -9.418443274210333}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31363984370773`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.86046111375152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72506063642794`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"4.01029726309017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63134125485357`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.004215870320166`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6483850579582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.3460160901857`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.4, "C", 
             Association[1 -> {
                Complex[163.31363984370773`, 17.86046111375152], 
                Complex[133.72506063642794`, -4.01029726309017]}, 2 -> {
                Complex[163.63134125485357`, -18.004215870320166`], 
                Complex[133.6483850579582, -37.3460160901857]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.5, -9.463899676183972}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31392703399072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.93330466832352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9443098592571175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63016664684008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.07712992966061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "C", 
             Association[1 -> {
                Complex[163.31392703399072`, 17.93330466832352], 
                Complex[133.72550560195975`, -3.9443098592571175`]}, 2 -> {
                Complex[163.63016664684008`, -18.07712992966061], 
                Complex[133.64522023907955`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -9.467408452338121}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31392703399072`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"17.93330466832352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72550560195975`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.9443098592571175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.63016664684008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.07712992966061`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64522023907955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.411507828356406`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.5, "C", 
             Association[1 -> {
                Complex[163.31392703399072`, 17.93330466832352], 
                Complex[133.72550560195975`, -3.9443098592571175`]}, 2 -> {
                Complex[163.63016664684008`, -18.07712992966061], 
                Complex[133.64522023907955`, -37.411507828356406`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -9.513078778595144}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31420517645438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.00549717041573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870841`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.878934695199984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62900770166812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31420517645438`, 18.00549717041573], 
                Complex[133.72593813870841`, -3.878934695199984]}, 2 -> {
                Complex[163.62900770166812`, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -9.516533022974468}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31420517645438`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.00549717041573`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72593813870841`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.878934695199984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62900770166812`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.14939239015977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.64207666243678`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.47638621333928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31420517645438`, 18.00549717041573], 
                Complex[133.72593813870841`, -3.878934695199984]}, 2 -> {
                Complex[163.62900770166812`, -18.14939239015977], 
                Complex[133.64207666243678`, -37.47638621333928]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -9.562414531281744}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3144745655963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.077050544896366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72635860132817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.814160476362023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62786403447276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.221015184158826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63895386837342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.54066255110091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3144745655963, 18.077050544896366`], 
                Complex[133.72635860132817`, -3.814160476362023]}, 2 -> {
                Complex[163.62786403447276`, -18.221015184158826`], 
                Complex[133.63895386837342`, -37.54066255110091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -9.565815629173109}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3144745655963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.077050544896366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72635860132817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.814160476362023`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62786403447276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.221015184158826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63895386837342`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.54066255110091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3144745655963, 18.077050544896366`], 
                Complex[133.72635860132817`, -3.814160476362023]}, 2 -> {
                Complex[163.62786403447276`, -18.221015184158826`], 
                Complex[133.63895386837342`, -37.54066255110091]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -9.611905649035476}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31473548397335`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.14797638433758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.749976223506348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62673527415205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.31473548397335`, 18.14797638433758], 
                Complex[133.72676733099715`, -3.749976223506348]}, 2 -> {
                Complex[163.62673527415205`, -18.292009911552334`], 
                Complex[133.6358514127178, -37.60434783208481]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -9.61525493723804}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31473548397335`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.14797638433758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72676733099715`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.749976223506348`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62673527415205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.292009911552334`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6358514127178`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.60434783208481`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.31473548397335`, 18.14797638433758], 
                Complex[133.72676733099715`, -3.749976223506348]}, 2 -> {
                Complex[163.62673527415205`, -18.292009911552334`], 
                Complex[133.6358514127178, -37.60434783208481]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -9.661550867161129}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31498820279393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62562106272594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63276886608713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.31498820279393`, 18.21828596147894], 
                Complex[133.72716465606138`, -3.686371260886986]}, 2 -> {
                Complex[163.62562106272594`, -18.362387852255672`], 
                Complex[133.63276886608713`, -37.66745274304553]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -9.664849636137967}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31498820279393`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.21828596147894`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72716465606138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.686371260886986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62562106272594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.362387852255672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.63276886608713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.66745274304553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.31498820279393`, 18.21828596147894], 
                Complex[133.72716465606138`, -3.686371260886986]}, 2 -> {
                Complex[163.62562106272594`, -18.362387852255672`], 
                Complex[133.63276886608713`, -37.66745274304553]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -9.71134894102546}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3152329824754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.28799024110279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.62333520497781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62452105473145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.43215997808431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322924`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.729987678324505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.3152329824754, 18.28799024110279], 
                Complex[133.7275508926416, -3.62333520497781]}, 2 -> {
                Complex[163.62452105473145`, -18.43215997808431], 
                Complex[133.62970581322924`, -37.729987678324505`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -9.714598436939959}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3152329824754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.28799024110279`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7275508926416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.62333520497781`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62452105473145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.43215997808431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62970581322924`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.729987678324505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.3152329824754, 18.28799024110279], 
                Complex[133.7275508926416, -3.62333520497781]}, 2 -> {
                Complex[163.62452105473145`, -18.43215997808431], 
                Complex[133.62970581322924`, -37.729987678324505`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -9.7612986456174}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3154700731691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.35709989135509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7279263452058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.5608579537275773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6234349166525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.501336964078423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.791962750599865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.3154700731691, 18.35709989135509], 
                Complex[133.7279263452058, -3.5608579537275773`]}, 2 -> {
                Complex[163.6234349166525, -18.501336964078423`], 
                Complex[133.62666185240195`, -37.791962750599865`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -9.764500072261637}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3154700731691`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.35709989135509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7279263452058`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.5608579537275773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6234349166525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.501336964078423`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62666185240195`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.791962750599865`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 
             Association[1 -> {
                Complex[163.3154700731691, 18.35709989135509], 
                Complex[133.7279263452058, -3.5608579537275773`]}, 2 -> {
                Complex[163.6234349166525, -18.501336964078423`], 
                Complex[133.62666185240195`, -37.791962750599865`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -9.811398775119251}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31569971525462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6223623263809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.569929199304017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.31569971525462`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[163.6223623263809, -18.569929199304017`], 
                Complex[133.62363659478487`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -9.81455329574104}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31569971525462`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.425625294542865`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72829130710898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.4989296763115263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6223623263809`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.569929199304017`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.62363659478487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.85338780113949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.31569971525462`, 18.425625294542865`], 
                Complex[133.72829130710898`, -3.4989296763115263`]}, 2 -> {
                Complex[163.6223623263809, -18.569929199304017`], 
                Complex[133.62363659478487`, -37.85338780113949]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -9.861648142488738}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31592213980636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6213029727077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.63794679715963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.620629663924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.31592213980636`, 18.493576557437454`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[163.6213029727077, -18.63794679715963], 
                Complex[133.620629663924, -37.91427240958484]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -9.86475688152358}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31592213980636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.493576557437454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7286460611034`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.4375408033518298`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6213029727077`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.63794679715963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.620629663924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"37.91427240958484`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.31592213980636`, 18.493576557437454`], 
                Complex[133.7286460611034, -3.4375408033518298`]}, 2 -> {
                Complex[163.6213029727077, -18.63794679715963], 
                Complex[133.620629663924, -37.91427240958484]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.4, -9.912045579051615}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31613756903312`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.56096352111073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62025655484186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.705399605215987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61764069520532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "C", 
             Association[1 -> {
                Complex[163.31613756903312`, 18.56096352111073], 
                Complex[133.72899087982017`, -3.376682017581235]}, 2 -> {
                Complex[163.62025655484186`, -18.705399605215987`], 
                Complex[133.61764069520532`, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -9.915109623765318}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31613756903312`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.56096352111073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72899087982017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.376682017581235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.62025655484186`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.705399605215987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61764069520532`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"37.974625903291766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.4, "C", 
             Association[1 -> {
                Complex[163.31613756903312`, 18.56096352111073], 
                Complex[133.72899087982017`, -3.376682017581235]}, 2 -> {
                Complex[163.62025655484186`, -18.705399605215987`], 
                Complex[133.61764069520532`, -37.974625903291766`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.5, -9.96258993410461}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3163462166933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.627795770329765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61922278195527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61466933535638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.03445736625228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "C", 
             Association[1 -> {
                Complex[163.3163462166933, 18.627795770329765`], 
                Complex[133.72932602622453`, -3.316344244925613]}, 2 -> {
                Complex[163.61922278195527`, -18.772297214614134`], 
                Complex[133.61466933535638`, -38.03445736625228]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -9.965610336151979}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3163462166933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.627795770329765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72932602622453`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.316344244925613`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61922278195527`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.772297214614134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61466933535638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.03445736625228`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.5, "C", 
             Association[1 -> {
                Complex[163.3163462166933, 18.627795770329765`], 
                Complex[133.72932602622453`, -3.316344244925613]}, 2 -> {
                Complex[163.61922278195527`, -18.772297214614134`], 
                Complex[133.61466933535638`, -38.03445736625228]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -10.013280074528467`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31654828848707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.694082642534067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7296517540468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61820137275217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.09377564761935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31654828848707`, 18.694082642534067`], 
                Complex[133.7296517540468, -3.25651864598262]}, 2 -> {
                Complex[163.61820137275217`, -18.838648969045266`], 
                Complex[133.61171524197408`, -38.09377564761935]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -10.016257851433062`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31654828848707`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.694082642534067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7296517540468`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.25651864598262`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61820137275217`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.838648969045266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.61171524197408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.09377564761935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31654828848707`, 18.694082642534067`], 
                Complex[133.7296517540468, -3.25651864598262]}, 2 -> {
                Complex[163.61820137275217`, -18.838648969045266`], 
                Complex[133.61171524197408`, -38.09377564761935]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -10.064114884410836`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31674398242674`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.197196607875771`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61719205506083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6087780830763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.152589369857864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.31674398242674`, 18.75983323641723], 
                Complex[133.72996830818994`, -3.197196607875771]}, 2 -> {
                Complex[163.61719205506083`, -18.904463973336576`], 
                Complex[133.6087780830763, -38.152589369857864`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -10.067051020970485`}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31674398242674`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.75983323641723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.72996830818994`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.197196607875771`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61719205506083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"18.904463973336576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.6087780830763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.152589369857864`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.31674398242674`, 18.75983323641723], 
                Complex[133.72996830818994`, -3.197196607875771]}, 2 -> {
                Complex[163.61719205506083`, -18.904463973336576`], 
                Complex[133.6087780830763, -38.152589369857864`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -10.115093264678798`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31693348918697`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.82505642013447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138369736463453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6161945654476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.969751101660396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.31693348918697`, 18.82505642013447], 
                Complex[133.73027592511528`, -3.138369736463453]}, 2 -> {
                Complex[163.6161945654476, -18.969751101660396`], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -10.11798871430121}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31693348918697`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.82505642013447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73027592511528`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.138369736463453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6161945654476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"18.969751101660396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60585753667738`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.210906936538066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 
             Association[1 -> {
                Complex[163.31693348918697`, 18.82505642013447], 
                Complex[133.73027592511528`, -3.138369736463453]}, 2 -> {
                Complex[163.6161945654476, -18.969751101660396`], 
                Complex[133.60585753667738`, -38.210906936538066`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.9, -10.166214132740722`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31711699243615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.88976083915551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.080029848884582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61520864885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.034519005391328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.26873653979493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "C", 
             Association[1 -> {
                Complex[163.31711699243615`, 18.88976083915551], 
                Complex[133.73057483320838`, -3.080029848884582]}, 2 -> {
                Complex[163.61520864885, -19.034519005391328`], 
                Complex[133.60295329038402`, -38.26873653979493]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -10.169069818713254`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31711699243615`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"18.88976083915551`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73057483320838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"3.080029848884582`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61520864885`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.034519005391328`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60295329038402`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.26873653979493`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.9, "C", 
             Association[1 -> {
                Complex[163.31711699243615`, 18.88976083915551], 
                Complex[133.73057483320838`, -3.080029848884582]}, 2 -> {
                Complex[163.61520864885, -19.034519005391328`], 
                Complex[133.60295329038402`, -38.26873653979493]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -10.21747642213731}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31729466915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.953954923781044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61423405822947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.09877612062455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.32608616746591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 
             Association[1 -> {
                Complex[163.31729466915, 18.953954923781044`], 
                Complex[133.7308652531255, -3.0221689664234717`]}, 2 -> {
                Complex[163.61423405822947`, -19.09877612062455], 
                Complex[133.60006504101256`, -38.32608616746591]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -10.220293238834703`}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31729466915`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"18.953954923781044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7308652531255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"3.0221689664234717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61423405822947`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.09877612062455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.60006504101256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.32608616746591`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 
             Association[1 -> {
                Complex[163.31729466915, 18.953954923781044`], 
                Complex[133.7308652531255, -3.0221689664234717`]}, 2 -> {
                Complex[163.61423405822947`, -19.09877612062455], 
                Complex[133.60006504101256`, -38.32608616746591]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -10.268879082201513`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31746668990834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.017646896340647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9647793076770235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61327055424135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.16253067537683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.31746668990834`, 19.017646896340647`], 
                Complex[133.73114739812223`, -2.9647793076770235`]}, 2 -> {
                Complex[163.61327055424135`, -19.16253067537683], 
                Complex[133.59719249422423`, -38.38296360992766]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -10.271657896235133`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31746668990834`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.017646896340647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73114739812223`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.9647793076770235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.61327055424135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.16253067537683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59719249422423`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.38296360992766`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.31746668990834`, 19.017646896340647`], 
                Complex[133.73114739812223`, -2.9647793076770235`]}, 2 -> {
                Complex[163.61327055424135`, -19.16253067537683], 
                Complex[133.59719249422423`, -38.38296360992766]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -10.320421077727106`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3176332191766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.080844778087723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.90785328200948`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6123179049217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.225790696484122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.4393764666446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.3176332191766, 19.080844778087723`], 
                Complex[133.73142147436542`, -2.90785328200948]}, 2 -> {
                Complex[163.6123179049217, -19.225790696484122`], 
                Complex[133.59433536417916`, -38.4393764666446]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -10.323162729038982`}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3176332191766`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.080844778087723`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73142147436542`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.90785328200948`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6123179049217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.225790696484122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59433536417916`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.4393764666446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.3176332191766, 19.080844778087723`], 
                Complex[133.73142147436542`, -2.90785328200948]}, 2 -> {
                Complex[163.6123179049217, -19.225790696484122`], 
                Complex[133.59433536417916`, -38.4393764666446]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -10.372101388645751`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31779441557222`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.14355639580752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6113758853897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.31779441557222`, 19.14355639580752], 
                Complex[133.73168768122898`, -2.8513834832794664`]}, 2 -> {
                Complex[163.6113758853897, -19.288564016212078`], 
                Complex[133.59149337320662`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -10.374806691550548`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31779441557222`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.14355639580752`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73168768122898`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.8513834832794664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6113758853897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.288564016212078`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.59149337320662`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.49533215244521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 
             Association[1 -> {
                Complex[163.31779441557222`, 19.14355639580752], 
                Complex[133.73168768122898`, -2.8513834832794664`]}, 2 -> {
                Complex[163.6113758853897, -19.288564016212078`], 
                Complex[133.59149337320662`, -38.49533215244521]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.4, -10.42391900971221}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31795043211764`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.20578938815203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7953626838262657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6104442775649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.35085827859341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "C", 
             Association[1 -> {
                Complex[163.31795043211764`, 19.20578938815203], 
                Complex[133.73194621157515`, -2.7953626838262657`]}, 2 -> {
                Complex[163.6104442775649, -19.35085827859341], 
                Complex[133.58866625149176`, -38.55083790353876]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -10.426588753890007`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31795043211764`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.20578938815203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73194621157515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7953626838262657`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6104442775649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.35085827859341`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58866625149176`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.55083790353876`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.4, "C", 
             Association[1 -> {
                Complex[163.31795043211764`, 19.20578938815203], 
                Complex[133.73194621157515`, -2.7953626838262657`]}, 2 -> {
                Complex[163.6104442775649, -19.35085827859341], 
                Complex[133.58866625149176`, -38.55083790353876]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -10.47587295019762}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31810141648003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.26755121171575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287020946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60952286989846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.605900783286515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.31810141648003`, 19.26755121171575], 
                Complex[133.73219725202154`, -2.7397838287020946`]}, 2 -> {
                Complex[163.60952286989846`, -19.41268094550624], 
                Complex[133.58585373677684`, -38.605900783286515`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -10.478507901640203`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31810141648003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.26755121171575`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73219725202154`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.7397838287020946`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60952286989846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.41268094550624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58585373677684`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.605900783286515`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 
             Association[1 -> {
                Complex[163.31810141648003`, 19.26755121171575], 
                Complex[133.73219725202154`, -2.7397838287020946`]}, 2 -> {
                Complex[163.60952286989846`, -19.41268094550624], 
                Complex[133.58585373677684`, -38.605900783286515`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -10.527962233590497`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31824751119916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6846400301384143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60861145711593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.6605276877375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31824751119916`, 19.328849146864805`], 
                Complex[133.73244098319515`, -2.6846400301384143`]}, 2 -> {
                Complex[163.60861145711593`, -19.47403930250476], 
                Complex[133.58305557407584`, -38.6605276877375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -10.530563135503742`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31824751119916`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.328849146864805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73244098319515`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.6846400301384143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60861145711593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.47403930250476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58305557407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.6605276877375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 
             Association[1 -> {
                Complex[163.31824751119916`, 19.328849146864805`], 
                Complex[133.73244098319515`, -2.6846400301384143`]}, 2 -> {
                Complex[163.60861145711593`, -19.47403930250476], 
                Complex[133.58305557407584`, -38.6605276877375]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.7, -10.58018589730535}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31838885390343`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7326775799737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60770983997617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.53494046441777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.71472535094414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "C", 
             Association[1 -> {
                Complex[163.31838885390343`, 19.389690303331637`], 
                Complex[133.7326775799737, -2.6299245622347733`]}, 2 -> {
                Complex[163.60770983997617`, -19.53494046441777], 
                Complex[133.58027151540554`, -38.71472535094414]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -10.582753470970054`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31838885390343`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.389690303331637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7326775799737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.6299245622347733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60770983997617`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.53494046441777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.58027151540554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.71472535094414`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.7, "C", 
             Association[1 -> {
                Complex[163.31838885390343`, 19.389690303331637`], 
                Complex[133.7326775799737, -2.6299245622347733`]}, 2 -> {
                Complex[163.60770983997617`, -19.53494046441777], 
                Complex[133.58027151540554`, -38.71472535094414]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.8, -10.632542992398594`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31852557751546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60681782503693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.59539138072089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "C", 
             Association[1 -> {
                Complex[163.31852557751546`, 19.45008162558661], 
                Complex[133.73290721171557`, -2.5756308558594796`]}, 2 -> {
                Complex[163.60681782503693`, -19.59539138072089], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -10.635077937992007`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31852557751546`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.45008162558661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73290721171557`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.5756308558594796`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60681782503693`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.59539138072089`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57750131952452`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.76850035006301`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.8, "C", 
             Association[1 -> {
                Complex[163.31852557751546`, 19.45008162558661], 
                Complex[133.73290721171557`, -2.5756308558594796`]}, 2 -> {
                Complex[163.60681782503693`, -19.59539138072089], 
                Complex[133.57750131952452`, -38.76850035006301]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -10.685032583291713`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3186578104471`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.510029897997104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.521752493751901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60593522443511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.65539884069858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.821859110255915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.3186578104471, 19.510029897997104`], 
                Complex[133.73313004247825`, -2.521752493751901]}, 2 -> {
                Complex[163.60593522443511`, -19.65539884069858], 
                Complex[133.57474475168777`, -38.821859110255915`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -10.687535580671852`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3186578104471`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.510029897997104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73313004247825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.521752493751901`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60593522443511`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.65539884069858`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57474475168777`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.821859110255915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 
             Association[1 -> {
                Complex[163.3186578104471, 19.510029897997104`], 
                Complex[133.73313004247825`, -2.521752493751901]}, 2 -> {
                Complex[163.60593522443511`, -19.65539884069858], 
                Complex[133.57474475168777`, -38.821859110255915`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -10.737653747501296`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31878567678518`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.56954174978439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.468283205816789`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6050618556758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.71496947840288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.31878567678518`, 19.56954174978439], 
                Complex[133.73334623122685`, -2.468283205816789]}, 2 -> {
                Complex[163.6050618556758, -19.71496947840288], 
                Complex[133.57200158341104`, -38.87480790939813]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -10.740125456956026`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31878567678518`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.56954174978439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73334623122685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.468283205816789`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6050618556758`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.71496947840288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.57200158341104`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.87480790939813`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 
             Association[1 -> {
                Complex[163.31878567678518`, 19.56954174978439], 
                Complex[133.73334623122685`, -2.468283205816789]}, 2 -> {
                Complex[163.6050618556758, -19.71496947840288], 
                Complex[133.57200158341104`, -38.87480790939813]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -10.790405575375866`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3189092964682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.628623659787667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73355593203246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.415216864601611`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60419754143146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3189092964682, 19.628623659787667`], 
                Complex[133.73355593203246`, -2.415216864601611]}, 2 -> {
                Complex[163.60419754143146`, -19.774109777419557`], 
                Complex[133.5692715922459, -38.92735288260375]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -10.792846638338625`}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3189092964682`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"19.628623659787667`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73355593203246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.415216864601611`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60419754143146`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.774109777419557`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5692715922459`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"38.92735288260375`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3189092964682, 19.628623659787667`], 
                Complex[133.73355593203246`, -2.415216864601611]}, 2 -> {
                Complex[163.60419754143146`, -19.774109777419557`], 
                Complex[133.5692715922459, -38.92735288260375]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -10.843287169839327`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31902878545432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.362547480948237`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6033421093502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.832826075450342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.979500026576446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.31902878545432`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.362547480948237]}, 2 -> {
                Complex[163.6033421093502, -19.832826075450342`], 
                Complex[133.56655456156514`, -38.979500026576446`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -10.845698209573142`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31902878545432`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.687281961044494`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73375929426132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.362547480948237`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.6033421093502`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"19.832826075450342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56655456156514`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"38.979500026576446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.31902878545432`, 19.687281961044494`], 
                Complex[133.73375929426132`, -2.362547480948237]}, 2 -> {
                Complex[163.6033421093502, -19.832826075450342`], 
                Complex[133.56655456156514`, -38.979500026576446`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.3, -10.896297646140754`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31914425588116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3102691998110743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60249539187296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "C", 
             Association[1 -> {
                Complex[163.31914425588116`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.3102691998110743`]}, 2 -> {
                Complex[163.60249539187296`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -10.898679268392321`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31914425588116`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.74552284519583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73395646275486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.3102691998110743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60249539187296`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.891124568720002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5638502803574`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.03125520379385`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.3, "C", 
             Association[1 -> {
                Complex[163.31914425588116`, 19.74552284519583], 
                Complex[133.73395646275486`, -2.3102691998110743`]}, 2 -> {
                Complex[163.60249539187296`, -19.891124568720002`], 
                Complex[133.5638502803574, -39.03125520379385]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.4, -10.94943613161043}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31925581621843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.80335236672411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60165722605888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.94901131621615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "C", 
             Association[1 -> {
                Complex[163.31925581621843`, 19.80335236672411], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[163.60165722605888`, -19.94901131621615], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -10.951788925235686`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31925581621843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.80335236672411`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73414757800202`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2583762962337417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60165722605888`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"19.94901131621615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.56115854303107`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.08262414653326`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.4, "C", 
             Association[1 -> {
                Complex[163.31925581621843`, 19.80335236672411], 
                Complex[133.73414757800202`, -2.2583762962337417`]}, 2 -> {
                Complex[163.60165722605888`, -19.94901131621615], 
                Complex[133.56115854303107`, -39.08262414653326]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -11.0027017654219}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31936357141305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.860776447031697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.206863171477252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60082745341847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.00649224376953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55847914922663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 
             Association[1 -> {
                Complex[163.31936357141305`, 19.860776447031697`], 
                Complex[133.73433277630326`, -2.206863171477252]}, 2 -> {
                Complex[163.60082745341847`, -20.00649224376953], 
                Complex[133.55847914922663`, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -11.005026302984596`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31936357141305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.860776447031697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73433277630326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.206863171477252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60082745341847`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.00649224376953`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55847914922663`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.133612460745795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 
             Association[1 -> {
                Complex[163.31936357141305`, 19.860776447031697`], 
                Complex[133.73433277630326`, -2.206863171477252]}, 2 -> {
                Complex[163.60082745341847`, -20.00649224376953], 
                Complex[133.55847914922663`, -39.133612460745795`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -11.056093698359952`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31946762302746`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.91780087836711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60000591975424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.06357314798203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.31946762302746`, 19.91780087836711], 
                Complex[133.73451218992716`, -2.155724349292754]}, 2 -> {
                Complex[163.60000591975424`, -20.06357314798203], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -11.058390536704572`}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31946762302746`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.91780087836711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73451218992716`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.155724349292754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.60000591975424`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.06357314798203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55581190363702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.18422562978594`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.31946762302746`, 19.91780087836711], 
                Complex[133.73451218992716`, -2.155724349292754]}, 2 -> {
                Complex[163.60000591975424`, -20.06357314798203], 
                Complex[133.55581190363702`, -39.18422562978594]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -11.109611092594234`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31956806937163`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59919247500852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.12025970000922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800312`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.31956806937163`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[163.59919247500852`, -20.12025970000922], 
                Complex[133.55315661583612`, -39.23446901800312]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -11.11188077339453}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31956806937163`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"19.97443132760581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73468594726006`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.104954472332331`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59919247500852`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.12025970000922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55315661583612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.23446901800312`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.31956806937163`, 19.97443132760581], 
                Complex[133.73468594726006`, -2.104954472332331]}, 2 -> {
                Complex[163.59919247500852`, -20.12025970000922], 
                Complex[133.55315661583612`, -39.23446901800312]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.8, -11.163253121458467`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.319665005629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.030673339891987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7348541729491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0545482986917456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59838697311696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "C", 
             Association[1 -> {
                Complex[163.319665005629, 20.030673339891987`], 
                Complex[133.7348541729491, -2.0545482986917456`]}, 2 -> {
                Complex[163.59838697311696`, -20.176557449202846`], 
                Complex[133.55051310011325`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -11.165496171742873`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.319665005629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.030673339891987`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7348541729491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0545482986917456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59838697311696`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.176557449202846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.55051310011325`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.28434787420011`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.8, "C", 
             Association[1 -> {
                Complex[163.319665005629, 20.030673339891987`], 
                Complex[133.7348541729491, -2.0545482986917456`]}, 2 -> {
                Complex[163.59838697311696`, -20.176557449202846`], 
                Complex[133.55051310011325`, -39.28434787420011]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{32.9, -11.217018969235063`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31975852397647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7350169880388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.00450069857931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5975892718708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232471826623705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "C", 
             Association[1 -> {
                Complex[163.31975852397647`, 20.086532342147553`], 
                Complex[133.7350169880388, -2.00450069857931]}, 2 -> {
                Complex[163.5975892718708, -20.232471826623705`], 
                Complex[133.54788117531726`, -39.333867334968495`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -11.219235901890078`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31975852397647`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.086532342147553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7350169880388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.00450069857931`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5975892718708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.232471826623705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54788117531726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.333867334968495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {32.9, "C", 
             Association[1 -> {
                Complex[163.31975852397647`, 20.086532342147553`], 
                Complex[133.7350169880388, -2.00450069857931]}, 2 -> {
                Complex[163.5975892718708, -20.232471826623705`], 
                Complex[133.54788117531726`, -39.333867334968495`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33., -11.270907830944946`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31984871369912`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73517451010144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59679923278136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54526066470336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "C", 
             Association[1 -> {
                Complex[163.31984871369912`, 20.14201364645422], 
                Complex[133.73517451010144`, -1.9548066511051871`]}, 2 -> {
                Complex[163.59679923278136`, -20.288008148422218`], 
                Complex[133.54526066470336`, -39.3830324278985]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33., -11.273099145197596`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.31984871369912`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.14201364645422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73517451010144`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9548066511051871`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59679923278136`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.288008148422218`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54526066470336`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.3830324278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33., "C", 
             Association[1 -> {
                Complex[163.31984871369912`, 20.14201364645422], 
                Complex[133.73517451010144`, -1.9548066511051871`]}, 2 -> {
                Complex[163.59679923278136`, -20.288008148422218`], 
                Complex[133.54526066470336`, -39.3830324278985]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -11.324918912142481`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3199356612996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.197122453313998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9054612411862166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59601672095425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3199356612996, 20.197122453313998`], 
                Complex[133.73532685336215`, -1.9054612411862166`]}, 2 -> {
                Complex[163.59601672095425`, -20.343171619103263`], 
                Complex[133.54265139579022`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -11.327085094022861`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3199356612996`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.197122453313998`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73532685336215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9054612411862166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59601672095425`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.343171619103263`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54265139579022`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.43184807467881`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3199356612996, 20.197122453313998`], 
                Complex[133.73532685336215`, -1.9054612411862166`]}, 2 -> {
                Complex[163.59601672095425`, -20.343171619103263`], 
                Complex[133.54265139579022`, -39.43184807467881]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -11.37905142871539}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320019450603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59524160496576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.397967334670057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.480319094081715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.320019450603, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608618`]}, 2 -> {
                Complex[163.59524160496576`, -20.397967334670057`], 
                Complex[133.54005320021986`, -39.480319094081715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -11.381192951500276`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320019450603`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.251863854793616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73547412881845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8564596565608618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59524160496576`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.397967334670057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.54005320021986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.480319094081715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.320019450603, 20.251863854793616`], 
                Complex[133.73547412881845`, -1.8564596565608618`]}, 2 -> {
                Complex[163.59524160496576`, -20.397967334670057`], 
                Complex[133.54005320021986`, -39.480319094081715`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.3, -11.43330460668943}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32010016285645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.3062428375576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849099015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59447375674608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.45240028565977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "C", 
             Association[1 -> {
                Complex[163.32010016285645`, 20.3062428375576], 
                Complex[133.73561644435446`, -1.8077971849099015`]}, 2 -> {
                Complex[163.59447375674608`, -20.45240028565977], 
                Complex[133.53746591362483`, -39.52845020484526]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -11.435421931327825`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32010016285645`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.3062428375576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73561644435446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8077971849099015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59447375674608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.45240028565977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53746591362483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.52845020484526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.3, "C", 
             Association[1 -> {
                Complex[163.32010016285645`, 20.3062428375576], 
                Complex[133.73561644435446`, -1.8077971849099015`]}, 2 -> {
                Complex[163.59447375674608`, -20.45240028565977], 
                Complex[133.53746591362483`, -39.52845020484526]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -11.487677682037804`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32017787682477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5937130514674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.506475360070965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.576246028452815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 
             Association[1 -> {
                Complex[163.32017787682477`, 20.360264285794972`], 
                Complex[133.73575390485036`, -1.7594692110781658`]}, 2 -> {
                Complex[163.5937130514674, -20.506475360070965`], 
                Complex[133.53488937550074`, -39.576246028452815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -11.48977125755933}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32017787682477`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.360264285794972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73575390485036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7594692110781658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5937130514674`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.506475360070965`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53488937550074`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.576246028452815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 
             Association[1 -> {
                Complex[163.32017787682477`, 20.360264285794972`], 
                Complex[133.73575390485036`, -1.7594692110781658`]}, 2 -> {
                Complex[163.5937130514674, -20.506475360070965`], 
                Complex[133.53488937550074`, -39.576246028452815`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -11.542169900495074`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320252668882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5929593674352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.5601973461902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.6237110918168`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 
             Association[1 -> {
                Complex[163.320252668882, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931463`]}, 2 -> {
                Complex[163.5929593674352, -20.5601973461902], 
                Complex[133.53232342908268`, -39.6237110918168]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -11.544240164401966`}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.320252668882`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.413932984043882`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7358866122874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7114712143931463`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5929593674352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.5601973461902`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.53232342908268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.6237110918168`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 
             Association[1 -> {
                Complex[163.320252668882, 20.413932984043882`], 
                Complex[133.7358866122874, -1.7114712143931463`]}, 2 -> {
                Complex[163.5929593674352, -20.5601973461902], 
                Complex[133.53232342908268`, -39.6237110918168]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -11.596780517375539`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32032461309848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59221258598674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52976792122885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32032461309848`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763436`]}, 2 -> {
                Complex[163.59221258598674`, -20.613570935319654`], 
                Complex[133.52976792122885`, -39.67084982986853]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -11.598827896019063`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32032461309848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.467253619918555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73601466584807`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6637987660763436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59221258598674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.613570935319654`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52976792122885`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.67084982986853`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32032461309848`, 20.467253619918555`], 
                Complex[133.73601466584807`, -1.6637987660763436`]}, 2 -> {
                Complex[163.59221258598674`, -20.613570935319654`], 
                Complex[133.52976792122885`, -39.67084982986853]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -11.651508797395898`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32039378132473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73613816201268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59147259138922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.666600724412163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658805997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32039378132473`, 20.52023078674261], 
                Complex[133.73613816201268`, -1.6164475267435492`]}, 2 -> {
                Complex[163.59147259138922`, -20.666600724412163`], 
                Complex[133.527222702305, -39.71766658805997]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -11.653533706337887`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32039378132473`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.52023078674261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73613816201268`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6164475267435492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59147259138922`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.666600724412163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.527222702305`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.71766658805997`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32039378132473`, 20.52023078674261], 
                Complex[133.73613816201268`, -1.6164475267435492`]}, 2 -> {
                Complex[163.59147259138922`, -20.666600724412163`], 
                Complex[133.527222702305, -39.71766658805997]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.8, -11.706354014502075`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32046024327133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59073927074817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.71929121861588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5246876260788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.76416562477979`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "C", 
             Association[1 -> {
                Complex[163.32046024327133`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[163.59073927074817`, -20.71929121861588], 
                Complex[133.5246876260788, -39.76416562477979]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -11.708356858862263`}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32046024327133`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.57286898609253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7362571946514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5694132439904322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59073927074817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.71929121861588`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.5246876260788`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"39.76416562477979`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.8, "C", 
             Association[1 -> {
                Complex[163.32046024327133`, 20.57286898609253], 
                Complex[133.7362571946514, -1.5694132439904322`]}, 2 -> {
                Complex[163.59073927074817`, -20.71929121861588], 
                Complex[133.5246876260788, -39.76416562477979]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{33.9, -11.761315451700147`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3205240665855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.625172630255136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59001251391317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "C", 
             Association[1 -> {
                Complex[163.3205240665855, 20.625172630255136`], 
                Complex[133.73637185511262`, -1.5226917500597743`]}, 2 -> {
                Complex[163.59001251391317`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -11.763296626489993`}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3205240665855`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.625172630255136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73637185511262`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5226917500597743`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.59001251391317`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.771646833732525`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.52216254961237`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.81035111368739`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {33.9, "C", 
             Association[1 -> {
                Complex[163.3205240665855, 20.625172630255136`], 
                Complex[133.73637185511262`, -1.5226917500597743`]}, 2 -> {
                Complex[163.59001251391317`, -20.771646833732525`], 
                Complex[133.52216254961237`, -39.81035111368739]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34., -11.816392400891218`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32058531692476`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.677146044602367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7364822323083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4762789595872228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58929221339187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.823671898594245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51964733316362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.856227145969456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "C", 
             Association[1 -> {
                Complex[163.32058531692476`, 20.677146044602367`], 
                Complex[133.7364822323083, -1.4762789595872228`]}, 2 -> {
                Complex[163.58929221339187`, -20.823671898594245`], 
                Complex[133.51964733316362`, -39.856227145969456`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34., -11.818352291334797`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32058531692476`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.677146044602367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7364822323083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4762789595872228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58929221339187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.823671898594245`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51964733316362`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.856227145969456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34., "C", 
             Association[1 -> {
                Complex[163.32058531692476`, 20.677146044602367`], 
                Complex[133.7364822323083, -1.4762789595872228`]}, 2 -> {
                Complex[163.58929221339187`, -20.823671898594245`], 
                Complex[133.51964733316362`, -39.856227145969456`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.1, -11.871584162710102`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3206440580269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.728793469886885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58857826426507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.875370657359298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51714184008853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.901797732519626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "C", 
             Association[1 -> {
                Complex[163.3206440580269, 20.728793469886885`], 
                Complex[133.7365884127948, -1.4301708674222517`]}, 2 -> {
                Complex[163.58857826426507`, -20.875370657359298`], 
                Complex[133.51714184008853`, -39.901797732519626`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -11.873523144552676`}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3206440580269`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.728793469886885`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7365884127948`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4301708674222517`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58857826426507`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.875370657359298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51714184008853`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.901797732519626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.1, "C", 
             Association[1 -> {
                Complex[163.3206440580269, 20.728793469886885`], 
                Complex[133.7365884127948, -1.4301708674222517`]}, 2 -> {
                Complex[163.58857826426507`, -20.875370657359298`], 
                Complex[133.51714184008853`, -39.901797732519626`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.2, -11.926890046367797`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32070035177745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.780119064461577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73669048085137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3843635465213247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5878705641061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.926747271733444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51464593674876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.9470668060475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "C", 
             Association[1 -> {
                Complex[163.32070035177745`, 20.780119064461577`], 
                Complex[133.73669048085137`, -1.3843635465213247`]}, 2 -> {
                Complex[163.5878705641061, -20.926747271733444`], 
                Complex[133.51464593674876`, -39.9470668060475]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -11.928808486172603`}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32070035177745`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.780119064461577`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73669048085137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.3843635465213247`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5878705641061`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"20.926747271733444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51464593674876`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.9470668060475`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.2, "C", 
             Association[1 -> {
                Complex[163.32070035177745`, 20.780119064461577`], 
                Complex[133.73669048085137`, -1.3843635465213247`]}, 2 -> {
                Complex[163.5878705641061, -20.926747271733444`], 
                Complex[133.51464593674876`, -39.9470668060475]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.3, -11.982309369497573`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32075425827455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3388531459104875`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58716901290316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51215949242192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.99203822311737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "C", 
             Association[1 -> {
                Complex[163.32075425827455`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.3388531459104875`]}, 2 -> {
                Complex[163.58716901290316`, -20.977805823117315`], 
                Complex[133.51215949242192`, -39.99203822311737]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -11.984207624931368`}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32075425827455`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.831126906426018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7367885185553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3388531459104875`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58716901290316`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"20.977805823117315`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.51215949242192`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"39.99203822311737`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.3, "C", 
             Association[1 -> {
                Complex[163.32075425827455`, 20.831126906426018`], 
                Complex[133.7367885185553, -1.3388531459104875`]}, 2 -> {
                Complex[163.58716901290316`, -20.977805823117315`], 
                Complex[133.51215949242192`, -39.99203822311737]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -12.037841458004586`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3208058358904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.881820995702782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58647351298407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.028550314683574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50968237921512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.03671576612024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 
             Association[1 -> {
                Complex[163.3208058358904, 20.881820995702782`], 
                Complex[133.73688260585354`, -1.293635888714526]}, 2 -> {
                Complex[163.58647351298407`, -21.028550314683574`], 
                Complex[133.50968237921512`, -40.03671576612024]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -12.039719878112422`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3208058358904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"20.881820995702782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73688260585354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.293635888714526`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58647351298407`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.028550314683574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50968237921512`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.03671576612024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 
             Association[1 -> {
                Complex[163.3208058358904, 20.881820995702782`], 
                Complex[133.73688260585354`, -1.293635888714526]}, 2 -> {
                Complex[163.58647351298407`, -21.028550314683574`], 
                Complex[133.50968237921512`, -40.03671576612024]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -12.093485645918978`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32085514133112`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73697282063236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.248708070250089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58578396894472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 
             Association[1 -> {
                Complex[163.32085514133112`, 20.9322052560464], 
                Complex[133.73697282063236`, -1.248708070250089]}, 2 -> {
                Complex[163.58578396894472`, -21.078984673387104`], 
                Complex[133.50721447198234`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -12.095344571388736`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32085514133112`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.9322052560464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73697282063236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.248708070250089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58578396894472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.078984673387104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50721447198234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.0811031451823`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 
             Association[1 -> {
                Complex[163.32085514133112`, 20.9322052560464], 
                Complex[133.73697282063236`, -1.248708070250089]}, 2 -> {
                Complex[163.58578396894472`, -21.078984673387104`], 
                Complex[133.50721447198234`, -40.0811031451823]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -12.14924127525225}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32090222969342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.982283536987506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5851002875799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.12911275191012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32090222969342`, 20.982283536987506`], 
                Complex[133.73705923878364`, -1.2040660561803698`]}, 2 -> {
                Complex[163.5851002875799, -21.12911275191012], 
                Complex[133.50475564824438`, -40.12520400001161]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -12.151081038669307`}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32090222969342`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"20.982283536987506`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73705923878364`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.2040660561803698`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5851002875799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.12911275191012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50475564824438`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.12520400001161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32090222969342`, 20.982283536987506`], 
                Complex[133.73705923878364`, -1.2040660561803698`]}, 2 -> {
                Complex[163.5851002875799, -21.12911275191012], 
                Complex[133.50475564824438`, -40.12520400001161]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -12.205107695856983`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32094715451944`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.03205961571474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58442237781642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32094715451944`, 21.03205961571474], 
                Complex[133.7371419342688, -1.1597062807288623`]}, 2 -> {
                Complex[163.58442237781642`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -12.206928621949514`}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32094715451944`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.03205961571474`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7371419342688`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597062807288623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58442237781642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.178938330545062`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.50230578811164`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.16902190168558`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32094715451944`, 21.03205961571474], 
                Complex[133.7371419342688, -1.1597062807288623`]}, 2 -> {
                Complex[163.58442237781642`, -21.178938330545062`], 
                Complex[133.50230578811164`, -40.16902190168558]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.8, -12.261084265289664`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32098996784921`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7372209791803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1156252449499178`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58375015064937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.228465119017653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "C", 
             Association[1 -> {
                Complex[163.32098996784921`, 21.081537198896875`], 
                Complex[133.7372209791803, -1.1156252449499178`]}, 2 -> {
                Complex[163.58375015064937`, -21.228465119017653`], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -12.262886671164939`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32098996784921`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.081537198896875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7372209791803`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1156252449499178`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58375015064937`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.228465119017653`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49986477421018`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.21256035438178`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.8, "C", 
             Association[1 -> {
                Complex[163.32098996784921`, 21.081537198896875`], 
                Complex[133.7372209791803, -1.1156252449499178`]}, 2 -> {
                Complex[163.58375015064937`, -21.228465119017653`], 
                Complex[133.49986477421018`, -40.21256035438178]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{34.9, -12.317170348676635`}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32103072027124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.13071992444728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5830835190799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "C", 
             Association[1 -> {
                Complex[163.32103072027124`, 21.13071992444728], 
                Complex[133.73729644380091`, -1.071819515054024]}, 2 -> {
                Complex[163.5830835190799, -21.277696758252304`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -12.3189545440487}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32103072027124`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.13071992444728`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73729644380091`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071819515054024`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5830835190799`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.277696758252304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4974324916098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.25582279705388`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {34.9, "C", 
             Association[1 -> {
                Complex[163.32103072027124`, 21.13071992444728], 
                Complex[133.73729644380091`, -1.071819515054024]}, 2 -> {
                Complex[163.5830835190799, -21.277696758252304`], 
                Complex[133.4974324916098, -40.25582279705388]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35., -12.373365318583007`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32106946097053`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58242239805642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "C", 
             Association[1 -> {
                Complex[163.32106946097053`, 21.179611363233054`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[163.58242239805642`, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35., -12.375131605992149`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32106946097053`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.179611363233054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73736839666017`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0282857207856466`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58242239805642`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.32663682208221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49500882775536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.29881260505506`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35., "C", 
             Association[1 -> {
                Complex[163.32106946097053`, 21.179611363233054`], 
                Complex[133.73736839666017`, -1.0282857207856466`]}, 2 -> {
                Complex[163.58242239805642`, -21.32663682208221], 
                Complex[133.49500882775536`, -40.29881260505506]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.1, -12.42966855488455}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32110623777564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58176670441676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.37528881890603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.341533091710815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "C", 
             Association[1 -> {
                Complex[163.32110623777564`, 21.228215020730886`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[163.58176670441676`, -21.37528881890603], 
                Complex[133.49259367239995`, -40.341533091710815`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -12.431417229908854`}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32110623777564`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.228215020730886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73743690458957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9850205538516192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58176670441676`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.37528881890603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49259367239995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.341533091710815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.1, "C", 
             Association[1 -> {
                Complex[163.32110623777564`, 21.228215020730886`], 
                Complex[133.73743690458957`, -0.9850205538516192]}, 2 -> {
                Complex[163.58176670441676`, -21.37528881890603], 
                Complex[133.49259367239995`, -40.341533091710815`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -12.48607944464236}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32114109720294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.27653433863163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58111635683326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.383987509842974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32114109720294`, 21.27653433863163], 
                Complex[133.73750203277484`, -0.9420207663983327]}, 2 -> {
                Complex[163.58111635683326`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.383987509842974`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -12.487810796101712`}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32114109720294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.27653433863163`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73750203277484`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9420207663983327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58111635683326`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.423656193293354`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.49018691754077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.383987509842974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32114109720294`, 21.27653433863163], 
                Complex[133.73750203277484`, -0.9420207663983327]}, 2 -> {
                Complex[163.58111635683326`, -21.423656193293354`], 
                Complex[133.49018691754077`, -40.383987509842974`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.3, -12.542597381980361`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3211740844998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.324572696395432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7375638448069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8992831695357282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58047127575952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.471742327540692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48778845735708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "C", 
             Association[1 -> {
                Complex[163.3211740844998, 21.324572696395432`], 
                Complex[133.7375638448069, -0.8992831695357282]}, 2 -> {
                Complex[163.58047127575952`, -21.471742327540692`], 
                Complex[133.48778845735708`, -40.4261790532468]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -12.544311692133219`}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3211740844998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.324572696395432`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7375638448069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8992831695357282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.58047127575952`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.471742327540692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48778845735708`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.4261790532468`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.3, "C", 
             Association[1 -> {
                Complex[163.3211740844998, 21.324572696395432`], 
                Complex[133.7375638448069, -0.8992831695357282]}, 2 -> {
                Complex[163.58047127575952`, -21.471742327540692`], 
                Complex[133.48778845735708`, -40.4261790532468]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.4, -12.599221767965476`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32120524368585`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57983138337912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.519550543179967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.46811085812299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "C", 
             Association[1 -> {
                Complex[163.32120524368585`, 21.372333412759414`], 
                Complex[133.73762240273044`, -0.8568046319064777]}, 2 -> {
                Complex[163.57983138337912`, -21.519550543179967`], 
                Complex[133.4853981881505, -40.46811085812299]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -12.600919312698695`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32120524368585`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.372333412759414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762240273044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8568046319064777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57983138337912`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.519550543179967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4853981881505`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.46811085812299`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.4, "C", 
             Association[1 -> {
                Complex[163.32120524368585`, 21.372333412759414`], 
                Complex[133.73762240273044`, -0.8568046319064777]}, 2 -> {
                Complex[163.57983138337912`, -21.519550543179967`], 
                Complex[133.4853981881505, -40.46811085812299]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -12.655952010490388`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32123461759284`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.419819747199476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73767776709124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8145820782986561`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57919660355603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.56708410244111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4830160082869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.50978600446605`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 
             Association[1 -> {
                Complex[163.32123461759284`, 21.419819747199476`], 
                Complex[133.73767776709124`, -0.8145820782986561]}, 2 -> {
                Complex[163.57919660355603`, -21.56708410244111], 
                Complex[133.4830160082869, -40.50978600446605]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -12.657633059502388`}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32123461759284`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.419819747199476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73767776709124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8145820782986561`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57919660355603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.56708410244111`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4830160082869`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.50978600446605`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 
             Association[1 -> {
                Complex[163.32123461759284`, 21.419819747199476`], 
                Complex[133.73767776709124`, -0.8145820782986561]}, 2 -> {
                Complex[163.57919660355603`, -21.56708410244111], 
                Complex[133.4830160082869, -40.50978600446605]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -12.712787524158928`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126224790258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.467034901348015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57856686178704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32126224790258`, 21.467034901348015`], 
                Complex[133.73772999698105`, -0.7726124883003074]}, 2 -> {
                Complex[163.57856686178704`, -21.61434620967065], 
                Complex[133.48064181814095`, -40.55120751741091]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -12.714452341136491`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126224790258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.467034901348015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73772999698105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7726124883003074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57856686178704`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.61434620967065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.48064181814095`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.55120751741091`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32126224790258`, 21.467034901348015`], 
                Complex[133.73772999698105`, -0.7726124883003074]}, 2 -> {
                Complex[163.57856686178704`, -21.61434620967065], 
                Complex[133.48064181814095`, -40.55120751741091]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -12.76972773017389}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128817518404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.513982020369067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944153`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57794208515563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.661340012707413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32128817518404`, 21.513982020369067`], 
                Complex[133.73777915008168`, -0.7308928949944153]}, 2 -> {
                Complex[163.57794208515563`, -21.661340012707413`], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -12.771376572962842`}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128817518404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.513982020369067`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73777915008168`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7308928949944153`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57794208515563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.661340012707413`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47827552004196`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.592378368538746`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32128817518404`, 21.513982020369067`], 
                Complex[133.73777915008168`, -0.7308928949944153]}, 2 -> {
                Complex[163.57794208515563`, -21.661340012707413`], 
                Complex[133.47827552004196`, -40.592378368538746`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.8, -12.826772056227314`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32131243892846`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5773222022874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.70806860421745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.63330147714419`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "C", 
             Association[1 -> {
                Complex[163.32131243892846`, 21.560664194292514`], 
                Complex[133.73782528270672`, -0.6894203836927915]}, 2 -> {
                Complex[163.5773222022874, -21.70806860421745], 
                Complex[133.47591701822174`, -40.63330147714419]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -12.828405176997304`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32131243892846`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.560664194292514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782528270672`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6894203836927915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5773222022874`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.70806860421745`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47591701822174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.63330147714419`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.8, "C", 
             Association[1 -> {
                Complex[163.32131243892846`, 21.560664194292514`], 
                Complex[133.73782528270672`, -0.6894203836927915]}, 2 -> {
                Complex[163.5773222022874, -21.70806860421745], 
                Complex[133.47591701822174`, -40.63330147714419]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.9, -12.883919936393088`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32133507758377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5767071433079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.67397971146615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "C", 
             Association[1 -> {
                Complex[163.32133507758377`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[163.5767071433079, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.67397971146615]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -12.885537581796784`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32133507758377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.60708445930873`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73786844984247`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6481920907074503`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5767071433079`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.754535022990805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47356621876492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.67397971146615`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.9, "C", 
             Association[1 -> {
                Complex[163.32133507758377`, 21.60708445930873], 
                Complex[133.73786844984247`, -0.6481920907074503]}, 2 -> {
                Complex[163.5767071433079, -21.754535022990805`], 
                Complex[133.47356621876492`, -40.67397971146615]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -12.941170811021891`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135612858696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57609683979973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.800742255195683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.714415889878296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32135612858696`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[163.57609683979973`, -21.800742255195683`], 
                Complex[133.47122302955884`, -40.714415889878296`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -12.942773222348714`}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135612858696`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.653245799025118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7379087051866`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6072052021582692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57609683979973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.800742255195683`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.47122302955884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.714415889878296`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32135612858696`, 21.653245799025118`], 
                Complex[133.7379087051866, -0.6072052021582692]}, 2 -> {
                Complex[163.57609683979973`, -21.800742255195683`], 
                Complex[133.47122302955884`, -40.714415889878296`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -12.998524126638355`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137562839594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5754912247639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.846693235601716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.754612782050174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.32137562839594`, 21.699151145685878`], 
                Complex[133.73794610118625`, -0.5664569528154928]}, 2 -> {
                Complex[163.5754912247639, -21.846693235601716`], 
                Complex[133.46888736024792`, -40.754612782050174`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -13.000111539963038`}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137562839594`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.699151145685878`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73794610118625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5664569528154928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5754912247639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"21.846693235601716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46888736024792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.754612782050174`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.32137562839594`, 21.699151145685878`], 
                Complex[133.73794610118625`, -0.5664569528154928]}, 2 -> {
                Complex[163.5754912247639, -21.846693235601716`], 
                Complex[133.46888736024792`, -40.754612782050174`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -13.055979335840428`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32139361252007`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758959`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57489023258069`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007123`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32139361252007`, 21.74480338135633], 
                Complex[133.73798068907436`, -0.5259446249758959]}, 2 -> {
                Complex[163.57489023258069`, -21.89239084876425], 
                Complex[133.46655912218745`, -40.79457311007123]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -13.057551982166574`}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32139361252007`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.74480338135633`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798068907436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5259446249758959`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57489023258069`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.89239084876425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46655912218745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.79457311007123`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32139361252007`, 21.74480338135633], 
                Complex[133.73798068907436`, -0.5259446249758959]}, 2 -> {
                Complex[163.57489023258069`, -21.89239084876425], 
                Complex[133.46655912218745`, -40.79457311007123]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.3, -13.113535897200816`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32141011554913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.79020533907295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57429379897212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4642382283995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.83429954954242`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "C", 
             Association[1 -> {
                Complex[163.32141011554913`, 21.79020533907295], 
                Complex[133.73801251890455`, -0.4856655473715783]}, 2 -> {
                Complex[163.57429379897212`, -21.937837930174453`], 
                Complex[133.4642382283995, -40.83429954954242]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -13.115094002599623`}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32141011554913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.79020533907295`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73801251890455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4856655473715783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57429379897212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.937837930174453`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4642382283995`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"40.83429954954242`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.3, "C", 
             Association[1 -> {
                Complex[163.32141011554913`, 21.79020533907295], 
                Complex[133.73801251890455`, -0.4856655473715783]}, 2 -> {
                Complex[163.57429379897212`, -21.937837930174453`], 
                Complex[133.4642382283995, -40.83429954954242]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.4, -13.17119327517058}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142517118197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57370186096605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "C", 
             Association[1 -> {
                Complex[163.32142517118197`, 21.835359803960376`], 
                Complex[133.73804163958545`, -0.4456170941100126]}, 2 -> {
                Complex[163.57370186096605`, -21.983037267377455`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -13.172737060914926`}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142517118197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.835359803960376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73804163958545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4456170941100126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57370186096605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"21.983037267377455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.46192459353048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.87379473063754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.4, "C", 
             Association[1 -> {
                Complex[163.32142517118197`, 21.835359803960376`], 
                Complex[133.73804163958545`, -0.4456170941100126]}, 2 -> {
                Complex[163.57370186096605`, -21.983037267377455`], 
                Complex[133.46192459353048`, -40.87379473063754]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.5, -13.228950939984676`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143881225352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836443967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57311435686128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.45961813380987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.913061239133484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "C", 
             Association[1 -> {
                Complex[163.32143881225352`, 21.880269514316595`], 
                Complex[133.73806809891312`, -0.4057966836443967]}, 2 -> {
                Complex[163.57311435686128`, -22.027991601058], 
                Complex[133.45961813380987`, -40.913061239133484`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -13.230480622678655`}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143881225352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.880269514316595`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806809891312`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4057966836443967`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57311435686128`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.027991601058`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"133.45961813380987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.913061239133484`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.5, "C", 
             Association[1 -> {
                Complex[163.32143881225352`, 21.880269514316595`], 
                Complex[133.73806809891312`, -0.4057966836443967]}, 2 -> {
                Complex[163.57311435686128`, -22.027991601058], 
                Complex[133.45961813380987`, -40.913061239133484`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.6, -13.286808367569506`}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145107076096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.924937162667188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360263`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.36620177777334817`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57253122619372`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.072703626095407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "C", 
             Association[1 -> {
                Complex[163.32145107076096`, 21.924937162667188`], 
                Complex[133.73809194360263`, -0.36620177777334817`]}, 2 -> {
                Complex[163.57253122619372`, -22.072703626095407`], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -13.2883241592735}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145107076096`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"21.924937162667188`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73809194360263`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36620177777334817`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57253122619372`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.072703626095407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45731876701024`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.95210161741164`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.6, "C", 
             Association[1 -> {
                Complex[163.32145107076096`, 21.924937162667188`], 
                Complex[133.73809194360263`, -0.36620177777334817`]}, 2 -> {
                Complex[163.57253122619372`, -22.072703626095407`], 
                Complex[133.45731876701024`, -40.95210161741164]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -13.344765039452378`}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214619778895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.96936539678994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73811321931896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3268298806687504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5719524097037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.117175992588685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3214619778895, 21.96936539678994], 
                Complex[133.73811321931896`, -0.3268298806687504]}, 2 -> {
                Complex[163.5719524097037, -22.117175992588685`], 
                Complex[133.45502641240844`, -40.99091836543069]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -13.34626714780364}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214619778895`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"21.96936539678994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73811321931896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3268298806687504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5719524097037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.117175992588685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45502641240844`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"40.99091836543069`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.3214619778895, 21.96936539678994], 
                Complex[133.73811321931896`, -0.3268298806687504]}, 2 -> {
                Complex[163.5719524097037, -22.117175992588685`], 
                Complex[133.45502641240844`, -40.99091836543069]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -13.40282044267285}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321471564036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.01355682071051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070584`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793105047`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57137784930458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.16141130685297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.02951394167229`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 
             Association[1 -> {
                Complex[163.321471564036, 22.01355682071051], 
                Complex[133.73813197070584`, -0.28767853793105047`]}, 2 -> {
                Complex[163.57137784930458`, -22.16141130685297], 
                Complex[133.45274099074845`, -41.02951394167229]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -13.4043090710013}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321471564036`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.01355682071051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73813197070584`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.28767853793105047`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57137784930458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.16141130685297`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45274099074845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.02951394167229`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 
             Association[1 -> {
                Complex[163.321471564036, 22.01355682071051], 
                Complex[133.73813197070584`, -0.28767853793105047`]}, 2 -> {
                Complex[163.57137784930458`, -22.16141130685297], 
                Complex[133.45274099074845`, -41.02951394167229]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -13.460974069695883`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32147985883367`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.05751399567081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141522`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.24874533567052026`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57080748805203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.0678907640604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 
             Association[1 -> {
                Complex[163.32147985883367`, 22.05751399567081], 
                Complex[133.73814824141522`, -0.24874533567052026`]}, 2 -> {
                Complex[163.57080748805203`, -22.205412132388133`], 
                Complex[133.45046242420474`, -41.0678907640604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -13.462449417134614`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32147985883367`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.05751399567081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73814824141522`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.24874533567052026`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.57080748805203`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.205412132388133`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.45046242420474`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.0678907640604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 
             Association[1 -> {
                Complex[163.32147985883367`, 22.05751399567081], 
                Complex[133.73814824141522`, -0.24874533567052026`]}, 2 -> {
                Complex[163.57080748805203`, -22.205412132388133`], 
                Complex[133.45046242420474`, -41.0678907640604]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -13.519225418326762`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148689117372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816207413375`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.21002789961483614`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5702412701146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085482`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32148689117372`, 22.101239441069634`], 
                Complex[133.73816207413375`, -0.21002789961483614`]}, 2 -> {
                Complex[163.5702412701146, -22.249180990820484`], 
                Complex[133.44819063634753`, -41.10605121085482]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -13.520687679885585`}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148689117372`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.101239441069634`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816207413375`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.21002789961483614`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5702412701146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.249180990820484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44819063634753`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.10605121085482`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32148689117372`, 22.101239441069634`], 
                Complex[133.73816207413375`, -0.21002789961483614`]}, 2 -> {
                Complex[163.5702412701146, -22.249180990820484`], 
                Complex[133.44819063634753`, -41.10605121085482]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -13.577573991627794`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214926892273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.14473563537842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56967914074468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.292720362818727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4459255521081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214926892273, 22.14473563537842], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[163.56967914074468`, -22.292720362818727`], 
                Complex[133.4459255521081, -41.14399762152054]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -13.579023358347536`}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214926892273`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.14473563537842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73817351060956`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.17152389424024506`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56967914074468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.292720362818727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4459255521081`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.14399762152054`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214926892273, 22.14473563537842], 
                Complex[133.73817351060956`, -0.17152389424024506`]}, 2 -> {
                Complex[163.56967914074468`, -22.292720362818727`], 
                Complex[133.4459255521081, -41.14399762152054]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -13.636019297836674`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214972804685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.188005017031273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.13323102192725855`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56912104625172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.3214972804685, 22.188005017031273`], 
                Complex[133.73818259167945`, -0.13323102192725855`]}, 2 -> {
                Complex[163.56912104625172`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -13.637455956808983`}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214972804685`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.188005017031273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818259167945`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.13323102192725855`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56912104625172`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.33603268898435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4436670977467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.18173229757264`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.3214972804685, 22.188005017031273`], 
                Complex[133.73818259167945`, -0.13323102192725855`]}, 2 -> {
                Complex[163.56912104625172`, -22.33603268898435], 
                Complex[133.4436670977467, -41.18173229757264]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.3, -13.694560850286479`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150069169228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937554`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56856693397444`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.379120370718276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.219257503398715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "C", 
             Association[1 -> {
                Complex[163.32150069169228`, 22.231049985290607`], 
                Complex[133.73818935729176`, -0.09514702213937554]}, 2 -> {
                Complex[163.56856693397444`, -22.379120370718276`], 
                Complex[133.44141520081965`, -41.219257503398715`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -13.695984984708574`}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150069169228`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.231049985290607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818935729176`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.09514702213937554`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56856693397444`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.379120370718276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.44141520081965`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.219257503398715`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.3, "C", 
             Association[1 -> {
                Complex[163.32150069169228`, 22.231049985290607`], 
                Complex[133.73818935729176`, -0.09514702213937554]}, 2 -> {
                Complex[163.56856693397444`, -22.379120370718276`], 
                Complex[133.44141520081965`, -41.219257503398715`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.4, -13.7531981673273}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150294903576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.27387290108978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381938465315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.05726967062375721`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56801675225492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.42198577106388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "C", 
             Association[1 -> {
                Complex[163.32150294903576`, 22.27387290108978], 
                Complex[133.7381938465315, -0.05726967062375721]}, 2 -> {
                Complex[163.56801675225492`, -22.42198577106388], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -13.7546099564828}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150294903576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.27387290108978`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381938465315`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.05726967062375721`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56801675225492`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.42198577106388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43916979014838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.25657546705884`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.4, "C", 
             Association[1 -> {
                Complex[163.32150294903576`, 22.27387290108978], 
                Complex[133.7381938465315, -0.05726967062375721]}, 2 -> {
                Complex[163.56801675225492`, -22.42198577106388], 
                Complex[133.43916979014838`, -41.25657546705884]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.5, -13.811930772249466`}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150407799693`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633637513`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56747045041436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.4646312155268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.29368838106346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "C", 
             Association[1 -> {
                Complex[163.32150407799693`, 22.316476087852756`], 
                Complex[133.73819609764354`, -0.019596778633637513`]}, 2 -> {
                Complex[163.56747045041436`, -22.4646312155268], 
                Complex[133.4369307957903, -41.29368838106346]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -13.81333039137917}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150407799693`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.316476087852756`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819609764354`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{"0.019596778633637513`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56747045041436`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.4646312155268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4369307957903`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.29368838106346`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.5, "C", 
             Association[1 -> {
                Complex[163.32150407799693`, 22.316476087852756`], 
                Complex[133.73819609764354`, -0.019596778633637513`]}, 2 -> {
                Complex[163.56747045041436`, -22.4646312155268], 
                Complex[133.4369307957903, -41.29368838106346]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.6, -13.870758193208252`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150410345304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.017873807828369337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56692797872756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.50705899287356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900826`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "C", 
             Association[1 -> {
                Complex[163.32150410345304`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.017873807828369337`]}, 2 -> {
                Complex[163.56692797872756`, -22.50705899287356], 
                Complex[133.43469814900826`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -13.872145813173345`}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150410345304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.358861832291833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819614805504`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.017873807828369337`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56692797872756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.50705899287356`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43469814900826`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.330598403131276`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.6, "C", 
             Association[1 -> {
                Complex[163.32150410345304`, 22.358861832291833`], 
                Complex[133.73819614805504`, 0.017873807828369337`]}, 2 -> {
                Complex[163.56692797872756`, -22.50705899287356], 
                Complex[133.43469814900826`, -41.330598403131276`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.7, -13.929679963150106`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150304967848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.40103238518414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874688142`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56638928839993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4324717822431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.36730765692628`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "C", 
             Association[1 -> {
                Complex[163.32150304967848`, 22.40103238518414], 
                Complex[133.73819403439737`, 0.05514420874688142]}, 2 -> {
                Complex[163.56638928839993`, -22.549271355908424`], 
                Complex[133.4324717822431, -41.36730765692628]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -13.931055764956248`}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150304967848`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.40103238518414`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73819403439737`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.05514420874688142`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56638928839993`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.549271355908424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4324717822431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.36730765692628`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.7, "C", 
             Association[1 -> {
                Complex[163.32150304967848`, 22.40103238518414], 
                Complex[133.73819403439737`, 0.05514420874688142]}, 2 -> {
                Complex[163.56638928839993`, -22.549271355908424`], 
                Complex[133.4324717822431, -41.36730765692628]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.8, -13.988695619740346`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150094036191`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56585433154422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.59127052222966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.403818232775386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "C", 
             Association[1 -> {
                Complex[163.32150094036191`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[163.56585433154422`, -22.59127052222966], 
                Complex[133.43025162908577`, -41.403818232775386`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -13.990059761504748`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32150094036191`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.442989962127523`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.738189792527`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09221651081071514`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56585433154422`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.59127052222966`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.43025162908577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.403818232775386`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.8, "C", 
             Association[1 -> {
                Complex[163.32150094036191`, 22.442989962127523`], 
                Complex[133.738189792527, 0.09221651081071514]}, 2 -> {
                Complex[163.56585433154422`, -22.59127052222966], 
                Complex[133.43025162908577`, -41.403818232775386`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -14.047804705292252`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149779862297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.484736744276518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818345754614`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.12909276811100767`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5653230611586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42803762425083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 
             Association[1 -> {
                Complex[163.32149779862297`, 22.484736744276518`], 
                Complex[133.73818345754614`, 0.12909276811100767`]}, 2 -> {
                Complex[163.5653230611586, -22.633058674966136`], 
                Complex[133.42803762425083`, -41.44013218836733]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -14.049157349774992`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149779862297`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.484736744276518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73818345754614`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.12909276811100767`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5653230611586`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.633058674966136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42803762425083`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.44013218836733`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 
             Association[1 -> {
                Complex[163.32149779862297`, 22.484736744276518`], 
                Complex[133.73818345754614`, 0.12909276811100767`]}, 2 -> {
                Complex[163.5653230611586, -22.633058674966136`], 
                Complex[133.42803762425083`, -41.44013218836733]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -14.107006766697602`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149364702843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381750638226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16577500282102164`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56479543110495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.674637963494348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42582970355036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.47625154943295`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32149364702843`, 22.526274879059077`], 
                Complex[133.7381750638226, 0.16577500282102164`]}, 2 -> {
                Complex[163.56479543110495`, -22.674637963494348`], 
                Complex[133.42582970355036`, -41.47625154943295]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -14.108348073506301`}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32149364702843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.526274879059077`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381750638226`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16577500282102164`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56479543110495`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.674637963494348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42582970355036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.47625154943295`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 
             Association[1 -> {
                Complex[163.32149364702843`, 22.526274879059077`], 
                Complex[133.7381750638226, 0.16577500282102164`]}, 2 -> {
                Complex[163.56479543110495`, -22.674637963494348`], 
                Complex[133.42582970355036`, -41.47625154943295]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -14.166301355358481`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214885076075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.567606480874492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500862`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.564271396088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.716010504136886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214885076075, 22.567606480874492`], 
                Complex[133.73816464500862`, 0.2022652058581258]}, 2 -> {
                Complex[163.564271396088, -22.716010504136886`], 
                Complex[133.42362780386904`, -41.51217831040793]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -14.167631481026163`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214885076075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.567606480874492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73816464500862`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2022652058581258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.564271396088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.716010504136886`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42362780386904`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.51217831040793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214885076075, 22.567606480874492`], 
                Complex[133.73816464500862`, 0.2022652058581258]}, 2 -> {
                Complex[163.564271396088, -22.716010504136886`], 
                Complex[133.42362780386904`, -41.51217831040793]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -14.225688027120512`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148240186692`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.608733631773358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.23856533752871556`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56375091163494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.547914435078255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32148240186692`, 22.608733631773358`], 
                Complex[133.73815223405947`, 0.23856533752871556`]}, 2 -> {
                Complex[163.56375091163494`, -22.757178380842813`], 
                Complex[133.42143186313936`, -41.547914435078255`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -14.227007125181148`}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32148240186692`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.608733631773358`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73815223405947`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.23856533752871556`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56375091163494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.757178380842813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.42143186313936`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.547914435078255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32148240186692`, 22.608733631773358`], 
                Complex[133.73815223405947`, 0.23856533752871556`]}, 2 -> {
                Complex[163.56375091163494`, -22.757178380842813`], 
                Complex[133.42143186313936`, -41.547914435078255`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.3, -14.285166342207287`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321475350806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.649658382119874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381378632521`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27467732815633283`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56323393407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41924182031818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "C", 
             Association[1 -> {
                Complex[163.321475350806, 22.649658382119874`], 
                Complex[133.7381378632521, 0.27467732815633283`]}, 2 -> {
                Complex[163.56323393407584`, -22.798143645850313`], 
                Complex[133.41924182031818`, -41.58346185720893]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -14.286474563269067`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.321475350806`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.649658382119874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381378632521`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.27467732815633283`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56323393407584`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.798143645850313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41924182031818`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.58346185720893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.3, "C", 
             Association[1 -> {
                Complex[163.321475350806, 22.649658382119874`], 
                Complex[133.7381378632521, 0.27467732815633283`]}, 2 -> {
                Complex[163.56323393407584`, -22.798143645850313`], 
                Complex[133.41924182031818`, -41.58346185720893]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.4, -14.344735865156146`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32146737492982`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.69038275123732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73812156420146`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5627204205249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.838908320332727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41705761536383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.618822481156855`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "C", 
             Association[1 -> {
                Complex[163.32146737492982`, 22.69038275123732], 
                Complex[133.73812156420146`, 0.3106030786938945]}, 2 -> {
                Complex[163.5627204205249, -22.838908320332727`], 
                Complex[133.41705761536383`, -41.618822481156855`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -14.346033356972598`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32146737492982`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.69038275123732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73812156420146`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3106030786938945`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5627204205249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"22.838908320332727`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41705761536383`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.618822481156855`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.4, "C", 
             Association[1 -> {
                Complex[163.32146737492982`, 22.69038275123732], 
                Complex[133.73812156420146`, 0.3106030786938945]}, 2 -> {
                Complex[163.5627204205249, -22.838908320332727`], 
                Complex[133.41705761536383`, -41.618822481156855`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.5, -14.404396164755122`}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145849426388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.730908728036773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381033678786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34634446131990515`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56221032886114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.653998182467525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "C", 
             Association[1 -> {
                Complex[163.32145849426388`, 22.730908728036773`], 
                Complex[133.7381033678786, 0.34634446131990515`]}, 2 -> {
                Complex[163.56221032886114`, -22.879474395027515`], 
                Complex[133.41487918921308`, -41.653998182467525`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -14.40568307229412}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32145849426388`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.730908728036773`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7381033678786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.34634446131990515`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56221032886114`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.879474395027515`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41487918921308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.653998182467525`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.5, "C", 
             Association[1 -> {
                Complex[163.32145849426388`, 22.730908728036773`], 
                Complex[133.7381033678786, 0.34634446131990515`]}, 2 -> {
                Complex[163.56221032886114`, -22.879474395027515`], 
                Complex[133.41487918921308`, -41.653998182467525`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -14.464146813981145`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214487283661`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.7712382716304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.38190332002009697`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56170361771126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830850002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.68899080845728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214487283661, 22.7712382716304], 
                Complex[133.7380833046258, 0.38190332002009697`]}, 2 -> {
                Complex[163.56170361771126`, -22.919843830850002`], 
                Complex[133.41270648376008`, -41.68899080845728]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -14.465423279491898`}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214487283661`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.7712382716304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380833046258`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.38190332002009697`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56170361771126`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.919843830850002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41270648376008`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.68899080845728`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.3214487283661, 22.7712382716304], 
                Complex[133.7380833046258, 0.38190332002009697`]}, 2 -> {
                Complex[163.56170361771126`, -22.919843830850002`], 
                Complex[133.41270648376008`, -41.68899080845728]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -14.523987389939338`}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143809634076`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.81137331192805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4172814711532169`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56120024643147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32143809634076`, 22.81137331192805], 
                Complex[133.73806140417352`, 0.4172814711532169]}, 2 -> {
                Complex[163.56120024643147`, -22.960018559490692`], 
                Complex[133.41053944183457`, -41.72380217877989]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -14.52525355301743}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32143809634076`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.81137331192805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73806140417352`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4172814711532169`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56120024643147`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"22.960018559490692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.41053944183457`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.72380217877989`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32143809634076`, 22.81137331192805], 
                Complex[133.73806140417352`, 0.4172814711532169]}, 2 -> {
                Complex[163.56120024643147`, -22.960018559490692`], 
                Complex[133.41053944183457`, -41.72380217877989]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.8, -14.583917473803615`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142661684998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.85131575022118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4524807040047172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56070017509117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.00000048399869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "C", 
             Association[1 -> {
                Complex[163.32142661684998`, 22.85131575022118], 
                Complex[133.73803769565515`, 0.4524807040047172]}, 2 -> {
                Complex[163.56070017509117`, -23.00000048399869], 
                Complex[133.40837800718197`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -14.585173471454159`}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32142661684998`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"22.85131575022118`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73803769565515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4524807040047172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56070017509117`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.00000048399869`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.40837800718197`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.758434085980085`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.8, "C", 
             Association[1 -> {
                Complex[163.32142661684998`, 22.85131575022118], 
                Complex[133.73803769565515`, 0.4524807040047172]}, 2 -> {
                Complex[163.56070017509117`, -23.00000048399869], 
                Complex[133.40837800718197`, -41.758434085980085`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.9, -14.64393665075821}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214143081261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.891067459749348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48750278132399316`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56020336445604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.039791479349606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4062221244428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.79288829603216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "C", 
             Association[1 -> {
                Complex[163.3214143081261, 22.891067459749348`], 
                Complex[133.7380122076221, 0.48750278132399316`]}, 2 -> {
                Complex[163.56020336445604`, -23.039791479349606`], 
                Complex[133.4062221244428, -41.79288829603216]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -14.645182617457156`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214143081261`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.891067459749348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7380122076221`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48750278132399316`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.56020336445604`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.039791479349606`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4062221244428`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.79288829603216`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.9, "C", 
             Association[1 -> {
                Complex[163.3214143081261, 22.891067459749348`], 
                Complex[133.7380122076221, 0.48750278132399316`]}, 2 -> {
                Complex[163.56020336445604`, -23.039791479349606`], 
                Complex[133.4062221244428, -41.79288829603216]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -14.704044509940454`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214011879832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.93063028625468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5597097759723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.07939339299977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4040717391336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.82716654886576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 
             Association[1 -> {
                Complex[163.3214011879832, 22.93063028625468], 
                Complex[133.73798496805838`, 0.5223494398501387]}, 2 -> {
                Complex[163.5597097759723, -23.07939339299977], 
                Complex[133.4040717391336, -41.82716654886576]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -14.705280577694161`}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3214011879832`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.93063028625468`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73798496805838`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5223494398501387`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5597097759723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.07939339299977`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4040717391336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.82716654886576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 
             Association[1 -> {
                Complex[163.3214011879832, 22.93063028625468], 
                Complex[133.73798496805838`, 0.5223494398501387]}, 2 -> {
                Complex[163.5597097759723, -23.07939339299977], 
                Complex[133.4040717391336, -41.82716654886576]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -14.76424064438456}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213872738282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.97000604852185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55921937175077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.11880804542669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4019267976277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.86127055887851`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3213872738282, 22.97000604852185], 
                Complex[133.73795600439445`, 0.5570223908239598]}, 2 -> {
                Complex[163.55921937175077`, -23.11880804542669], 
                Complex[133.4019267976277, -41.86127055887851]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -14.765466942787674`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213872738282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"22.97000604852185`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73795600439445`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5570223908239598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55921937175077`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.11880804542669`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.4019267976277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"41.86127055887851`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 
             Association[1 -> {
                Complex[163.3213872738282, 22.97000604852185], 
                Complex[133.73795600439445`, 0.5570223908239598]}, 2 -> {
                Complex[163.55921937175077`, -23.11880804542669], 
                Complex[133.4019267976277, -41.86127055887851]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -14.824524650966445`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137258267184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5587321145525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.15803723065625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.89520201543604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32137258267184`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874362]}, 2 -> {
                Complex[163.5587321145525, -23.15803723065625], 
                Complex[133.39978724713728`, -41.89520201543604]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -14.825741307258072`}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32137258267184`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.009196538904806`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73792534352103`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.5915233204874362`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5587321145525`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.15803723065625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39978724713728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.89520201543604`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 
             Association[1 -> {
                Complex[163.32137258267184`, 23.009196538904806`], 
                Complex[133.73792534352103`, 0.5915233204874362]}, 2 -> {
                Complex[163.5587321145525, -23.15803723065625], 
                Complex[133.39978724713728`, -41.89520201543604]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.3, -14.884896130349604`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135713113917`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.04820352384075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55824796777307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.197082716776826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "C", 
             Association[1 -> {
                Complex[163.32135713113917`, 23.04820352384075], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[163.55824796777307`, -23.197082716776826`], 
                Complex[133.39765303569465`, -41.92896258335967]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -14.886103269467982`}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32135713113917`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.04820352384075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7378930118022`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6258538905710189`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55824796777307`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.197082716776826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39765303569465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.92896258335967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.3, "C", 
             Association[1 -> {
                Complex[163.32135713113917`, 23.04820352384075], 
                Complex[133.7378930118022, 0.6258538905710189]}, 2 -> {
                Complex[163.55824796777307`, -23.197082716776826`], 
                Complex[133.39765303569465`, -41.92896258335967]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.4, -14.945354686931998`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32134093547978`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508835`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6600157387690366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55776689542964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340244`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "C", 
             Association[1 -> {
                Complex[163.32134093547978`, 23.087028744351493`], 
                Complex[133.73785903508835`, 0.6600157387690366]}, 2 -> {
                Complex[163.55776689542964`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340244]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -14.94655243156754}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32134093547978`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.087028744351493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73785903508835`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6600157387690366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55776689542964`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.235946246441227`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39552411213612`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.96255390340244`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.4, "C", 
             Association[1 -> {
                Complex[163.32134093547978`, 23.087028744351493`], 
                Complex[133.73785903508835`, 0.6600157387690366]}, 2 -> {
                Complex[163.55776689542964`, -23.235946246441227`], 
                Complex[133.39552411213612`, -41.96255390340244]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -15.005899928793841`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213240115776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.12567391653264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782343872844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6940104792034631`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55728886214564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.99597759271317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 
             Association[1 -> {
                Complex[163.3213240115776, 23.12567391653264], 
                Complex[133.73782343872844`, 0.6940104792034631]}, 2 -> {
                Complex[163.55728886214564`, -23.27462953735598], 
                Complex[133.39340042608356`, -41.99597759271317]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -15.007088399440754`}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3213240115776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.12567391653264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73782343872844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.6940104792034631`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55728886214564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.27462953735598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39340042608356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"41.99597759271317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 
             Association[1 -> {
                Complex[163.3213240115776, 23.12567391653264], 
                Complex[133.73782343872844`, 0.6940104792034631]}, 2 -> {
                Complex[163.55728886214564`, -23.27462953735598], 
                Complex[133.39340042608356`, -41.99597759271317]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -15.066531467646453`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32130637496067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7377862475824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7278397028767358`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55681383313836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.02923524528987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32130637496067`, 23.164140732031207`], 
                Complex[133.7377862475824, 0.7278397028767358]}, 2 -> {
                Complex[163.55681383313836`, -23.313134282759357`], 
                Complex[133.39128192792896`, -42.02923524528987]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -15.067710782652842`}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32130637496067`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.164140732031207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.7377862475824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7278397028767358`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55681383313836`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.313134282759357`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.39128192792896`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.02923524528987`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 
             Association[1 -> {
                Complex[163.32130637496067`, 23.164140732031207`], 
                Complex[133.7377862475824, 0.7278397028767358]}, 2 -> {
                Complex[163.55681383313836`, -23.313134282759357`], 
                Complex[133.39128192792896`, -42.02923524528987]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -15.127248918781941`}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128804080997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.2024308585112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5563417742055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.351462151887404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.389168568818`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.062328432421694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32128804080997`, 23.2024308585112], 
                Complex[133.73774748603233`, 0.7615049781131837]}, 2 -> {
                Complex[163.5563417742055, -23.351462151887404`], 
                Complex[133.389168568818, -42.062328432421694`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -15.12841919439854}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32128804080997`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.2024308585112`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73774748603233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7615049781131837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.5563417742055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.351462151887404`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.389168568818`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.062328432421694`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 
             Association[1 -> {
                Complex[163.32128804080997`, 23.2024308585112], 
                Complex[133.73774748603233`, 0.7615049781131837]}, 2 -> {
                Complex[163.5563417742055, -23.351462151887404`], 
                Complex[133.389168568818, -42.062328432421694`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.8, -15.188051901023886`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126902396925`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55587265171218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.38961479042947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "C", 
             Association[1 -> {
                Complex[163.32126902396925`, 23.24054594010908], 
                Complex[133.73770717799474`, 0.7950078509907748]}, 2 -> {
                Complex[163.55587265171218`, -23.38961479042947], 
                Complex[133.3870603006344, -42.095258703120926`]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -15.189213251451351`}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32126902396925`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.24054594010908`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73770717799474`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.7950078509907748`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55587265171218`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.38961479042947`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.3870603006344`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"42.095258703120926`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.8, "C", 
             Association[1 -> {
                Complex[163.32126902396925`, 23.24054594010908], 
                Complex[133.73770717799474`, 0.7950078509907748]}, 2 -> {
                Complex[163.55587265171218`, -23.38961479042947], 
                Complex[133.3870603006344, -42.095258703120926`]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{39.9, -15.24894003667886}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32124933895304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.278487597877273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8283498457615899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.555406432579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "C", 
             Association[1 -> {
                Complex[163.32124933895304`, 23.278487597877273`], 
                Complex[133.73766534693092`, 0.8283498457615899]}, 2 -> {
                Complex[163.555406432579, -23.427593820972138`], 
                Complex[133.38495707598477`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -15.250092574113639`}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.32124933895304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"23.278487597877273`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73766534693092`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8283498457615899`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.555406432579`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"23.427593820972138`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38495707598477`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.12802758454397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {39.9, "C", 
             Association[1 -> {
                Complex[163.32124933895304`, 23.278487597877273`], 
                Complex[133.73766534693092`, 0.8283498457615899]}, 2 -> {
                Complex[163.555406432579, -23.427593820972138`], 
                Complex[133.38495707598477`, -42.12802758454397]}]}, 
            "Tooltip"]& ]}}, {
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 1, 
           NCache[
            Rational[1, 3], 0.3333333333333333]], 
          TagBox[
           TooltipBox[PointBox[{40., -15.309912951488823`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3212289999553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.316257430218013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55494308426918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.465400843433205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "C", 
             Association[1 -> {
                Complex[163.3212289999553, 23.316257430218013`], 
                Complex[133.73762201585797`, 0.8615324652630996]}, 2 -> {
                Complex[163.55494308426918`, -23.465400843433205`], 
                Complex[133.38285884818328`, -42.16063658240298]}]}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{40., -15.311056786167487`}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.3212289999553`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"23.316257430218013`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.73762201585797`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.8615324652630996`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"163.55494308426918`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"23.465400843433205`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"133.38285884818328`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"42.16063658240298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}]}], "}"}]],
           Annotation[#, {40., "C", 
             Association[1 -> {
                Complex[163.3212289999553, 23.316257430218013`], 
                Complex[133.73762201585797`, 0.8615324652630996]}, 2 -> {
                Complex[163.55494308426918`, -23.465400843433205`], 
                Complex[133.38285884818328`, -42.16063658240298]}]}, 
            "Tooltip"]& ]}}}},
      AspectRatio->0.5555555555555556,
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], 
        FormBox["\"harmonic dipole\"", TraditionalForm]},
      ImageSize->800,
      PlotRange->{Automatic, {-8.5, -5.6}},
      PlotRangeClipping->True]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Uniform Approximation total spectrum", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "UAdipole"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"UAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(1\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation],transition] returns the total harmonic-dipole \
contribution in the uniform approximation from the specified saddle points, \
taking the given Stokes transition set as a reference.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info223674213809-4227106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColour", ",", "transitions"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<A\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"6.3", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ",", 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"keyColour", "=", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\"\<A\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Black"}], ",", 
            RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<B\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Red"}], ",", 
            RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<C\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Orange"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<D\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}],
         "\[RightAssociation]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"keyColour", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", "Black"}], ",", 
       RowBox[{"\"\<B\>\"", "\[Rule]", "Red"}], ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", "Purple"}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#1", "/", "\[Omega]"}], ",", 
                SuperscriptBox[
                 RowBox[{"Norm", "[", 
                  RowBox[{"Total", "[", "#2", "]"}], "]"}], "2"]}], "}"}], 
              "&"}], "\[IndentingNewLine]", ",", 
             RowBox[{
              RowBox[{"Query", "[", "Transpose", "]"}], "[", 
              "\[IndentingNewLine]", 
              RowBox[{"MapIndexed", "[", 
               RowBox[{"(*", 
                RowBox[{
                "calculate", " ", "the", " ", "dipole", " ", "for", " ", 
                 "each", " ", "label", " ", "and", " ", "harmonic", " ", 
                 "energy"}], "*)"}], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"With", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"saddles", "=", "#1"}], ",", 
                    RowBox[{"index", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
                    RowBox[{"\[CapitalOmega]", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"UAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], "]"}]}], 
                  "\[IndentingNewLine]", "]"}], "&"}], ",", "selection", ",", 
                
                RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n_", ",", 
             RowBox[{"d_", "/;", 
              RowBox[{
               RowBox[{"Abs", "[", "d", "]"}], "<", 
               SuperscriptBox["10", 
                RowBox[{"-", "20"}]]}]}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{",", 
           RowBox[{"GridLines", "\[Rule]", "All"}]}], "*)"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], "\[IndentingNewLine]", 
         ",", 
         RowBox[{"ImageSize", "\[Rule]", "700"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
            "\"\<harmonic dipole\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#1", "/", "\[Omega]"}], ",", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Norm", "[", 
                 RowBox[{"Total", "[", "#2", "]"}], "]"}], "2"], "+", 
               SuperscriptBox["10", 
                RowBox[{"-", "20"}]]}]}], "}"}], "&"}], "\[IndentingNewLine]",
            ",", 
           RowBox[{
            RowBox[{"Query", "[", "Transpose", "]"}], "[", 
            "\[IndentingNewLine]", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{"(*", 
              RowBox[{
              "calculate", " ", "the", " ", "dipole", " ", "for", " ", "each",
                " ", "label", " ", "and", " ", "harmonic", " ", "energy"}], 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"With", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"saddles", "=", "#1"}], ",", 
                   RowBox[{"index", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
                   RowBox[{"\[CapitalOmega]", "=", 
                    RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"UAdipole", "[", 
                  RowBox[{
                  "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], 
                   "\[IndentingNewLine]", ",", 
                   RowBox[{"transitions", "[", "index", "]"}]}], "]"}]}], 
                "\[IndentingNewLine]", "]"}], "&"}], ",", 
              RowBox[{
               RowBox[{"KeySelect", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    RowBox[{"#", "-", 
                    RowBox[{"Round", "[", 
                    RowBox[{"#", ",", "\[Omega]"}], "]"}]}], "]"}], "<", 
                   RowBox[{"0.05", "\[Omega]"}]}], "&&", 
                  RowBox[{"OddQ", "[", 
                   RowBox[{"Round", "[", 
                    RowBox[{"#", "/", "\[Omega]"}], "]"}], "]"}]}], "&"}], 
                "]"}], "/@", "selection"}], ",", 
              RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{",", 
           RowBox[{"GridLines", "\[Rule]", "All"}]}], "*)"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], "\[IndentingNewLine]", 
         ",", 
         RowBox[{"ImageSize", "\[Rule]", "700"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
            "\"\<harmonic dipole\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {GrayLevel[0], PointSize[0.01388888888888889], AbsoluteThickness[1.6],
          PointBox[CompressedData["
1:eJw1lglUlHUXxjEo00BAwUAsNVw6SMCszLyzPe87iLK4oZKI8YECCZoLg0qB
4m4hXyhukJAknySJho6ouI5ayu4OkhshDoWCsmgZph8y9/8/Z84czuH/zHN/
97n3fUfMWRQS85aVlVVTz+fNd/ab4+qDo0cSBjhP0JgkvccH66WmAycaVaaq
NyfYB4a1C1c1jlKZYnuPD/b13zg9uIQzvX5zUn3wkeyrwcFLOFOvXrYPUsqq
F2smcBY9ow/Cr2Qa4j05i16VD3b2qXvoPZCz6Jl90GTfbB7WoTRZ9R4Rpta5
nlpRqbTouYrQPG7rZF2+kvyJUFK5/qJhlZL8iZDzVxJ3OE5J/kRIktdePx5N
eqtEMK+zjQ9fTnrZIlRHtT5RFZKeUYT/XlvdNrYv8yfCE5fuyOoi5k+E3yIr
v/drV5EfMaTPlv9SXasiP2I0S1MORi+n+8Fi5Nl9Ps5cojTF9AqIceh589p6
Tkm8xEi2WzZ5VYuC/IjRXlQ4auZxBfkR46r2kFN1rsJU3SsoRkVUu2fYTgX5
EePPRzNXJOYrLHqvxXhcn795zHnSc5VAb7fS0NhFehIJbj4/lLFWy3hJ8Ku2
z9Af8hkvCaYuLXs4aSzrpwRDT0tzmxtYPyWIirSHzy2q1yhBjd/Mti65hnhJ
sP78wAHJMh35k6BQXp64IBqm73r9SOGc4dzwYbnWJO4VkCLt/V2haxrU5EeK
6+Zng/qdZPmSIkpnHTS0k6P+SfHyrkeXXwxnyur1I0XgkIqN3lacRc8oxYZo
m0JTKdVXJUX7pL9nz91E9ZmleHW6rilzMcuXDIc7yl4ExrJ8yZD/qsLm93iW
Lxm4ayFb+q5UWvgHy7DDKfLa7TzGS4b3nnBzXt1k/ZRh/78R1x+MYLxk+Cl8
W1vNJpb/Hr1P3KoLh9M8Vcmwwb0la/pLlSUfZhkqVsa3jlymIT9yjP/sQveV
C2we5eivk39asF1NfuQovbxS1K+PmvzIcfPHMolyv4r8yJFZNXHbvETKa7Yc
GV8/D0oLZv2Tw7j07YxzY5kfOfwcqsd5OhB/sxwlF3z6Z3VTHl7L8cEHwmOb
dqrP1RdlV5P32HYSf4kvfh50SRRnzfaFL348c7vbx5310xchC9pfJE5TUT99
kRLeUoQdKks+sn0xxe3pjJCnKuqnL5rKdFd2L6B8VPXc50z2g0dryJ8vGsKP
RMgStZY8uCrgKqrbMnsay5cCQ3alB/xhZvlSIL1ItmH/IMZLgYToK8smrWW8
FNiU/tqqfQjjpUBbt7Q0v4b1T4G3drz8xjaLo3lUYPiXoXyCge0HBRJH7vw3
K4LxUmC9R+sZ/5mMlxLvZqwJdIhkvJTw3GhWBC9j+0KJPMe9J91zONoXSjz5
Jze34jqbRyVCF4m/7TOC+VPisMeGMfo01k8l3KYdSvrFjfHq+fuaXZ97T6le
sxKnKyqTv4/Ukh8Oc2bd/s+CzVrKF4fPIuwOq6bQPAdzcPRyDR36k5r8cMgr
HL89wV9NfjjktF/JtOmnJj8chr0bWBTYxPrHwd/BPe6fyyxfHGR7rI67X2T5
4nCga8XVOecpD1YqLChfJu86R3lwVeHMU9vJfX9h+1WFVHtR4vVyli8VLo6Y
khdUy/KlQmv6ee5kq8r0qtefCsa+VxMuOatpX6iQtt1mcESomvypMGpu39XF
pxgvFWKCNsw8Es3ypcKpQn1Y7V7GSw1J4+K7JxIZLzU6glKnnn5LQ/Ooht3e
j44bPBgvNV44t/o/28bypYZKt6LcdQzrnxrFzl/uaLzB9pcaT5eNPPheT74q
e/2osX++82XrLygPZjU8XR5GHZvK8qWG99v5Te+MY/nS4MGYvfI0f8qrRINP
ndznpoayfGlwxHv4/DtLKa+xGtyPEe9ML2D7VYOGaMez/zxi+0uDjck3lOOD
WT81WHznTuuU66yfGqjXnLs2KofqNWvg4r86Ludftr+0mJX9l3N8fzaPWvy6
8IdLxSVsHrUIcS1zTHrB+qdFysJdw26tZPtBi+aOJ+eKPRgvLT4qMpy2b2e8
tLi3b+yHpkr2vNaiPOjmAP4Ym0ct7Gd4NGUc4ix5eK3FoM46c24pPT9cdXAq
LfUYdJnNow5//tj9jqaD8dJh9Ox+hcNGMn86fJWwyN8Yy/qpw+7F3jMXnmb+
dLh/LCAj2UtN86jDX4uCnp//lfZ1lQ41WY3fzvpeQ7x0iOsKezzMXmf5PVug
dFSxcbxSR/yAmnansP91UB5HA0cz8jzd/djzAPjmUf+DDbU0jzpA9t3KMlMG
4ws4tj3wujmH5jMM6Nx26djjALb/gDs7AxRpPPk1AI3qkRkHx6uJP+DhUj5/
UjjppQPcvJARzils3oEZHa9cp/1EegWApsE61r6ZzRfwwf11LX5SjcXfWeBt
c+6uBdvZ+wJQXfbFEqMDzVc9ILn3+ybrw1rqHzBwybs3ErfpLP46geV3jk40
bISFpy2Pj0/E1XfsZe8XPOZPd3JQ9AXx4rEuINDv2Twd9ZfHg65bv2fa6IgX
j/T3g9y8LmqJF4/M1vlX638gP2E8Pr+TZBW7hfzE8khuid8VuoXm38Bjxtf7
dxzYrSVePOTN8QcjT2ot/tJ5nD+XoRjaRHrZPEqKPHeKhtD7UQGPyN8MF/dF
UH1GHvemu21aYSR/Z3m0V7jUOg0A8eKRFeGZ+MVkEC8eG8sc7c7kU73mHn9L
R7VmuvDEi0f2ZieH2fU85UtAxYGiWfWveMqX0LO/K/LT5/LES4D4oZAgdqL7
EgG1k3Nawh7CUh8EzM1Nub+0nPgHC7A5N7jP5hPkJ0zAduuaTZtLQPtPgOaz
upLS47DwNwjwCkg9YnsBND8COifJd9vcoPrSBRRN+PzW8kekly0gonqrf0Y/
8lfQ8/+BCrfLXuTPKODuhK442Wze4s8koDkpaVzqVp7mTcCBn2UnLtTxlnzU
C7h9bV/k314C8RLQEp5zsLBAsPjr7PF3KfPS+Hg98dJjYt4I77DteuKlR0LU
V39UvqT7o/WImScTPIoF4qWH89xP1lqvE4iXHg8ubt1dES9QvvRo6xc375sI
gXjp8eHa4dzHs0kvVg/HqZr4P6NIz6DHkoDNwTULBeKlx9EQ1eCQNaSXrken
d6p/UA7pZevx9+Wr9xtPkV5Bj7+7Z71ym0jPqMfe4sFRSU56ypceyphbe0ST
qN4qPZzKu1watlG99Xqkxe0xfNmmJ156HAr+WZc2z4/ypUd8SvfRNV7jTP8H
KnzFag==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{15.728124999999999`, -43.65327891074053},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"harmonic dipole\"", TraditionalForm], None}, {
         FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-41.44653167389282, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.93054075013613, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.843529373146502`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.763486665472964`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.689378693319245`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.620385821832294`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.555847300694722`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-41.44653167389282, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.93054075013613, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.843529373146502`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.763486665472964`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.689378693319245`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.620385821832294`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-22.555847300694722`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->700,
      Method->{},
      PlotRange->{{16.099999999999998`, 
       39.9}, {-43.350706300427696`, -24.591204461032056`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}]},
    {
     GraphicsBox[{{}, {{}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], PointBox[{{17., -25.7948873087283}, {
          18.999999999999996`, -24.758416213426365`}, {
          21., -25.399581537660296`}, {
          22.999999999999996`, -26.94148136222765}, {
          24.999999999999996`, -26.344829492573204`}, {
          27., -27.757632629489514`}, {
          28.999999999999996`, -26.269636427986438`}, {
          30.999999999999993`, -26.725065635189218`}, {
          33., -28.356665339404184`}, {35., -30.731943767664085`}, {
          36.99999999999999, -33.65638691194051}, {
          38.99999999999999, -37.01801076326267}}]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{16.65625, -37.90782004510564},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"harmonic dipole\"", TraditionalForm], None}, {
         FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-36.841361487904734`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.45079940033883, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.04533429223067, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.75765221977888, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.534508668464674`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.35218711167072, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.19803643184346, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.06450503921894, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.946722003562556`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.14821430734479, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.74274919923662, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.45506712678484, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.23192357547063, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.04960201867667, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.89545133884942, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.76191994622489, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.64413691056851, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.84562921435074, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.44016410624258, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.1524820337908, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.92933848247659, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.74701692568263, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.59286624585537, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.45933485323085, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.34155181757447, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.543044121356694`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.13757901324853, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.84989694079675, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.626753389482538`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.444431832688586`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.290281152861326`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.156749760236803`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.03896672458042, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.240459028362647`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.834993920254483`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.547311847802703`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.324168296488494`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.14184673969454, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.98769605986728, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.85416466724276, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.736381631586376`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.937873935368604`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.53240882726044, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.244726754808656`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.021583203494448`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.839261646700493`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.685110966873236`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.551579574248713`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.43379653859233, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.635288842374557`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.229823734266393`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.942141661814613`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.7189981105004, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.536676553706446`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.38252587387919, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.248994481254666`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.131211445598282`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-36.841361487904734`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.45079940033883, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-38.04533429223067, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.75765221977888, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.534508668464674`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.35218711167072, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.19803643184346, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-37.06450503921894, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.946722003562556`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.14821430734479, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.74274919923662, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.45506712678484, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.23192357547063, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-35.04960201867667, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.89545133884942, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.76191994622489, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.64413691056851, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.84562921435074, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.44016410624258, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-33.1524820337908, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.92933848247659, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.74701692568263, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.59286624585537, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.45933485323085, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.34155181757447, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.543044121356694`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-31.13757901324853, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.84989694079675, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.626753389482538`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.444431832688586`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.290281152861326`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.156749760236803`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-30.03896672458042, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.240459028362647`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.834993920254483`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.547311847802703`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.324168296488494`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-28.14184673969454, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.98769605986728, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.85416466724276, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.736381631586376`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.937873935368604`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.53240882726044, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.244726754808656`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-26.021583203494448`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.839261646700493`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.685110966873236`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.551579574248713`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.43379653859233, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.635288842374557`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-24.229823734266393`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.942141661814613`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.7189981105004, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.536676553706446`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.38252587387919, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.248994481254666`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.131211445598282`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->700,
      Method->{},
      PlotRange->{{17., 
       38.99999999999999}, {-37.699099349364694`, -24.758416213426365`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Testing the degrading of UAdipole to SPAdipole when there\[CloseCurlyQuote]s \
too few or too many solutions\
\>", "Subsection"],

Cell[TextData[{
 "\nThe ",
 StyleBox["classifierFunction", "Code"],
 " below has been explicitly chosen so that the spectrum gets damaged: the \
\[OpenCurlyQuote]keeper\[CloseCurlyQuote] member of the A pair has been cut \
off by asking for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Im", "(", 
     RowBox[{"\[Omega]", " ", "t"}], ")"}], "<", "0.5"}], TraditionalForm]]],
 ", and the lower ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Re", "(", 
    RowBox[{"\[Omega]", " ", "t"}], ")"}], TraditionalForm]]],
 " limit of the C pair has been chosen too low so that there is an extra \
saddle intruding upon the set.\n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]", ",", 
     "selection", ",", "classifierFunction", ",", "sortingFunction", ",", 
     "keyColourPoints", ",", "keyColourSpectrum", ",", "transitions"}], "}"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "Ip", ",", "\[Kappa]", ",", "U", ",", "\[Gamma]"}], 
      "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "Ip", ",", 
        SqrtBox[
         RowBox[{"2", "Ip"}]], ",", 
        FractionBox[
         SuperscriptBox["F", "2"], 
         RowBox[{"4", 
          SuperscriptBox["\[Omega]", "2"]}]], ",", 
        FractionBox[
         RowBox[{"\[Kappa]", " ", "\[Omega]"}], "F"]}], "}"}], "//.", 
      "parameters"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"classifierFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], "}"}], ",", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"1.65", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}], "<", "0.5"}]}], "]"}], 
         ",", "\"\<A\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"1.65", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "6.3"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", "0"}]}], "]"}], ",", "\"\<B\>\"",
            ","}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"5.654", "<", 
            RowBox[{"\[Omega]", " ", 
             RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
           RowBox[{
            FractionBox[
             RowBox[{"Floor", "[", 
              RowBox[{
               RowBox[{"\[Omega]", " ", 
                RowBox[{"Re", "[", 
                 RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], "]"}],
              "\[Pi]"], "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}], ">", 
            RowBox[{"-", "0.4"}]}]}], "]"}], ",", "\"\<C\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"6.3", "<", 
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", "\[Tau]", "]"}]}], "<", "8.9"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{"Floor", "[", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                "]"}], "\[Pi]"], "\[Equal]", 
              RowBox[{"-", "1"}]}]}], "]"}], ",", "\"\<D\>\"", ","}], "*)"}], 
         "\[IndentingNewLine]", "True", ",", "\"\<Discard\>\""}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"sortingFunction", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"list", ",", 
       RowBox[{"SortBy", "[", 
        RowBox[{"list", ",", 
         RowBox[{"Function", "[", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "-", 
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "-", 
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"keyColour", "=", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\"\<A\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Black"}], ",", 
            RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<B\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "Red"}], ",", 
            RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
         ",", 
         RowBox[{"\"\<C\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Orange"}], ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"Darker", "[", "Red", "]"}]}]}], 
           "\[RightAssociation]"}]}], ",", 
         RowBox[{"\"\<D\>\"", "\[Rule]", 
          RowBox[{"\[LeftAssociation]", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
            RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}],
         "\[RightAssociation]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"keyColourPoints", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Black"}], ",", 
          RowBox[{"2", "\[Rule]", "Blue"}]}], "\[RightAssociation]"}]}], ",", 
       
       RowBox[{"\"\<B\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "Red"}], ",", 
          RowBox[{"2", "\[Rule]", "Magenta"}]}], "\[RightAssociation]"}]}], 
       ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Orange"}], ",", 
          RowBox[{"3", "\[Rule]", 
           RowBox[{"Darker", "[", "Red", "]"}]}]}], "\[RightAssociation]"}]}],
        ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", 
        RowBox[{"\[LeftAssociation]", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"Darker", "[", "Cyan", "]"}]}], ",", 
          RowBox[{"2", "\[Rule]", "Purple"}]}], "\[RightAssociation]"}]}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"keyColourSpectrum", "=", 
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\"\<A\>\"", "\[Rule]", "Black"}], ",", 
       RowBox[{"\"\<B\>\"", "\[Rule]", "Red"}], ",", 
       RowBox[{"\"\<C\>\"", "\[Rule]", 
        RowBox[{"Darker", "[", "Green", "]"}]}], ",", 
       RowBox[{"\"\<D\>\"", "\[Rule]", "Purple"}]}], 
      "\[RightAssociation]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"selection", "=", 
     RowBox[{"ClassifyQuantumOrbits", "[", 
      RowBox[{
      "saddlePoints", ",", "classifierFunction", ",", "sortingFunction", ",", 
       
       RowBox[{"DiscardedLabels", "\[Rule]", 
        RowBox[{"{", "\"\<Discard\>\"", "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"transitions", "=", 
     RowBox[{"FindStokesTransitions", "[", 
      RowBox[{"S", ",", "selection"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Column", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"transitions", ",", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"KeyValueMap", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Function", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"n", ",", "t", ",", "\[Tau]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"keyColourPoints", "[", 
                    RowBox[{"index", ",", "n"}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", 
                    "Gray"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"ReIm", "[", 
                    RowBox[{"\[Omega]", " ", "t"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", "n", ",", 
                    RowBox[{"\[Omega]", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}]}], ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Floor", "[", 
                    RowBox[{
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{"t", "-", "\[Tau]"}], "]"}]}], ",", "\[Pi]"}], 
                    "]"}]}]}], "}"}]}], "]"}]}], "}"}]}], 
                   "\[IndentingNewLine]", "]"}], "@*", 
                  RowBox[{"Apply", "[", "Sequence", "]"}], "@*", "Flatten", "@*",
                   "List"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"selection", "[", 
                  RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], "]"}], 
               "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[CapitalOmega]", ",", 
                RowBox[{"Keys", "[", 
                 RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"index", ",", 
              RowBox[{"Keys", "[", "selection", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(\[Omega]t)\>\"", ",", "\"\<Im(\[Omega]t)\>\""}], 
           "}"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"keyColourSpectrum", "[", "index", "]"}], "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", "Gray"}], 
                  "}"}]}], 
                RowBox[{"(*", 
                 RowBox[{"/.", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Black", "\[Rule]", "Gray"}], ",", 
                    RowBox[{
                    RowBox[{"Darker", "[", "Green", "]"}], "\[Rule]", 
                    RowBox[{"Lighter", "[", "Green", "]"}]}]}], "}"}]}], 
                 "*)"}], ",", "\[IndentingNewLine]", 
                RowBox[{"Tooltip", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Point", "[", "\[IndentingNewLine]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"Log10", "[", 
                    RowBox[{
                    SuperscriptBox["10", 
                    RowBox[{"-", "7"}]], "+", 
                    RowBox[{"Norm", "[", "\[IndentingNewLine]", 
                    RowBox[{"SPAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], "]"}], 
                    "\[IndentingNewLine]", "]"}]}], "]"}]}], "}"}], 
                   "\[IndentingNewLine]", "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", 
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], ",", 
                    "\"\<SPA\>\""}], "}"}]}], "]"}], ",", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"keyColourSpectrum", "[", "index", "]"}], "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Missing", "[", "__", "]"}], "\[Rule]", "Gray"}], 
                  "}"}]}], ",", "\[IndentingNewLine]", 
                RowBox[{"Tooltip", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Point", "[", "\[IndentingNewLine]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    RowBox[{"Log10", "[", 
                    RowBox[{
                    SuperscriptBox["10", 
                    RowBox[{"-", "7"}]], "+", 
                    RowBox[{"Norm", "[", "\[IndentingNewLine]", 
                    RowBox[{"UAdipole", "[", 
                    RowBox[{
                    "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}], ",", 
                    RowBox[{"transitions", "[", "index", "]"}]}], "]"}], 
                    "\[IndentingNewLine]", "]"}]}], "]"}]}], "}"}], 
                   "\[IndentingNewLine]", "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"\[CapitalOmega]", "/", "\[Omega]"}], ",", 
                    "index", ",", 
                    RowBox[{"\[Omega]", " ", 
                    RowBox[{"selection", "[", 
                    RowBox[{"index", ",", "\[CapitalOmega]"}], "]"}]}], ",", 
                    "\"\<UA\>\""}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
               "}"}], "\[IndentingNewLine]", ",", 
              RowBox[{"{", 
               RowBox[{"\[CapitalOmega]", ",", 
                RowBox[{"Keys", "[", 
                 RowBox[{"selection", "[", "index", "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"index", ",", 
              RowBox[{"Reverse", "@", 
               RowBox[{"Keys", "[", "selection", "]"}]}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
         RowBox[{"ImageSize", "\[Rule]", "800"}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"AspectRatio", "\[Rule]", 
          RowBox[{"1", "/", "1.8"}]}], "\[IndentingNewLine]", ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalOmega]/\[Omega]\>\"", ",", 
            "\"\<harmonic dipole\>\""}], "}"}]}], "\[IndentingNewLine]", ",", 
         
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "7.1"}], ",", 
              RowBox[{"-", "5.3"}]}], "}"}]}], "}"}]}], "\[IndentingNewLine]",
          ",", 
         RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
     "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindStokesTransitions", "::", "saddleno"}], "MessageName"], ":", 
  " ", "\<\"FindStokesTransitions called with \[NoBreak]\\!\\(55\\)\[NoBreak] \
of \[NoBreak]\\!\\(241\\)\[NoBreak] saddle-point sets of length different \
from 2, with set length structure \[NoBreak]\\!\\({\\(\\({2, 186}\\)\\), \
\\(\\({1, 55}\\)\\)}\\)\[NoBreak]. Excluding those sets from the calculation.\
\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindStokesTransitions", "::", "saddleno"}], "MessageName"], ":", 
  " ", "\<\"FindStokesTransitions called with \
\[NoBreak]\\!\\(219\\)\[NoBreak] of \[NoBreak]\\!\\(241\\)\[NoBreak] \
saddle-point sets of length different from 2, with set length structure \
\[NoBreak]\\!\\({\\(\\({3, 33}\\)\\), \\(\\({2, 22}\\)\\), \\(\\({1, \
186}\\)\\)}\\)\[NoBreak]. Excluding those sets from the calculation.\"\>"}]], \
"Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SPAdipole", "::", "wrongno"}], "MessageName"], ":", 
  " ", "\<\"SPAdipole called with a Stokes transition but with an input \
association of length \[NoBreak]\\!\\(3\\)\[NoBreak] at harmonic energy \
\[CapitalOmega]=\[NoBreak]\\!\\(0.912`\\)\[NoBreak]. Reverting to \
unstructured evaluation.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"UAdipole", "::", "saddleno"}], "MessageName"], ":", 
  " ", "\<\"UAdipole called with \[NoBreak]\\!\\(3\\)\[NoBreak] time pairs at \
\[CapitalOmega]=\[NoBreak]\\!\\(0.912`\\)\[NoBreak]. Reverting to the \
saddle-point approximation for this set.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SPAdipole", "::", "wrongno"}], "MessageName"], ":", 
  " ", "\<\"SPAdipole called with a Stokes transition but with an input \
association of length \[NoBreak]\\!\\(3\\)\[NoBreak] at harmonic energy \
\[CapitalOmega]=\[NoBreak]\\!\\(0.9177000000000001`\\)\[NoBreak]. Reverting \
to unstructured evaluation.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"UAdipole", "::", "saddleno"}], "MessageName"], ":", 
  " ", "\<\"UAdipole called with \[NoBreak]\\!\\(3\\)\[NoBreak] time pairs at \
\[CapitalOmega]=\[NoBreak]\\!\\(0.9177000000000001`\\)\[NoBreak]. Reverting \
to the saddle-point approximation for this set.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SPAdipole", "::", "wrongno"}], "MessageName"], ":", 
  " ", "\<\"SPAdipole called with a Stokes transition but with an input \
association of length \[NoBreak]\\!\\(3\\)\[NoBreak] at harmonic energy \
\[CapitalOmega]=\[NoBreak]\\!\\(0.9234`\\)\[NoBreak]. Reverting to \
unstructured evaluation.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(SPAdipole :: \
wrongno\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"UAdipole", "::", "saddleno"}], "MessageName"], ":", 
  " ", "\<\"UAdipole called with \[NoBreak]\\!\\(3\\)\[NoBreak] time pairs at \
\[CapitalOmega]=\[NoBreak]\\!\\(0.9234`\\)\[NoBreak]. Reverting to the \
saddle-point approximation for this set.\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(UAdipole :: \
saddleno\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"\[LeftAssociation]", 
      RowBox[{
       RowBox[{"\<\"A\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.767`", ",", "1.8354`", ",", "2"}], "}"}]}], ",", 
       RowBox[{"\<\"C\"\>", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1.1628`", ",", "1.1742`", ",", "1"}], "}"}]}]}], 
      "\[RightAssociation]"}]},
    {
     GraphicsBox[{{{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.6980000948375882, -0.6433017314670934}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 1, {
              Complex[0.6980000948375882, -0.6433017314670934], 
              Complex[1.7951626777960403`, -2.1401483895471043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.6944263543752545`, 0.006645071137818129}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {15.999999999999998`, "A", 2, {
              Complex[4.6944263543752545`, 0.006645071137818129], 
              Complex[6.196232266214944, -1.1633793876684915`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7333882582665036, -0.6165221792948049}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 1, {
              Complex[0.7333882582665036, -0.6165221792948049], 
              Complex[1.8301368298409664`, -2.112021181971959]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.654309125631486, 0.006712510785854934}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.099999999999998`, "A", 2, {
              Complex[4.654309125631486, 0.006712510785854934], 
              Complex[6.155525231634676, -1.1633781485602357`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7629774456127986, -0.5952855745698065}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 1, {
              Complex[0.7629774456127986, -0.5952855745698065], 
              Complex[1.8593666135298341`, -2.0894057490922227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.621891868208896, 0.006786025025047798}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.2, "A", 2, {
              Complex[4.621891868208896, 0.006786025025047798], 
              Complex[6.122517060306257, -1.163371113059422]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.7891581377234371, -0.5773156862277916}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 1, {
              Complex[0.7891581377234371, -0.5773156862277916], 
              Complex[1.8852354657886545`, -2.0700333477056216`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.593955318850742, 0.0068633365731448895`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068633365731448895`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.299999999999997`, "A", 2, {
              Complex[4.593955318850742, 0.0068633365731448895`], 
              Complex[6.093988110787665, -1.1633606215314776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.813020240902394, -0.5615718710865851}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 1, {
              Complex[0.813020240902394, -0.5615718710865851], 
              Complex[1.908828689419144, -2.052868131119601]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.569036631840206, 0.006943461497604872}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.4, "A", 2, {
              Complex[4.569036631840206, 0.006943461497604872], 
              Complex[6.068475300453683, -1.163347697400969]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.835170145892391, -0.5474736791133877}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 1, {
              Complex[0.835170145892391, -0.5474736791133877], 
              Complex[1.9307493118589267`, -2.037333072756486]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5463246331431195`, 0.007025882918871681}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.499999999999996`, "A", 2, {
              Complex[4.5463246331431195`, 0.007025882918871681], 
              Complex[6.045167287063116, -1.1633328856106508`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8559867126628703, -0.5346576120369388}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 1, {
              Complex[0.8559867126628703, -0.5346576120369388], 
              Complex[1.9513735684640627`, -2.023067278104828]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5253142371097725`, 0.007110298008162873}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.599999999999998`, "A", 2, {
              Complex[4.5253142371097725`, 0.007110298008162873], 
              Complex[6.023558855884933, -1.163316510563181]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8757255721593927, -0.52287788641464}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 1, {
              Complex[0.8757255721593927, -0.52287788641464], 
              Complex[1.9709549506972748`, -2.009827028796298]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.5056658326490995`, 0.007196517077880139}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.7, "A", 2, {
              Complex[4.5056658326490995`, 0.007196517077880139], 
              Complex[6.003310291269154, -1.1632987794618457`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.8945689747906652, -0.5119589442981493}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 1, {
              Complex[0.8945689747906652, -0.5119589442981493], 
              Complex[1.9896739101964132`, -1.9974384540079684`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.487138168550514, 0.007284416332243672}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.799999999999997`, "A", 2, {
              Complex[4.487138168550514, 0.007284416332243672], 
              Complex[5.984180253839812, -1.1632798309089607`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9126523619522108, -0.5017701062164057}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 1, {
              Complex[0.9126523619522108, -0.5017701062164057], 
              Complex[2.007664340945304, -1.9857722832958542`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.469552623884141, 0.007373913179256361}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {16.9, "A", 2, {
              Complex[4.469552623884141, 0.007373913179256361], 
              Complex[5.965990045977094, -1.1632597604074917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9300797102089358, -0.4922109148816913}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 1, {
              Complex[0.9300797102089358, -0.4922109148816913], 
              Complex[2.02502886467753, -1.9747292562304524`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.452772601155936, 0.007464952252033912}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17., "A", 2, {
              Complex[4.452772601155936, 0.007464952252033912], 
              Complex[5.948603001807257, -1.1632386348615993`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9469329539089921, -0.48320212310888055`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 1, {
              Complex[0.9469329539089921, -0.48320212310888055`], 
              Complex[2.0418482129451156`, -1.964231155946584]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.436690887655669, 0.007557496991163237}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.099999999999998`, "A", 2, {
              Complex[4.436690887655669, 0.007557496991163237], 
              Complex[5.931911846413443, -1.1632165013453923`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9632780610078037, -0.47467987499817715`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 1, {
              Complex[0.9632780610078037, -0.47467987499817715`], 
              Complex[2.0581872738940445`, -1.9542150231143458`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.421221515937318, 0.0076515243225991425`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0076515243225991425`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.2, "A", 2, {
              Complex[4.421221515937318, 0.0076515243225991425`], 
              Complex[5.91583055481642, -1.1631933926704505`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9791691098460469, -0.46659179640833603`}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 1, {
              Complex[0.9791691098460469, -0.46659179640833603`], 
              Complex[2.0740991475740485`, -1.9446292707044912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.406294309063904, 0.007747021157202576}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.299999999999997`, "A", 2, {
              Complex[4.406294309063904, 0.007747021157202576], 
              Complex[5.900288896133161, -1.1631693310632665`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{0.9946511165926878, -0.45889427989730874`}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 1, {
              Complex[0.9946511165926878, -0.45889427989730874`], 
              Complex[2.089627957098805, -1.9354309873904427`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.391851102143664, 0.007843982012263403}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.4, "A", 2, {
              Complex[4.391851102143664, 0.007843982012263403], 
              Complex[5.885228654304801, -1.1631443306747422`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.009762051806893, -0.45155054573492875`}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 1, {
              Complex[1.009762051806893, -0.45155054573492875`], 
              Complex[2.1048108525831113`, -1.926584012895829]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.377843050837108, 0.007942407351021055}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.5, "A", 2, {
              Complex[4.377843050837108, 0.007942407351021055], 
              Complex[5.870600935988343, -1.1631183993398404`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.024534313536096, -0.4445292235923795}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 1, {
              Complex[1.024534313536096, -0.4445292235923795], 
              Complex[2.119679474265541, -1.918057531021162]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3642286676832285`, 0.00804230239670521}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.599999999999998`, "A", 2, {
              Complex[4.3642286676832285`, 0.00804230239670521], 
              Complex[5.856364206404795, -1.1630915398400685`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0389958259885552`, -0.43780329333443724`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 1, {
              Complex[1.0389958259885552`, -0.43780329333443724`], 
              Complex[2.134261043168297, -1.9098250195461783`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.350972359395372, 0.008143676269233574}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.7, "A", 2, {
              Complex[4.350972359395372, 0.008143676269233574], 
              Complex[5.842482826256841, -1.1630637508268273`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0531708739791161`, -0.43134927949335167`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 1, {
              Complex[1.0531708739791161`, -0.43134927949335167`], 
              Complex[2.148579189013272, -1.9018634521265043`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.338043317353644, 0.008246541346654037}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.799999999999997`, "A", 2, {
              Complex[4.338043317353644, 0.008246541346654037], 
              Complex[5.828925941917192, -1.1630350275077863`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0670807469468007`, -0.42514662876555165`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 1, {
              Complex[1.0670807469468007`, -0.42514662876555165`], 
              Complex[2.1626545888502187`, -1.8941526819126022`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.325414662407916, 0.008350912786611275}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.9, "A", 2, {
              Complex[4.325414662407916, 0.008350912786611275], 
              Complex[5.815666629983418, -1.1630053621640044`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0807442431495686`, -0.4191772220375579}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 1, {
              Complex[1.0807442431495686`, -0.4191772220375579], 
              Complex[2.176505466752442, -1.8866749586802045`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.3130627762344576`, 0.00845680816400054}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {17.999999999999996`, "A", 2, {
              Complex[4.3130627762344576`, 0.00845680816400054], 
              Complex[5.802681228429218, -1.1629747445437837`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.0941780694739518`, -0.41342498695323976`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 1, {
              Complex[1.0941780694739518`, -0.41342498695323976`], 
              Complex[2.19014798983231, -1.8794145456947622`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.300966771833883, 0.008564247194411541}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.099999999999998`, "A", 2, {
              Complex[4.300966771833883, 0.008564247194411541], 
              Complex[5.789948806930199, -1.1629431621652235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.107397162145414, -0.4078755867501416}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 1, {
              Complex[1.107397162145414, -0.4078755867501416], 
              Complex[2.203596585722576, -1.8723574121967355`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.289108069365748, 0.008673251522090971}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.2, "A", 2, {
              Complex[4.289108069365748, 0.008673251522090971], 
              Complex[5.777450742552286, -1.162910600549928]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1204149466885311`, -0.40251616773611126`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 1, {
              Complex[1.1204149466885311`, -0.40251616773611126`], 
              Complex[2.216864199765705, -1.8654909840009626`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.277470052807503, 0.008783844556995735}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.299999999999997`, "A", 2, {
              Complex[4.277470052807503, 0.008783844556995735], 
              Complex[5.765170376285118, -1.162877043404163]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1332435506568057`, -0.39733515240586337`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 1, {
              Complex[1.1332435506568057`, -0.39733515240586337`], 
              Complex[2.2299625053481065`, -1.8588039393045301`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.266037789390484, 0.008896051349858974}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.399999999999995`, "A", 2, {
              Complex[4.266037789390484, 0.008896051349858974], 
              Complex[5.75309273236891, -1.1628424727592266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1458939792326737`, -0.3923220684765709}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 1, {
              Complex[1.1458939792326737`, -0.3923220684765709], 
              Complex[2.242902077414907, -1.8522860400567256`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.254797798340199, 0.009009898497034034}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.499999999999996`, "A", 2, {
              Complex[4.254797798340199, 0.009009898497034034], 
              Complex[5.74120428693884, -1.1628068690797755`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1583762613396105`, -0.38746740648134814`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 1, {
              Complex[1.1583762613396105`, -0.38746740648134814`], 
              Complex[2.2556925367556313`, -1.8459279915891424`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.243737858735289, 0.009125414068990397}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.599999999999998`, "A", 2, {
              Complex[4.243737858735289, 0.009125414068990397], 
              Complex[5.729492775798816, -1.162770211346653]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1706995721155862`, -0.382762500281366}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 1, {
              Complex[1.1706995721155862`, -0.382762500281366], 
              Complex[2.268342670868865, -1.8397213249141577`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.232846848694921, 0.009242627557842213}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.7, "A", 2, {
              Complex[4.232846848694921, 0.009242627557842213], 
              Complex[5.717947033532342, -1.1627324771191423`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1828723362728408`, -0.378199426130277}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 1, {
              Complex[1.1828723362728408`, -0.378199426130277], 
              Complex[2.280860535897551, -1.8336582973639248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.222114609872632, 0.009361569840391626}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.8, "A", 2, {
              Complex[4.222114609872632, 0.009361569840391626], 
              Complex[5.706556857926958, -1.1626936425804282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.1949023158791763`, -0.3737709168766501}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 1, {
              Complex[1.1949023158791763`, -0.3737709168766501], 
              Complex[2.293253543143009, -1.8277318081869505`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.211531832555506, 0.009482273153986658}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.9, "A", 2, {
              Complex[4.211531832555506, 0.009482273153986658], 
              Complex[5.695312895009785, -1.162653682569165]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2067966853478913`, -0.369470288610321}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 1, {
              Complex[1.2067966853478913`, -0.369470288610321], 
              Complex[2.30552853292255, -1.8219353264340092`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.201089957665183, 0.009604771083122505}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {18.999999999999996`, "A", 2, {
              Complex[4.201089957665183, 0.009604771083122505], 
              Complex[5.684206540989641, -1.1626125705993822`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2185620958524552`, -0.36529137760862845`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 1, {
              Complex[1.2185620958524552`, -0.36529137760862845`], 
              Complex[2.317691837968342, -1.816262829010749]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.190781092718281, 0.009729098555121772}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.099999999999998`, "A", 2, {
              Complex[4.190781092718281, 0.009729098555121772], 
              Complex[5.67322985816244, -1.1625702788705317`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2302047309418311`, -0.3612284858628565}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 1, {
              Complex[1.2302047309418311`, -0.3612284858628565], 
              Complex[2.329749338128147, -1.8107087471951664`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.180597939390085, 0.00985529184370446}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.2, "A", 2, {
              Complex[4.180597939390085, 0.00985529184370446], 
              Complex[5.662375502422985, -1.1625267782689677`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2417303547902065`, -0.3572763337954378}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 1, {
              Complex[1.2417303547902065`, -0.3572763337954378], 
              Complex[2.3417065077888246`, -1.8052679202454833`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.170533730780807, 0.009983388579384763}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.299999999999997`, "A", 2, {
              Complex[4.170533730780807, 0.009983388579384763], 
              Complex[5.65163666048189, -1.1624820383620078`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.253144354246581, -0.35343001903737564`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 1, {
              Complex[1.253144354246581, -0.35343001903737564`], 
              Complex[2.3535684571772366`, -1.799935554980541]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.16058217684066, 0.010113427765967319`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.4, "A", 2, {
              Complex[4.16058217684066, 0.010113427765967319`], 
              Complex[5.6410069952433215`, -1.1624360273853815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.2644517756377363`, -0.34968498034029766`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 1, {
              Complex[1.2644517756377363`, -0.34968498034029766`], 
              Complex[2.3653399684829135`, -1.7947071904178555`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.1507374166916415`, 0.010245449802525813`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.499999999999996`, "A", 2, {
              Complex[4.1507374166916415`, 0.010245449802525813`], 
              Complex[5.630480598081044, -1.1623887122247345`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.275657357109484, -0.34603696586050564`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 1, {
              Complex[1.275657357109484, -0.34603696586050564`], 
              Complex[2.3770255275795726`, -1.7895786667158637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.140993976808082, 0.01037949651040012}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.599999999999998`, "A", 2, {
              Complex[4.140993976808082, 0.01037949651040012], 
              Complex[5.620051946974447, -1.162340058391703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.286765557155954, -0.34248200518323674`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 1, {
              Complex[1.286765557155954, -0.34248200518323674`], 
              Complex[2.388629351988557, -1.7845460977964305`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.131346734197311, 0.010515611164854463`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.7, "A", 2, {
              Complex[4.131346734197311, 0.010515611164854463`], 
              Complex[5.609715869645587, -1.162290029994955]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.297780579877745, -0.33901638456087957`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 1, {
              Complex[1.297780579877745, -0.33901638456087957`], 
              Complex[2.4001554156192917`, -1.7796058471281258`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.121790883866403, 0.010653838531129443`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.799999999999997`, "A", 2, {
              Complex[4.121790883866403, 0.010653838531129443`], 
              Complex[5.599467510982897, -1.1622385897064982`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3087063974214082`, -0.33563662492447366`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 1, {
              Complex[1.3087063974214082`, -0.33563662492447366`], 
              Complex[2.4116074707342525`, -1.774754506235453]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.11232190997813, 0.010794224904694102`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {19.9, "A", 2, {
              Complex[4.11232190997813, 0.010794224904694102`], 
              Complex[5.58930230415447, -1.1621856987234667`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.319546769980594, -0.3323394622978922}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 1, {
              Complex[1.319546769980594, -0.3323394622978922], 
              Complex[2.4229890675144987`, -1.7699888755685143`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.102935560194785, 0.010936818155564383`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20., "A", 2, {
              Complex[4.102935560194785, 0.010936818155564383`], 
              Complex[5.579215944909336, -1.1621313167255454`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3303052636801032`, -0.3291218303014382}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 1, {
              Complex[1.3303052636801032`, -0.3291218303014382], 
              Complex[2.434303571543257, -1.7653059474242632`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.093627822786881, 0.011081667776607964`}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.1, "A", 2, {
              Complex[4.093627822786881, 0.011081667776607964`], 
              Complex[5.569204368643545, -1.1620754018281332`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3409852666152733`, -0.32598084447903347`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 1, {
              Complex[1.3409852666152733`, -0.32598084447903347`], 
              Complex[2.4455541794767472`, -1.76070289065742]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.084394906148223, 0.011228824935798519`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.199999999999996`, "A", 2, {
              Complex[4.084394906148223, 0.011228824935798519`], 
              Complex[5.559263729872352, -1.1620179105312722`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.351590003278767, -0.32291378822242217`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 1, {
              Complex[1.351590003278767, -0.32291378822242217`], 
              Complex[2.45674393313144, -1.7561770369578598`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.075233220412342, 0.01137834253242333}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.299999999999997`, "A", 2, {
              Complex[4.075233220412342, 0.01137834253242333], 
              Complex[5.549390383803343, -1.1619587976643724`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.362122547573207, -0.319918100098616}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 1, {
              Complex[1.362122547573207, -0.319918100098616], 
              Complex[2.4678757321837086`, -1.7517258685037105`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.066139360909642, 0.01153027525727997}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.4, "A", 2, {
              Complex[4.066139360909642, 0.01153027525727997], 
              Complex[5.539580869749673, -1.1618980163266774`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3725858345799593`, -0.31699136241415216`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 1, {
              Complex[1.3725858345799593`, -0.31699136241415216`], 
              Complex[2.478952345649963, -1.7473470068263863`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.057110093241812, 0.011684679656931263`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.5, "A", 2, {
              Complex[4.057110093241812, 0.011684679656931263`], 
              Complex[5.529831896159836, -1.1618355178234179`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.382982671230815, -0.31413129087274266`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 1, {
              Complex[1.382982671230815, -0.31413129087274266`], 
              Complex[2.4899764222920577`, -1.7430382027464781`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.04814233978115, 0.011841614202115778`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.599999999999994`, "A", 2, {
              Complex[4.04814233978115, 0.011841614202115778`], 
              Complex[5.520140327071446, -1.1617712515975434`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.3933157460094145`, -0.3113357252023996}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 1, {
              Complex[1.3933157460094145`, -0.3113357252023996], 
              Complex[2.500950500073134, -1.7387973272586896`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.039233167428713, 0.012001139360437396`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.699999999999996`, "A", 2, {
              Complex[4.039233167428713, 0.012001139360437396`], 
              Complex[5.510503169822832, -1.161705165156914]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4035876377924137`, -0.3086026206444544}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 1, {
              Complex[1.4035876377924137`, -0.3086026206444544], 
              Complex[2.511877014772337, -1.7346223632600892`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.030379776487371, 0.012163317673485264`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.799999999999997`, "A", 2, {
              Complex[4.030379776487371, 0.012163317673485264`], 
              Complex[5.500917563878367, -1.1616372039967815`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4138008239261344`, -0.3059300402110024}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 1, {
              Complex[1.4138008239261344`, -0.3059300402110024], 
              Complex[2.522758307852828, -1.730511398029892]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.021579490524692, 0.012328213838552492`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {20.9, "A", 2, {
              Complex[4.021579490524692, 0.012328213838552492`], 
              Complex[5.491380770642325, -1.1615673115173932`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4239576876222573`, -0.3033161476291157}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 1, {
              Complex[1.4239576876222573`, -0.3033161476291157], 
              Complex[2.5335966336654483`, -1.726462616380607]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.012829747116558, 0.012495894795164358`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21., "A", 2, {
              Complex[4.012829747116558, 0.012495894795164358`], 
              Complex[5.4818901641520625`, -1.1614954289364903`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.434060524745711, -0.30075920090048514`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 1, {
              Complex[1.434060524745711, -0.30075920090048514`], 
              Complex[2.544394166060117, -1.7224742944105478`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{4.004128089376173, 0.012666429816627254`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.099999999999998`, "A", 2, {
              Complex[4.004128089376173, 0.012666429816627254`], 
              Complex[5.4724432225550075`, -1.1614214951964699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4441115500589816`, -0.29825754641387064`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 1, {
              Complex[1.4441115500589816`, -0.29825754641387064`], 
              Complex[2.5551530044682607`, -1.7185447937963199`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.995472158184808, 0.012839890606854708`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.2, "A", 2, {
              Complex[3.995472158184808, 0.012839890606854708`], 
              Complex[5.463037520285709, -1.161345446865949]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.454112902979397, -0.29580961355530405`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 1, {
              Complex[1.454112902979397, -0.29580961355530405`], 
              Complex[2.5658751795119747`, -1.7146725565713103`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.986859685050743, 0.013016351402742245`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.3, "A", 2, {
              Complex[3.986859685050743, 0.013016351402742245`], 
              Complex[5.45367072086924, -1.1612672180354269`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4640666528993398`, -0.29341390976756415`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 1, {
              Complex[1.4640666528993398`, -0.29341390976756415`], 
              Complex[2.5765626581891587`, -1.710856100342704]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9782884855315257`, 0.013195889082391367`}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.4, "A", 2, {
              Complex[3.9782884855315257`, 0.013195889082391367`], 
              Complex[5.444340570285955, -1.1611867402067302`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4739748041135785`, -0.29106901601605945`}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 1, {
              Complex[1.4739748041135785`, -0.29106901601605945`], 
              Complex[2.587217348678115, -1.70709401390507]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9697564531622382`, 0.01337858327951261}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.499999999999996`, "A", 2, {
              Complex[3.9697564531622382`, 0.01337858327951261], 
              Complex[5.435044890840143, -1.1611039421758809`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.483839300392978, -0.2887735826232169}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 1, {
              Complex[1.483839300392978, -0.2887735826232169], 
              Complex[2.5978411048003482`, -1.7033849532134366`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.961261553838926, 0.013564516504362838`}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.599999999999998`, "A", 2, {
              Complex[3.961261553838926, 0.013564516504362838`], 
              Complex[5.425781575481578, -1.1610187499090083`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.4936620292395204`, -0.28652632543776696`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 1, {
              Complex[1.4936620292395204`, -0.28652632543776696`], 
              Complex[2.608435730175939, -1.699727637683005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.952801820612012, 0.013753774271608805`}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.7, "A", 2, {
              Complex[3.952801820612012, 0.013753774271608805`], 
              Complex[5.416548582534638, -1.1609310864108733`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.503444825853813, -0.28432602230905957`}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 1, {
              Complex[1.503444825853813, -0.28432602230905957`], 
              Complex[2.61900298210226, -1.6961208467863342`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9443753488495013`, 0.01394644523553293}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.799999999999997`, "A", 2, {
              Complex[3.9443753488495013`, 0.01394644523553293], 
              Complex[5.407343930794649, -1.1608408715855623`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.513189476842979, -0.2821715098398555}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 1, {
              Complex[1.513189476842979, -0.2821715098398555], 
              Complex[2.6295445751835302`, -1.6925634169220722`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9359802917339604`, 0.01414262133304412}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.899999999999995`, "A", 2, {
              Complex[3.9359802917339604`, 0.01414262133304412], 
              Complex[5.398165694955262, -1.1607480220888433`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5228977236939458`, -0.280061680393945}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 1, {
              Complex[1.5228977236939458`, -0.280061680393945], 
              Complex[2.640062184735898, -1.6890542385321856`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.927614856061183, 0.014342397934981635`}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {21.999999999999996`, "A", 2, {
              Complex[3.927614856061183, 0.014342397934981635`], 
              Complex[5.389012001334582, -1.1606524511716514`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5325712660346489`, -0.2779954793374565}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 1, {
              Complex[1.5325712660346489`, -0.2779954793374565], 
              Complex[2.650557449990277, -1.685592253447088]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9192772983115907`, 0.014545874006250778`}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.099999999999998`, "A", 2, {
              Complex[3.9192772983115907`, 0.014545874006250778`], 
              Complex[5.379881023870964, -1.160554068514124]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5422117647034572`, -0.2759719024950626}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 1, {
              Complex[1.5422117647034572`, -0.2759719024950626], 
              Complex[2.6610319771130446`, -1.682176452440394]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.910965920968408, 0.014753152275367222`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.2, "A", 2, {
              Complex[3.910965920968408, 0.014753152275367222`], 
              Complex[5.3707709803622485`, -1.1604527800495485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5518208446451707`, -0.27398999380419353`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 1, {
              Complex[1.5518208446451707`, -0.27398999380419353`], 
              Complex[2.671487342062719, -1.678805872976879]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.9026790690591686`, 0.014964339414034983`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.3, "A", 2, {
              Complex[3.9026790690591686`, 0.014964339414034983`], 
              Complex[5.36168012892486, -1.1603484877775456`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5614000976502447`, -0.27204884315225314`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 1, {
              Complex[1.5614000976502447`, -0.27204884315225314`], 
              Complex[2.68192509329917, -1.675479597139089]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.894415126899331, 0.015179546227436329`}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.4, "A", 2, {
              Complex[3.894415126899331, 0.015179546227436329`], 
              Complex[5.352606764651277, -1.1602410895657407`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5709510849523987`, -0.27014758438335246`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 1, {
              Complex[1.5709510849523987`, -0.27014758438335246`], 
              Complex[2.692346754360388, -1.6721967497195438`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8861725150187785`, 0.015398887855965335`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.499999999999996`, "A", 2, {
              Complex[3.8861725150187785`, 0.015398887855965335`], 
              Complex[5.343549216446447, -1.1601304789391282`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5804753396984255`, -0.26828539346253044`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 1, {
              Complex[1.5804753396984255`, -0.26828539346253044`], 
              Complex[2.702753826320577, -1.668956496466899]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8779496872537016`, 0.015622483989198204`}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.599999999999998`, "A", 2, {
              Complex[3.8779496872537016`, 0.015622483989198204`], 
              Complex[5.334505844025381, -1.160016544856252]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5899743693028523`, -0.26646148678673565`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 1, {
              Complex[1.5899743693028523`, -0.26646148678673565`], 
              Complex[2.7131477901421976`, -1.6657580424757248`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8697451279879247`, 0.015850459092959818`}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.7, "A", 2, {
              Complex[3.8697451279879247`, 0.015850459092959818`], 
              Complex[5.325475035055748, -1.1598991714712619`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.5994496576990789`, -0.26467511963294016`}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 1, {
              Complex[1.5994496576990789`, -0.26467511963294016`], 
              Complex[2.7235301089335913`, -1.6626006307106493`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.861557349529051, 0.01608294265041592}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.799999999999997`, "A", 2, {
              Complex[3.861557349529051, 0.01608294265041592], 
              Complex[5.316455202430543, -1.1597782378808235`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6089026674977167`, -0.2629255847348713}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 1, {
              Complex[1.6089026674977167`, -0.2629255847348713], 
              Complex[2.733902230122971, -1.6594835406566912`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8533848896060525`, 0.0163200694182023}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.9, "A", 2, {
              Complex[3.8533848896060525`, 0.0163200694182023], 
              Complex[5.307444781657183, -1.1596536178547647`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6183348420620054`, -0.2612122109807513}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 1, {
              Complex[1.6183348420620054`, -0.2612122109807513], 
              Complex[2.7442655875587194`, -1.6564060870885489`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8452263089759486`, 0.01656197969868379}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {22.999999999999996`, "A", 2, {
              Complex[3.8452263089759486`, 0.01656197969868379], 
              Complex[5.2984422283503445`, -1.1595251795492592`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6277476075095596`, -0.2595343622253301}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 1, {
              Complex[1.6277476075095596`, -0.2595343622253301], 
              Complex[2.7546216035454134`, -1.653367618952437]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.837080189128189, 0.016808819629533064`}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.099999999999998`, "A", 2, {
              Complex[3.837080189128189, 0.016808819629533064`], 
              Complex[5.289446015816816, -1.159392785201224]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.637142374648998, -0.2578914362102892}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 1, {
              Complex[1.637142374648998, -0.2578914362102892], 
              Complex[2.7649716908242405`, -1.6503675183549187`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8289451300761326`, 0.017060741491919426`}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.199999999999996`, "A", 2, {
              Complex[3.8289451300761326`, 0.017060741491919426`], 
              Complex[5.280454632721417, -1.159256290802515]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6465205408595256`, -0.2562828635878306}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 1, {
              Complex[1.6465205408595256`, -0.2562828635878306], 
              Complex[2.7753172545061173`, -1.6474051996538635`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.820819748225798, 0.01731790403871422}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.299999999999997`, "A", 2, {
              Complex[3.820819748225798, 0.01731790403871422], 
              Complex[5.271466580823749, -1.1591155457523543`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6558834919210377`, -0.25470810704296915`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 1, {
              Complex[1.6558834919210377`, -0.25470810704296915`], 
              Complex[2.7856596939652984`, -1.644480108647397]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.812702674312651, 0.0175804728442376}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.4, "A", 2, {
              Complex[3.812702674312651, 0.0175804728442376], 
              Complex[5.262480372776144, -1.158970392486303]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6652326038019236`, -0.2531666605106765}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 1, {
              Complex[1.6652326038019236`, -0.2531666605106765], 
              Complex[2.796000404700961, -1.6415917218573375`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.8045925513977634`, 0.017848620677213583`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.5, "A", 2, {
              Complex[3.8045925513977634`, 0.017848620677213583`], 
              Complex[5.253494529973697, -1.1588206660799292`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6745692444113933`, -0.251658048484637}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 1, {
              Complex[1.6745692444113933`, -0.251658048484637], 
              Complex[2.8063407801738802`, -1.6387395459042156`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.796488032915171, 0.018122527898744724`}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.6, "A", 2, {
              Complex[3.796488032915171, 0.018122527898744724`], 
              Complex[5.244507580447731, -1.158666193825158]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6838947753228468`, -0.25018182541497563`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 1, {
              Complex[1.6838947753228468`, -0.25018182541497563`], 
              Complex[2.816682213625116, -1.635923116971627]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7883877807626547`, 0.018402382887287773`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.699999999999996`, "A", 2, {
              Complex[3.7883877807626547`, 0.018402382887287773`], 
              Complex[5.235518056794404, -1.1585067947770962`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.6932105534745874`, -0.2487375751928472}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 1, {
              Complex[1.6932105534745874`, -0.2487375751928472], 
              Complex[2.8270260998834287`, -1.6331420003581567`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7802904634285417`, 0.018688382492788227`}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.799999999999997`, "A", 2, {
              Complex[3.7802904634285417`, 0.018688382492788227`], 
              Complex[5.226524494130514, -1.158342279268929]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7025179328539397`, -0.2473249107203387}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 1, {
              Complex[1.7025179328539397`, -0.2473249107203387], 
              Complex[2.8373738371679282`, -1.6303957901157322`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.772194754147412, 0.018980732522336802`}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {23.9, "A", 2, {
              Complex[3.772194754147412, 0.018980732522336802`], 
              Complex[5.217525428068778, -1.1581724483922544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.711818266170711, -0.24594347356467736`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 1, {
              Complex[1.711818266170711, -0.24594347356467736`], 
              Complex[2.8477268288924487`, -1.627684108773821]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7640993290778377`, 0.019279648259930993`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24., "A", 2, {
              Complex[3.7640993290778377`, 0.019279648259930993`], 
              Complex[5.208519392705085, -1.1579970934399617`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7211129065258053`, -0.2445929336962447}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 1, {
              Complex[1.7211129065258053`, -0.2445929336962447], 
              Complex[2.8580864854780335`, -1.6250066071493976`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7560028654954856`, 0.01958535502317048}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.099999999999994`, "A", 2, {
              Complex[3.7560028654954856`, 0.01958535502317048], 
              Complex[5.199504918610364, -1.1578159953084994`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7304032090806973`, -0.24327298931041993`}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 1, {
              Complex[1.7304032090806973`, -0.24327298931041993`], 
              Complex[2.8684542261798467`, -1.6223629642431867`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.747904039995082, 0.01989808875998759}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.199999999999996`, "A", 2, {
              Complex[3.747904039995082, 0.01989808875998759], 
              Complex[5.190480530819805, -1.1576289238560522`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.739690532733481, -0.24198336673385532`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 1, {
              Complex[1.739690532733481, -0.24198336673385532`], 
              Complex[2.8788314809349784`, -1.6197528872232836`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.739801526694796, 0.020218096688815523`}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.299999999999997`, "A", 2, {
              Complex[3.739801526694796, 0.020218096688815523`], 
              Complex[5.181444746812216, -1.157435637212811]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7489762418071482`, -0.24072382041628856`}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 1, {
              Complex[1.7489762418071482`, -0.24072382041628856`], 
              Complex[2.889219692237537, -1.6171761114978094`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7316939954367316`, 0.020545637985933}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.4, "A", 2, {
              Complex[3.7316939954367316`, 0.020545637985933], 
              Complex[5.1723960744723065`, -1.1572358810391412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.758261707755823, -0.23949413300958816`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 1, {
              Complex[1.758261707755823, -0.23949413300958816`], 
              Complex[2.8996203170476376`, -1.6146324008788797`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.723580109977185, 0.020880984524095002`}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.499999999999996`, "A", 2, {
              Complex[3.723580109977185, 0.020880984524095002`], 
              Complex[5.163333010028643, -1.1570293877270226`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7675483108947163`, -0.2382941155363085}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 1, {
              Complex[1.7675483108947163`, -0.2382941155363085], 
              Complex[2.910034828740952, -1.6121215478408175`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.7154585261603414`, 0.021224421666976207`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.599999999999998`, "A", 2, {
              Complex[3.7154585261603414`, 0.021224421666976207`], 
              Complex[5.1542540359599105`, -1.156815875539666]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.776837442159661, -0.23712360765068694`}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 1, {
              Complex[1.776837442159661, -0.23712360765068694`], 
              Complex[2.920464719105737, -1.6096433738762477`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.707327890069032, 0.02157624912441267}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.7, "A", 2, {
              Complex[3.707327890069032, 0.02157624912441267], 
              Complex[5.145157618862019, -1.156595047683686]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7861305049022496`, -0.23598247799562685`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 1, {
              Complex[1.7861305049022496`, -0.23598247799562685`], 
              Complex[2.930911500394467, -1.6071977299543905`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6991868361460636`, 0.021936781873947247`}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.8, "A", 2, {
              Complex[3.6991868361460636`, 0.021936781873947247`], 
              Complex[5.136042207268361, -1.1563665913076095`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.7954289167267061`, -0.23487062465998598`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 1, {
              Complex[1.7954289167267061`, -0.23487062465998598`], 
              Complex[2.9413767074374184`, -1.6047844970867333`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6910339852795406`, 0.022306351154756415`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.9, "A", 2, {
              Complex[3.6910339852795406`, 0.022306351154756415`], 
              Complex[5.126906229415363, -1.1561301764198544`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8047341113748927`, -0.23378797574120985`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 1, {
              Complex[1.8047341113748927`, -0.23378797574120985`], 
              Complex[2.9518618998259756`, -1.6024035870060647`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6828679428453777`, 0.022685305540684448`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {24.999999999999996`, "A", 2, {
              Complex[3.6828679428453777`, 0.022685305540684448`], 
              Complex[5.117748090945093, -1.1558854547185569`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.814047540666005, -0.23273449001922963`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 1, {
              Complex[1.814047540666005, -0.23273449001922963`], 
              Complex[2.962368664173644, -1.6000549429658453`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6746872967000694`, 0.0230740120998302}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.099999999999998`, "A", 2, {
              Complex[3.6746872967000694`, 0.0230740120998302], 
              Complex[5.1085661725364995`, -1.155632058324808]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8233706764978728`, -0.2317101577484136}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 1, {
              Complex[1.8233706764978728`, -0.2317101577484136], 
              Complex[2.9728986164633167`, -1.5977385406678668`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6664906151164782`, 0.023472857648944835`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.199999999999996`, "A", 2, {
              Complex[3.6664906151164782`, 0.023472857648944835`], 
              Complex[5.099358827456356, -1.1553695984099268`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8327050129169915`, -0.23071500157543248`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 1, {
              Complex[1.8327050129169915`, -0.23071500157543248`], 
              Complex[2.983453404489649, -1.5954543893273732`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6582764446551637`, 0.023882250111808095`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.299999999999997`, "A", 2, {
              Complex[3.6582764446551637`, 0.023882250111808095`], 
              Complex[5.090124379020649, -1.1550976637063444`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8420520682648396`, -0.22974907759194238`}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 1, {
              Complex[1.8420520682648396`, -0.22974907759194238`], 
              Complex[2.9940347104060323`, -1.5932025328859922`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6500433079634345`, 0.02430261999177399}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.399999999999995`, "A", 2, {
              Complex[3.6500433079634345`, 0.02430261999177399], 
              Complex[5.080861117956597, -1.15481581889049]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8514133874083418`, -0.22881247653229805`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 1, {
              Complex[1.8514133874083418`, -0.22881247653229805`], 
              Complex[3.0046442533860986`, -1.5909830513843415`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.64178970149396, 0.024734421969833987`}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.499999999999996`, "A", 2, {
              Complex[3.64178970149396, 0.024734421969833987`], 
              Complex[5.071567299655017, -1.154523602824754]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.860790544062835, -0.2279053251278246}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 1, {
              Complex[1.860790544062835, -0.2279053251278246], 
              Complex[3.0152837924104205`, -1.58879606250765]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.633514093134369, 0.025178136640842893`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.599999999999998`, "A", 2, {
              Complex[3.633514093134369, 0.025178136640842893`], 
              Complex[5.0622411413021275`, -1.1542205266440742`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8701851432162653`, -0.22702778763077072`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 1, {
              Complex[1.8701851432162653`, -0.22702778763077072`], 
              Complex[3.0259551291896356`, -1.586641723319602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.625214919738834, 0.025634272402031196`}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.7, "A", 2, {
              Complex[3.625214919738834, 0.025634272402031196`], 
              Complex[5.052880818879211, -1.1539060716710012`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8795988236639012`, -0.22618006752276323`}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 1, {
              Complex[1.8795988236639012`, -0.22618006752276323`], 
              Complex[3.036660111236013, -1.5845202322015446`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6168905845521655`, 0.0261033675095845}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.799999999999997`, "A", 2, {
              Complex[3.6168905845521655`, 0.0261033675095845], 
              Complex[5.043484464017904, -1.1535796871411728`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8890332606633722`, -0.22536240942454516`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 1, {
              Complex[1.8890332606633722`, -0.22536240942454516`], 
              Complex[3.047400635096297, -1.582431831016463]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6085394545164045`, 0.026585992320965875`}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {25.9, "A", 2, {
              Complex[3.6085394545164045`, 0.026585992320965875`], 
              Complex[5.034050160698048, -1.1532407877189192`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.8984901687203608`, -0.2245751012259816}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 1, {
              Complex[1.8984901687203608`, -0.2245751012259816], 
              Complex[3.0581786497594123`, -1.580376807519702]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.6001598574493725`, 0.027082751742796535`}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26., "A", 2, {
              Complex[3.6001598574493725`, 0.027082751742796535`], 
              Complex[5.024575941774229, -1.1528887507802408`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9079713045159428`, -0.22381847645779898`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 1, {
              Complex[1.9079713045159428`, -0.22381847645779898`], 
              Complex[3.0689961602536635`, -1.5783554980412648`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5917500790840515`, 0.02759428790654434}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.099999999999998`, "A", 2, {
              Complex[3.5917500790840515`, 0.02759428790654434], 
              Complex[5.015059785316232, -1.1525229134375576`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9174784699871426`, -0.22309291692935715`}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 1, {
              Complex[1.9174784699871426`, -0.22309291692935715`], 
              Complex[3.0798552314489034`, -1.5763682904678329`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.583308359957026, 0.02812128309705336}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.2, "A", 2, {
              Complex[3.583308359957026, 0.02812128309705336], 
              Complex[5.005499610747706, -1.1521425692773901`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.927013515572947, -0.22239885565995451`}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 1, {
              Complex[1.927013515572947, -0.22239885565995451`], 
              Complex[3.0907579920802752`, -1.57441562755638]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5748328921336294`, 0.02866446296210389}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.299999999999997`, "A", 2, {
              Complex[3.5748328921336294`, 0.02866446296210389], 
              Complex[4.99589327476625, -1.151746964778438]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9365783436386594`, -0.22173678013483558`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 1, {
              Complex[1.9365783436386594`, -0.22173678013483558`], 
              Complex[3.1017066390111165`, -1.572498010615533]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.566321815756732, 0.029224600034819154`}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.399999999999995`, "A", 2, {
              Complex[3.566321815756732, 0.029224600034819154`], 
              Complex[4.986238567027153, -1.1513352953732716`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9461749120921603`, -0.22110723592124693`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 1, {
              Complex[1.9461749120921603`, -0.22110723592124693`], 
              Complex[3.112703441753819, -1.5706160035957246`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.557773215405521, 0.029802517604874564`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.499999999999996`, "A", 2, {
              Complex[3.557773215405521, 0.029802517604874564`], 
              Complex[4.976533205571878, -1.1509067011120162`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9558052382062334`, -0.22051083068468325`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 1, {
              Complex[1.9558052382062334`, -0.22051083068468325`], 
              Complex[3.123750747268464, -1.5687702376348136`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5491851162499515`, 0.030399093979211273`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.599999999999998`, "A", 2, {
              Complex[3.5491851162499515`, 0.030399093979211273`], 
              Complex[4.966774831981249, -1.1504602618808104`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.965471402661748, -0.21994823865092936`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 1, {
              Complex[1.965471402661748, -0.21994823865092936`], 
              Complex[3.1348509850602824`, -1.56696141611226]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.540555479985998, 0.031015267178413904`}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.699999999999996`, "A", 2, {
              Complex[3.540555479985998, 0.031015267178413904`], 
              Complex[4.956961006232221, -1.149994992121425]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9751755538269593`, -0.21942020556585135`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 1, {
              Complex[1.9751755538269593`, -0.21942020556585135`], 
              Complex[3.1460066725980353`, -1.5651903202724227`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.531882200536309, 0.031652040121196476`}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.799999999999997`, "A", 2, {
              Complex[3.531882200536309, 0.031652040121196476`], 
              Complex[4.947089201235956, -1.149509834990993]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.984919912288591, -0.2189275542121152}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 1, {
              Complex[1.984919912288591, -0.2189275542121152], 
              Complex[3.157220421076432, -1.563457815486074]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5231630995005294`, 0.03231048635665899}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {26.9, "A", 2, {
              Complex[3.5231630995005294`, 0.03231048635665899], 
              Complex[4.937156797033987, -1.1490036558923022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{1.9947067756505623`, -0.21847119055042036`}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 1, {
              Complex[1.9947067756505623`, -0.21847119055042036`], 
              Complex[3.168494941546649, -1.561764858229167]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.5143959213393177`, 0.03299175641234993}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27., "A", 2, {
              Complex[3.5143959213393177`, 0.03299175641234993], 
              Complex[4.927161074628285, -1.1484752352951793`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.004538523616137, -0.21805211056251306`}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 1, {
              Complex[2.004538523616137, -0.21805211056251306`], 
              Complex[3.179833051439644, -1.5601125038693653`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.505578328276208, 0.03369708483581626}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.1, "A", 2, {
              Complex[3.505578328276208, 0.03369708483581626], 
              Complex[4.917099209420432, -1.1479232607580627`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.014417623368864, -0.21767140788446343`}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 1, {
              Complex[2.014417623368864, -0.21767140788446343`], 
              Complex[3.191237681507362, -1.5585019153641586`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4967078949018573`, 0.03442779801852968}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.2, "A", 2, {
              Complex[3.4967078949018573`, 0.03442779801852968], 
              Complex[4.9069682642347, -1.147346318045541]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0243466352667068`, -0.21733028233169743`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 1, {
              Complex[2.0243466352667068`, -0.21733028233169743`], 
              Complex[3.2027118832068138`, -1.556934372989885]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4877821024662152`, 0.035185322904060734`}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.299999999999997`, "A", 2, {
              Complex[3.4877821024662152`, 0.035185322904060734`], 
              Complex[4.896765181899932, -1.1467428812221832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.034328218862186, -0.2170300494324249}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 1, {
              Complex[2.034328218862186, -0.2170300494324249], 
              Complex[3.2142588365513363`, -1.5554112852390447`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.478798332845711, 0.03597119669747849}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.4, "A", 2, {
              Complex[3.478798332845711, 0.03597119669747849], 
              Complex[4.886486777365878, -1.1461113015849471`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0443651392587743`, -0.2167721511036576}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 1, {
              Complex[2.0443651392587743`, -0.2167721511036576], 
              Complex[3.225881858451649, -1.5539342010442934`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.469753862175173, 0.036787077710537186`}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.499999999999993`, "A", 2, {
              Complex[3.469753862175173, 0.036787077710537186`], 
              Complex[4.876129729331248, -1.1454497952754266`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.054460273810074, -0.2165581676245985}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 1, {
              Complex[2.054460273810074, -0.2165581676245985], 
              Complex[3.2375844115665666`, -1.5525048235121883`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.460645854137856, 0.03763475749771081}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.599999999999994`, "A", 2, {
              Complex[3.460645854137856, 0.03763475749771081], 
              Complex[4.8656905713635386`, -1.1447564293886006`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0646166191629156`, -0.21638983108607387`}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 1, {
              Complex[2.0646166191629156`, -0.21638983108607387`], 
              Complex[3.2493701136786943`, -1.5511250253784847`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4514713529124292`, 0.03851617446207811}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.699999999999996`, "A", 2, {
              Complex[3.4514713529124292`, 0.03851617446207811], 
              Complex[4.855165682495277, -1.144029106365958]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0748372986380015`, -0.2162690405227275}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 1, {
              Complex[2.0748372986380015`, -0.2162690405227275], 
              Complex[3.261242747603761, -1.5497968664306097`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.442227275783197, 0.03943342913804209}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.799999999999997`, "A", 2, {
              Complex[3.442227275783197, 0.03943342913804209], 
              Complex[4.844551277287891, -1.1432655464271397`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0851255699314044`, -0.21619787896744103`}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 1, {
              Complex[2.0851255699314044`, -0.21619787896744103`], 
              Complex[3.2732062716325756`, -1.5485226131825367`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4329104054302233`, 0.04038880139063529}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.9, "A", 2, {
              Complex[3.4329104054302233`, 0.04038880139063529], 
              Complex[4.833843395364207, -1.142463267754563]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.0954848331061537`, -0.21617863270584692`}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 1, {
              Complex[2.0954848331061537`, -0.21617863270584692`], 
              Complex[3.2852648304909695`, -1.5473047611339121`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.423517381930075, 0.04138476980950441}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {27.999999999999996`, "A", 2, {
              Complex[3.423517381930075, 0.04138476980950441], 
              Complex[4.823037890424123, -1.141619564099015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1059186388242215`, -0.21621381305374038`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 1, {
              Complex[2.1059186388242215`, -0.21621381305374038`], 
              Complex[3.297422766784158, -1.5461460599999757`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4140446945168277`, 0.042424033620649226`}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.099999999999998`, "A", 2, {
              Complex[3.4140446945168277`, 0.042424033620649226`], 
              Complex[4.812130418776984, -1.1407314794193448`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.116430696743796, -0.21630618103294583`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 1, {
              Complex[2.116430696743796, -0.21630618103294583`], 
              Complex[3.3096846328660456`, -1.545049542363364]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.4044886731783923`, 0.043509537491681564`}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.2, "A", 2, {
              Complex[3.4044886731783923`, 0.043509537491681564`], 
              Complex[4.801116427450052, -1.1397957791050333`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.127024883972908, -0.21645877538292152`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 1, {
              Complex[2.127024883972908, -0.21645877538292152`], 
              Complex[3.3220552030387194`, -1.5440185562746338`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3948454801970804`, 0.044644499668114825`}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.3, "A", 2, {
              Complex[3.3948454801970804`, 0.044644499668114825`], 
              Complex[4.78999114196779, -1.1388089172545464`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.137705253425444, -0.21667494441768215`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 1, {
              Complex[2.137705253425444, -0.21667494441768215`], 
              Complex[3.3345394859397897`, -1.5430568024175473`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3851111017883304`, 0.045832443950466685`}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.399999999999995`, "A", 2, {
              Complex[3.3851111017883304`, 0.045832443950466685`], 
              Complex[4.778749553944276, -1.1377669993932331`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1484760418658873`, -0.21695838232209172`}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 1, {
              Complex[2.1484760418658873`, -0.21695838232209172`], 
              Complex[3.347142736911111, -1.54216837655994]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3752813400511936`, 0.04707723610641603}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.499999999999996`, "A", 2, {
              Complex[3.3752813400511936`, 0.04707723610641603], 
              Complex[4.767386408695089, -1.1366657399097988`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.15934167735015, -0.21731317057992383`}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 1, {
              Complex[2.15934167735015, -0.21731317057992383`], 
              Complex[3.359870470056671, -1.5413578181336938`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.365351805523236, 0.04838312541060397}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.599999999999998`, "A", 2, {
              Complex[3.365351805523236, 0.04838312541060397], 
              Complex[4.755896193160949, -1.1355004133676159`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.170306785665302, -0.21774382534019746`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 1, {
              Complex[2.170306785665302, -0.21774382534019746`], 
              Complex[3.3727284695824946`, -1.5406301659307429`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3553179107369844`, 0.049754792118764775`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.699999999999996`, "A", 2, {
              Complex[3.3553179107369844`, 0.049754792118764775`], 
              Complex[4.744273124550122, -1.1342657987037832`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.181376195232895, -0.2182553516597405}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 1, {
              Complex[2.181376195232895, -0.2182553516597405], 
              Complex[3.3857227998582564`, -1.539991022068634]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.345174865313174, 0.0511974018142957}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.799999999999994`, "A", 2, {
              Complex[3.345174865313174, 0.0511974018142957], 
              Complex[4.7325111402598825`, -1.1329561151622776`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.1925549397581063`, -0.21885330570991673`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 1, {
              Complex[2.1925549397581063`, -0.21885330570991673`], 
              Complex[3.398859813435927, -1.5394466255711594`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3349176733086154`, 0.052716667715368405`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.899999999999995`, "A", 2, {
              Complex[3.3349176733086154`, 0.052716667715368405`], 
              Complex[4.720603889841739, -1.1315649486154922`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2038482576658165`, -0.2195438662043097}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 1, {
              Complex[2.2038482576658165`, -0.2195438662043097], 
              Complex[3.4121461559885473`, -1.5390039371286066`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3245411337774544`, 0.05431892219952697}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {28.999999999999996`, "A", 2, {
              Complex[3.3245411337774544`, 0.05431892219952697], 
              Complex[4.70854473004717, -1.130085166709498]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2152615870464745`, -0.2203339164903331}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 1, {
              Complex[2.2152615870464745`, -0.2203339164903331], 
              Complex[3.4255887667699536`, -1.538670736847748]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.314039845823023, 0.05601119898888117}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.099999999999998`, "A", 2, {
              Complex[3.314039845823023, 0.05601119898888117], 
              Complex[4.696326724353138, -1.12850882102276]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2268005544144556`, -0.22123113894674887`}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 1, {
              Complex[2.2268005544144556`, -0.22123113894674887`], 
              Complex[3.4391948727143977`, -1.5384557370705048`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.3034082198375003`, 0.05780132763801396}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.2, "A", 2, {
              Complex[3.3034082198375003`, 0.05780132763801396], 
              Complex[4.683942648848311, -1.1268270341592392`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.23847095502768, -0.2222441235311438}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 1, {
              Complex[2.23847095502768, -0.2222441235311438], 
              Complex[3.452971973654928, -1.5383687126232317`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.292640497180628, 0.059698042168788046`}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.299999999999997`, "A", 2, {
              Complex[3.292640497180628, 0.059698042168788046`], 
              Complex[4.671385007001143, -1.1250298694138172`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.250278721787946, -0.22338249250843553`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 1, {
              Complex[2.250278721787946, -0.22338249250843553`], 
              Complex[3.466927815290494, -1.5384206511375549`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2817307812779952`, 0.061711105883242925`}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.4, "A", 2, {
              Complex[3.2817307812779952`, 0.061711105883242925`], 
              Complex[4.658646056679823, -1.1231061803689852`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2622298787838817`, -0.2246570435317342}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 1, {
              Complex[2.2622298787838817`, -0.2246570435317342], 
              Complex[3.4810703454089253`, -1.5386239263253452`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.270673084076976, 0.06385145452602974}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.5, "A", 2, {
              Complex[3.270673084076976, 0.06385145452602974], 
              Complex[4.645717853916905, -1.1210434375401022`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.274330474286138, -0.22607991328743204`}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 1, {
              Complex[2.274330474286138, -0.22607991328743204`], 
              Complex[3.49540764739327, -1.538992497237254]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2594613930506555`, 0.06613136000835836}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.599999999999998`, "A", 2, {
              Complex[3.2594613930506555`, 0.06613136000835836], 
              Complex[4.6325923193910725`, -1.1188275290397074`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2865864863773204`, -0.2276647637711871}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 1, {
              Complex[2.2865864863773204`, -0.2276647637711871], 
              Complex[3.5099478431009334`, -1.5395421364907365`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2480897655672782`, 0.06856461676025145}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.699999999999996`, "A", 2, {
              Complex[3.2480897655672782`, 0.06856461676025145], 
              Complex[4.619261335536663, -1.1164425322748186`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.2990036923040837`, -0.2294269927942462}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 1, {
              Complex[2.2990036923040837`, -0.2294269927942462], 
              Complex[3.524698954687548, -1.5402906900657316`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.23655245953774, 0.07116675231062944}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.799999999999997`, "A", 2, {
              Complex[3.23655245953774, 0.07116675231062944], 
              Complex[4.605716884708899, -1.1138704540789917`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.311587489979285, -0.23138396931833907`}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 1, {
              Complex[2.311587489979285, -0.23138396931833907`], 
              Complex[3.539668711719687, -1.54125837029078]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.2248441119132174`, 0.07395526269357484}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.899999999999995`, "A", 2, {
              Complex[3.2248441119132174`, 0.07395526269357484], 
              Complex[4.591951242060749, -1.1110909376562412`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.324342656755631, -0.2335552923600304}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 1, {
              Complex[2.324342656755631, -0.2335552923600304], 
              Complex[3.554864285859265, -1.5424680817046263`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.212959979911501, 0.07694987142173919}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {29.999999999999996`, "A", 2, {
              Complex[3.212959979911501, 0.07694987142173919], 
              Complex[4.577957240848535, -1.1080809366516995`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3372730266129884`, -0.2359630690132302}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 1, {
              Complex[2.3372730266129884`, -0.2359630690132302], 
              Complex[3.5702919304393554`, -1.543945776013632]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.20089626382986, 0.0801728075757009}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.099999999999998`, "A", 2, {
              Complex[3.20089626382986, 0.0801728075757009], 
              Complex[4.563728632846572, -1.1048143601285867`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3503810623577226`, -0.23863220192231419`}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 1, {
              Complex[2.3503810623577226`, -0.23863220192231419`], 
              Complex[3.5859564964599824`, -1.545720826549354]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.18865053484601, 0.08364909334179278}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.199999999999996`, "A", 2, {
              Complex[3.18865053484601, 0.08364909334179278], 
              Complex[4.549260572342168, -1.1012616980470777`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3636672947096224`, -0.24159066834690415`}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 1, {
              Complex[2.3636672947096224`, -0.24159066834690415`], 
              Complex[3.6018607902943125`, -1.547826403307316]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.176222295931689, 0.08740682313953917}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.299999999999997`, "A", 2, {
              Complex[3.176222295931689, 0.08740682313953917], 
              Complex[4.534550258420687, -1.0973896461639485`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3771295961517165`, -0.24486976056502352`}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 1, {
              Complex[2.3771295961517165`, -0.24486976056502352`], 
              Complex[3.6180047326806646`, -1.5502998152929637`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1636137080034565`, 0.09147740408549974}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.4, "A", 2, {
              Complex[3.1636137080034565`, 0.09147740408549974], 
              Complex[4.519597775965093, -1.093160763626926]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.3907622559358295`, -0.24850423935263424`}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 1, {
              Complex[2.3907622559358295`, -0.24850423935263424`], 
              Complex[3.634384275397017, -1.5531827657019448`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1508305149179034`, 0.09589570953158899}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.5, "A", 2, {
              Complex[3.1508305149179034`, 0.09589570953158899], 
              Complex[4.504407178973381, -1.0885332177365603`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.404554826889628, -0.25253232740394693`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 1, {
              Complex[2.404554826889628, -0.25253232740394693`], 
              Complex[3.6509900350811173`, -1.5565214356849029`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.137883196665494, 0.10070007254234226`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.599999999999998`, "A", 2, {
              Complex[3.137883196665494, 0.10070007254234226`], 
              Complex[4.488987856730723, -1.083460700125328]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4184907299124174`, -0.2569954375693104}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 1, {
              Complex[2.4184907299124174`, -0.2569954375693104], 
              Complex[3.66780561916792, -1.560366273382241]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.124788364875778, 0.1059320141880026}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.699999999999996`, "A", 2, {
              Complex[3.124788364875778, 0.1059320141880026], 
              Complex[4.473356207864622, -1.0778926376684699`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4325456359616355`, -0.26193749411720374`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 1, {
              Complex[2.4325456359616355`, -0.26193749411720374`], 
              Complex[3.6848056561525757`, -1.564771318831329]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.1115703808320068`, 0.11163556486001101`}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.799999999999997`, "A", 2, {
              Complex[3.1115703808320068`, 0.11163556486001101`], 
              Complex[4.4575376100748025`, -1.071774867524016]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4466857074528354`, -0.2674036718059935}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 1, {
              Complex[2.4466857074528354`, -0.2674036718059935], 
              Complex[3.7019536132591475`, -1.56979285088015]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.098263114072366, 0.11785600339463051`}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.9, "A", 2, {
              Complex[3.098263114072366, 0.11785600339463051`], 
              Complex[4.44156860245767, -1.0650509901679486`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4608658796691665`, -0.2734383645589258}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 1, {
              Complex[2.4608658796691665`, -0.2734383645589258], 
              Complex[3.719199600336585, -1.5754871190552318`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.084911660981808, 0.1246378257982292}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {30.999999999999993`, "A", 2, {
              Complex[3.084911660981808, 0.1246378257982292], 
              Complex[4.425499081603797, -1.0576646374765921`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4750284976365355`, -0.28008223230347307`}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 1, {
              Complex[2.4750284976365355`, -0.28008223230347307`], 
              Complex[3.736478521301466, -1.58190695616248]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.071573707918281, 0.1320217921353984}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.099999999999994`, "A", 2, {
              Complex[3.071573707918281, 0.1320217921353984], 
              Complex[4.409394150148913, -1.0495628600775766`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.4891027727434665`, -0.2873682998621285}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 1, {
              Complex[2.4891027727434665`, -0.2873682998621285], 
              Complex[3.7537091204741744`, -1.5890972039111015`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0583200745943513`, 0.1400410254670661}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.199999999999996`, "A", 2, {
              Complex[3.0583200745943513`, 0.1400410254670661], 
              Complex[4.393335070431694, -1.040700701679103]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5030056270697787`, -0.29531732776612113`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 1, {
              Complex[2.5030056270697787`, -0.29531732776612113`], 
              Complex[3.770794613325989, -1.5970891666976441`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0452338697500734`, 0.14871638271009868`}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.299999999999997`, "A", 2, {
              Complex[3.0452338697500734`, 0.14871638271009868`], 
              Complex[4.377418633740917, -1.0310467452404806`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5166444532991594`, -0.3039330313949986}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 1, {
              Complex[2.5166444532991594`, -0.3039330313949986], 
              Complex[3.787625571970204, -1.605894733710108]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.032407731242035, 0.1580516738214428}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.4, "A", 2, {
              Complex[3.032407731242035, 0.1580516738214428], 
              Complex[4.361754274818786, -1.0205889908238692`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5299220300509884`, -0.31319809514055186`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 1, {
              Complex[2.5299220300509884`, -0.31319809514055186`], 
              Complex[3.8040854242836235`, -1.615501270452578]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.0199389107132126`, 0.16802967600526134`}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.499999999999996`, "A", 2, {
              Complex[3.0199389107132126`, 0.16802967600526134`], 
              Complex[4.34645857273412, -1.0093399640268068`]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5427432708771702`, -0.3230721172560292}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 1, {
              Complex[2.5427432708771702`, -0.3230721172560292], 
              Complex[3.8200582761098674`, -1.6258686488669851`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{3.007922524597889, 0.17861007860412123`}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.599999999999998`, "A", 2, {
              Complex[3.007922524597889, 0.17861007860412123`], 
              Complex[4.331647428673965, -0.9973396858188015]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5550227978429705`, -0.33349241406049857`}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 1, {
              Complex[2.5550227978429705`, -0.33349241406049857`], 
              Complex[3.8354379364471782`, -1.6369295948434275`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.996443980542599, 0.1897302873440814}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.7, "A", 2, {
              Complex[2.996443980542599, 0.1897302873440814], 
              Complex[4.317427040750872, -0.984655324990569]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5666918389490667`, -0.3443779449095298}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 1, {
              Complex[2.5666918389490667`, -0.3443779449095298], 
              Complex[3.8501363909766324`, -1.648593781537542]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9855720799859258`, 0.20130934934494918`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.8, "A", 2, {
              Complex[2.9855720799859258`, 0.20130934934494918`], 
              Complex[4.303885430470007, -0.971377104797334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5777029731444694`, -0.35563571212946193`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 1, {
              Complex[2.5777029731444694`, -0.35563571212946193`], 
              Complex[3.864089926301709, -1.6607550217891218`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9753542731474694`, 0.21325435309295854`}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.899999999999995`, "A", 2, {
              Complex[2.9753542731474694`, 0.21325435309295854`], 
              Complex[4.291086318485069, -0.9576111105020115]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.588031851130083, -0.3671682712416466}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 1, {
              Complex[2.588031851130083, -0.3671682712416466], 
              Complex[3.8772617652382886`, -1.6733000146368147`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.965814938226205, 0.22546793870233256`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {31.999999999999996`, "A", 2, {
              Complex[2.965814938226205, 0.22546793870233256`], 
              Complex[4.2790664893039665`, -0.9434705428233618]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.5976759196164494`, -0.3788808057418005}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 1, {
              Complex[2.5976759196164494`, -0.3788808057418005], 
              Complex[3.889641123048907, -1.6861168153853223`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9569566571447035`, 0.2378553727309031}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.099999999999994`, "A", 2, {
              Complex[2.9569566571447035`, 0.2378553727309031], 
              Complex[4.267836735050403, -0.9290672478326643]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.606650933262854, -0.3906866010723904}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 1, {
              Complex[2.606650933262854, -0.3906866010723904], 
              Complex[3.901239519558195, -1.699101588537602]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9487637036120304`, 0.25033002218771455`}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.199999999999996`, "A", 2, {
              Complex[2.9487637036120304`, 0.25033002218771455`], 
              Complex[4.257385543344473, -0.9145049639864019]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6149863657999486`, -0.40251041678372024`}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 1, {
              Complex[2.6149863657999486`, -0.40251041678372024`], 
              Complex[3.912085621903242, -1.7121629626858925`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9412066320031385`, 0.2628167267283543}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.3, "A", 2, {
              Complex[2.9412066320031385`, 0.2628167267283543], 
              Complex[4.247684254548457, -0.8998749672010703]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6227207308158538`, -0.41428986426444875`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 1, {
              Complex[2.6227207308158538`, -0.41428986426444875`], 
              Complex[3.9222198214979063`, -1.7252240340035678`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.93424695657482, 0.27525317641875774`}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.4, "A", 2, {
              Complex[2.93424695657482, 0.27525317641875774`], 
              Complex[4.2386924847988485`, -0.8852540673280815]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.629897485254924, -0.42597525546826037`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 1, {
              Complex[2.629897485254924, -0.42597525546826037`], 
              Complex[3.9316893781660758`, -1.738222515211657]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.927841247969024, 0.28758976049421764`}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.49999999999999, "A", 2, {
              Complex[2.927841247969024, 0.28758976049421764`], 
              Complex[4.230362981869568, -0.8707044591549228]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.636561822697944, -0.4375284851167467}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 1, {
              Complex[2.636561822697944, -0.4375284851167467], 
              Complex[3.9405445393067433`, -1.7511096707348455`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.921944339934747, 0.2997884495937316}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.599999999999994`, "A", 2, {
              Complex[2.921944339934747, 0.2997884495937316], 
              Complex[4.222645506003507, -0.856274787217682]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6427583897826854`, -0.4489214364481581}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 1, {
              Complex[2.6427583897826854`, -0.4489214364481581], 
              Complex[3.948835712532859, -1.7638486148780157`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9165116129095963`, 0.31182120153934106`}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.699999999999996`, "A", 2, {
              Complex[2.9165116129095963`, 0.31182120153934106`], 
              Complex[4.2154896572704255`, -0.842001847593885]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.648529805818011, -0.4601342612759221}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 1, {
              Complex[2.648529805818011, -0.4601342612759221], 
              Complex[3.9566115778779483`, -1.7764123973101795`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.911500474407813, 0.323668241424401}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.8, "A", 2, {
              Complex[2.911500474407813, 0.323668241424401], 
              Complex[4.208846763357217, -0.8279125023887512]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.653915808537619, -0.4711537472500261}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 1, {
              Complex[2.653915808537619, -0.4711537472500261], 
              Complex[3.963917947183657, -1.7887821416602485`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.90687121326868, 0.33531642890390234`}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {32.9, "A", 2, {
              Complex[2.90687121326868, 0.33531642890390234`], 
              Complex[4.202671020177384, -0.8140255411104018]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6589528500918, -0.48197187877303665`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 1, {
              Complex[2.6589528500918, -0.48197187877303665`], 
              Complex[3.9707971711833534`, -1.8009453770853803`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.9025874036669044`, 0.3467578191386486}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33., "A", 2, {
              Complex[2.9025874036669044`, 0.3467578191386486], 
              Complex[4.196920084784548, -0.8003533490732543]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6636739953559614`, -0.49258462786579826`}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 1, {
              Complex[2.6636739953559614`, -0.49258462786579826`], 
              Complex[3.977287922300882, -1.8128946175014522`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8986160068062667`, 0.3579884536883491}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.099999999999994`, "A", 2, {
              Complex[2.8986160068062667`, 0.3579884536883491], 
              Complex[4.1915552925709445`, -0.7869033281400255]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.668109009751523, -0.50299097090211}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 1, {
              Complex[2.668109009751523, -0.50299097090211], 
              Complex[3.9834252194900266`, -1.8246261926386431`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8949272831009005`, 0.36900737727295585`}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.199999999999996`, "A", 2, {
              Complex[2.8949272831009005`, 0.36900737727295585`], 
              Complex[4.1865416324253255`, -0.7736790656393452]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6722845561748567`, -0.5131921073476409}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 1, {
              Complex[2.6722845561748567`, -0.5131921073476409], 
              Complex[3.989240598169983, -1.836139309119696]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8914945952485174`, 0.37981585653752775`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.3, "A", 2, {
              Complex[2.8914945952485174`, 0.37981585653752775`], 
              Complex[4.1818475767949295`, -0.7606812732613812]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.67622444669189, -0.5231908494724435}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 1, {
              Complex[2.67622444669189, -0.5231908494724435], 
              Complex[3.994762358551031, -1.847435309214209]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8882941565379943`, 0.3904167697900055}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.39999999999999, "A", 2, {
              Complex[2.8882941565379943`, 0.3904167697900055], 
              Complex[4.177444833357386, -0.7479085282781004]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.679949913999627, -0.5329911517598123}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 1, {
              Complex[2.679949913999627, -0.5329911517598123], 
              Complex[4.000015848490728, -1.8585170930917838`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8853047593900265`, 0.4008141364346624}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.49999999999999, "A", 2, {
              Complex[2.8853047593900265`, 0.4008141364346624], 
              Complex[4.173308062162179, -0.735357851265334]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.683479881251108, -0.5425977517885688}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 1, {
              Complex[2.683479881251108, -0.5425977517885688], 
              Complex[4.005023753334011, -1.8693886729252434`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8825075055343556`, 0.41101275787833075`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.599999999999994`, "A", 2, {
              Complex[2.8825075055343556`, 0.41101275787833075`], 
              Complex[4.169414585788292, -0.7230251519753936]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6868312180069145`, -0.5520158986267104}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 1, {
              Complex[2.6868312180069145`, -0.5520158986267104], 
              Complex[4.009806376364359, -1.880054831501801]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8798855500604437`, 0.42101794594737985`}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.699999999999996`, "A", 2, {
              Complex[2.8798855500604437`, 0.42101794594737985`], 
              Complex[4.165744108890901, -0.7109055707023496]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.6900189760399855`, -0.5612511491377956}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 1, {
              Complex[2.6900189760399855`, -0.5612511491377956], 
              Complex[4.01438190088909, -1.890520862682429]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8774238656148396`, 0.4308353192168015}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.8, "A", 2, {
              Complex[2.8774238656148396`, 0.4308353192168015], 
              Complex[4.162278456114006, -0.6989937377997083]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.693056602464925, -0.5703092165540393}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 1, {
              Complex[2.693056602464925, -0.5703092165540393], 
              Complex[4.018766629721939, -1.900792375423005]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8751090292740487`, 0.4404706516054349}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {33.9, "A", 2, {
              Complex[2.8751090292740487`, 0.4404706516054349], 
              Complex[4.159001332605871, -0.6872839696368801]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.695956129918709, -0.5791958590266285}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 1, {
              Complex[2.695956129918709, -0.5791958590266285], 
              Complex[4.022975200759234, -1.9108751468578677`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8729290323659913`, 0.4499297609478434}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34., "A", 2, {
              Complex[2.8729290323659913`, 0.4499297609478434], 
              Complex[4.155898108440934, -0.6757704154937819]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.698728344803272, -0.5879167986060275}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 1, {
              Complex[2.698728344803272, -0.5879167986060275], 
              Complex[4.02702077908128, -1.9207750130848582`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8708731122295896`, 0.4592184279956057}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.1, "A", 2, {
              Complex[2.8708731122295896`, 0.4592184279956057], 
              Complex[4.152955626516613, -0.664447166754532]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7013829352654026`, -0.5964776632911527}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 1, {
              Complex[2.7013829352654026`, -0.5964776632911527], 
              Complex[4.030915226970466, -1.9304977888211983`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8689316042370305`, 0.4683423384869718}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.2, "A", 2, {
              Complex[2.8689316042370305`, 0.4683423384869718], 
              Complex[4.150162032533434, -0.6533083372307825]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7039286208715065`, -0.6048839465011073}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 1, {
              Complex[2.7039286208715065`, -0.6048839465011073], 
              Complex[4.034669253707697, -1.9400492091033885`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8670958121211547`, 0.477307042638535}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.3, "A", 2, {
              Complex[2.8670958121211547`, 0.477307042638535], 
              Complex[4.147506625196923, -0.642348121441579]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.7063732659882276`, -0.613140979653751}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 1, {
              Complex[2.7063732659882276`, -0.613140979653751], 
              Complex[4.038292547177894, -1.9494348877721928`]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8653578945969786`, 0.48611792774323803`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.39999999999999, "A", 2, {
              Complex[2.8653578945969786`, 0.48611792774323803`], 
              Complex[4.144979724610491, -0.631560836108617]}, -1}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{2.708723978803601, -0.6212539145605391}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 1, {
              Complex[2.708723978803601, -0.6212539145605391], 
              Complex[4.041793889306879, -1.958660288701135]}, -1}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 0, 1], 
          TagBox[
           TooltipBox[PointBox[{2.8637107663426793`, 0.49478020058417876`}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]],
           Annotation[#, {34.49999999999999, "A", 2, {
              Complex[2.8637107663426793`, 0.49478020058417876`], 
              Complex[4.1425725568370115`, -0.6209409489084496]}, -1}, 
            "Tooltip"]& ]}}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.710987197779323, -0.6292277131331433}],
           RowBox[{"{", 
             RowBox[{"34.599999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {34.599999999999994`, "A", 1, {
             Complex[2.710987197779323, -0.6292277131331433], 
             Complex[4.045181257244431, -1.9677307066670986`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7131687671511795`, -0.6370671424983351}],
           RowBox[{"{", 
             RowBox[{"34.699999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {34.699999999999996`, "A", 1, {
             Complex[2.7131687671511795`, -0.6370671424983351], 
             Complex[4.048461912051173, -1.9766512554854927`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.71527400291423, -0.6447767740762022}],
           RowBox[{"{", 
             RowBox[{"34.8`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {34.8, "A", 1, {
             Complex[2.71527400291423, -0.6447767740762022], 
             Complex[4.051642476470395, -1.9854268615885537`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.717307750554921, -0.6523609855265123}],
           RowBox[{"{", 
             RowBox[{"34.9`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {34.9, "A", 1, {
             Complex[2.717307750554921, -0.6523609855265123], 
             Complex[4.054729003187752, -1.9940622616524228`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7192744356306133`, -0.6598239647344449}],
           RowBox[{"{", 
             RowBox[{"35.`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35., "A", 1, {
             Complex[2.7192744356306133`, -0.6598239647344449], 
             Complex[4.057727034812088, -2.002562003206256]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7211781081510784`, -0.6671697152100743}],
           RowBox[{"{", 
             RowBox[{"35.1`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.1, "A", 1, {
             Complex[2.7211781081510784`, -0.6671697152100743], 
             Complex[4.060641656654434, -2.01093044740819]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7230224815870465`, -0.6744020624307276}],
           RowBox[{"{", 
             RowBox[{"35.199999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.199999999999996`, "A", 1, {
             Complex[2.7230224815870465`, -0.6744020624307276], 
             Complex[4.063477543241718, -2.0191717733661476`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.724810967217476, -0.6815246607732999}],
           RowBox[{"{", 
             RowBox[{"35.3`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.3, "A", 1, {
             Complex[2.724810967217476, -0.6815246607732999], 
             Complex[4.066238999377148, -2.0272899835297706`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7265467044285883`, -0.6885410007735716}],
           RowBox[{"{", 
             RowBox[{"35.4`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.4, "A", 1, {
             Complex[2.7265467044285883`, -0.6885410007735716], 
             Complex[4.06892999644998, -2.0352889097939637`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7282325874925664`, -0.6954544165180527}],
           RowBox[{"{", 
             RowBox[{"35.49999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.49999999999999, "A", 1, {
             Complex[2.7282325874925664`, -0.6954544165180527], 
             Complex[4.07155420460227, -2.0431722200421385`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.729871289280439, -0.7022680930260651}],
           RowBox[{"{", 
             RowBox[{"35.599999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.599999999999994`, "A", 1, {
             Complex[2.729871289280439, -0.7022680930260651], 
             Complex[4.074115021277763, -2.0509434249247764`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7314652823007664`, -0.7089850735194753}],
           RowBox[{"{", 
             RowBox[{"35.699999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.699999999999996`, "A", 1, {
             Complex[2.7314652823007664`, -0.7089850735194753], 
             Complex[4.076615596606935, -2.0586058847208237`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.733016857401756, -0.7156082665076033}],
           RowBox[{"{", 
             RowBox[{"35.8`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.8, "A", 1, {
             Complex[2.733016857401756, -0.7156082665076033], 
             Complex[4.079058856020895, -2.0661628161692955`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.734528140428245, -0.7221404526376912}],
           RowBox[{"{", 
             RowBox[{"35.9`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.9, "A", 1, {
             Complex[2.734528140428245, -0.7221404526376912], 
             Complex[4.081447520434109, -2.07361729918916]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.736001107085408, -0.7285842912785057}],
           RowBox[{"{", 
             RowBox[{"35.99999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {35.99999999999999, "A", 1, {
             Complex[2.736001107085408, -0.7285842912785057], 
             Complex[4.0837841242905935`, -2.080972283429037]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7374375962271382`, -0.7349423268176083}],
           RowBox[{"{", 
             RowBox[{"36.099999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.099999999999994`, "A", 1, {
             Complex[2.7374375962271382`, -0.7349423268176083], 
             Complex[4.086071031729208, -2.088230594606227]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7388393217580846`, -0.7412169946624545}],
           RowBox[{"{", 
             RowBox[{"36.199999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.199999999999996`, "A", 1, {
             Complex[2.7388393217580846`, -0.7412169946624545], 
             Complex[4.088310451090251, -2.095394940608318]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7402078833132797`, -0.7474106269426312}],
           RowBox[{"{", 
             RowBox[{"36.3`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.3, "A", 1, {
             Complex[2.7402078833132797`, -0.7474106269426312], 
             Complex[4.090504447956572, -2.1024679173410123`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7415447758580713`, -0.7535254579157126}],
           RowBox[{"{", 
             RowBox[{"36.4`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.4, "A", 1, {
             Complex[2.7415447758580713`, -0.7535254579157126], 
             Complex[4.092654956897793, -2.109452014313655]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.742851398332544, -0.7595636290829759}],
           RowBox[{"{", 
             RowBox[{"36.5`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.5, "A", 1, {
             Complex[2.742851398332544, -0.7595636290829759], 
             Complex[4.094763792064631, -2.11634961995984]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.744129061448893, -0.7655271940238008}],
           RowBox[{"{", 
             RowBox[{"36.6`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.6, "A", 1, {
             Complex[2.744129061448893, -0.7655271940238008], 
             Complex[4.096832656761998, -2.1231630266947916`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.745378994736478, -0.7714181229593412}],
           RowBox[{"{", 
             RowBox[{"36.699999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.699999999999996`, "A", 1, {
             Complex[2.745378994736478, -0.7714181229593412], 
             Complex[4.098863152113465, -2.1298944357144087`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.746602352917594, -0.7772383070571701}],
           RowBox[{"{", 
             RowBox[{"36.79999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.79999999999999, "A", 1, {
             Complex[2.746602352917594, -0.7772383070571701], 
             Complex[4.100856784915977, -2.136545961543077]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7478002216867257`, -0.7829895624892164}],
           RowBox[{"{", 
             RowBox[{"36.89999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.89999999999999, "A", 1, {
             Complex[2.7478002216867257`, -0.7829895624892164], 
             Complex[4.102814974771636, -2.143119636338954]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.748973622957287, -0.7886736342555815}],
           RowBox[{"{", 
             RowBox[{"36.99999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {36.99999999999999, "A", 1, {
             Complex[2.748973622957287, -0.7886736342555815], 
             Complex[4.104739060573037, -2.1496174139664057`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.750123519632142, -0.794292199786831}],
           RowBox[{"{", 
             RowBox[{"37.099999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.099999999999994`, "A", 1, {
             Complex[2.750123519632142, -0.794292199786831], 
             Complex[4.106630306409572, -2.156041173845927]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.751250819947598, -0.7998468723371362}],
           RowBox[{"{", 
             RowBox[{"37.199999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.199999999999996`, "A", 1, {
             Complex[2.751250819947598, -0.7998468723371362], 
             Complex[4.108489906954296, -2.1623927245921424`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7523563814347085`, -0.8053392041803537}],
           RowBox[{"{", 
             RowBox[{"37.3`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.3, "A", 1, {
             Complex[2.7523563814347085`, -0.8053392041803537], 
             Complex[4.11031899238399, -2.168673807450607]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7534410145367234`, -0.8107706896206492}],
           RowBox[{"{", 
             RowBox[{"37.4`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.4, "A", 1, {
             Complex[2.7534410145367234`, -0.8107706896206492], 
             Complex[4.112118632879193, -2.174886099543967]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7545054859170786`, -0.8161427678288303}],
           RowBox[{"{", 
             RowBox[{"37.5`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.5, "A", 1, {
             Complex[2.7545054859170786`, -0.8161427678288303], 
             Complex[4.113889842745602, -2.1810312169378863`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7555505214884586`, -0.8214568255150109}],
           RowBox[{"{", 
             RowBox[{"37.6`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.6, "A", 1, {
             Complex[2.7555505214884586`, -0.8214568255150109], 
             Complex[4.115633584193734, -2.1871107175367754`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7565768091900997`, -0.8267141994476596}],
           RowBox[{"{", 
             RowBox[{"37.7`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.7, "A", 1, {
             Complex[2.7565768091900997`, -0.8267141994476596], 
             Complex[4.117350770809639, -2.193126103819013]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7575850015374925`, -0.8319161788285991}],
           RowBox[{"{", 
             RowBox[{"37.8`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.8, "A", 1, {
             Complex[2.7575850015374925`, -0.8319161788285991], 
             Complex[4.119042270745964, -2.199078825420972]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7585757179660733`, -0.8370640075328957}],
           RowBox[{"{", 
             RowBox[{"37.89999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.89999999999999, "A", 1, {
             Complex[2.7585757179660733`, -0.8370640075328957], 
             Complex[4.120708909659479, -2.204970281578657]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.759549546988155, -0.8421588862221198}],
           RowBox[{"{", 
             RowBox[{"37.99999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {37.99999999999999, "A", 1, {
             Complex[2.759549546988155, -0.8421588862221198], 
             Complex[4.122351473418491, -2.2108018234353835`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.760507048180339, -0.8472019743388879}],
           RowBox[{"{", 
             RowBox[{"38.099999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.099999999999994`, "A", 1, {
             Complex[2.760507048180339, -0.8472019743388879], 
             Complex[4.123970710601056, -2.2165747562234497`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7614487540168455`, -0.8521943919901349}],
           RowBox[{"{", 
             RowBox[{"38.199999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.199999999999996`, "A", 1, {
             Complex[2.7614487540168455`, -0.8521943919901349], 
             Complex[4.12556733480281, -2.222290341327314]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.762375171562624, -0.8571372217260823}],
           RowBox[{"{", 
             RowBox[{"38.3`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.3, "A", 1, {
             Complex[2.762375171562624, -0.8571372217260823], 
             Complex[4.127142026771301, -2.2279497982353837`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7632867840386814`, -0.8620315102214068}],
           RowBox[{"{", 
             RowBox[{"38.4`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.4, "A", 1, {
             Complex[2.7632867840386814`, -0.8620315102214068], 
             Complex[4.128695436382012, -2.2335543063870658`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.764184052270831, -0.8668782698647187}],
           RowBox[{"{", 
             RowBox[{"38.5`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.5, "A", 1, {
             Complex[2.764184052270831, -0.8668782698647187], 
             Complex[4.130228184469746, -2.239105006921373]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.765067416031943, -0.8716784802620265}],
           RowBox[{"{", 
             RowBox[{"38.599999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.599999999999994`, "A", 1, {
             Complex[2.765067416031943, -0.8716784802620265], 
             Complex[4.131740864527742, -2.2446030043329674`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7659372952868275`, -0.8764330896595155}],
           RowBox[{"{", 
             RowBox[{"38.699999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.699999999999996`, "A", 1, {
             Complex[2.7659372952868275`, -0.8764330896595155], 
             Complex[4.133234044285656, -2.25004936804117]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7667940913479225`, -0.8811430162906054}],
           RowBox[{"{", 
             RowBox[{"38.8`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.8, "A", 1, {
             Complex[2.7667940913479225`, -0.8811430162906054], 
             Complex[4.134708267176491, -2.2554451338771337`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7676381879492564`, -0.8858091496519156}],
           RowBox[{"{", 
             RowBox[{"38.9`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.9, "A", 1, {
             Complex[2.7676381879492564`, -0.8858091496519156], 
             Complex[4.136164053701611, -2.260791305494017]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.768469952245414, -0.8904323517124777}],
           RowBox[{"{", 
             RowBox[{"38.99999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {38.99999999999999, "A", 1, {
             Complex[2.768469952245414, -0.8904323517124777], 
             Complex[4.137601902702118, -2.2660888557047376`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7692897357415935`, -0.8950134580602265}],
           RowBox[{"{", 
             RowBox[{"39.099999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.099999999999994`, "A", 1, {
             Complex[2.7692897357415935`, -0.8950134580602265], 
             Complex[4.139022292544098, -2.271338727751554]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.770097875160309, -0.8995532789895441}],
           RowBox[{"{", 
             RowBox[{"39.199999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.199999999999996`, "A", 1, {
             Complex[2.770097875160309, -0.8995532789895441], 
             Complex[4.1404256822245795`, -2.2765418365114742`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.770894693249766, -0.9040526005333875}],
           RowBox[{"{", 
             RowBox[{"39.3`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.3, "A", 1, {
             Complex[2.770894693249766, -0.9040526005333875], 
             Complex[4.141812512404396, -2.2816990696412365`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.771680499538499, -0.9085121854432784}],
           RowBox[{"{", 
             RowBox[{"39.4`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.4, "A", 1, {
             Complex[2.771680499538499, -0.9085121854432784], 
             Complex[4.143183206373633, -2.286811288665357]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.772455591040422, -0.9129327741202401}],
           RowBox[{"{", 
             RowBox[{"39.49999999999999`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.49999999999999, "A", 1, {
             Complex[2.772455591040422, -0.9129327741202401], 
             Complex[4.1445381709548, -2.291879330010544]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.773220252914124, -0.9173150854995425}],
           RowBox[{"{", 
             RowBox[{"39.599999999999994`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.599999999999994`, "A", 1, {
             Complex[2.773220252914124, -0.9173150854995425], 
             Complex[4.1458777973484535`, -2.2969040059895236`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.7739747590798687`, -0.9216598178919512}],
           RowBox[{"{", 
             RowBox[{"39.699999999999996`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.699999999999996`, "A", 1, {
             Complex[2.7739747590798687`, -0.9216598178919512], 
             Complex[4.147202461925569, -2.3018861057371836`]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.774719372797445, -0.9259676497839711}],
           RowBox[{"{", 
             RowBox[{"39.8`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.8, "A", 1, {
             Complex[2.774719372797445, -0.9259676497839711], 
             Complex[4.148512526970578, -2.306826396101705]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.775454347207829, -0.9302392405994732}],
           RowBox[{"{", 
             RowBox[{"39.9`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {39.9, "A", 1, {
             Complex[2.775454347207829, -0.9302392405994732], 
             Complex[4.149808341378721, -2.311725622493254]}, -1}, 
           "Tooltip"]& ]}, 
        {GrayLevel[0], 
         TagBox[
          TooltipBox[PointBox[{2.776179925841262, -0.9344752314248258}],
           RowBox[{"{", 
             RowBox[{"40.`", ",", "\"A\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", 
               RowBox[{"-", "1"}]}], "}"}]],
          Annotation[#, {40., "A", 1, {
             Complex[2.776179925841262, -0.9344752314248258], 
             Complex[4.151090241310992, -2.3165845096925235`]}, -1}, 
           "Tooltip"]& ]}}, {{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.8360190079650485`, 0.006645071137818026}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 1, {
              Complex[7.8360190079650485`, 0.006645071137818026], 
              Complex[6.1962322662149445`, -1.1633793876684915`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.118560581075961, 0.0068877274873969585`}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0068877274873969585`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 2, {
              Complex[8.118560581075961, 0.0068877274873969585`], 
              Complex[6.478753355849045, -1.1631402225643317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.53989419288883, -0.01324317030169899}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {15.999999999999998`, "C", 3, {
              Complex[10.53989419288883, -0.01324317030169899], 
              Complex[8.80001605246603, -1.1961486271318056`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.795901779221279, 0.006712510785854963}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 1, {
              Complex[7.795901779221279, 0.006712510785854963], 
              Complex[6.155525231634676, -1.1633781485602357`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.162580737731858, 0.007042959985370651}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 2, {
              Complex[8.162580737731858, 0.007042959985370651], 
              Complex[6.5221587863983865`, -1.1630554690196342`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.494506767269, -0.013509876715323853`}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.099999999999998`, "C", 3, {
              Complex[10.494506767269, -0.013509876715323853`], 
              Complex[8.75509227462806, -1.1963255671672886`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.763484521798694, 0.006786025025048383}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 1, {
              Complex[7.763484521798694, 0.006786025025048383], 
              Complex[6.122517060306264, -1.1633711130594213`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.198987977866883, 0.007197843246654797}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 2, {
              Complex[8.198987977866883, 0.007197843246654797], 
              Complex[6.557943371421671, -1.162972548762566]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.457042457039066`, -0.013751044852512806`}],
            
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.2, "C", 3, {
              Complex[10.457042457039066`, -0.013751044852512806`], 
              Complex[8.71810174166509, -1.1964748219538672`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.735547972440535, 0.006863336573144897}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 1, {
              Complex[7.735547972440535, 0.006863336573144897], 
              Complex[6.093988110787665, -1.1633606215314773`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.231005147885755, 0.0073549519610065905`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0073549519610065905`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 2, {
              Complex[8.231005147885755, 0.0073549519610065905`], 
              Complex[6.589330078860689, -1.1628888789503151`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.42414741707873, -0.0139798695984579}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.299999999999997`, "C", 3, {
              Complex[10.42414741707873, -0.0139798695984579], 
              Complex[8.685690080337725, -1.1966097210740347`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.710629285429999, 0.00694346149760476}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 1, {
              Complex[7.710629285429999, 0.00694346149760476], 
              Complex[6.068475300453683, -1.1633476974009693`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.260098904258959, 0.007515591774090756}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 2, {
              Complex[8.260098904258959, 0.007515591774090756], 
              Complex[6.61778553109412, -1.162803172863648]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.39429571170861, -0.014202465960725278`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.4, "C", 3, {
              Complex[10.39429571170861, -0.014202465960725278`], 
              Complex[8.656331133890323, -1.1967364397628084`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.687917286732913, 0.007025882918871702}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 1, {
              Complex[7.687917286732913, 0.007025882918871702], 
              Complex[6.045167287063117, -1.163332885610651]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.287084479515974, 0.007680628289981289}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 2, {
              Complex[8.287084479515974, 0.007680628289981289], 
              Complex[6.644124842294815, -1.162714599075609]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.366639367283945`, -0.014422357660350082`}],
            
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.499999999999996`, "C", 3, {
              Complex[10.366639367283945`, -0.014422357660350082`], 
              Complex[8.629176867782464, -1.196858523000041]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.666906890699567, 0.007110298008162871}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 1, {
              Complex[7.666906890699567, 0.007110298008162871], 
              Complex[6.023558855884935, -1.163316510563181]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.312471288002852, 0.00785074316053409}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 2, {
              Complex[8.312471288002852, 0.00785074316053409], 
              Complex[6.668857252414808, -1.1626225207983634`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.340648661463618`, -0.014641876121436062`}],
            
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.599999999999998`, "C", 3, {
              Complex[10.340648661463618`, -0.014641876121436062`], 
              Complex[8.603697599379137, -1.1969782988821367`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.6472584862388935`, 0.007196517077880152}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 1, {
              Complex[7.6472584862388935`, 0.007196517077880152], 
              Complex[6.0033102912691545`, -1.163298779461846]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.336603564825275, 0.00802653852897203}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 2, {
              Complex[8.336603564825275, 0.00802653852897203], 
              Complex[6.6923267792271615`, -1.1625263894330444`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.315965756037766`, -0.014862729232274637`}],
            
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.7, "C", 3, {
              Complex[10.315965756037766`, -0.014862729232274637`], 
              Complex[8.579535601926915, -1.1970974543173976`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.628730822140306, 0.0072844163322486775`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0072844163322486775`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 1, {
              Complex[7.628730822140306, 0.0072844163322486775`], 
              Complex[5.984180253839811, -1.1632798309089558`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.359727508694593, 0.008208588338762687}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 2, {
              Complex[8.359727508694593, 0.008208588338762687], 
              Complex[6.714779367617378, -1.162425692393188]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.29233482504539, -0.015086273942248}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.799999999999997`, "C", 3, {
              Complex[10.29233482504539, -0.015086273942248], 
              Complex[8.556435217312078, -1.197217311276035]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.611145277473936, 0.007373913179256576}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 1, {
              Complex[7.611145277473936, 0.007373913179256576], 
              Complex[5.965990045977096, -1.1632597604074917`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.382027043209192, 0.008397467701836855}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 2, {
              Complex[8.382027043209192, 0.008397467701836855], 
              Complex[6.736398653893472, -1.1623199234705246`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.269564843263957`, -0.01531366326459591}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {16.9, "C", 3, {
              Complex[10.269564843263957`, -0.01531366326459591], 
              Complex[8.534205636043778, -1.1973389757687454`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.5943652547457265`, 0.0074649522520338}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 1, {
              Complex[7.5943652547457265`, 0.0074649522520338], 
              Complex[5.948603001807254, -1.1632386348615993`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.40364445944282, 0.008593772293729832}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 2, {
              Complex[8.40364445944282, 0.008593772293729832], 
              Complex[6.757326609412581, -1.1622085635431991`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.247508108692935`, -0.01554593341902805}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17., "C", 3, {
              Complex[10.247508108692935`, -0.01554593341902805], 
              Complex[8.512699415121856, -1.1974634260014816`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           
           TooltipBox[PointBox[{7.5782835412454626`, 0.0075574969911607935`}],
            
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.0075574969911607935`", " ", "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 1, {
              Complex[7.5782835412454626`, 0.0075574969911607935`], 
              Complex[5.931911846413442, -1.1632165013453948`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.424693095053826, 0.00879813306517896}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 2, {
              Complex[8.424693095053826, 0.00879813306517896], 
              Complex[6.777676219425206, -1.1620910662296873`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.226047052260421`, -0.01578406003523005}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.099999999999998`, "C", 3, {
              Complex[10.226047052260421`, -0.01578406003523005], 
              Complex[8.491799285559544, -1.1975915689762857`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.5628141695271145`, 0.007651524322598731}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 1, {
              Complex[7.5628141695271145`, 0.007651524322598731], 
              Complex[5.915830554816423, -1.163193392670451]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.445265519754589, 0.009011228909084963}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 2, {
              Complex[8.445265519754589, 0.009011228909084963], 
              Complex[6.797539667322055, -1.161966845801127]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.20508572371207, -0.016028997503587203`}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.2, "C", 3, {
              Complex[10.20508572371207, -0.016028997503587203`], 
              Complex[8.471409637754663, -1.1977242798043068`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.547886962653699, 0.00774702115719995}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 1, {
              Complex[7.547886962653699, 0.00774702115719995], 
              Complex[5.900288896133163, -1.1631693310632691`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.465439042444201, 0.009233798770935121}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 2, {
              Complex[8.465439042444201, 0.009233798770935121], 
              Complex[6.8169938397567895`, -1.161835265847092]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.184544064614805`, -0.016281708942805753`}],
            
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.299999999999997`, "C", 3, {
              Complex[10.184544064614805`, -0.016281708942805753`], 
              Complex[8.451450795228004, -1.1978624312936872`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.533443755733459, 0.007843982012263152}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 1, {
              Complex[7.533443755733459, 0.007843982012263152], 
              Complex[5.885228654304802, -1.1631443306747424`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.485279549606197, 0.009466654168547486}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 2, {
              Complex[8.485279549606197, 0.009466654168547486], 
              Complex[6.836104162316991, -1.1616956277315167`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.164353917920575`, -0.016543191071888914`}],
            
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.4, "C", 3, {
              Complex[10.164353917920575`, -0.016543191071888914`], 
              Complex[8.431855025955324, -1.1980069181435884`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.5194357044269005`, 0.007942407351021058}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 1, {
              Complex[7.5194357044269005`, 0.007942407351021058], 
              Complex[5.870600935988343, -1.1631183993398404`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.504844265661474, 0.009710692858210806}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 2, {
              Complex[8.504844265661474, 0.009710692858210806], 
              Complex[6.854927356440139, -1.1615471581185317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.144456159495563`, -0.016814496662831836`}],
            
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.5, "C", 3, {
              Complex[10.144456159495563`, -0.016814496662831836`], 
              Complex[8.412563676597298, -1.1981586784333549`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.5058213212730225`, 0.008042302396705316}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 1, {
              Complex[7.5058213212730225`, 0.008042302396705316], 
              Complex[5.856364206404795, -1.1630915398400685`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.52418379610039, 0.00996691431009624}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 2, {
              Complex[8.52418379610039, 0.00996691431009624], 
              Complex[6.873513478358425, -1.1613889949346565`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.124798576239256`, -0.017096756417673668`}],
            
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.599999999999998`, "C", 3, {
              Complex[10.124798576239256`, -0.017096756417673668`], 
              Complex[8.393525054229872, -1.1983187142405292`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.492565012985164, 0.008143676269233487}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 1, {
              Complex[7.492565012985164, 0.008143676269233487], 
              Complex[5.842482826256841, -1.1630637508268273`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.543343682297635, 0.01023643767719948}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 2, {
              Complex[8.543343682297635, 0.01023643767719948], 
              Complex[6.891907468896068, -1.161220171125207]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.105334252708913`, -0.017391201699304026`}],
            
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.7, "C", 3, {
              Complex[10.105334252708913`, -0.017391201699304026`], 
              Complex[8.374692817528384, -1.1984881127881408`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.479635970943437, 0.008246541346654087}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 1, {
              Complex[7.479635970943437, 0.008246541346654087], 
              Complex[5.828925941917191, -1.1630350275077863`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.562365618323055, 0.010520523036427927`}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 2, {
              Complex[8.562365618323055, 0.010520523036427927`], 
              Complex[6.9101503643132345`, -1.1610395954830415`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.086020309962356`, -0.017699189379580486`}],
            
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.799999999999997`, "C", 3, {
              Complex[10.086020309962356`, -0.017699189379580486`], 
              Complex[8.356024721208028, -1.1986680693372456`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.4670073159977095`, 0.008350912786614366}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 1, {
              Complex[7.4670073159977095`, 0.008350912786614366], 
              Complex[5.815666629983416, -1.1630053621640015`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.581288431797727, 0.010820596844492403`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 2, {
              Complex[8.581288431797727, 0.010820596844492403`], 
              Complex[6.9282802700841595`, -1.1608460296816647`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.06681689057666, -0.018022230071644385`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.9, "C", 3, {
              Complex[10.06681689057666, -0.018022230071644385`], 
              Complex[8.337481607819116, -1.1988599130234305`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.454655429824251, 0.008456808164000526}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 1, {
              Complex[7.454655429824251, 0.008456808164000526], 
              Complex[5.802681228429218, -1.1629747445437837`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.600148900521386, 0.011138282794836918`}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 2, {
              Complex[8.600148900521386, 0.011138282794836918`], 
              Complex[6.946333169123364, -1.1606380604240905`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.047686315383556`, -0.018362021154624195`}],
            
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {17.999999999999996`, "C", 3, {
              Complex[10.047686315383556`, -0.018362021154624195`], 
              Complex[8.319026572634915, -1.199065136952576]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.442559425423676, 0.008564247194411552}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 1, {
              Complex[7.442559425423676, 0.008564247194411552], 
              Complex[5.7899488069302, -1.1629431621652235`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.618982457304563, 0.011475439606775252`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 2, {
              Complex[8.618982457304563, 0.011475439606775252`], 
              Complex[6.964343616618659, -1.1604140653041306`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{10.02859235757786, -0.018720486277070698`}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.099999999999998`, "C", 3, {
              Complex[10.02859235757786, -0.018720486277070698`], 
              Complex[8.300624247551832, -1.1992854341178674`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.430700722955541, 0.008673251522090992}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 1, {
              Complex[7.430700722955541, 0.008673251522090992], 
              Complex[5.7774507425522845`, -1.162910600549928]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.637823823216573, 0.011834207760463409`}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 2, {
              Complex[8.637823823216573, 0.011834207760463409`], 
              Complex[6.982345361327388, -1.160172170534845]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           
           TooltipBox[PointBox[{10.009499592627153`, -0.019099823463292497`}],
            
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.2, "C", 3, {
              Complex[10.009499592627153`, -0.019099823463292497`], 
              Complex[8.28224016277643, -1.1995227410964953`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.419062706397297, 0.008783844556995738}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 1, {
              Complex[7.419062706397297, 0.008783844556995738], 
              Complex[5.765170376285118, -1.162877043404163]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.656707602013043, 0.012217067867222313`}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 2, {
              Complex[8.656707602013043, 0.012217067867222313`], 
              Complex[7.000371925640259, -1.1599101980783053`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.990372790233621, -0.01950256459218661}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.299999999999997`, "C", 3, {
              Complex[9.990372790233621, -0.01950256459218661], 
              Complex[8.263840153003093, -1.1997792920739636`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.4076304429802775`, 0.00889605134985899}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 1, {
              Complex[7.4076304429802775`, 0.00889605134985899], 
              Complex[5.753092732368909, -1.1628424727592266`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.675668864524779, 0.012626914319474911`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 2, {
              Complex[8.675668864524779, 0.012626914319474911`], 
              Complex[7.018457172595781, -1.1596255988326747`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.971176318841339, -0.019931649951741043`}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.399999999999995`, "C", 3, {
              Complex[9.971176318841339, -0.019931649951741043`], 
              Complex[8.24538977916942, -1.2000576866004597`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.396390451929997, 0.009009898497033932}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 1, {
              Complex[7.396390451929997, 0.009009898497033932], 
              Complex[5.741204286938846, -1.1628068690797762`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.694743750598732, 0.013067149229433986`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 2, {
              Complex[8.694743750598732, 0.013067149229433986`], 
              Complex[7.036635886648768, -1.1593153672755068`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.951873534557844, -0.020390522922278387`}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.499999999999996`, "C", 3, {
              Complex[9.951873534557844, -0.020390522922278387`], 
              Complex[8.226853738441676, -1.2003609757255185`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.3853305123250825`, 0.009125414068990404}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 1, {
              Complex[7.3853305123250825`, 0.009125414068990404], 
              Complex[5.729492775798816, -1.1627702113466531`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.713970117564823, 0.013541803645186434`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 2, {
              Complex[8.713970117564823, 0.013541803645186434`], 
              Complex[7.054944396120723, -1.1589759311366727`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.932426125107996, -0.020883251810279745`}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.599999999999998`, "C", 3, {
              Complex[9.932426125107996, -0.020883251810279745`], 
              Complex[8.208195234091123, -1.2006927729717152`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.374439502284718, 0.00924262755784085}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 1, {
              Complex[7.374439502284718, 0.00924262755784085], 
              Complex[5.7179470335323455`, -1.1627324771191436`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.733388268345113, 0.014055695951277626`}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 2, {
              Complex[8.733388268345113, 0.014055695951277626`], 
              Complex[7.073421269042284, -1.158603006979818]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.912793375391814, -0.02141468876524509}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.7, "C", 3, {
              Complex[9.912793375391814, -0.02141468876524509], 
              Complex[8.18937527323683, -1.2010573992945917`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.363707263462426, 0.009361569840391621}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 1, {
              Complex[7.363707263462426, 0.009361569840391621], 
              Complex[5.706556857926958, -1.1626936425804284`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.753041799848587, 0.014614641743299649`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 2, {
              Complex[8.753041799848587, 0.014614641743299649`], 
              Complex[7.092108121115127, -1.1581914085205156`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.892931313762208, -0.021990680088691875`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.8, "C", 3, {
              Complex[9.892931313762208, -0.021990680088691875`], 
              Complex[8.170351853484789, -1.2014600752208564`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.3531244861453, 0.009482273153988793}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 1, {
              Complex[7.3531244861453, 0.009482273153988793], 
              Complex[5.695312895009786, -1.1626536825691627`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.77297862441228, 0.015225736181981687`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 2, {
              Complex[8.77297862441228, 0.015225736181981687`], 
              Complex[7.111050585905176, -1.157734788294595]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.872791686074075, -0.02261834895605743}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.9, "C", 3, {
              Complex[9.872791686074075, -0.02261834895605743], 
              Complex[8.151078988162066, -1.201907179567137]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.342682611254977, 0.009604771083122523}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 1, {
              Complex[7.342682611254977, 0.009604771083122523], 
              Complex[5.684206540989642, -1.1626125705993822`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.793252235841303, 0.01589774035976148}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 2, {
              Complex[8.793252235841303, 0.01589774035976148], 
              Complex[7.130299515097567, -1.1572252835375132`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.852320685804424, -0.02330648209651281}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {18.999999999999996`, "C", 3, {
              Complex[9.852320685804424, -0.02330648209651281], 
              Complex[8.13150550216652, -1.2024066038908527`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.332373746308075, 0.009729098555121761}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 1, {
              Complex[7.332373746308075, 0.009729098555121761], 
              Complex[5.67322985816244, -1.1625702788705317`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.813923320576674, 0.016641620135819556`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 2, {
              Complex[8.813923320576674, 0.016641620135819556`], 
              Complex[7.149912504017514, -1.1566530214405544`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.831457339597339, -0.02406606889621767}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.099999999999998`, "C", 3, {
              Complex[9.831457339597339, -0.02406606889621767], 
              Complex[8.11157350310953, -1.202968247517296]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{7.322190592979878, 0.009855291843704485}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 1, {
              Complex[7.322190592979878, 0.009855291843704485], 
              Complex[5.662375502422984, -1.1625267782689677`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{8.835061859626233, 0.017471313877762306`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 2, {
              Complex[8.835061859626233, 0.017471313877762306`], 
              Complex[7.169955880282916, -1.1560054129682455`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          TagBox[
           TooltipBox[PointBox[{9.81013140250469, -0.02491106937082747}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", "3", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.2, "C", 3, {
              Complex[9.81013140250469, -0.02491106937082747], 
              Complex[8.09121638979124, -1.2036047239664327`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.856749938394854, 0.01840485331132207}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 1, {
              Complex[8.856749938394854, 0.01840485331132207], 
              Complex[7.190507361138085, -1.1552661200223417`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.78826054571076, -0.02585953521479562}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.299999999999997`, "C", 2, {
              Complex[9.78826054571076, -0.02585953521479562], 
              Complex[8.070356192382524, -1.2043323940004822`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.879085597629635, 0.019466046203823823`}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 1, {
              Complex[8.879085597629635, 0.019466046203823823`], 
              Complex[7.211659694982882, -1.1544135020746285`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.76574650346378, -0.02693529265819088}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.4, "C", 2, {
              Complex[9.76574650346378, -0.02693529265819088], 
              Complex[8.048899928737553, -1.2051729191751688`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.902188252549184, 0.020687085496539234`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 1, {
              Complex[8.902188252549184, 0.020687085496539234`], 
              Complex[7.233525786397051, -1.1534182031380908`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.742469652095146, -0.028170551750257837`}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.499999999999996`, "C", 2, {
              Complex[9.742469652095146, -0.028170551750257837`], 
              Complex[8.026734477486409, -1.2061556750293905`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.926206541442703, 0.02211275107353916}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 1, {
              Complex[8.926206541442703, 0.02211275107353916], 
              Complex[7.256246121108593, -1.1522392586053043`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.718281159799472, -0.029610108260631186`}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.599999999999998`, "C", 2, {
              Complex[9.718281159799472, -0.029610108260631186`], 
              Complex[8.003719151417389, -1.2073216443878656`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.95133006145241, 0.023807487220115792`}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 1, {
              Complex[8.95133006145241, 0.023807487220115792`], 
              Complex[7.279999873987634, -1.1508175252699344`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.692991249427967, -0.0313184212541546}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.7, "C", 2, {
              Complex[9.692991249427967, -0.0313184212541546], 
              Complex[7.979674588033221, -1.2087299874638697`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{8.977807551308572, 0.025867986584037196`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 1, {
              Complex[8.977807551308572, 0.025867986584037196`], 
              Complex[7.305022131856608, -1.1490639772295173`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.6663510144975, -0.033392197154710215`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.799999999999997`, "C", 2, {
              Complex[9.6663510144975, -0.033392197154710215`], 
              Complex[7.954365525461625, -1.2104697460661467`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.005976175768346, 0.028447097632704935`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 1, {
              Complex[9.005976175768346, 0.028447097632704935`], 
              Complex[7.3316316615292605`, -1.1468374259621588`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.638023133640685, -0.035984297293206895`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {19.9, "C", 2, {
              Complex[9.638023133640685, -0.035984297293206895`], 
              Complex[7.927473033284, -1.2126821236194971`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.036310546964627, 0.031803157852373865`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 1, {
              Complex[9.036310546964627, 0.031803157852373865`], 
              Complex[7.360277468735849, -1.1438984501954066`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.607532848271008, -0.039353071187373335`}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20., "C", 2, {
              Complex[9.607532848271008, -0.039353071187373335`], 
              Complex[7.89854795260484, -1.2156065553823723`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.069506749440478, 0.03641303093548226}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 1, {
              Complex[9.069506749440478, 0.03641303093548226], 
              Complex[7.391618832430621, -1.1398036000155798`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.574183936670554, -0.04397539380088848}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.1, "C", 2, {
              Complex[9.574183936670554, -0.04397539380088848], 
              Complex[7.866930860848725, -1.2196865044147176`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.106617372354673, 0.04326772266645232}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 1, {
              Complex[9.106617372354673, 0.04326772266645232], 
              Complex[7.426654831776879, -1.133628019546016]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.536923681000955, -0.05084228149321134}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.199999999999996`, "C", 2, {
              Complex[9.536923681000955, -0.05084228149321134], 
              Complex[7.831622543975548, -1.2258468389686776`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.149127159726488, 0.05476808187732223}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 1, {
              Complex[9.149127159726488, 0.05476808187732223], 
              Complex[7.466802670715167, -1.123122290976753]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.494267216357189, -0.062354593032578}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.299999999999997`, "C", 2, {
              Complex[9.494267216357189, -0.062354593032578], 
              Complex[7.7912056711960345`, -1.236336988520793]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.197298230159177, 0.07734359441247762}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 1, {
              Complex[9.197298230159177, 0.07734359441247762], 
              Complex[7.512359287571745, -1.1022322984450346`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.445952310414624, -0.08494182361234351}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.4, "C", 2, {
              Complex[9.445952310414624, -0.08494182361234351], 
              Complex[7.745383184720138, -1.2572110799472442`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.239565409647748, 0.11902724764149018`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 1, {
              Complex[9.239565409647748, 0.11902724764149018`], 
              Complex[7.5524910234485665`, -1.0633012820313072`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.403544030055139, -0.12663696940988678`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.5, "C", 2, {
              Complex[9.403544030055139, -0.12663696940988678`], 
              Complex[7.704988630788347, -1.296125883577755]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.262317347784464, 0.16611165996512323`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 1, {
              Complex[9.262317347784464, 0.16611165996512323`], 
              Complex[7.574268139734727, -1.0191412329171092`]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.380653624650824, -0.17373265713467972`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.599999999999994`, "C", 2, {
              Complex[9.380653624650824, -0.17373265713467972`], 
              Complex[7.682951641637801, -1.3402694180832728`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.27379501912068, 0.20695392178184982`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 1, {
              Complex[9.27379501912068, 0.20695392178184982`], 
              Complex[7.585368797745682, -0.9807872587669504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.369040024240906, -0.21458598503237647`}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.699999999999996`, "C", 2, {
              Complex[9.369040024240906, -0.21458598503237647`], 
              Complex[7.671593955391099, -1.3786065851349265`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.280570529089989, 0.24191392575349288`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 1, {
              Complex[9.280570529089989, 0.24191392575349288`], 
              Complex[7.591990895909478, -0.9479498476029737]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.362131033190314, -0.2495568531847539}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.799999999999997`, "C", 2, {
              Complex[9.362131033190314, -0.2495568531847539], 
              Complex[7.664717578441821, -1.4114269055666684`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.285085225476458, 0.27256109297706776`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 1, {
              Complex[9.285085225476458, 0.27256109297706776`], 
              Complex[7.59644818910947, -0.9191675975214383]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.357485218342608, -0.2802146897125705}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {20.9, "C", 2, {
              Complex[9.357485218342608, -0.2802146897125705], 
              Complex[7.660008665723722, -1.440191789692609]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.288342049505975, 0.3000009300835058}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 1, {
              Complex[9.288342049505975, 0.3000009300835058], 
              Complex[7.599694877117055, -0.8934053728141108]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.35409955758327, -0.30766500790255313`}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21., "C", 2, {
              Complex[9.35409955758327, -0.30766500790255313`], 
              Complex[7.656512931924068, -1.4659363812164734`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.290821923790588, 0.32496389242763857`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 1, {
              Complex[9.290821923790588, 0.32496389242763857`], 
              Complex[7.602190099828044, -0.8699776507064156]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.351493051581292, -0.33263826942312025`}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.099999999999998`, "C", 2, {
              Complex[9.351493051581292, -0.33263826942312025`], 
              Complex[7.653771155925205, -1.4893462105216049`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.292784687952791, 0.34794816918876}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 1, {
              Complex[9.292784687952791, 0.34794816918876], 
              Complex[7.604182742222915, -0.8484162452714185]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.349405787878045, -0.35563266944840766`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.2, "C", 2, {
              Complex[9.349405787878045, -0.35563266944840766`], 
              Complex[7.6515343755500105`, -1.5108894707826885`]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.294383744285957, 0.36930769700429716`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 1, {
              Complex[9.294383744285957, 0.36930769700429716`], 
              Complex[7.605820205415673, -0.8283882117511504]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.347684294964536, -0.37700215031345224`}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                  "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.3, "C", 2, {
              Complex[9.347684294964536, -0.37700215031345224`], 
              Complex[7.649655116243796, -1.530899113668034]}, 0}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{9.29571595421648, 0.3893033507690842}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "1", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 1, {
              Complex[9.29571595421648, 0.3893033507690842], 
              Complex[7.607195850080812, -0.8096479618228554]}, 0}, 
            "Tooltip"]& ]}, 
         {RGBColor[1, 0.5, 0], 
          TagBox[
           TooltipBox[PointBox[{9.346231645579115, -0.3970075923331433}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", "2", ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                   "}"}], ",", "0"}], "}"}]],
           Annotation[#, {21.4, "C", 2, {
              Complex[9.346231645579115, -0.3970075923331433], 
              Complex[7.6480399474006955`, -1.5496207340949588`]}, 0}, 
            "Tooltip"]& ]}}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.296845766278874, 0.4081334915298239}],
           RowBox[{"{", 
             RowBox[{"21.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.499999999999996`, "C", 1, {
             Complex[9.296845766278874, 0.4081334915298239], 
             Complex[7.608371984798496, -0.7920086413709166]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.297817893725249, 0.42595292805234636`}],
           RowBox[{"{", 
             RowBox[{"21.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.599999999999998`, "C", 1, {
             Complex[9.297817893725249, 0.42595292805234636`], 
             Complex[7.6093919681901685`, -0.7753243442615882]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.298664434058157, 0.44288515307919907`}],
           RowBox[{"{", 
             RowBox[{"21.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.7, "C", 1, {
             Complex[9.298664434058157, 0.44288515307919907`], 
             Complex[7.61028701795302, -0.7594786249471307]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.299409090344204, 0.45903052180506093`}],
           RowBox[{"{", 
             RowBox[{"21.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.799999999999997`, "C", 1, {
             Complex[9.299409090344204, 0.45903052180506093`], 
             Complex[7.611080255416446, -0.7443768154213608]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.300069789499112, 0.47447188989313444`}],
           RowBox[{"{", 
             RowBox[{"21.899999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.899999999999995`, "C", 1, {
             Complex[9.300069789499112, 0.47447188989313444`], 
             Complex[7.611789218669329, -0.7299407258319833]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.300660369136605, 0.4892786068277399}],
           RowBox[{"{", 
             RowBox[{"21.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {21.999999999999996`, "C", 1, {
             Complex[9.300660369136605, 0.4892786068277399], 
             Complex[7.612427484506159, -0.7161048892141156]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.301191700128847, 0.503509412285517}],
           RowBox[{"{", 
             RowBox[{"22.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.099999999999998`, "C", 1, {
             Complex[9.301191700128847, 0.503509412285517], 
             Complex[7.613005749670385, -0.7028138366825419]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.301672454837956, 0.5172145811965813}],
           RowBox[{"{", 
             RowBox[{"22.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.2, "C", 1, {
             Complex[9.301672454837956, 0.5172145811965813], 
             Complex[7.613532572082193, -0.6900200786894212]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.302109645838716, 0.5304375419992581}],
           RowBox[{"{", 
             RowBox[{"22.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.3, "C", 1, {
             Complex[9.302109645838716, 0.5304375419992581], 
             Complex[7.614014891510713, -0.6776825815576776]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.302509011886752, 0.5432161176861714}],
           RowBox[{"{", 
             RowBox[{"22.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.4, "C", 1, {
             Complex[9.302509011886752, 0.5432161176861714], 
             Complex[7.614458403240932, -0.6657655987699644]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.302875299750397, 0.5555834916479572}],
           RowBox[{"{", 
             RowBox[{"22.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.499999999999996`, "C", 1, {
             Complex[9.302875299750397, 0.5555834916479572], 
             Complex[7.6148678313818445`, -0.6542377611605058]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.303212473521276, 0.5675689693259758}],
           RowBox[{"{", 
             RowBox[{"22.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.599999999999998`, "C", 1, {
             Complex[9.303212473521276, 0.5675689693259758], 
             Complex[7.615247132185832, -0.6430713592597935]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.303523872448524, 0.5791985860418385}],
           RowBox[{"{", 
             RowBox[{"22.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.7, "C", 1, {
             Complex[9.303523872448524, 0.5791985860418385], 
             Complex[7.615599647619973, -0.6322417704324753]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.303812331602318, 0.5904955973399487}],
           RowBox[{"{", 
             RowBox[{"22.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.799999999999997`, "C", 1, {
             Complex[9.303812331602318, 0.5904955973399487], 
             Complex[7.615928222964841, -0.6217269966329017]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.304080275277004, 0.6014808784641332}],
           RowBox[{"{", 
             RowBox[{"22.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.9, "C", 1, {
             Complex[9.304080275277004, 0.6014808784641332], 
             Complex[7.616235297995222, -0.6115072877338223]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.304329790117846, 0.612173252747982}],
           RowBox[{"{", 
             RowBox[{"22.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {22.999999999999996`, "C", 1, {
             Complex[9.304329790117846, 0.612173252747982], 
             Complex[7.616522978484024, -0.6015648318155976]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30456268297077, 0.6225897638061416}],
           RowBox[{"{", 
             RowBox[{"23.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.099999999999998`, "C", 1, {
             Complex[9.30456268297077, 0.6225897638061416], 
             Complex[7.616793092860656, -0.5918834984038932]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.304780527085194, 0.6327459028649576}],
           RowBox[{"{", 
             RowBox[{"23.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.199999999999996`, "C", 1, {
             Complex[9.304780527085194, 0.6327459028649576], 
             Complex[7.617047237536009, -0.5824486239818062]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.304984699340448, 0.6426557999628848}],
           RowBox[{"{", 
             RowBox[{"23.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.299999999999997`, "C", 1, {
             Complex[9.304984699340448, 0.6426557999628848], 
             Complex[7.617286813480894, -0.5732468315559044]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.305176410484561, 0.6523323858111223}],
           RowBox[{"{", 
             RowBox[{"23.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.4, "C", 1, {
             Complex[9.305176410484561, 0.6523323858111223], 
             Complex[7.6175130559865005`, -0.5642658778811105]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30535672988259, 0.6617875296457956}],
           RowBox[{"{", 
             RowBox[{"23.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.5, "C", 1, {
             Complex[9.30535672988259, 0.6617875296457956], 
             Complex[7.617727059060542, -0.5554945233226201]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.305526605913883, 0.6710321572939462}],
           RowBox[{"{", 
             RowBox[{"23.6`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.6, "C", 1, {
             Complex[9.305526605913883, 0.6710321572939462], 
             Complex[7.617929795566583, -0.5469224203770374]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.305686882893223, 0.6800763528244194}],
           RowBox[{"{", 
             RowBox[{"23.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.699999999999996`, "C", 1, {
             Complex[9.305686882893223, 0.6800763528244194], 
             Complex[7.618122133957997, -0.5385400176762593]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.305838315194185, 0.6889294464957751}],
           RowBox[{"{", 
             RowBox[{"23.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.799999999999997`, "C", 1, {
             Complex[9.305838315194185, 0.6889294464957751], 
             Complex[7.618304852267418, -0.5303384769181552]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.305981579104797, 0.697600091198504}],
           RowBox[{"{", 
             RowBox[{"23.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {23.9, "C", 1, {
             Complex[9.305981579104797, 0.697600091198504], 
             Complex[7.618478649868708, -0.5223096006529586]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30611728283302, 0.7060963291837463}],
           RowBox[{"{", 
             RowBox[{"24.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24., "C", 1, {
             Complex[9.30611728283302, 0.7060963291837463], 
             Complex[7.618644157419196, -0.5144457692358492]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306245974993525, 0.7144256505494249}],
           RowBox[{"{", 
             RowBox[{"24.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.099999999999994`, "C", 1, {
             Complex[9.306245974993525, 0.7144256505494249], 
             Complex[7.618801945306149, -0.5067398855588761]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306368151840394, 0.722595044698084}],
           RowBox[{"{", 
             RowBox[{"24.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {24.199999999999996`, "C", 1, {
             Complex[9.306368151840394, 0.722595044698084], 
             Complex[7.61895253085656, -0.49918532641716257`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30648426345883, 0.730611045774511}],
           RowBox[{"{", 
             RowBox[{"24.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.299999999999997`, "C", 1, {
             Complex[9.30648426345883, 0.730611045774511], 
             Complex[7.6190963845189446`, -0.4917758995586582]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30659471908804, 0.7384797729243899}],
           RowBox[{"{", 
             RowBox[{"24.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.4, "C", 1, {
             Complex[9.30659471908804, 0.7384797729243899], 
             Complex[7.619233935186141, -0.4845058056239263]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306699891715693, 0.7462069660795199}],
           RowBox[{"{", 
             RowBox[{"24.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.499999999999996`, "C", 1, {
             Complex[9.306699891715693, 0.7462069660795199], 
             Complex[7.619365574796855, -0.4773696043103919]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306800122058599, 0.7537980178639988}],
           RowBox[{"{", 
             RowBox[{"24.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.599999999999998`, "C", 1, {
             Complex[9.306800122058599, 0.7537980178639988], 
             Complex[7.619491662328774, -0.4703621842002206]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306895722024107, 0.7612580021246124}],
           RowBox[{"{", 
             RowBox[{"24.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.7, "C", 1, {
             Complex[9.306895722024107, 0.7612580021246124], 
             Complex[7.619612527276209, -0.4634787357769729]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.306986977730267, 0.7685916995129599}],
           RowBox[{"{", 
             RowBox[{"24.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.8, "C", 1, {
             Complex[9.306986977730267, 0.7685916995129599], 
             Complex[7.619728472689179, -0.4567147272275417]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30707415214959, 0.7758036204842984}],
           RowBox[{"{", 
             RowBox[{"24.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {24.9, "C", 1, {
             Complex[9.30707415214959, 0.7758036204842984], 
             Complex[7.619839777837855, -0.45006588268489056`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307157487430532, 0.7828980260257034}],
           RowBox[{"{", 
             RowBox[{"24.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {24.999999999999996`, "C", 1, {
             Complex[9.307157487430532, 0.7828980260257034], 
             Complex[7.619946700555886, -0.4435281626164995]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307237206941968, 0.7898789463823147}],
           RowBox[{"{", 
             RowBox[{"25.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {25.099999999999998`, "C", 1, {
             Complex[9.307237206941968, 0.7898789463823147], 
             Complex[7.620049479307305, -0.43709774610477947`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307313517078901, 0.7967501980135657}],
           RowBox[{"{", 
             RowBox[{"25.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {25.199999999999996`, "C", 1, {
             Complex[9.307313517078901, 0.7967501980135657], 
             Complex[7.620148335014864, -0.4307710148004997]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307386608861503, 0.8035153989801238}],
           RowBox[{"{", 
             RowBox[{"25.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {25.299999999999997`, "C", 1, {
             Complex[9.307386608861503, 0.8035153989801238], 
             Complex[7.620243472681646, -0.42454453835966893`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307456659354887, 0.8101779829358526}],
           RowBox[{"{", 
             RowBox[{"25.399999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {25.399999999999995`, "C", 1, {
             Complex[9.307456659354887, 0.8101779829358526], 
             Complex[7.620335082833091, -0.4184150611992563]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307523832932748, 0.8167412118766469}],
           RowBox[{"{", 
             RowBox[{"25.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {25.499999999999996`, "C", 1, {
             Complex[9.307523832932748, 0.8167412118766469], 
             Complex[7.620423342802423, -0.4123794904283191]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307588282404819, 0.8232081877787825}],
           RowBox[{"{", 
             RowBox[{"25.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {25.599999999999998`, "C", 1, {
             Complex[9.307588282404819, 0.8232081877787825], 
             Complex[7.620508417879314, -0.4064348848292412]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30765015002498, 0.8295818632429439}],
           RowBox[{"{", 
             RowBox[{"25.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {25.7, "C", 1, {
             Complex[9.30765015002498, 0.8295818632429439], 
             Complex[7.620590462338554, -0.40057844477933563`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30770956839477, 0.8358650512460974}],
           RowBox[{"{", 
             RowBox[{"25.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {25.799999999999997`, "C", 1, {
             Complex[9.30770956839477, 0.8358650512460974], 
             Complex[7.620669620363364, -0.3948075030162847]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307766661274705, 0.8420604340909561}],
           RowBox[{"{", 
             RowBox[{"25.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {25.9, "C", 1, {
             Complex[9.307766661274705, 0.8420604340909561], 
             Complex[7.620746026875822, -0.38911951616260565`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307821544314418, 0.8481705716325364}],
           RowBox[{"{", 
             RowBox[{"26.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26., "C", 1, {
             Complex[9.307821544314418, 0.8481705716325364], 
             Complex[7.620819808285308, -0.38351205693401424`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307874325710909, 0.8541979088518956}],
           RowBox[{"{", 
             RowBox[{"26.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {26.099999999999998`, "C", 1, {
             Complex[9.307874325710909, 0.8541979088518956], 
             Complex[7.620891083164294, -0.3779828069654451]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30792510680319, 0.860144782839487}],
           RowBox[{"{", 
             RowBox[{"26.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.2, "C", 1, {
             Complex[9.30792510680319, 0.860144782839487], 
             Complex[7.620959962859786, -0.37252955019570744`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.307973982610356, 0.8660134292433511}],
           RowBox[{"{", 
             RowBox[{"26.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.299999999999997`, "C", 1, {
             Complex[9.307973982610356, 0.8660134292433511], 
             Complex[7.6210265520474145`, -0.36715016675857504`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308021042319387, 0.8718059882315835}],
           RowBox[{"{", 
             RowBox[{"26.399999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.399999999999995`, "C", 1, {
             Complex[9.308021042319387, 0.8718059882315835], 
             Complex[7.621090949234536, -0.36184262733357503`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308066369728037, 0.8775245100130518}],
           RowBox[{"{", 
             RowBox[{"26.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.499999999999996`, "C", 1, {
             Complex[9.308066369728037, 0.8775245100130518], 
             Complex[7.621153247217728, -0.35660498791489154`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308110043647693, 0.8831709599557607}],
           RowBox[{"{", 
             RowBox[{"26.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {26.599999999999998`, "C", 1, {
             Complex[9.308110043647693, 0.8831709599557607], 
             Complex[7.621213533499528, -0.3514353849611332]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30815213827031, 0.888747223338151}],
           RowBox[{"{", 
             RowBox[{"26.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.699999999999996`, "C", 1, {
             Complex[9.30815213827031, 0.888747223338151], 
             Complex[7.621271890668614, -0.34633203089259035`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308192723503184, 0.8942551097650254}],
           RowBox[{"{", 
             RowBox[{"26.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {26.799999999999997`, "C", 1, {
             Complex[9.308192723503184, 0.8942551097650254], 
             Complex[7.6213283967471925`, -0.3412932099060126]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30823186527481, 0.8996963572765849}],
           RowBox[{"{", 
             RowBox[{"26.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {26.9, "C", 1, {
             Complex[9.30823186527481, 0.8996963572765849], 
             Complex[7.621383125508848, -0.33631727407995976`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308269625814717, 0.9050726361762732}],
           RowBox[{"{", 
             RowBox[{"27.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {27., "C", 1, {
             Complex[9.308269625814717, 0.9050726361762732], 
             Complex[7.621436146769792, -0.33140263974642126`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308306063909846, 0.9103855526005625}],
           RowBox[{"{", 
             RowBox[{"27.1`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.1, "C", 1, {
             Complex[9.308306063909846, 0.9103855526005625], 
             Complex[7.621487526656122, -0.3265477841068158]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308341235139771, 0.9156366518516708}],
           RowBox[{"{", 
             RowBox[{"27.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.2, "C", 1, {
             Complex[9.308341235139771, 0.9156366518516708], 
             Complex[7.621537327849359, -0.321751242072515]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308375192092747, 0.9208274215121248}],
           RowBox[{"{", 
             RowBox[{"27.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.299999999999997`, "C", 1, {
             Complex[9.308375192092747, 0.9208274215121248], 
             Complex[7.62158560981236, -0.3170116033119914]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30840798456442, 0.9259592943584085}],
           RowBox[{"{", 
             RowBox[{"27.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {27.4, "C", 1, {
             Complex[9.30840798456442, 0.9259592943584085], 
             Complex[7.621632428997374, -0.31232750948827986`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308439659740836, 0.931033651089264}],
           RowBox[{"{", 
             RowBox[{"27.499999999999993`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.499999999999993`, "C", 1, {
             Complex[9.308439659740836, 0.931033651089264], 
             Complex[7.621677839037961, -0.3076976516720168]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30847026236711, 0.9360518228828761}],
           RowBox[{"{", 
             RowBox[{"27.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.599999999999994`, "C", 1, {
             Complex[9.30847026236711, 0.9360518228828761], 
             Complex[7.621721890926156, -0.3031207679165936]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308499834903161, 0.9410150937958542}],
           RowBox[{"{", 
             RowBox[{"27.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {27.699999999999996`, "C", 1, {
             Complex[9.308499834903161, 0.9410150937958542], 
             Complex[7.62176463317627, -0.29859564098319413`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308528417667576, 0.9459247030157971}],
           RowBox[{"{", 
             RowBox[{"27.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {27.799999999999997`, "C", 1, {
             Complex[9.308528417667576, 0.9459247030157971], 
             Complex[7.621806111976447, -0.29412109620456683`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308556048970686, 0.9507818469782096}],
           RowBox[{"{", 
             RowBox[{"27.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {27.9, "C", 1, {
             Complex[9.308556048970686, 0.9507818469782096], 
             Complex[7.6218463713290605`, -0.28969599947733177`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308582765237823, 0.9555876813576076}],
           RowBox[{"{", 
             RowBox[{"27.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {27.999999999999996`, "C", 1, {
             Complex[9.308582765237823, 0.9555876813576076], 
             Complex[7.621885453180955, -0.2853192553735133]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30860860112351, 0.960343322941825}],
           RowBox[{"{", 
             RowBox[{"28.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {28.099999999999998`, "C", 1, {
             Complex[9.30860860112351, 0.960343322941825], 
             Complex[7.621923397544282, -0.2809898053627634]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308633589617479, 0.9650498513977598}],
           RowBox[{"{", 
             RowBox[{"28.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {28.2, "C", 1, {
             Complex[9.308633589617479, 0.9650498513977598], 
             Complex[7.6219602426088535`, -0.276706626137473]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30865776214308, 0.9697083109361536}],
           RowBox[{"{", 
             RowBox[{"28.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.3, "C", 1, {
             Complex[9.30865776214308, 0.9697083109361536], 
             Complex[7.6219960248466, -0.27246872803358446`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30868114864878, 0.974319711882344}],
           RowBox[{"{", 
             RowBox[{"28.399999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {28.399999999999995`, "C", 1, {
             Complex[9.30868114864878, 0.974319711882344], 
             Complex[7.622030779108829, -0.2682751535405323]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308703777693312, 0.9788850321593942}],
           RowBox[{"{", 
             RowBox[{"28.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.499999999999996`, "C", 1, {
             Complex[9.308703777693312, 0.9788850321593942], 
             Complex[7.622064538716871, -0.26412497589424166`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308725676524938, 0.9834052186894814}],
           RowBox[{"{", 
             RowBox[{"28.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.599999999999998`, "C", 1, {
             Complex[9.308725676524938, 0.9834052186894814], 
             Complex[7.6220973355465995`, -0.26001729774761967`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308746871155384, 0.9878811887189863}],
           RowBox[{"{", 
             RowBox[{"28.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {28.699999999999996`, "C", 1, {
             Complex[9.308746871155384, 0.9878811887189863], 
             Complex[7.622129200107364, -0.2559512499133873]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308767386428746, 0.9923138310722672}],
           RowBox[{"{", 
             RowBox[{"28.799999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.799999999999994`, "C", 1, {
             Complex[9.308767386428746, 0.9923138310722672], 
             Complex[7.622160161615688, -0.25192599017451744`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30878724608588, 0.9967040073387546}],
           RowBox[{"{", 
             RowBox[{"28.899999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.899999999999995`, "C", 1, {
             Complex[9.30878724608588, 0.9967040073387546], 
             Complex[7.622190248064221, -0.24794070215790154`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308806472824529, 1.0010525529976397`}],
           RowBox[{"{", 
             RowBox[{"28.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {28.999999999999996`, "C", 1, {
             Complex[9.308806472824529, 1.0010525529976397`], 
             Complex[7.622219486286243, -0.24399459426719103`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308825088355581, 1.0053602784840994`}],
           RowBox[{"{", 
             RowBox[{"29.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.099999999999998`, "C", 1, {
             Complex[9.308825088355581, 1.0053602784840994`], 
             Complex[7.622247902016085, -0.24008689867107663`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308843113455703, 1.0096279702007276`}],
           RowBox[{"{", 
             RowBox[{"29.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {29.2, "C", 1, {
             Complex[9.308843113455703, 1.0096279702007276`], 
             Complex[7.622275519945756, -0.236216870343528]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308860568016621, 1.0138563914775585`}],
           RowBox[{"{", 
             RowBox[{"29.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.299999999999997`, "C", 1, {
             Complex[9.308860568016621, 1.0138563914775585`], 
             Complex[7.622302363778045, -0.23238378615278985`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308877471091341, 1.0180462834838366`}],
           RowBox[{"{", 
             RowBox[{"29.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.4, "C", 1, {
             Complex[9.308877471091341, 1.0180462834838366`], 
             Complex[7.622328456276393, -0.22858694399613969`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308893840937472, 1.0221983660944407`}],
           RowBox[{"{", 
             RowBox[{"29.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.5, "C", 1, {
             Complex[9.308893840937472, 1.0221983660944407`], 
             Complex[7.622353819311706, -0.22482566197765572`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.3089096950579, 1.0263133387136967`}],
           RowBox[{"{", 
             RowBox[{"29.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.599999999999998`, "C", 1, {
             Complex[9.3089096950579, 1.0263133387136967`], 
             Complex[7.62237847390638, -0.22109927762639908`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30892505023899, 1.0303918810590929`}],
           RowBox[{"{", 
             RowBox[{"29.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.699999999999996`, "C", 1, {
             Complex[9.30892505023899, 1.0303918810590929`], 
             Complex[7.622402440275706, -0.21740714715263532`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30893992258648, 1.034434653907242}],
           RowBox[{"{", 
             RowBox[{"29.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.799999999999997`, "C", 1, {
             Complex[9.30893992258648, 1.034434653907242], 
             Complex[7.622425737866838, -0.21374864473986183`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308954327559254, 1.0384422998042997`}],
           RowBox[{"{", 
             RowBox[{"29.899999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {29.899999999999995`, "C", 1, {
             Complex[9.308954327559254, 1.0384422998042997`], 
             Complex[7.622448385395499, -0.2101231618705582]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308968280001098, 1.042415443742859}],
           RowBox[{"{", 
             RowBox[{"29.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {29.999999999999996`, "C", 1, {
             Complex[9.308968280001098, 1.042415443742859], 
             Complex[7.622470400880571, -0.20653010668373517`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30898179417064, 1.04635469380724}],
           RowBox[{"{", 
             RowBox[{"30.099999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.099999999999998`, "C", 1, {
             Complex[9.30898179417064, 1.04635469380724], 
             Complex[7.6224918016767305`, -0.20296890336247192`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.308994883769515, 1.0502606417889433`}],
           RowBox[{"{", 
             RowBox[{"30.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {30.199999999999996`, "C", 1, {
             Complex[9.308994883769515, 1.0502606417889433`], 
             Complex[7.622512604505212, -0.199438991549757]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309007561968963, 1.0541338637739348`}],
           RowBox[{"{", 
             RowBox[{"30.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.299999999999997`, "C", 1, {
             Complex[9.309007561968963, 1.0541338637739348`], 
             Complex[7.622532825482894, -0.19593982579105432`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309019841434887, 1.0579749207033116`}],
           RowBox[{"{", 
             RowBox[{"30.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {30.4, "C", 1, {
             Complex[9.309019841434887, 1.0579749207033116`], 
             Complex[7.62255248014975, -0.1924708750021304]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309031734351517, 1.0617843589087967`}],
           RowBox[{"{", 
             RowBox[{"30.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.5, "C", 1, {
             Complex[9.309031734351517, 1.0617843589087967`], 
             Complex[7.622571583494798, -0.18903162196075995`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309043252443763, 1.0655627106244419`}],
           RowBox[{"{", 
             RowBox[{"30.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.599999999999998`, "C", 1, {
             Complex[9.309043252443763, 1.0655627106244419`], 
             Complex[7.6225901499806685`, -0.18562156282100936`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309054406998325, 1.069310494475782}],
           RowBox[{"{", 
             RowBox[{"30.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.699999999999996`, "C", 1, {
             Complex[9.309054406998325, 1.069310494475782], 
             Complex[7.622608193566827, -0.18224020664891896`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309065208883657, 1.0730282159476647`}],
           RowBox[{"{", 
             RowBox[{"30.799999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.799999999999997`, "C", 1, {
             Complex[9.309065208883657, 1.0730282159476647`], 
             Complex[7.622625727731571, -0.17888707497841683`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30907566856886, 1.076716367831864}],
           RowBox[{"{", 
             RowBox[{"30.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {30.9, "C", 1, {
             Complex[9.30907566856886, 1.076716367831864], 
             Complex[7.622642765492878, -0.17556170138642116`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309085796141549, 1.0803754306555196`}],
           RowBox[{"{", 
             RowBox[{"30.999999999999993`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {30.999999999999993`, "C", 1, {
             Complex[9.309085796141549, 1.0803754306555196`], 
             Complex[7.622659319428154, -0.1722636310861379]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309095601324776, 1.0840058730914168`}],
           RowBox[{"{", 
             RowBox[{"31.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.099999999999994`, "C", 1, {
             Complex[9.309095601324776, 1.0840058730914168`], 
             Complex[7.622675401692968, -0.16899242053759034`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309105093493066, 1.0876081523510002`}],
           RowBox[{"{", 
             RowBox[{"31.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.199999999999996`, "C", 1, {
             Complex[9.309105093493066, 1.0876081523510002`], 
             Complex[7.622691024038829, -0.16574763707454038`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309114281687616, 1.0911827145610287`}],
           RowBox[{"{", 
             RowBox[{"31.299999999999997`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.299999999999997`, "C", 1, {
             Complex[9.309114281687616, 1.0911827145610287`], 
             Complex[7.622706197830052, -0.16252885854692958`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309123174630706, 1.0947299951246658`}],
           RowBox[{"{", 
             RowBox[{"31.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.4, "C", 1, {
             Complex[9.309123174630706, 1.0947299951246658`], 
             Complex[7.6227209340597835`, -0.15933567297809714`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309131780739362, 1.098250419067798}],
           RowBox[{"{", 
             RowBox[{"31.499999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {31.499999999999996`, "C", 1, {
             Complex[9.309131780739362, 1.098250419067798], 
             Complex[7.622735243365228, -0.1561676782360194]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309140108138353, 1.1017444013712938`}],
           RowBox[{"{", 
             RowBox[{"31.599999999999998`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.599999999999998`, "C", 1, {
             Complex[9.309140108138353, 1.1017444013712938`], 
             Complex[7.622749136042124, -0.15302448171788963`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309148164672497, 1.1052123472899034`}],
           RowBox[{"{", 
             RowBox[{"31.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.7, "C", 1, {
             Complex[9.309148164672497, 1.1052123472899034`], 
             Complex[7.622762622058501, -0.14990570004738207`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309155957918382, 1.1086546526584367`}],
           RowBox[{"{", 
             RowBox[{"31.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.8, "C", 1, {
             Complex[9.309155957918382, 1.1086546526584367`], 
             Complex[7.622775711067788, -0.14681095878399034`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309163495195484, 1.112071704185835}],
           RowBox[{"{", 
             RowBox[{"31.899999999999995`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.899999999999995`, "C", 1, {
             Complex[9.309163495195484, 1.112071704185835], 
             Complex[7.622788412421261, -0.14373989214385835`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309170783576755, 1.11546387973771}],
           RowBox[{"{", 
             RowBox[{"31.999999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {31.999999999999996`, "C", 1, {
             Complex[9.309170783576755, 1.11546387973771], 
             Complex[7.622800735179931, -0.14069214273155697`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309177829898688, 1.118831548607897}],
           RowBox[{"{", 
             RowBox[{"32.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.099999999999994`, "C", 1, {
             Complex[9.309177829898688, 1.118831548607897], 
             Complex[7.62281268812585, -0.13766736128229182`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309184640770896, 1.1221750717795362`}],
           RowBox[{"{", 
             RowBox[{"32.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {32.199999999999996`, "C", 1, {
             Complex[9.309184640770896, 1.1221750717795362`], 
             Complex[7.622824279772895, -0.1346652064140495]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309191222585227, 1.1254948021761624`}],
           RowBox[{"{", 
             RowBox[{"32.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.3, "C", 1, {
             Complex[9.309191222585227, 1.1254948021761624`], 
             Complex[7.622835518377028, -0.13168534438923124`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309197581524451, 1.1287910849032743`}],
           RowBox[{"{", 
             RowBox[{"32.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.4, "C", 1, {
             Complex[9.309197581524451, 1.1287910849032743`], 
             Complex[7.6228464119461155`, -0.12872744888532328`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309203723570544, 1.1320642574808066`}],
           RowBox[{"{", 
             RowBox[{"32.49999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {32.49999999999999, "C", 1, {
             Complex[9.309203723570544, 1.1320642574808066`], 
             Complex[7.622856968249287, -0.1257912007742034]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309209654512566, 1.1353146500669253`}],
           RowBox[{"{", 
             RowBox[{"32.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.599999999999994`, "C", 1, {
             Complex[9.309209654512566, 1.1353146500669253`], 
             Complex[7.622867194825848, -0.12287628790968698`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309215379954184, 1.1385425856735312`}],
           RowBox[{"{", 
             RowBox[{"32.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.699999999999996`, "C", 1, {
             Complex[9.309215379954184, 1.1385425856735312`], 
             Complex[7.622877098993824, -0.11998240492294286`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309220905320853, 1.1417483803738433`}],
           RowBox[{"{", 
             RowBox[{"32.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {32.8, "C", 1, {
             Complex[9.309220905320853, 1.1417483803738433`], 
             Complex[7.622886687858099, -0.1171092530254295]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30922623586666, 1.1449323435024106`}],
           RowBox[{"{", 
             RowBox[{"32.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {32.9, "C", 1, {
             Complex[9.30922623586666, 1.1449323435024106`], 
             Complex[7.622895968318212, -0.11425653981902067`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30923137668085, 1.1480947778478905`}],
           RowBox[{"{", 
             RowBox[{"33.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33., "C", 1, {
             Complex[9.30923137668085, 1.1480947778478905`], 
             Complex[7.622904947075782, -0.11142397911299567`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309236332694079, 1.151235979838898}],
           RowBox[{"{", 
             RowBox[{"33.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.099999999999994`, "C", 1, {
             Complex[9.309236332694079, 1.151235979838898], 
             Complex[7.622913630641643, -0.10861129074761434`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309241108684372, 1.154356239723236}],
           RowBox[{"{", 
             RowBox[{"33.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.199999999999996`, "C", 1, {
             Complex[9.309241108684372, 1.154356239723236], 
             Complex[7.622922025342652, -0.10581820042396912`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309245709282818, 1.1574558417407832`}],
           RowBox[{"{", 
             RowBox[{"33.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.3, "C", 1, {
             Complex[9.309245709282818, 1.1574558417407832`], 
             Complex[7.622930137328205, -0.10304443953986439`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309250138979012, 1.1605350642903134`}],
           RowBox[{"{", 
             RowBox[{"33.39999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.39999999999999, "C", 1, {
             Complex[9.309250138979012, 1.1605350642903134`], 
             Complex[7.62293797257647, -0.10028974503145545`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309254402126275, 1.1635941800905014`}],
           RowBox[{"{", 
             RowBox[{"33.49999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.49999999999999, "C", 1, {
             Complex[9.309254402126275, 1.1635941800905014`], 
             Complex[7.6229455369003825`, -0.09755385922040935]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309258502946614, 1.1666334563353578`}],
           RowBox[{"{", 
             RowBox[{"33.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.599999999999994`, "C", 1, {
             Complex[9.309258502946614, 1.1666334563353578`], 
             Complex[7.622952835953341, -0.09483652966635159]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30926244553551, 1.1696531548443287`}],
           RowBox[{"{", 
             RowBox[{"33.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.699999999999996`, "C", 1, {
             Complex[9.30926244553551, 1.1696531548443287`], 
             Complex[7.622959875234723, -0.09213750902438231]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309266233866467, 1.1726535322072742`}],
           RowBox[{"{", 
             RowBox[{"33.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.8, "C", 1, {
             Complex[9.309266233866467, 1.1726535322072742`], 
             Complex[7.62296666009513, -0.08945655490745465]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309269871795374, 1.1756348399245429`}],
           RowBox[{"{", 
             RowBox[{"33.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {33.9, "C", 1, {
             Complex[9.309269871795374, 1.1756348399245429`], 
             Complex[7.6229731957414195`, -0.08679342975340713]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309273363064712, 1.178597324542335}],
           RowBox[{"{", 
             RowBox[{"34.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {34., "C", 1, {
             Complex[9.309273363064712, 1.178597324542335], 
             Complex[7.622979487241573, -0.0841479006964717]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309276711307533, 1.1815412277835524`}],
           RowBox[{"{", 
             RowBox[{"34.1`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.1, "C", 1, {
             Complex[9.309276711307533, 1.1815412277835524`], 
             Complex[7.622985539529303, -0.08151973944306835]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309279920051315, 1.18446678667431}],
           RowBox[{"{", 
             RowBox[{"34.2`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {34.2, "C", 1, {
             Complex[9.309279920051315, 1.18446678667431], 
             Complex[7.622991357408528, -0.0789087221517155]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30928299272165, 1.1873742336662831`}],
           RowBox[{"{", 
             RowBox[{"34.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {34.3, "C", 1, {
             Complex[9.30928299272165, 1.1873742336662831`], 
             Complex[7.622996945557652, -0.0763146293168978]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309285932645754, 1.1902637967550587`}],
           RowBox[{"{", 
             RowBox[{"34.39999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.39999999999999, "C", 1, {
             Complex[9.309285932645754, 1.1902637967550587`], 
             Complex[7.623002308533652, -0.07373724565672798]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309288743055875, 1.193135699594645}],
           RowBox[{"{", 
             RowBox[{"34.49999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.49999999999999, "C", 1, {
             Complex[9.309288743055875, 1.193135699594645], 
             Complex[7.623007450776044, -0.07117636000425508]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309291427092525, 1.195990161608288}],
           RowBox[{"{", 
             RowBox[{"34.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.599999999999994`, "C", 1, {
             Complex[9.309291427092525, 1.195990161608288], 
             Complex[7.623012376610668, -0.06863176520228108]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309293987807608, 1.1988273980957402`}],
           RowBox[{"{", 
             RowBox[{"34.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.699999999999996`, "C", 1, {
             Complex[9.309293987807608, 1.1988273980957402`], 
             Complex[7.623017090253322, -0.06610325800154515]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309296428167405, 1.201647620337122}],
           RowBox[{"{", 
             RowBox[{"34.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {34.8, "C", 1, {
             Complex[9.309296428167405, 1.201647620337122], 
             Complex[7.623021595813277, -0.06359063896214531]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309298751055461, 1.204451035693495}],
           RowBox[{"{", 
             RowBox[{"34.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {34.9, "C", 1, {
             Complex[9.309298751055461, 1.204451035693495], 
             Complex[7.623025897296652, -0.061093712358079366`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30930095927532, 1.2072378477042842`}],
           RowBox[{"{", 
             RowBox[{"35.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {35., "C", 1, {
             Complex[9.30930095927532, 1.2072378477042842`], 
             Complex[7.62302999860963, -0.05861228608478186]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309303055553212, 1.2100082561816605`}],
           RowBox[{"{", 
             RowBox[{"35.1`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.1, "C", 1, {
             Complex[9.309303055553212, 1.2100082561816605`], 
             Complex[7.6230339035616055`, -0.0561461715695423]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309305042540569, 1.212762457302003}],
           RowBox[{"{", 
             RowBox[{"35.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {35.199999999999996`, "C", 1, {
             Complex[9.309305042540569, 1.212762457302003], 
             Complex[7.623037615868166, -0.05369518368470496]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30930692281649, 1.2155006436945397`}],
           RowBox[{"{", 
             RowBox[{"35.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.3, "C", 1, {
             Complex[9.30930692281649, 1.2155006436945397`], 
             Complex[7.623041139153995, -0.051259140663536505`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309308698890094, 1.2182230045272866`}],
           RowBox[{"{", 
             RowBox[{"35.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.4, "C", 1, {
             Complex[9.309308698890094, 1.2182230045272866`], 
             Complex[7.623044476955635, -0.048837864018669234`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309310373202791, 1.2209297255903702`}],
           RowBox[{"{", 
             RowBox[{"35.49999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.49999999999999, "C", 1, {
             Complex[9.309310373202791, 1.2209297255903702`], 
             Complex[7.623047632724201, -0.0464311784630234]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309311948130448, 1.2236209893768368`}],
           RowBox[{"{", 
             RowBox[{"35.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {35.599999999999994`, "C", 1, {
             Complex[9.309311948130448, 1.2236209893768368`], 
             Complex[7.62305060982792, -0.04403891183311752]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30931342598549, 1.2262969751610369`}],
           RowBox[{"{", 
             RowBox[{"35.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.699999999999996`, "C", 1, {
             Complex[9.30931342598549, 1.2262969751610369`], 
             Complex[7.623053411554656, -0.041660895014681676`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309314809018922, 1.2289578590746733`}],
           RowBox[{"{", 
             RowBox[{"35.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {35.8, "C", 1, {
             Complex[9.309314809018922, 1.2289578590746733`], 
             Complex[7.623056041114284, -0.03929696187048912]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309316099422276, 1.2316038141805976`}],
           RowBox[{"{", 
             RowBox[{"35.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {35.9, "C", 1, {
             Complex[9.309316099422276, 1.2316038141805976`], 
             Complex[7.623058501641021, -0.03694694917032467]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309317299329457, 1.2342350105444317`}],
           RowBox[{"{", 
             RowBox[{"35.99999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {35.99999999999999, "C", 1, {
             Complex[9.309317299329457, 1.2342350105444317`], 
             Complex[7.623060796195637, -0.034610696523021345`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30931841081857, 1.2368516153040952`}],
           RowBox[{"{", 
             RowBox[{"36.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {36.099999999999994`, "C", 1, {
             Complex[9.30931841081857, 1.2368516153040952`], 
             Complex[7.6230629277676165`, -0.03228804631048309]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309319435913645, 1.2394537927373108`}],
           RowBox[{"{", 
             RowBox[{"36.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.199999999999996`, "C", 1, {
             Complex[9.309319435913645, 1.2394537927373108`], 
             Complex[7.623064899277239, -0.029978843623626066`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309320376586301, 1.2420417043271583`}],
           RowBox[{"{", 
             RowBox[{"36.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.3, "C", 1, {
             Complex[9.309320376586301, 1.2420417043271583`], 
             Complex[7.62306671357756, -0.027682936200179965`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309321234757373, 1.2446155088257416`}],
           RowBox[{"{", 
             RowBox[{"36.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {36.4, "C", 1, {
             Complex[9.309321234757373, 1.2446155088257416`], 
             Complex[7.623068373456371, -0.02540017436427072]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30932201229845, 1.247175362316046}],
           RowBox[{"{", 
             RowBox[{"36.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {36.5, "C", 1, {
             Complex[9.30932201229845, 1.247175362316046], 
             Complex[7.623069881638048, -0.02313041096773061]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309322711033374, 1.2497214182720298`}],
           RowBox[{"{", 
             RowBox[{"36.6`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.6, "C", 1, {
             Complex[9.309322711033374, 1.2497214182720298`], 
             Complex[7.62307124078535, -0.020873501333080847`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309323332739702, 1.2522538276170265`}],
           RowBox[{"{", 
             RowBox[{"36.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.699999999999996`, "C", 1, {
             Complex[9.309323332739702, 1.2522538276170265`], 
             Complex[7.623072453501181, -0.018629303198118775`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309323879150051, 1.254772738780499}],
           RowBox[{"{", 
             RowBox[{"36.79999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.79999999999999, "C", 1, {
             Complex[9.309323879150051, 1.254772738780499], 
             Complex[7.623073522330233, -0.016397676662069878`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309324351953519, 1.2572782977532362`}],
           RowBox[{"{", 
             RowBox[{"36.89999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {36.89999999999999, "C", 1, {
             Complex[9.309324351953519, 1.2572782977532362`], 
             Complex[7.623074449760668, -0.014178484133219656`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309324752796902, 1.2597706481409692`}],
           RowBox[{"{", 
             RowBox[{"36.99999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {36.99999999999999, "C", 1, {
             Complex[9.309324752796902, 1.2597706481409692`], 
             Complex[7.623075238225624, -0.01197159027804566]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325083285957, 1.26224993121657}],
           RowBox[{"{", 
             RowBox[{"37.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.099999999999994`, "C", 1, {
             Complex[9.309325083285957, 1.26224993121657], 
             Complex[7.623075890104745, -0.009776861971693968]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325344986703, 1.2647162859707826`}],
           RowBox[{"{", 
             RowBox[{"37.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.199999999999996`, "C", 1, {
             Complex[9.309325344986703, 1.2647162859707826`], 
             Complex[7.623076407725729, -0.007594168249853738]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30932553942646, 1.2671698491615646`}],
           RowBox[{"{", 
             RowBox[{"37.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.3, "C", 1, {
             Complex[9.30932553942646, 1.2671698491615646`], 
             Complex[7.62307679336563, -0.005423380261944406]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325668095038, 1.2696107553621176`}],
           RowBox[{"{", 
             RowBox[{"37.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.4, "C", 1, {
             Complex[9.309325668095038, 1.2696107553621176`], 
             Complex[7.623077049252295, -0.003264371225554161]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325732445826, 1.2720391370076072`}],
           RowBox[{"{", 
             RowBox[{"37.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.5, "C", 1, {
             Complex[9.309325732445826, 1.2720391370076072`], 
             Complex[7.623077177565682, -0.0011170163821173382`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325733896824, 1.2744551244406346`}],
           RowBox[{"{", 
             RowBox[{"37.6`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.6, "C", 1, {
             Complex[9.309325733896824, 1.2744551244406346`], 
             Complex[7.623077180439138, 0.0010188070462170521`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325673831674, 1.2768588459554961`}],
           RowBox[{"{", 
             RowBox[{"37.7`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.7, "C", 1, {
             Complex[9.309325673831674, 1.2768588459554961`], 
             Complex[7.62307705996065, 0.003143219898572241]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30932555360063, 1.2792504278412689`}],
           RowBox[{"{", 
             RowBox[{"37.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.8, "C", 1, {
             Complex[9.30932555360063, 1.2792504278412689`], 
             Complex[7.62307681817404, 0.005256341116210763]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30932537452151, 1.2816299944237615`}],
           RowBox[{"{", 
             RowBox[{"37.89999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.89999999999999, "C", 1, {
             Complex[9.30932537452151, 1.2816299944237615`], 
             Complex[7.62307645708013, 0.007358287782327438]}, 0}, "Tooltip"]& 
          ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309325137880622, 1.2839976681063674`}],
           RowBox[{"{", 
             RowBox[{"37.99999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {37.99999999999999, "C", 1, {
             Complex[9.309325137880622, 1.2839976681063674`], 
             Complex[7.623075978637889, 0.009449175160798235]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309324844933629, 1.286353569409846}],
           RowBox[{"{", 
             RowBox[{"38.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {38.099999999999994`, "C", 1, {
             Complex[9.309324844933629, 1.286353569409846], 
             Complex[7.6230753847654915`, 0.01152911673391317]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309324496906415, 1.2886978170110814`}],
           RowBox[{"{", 
             RowBox[{"38.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {38.199999999999996`, "C", 1, {
             Complex[9.309324496906415, 1.2886978170110814`], 
             Complex[7.62307467734139, 0.013598224239136788`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309324094995942, 1.291030527780833}],
           RowBox[{"{", 
             RowBox[{"38.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {38.3, "C", 1, {
             Complex[9.309324094995942, 1.291030527780833], 
             Complex[7.62307385820537, 0.015656607704910973`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309323640371, 1.2933518168205271`}],
           RowBox[{"{", 
             RowBox[{"38.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {38.4, "C", 1, {
             Complex[9.309323640371, 1.2933518168205271`], 
             Complex[7.623072929159484, 0.017704375485551985`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309323134173042, 1.2956617974980962`}],
           RowBox[{"{", 
             RowBox[{"38.5`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {38.5, "C", 1, {
             Complex[9.309323134173042, 1.2956617974980962`], 
             Complex[7.623071891969081, 0.019741634295234595`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309322577516868, 1.2979605814829327`}],
           RowBox[{"{", 
             RowBox[{"38.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {38.599999999999994`, "C", 1, {
             Complex[9.309322577516868, 1.2979605814829327`], 
             Complex[7.623070748363671, 0.02176848924114553]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309321971491423, 1.300248278779899}],
           RowBox[{"{", 
             RowBox[{"38.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {38.699999999999996`, "C", 1, {
             Complex[9.309321971491423, 1.300248278779899], 
             Complex[7.623069500037891, 0.023785043855733365`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30932131716045, 1.3025249977626072`}],
           RowBox[{"{", 
             RowBox[{"38.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {38.8, "C", 1, {
             Complex[9.30932131716045, 1.3025249977626072`], 
             Complex[7.623068148652344, 0.02579140012826888]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309320615563188, 1.3047908452057129`}],
           RowBox[{"{", 
             RowBox[{"38.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {38.9, "C", 1, {
             Complex[9.309320615563188, 1.3047908452057129`], 
             Complex[7.623066695834459, 0.02778765853546761]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309319867715043, 1.3070459263165168`}],
           RowBox[{"{", 
             RowBox[{"38.99999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {38.99999999999999, "C", 1, {
             Complex[9.309319867715043, 1.3070459263165168`], 
             Complex[7.623065143179328, 0.02977391807145791]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309319074608208, 1.3092903447657454`}],
           RowBox[{"{", 
             RowBox[{"39.099999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.099999999999994`, "C", 1, {
             Complex[9.309319074608208, 1.3092903447657454`], 
             Complex[7.623063492250484, 0.03175027627696571]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309318237212295, 1.311524202717574}],
           RowBox[{"{", 
             RowBox[{"39.199999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.199999999999996`, "C", 1, {
             Complex[9.309318237212295, 1.311524202717574], 
             Complex[7.623061744580699, 0.03371682926778386]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309317356474933, 1.3137476008589228`}],
           RowBox[{"{", 
             RowBox[{"39.3`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.3, "C", 1, {
             Complex[9.309317356474933, 1.3137476008589228`], 
             Complex[7.623059901672726, 0.03567367176254808]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309316433322348, 1.3159606384280351`}],
           RowBox[{"{", 
             RowBox[{"39.4`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {39.4, "C", 1, {
             Complex[9.309316433322348, 1.3159606384280351`], 
             Complex[7.6230579650000365`, 0.037620897109835086`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309315468659923, 1.3181634132423605`}],
           RowBox[{"{", 
             RowBox[{"39.49999999999999`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                  "}"}], ",", "0"}], "}"}]],
          Annotation[#, {39.49999999999999, "C", 1, {
             Complex[9.309315468659923, 1.3181634132423605`], 
             Complex[7.623055936007521, 0.0395585973145974]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30931446337276, 1.3203560217257788`}],
           RowBox[{"{", 
             RowBox[{"39.599999999999994`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.599999999999994`, "C", 1, {
             Complex[9.30931446337276, 1.3203560217257788`], 
             Complex[7.623053816112197, 0.04148686306397394]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.30931341832617, 1.3225385589351384`}],
           RowBox[{"{", 
             RowBox[{"39.699999999999996`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.699999999999996`, "C", 1, {
             Complex[9.30931341832617, 1.3225385589351384`], 
             Complex[7.623051606703843, 0.04340578375245147]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309312334366247, 1.3247111185862175`}],
           RowBox[{"{", 
             RowBox[{"39.8`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {39.8, "C", 1, {
             Complex[9.309312334366247, 1.3247111185862175`], 
             Complex[7.6230493091457, 0.04531544750647416]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309311212320324, 1.3268737930790047`}],
           RowBox[{"{", 
             RowBox[{"39.9`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                 "}"}], ",", "0"}], "}"}]],
          Annotation[#, {39.9, "C", 1, {
             Complex[9.309311212320324, 1.3268737930790047`], 
             Complex[7.623046924775063, 0.047215941208410626`]}, 0}, 
           "Tooltip"]& ]}, 
        {RGBColor[0, 
          NCache[
           Rational[2, 3], 0.6666666666666666], 0], 
         TagBox[
          TooltipBox[PointBox[{9.309310052997454, 1.3290266735224268`}],
           RowBox[{"{", 
             RowBox[{"40.`", ",", "\"C\"", ",", "1", ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                   ",", 
                   RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], "}"}],
                ",", "0"}], "}"}]],
          Annotation[#, {40., "C", 1, {
             Complex[9.309310052997454, 1.3290266735224268`], 
             Complex[7.623044454903904, 0.04910735051999668]}, 0}, 
           "Tooltip"]& ]}}},
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"Re(\[Omega]t)\"", TraditionalForm], 
        FormBox["\"Im(\[Omega]t)\"", TraditionalForm]},
      ImageSize->800,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[{{{
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.071355131675201}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0068877274873969585`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {15.999999999999998`, "C", 
             Association[1 -> {
                Complex[7.8360190079650485`, 0.006645071137818026], 
                Complex[6.1962322662149445`, -1.1633793876684915`]}, 2 -> {
                Complex[8.118560581075961, 0.0068877274873969585`], 
                Complex[6.478753355849045, -1.1631402225643317`]}, 3 -> {
                Complex[10.53989419288883, -0.01324317030169899], 
                Complex[8.80001605246603, -1.1961486271318056`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.071355131675201}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.8360190079650485`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.1962322662149445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.118560581075961`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0068877274873969585`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.478753355849045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631402225643317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.53989419288883`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01324317030169899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.80001605246603`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1961486271318056`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {15.999999999999998`, "C", 
             Association[1 -> {
                Complex[7.8360190079650485`, 0.006645071137818026], 
                Complex[6.1962322662149445`, -1.1633793876684915`]}, 2 -> {
                Complex[8.118560581075961, 0.0068877274873969585`], 
                Complex[6.478753355849045, -1.1631402225643317`]}, 3 -> {
                Complex[10.53989419288883, -0.01324317030169899], 
                Complex[8.80001605246603, -1.1961486271318056`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.073780811395456}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.795901779221279, 0.006712510785854963], 
                Complex[6.155525231634676, -1.1633781485602357`]}, 2 -> {
                Complex[8.162580737731858, 0.007042959985370651], 
                Complex[6.5221587863983865`, -1.1630554690196342`]}, 3 -> {
                Complex[10.494506767269, -0.013509876715323853`], 
                Complex[8.75509227462806, -1.1963255671672886`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.073780811395456}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.795901779221279`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.162580737731858`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007042959985370651`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.5221587863983865`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1630554690196342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.494506767269`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.013509876715323853`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.75509227462806`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1963255671672886`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.795901779221279, 0.006712510785854963], 
                Complex[6.155525231634676, -1.1633781485602357`]}, 2 -> {
                Complex[8.162580737731858, 0.007042959985370651], 
                Complex[6.5221587863983865`, -1.1630554690196342`]}, 3 -> {
                Complex[10.494506767269, -0.013509876715323853`], 
                Complex[8.75509227462806, -1.1963255671672886`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.079880266251177}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.2, "C", 
             Association[1 -> {
                Complex[7.763484521798694, 0.006786025025048383], 
                Complex[6.122517060306264, -1.1633711130594213`]}, 2 -> {
                Complex[8.198987977866883, 0.007197843246654797], 
                Complex[6.557943371421671, -1.162972548762566]}, 3 -> {
                Complex[10.457042457039066`, -0.013751044852512806`], 
                Complex[8.71810174166509, -1.1964748219538672`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -6.079880266251177}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.763484521798694`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025048383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306264`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633711130594213`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.198987977866883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007197843246654797`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.557943371421671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162972548762566`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.457042457039066`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.013751044852512806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.71810174166509`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1964748219538672`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.2, "C", 
             Association[1 -> {
                Complex[7.763484521798694, 0.006786025025048383], 
                Complex[6.122517060306264, -1.1633711130594213`]}, 2 -> {
                Complex[8.198987977866883, 0.007197843246654797], 
                Complex[6.557943371421671, -1.162972548762566]}, 3 -> {
                Complex[10.457042457039066`, -0.013751044852512806`], 
                Complex[8.71810174166509, -1.1964748219538672`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.071710947469221}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0073549519610065905`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.735547972440535, 0.006863336573144897], 
                Complex[6.093988110787665, -1.1633606215314773`]}, 2 -> {
                Complex[8.231005147885755, 0.0073549519610065905`], 
                Complex[6.589330078860689, -1.1628888789503151`]}, 3 -> {
                Complex[10.42414741707873, -0.0139798695984579], 
                Complex[8.685690080337725, -1.1966097210740347`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -6.071710947469221}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.735547972440535`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006863336573144897`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314773`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.231005147885755`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0073549519610065905`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.589330078860689`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628888789503151`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.42414741707873`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0139798695984579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.685690080337725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1966097210740347`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.735547972440535, 0.006863336573144897], 
                Complex[6.093988110787665, -1.1633606215314773`]}, 2 -> {
                Complex[8.231005147885755, 0.0073549519610065905`], 
                Complex[6.589330078860689, -1.1628888789503151`]}, 3 -> {
                Complex[10.42414741707873, -0.0139798695984579], 
                Complex[8.685690080337725, -1.1966097210740347`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -6.044536077552919}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.4, "C", 
             Association[1 -> {
                Complex[7.710629285429999, 0.00694346149760476], 
                Complex[6.068475300453683, -1.1633476974009693`]}, 2 -> {
                Complex[8.260098904258959, 0.007515591774090756], 
                Complex[6.61778553109412, -1.162803172863648]}, 3 -> {
                Complex[10.39429571170861, -0.014202465960725278`], 
                Complex[8.656331133890323, -1.1967364397628084`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -6.044536077552919}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.710629285429999`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00694346149760476`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633476974009693`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.260098904258959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007515591774090756`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.61778553109412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162803172863648`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.39429571170861`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014202465960725278`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.656331133890323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1967364397628084`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.4, "C", 
             Association[1 -> {
                Complex[7.710629285429999, 0.00694346149760476], 
                Complex[6.068475300453683, -1.1633476974009693`]}, 2 -> {
                Complex[8.260098904258959, 0.007515591774090756], 
                Complex[6.61778553109412, -1.162803172863648]}, 3 -> {
                Complex[10.39429571170861, -0.014202465960725278`], 
                Complex[8.656331133890323, -1.1967364397628084`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -6.00437013766296}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.499999999999996`, "C", 
             Association[1 -> {
                Complex[7.687917286732913, 0.007025882918871702], 
                Complex[6.045167287063117, -1.163332885610651]}, 2 -> {
                Complex[8.287084479515974, 0.007680628289981289], 
                Complex[6.644124842294815, -1.162714599075609]}, 3 -> {
                Complex[10.366639367283945`, -0.014422357660350082`], 
                Complex[8.629176867782464, -1.196858523000041]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -6.00437013766296}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.687917286732913`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007025882918871702`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163332885610651`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.287084479515974`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007680628289981289`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.644124842294815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162714599075609`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.366639367283945`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014422357660350082`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.629176867782464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.196858523000041`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.499999999999996`, "C", 
             Association[1 -> {
                Complex[7.687917286732913, 0.007025882918871702], 
                Complex[6.045167287063117, -1.163332885610651]}, 2 -> {
                Complex[8.287084479515974, 0.007680628289981289], 
                Complex[6.644124842294815, -1.162714599075609]}, 3 -> {
                Complex[10.366639367283945`, -0.014422357660350082`], 
                Complex[8.629176867782464, -1.196858523000041]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.960278225909455}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.666906890699567, 0.007110298008162871], 
                Complex[6.023558855884935, -1.163316510563181]}, 2 -> {
                Complex[8.312471288002852, 0.00785074316053409], 
                Complex[6.668857252414808, -1.1626225207983634`]}, 3 -> {
                Complex[10.340648661463618`, -0.014641876121436062`], 
                Complex[8.603697599379137, -1.1969782988821367`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.960278225909455}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.666906890699567`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007110298008162871`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.312471288002852`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00785074316053409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.668857252414808`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626225207983634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.340648661463618`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014641876121436062`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.603697599379137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1969782988821367`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.666906890699567, 0.007110298008162871], 
                Complex[6.023558855884935, -1.163316510563181]}, 2 -> {
                Complex[8.312471288002852, 0.00785074316053409], 
                Complex[6.668857252414808, -1.1626225207983634`]}, 3 -> {
                Complex[10.340648661463618`, -0.014641876121436062`], 
                Complex[8.603697599379137, -1.1969782988821367`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.918848526807887}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.7, "C", 
             Association[1 -> {
                Complex[7.6472584862388935`, 0.007196517077880152], 
                Complex[6.0033102912691545`, -1.163298779461846]}, 2 -> {
                Complex[8.336603564825275, 0.00802653852897203], 
                Complex[6.6923267792271615`, -1.1625263894330444`]}, 3 -> {
                Complex[10.315965756037766`, -0.014862729232274637`], 
                Complex[8.579535601926915, -1.1970974543173976`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.918848526807887}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.6472584862388935`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.0033102912691545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.163298779461846`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.336603564825275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00802653852897203`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.6923267792271615`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1625263894330444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.315965756037766`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.014862729232274637`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.579535601926915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1970974543173976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.7, "C", 
             Association[1 -> {
                Complex[7.6472584862388935`, 0.007196517077880152], 
                Complex[6.0033102912691545`, -1.163298779461846]}, 2 -> {
                Complex[8.336603564825275, 0.00802653852897203], 
                Complex[6.6923267792271615`, -1.1625263894330444`]}, 3 -> {
                Complex[10.315965756037766`, -0.014862729232274637`], 
                Complex[8.579535601926915, -1.1970974543173976`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.883539472838865}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0072844163322486775`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.799999999999997`, "C", 
             Association[1 -> {
                Complex[7.628730822140306, 0.0072844163322486775`], 
                Complex[5.984180253839811, -1.1632798309089558`]}, 2 -> {
                Complex[8.359727508694593, 0.008208588338762687], 
                Complex[6.714779367617378, -1.162425692393188]}, 3 -> {
                Complex[10.29233482504539, -0.015086273942248], 
                Complex[8.556435217312078, -1.197217311276035]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.883539472838865}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.628730822140306`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0072844163322486775`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.984180253839811`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089558`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.359727508694593`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008208588338762687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.714779367617378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162425692393188`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.29233482504539`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.015086273942248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.556435217312078`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.197217311276035`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.799999999999997`, "C", 
             Association[1 -> {
                Complex[7.628730822140306, 0.0072844163322486775`], 
                Complex[5.984180253839811, -1.1632798309089558`]}, 2 -> {
                Complex[8.359727508694593, 0.008208588338762687], 
                Complex[6.714779367617378, -1.162425692393188]}, 3 -> {
                Complex[10.29233482504539, -0.015086273942248], 
                Complex[8.556435217312078, -1.197217311276035]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.855824664058633}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.9, "C", 
             Association[1 -> {
                Complex[7.611145277473936, 0.007373913179256576], 
                Complex[5.965990045977096, -1.1632597604074917`]}, 2 -> {
                Complex[8.382027043209192, 0.008397467701836855], 
                Complex[6.736398653893472, -1.1623199234705246`]}, 3 -> {
                Complex[10.269564843263957`, -0.01531366326459591], 
                Complex[8.534205636043778, -1.1973389757687454`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.855824664058633}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.611145277473936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.382027043209192`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008397467701836855`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.736398653893472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623199234705246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.269564843263957`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01531366326459591`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.534205636043778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1973389757687454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.9, "C", 
             Association[1 -> {
                Complex[7.611145277473936, 0.007373913179256576], 
                Complex[5.965990045977096, -1.1632597604074917`]}, 2 -> {
                Complex[8.382027043209192, 0.008397467701836855], 
                Complex[6.736398653893472, -1.1623199234705246`]}, 3 -> {
                Complex[10.269564843263957`, -0.01531366326459591], 
                Complex[8.534205636043778, -1.1973389757687454`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17., -5.836211563119514}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17., "C", 
             Association[1 -> {
                Complex[7.5943652547457265`, 0.0074649522520338], 
                Complex[5.948603001807254, -1.1632386348615993`]}, 2 -> {
                Complex[8.40364445944282, 0.008593772293729832], 
                Complex[6.757326609412581, -1.1622085635431991`]}, 3 -> {
                Complex[10.247508108692935`, -0.01554593341902805], 
                Complex[8.512699415121856, -1.1974634260014816`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17., -5.836211563119514}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5943652547457265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0074649522520338`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.948603001807254`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.40364445944282`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008593772293729832`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.757326609412581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622085635431991`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.247508108692935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01554593341902805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.512699415121856`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1974634260014816`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17., "C", 
             Association[1 -> {
                Complex[7.5943652547457265`, 0.0074649522520338], 
                Complex[5.948603001807254, -1.1632386348615993`]}, 2 -> {
                Complex[8.40364445944282, 0.008593772293729832], 
                Complex[6.757326609412581, -1.1622085635431991`]}, 3 -> {
                Complex[10.247508108692935`, -0.01554593341902805], 
                Complex[8.512699415121856, -1.1974634260014816`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.8248274712645935`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.0075574969911607935`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.5782835412454626`, 0.0075574969911607935`], 
                Complex[5.931911846413442, -1.1632165013453948`]}, 2 -> {
                Complex[8.424693095053826, 0.00879813306517896], 
                Complex[6.777676219425206, -1.1620910662296873`]}, 3 -> {
                Complex[10.226047052260421`, -0.01578406003523005], 
                Complex[8.491799285559544, -1.1975915689762857`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.8248274712645935`}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5782835412454626`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{"0.0075574969911607935`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.931911846413442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453948`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.424693095053826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00879813306517896`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.777676219425206`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620910662296873`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.226047052260421`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.01578406003523005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.491799285559544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1975915689762857`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.5782835412454626`, 0.0075574969911607935`], 
                Complex[5.931911846413442, -1.1632165013453948`]}, 2 -> {
                Complex[8.424693095053826, 0.00879813306517896], 
                Complex[6.777676219425206, -1.1620910662296873`]}, 3 -> {
                Complex[10.226047052260421`, -0.01578406003523005], 
                Complex[8.491799285559544, -1.1975915689762857`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.821713994123085}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.2, "C", 
             Association[1 -> {
                Complex[7.5628141695271145`, 0.007651524322598731], 
                Complex[5.915830554816423, -1.163193392670451]}, 2 -> {
                Complex[8.445265519754589, 0.009011228909084963], 
                Complex[6.797539667322055, -1.161966845801127]}, 3 -> {
                Complex[10.20508572371207, -0.016028997503587203`], 
                Complex[8.471409637754663, -1.1977242798043068`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.821713994123085}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5628141695271145`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007651524322598731`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.915830554816423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163193392670451`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.445265519754589`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009011228909084963`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.797539667322055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161966845801127`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.20508572371207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.016028997503587203`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.471409637754663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1977242798043068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.2, "C", 
             Association[1 -> {
                Complex[7.5628141695271145`, 0.007651524322598731], 
                Complex[5.915830554816423, -1.163193392670451]}, 2 -> {
                Complex[8.445265519754589, 0.009011228909084963], 
                Complex[6.797539667322055, -1.161966845801127]}, 3 -> {
                Complex[10.20508572371207, -0.016028997503587203`], 
                Complex[8.471409637754663, -1.1977242798043068`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.826969917803852}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.547886962653699, 0.00774702115719995], 
                Complex[5.900288896133163, -1.1631693310632691`]}, 2 -> {
                Complex[8.465439042444201, 0.009233798770935121], 
                Complex[6.8169938397567895`, -1.161835265847092]}, 3 -> {
                Complex[10.184544064614805`, -0.016281708942805753`], 
                Complex[8.451450795228004, -1.1978624312936872`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.826969917803852}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.547886962653699`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00774702115719995`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.900288896133163`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632691`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.465439042444201`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009233798770935121`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.8169938397567895`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.161835265847092`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.184544064614805`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016281708942805753`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.451450795228004`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1978624312936872`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.547886962653699, 0.00774702115719995], 
                Complex[5.900288896133163, -1.1631693310632691`]}, 2 -> {
                Complex[8.465439042444201, 0.009233798770935121], 
                Complex[6.8169938397567895`, -1.161835265847092]}, 3 -> {
                Complex[10.184544064614805`, -0.016281708942805753`], 
                Complex[8.451450795228004, -1.1978624312936872`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.840819673068846}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.4, "C", 
             Association[1 -> {
                Complex[7.533443755733459, 0.007843982012263152], 
                Complex[5.885228654304802, -1.1631443306747424`]}, 2 -> {
                Complex[8.485279549606197, 0.009466654168547486], 
                Complex[6.836104162316991, -1.1616956277315167`]}, 3 -> {
                Complex[10.164353917920575`, -0.016543191071888914`], 
                Complex[8.431855025955324, -1.1980069181435884`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.840819673068846}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.533443755733459`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263152`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304802`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.485279549606197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009466654168547486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.836104162316991`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616956277315167`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.164353917920575`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016543191071888914`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.431855025955324`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1980069181435884`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.4, "C", 
             Association[1 -> {
                Complex[7.533443755733459, 0.007843982012263152], 
                Complex[5.885228654304802, -1.1631443306747424`]}, 2 -> {
                Complex[8.485279549606197, 0.009466654168547486], 
                Complex[6.836104162316991, -1.1616956277315167`]}, 3 -> {
                Complex[10.164353917920575`, -0.016543191071888914`], 
                Complex[8.431855025955324, -1.1980069181435884`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.863636474998081}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.5, "C", 
             Association[1 -> {
                Complex[7.5194357044269005`, 0.007942407351021058], 
                Complex[5.870600935988343, -1.1631183993398404`]}, 2 -> {
                Complex[8.504844265661474, 0.009710692858210806], 
                Complex[6.854927356440139, -1.1615471581185317`]}, 3 -> {
                Complex[10.144456159495563`, -0.016814496662831836`], 
                Complex[8.412563676597298, -1.1981586784333549`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.863636474998081}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5194357044269005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007942407351021058`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.504844265661474`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009710692858210806`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.854927356440139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615471581185317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.144456159495563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.016814496662831836`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.412563676597298`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1981586784333549`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.5, "C", 
             Association[1 -> {
                Complex[7.5194357044269005`, 0.007942407351021058], 
                Complex[5.870600935988343, -1.1631183993398404`]}, 2 -> {
                Complex[8.504844265661474, 0.009710692858210806], 
                Complex[6.854927356440139, -1.1615471581185317`]}, 3 -> {
                Complex[10.144456159495563`, -0.016814496662831836`], 
                Complex[8.412563676597298, -1.1981586784333549`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.895906578236367}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.5058213212730225`, 0.008042302396705316], 
                Complex[5.856364206404795, -1.1630915398400685`]}, 2 -> {
                Complex[8.52418379610039, 0.00996691431009624], 
                Complex[6.873513478358425, -1.1613889949346565`]}, 3 -> {
                Complex[10.124798576239256`, -0.017096756417673668`], 
                Complex[8.393525054229872, -1.1983187142405292`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.895906578236367}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.5058213212730225`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008042302396705316`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.52418379610039`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00996691431009624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.873513478358425`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1613889949346565`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.124798576239256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017096756417673668`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.393525054229872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1983187142405292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.5058213212730225`, 0.008042302396705316], 
                Complex[5.856364206404795, -1.1630915398400685`]}, 2 -> {
                Complex[8.52418379610039, 0.00996691431009624], 
                Complex[6.873513478358425, -1.1613889949346565`]}, 3 -> {
                Complex[10.124798576239256`, -0.017096756417673668`], 
                Complex[8.393525054229872, -1.1983187142405292`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.938048687861849}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.7, "C", 
             Association[1 -> {
                Complex[7.492565012985164, 0.008143676269233487], 
                Complex[5.842482826256841, -1.1630637508268273`]}, 2 -> {
                Complex[8.543343682297635, 0.01023643767719948], 
                Complex[6.891907468896068, -1.161220171125207]}, 3 -> {
                Complex[10.105334252708913`, -0.017391201699304026`], 
                Complex[8.374692817528384, -1.1984881127881408`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.938048687861849}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.492565012985164`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233487`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.543343682297635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01023643767719948`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"6.891907468896068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161220171125207`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.105334252708913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017391201699304026`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.374692817528384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1984881127881408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.7, "C", 
             Association[1 -> {
                Complex[7.492565012985164, 0.008143676269233487], 
                Complex[5.842482826256841, -1.1630637508268273`]}, 2 -> {
                Complex[8.543343682297635, 0.01023643767719948], 
                Complex[6.891907468896068, -1.161220171125207]}, 3 -> {
                Complex[10.105334252708913`, -0.017391201699304026`], 
                Complex[8.374692817528384, -1.1984881127881408`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.989820763960413}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.799999999999997`, "C", 
             Association[1 -> {
                Complex[7.479635970943437, 0.008246541346654087], 
                Complex[5.828925941917191, -1.1630350275077863`]}, 2 -> {
                Complex[8.562365618323055, 0.010520523036427927`], 
                Complex[6.9101503643132345`, -1.1610395954830415`]}, 3 -> {
                Complex[10.086020309962356`, -0.017699189379580486`], 
                Complex[8.356024721208028, -1.1986680693372456`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.989820763960413}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.479635970943437`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654087`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917191`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.562365618323055`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010520523036427927`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9101503643132345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1610395954830415`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.086020309962356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.017699189379580486`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.356024721208028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1986680693372456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.799999999999997`, "C", 
             Association[1 -> {
                Complex[7.479635970943437, 0.008246541346654087], 
                Complex[5.828925941917191, -1.1630350275077863`]}, 2 -> {
                Complex[8.562365618323055, 0.010520523036427927`], 
                Complex[6.9101503643132345`, -1.1610395954830415`]}, 3 -> {
                Complex[10.086020309962356`, -0.017699189379580486`], 
                Complex[8.356024721208028, -1.1986680693372456`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -6.0485946371245065`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.9, "C", 
             Association[1 -> {
                Complex[7.4670073159977095`, 0.008350912786614366], 
                Complex[5.815666629983416, -1.1630053621640015`]}, 2 -> {
                Complex[8.581288431797727, 0.010820596844492403`], 
                Complex[6.9282802700841595`, -1.1608460296816647`]}, 3 -> {
                Complex[10.06681689057666, -0.018022230071644385`], 
                Complex[8.337481607819116, -1.1988599130234305`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -6.0485946371245065`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.4670073159977095`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.008350912786614366`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983416`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.581288431797727`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010820596844492403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.9282802700841595`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1608460296816647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.06681689057666`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018022230071644385`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.337481607819116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1988599130234305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.9, "C", 
             Association[1 -> {
                Complex[7.4670073159977095`, 0.008350912786614366], 
                Complex[5.815666629983416, -1.1630053621640015`]}, 2 -> {
                Complex[8.581288431797727, 0.010820596844492403`], 
                Complex[6.9282802700841595`, -1.1608460296816647`]}, 3 -> {
                Complex[10.06681689057666, -0.018022230071644385`], 
                Complex[8.337481607819116, -1.1988599130234305`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -6.105176575579468}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.999999999999996`, "C", 
             Association[1 -> {
                Complex[7.454655429824251, 0.008456808164000526], 
                Complex[5.802681228429218, -1.1629747445437837`]}, 2 -> {
                Complex[8.600148900521386, 0.011138282794836918`], 
                Complex[6.946333169123364, -1.1606380604240905`]}, 3 -> {
                Complex[10.047686315383556`, -0.018362021154624195`], 
                Complex[8.319026572634915, -1.199065136952576]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -6.105176575579468}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.454655429824251`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008456808164000526`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.600148900521386`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011138282794836918`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.946333169123364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606380604240905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.047686315383556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.018362021154624195`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.319026572634915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.199065136952576`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.999999999999996`, "C", 
             Association[1 -> {
                Complex[7.454655429824251, 0.008456808164000526], 
                Complex[5.802681228429218, -1.1629747445437837`]}, 2 -> {
                Complex[8.600148900521386, 0.011138282794836918`], 
                Complex[6.946333169123364, -1.1606380604240905`]}, 3 -> {
                Complex[10.047686315383556`, -0.018362021154624195`], 
                Complex[8.319026572634915, -1.199065136952576]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -6.138606178575703}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.442559425423676, 0.008564247194411552], 
                Complex[5.7899488069302, -1.1629431621652235`]}, 2 -> {
                Complex[8.618982457304563, 0.011475439606775252`], 
                Complex[6.964343616618659, -1.1604140653041306`]}, 3 -> {
                Complex[10.02859235757786, -0.018720486277070698`], 
                Complex[8.300624247551832, -1.1992854341178674`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -6.138606178575703}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.442559425423676`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411552`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7899488069302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.618982457304563`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011475439606775252`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.964343616618659`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1604140653041306`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.02859235757786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.018720486277070698`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.300624247551832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1992854341178674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.442559425423676, 0.008564247194411552], 
                Complex[5.7899488069302, -1.1629431621652235`]}, 2 -> {
                Complex[8.618982457304563, 0.011475439606775252`], 
                Complex[6.964343616618659, -1.1604140653041306`]}, 3 -> {
                Complex[10.02859235757786, -0.018720486277070698`], 
                Complex[8.300624247551832, -1.1992854341178674`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -6.125561041199423}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.2, "C", 
             Association[1 -> {
                Complex[7.430700722955541, 0.008673251522090992], 
                Complex[5.7774507425522845`, -1.162910600549928]}, 2 -> {
                Complex[8.637823823216573, 0.011834207760463409`], 
                Complex[6.982345361327388, -1.160172170534845]}, 3 -> {
                Complex[10.009499592627153`, -0.019099823463292497`], 
                Complex[8.28224016277643, -1.1995227410964953`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -6.125561041199423}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.430700722955541`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090992`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.7774507425522845`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.637823823216573`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011834207760463409`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.982345361327388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160172170534845`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"10.009499592627153`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.019099823463292497`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.28224016277643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1995227410964953`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.2, "C", 
             Association[1 -> {
                Complex[7.430700722955541, 0.008673251522090992], 
                Complex[5.7774507425522845`, -1.162910600549928]}, 2 -> {
                Complex[8.637823823216573, 0.011834207760463409`], 
                Complex[6.982345361327388, -1.160172170534845]}, 3 -> {
                Complex[10.009499592627153`, -0.019099823463292497`], 
                Complex[8.28224016277643, -1.1995227410964953`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -6.069094866452612}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.419062706397297, 0.008783844556995738], 
                Complex[5.765170376285118, -1.162877043404163]}, 2 -> {
                Complex[8.656707602013043, 0.012217067867222313`], 
                Complex[7.000371925640259, -1.1599101980783053`]}, 3 -> {
                Complex[9.990372790233621, -0.01950256459218661], 
                Complex[8.263840153003093, -1.1997792920739636`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -6.069094866452612}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.419062706397297`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995738`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.656707602013043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012217067867222313`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.000371925640259`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1599101980783053`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.990372790233621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.01950256459218661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.263840153003093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1997792920739636`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.299999999999997`, "C", 
             Association[1 -> {
                Complex[7.419062706397297, 0.008783844556995738], 
                Complex[5.765170376285118, -1.162877043404163]}, 2 -> {
                Complex[8.656707602013043, 0.012217067867222313`], 
                Complex[7.000371925640259, -1.1599101980783053`]}, 3 -> {
                Complex[9.990372790233621, -0.01950256459218661], 
                Complex[8.263840153003093, -1.1997792920739636`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.993843598715004}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.399999999999995`, "C", 
             Association[1 -> {
                Complex[7.4076304429802775`, 0.00889605134985899], 
                Complex[5.753092732368909, -1.1628424727592266`]}, 2 -> {
                Complex[8.675668864524779, 0.012626914319474911`], 
                Complex[7.018457172595781, -1.1596255988326747`]}, 3 -> {
                Complex[9.971176318841339, -0.019931649951741043`], 
                Complex[8.24538977916942, -1.2000576866004597`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.993843598715004}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.4076304429802775`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00889605134985899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.753092732368909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.675668864524779`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012626914319474911`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.018457172595781`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596255988326747`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.971176318841339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.019931649951741043`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.24538977916942`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2000576866004597`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.399999999999995`, "C", 
             Association[1 -> {
                Complex[7.4076304429802775`, 0.00889605134985899], 
                Complex[5.753092732368909, -1.1628424727592266`]}, 2 -> {
                Complex[8.675668864524779, 0.012626914319474911`], 
                Complex[7.018457172595781, -1.1596255988326747`]}, 3 -> {
                Complex[9.971176318841339, -0.019931649951741043`], 
                Complex[8.24538977916942, -1.2000576866004597`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.91814751956294}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.499999999999996`, "C", 
             Association[1 -> {
                Complex[7.396390451929997, 0.009009898497033932], 
                Complex[5.741204286938846, -1.1628068690797762`]}, 2 -> {
                Complex[8.694743750598732, 0.013067149229433986`], 
                Complex[7.036635886648768, -1.1593153672755068`]}, 3 -> {
                Complex[9.951873534557844, -0.020390522922278387`], 
                Complex[8.226853738441676, -1.2003609757255185`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.91814751956294}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.396390451929997`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497033932`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.741204286938846`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797762`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.694743750598732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013067149229433986`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.036635886648768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1593153672755068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.951873534557844`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020390522922278387`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.226853738441676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2003609757255185`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.499999999999996`, "C", 
             Association[1 -> {
                Complex[7.396390451929997, 0.009009898497033932], 
                Complex[5.741204286938846, -1.1628068690797762`]}, 2 -> {
                Complex[8.694743750598732, 0.013067149229433986`], 
                Complex[7.036635886648768, -1.1593153672755068`]}, 3 -> {
                Complex[9.951873534557844, -0.020390522922278387`], 
                Complex[8.226853738441676, -1.2003609757255185`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.849275020774315}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.3853305123250825`, 0.009125414068990404], 
                Complex[5.729492775798816, -1.1627702113466531`]}, 2 -> {
                Complex[8.713970117564823, 0.013541803645186434`], 
                Complex[7.054944396120723, -1.1589759311366727`]}, 3 -> {
                Complex[9.932426125107996, -0.020883251810279745`], 
                Complex[8.208195234091123, -1.2006927729717152`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.849275020774315}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.3853305123250825`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.009125414068990404`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627702113466531`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.713970117564823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013541803645186434`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.054944396120723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1589759311366727`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.932426125107996`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.020883251810279745`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.208195234091123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2006927729717152`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.599999999999998`, "C", 
             Association[1 -> {
                Complex[7.3853305123250825`, 0.009125414068990404], 
                Complex[5.729492775798816, -1.1627702113466531`]}, 2 -> {
                Complex[8.713970117564823, 0.013541803645186434`], 
                Complex[7.054944396120723, -1.1589759311366727`]}, 3 -> {
                Complex[9.932426125107996, -0.020883251810279745`], 
                Complex[8.208195234091123, -1.2006927729717152`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.788963211825338}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.7, "C", 
             Association[1 -> {
                Complex[7.374439502284718, 0.00924262755784085], 
                Complex[5.7179470335323455`, -1.1627324771191436`]}, 2 -> {
                Complex[8.733388268345113, 0.014055695951277626`], 
                Complex[7.073421269042284, -1.158603006979818]}, 3 -> {
                Complex[9.912793375391814, -0.02141468876524509], 
                Complex[8.18937527323683, -1.2010573992945917`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.788963211825338}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.374439502284718`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00924262755784085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.7179470335323455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1627324771191436`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.733388268345113`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014055695951277626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.073421269042284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158603006979818`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.912793375391814`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02141468876524509`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.18937527323683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2010573992945917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.7, "C", 
             Association[1 -> {
                Complex[7.374439502284718, 0.00924262755784085], 
                Complex[5.7179470335323455`, -1.1627324771191436`]}, 2 -> {
                Complex[8.733388268345113, 0.014055695951277626`], 
                Complex[7.073421269042284, -1.158603006979818]}, 3 -> {
                Complex[9.912793375391814, -0.02141468876524509], 
                Complex[8.18937527323683, -1.2010573992945917`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.73700069657686}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.8, "C", 
             Association[1 -> {
                Complex[7.363707263462426, 0.009361569840391621], 
                Complex[5.706556857926958, -1.1626936425804284`]}, 2 -> {
                Complex[8.753041799848587, 0.014614641743299649`], 
                Complex[7.092108121115127, -1.1581914085205156`]}, 3 -> {
                Complex[9.892931313762208, -0.021990680088691875`], 
                Complex[8.170351853484789, -1.2014600752208564`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.73700069657686}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.363707263462426`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391621`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804284`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.753041799848587`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014614641743299649`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.092108121115127`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581914085205156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.892931313762208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.021990680088691875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.170351853484789`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2014600752208564`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.8, "C", 
             Association[1 -> {
                Complex[7.363707263462426, 0.009361569840391621], 
                Complex[5.706556857926958, -1.1626936425804284`]}, 2 -> {
                Complex[8.753041799848587, 0.014614641743299649`], 
                Complex[7.092108121115127, -1.1581914085205156`]}, 3 -> {
                Complex[9.892931313762208, -0.021990680088691875`], 
                Complex[8.170351853484789, -1.2014600752208564`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.692639530486104}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.9, "C", 
             Association[1 -> {
                Complex[7.3531244861453, 0.009482273153988793], 
                Complex[5.695312895009786, -1.1626536825691627`]}, 2 -> {
                Complex[8.77297862441228, 0.015225736181981687`], 
                Complex[7.111050585905176, -1.157734788294595]}, 3 -> {
                Complex[9.872791686074075, -0.02261834895605743], 
                Complex[8.151078988162066, -1.201907179567137]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.692639530486104}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.3531244861453`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153988793`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626536825691627`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.77297862441228`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015225736181981687`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.111050585905176`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157734788294595`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.872791686074075`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02261834895605743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.151078988162066`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.201907179567137`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.9, "C", 
             Association[1 -> {
                Complex[7.3531244861453, 0.009482273153988793], 
                Complex[5.695312895009786, -1.1626536825691627`]}, 2 -> {
                Complex[8.77297862441228, 0.015225736181981687`], 
                Complex[7.111050585905176, -1.157734788294595]}, 3 -> {
                Complex[9.872791686074075, -0.02261834895605743], 
                Complex[8.151078988162066, -1.201907179567137]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.655072486886321}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.999999999999996`, "C", 
             Association[1 -> {
                Complex[7.342682611254977, 0.009604771083122523], 
                Complex[5.684206540989642, -1.1626125705993822`]}, 2 -> {
                Complex[8.793252235841303, 0.01589774035976148], 
                Complex[7.130299515097567, -1.1572252835375132`]}, 3 -> {
                Complex[9.852320685804424, -0.02330648209651281], 
                Complex[8.13150550216652, -1.2024066038908527`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.655072486886321}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.342682611254977`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.793252235841303`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01589774035976148`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.130299515097567`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1572252835375132`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.852320685804424`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02330648209651281`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.13150550216652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2024066038908527`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.999999999999996`, "C", 
             Association[1 -> {
                Complex[7.342682611254977, 0.009604771083122523], 
                Complex[5.684206540989642, -1.1626125705993822`]}, 2 -> {
                Complex[8.793252235841303, 0.01589774035976148], 
                Complex[7.130299515097567, -1.1572252835375132`]}, 3 -> {
                Complex[9.852320685804424, -0.02330648209651281], 
                Complex[8.13150550216652, -1.2024066038908527`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.62357528164876}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.332373746308075, 0.009729098555121761], 
                Complex[5.67322985816244, -1.1625702788705317`]}, 2 -> {
                Complex[8.813923320576674, 0.016641620135819556`], 
                Complex[7.149912504017514, -1.1566530214405544`]}, 3 -> {
                Complex[9.831457339597339, -0.02406606889621767], 
                Complex[8.11157350310953, -1.202968247517296]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.62357528164876}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.332373746308075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121761`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.813923320576674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016641620135819556`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.149912504017514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1566530214405544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.831457339597339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02406606889621767`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.11157350310953`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.202968247517296`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.099999999999998`, "C", 
             Association[1 -> {
                Complex[7.332373746308075, 0.009729098555121761], 
                Complex[5.67322985816244, -1.1625702788705317`]}, 2 -> {
                Complex[8.813923320576674, 0.016641620135819556`], 
                Complex[7.149912504017514, -1.1566530214405544`]}, 3 -> {
                Complex[9.831457339597339, -0.02406606889621767], 
                Complex[8.11157350310953, -1.202968247517296]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.5975354754715845`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.2, "C", 
             Association[1 -> {
                Complex[7.322190592979878, 0.009855291843704485], 
                Complex[5.662375502422984, -1.1625267782689677`]}, 2 -> {
                Complex[8.835061859626233, 0.017471313877762306`], 
                Complex[7.169955880282916, -1.1560054129682455`]}, 3 -> {
                Complex[9.81013140250469, -0.02491106937082747], 
                Complex[8.09121638979124, -1.2036047239664327`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.5975354754715845`}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"7.322190592979878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009855291843704485`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.662375502422984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.835061859626233`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.017471313877762306`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.169955880282916`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1560054129682455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"3", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.81013140250469`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02491106937082747`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.09121638979124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2036047239664327`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.2, "C", 
             Association[1 -> {
                Complex[7.322190592979878, 0.009855291843704485], 
                Complex[5.662375502422984, -1.1625267782689677`]}, 2 -> {
                Complex[8.835061859626233, 0.017471313877762306`], 
                Complex[7.169955880282916, -1.1560054129682455`]}, 3 -> {
                Complex[9.81013140250469, -0.02491106937082747], 
                Complex[8.09121638979124, -1.2036047239664327`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.717440277022293}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.299999999999997`, "C", 
             Association[1 -> {
                Complex[8.856749938394854, 0.01840485331132207], 
                Complex[7.190507361138085, -1.1552661200223417`]}, 2 -> {
                Complex[9.78826054571076, -0.02585953521479562], 
                Complex[8.070356192382524, -1.2043323940004822`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.76724784350877}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.856749938394854`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01840485331132207`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.190507361138085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1552661200223417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.78826054571076`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02585953521479562`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.070356192382524`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2043323940004822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.299999999999997`, "C", 
             Association[1 -> {
                Complex[8.856749938394854, 0.01840485331132207], 
                Complex[7.190507361138085, -1.1552661200223417`]}, 2 -> {
                Complex[9.78826054571076, -0.02585953521479562], 
                Complex[8.070356192382524, -1.2043323940004822`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.720706846286295}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.4, "C", 
             Association[1 -> {
                Complex[8.879085597629635, 0.019466046203823823`], 
                Complex[7.211659694982882, -1.1544135020746285`]}, 2 -> {
                Complex[9.76574650346378, -0.02693529265819088], 
                Complex[8.048899928737553, -1.2051729191751688`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.77836323221212}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.879085597629635`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.019466046203823823`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.211659694982882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1544135020746285`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.76574650346378`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.02693529265819088`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"8.048899928737553`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2051729191751688`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.4, "C", 
             Association[1 -> {
                Complex[8.879085597629635, 0.019466046203823823`], 
                Complex[7.211659694982882, -1.1544135020746285`]}, 2 -> {
                Complex[9.76574650346378, -0.02693529265819088], 
                Complex[8.048899928737553, -1.2051729191751688`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.723740492634645}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.499999999999996`, "C", 
             Association[1 -> {
                Complex[8.902188252549184, 0.020687085496539234`], 
                Complex[7.233525786397051, -1.1534182031380908`]}, 2 -> {
                Complex[9.742469652095146, -0.028170551750257837`], 
                Complex[8.026734477486409, -1.2061556750293905`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.790459827864813}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.902188252549184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020687085496539234`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.233525786397051`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1534182031380908`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.742469652095146`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.028170551750257837`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.026734477486409`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2061556750293905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.499999999999996`, "C", 
             Association[1 -> {
                Complex[8.902188252549184, 0.020687085496539234`], 
                Complex[7.233525786397051, -1.1534182031380908`]}, 2 -> {
                Complex[9.742469652095146, -0.028170551750257837`], 
                Complex[8.026734477486409, -1.2061556750293905`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.726227634458349}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.599999999999998`, "C", 
             Association[1 -> {
                Complex[8.926206541442703, 0.02211275107353916], 
                Complex[7.256246121108593, -1.1522392586053043`]}, 2 -> {
                Complex[9.718281159799472, -0.029610108260631186`], 
                Complex[8.003719151417389, -1.2073216443878656`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.8034842821045}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.926206541442703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02211275107353916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.256246121108593`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1522392586053043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.718281159799472`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029610108260631186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"8.003719151417389`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2073216443878656`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.599999999999998`, "C", 
             Association[1 -> {
                Complex[8.926206541442703, 0.02211275107353916], 
                Complex[7.256246121108593, -1.1522392586053043`]}, 2 -> {
                Complex[9.718281159799472, -0.029610108260631186`], 
                Complex[8.003719151417389, -1.2073216443878656`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.727779298372652}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.7, "C", 
             Association[1 -> {
                Complex[8.95133006145241, 0.023807487220115792`], 
                Complex[7.279999873987634, -1.1508175252699344`]}, 2 -> {
                Complex[9.692991249427967, -0.0313184212541546], 
                Complex[7.979674588033221, -1.2087299874638697`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.817386818846394}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.95133006145241`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.023807487220115792`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.279999873987634`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1508175252699344`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.692991249427967`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0313184212541546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.979674588033221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2087299874638697`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.7, "C", 
             Association[1 -> {
                Complex[8.95133006145241, 0.023807487220115792`], 
                Complex[7.279999873987634, -1.1508175252699344`]}, 2 -> {
                Complex[9.692991249427967, -0.0313184212541546], 
                Complex[7.979674588033221, -1.2087299874638697`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.727894407299563}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.799999999999997`, "C", 
             Association[1 -> {
                Complex[8.977807551308572, 0.025867986584037196`], 
                Complex[7.305022131856608, -1.1490639772295173`]}, 2 -> {
                Complex[9.6663510144975, -0.033392197154710215`], 
                Complex[7.954365525461625, -1.2104697460661467`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.8321207672319195`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"8.977807551308572`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025867986584037196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.305022131856608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490639772295173`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.6663510144975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.033392197154710215`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.954365525461625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2104697460661467`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.799999999999997`, "C", 
             Association[1 -> {
                Complex[8.977807551308572, 0.025867986584037196`], 
                Complex[7.305022131856608, -1.1490639772295173`]}, 2 -> {
                Complex[9.6663510144975, -0.033392197154710215`], 
                Complex[7.954365525461625, -1.2104697460661467`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.725899527837187}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.9, "C", 
             Association[1 -> {
                Complex[9.005976175768346, 0.028447097632704935`], 
                Complex[7.3316316615292605`, -1.1468374259621588`]}, 2 -> {
                Complex[9.638023133640685, -0.035984297293206895`], 
                Complex[7.927473033284, -1.2126821236194971`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.847642152846497}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.005976175768346`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.028447097632704935`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.3316316615292605`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1468374259621588`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.638023133640685`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.035984297293206895`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.927473033284`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2126821236194971`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.9, "C", 
             Association[1 -> {
                Complex[9.005976175768346, 0.028447097632704935`], 
                Complex[7.3316316615292605`, -1.1468374259621588`]}, 2 -> {
                Complex[9.638023133640685, -0.035984297293206895`], 
                Complex[7.927473033284, -1.2126821236194971`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.720845950715181}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20., "C", 
             Association[1 -> {
                Complex[9.036310546964627, 0.031803157852373865`], 
                Complex[7.360277468735849, -1.1438984501954066`]}, 2 -> {
                Complex[9.607532848271008, -0.039353071187373335`], 
                Complex[7.89854795260484, -1.2156065553823723`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.86390933747946}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.036310546964627`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031803157852373865`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.360277468735849`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1438984501954066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.607532848271008`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.039353071187373335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"7.89854795260484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2156065553823723`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20., "C", 
             Association[1 -> {
                Complex[9.036310546964627, 0.031803157852373865`], 
                Complex[7.360277468735849, -1.1438984501954066`]}, 2 -> {
                Complex[9.607532848271008, -0.039353071187373335`], 
                Complex[7.89854795260484, -1.2156065553823723`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.71133283239896}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.1, "C", 
             Association[1 -> {
                Complex[9.069506749440478, 0.03641303093548226], 
                Complex[7.391618832430621, -1.1398036000155798`]}, 2 -> {
                Complex[9.574183936670554, -0.04397539380088848], 
                Complex[7.866930860848725, -1.2196865044147176`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.880882699481707}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.069506749440478`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03641303093548226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.391618832430621`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1398036000155798`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.574183936670554`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.04397539380088848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.866930860848725`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2196865044147176`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.1, "C", 
             Association[1 -> {
                Complex[9.069506749440478, 0.03641303093548226], 
                Complex[7.391618832430621, -1.1398036000155798`]}, 2 -> {
                Complex[9.574183936670554, -0.04397539380088848], 
                Complex[7.866930860848725, -1.2196865044147176`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.695254812493801}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.106617372354673, 0.04326772266645232], 
                Complex[7.426654831776879, -1.133628019546016]}, 2 -> {
                Complex[9.536923681000955, -0.05084228149321134], 
                Complex[7.831622543975548, -1.2258468389686776`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.8985243482080945`}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.106617372354673`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04326772266645232`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.426654831776879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.133628019546016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.536923681000955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.05084228149321134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.831622543975548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2258468389686776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.106617372354673, 0.04326772266645232], 
                Complex[7.426654831776879, -1.133628019546016]}, 2 -> {
                Complex[9.536923681000955, -0.05084228149321134], 
                Complex[7.831622543975548, -1.2258468389686776`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.6700893952540445`}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.149127159726488, 0.05476808187732223], 
                Complex[7.466802670715167, -1.123122290976753]}, 2 -> {
                Complex[9.494267216357189, -0.062354593032578], 
                Complex[7.7912056711960345`, -1.236336988520793]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.916797867190696}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.149127159726488`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05476808187732223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.466802670715167`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.123122290976753`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.494267216357189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.062354593032578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.7912056711960345`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.236336988520793`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.149127159726488, 0.05476808187732223], 
                Complex[7.466802670715167, -1.123122290976753]}, 2 -> {
                Complex[9.494267216357189, -0.062354593032578], 
                Complex[7.7912056711960345`, -1.236336988520793]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.641058418937706}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.4, "C", 
             Association[1 -> {
                Complex[9.197298230159177, 0.07734359441247762], 
                Complex[7.512359287571745, -1.1022322984450346`]}, 2 -> {
                Complex[9.445952310414624, -0.08494182361234351], 
                Complex[7.745383184720138, -1.2572110799472442`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.93566808163679}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.197298230159177`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07734359441247762`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.512359287571745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1022322984450346`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.445952310414624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.08494182361234351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.745383184720138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.2572110799472442`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.4, "C", 
             Association[1 -> {
                Complex[9.197298230159177, 0.07734359441247762], 
                Complex[7.512359287571745, -1.1022322984450346`]}, 2 -> {
                Complex[9.445952310414624, -0.08494182361234351], 
                Complex[7.745383184720138, -1.2572110799472442`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.652991792376542}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.5, "C", 
             Association[1 -> {
                Complex[9.239565409647748, 0.11902724764149018`], 
                Complex[7.5524910234485665`, -1.0633012820313072`]}, 2 -> {
                Complex[9.403544030055139, -0.12663696940988678`], 
                Complex[7.704988630788347, -1.296125883577755]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.9551008466288735`}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.239565409647748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11902724764149018`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.5524910234485665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.0633012820313072`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.403544030055139`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.12663696940988678`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.704988630788347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.296125883577755`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.5, "C", 
             Association[1 -> {
                Complex[9.239565409647748, 0.11902724764149018`], 
                Complex[7.5524910234485665`, -1.0633012820313072`]}, 2 -> {
                Complex[9.403544030055139, -0.12663696940988678`], 
                Complex[7.704988630788347, -1.296125883577755]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -5.825249344930458}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.262317347784464, 0.16611165996512323`], 
                Complex[7.574268139734727, -1.0191412329171092`]}, 2 -> {
                Complex[9.380653624650824, -0.17373265713467972`], 
                Complex[7.682951641637801, -1.3402694180832728`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -5.9750628530590655`}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.262317347784464`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.16611165996512323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.574268139734727`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0191412329171092`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.380653624650824`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.17373265713467972`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.682951641637801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3402694180832728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.262317347784464, 0.16611165996512323`], 
                Complex[7.574268139734727, -1.0191412329171092`]}, 2 -> {
                Complex[9.380653624650824, -0.17373265713467972`], 
                Complex[7.682951641637801, -1.3402694180832728`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -5.874202110420369}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.27379501912068, 0.20695392178184982`], 
                Complex[7.585368797745682, -0.9807872587669504]}, 2 -> {
                Complex[9.369040024240906, -0.21458598503237647`], 
                Complex[7.671593955391099, -1.3786065851349265`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -5.99552144888323}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.27379501912068`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.20695392178184982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.585368797745682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9807872587669504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.369040024240906`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21458598503237647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.671593955391099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.3786065851349265`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.27379501912068, 0.20695392178184982`], 
                Complex[7.585368797745682, -0.9807872587669504]}, 2 -> {
                Complex[9.369040024240906, -0.21458598503237647`], 
                Complex[7.671593955391099, -1.3786065851349265`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -5.915846569341985}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.280570529089989, 0.24191392575349288`], 
                Complex[7.591990895909478, -0.9479498476029737]}, 2 -> {
                Complex[9.362131033190314, -0.2495568531847539], 
                Complex[7.664717578441821, -1.4114269055666684`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -6.016444473762219}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.280570529089989`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.24191392575349288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.591990895909478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9479498476029737`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.362131033190314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2495568531847539`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.664717578441821`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4114269055666684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.280570529089989, 0.24191392575349288`], 
                Complex[7.591990895909478, -0.9479498476029737]}, 2 -> {
                Complex[9.362131033190314, -0.2495568531847539], 
                Complex[7.664717578441821, -1.4114269055666684`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -5.952479620601521}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.9, "C", 
             Association[1 -> {
                Complex[9.285085225476458, 0.27256109297706776`], 
                Complex[7.59644818910947, -0.9191675975214383]}, 2 -> {
                Complex[9.357485218342608, -0.2802146897125705], 
                Complex[7.660008665723722, -1.440191789692609]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.03780010557337}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.285085225476458`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27256109297706776`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.59644818910947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9191675975214383`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.357485218342608`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2802146897125705`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.660008665723722`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.440191789692609`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.9, "C", 
             Association[1 -> {
                Complex[9.285085225476458, 0.27256109297706776`], 
                Complex[7.59644818910947, -0.9191675975214383]}, 2 -> {
                Complex[9.357485218342608, -0.2802146897125705], 
                Complex[7.660008665723722, -1.440191789692609]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21., -5.985902417731189}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21., "C", 
             Association[1 -> {
                Complex[9.288342049505975, 0.3000009300835058], 
                Complex[7.599694877117055, -0.8934053728141108]}, 2 -> {
                Complex[9.35409955758327, -0.30766500790255313`], 
                Complex[7.656512931924068, -1.4659363812164734`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21., -6.05955671765176}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.288342049505975`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3000009300835058`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.599694877117055`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8934053728141108`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.35409955758327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30766500790255313`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.656512931924068`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4659363812164734`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21., "C", 
             Association[1 -> {
                Complex[9.288342049505975, 0.3000009300835058], 
                Complex[7.599694877117055, -0.8934053728141108]}, 2 -> {
                Complex[9.35409955758327, -0.30766500790255313`], 
                Complex[7.656512931924068, -1.4659363812164734`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.017220595936366}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.290821923790588, 0.32496389242763857`], 
                Complex[7.602190099828044, -0.8699776507064156]}, 2 -> {
                Complex[9.351493051581292, -0.33263826942312025`], 
                Complex[7.653771155925205, -1.4893462105216049`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.081682745961504}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.290821923790588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.32496389242763857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.602190099828044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8699776507064156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.351493051581292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33263826942312025`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.653771155925205`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.4893462105216049`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.290821923790588, 0.32496389242763857`], 
                Complex[7.602190099828044, -0.8699776507064156]}, 2 -> {
                Complex[9.351493051581292, -0.33263826942312025`], 
                Complex[7.653771155925205, -1.4893462105216049`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.047114326074205}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.2, "C", 
             Association[1 -> {
                Complex[9.292784687952791, 0.34794816918876], 
                Complex[7.604182742222915, -0.8484162452714185]}, 2 -> {
                Complex[9.349405787878045, -0.35563266944840766`], 
                Complex[7.6515343755500105`, -1.5108894707826885`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.10414656571362}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.292784687952791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.34794816918876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.604182742222915`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8484162452714185`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.349405787878045`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35563266944840766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6515343755500105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5108894707826885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.2, "C", 
             Association[1 -> {
                Complex[9.292784687952791, 0.34794816918876], 
                Complex[7.604182742222915, -0.8484162452714185]}, 2 -> {
                Complex[9.349405787878045, -0.35563266944840766`], 
                Complex[7.6515343755500105`, -1.5108894707826885`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.076015089190307}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.3, "C", 
             Association[1 -> {
                Complex[9.294383744285957, 0.36930769700429716`], 
                Complex[7.605820205415673, -0.8283882117511504]}, 2 -> {
                Complex[9.347684294964536, -0.37700215031345224`], 
                Complex[7.649655116243796, -1.530899113668034]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.126916377245599}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.294383744285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.36930769700429716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.605820205415673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8283882117511504`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.347684294964536`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37700215031345224`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.649655116243796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.530899113668034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.3, "C", 
             Association[1 -> {
                Complex[9.294383744285957, 0.36930769700429716`], 
                Complex[7.605820205415673, -0.8283882117511504]}, 2 -> {
                Complex[9.347684294964536, -0.37700215031345224`], 
                Complex[7.649655116243796, -1.530899113668034]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.104204540137779}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.4, "C", 
             Association[1 -> {
                Complex[9.29571595421648, 0.3893033507690842], 
                Complex[7.607195850080812, -0.8096479618228554]}, 2 -> {
                Complex[9.346231645579115, -0.3970075923331433], 
                Complex[7.6480399474006955`, -1.5496207340949588`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -6.149960101262856}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.29571595421648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.3893033507690842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.607195850080812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8096479618228554`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.346231645579115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3970075923331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6480399474006955`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5496207340949588`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.4, "C", 
             Association[1 -> {
                Complex[9.29571595421648, 0.3893033507690842], 
                Complex[7.607195850080812, -0.8096479618228554]}, 2 -> {
                Complex[9.346231645579115, -0.3970075923331433], 
                Complex[7.6480399474006955`, -1.5496207340949588`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.131870245843}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.296845766278874, 0.4081334915298239], 
                Complex[7.608371984798496, -0.7920086413709166]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -6.131870245843}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.296845766278874`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4081334915298239`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.608371984798496`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7920086413709166`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.296845766278874, 0.4081334915298239], 
                Complex[7.608371984798496, -0.7920086413709166]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.159138267649699}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.297817893725249, 0.42595292805234636`], 
                Complex[7.6093919681901685`, -0.7753243442615882]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -6.159138267649699}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.297817893725249`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.42595292805234636`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6093919681901685`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7753243442615882`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.297817893725249, 0.42595292805234636`], 
                Complex[7.6093919681901685`, -0.7753243442615882]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.186092975273801}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.7, "C", 
             Association[1 -> {
                Complex[9.298664434058157, 0.44288515307919907`], 
                Complex[7.61028701795302, -0.7594786249471307]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -6.186092975273801}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.298664434058157`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.44288515307919907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61028701795302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7594786249471307`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.7, "C", 
             Association[1 -> {
                Complex[9.298664434058157, 0.44288515307919907`], 
                Complex[7.61028701795302, -0.7594786249471307]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -6.212789550037768}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.299409090344204, 0.45903052180506093`], 
                Complex[7.611080255416446, -0.7443768154213608]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -6.212789550037768}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.299409090344204`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.45903052180506093`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611080255416446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7443768154213608`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.299409090344204, 0.45903052180506093`], 
                Complex[7.611080255416446, -0.7443768154213608]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -6.23926214238019}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.300069789499112, 0.47447188989313444`], 
                Complex[7.611789218669329, -0.7299407258319833]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -6.23926214238019}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.300069789499112`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.47447188989313444`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.611789218669329`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7299407258319833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.300069789499112, 0.47447188989313444`], 
                Complex[7.611789218669329, -0.7299407258319833]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -6.265529356422009}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.300660369136605, 0.4892786068277399], 
                Complex[7.612427484506159, -0.7161048892141156]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -6.265529356422009}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.300660369136605`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.4892786068277399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.612427484506159`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7161048892141156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {21.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.300660369136605, 0.4892786068277399], 
                Complex[7.612427484506159, -0.7161048892141156]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -6.291598040534169}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.301191700128847, 0.503509412285517], 
                Complex[7.613005749670385, -0.7028138366825419]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -6.291598040534169}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.301191700128847`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.503509412285517`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613005749670385`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7028138366825419`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.301191700128847, 0.503509412285517], 
                Complex[7.613005749670385, -0.7028138366825419]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -6.317465976571192}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.2, "C", 
             Association[1 -> {
                Complex[9.301672454837956, 0.5172145811965813], 
                Complex[7.613532572082193, -0.6900200786894212]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -6.317465976571192}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.301672454837956`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5172145811965813`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.613532572082193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6900200786894212`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.2, "C", 
             Association[1 -> {
                Complex[9.301672454837956, 0.5172145811965813], 
                Complex[7.613532572082193, -0.6900200786894212]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -6.343123837847275}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.3, "C", 
             Association[1 -> {
                Complex[9.302109645838716, 0.5304375419992581], 
                Complex[7.614014891510713, -0.6776825815576776]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -6.343123837847275}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302109645838716`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5304375419992581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614014891510713`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6776825815576776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.3, "C", 
             Association[1 -> {
                Complex[9.302109645838716, 0.5304375419992581], 
                Complex[7.614014891510713, -0.6776825815576776]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -6.368556653507212}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.4, "C", 
             Association[1 -> {
                Complex[9.302509011886752, 0.5432161176861714], 
                Complex[7.614458403240932, -0.6657655987699644]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -6.368556653507212}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302509011886752`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5432161176861714`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.614458403240932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6657655987699644`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.4, "C", 
             Association[1 -> {
                Complex[9.302509011886752, 0.5432161176861714], 
                Complex[7.614458403240932, -0.6657655987699644]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -6.393744935797419}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.302875299750397, 0.5555834916479572], 
                Complex[7.6148678313818445`, -0.6542377611605058]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -6.393744935797419}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.302875299750397`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5555834916479572`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6148678313818445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6542377611605058`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.302875299750397, 0.5555834916479572], 
                Complex[7.6148678313818445`, -0.6542377611605058]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.418665575619495}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.303212473521276, 0.5675689693259758], 
                Complex[7.615247132185832, -0.6430713592597935]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -6.418665575619495}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303212473521276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5675689693259758`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615247132185832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6430713592597935`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.303212473521276, 0.5675689693259758], 
                Complex[7.615247132185832, -0.6430713592597935]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.44329257866816}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.7, "C", 
             Association[1 -> {
                Complex[9.303523872448524, 0.5791985860418385], 
                Complex[7.615599647619973, -0.6322417704324753]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -6.44329257866816}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303523872448524`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5791985860418385`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615599647619973`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6322417704324753`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.7, "C", 
             Association[1 -> {
                Complex[9.303523872448524, 0.5791985860418385], 
                Complex[7.615599647619973, -0.6322417704324753]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.467597692468724}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.303812331602318, 0.5904955973399487], 
                Complex[7.615928222964841, -0.6217269966329017]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -6.467597692468724}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.303812331602318`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.5904955973399487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.615928222964841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6217269966329017`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.303812331602318, 0.5904955973399487], 
                Complex[7.615928222964841, -0.6217269966329017]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.491550959601722}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.9, "C", 
             Association[1 -> {
                Complex[9.304080275277004, 0.6014808784641332], 
                Complex[7.616235297995222, -0.6115072877338223]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.491550959601722}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304080275277004`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6014808784641332`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616235297995222`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6115072877338223`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.9, "C", 
             Association[1 -> {
                Complex[9.304080275277004, 0.6014808784641332], 
                Complex[7.616235297995222, -0.6115072877338223]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.515121221818219}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.304329790117846, 0.612173252747982], 
                Complex[7.616522978484024, -0.6015648318155976]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.515121221818219}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304329790117846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.612173252747982`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616522978484024`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6015648318155976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {22.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.304329790117846, 0.612173252747982], 
                Complex[7.616522978484024, -0.6015648318155976]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.53827659205023}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30456268297077, 0.6225897638061416], 
                Complex[7.616793092860656, -0.5918834984038932]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.53827659205023}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30456268297077`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6225897638061416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.616793092860656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5918834984038932`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30456268297077, 0.6225897638061416], 
                Complex[7.616793092860656, -0.5918834984038932]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.560984905529962}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.304780527085194, 0.6327459028649576], 
                Complex[7.617047237536009, -0.5824486239818062]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.560984905529962}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304780527085194`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6327459028649576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617047237536009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5824486239818062`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.304780527085194, 0.6327459028649576], 
                Complex[7.617047237536009, -0.5824486239818062]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.583214156735538}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.304984699340448, 0.6426557999628848], 
                Complex[7.617286813480894, -0.5732468315559044]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.583214156735538}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.304984699340448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6426557999628848`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617286813480894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5732468315559044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.304984699340448, 0.6426557999628848], 
                Complex[7.617286813480894, -0.5732468315559044]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.6049329252981455`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.4, "C", 
             Association[1 -> {
                Complex[9.305176410484561, 0.6523323858111223], 
                Complex[7.6175130559865005`, -0.5642658778811105]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.6049329252981455`}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305176410484561`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6523323858111223`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6175130559865005`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5642658778811105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.4, "C", 
             Association[1 -> {
                Complex[9.305176410484561, 0.6523323858111223], 
                Complex[7.6175130559865005`, -0.5642658778811105]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.626110791107342}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.5, "C", 
             Association[1 -> {
                Complex[9.30535672988259, 0.6617875296457956], 
                Complex[7.617727059060542, -0.5554945233226201]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.626110791107342}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30535672988259`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6617875296457956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617727059060542`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5554945233226201`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.5, "C", 
             Association[1 -> {
                Complex[9.30535672988259, 0.6617875296457956], 
                Complex[7.617727059060542, -0.5554945233226201]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.646718736509068}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.6, "C", 
             Association[1 -> {
                Complex[9.305526605913883, 0.6710321572939462], 
                Complex[7.617929795566583, -0.5469224203770374]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.646718736509068}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305526605913883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6710321572939462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.617929795566583`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5469224203770374`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.6, "C", 
             Association[1 -> {
                Complex[9.305526605913883, 0.6710321572939462], 
                Complex[7.617929795566583, -0.5469224203770374]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.666729531642371}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.305686882893223, 0.6800763528244194], 
                Complex[7.618122133957997, -0.5385400176762593]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.666729531642371}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305686882893223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6800763528244194`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618122133957997`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5385400176762593`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.305686882893223, 0.6800763528244194], 
                Complex[7.618122133957997, -0.5385400176762593]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.686118097584282}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.305838315194185, 0.6889294464957751], 
                Complex[7.618304852267418, -0.5303384769181552]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.686118097584282}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305838315194185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.6889294464957751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618304852267418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5303384769181552`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.305838315194185, 0.6889294464957751], 
                Complex[7.618304852267418, -0.5303384769181552]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.704861841068211}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.9, "C", 
             Association[1 -> {
                Complex[9.305981579104797, 0.697600091198504], 
                Complex[7.618478649868708, -0.5223096006529586]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.704861841068211}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.305981579104797`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.697600091198504`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618478649868708`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5223096006529586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {23.9, "C", 
             Association[1 -> {
                Complex[9.305981579104797, 0.697600091198504], 
                Complex[7.618478649868708, -0.5223096006529586]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24., -6.722940954115716}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24., "C", 
             Association[1 -> {
                Complex[9.30611728283302, 0.7060963291837463], 
                Complex[7.618644157419196, -0.5144457692358492]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24., -6.722940954115716}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30611728283302`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7060963291837463`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618644157419196`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5144457692358492`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24., "C", 
             Association[1 -> {
                Complex[9.30611728283302, 0.7060963291837463], 
                Complex[7.618644157419196, -0.5144457692358492]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.740338671976036}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.306245974993525, 0.7144256505494249], 
                Complex[7.618801945306149, -0.5067398855588761]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.740338671976036}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306245974993525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7144256505494249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.618801945306149`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5067398855588761`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.306245974993525, 0.7144256505494249], 
                Complex[7.618801945306149, -0.5067398855588761]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.757041483287254}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {24.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.306368151840394, 0.722595044698084], 
                Complex[7.61895253085656, -0.49918532641716257`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.757041483287254}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306368151840394`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.722595044698084`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.61895253085656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.49918532641716257`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {24.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.306368151840394, 0.722595044698084], 
                Complex[7.61895253085656, -0.49918532641716257`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.773039287322193}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.30648426345883, 0.730611045774511], 
                Complex[7.6190963845189446`, -0.4917758995586582]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.773039287322193}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30648426345883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.730611045774511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6190963845189446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4917758995586582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.30648426345883, 0.730611045774511], 
                Complex[7.6190963845189446`, -0.4917758995586582]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.788325494501076}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.4, "C", 
             Association[1 -> {
                Complex[9.30659471908804, 0.7384797729243899], 
                Complex[7.619233935186141, -0.4845058056239263]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.788325494501076}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30659471908804`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7384797729243899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619233935186141`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4845058056239263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.4, "C", 
             Association[1 -> {
                Complex[9.30659471908804, 0.7384797729243899], 
                Complex[7.619233935186141, -0.4845058056239263]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.802897067958586}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.306699891715693, 0.7462069660795199], 
                Complex[7.619365574796855, -0.4773696043103919]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.802897067958586}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306699891715693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7462069660795199`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619365574796855`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4773696043103919`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.306699891715693, 0.7462069660795199], 
                Complex[7.619365574796855, -0.4773696043103919]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -6.816754505743258}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.306800122058599, 0.7537980178639988], 
                Complex[7.619491662328774, -0.4703621842002206]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -6.816754505743258}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306800122058599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7537980178639988`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619491662328774`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4703621842002206`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.306800122058599, 0.7537980178639988], 
                Complex[7.619491662328774, -0.4703621842002206]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -6.82990176508817}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.7, "C", 
             Association[1 -> {
                Complex[9.306895722024107, 0.7612580021246124], 
                Complex[7.619612527276209, -0.4634787357769729]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -6.82990176508817}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306895722024107`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7612580021246124`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619612527276209`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4634787357769729`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.7, "C", 
             Association[1 -> {
                Complex[9.306895722024107, 0.7612580021246124], 
                Complex[7.619612527276209, -0.4634787357769729]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -6.842346132006417}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.8, "C", 
             Association[1 -> {
                Complex[9.306986977730267, 0.7685916995129599], 
                Complex[7.619728472689179, -0.4567147272275417]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -6.842346132006417}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.306986977730267`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7685916995129599`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619728472689179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4567147272275417`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.8, "C", 
             Association[1 -> {
                Complex[9.306986977730267, 0.7685916995129599], 
                Complex[7.619728472689179, -0.4567147272275417]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -6.8540980411225725`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {24.9, "C", 
             Association[1 -> {
                Complex[9.30707415214959, 0.7758036204842984], 
                Complex[7.619839777837855, -0.45006588268489056`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -6.8540980411225725`}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30707415214959`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7758036204842984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619839777837855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.45006588268489056`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {24.9, "C", 
             Association[1 -> {
                Complex[9.30707415214959, 0.7758036204842984], 
                Complex[7.619839777837855, -0.45006588268489056`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -6.865170852056796}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.307157487430532, 0.7828980260257034], 
                Complex[7.619946700555886, -0.4435281626164995]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -6.865170852056796}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307157487430532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7828980260257034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.619946700555886`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4435281626164995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {24.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.307157487430532, 0.7828980260257034], 
                Complex[7.619946700555886, -0.4435281626164995]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -6.875580589759436}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {25.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.307237206941968, 0.7898789463823147], 
                Complex[7.620049479307305, -0.43709774610477947`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -6.875580589759436}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307237206941968`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7898789463823147`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620049479307305`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.43709774610477947`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {25.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.307237206941968, 0.7898789463823147], 
                Complex[7.620049479307305, -0.43709774610477947`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -6.885345656905611}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.307313517078901, 0.7967501980135657], 
                Complex[7.620148335014864, -0.4307710148004997]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -6.885345656905611}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307313517078901`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.7967501980135657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620148335014864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4307710148004997`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {25.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.307313517078901, 0.7967501980135657], 
                Complex[7.620148335014864, -0.4307710148004997]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -6.89448652678577}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {25.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.307386608861503, 0.8035153989801238], 
                Complex[7.620243472681646, -0.42454453835966893`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -6.89448652678577}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307386608861503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8035153989801238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620243472681646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.42454453835966893`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {25.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.307386608861503, 0.8035153989801238], 
                Complex[7.620243472681646, -0.42454453835966893`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -6.903025425081526}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.307456659354887, 0.8101779829358526], 
                Complex[7.620335082833091, -0.4184150611992563]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -6.903025425081526}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307456659354887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8101779829358526`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620335082833091`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4184150611992563`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {25.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.307456659354887, 0.8101779829358526], 
                Complex[7.620335082833091, -0.4184150611992563]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -6.910986008532176}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.307523832932748, 0.8167412118766469], 
                Complex[7.620423342802423, -0.4123794904283191]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -6.910986008532176}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307523832932748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8167412118766469`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620423342802423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4123794904283191`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {25.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.307523832932748, 0.8167412118766469], 
                Complex[7.620423342802423, -0.4123794904283191]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -6.9183930478307705`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.307588282404819, 0.8232081877787825], 
                Complex[7.620508417879314, -0.4064348848292412]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -6.9183930478307705`}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307588282404819`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8232081877787825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620508417879314`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4064348848292412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {25.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.307588282404819, 0.8232081877787825], 
                Complex[7.620508417879314, -0.4064348848292412]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.925272121205421}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {25.7, "C", 
             Association[1 -> {
                Complex[9.30765015002498, 0.8295818632429439], 
                Complex[7.620590462338554, -0.40057844477933563`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.925272121205421}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30765015002498`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8295818632429439`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620590462338554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.40057844477933563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {25.7, "C", 
             Association[1 -> {
                Complex[9.30765015002498, 0.8295818632429439], 
                Complex[7.620590462338554, -0.40057844477933563`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.931649324112859}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.30770956839477, 0.8358650512460974], 
                Complex[7.620669620363364, -0.3948075030162847]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.931649324112859}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30770956839477`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8358650512460974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620669620363364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3948075030162847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {25.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.30770956839477, 0.8358650512460974], 
                Complex[7.620669620363364, -0.3948075030162847]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.937550999367053}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.9, "C", 
             Association[1 -> {
                Complex[9.307766661274705, 0.8420604340909561], 
                Complex[7.620746026875822, -0.38911951616260565`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.937550999367053}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307766661274705`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8420604340909561`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620746026875822`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38911951616260565`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {25.9, "C", 
             Association[1 -> {
                Complex[9.307766661274705, 0.8420604340909561], 
                Complex[7.620746026875822, -0.38911951616260565`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26., -6.943003490909722}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26., "C", 
             Association[1 -> {
                Complex[9.307821544314418, 0.8481705716325364], 
                Complex[7.620819808285308, -0.38351205693401424`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26., -6.943003490909722}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307821544314418`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8481705716325364`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620819808285308`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.38351205693401424`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26., "C", 
             Association[1 -> {
                Complex[9.307821544314418, 0.8481705716325364], 
                Complex[7.620819808285308, -0.38351205693401424`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.948032923355843}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.307874325710909, 0.8541979088518956], 
                Complex[7.620891083164294, -0.3779828069654451]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.948032923355843}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307874325710909`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8541979088518956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620891083164294`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3779828069654451`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {26.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.307874325710909, 0.8541979088518956], 
                Complex[7.620891083164294, -0.3779828069654451]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.952665008458321}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.37252955019570744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.2, "C", 
             Association[1 -> {
                Complex[9.30792510680319, 0.860144782839487], 
                Complex[7.620959962859786, -0.37252955019570744`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.952665008458321}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30792510680319`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.860144782839487`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.620959962859786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.37252955019570744`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"UA\""}], "}"}]],
           Annotation[#, {26.2, "C", 
             Association[1 -> {
                Complex[9.30792510680319, 0.860144782839487], 
                Complex[7.620959962859786, -0.37252955019570744`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.956924878761477}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.307973982610356, 0.8660134292433511], 
                Complex[7.6210265520474145`, -0.36715016675857504`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.956924878761477}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.307973982610356`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8660134292433511`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6210265520474145`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.36715016675857504`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.307973982610356, 0.8660134292433511], 
                Complex[7.6210265520474145`, -0.36715016675857504`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.960836947971369}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.308021042319387, 0.8718059882315835], 
                Complex[7.621090949234536, -0.36184262733357503`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.960836947971369}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308021042319387`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8718059882315835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621090949234536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.36184262733357503`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.308021042319387, 0.8718059882315835], 
                Complex[7.621090949234536, -0.36184262733357503`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.9644247969692445`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.308066369728037, 0.8775245100130518], 
                Complex[7.621153247217728, -0.35660498791489154`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.9644247969692445`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308066369728037`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8775245100130518`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621153247217728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.35660498791489154`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.308066369728037, 0.8775245100130518], 
                Complex[7.621153247217728, -0.35660498791489154`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.9677110839315555`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.308110043647693, 0.8831709599557607], 
                Complex[7.621213533499528, -0.3514353849611332]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.9677110839315555`}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308110043647693`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8831709599557607`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621213533499528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3514353849611332`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {26.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.308110043647693, 0.8831709599557607], 
                Complex[7.621213533499528, -0.3514353849611332]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.970717476687782}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30815213827031, 0.888747223338151], 
                Complex[7.621271890668614, -0.34633203089259035`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.970717476687782}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30815213827031`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.888747223338151`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621271890668614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.34633203089259035`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30815213827031, 0.888747223338151], 
                Complex[7.621271890668614, -0.34633203089259035`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.973464605232962}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.308192723503184, 0.8942551097650254], 
                Complex[7.6213283967471925`, -0.3412932099060126]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.973464605232962}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308192723503184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8942551097650254`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6213283967471925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3412932099060126`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {26.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.308192723503184, 0.8942551097650254], 
                Complex[7.6213283967471925`, -0.3412932099060126]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.975972032199774}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {26.9, "C", 
             Association[1 -> {
                Complex[9.30823186527481, 0.8996963572765849], 
                Complex[7.621383125508848, -0.33631727407995976`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.975972032199774}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30823186527481`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.8996963572765849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621383125508848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33631727407995976`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {26.9, "C", 
             Association[1 -> {
                Complex[9.30823186527481, 0.8996963572765849], 
                Complex[7.621383125508848, -0.33631727407995976`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27., -6.978258239068285}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27., "C", 
             Association[1 -> {
                Complex[9.308269625814717, 0.9050726361762732], 
                Complex[7.621436146769792, -0.33140263974642126`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27., -6.978258239068285}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308269625814717`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9050726361762732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621436146769792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.33140263974642126`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27., "C", 
             Association[1 -> {
                Complex[9.308269625814717, 0.9050726361762732], 
                Complex[7.621436146769792, -0.33140263974642126`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.980340625933153}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.1, "C", 
             Association[1 -> {
                Complex[9.308306063909846, 0.9103855526005625], 
                Complex[7.621487526656122, -0.3265477841068158]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.980340625933153}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308306063909846`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9103855526005625`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621487526656122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3265477841068158`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {27.1, "C", 
             Association[1 -> {
                Complex[9.308306063909846, 0.9103855526005625], 
                Complex[7.621487526656122, -0.3265477841068158]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.982235522742103}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27.2, "C", 
             Association[1 -> {
                Complex[9.308341235139771, 0.9156366518516708], 
                Complex[7.621537327849359, -0.321751242072515]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.982235522742103}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308341235139771`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9156366518516708`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621537327849359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.321751242072515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27.2, "C", 
             Association[1 -> {
                Complex[9.308341235139771, 0.9156366518516708], 
                Complex[7.621537327849359, -0.321751242072515]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.983958210051338}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.308375192092747, 0.9208274215121248], 
                Complex[7.62158560981236, -0.3170116033119914]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.983958210051338}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308375192092747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9208274215121248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62158560981236`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3170116033119914`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {27.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.308375192092747, 0.9208274215121248], 
                Complex[7.62158560981236, -0.3170116033119914]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.985522947500635}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27.4, "C", 
             Association[1 -> {
                Complex[9.30840798456442, 0.9259592943584085], 
                Complex[7.621632428997374, -0.31232750948827986`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.985522947500635}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30840798456442`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9259592943584085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621632428997374`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.31232750948827986`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27.4, "C", 
             Association[1 -> {
                Complex[9.30840798456442, 0.9259592943584085], 
                Complex[7.621632428997374, -0.31232750948827986`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.986943008382346}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.499999999999993`, "C", 
             Association[1 -> {
                Complex[9.308439659740836, 0.931033651089264], 
                Complex[7.621677839037961, -0.3076976516720168]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.986943008382346}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308439659740836`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.931033651089264`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621677839037961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3076976516720168`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {27.499999999999993`, "C", 
             Association[1 -> {
                Complex[9.308439659740836, 0.931033651089264], 
                Complex[7.621677839037961, -0.3076976516720168]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.988230718856032}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.30847026236711, 0.9360518228828761], 
                Complex[7.621721890926156, -0.3031207679165936]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.988230718856032}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30847026236711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9360518228828761`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621721890926156`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3031207679165936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {27.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.30847026236711, 0.9360518228828761], 
                Complex[7.621721890926156, -0.3031207679165936]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.98939750053692}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.308499834903161, 0.9410150937958542], 
                Complex[7.62176463317627, -0.29859564098319413`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.98939750053692}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308499834903161`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9410150937958542`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62176463317627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29859564098319413`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.308499834903161, 0.9410150937958542], 
                Complex[7.62176463317627, -0.29859564098319413`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.99045391535693}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.308528417667576, 0.9459247030157971], 
                Complex[7.621806111976447, -0.29412109620456683`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.99045391535693}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308528417667576`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9459247030157971`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621806111976447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.29412109620456683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.308528417667576, 0.9459247030157971], 
                Complex[7.621806111976447, -0.29412109620456683`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.991409711757989}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {27.9, "C", 
             Association[1 -> {
                Complex[9.308556048970686, 0.9507818469782096], 
                Complex[7.6218463713290605`, -0.28969599947733177`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.991409711757989}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308556048970686`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9507818469782096`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6218463713290605`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.28969599947733177`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {27.9, "C", 
             Association[1 -> {
                Complex[9.308556048970686, 0.9507818469782096], 
                Complex[7.6218463713290605`, -0.28969599947733177`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.992273871426272}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308582765237823, 0.9555876813576076], 
                Complex[7.621885453180955, -0.2853192553735133]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.992273871426272}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308582765237823`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9555876813576076`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621885453180955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2853192553735133`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {27.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308582765237823, 0.9555876813576076], 
                Complex[7.621885453180955, -0.2853192553735133]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.993054655911657}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30860860112351, 0.960343322941825], 
                Complex[7.621923397544282, -0.2809898053627634]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.993054655911657}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30860860112351`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.960343322941825`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.621923397544282`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2809898053627634`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {28.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30860860112351, 0.960343322941825], 
                Complex[7.621923397544282, -0.2809898053627634]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.993759652598297}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.2, "C", 
             Association[1 -> {
                Complex[9.308633589617479, 0.9650498513977598], 
                Complex[7.6219602426088535`, -0.276706626137473]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.993759652598297}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308633589617479`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9650498513977598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219602426088535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.276706626137473`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.2, "C", 
             Association[1 -> {
                Complex[9.308633589617479, 0.9650498513977598], 
                Complex[7.6219602426088535`, -0.276706626137473]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.994395819599885}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.3, "C", 
             Association[1 -> {
                Complex[9.30865776214308, 0.9697083109361536], 
                Complex[7.6219960248466, -0.27246872803358446`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.994395819599885}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30865776214308`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9697083109361536`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6219960248466`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.27246872803358446`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.3, "C", 
             Association[1 -> {
                Complex[9.30865776214308, 0.9697083109361536], 
                Complex[7.6219960248466, -0.27246872803358446`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.994969529247376}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.30868114864878, 0.974319711882344], 
                Complex[7.622030779108829, -0.2682751535405323]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.994969529247376}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30868114864878`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.974319711882344`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622030779108829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2682751535405323`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {28.399999999999995`, "C", 
             Association[1 -> {
                Complex[9.30868114864878, 0.974319711882344], 
                Complex[7.622030779108829, -0.2682751535405323]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.995486609918283}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.308703777693312, 0.9788850321593942], 
                Complex[7.622064538716871, -0.26412497589424166`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.995486609918283}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308703777693312`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9788850321593942`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622064538716871`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.26412497589424166`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.308703777693312, 0.9788850321593942], 
                Complex[7.622064538716871, -0.26412497589424166`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -6.995952386026216}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.308725676524938, 0.9834052186894814], 
                Complex[7.6220973355465995`, -0.26001729774761967`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -6.995952386026216}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308725676524938`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9834052186894814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6220973355465995`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.26001729774761967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.308725676524938, 0.9834052186894814], 
                Complex[7.6220973355465995`, -0.26001729774761967`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -6.9963717160481025`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.308746871155384, 0.9878811887189863], 
                Complex[7.622129200107364, -0.2559512499133873]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -6.9963717160481025`}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308746871155384`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9878811887189863`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622129200107364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2559512499133873`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {28.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.308746871155384, 0.9878811887189863], 
                Complex[7.622129200107364, -0.2559512499133873]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -6.9967490285155485`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.799999999999994`, "C", 
             Association[1 -> {
                Complex[9.308767386428746, 0.9923138310722672], 
                Complex[7.622160161615688, -0.25192599017451744`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -6.9967490285155485`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308767386428746`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9923138310722672`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622160161615688`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.25192599017451744`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.799999999999994`, "C", 
             Association[1 -> {
                Complex[9.308767386428746, 0.9923138310722672], 
                Complex[7.622160161615688, -0.25192599017451744`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -6.9970883559372945`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.30878724608588, 0.9967040073387546], 
                Complex[7.622190248064221, -0.24794070215790154`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -6.9970883559372945`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30878724608588`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.9967040073387546`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622190248064221`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24794070215790154`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.30878724608588, 0.9967040073387546], 
                Complex[7.622190248064221, -0.24794070215790154`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -6.9973933666525765`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {28.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308806472824529, 1.0010525529976397`], 
                Complex[7.622219486286243, -0.24399459426719103`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -6.9973933666525765`}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308806472824529`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0010525529976397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622219486286243`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24399459426719103`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {28.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308806472824529, 1.0010525529976397`], 
                Complex[7.622219486286243, -0.24399459426719103`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -6.997667394641541}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.308825088355581, 1.0053602784840994`], 
                Complex[7.622247902016085, -0.24008689867107663`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -6.997667394641541}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308825088355581`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0053602784840994`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622247902016085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.24008689867107663`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.308825088355581, 1.0053602784840994`], 
                Complex[7.622247902016085, -0.24008689867107663`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -6.997913467339556}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.2, "C", 
             Association[1 -> {
                Complex[9.308843113455703, 1.0096279702007276`], 
                Complex[7.622275519945756, -0.236216870343528]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -6.997913467339556}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308843113455703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0096279702007276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622275519945756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.236216870343528`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.2, "C", 
             Association[1 -> {
                Complex[9.308843113455703, 1.0096279702007276`], 
                Complex[7.622275519945756, -0.236216870343528]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -6.998134331518096}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.308860568016621, 1.0138563914775585`], 
                Complex[7.622302363778045, -0.23238378615278985`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -6.998134331518096}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308860568016621`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0138563914775585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622302363778045`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.23238378615278985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.308860568016621, 1.0138563914775585`], 
                Complex[7.622302363778045, -0.23238378615278985`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -6.998332477306674}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.4, "C", 
             Association[1 -> {
                Complex[9.308877471091341, 1.0180462834838366`], 
                Complex[7.622328456276393, -0.22858694399613969`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -6.998332477306674}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308877471091341`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0180462834838366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622328456276393`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22858694399613969`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.4, "C", 
             Association[1 -> {
                Complex[9.308877471091341, 1.0180462834838366`], 
                Complex[7.622328456276393, -0.22858694399613969`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -6.998510160438676}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.5, "C", 
             Association[1 -> {
                Complex[9.308893840937472, 1.0221983660944407`], 
                Complex[7.622353819311706, -0.22482566197765572`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -6.998510160438676}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308893840937472`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0221983660944407`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622353819311706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22482566197765572`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.5, "C", 
             Association[1 -> {
                Complex[9.308893840937472, 1.0221983660944407`], 
                Complex[7.622353819311706, -0.22482566197765572`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -6.998669422809505}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.3089096950579, 1.0263133387136967`], 
                Complex[7.62237847390638, -0.22109927762639908`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -6.998669422809505}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.3089096950579`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0263133387136967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62237847390638`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.22109927762639908`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.3089096950579, 1.0263133387136967`], 
                Complex[7.62237847390638, -0.22109927762639908`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -6.998812111438651}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21740714715263532`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30892505023899, 1.0303918810590929`], 
                Complex[7.622402440275706, -0.21740714715263532`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -6.998812111438651}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30892505023899`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0303918810590929`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622402440275706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21740714715263532`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"UA\""}], "}"}]],
           Annotation[#, {29.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30892505023899, 1.0303918810590929`], 
                Complex[7.622402440275706, -0.21740714715263532`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -6.9989398959287}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.30893992258648, 1.034434653907242], 
                Complex[7.622425737866838, -0.21374864473986183`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -6.9989398959287}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30893992258648`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.034434653907242`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622425737866838`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.21374864473986183`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.30893992258648, 1.034434653907242], 
                Complex[7.622425737866838, -0.21374864473986183`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -6.999054284514078}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.308954327559254, 1.0384422998042997`], 
                Complex[7.622448385395499, -0.2101231618705582]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -6.999054284514078}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308954327559254`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0384422998042997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622448385395499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2101231618705582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {29.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.308954327559254, 1.0384422998042997`], 
                Complex[7.622448385395499, -0.2101231618705582]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -6.999156638791043}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {29.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308968280001098, 1.042415443742859], 
                Complex[7.622470400880571, -0.20653010668373517`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -6.999156638791043}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308968280001098`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.042415443742859`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622470400880571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.20653010668373517`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {29.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.308968280001098, 1.042415443742859], 
                Complex[7.622470400880571, -0.20653010668373517`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -6.999248187218114}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30898179417064, 1.04635469380724], 
                Complex[7.6224918016767305`, -0.20296890336247192`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -6.999248187218114}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30898179417064`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.04635469380724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6224918016767305`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.20296890336247192`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.099999999999998`, "C", 
             Association[1 -> {
                Complex[9.30898179417064, 1.04635469380724], 
                Complex[7.6224918016767305`, -0.20296890336247192`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -6.999330037473218}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.308994883769515, 1.0502606417889433`], 
                Complex[7.622512604505212, -0.199438991549757]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -6.999330037473218}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.308994883769515`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0502606417889433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622512604505212`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.199438991549757`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.308994883769515, 1.0502606417889433`], 
                Complex[7.622512604505212, -0.199438991549757]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -6.999403187750341}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.309007561968963, 1.0541338637739348`], 
                Complex[7.622532825482894, -0.19593982579105432`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -6.999403187750341}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309007561968963`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0541338637739348`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622532825482894`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.19593982579105432`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.309007561968963, 1.0541338637739348`], 
                Complex[7.622532825482894, -0.19593982579105432`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -6.999468537074665}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.4, "C", 
             Association[1 -> {
                Complex[9.309019841434887, 1.0579749207033116`], 
                Complex[7.62255248014975, -0.1924708750021304]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -6.999468537074665}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309019841434887`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0579749207033116`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62255248014975`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1924708750021304`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {30.4, "C", 
             Association[1 -> {
                Complex[9.309019841434887, 1.0579749207033116`], 
                Complex[7.62255248014975, -0.1924708750021304]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -6.99952689471113}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.5, "C", 
             Association[1 -> {
                Complex[9.309031734351517, 1.0617843589087967`], 
                Complex[7.622571583494798, -0.18903162196075995`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -6.99952689471113}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309031734351517`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0617843589087967`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622571583494798`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18903162196075995`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.5, "C", 
             Association[1 -> {
                Complex[9.309031734351517, 1.0617843589087967`], 
                Complex[7.622571583494798, -0.18903162196075995`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -6.9995789887372055`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.309043252443763, 1.0655627106244419`], 
                Complex[7.6225901499806685`, -0.18562156282100936`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -6.9995789887372055`}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309043252443763`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0655627106244419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6225901499806685`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.18562156282100936`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.309043252443763, 1.0655627106244419`], 
                Complex[7.6225901499806685`, -0.18562156282100936`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -6.999625473846427}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309054406998325, 1.069310494475782], 
                Complex[7.622608193566827, -0.18224020664891896`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -6.999625473846427}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309054406998325`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.069310494475782`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622608193566827`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.18224020664891896`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309054406998325, 1.069310494475782], 
                Complex[7.622608193566827, -0.18224020664891896`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -6.999666938445119}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.309065208883657, 1.0730282159476647`], 
                Complex[7.622625727731571, -0.17888707497841683`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -6.999666938445119}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309065208883657`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0730282159476647`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622625727731571`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17888707497841683`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.799999999999997`, "C", 
             Association[1 -> {
                Complex[9.309065208883657, 1.0730282159476647`], 
                Complex[7.622625727731571, -0.17888707497841683`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -6.999703911100574}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {30.9, "C", 
             Association[1 -> {
                Complex[9.30907566856886, 1.076716367831864], 
                Complex[7.622642765492878, -0.17556170138642116`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -6.999703911100574}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30907566856886`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.076716367831864`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622642765492878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.17556170138642116`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {30.9, "C", 
             Association[1 -> {
                Complex[9.30907566856886, 1.076716367831864], 
                Complex[7.622642765492878, -0.17556170138642116`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -6.999736866395001}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.999999999999993`, "C", 
             Association[1 -> {
                Complex[9.309085796141549, 1.0803754306555196`], 
                Complex[7.622659319428154, -0.1722636310861379]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -6.999736866395001}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309085796141549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0803754306555196`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622659319428154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1722636310861379`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {30.999999999999993`, "C", 
             Association[1 -> {
                Complex[9.309085796141549, 1.0803754306555196`], 
                Complex[7.622659319428154, -0.1722636310861379]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.999766230235693}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309095601324776, 1.0840058730914168`], 
                Complex[7.622675401692968, -0.16899242053759034`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.999766230235693}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309095601324776`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0840058730914168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622675401692968`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16899242053759034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309095601324776, 1.0840058730914168`], 
                Complex[7.622675401692968, -0.16899242053759034`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.999792384668199}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309105093493066, 1.0876081523510002`], 
                Complex[7.622691024038829, -0.16574763707454038`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.999792384668199}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309105093493066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0876081523510002`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622691024038829`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16574763707454038`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309105093493066, 1.0876081523510002`], 
                Complex[7.622691024038829, -0.16574763707454038`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.999815672235732}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.309114281687616, 1.0911827145610287`], 
                Complex[7.622706197830052, -0.16252885854692958`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.999815672235732}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309114281687616`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0911827145610287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622706197830052`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.16252885854692958`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.299999999999997`, "C", 
             Association[1 -> {
                Complex[9.309114281687616, 1.0911827145610287`], 
                Complex[7.622706197830052, -0.16252885854692958`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.999836399924792}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.4, "C", 
             Association[1 -> {
                Complex[9.309123174630706, 1.0947299951246658`], 
                Complex[7.6227209340597835`, -0.15933567297809714`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.999836399924792}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309123174630706`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.0947299951246658`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6227209340597835`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.15933567297809714`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.4, "C", 
             Association[1 -> {
                Complex[9.309123174630706, 1.0947299951246658`], 
                Complex[7.6227209340597835`, -0.15933567297809714`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.999854842733777}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.309131780739362, 1.098250419067798], 
                Complex[7.622735243365228, -0.1561676782360194]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.999854842733777}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309131780739362`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.098250419067798`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622735243365228`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1561676782360194`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {31.499999999999996`, "C", 
             Association[1 -> {
                Complex[9.309131780739362, 1.098250419067798], 
                Complex[7.622735243365228, -0.1561676782360194]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.999871246898463}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.309140108138353, 1.1017444013712938`], 
                Complex[7.622749136042124, -0.15302448171788963`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.999871246898463}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309140108138353`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1017444013712938`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622749136042124`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.15302448171788963`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.599999999999998`, "C", 
             Association[1 -> {
                Complex[9.309140108138353, 1.1017444013712938`], 
                Complex[7.622749136042124, -0.15302448171788963`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.999885832805462}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.7, "C", 
             Association[1 -> {
                Complex[9.309148164672497, 1.1052123472899034`], 
                Complex[7.622762622058501, -0.14990570004738207`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.999885832805462}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309148164672497`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1052123472899034`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622762622058501`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14990570004738207`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.7, "C", 
             Association[1 -> {
                Complex[9.309148164672497, 1.1052123472899034`], 
                Complex[7.622762622058501, -0.14990570004738207`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.9998987976221665`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.8, "C", 
             Association[1 -> {
                Complex[9.309155957918382, 1.1086546526584367`], 
                Complex[7.622775711067788, -0.14681095878399034`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.9998987976221665`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309155957918382`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1086546526584367`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622775711067788`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14681095878399034`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.8, "C", 
             Association[1 -> {
                Complex[9.309155957918382, 1.1086546526584367`], 
                Complex[7.622775711067788, -0.14681095878399034`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.999910317669357}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.309163495195484, 1.112071704185835], 
                Complex[7.622788412421261, -0.14373989214385835`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.999910317669357}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309163495195484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.112071704185835`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622788412421261`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14373989214385835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.899999999999995`, "C", 
             Association[1 -> {
                Complex[9.309163495195484, 1.112071704185835], 
                Complex[7.622788412421261, -0.14373989214385835`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.999920550560357}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {31.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.309170783576755, 1.11546387973771], 
                Complex[7.622800735179931, -0.14069214273155697`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.999920550560357}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309170783576755`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.11546387973771`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622800735179931`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.14069214273155697`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {31.999999999999996`, "C", 
             Association[1 -> {
                Complex[9.309170783576755, 1.11546387973771], 
                Complex[7.622800735179931, -0.14069214273155697`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.999929637128603}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309177829898688, 1.118831548607897], 
                Complex[7.62281268812585, -0.13766736128229182`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.999929637128603}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309177829898688`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.118831548607897`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62281268812585`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13766736128229182`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309177829898688, 1.118831548607897], 
                Complex[7.62281268812585, -0.13766736128229182`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.999937703163588}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309184640770896, 1.1221750717795362`], 
                Complex[7.622824279772895, -0.1346652064140495]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.999937703163588}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309184640770896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1221750717795362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622824279772895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1346652064140495`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {32.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309184640770896, 1.1221750717795362`], 
                Complex[7.622824279772895, -0.1346652064140495]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.999944860973354}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.13168534438923124`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.3, "C", 
             Association[1 -> {
                Complex[9.309191222585227, 1.1254948021761624`], 
                Complex[7.622835518377028, -0.13168534438923124`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.999944860973354}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309191222585227`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1254948021761624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622835518377028`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.13168534438923124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.3, "C", 
             Association[1 -> {
                Complex[9.309191222585227, 1.1254948021761624`], 
                Complex[7.622835518377028, -0.13168534438923124`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.999951210790131}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.4, "C", 
             Association[1 -> {
                Complex[9.309197581524451, 1.1287910849032743`], 
                Complex[7.6228464119461155`, -0.12872744888532328`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.999951210790131}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309197581524451`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1287910849032743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6228464119461155`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.12872744888532328`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.4, "C", 
             Association[1 -> {
                Complex[9.309197581524451, 1.1287910849032743`], 
                Complex[7.6228464119461155`, -0.12872744888532328`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.999956842034182}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309203723570544, 1.1320642574808066`], 
                Complex[7.622856968249287, -0.1257912007742034]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.999956842034182}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309203723570544`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1320642574808066`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622856968249287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1257912007742034`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {32.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309203723570544, 1.1320642574808066`], 
                Complex[7.622856968249287, -0.1257912007742034]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.999961834449588}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309209654512566, 1.1353146500669253`], 
                Complex[7.622867194825848, -0.12287628790968698`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.999961834449588}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309209654512566`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1353146500669253`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622867194825848`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.12287628790968698`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309209654512566, 1.1353146500669253`], 
                Complex[7.622867194825848, -0.12287628790968698`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.999966259124438}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309215379954184, 1.1385425856735312`], 
                Complex[7.622877098993824, -0.11998240492294286`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.999966259124438}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309215379954184`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1385425856735312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622877098993824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11998240492294286`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309215379954184, 1.1385425856735312`], 
                Complex[7.622877098993824, -0.11998240492294286`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.999970179406722}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.8, "C", 
             Association[1 -> {
                Complex[9.309220905320853, 1.1417483803738433`], 
                Complex[7.622886687858099, -0.1171092530254295]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.999970179406722}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309220905320853`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1417483803738433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622886687858099`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.1171092530254295`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {32.8, "C", 
             Association[1 -> {
                Complex[9.309220905320853, 1.1417483803738433`], 
                Complex[7.622886687858099, -0.1171092530254295]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.999973651726196}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {32.9, "C", 
             Association[1 -> {
                Complex[9.30922623586666, 1.1449323435024106`], 
                Complex[7.622895968318212, -0.11425653981902067`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.999973651726196}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30922623586666`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1449323435024106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622895968318212`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11425653981902067`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {32.9, "C", 
             Association[1 -> {
                Complex[9.30922623586666, 1.1449323435024106`], 
                Complex[7.622895968318212, -0.11425653981902067`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33., -6.999976726331536}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33., "C", 
             Association[1 -> {
                Complex[9.30923137668085, 1.1480947778478905`], 
                Complex[7.622904947075782, -0.11142397911299567`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33., -6.999976726331536}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30923137668085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1480947778478905`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622904947075782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.11142397911299567`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33., "C", 
             Association[1 -> {
                Complex[9.30923137668085, 1.1480947778478905`], 
                Complex[7.622904947075782, -0.11142397911299567`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.999979447951171}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309236332694079, 1.151235979838898], 
                Complex[7.622913630641643, -0.10861129074761434`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.999979447951171}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309236332694079`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.151235979838898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622913630641643`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10861129074761434`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309236332694079, 1.151235979838898], 
                Complex[7.622913630641643, -0.10861129074761434`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.99998185638546}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309241108684372, 1.154356239723236], 
                Complex[7.622922025342652, -0.10581820042396912`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.99998185638546}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309241108684372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.154356239723236`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622922025342652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10581820042396912`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309241108684372, 1.154356239723236], 
                Complex[7.622922025342652, -0.10581820042396912`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.9999839870370755`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.3, "C", 
             Association[1 -> {
                Complex[9.309245709282818, 1.1574558417407832`], 
                Complex[7.622930137328205, -0.10304443953986439`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.9999839870370755`}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309245709282818`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1574558417407832`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622930137328205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10304443953986439`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.3, "C", 
             Association[1 -> {
                Complex[9.309245709282818, 1.1574558417407832`], 
                Complex[7.622930137328205, -0.10304443953986439`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.999985871385845}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.39999999999999, "C", 
             Association[1 -> {
                Complex[9.309250138979012, 1.1605350642903134`], 
                Complex[7.62293797257647, -0.10028974503145545`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.999985871385845}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309250138979012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1605350642903134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62293797257647`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.10028974503145545`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.39999999999999, "C", 
             Association[1 -> {
                Complex[9.309250138979012, 1.1605350642903134`], 
                Complex[7.62293797257647, -0.10028974503145545`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.999987537413677}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309254402126275, 1.1635941800905014`], 
                Complex[7.6229455369003825`, -0.09755385922040935]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.999987537413677}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309254402126275`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1635941800905014`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229455369003825`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.09755385922040935`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309254402126275, 1.1635941800905014`], 
                Complex[7.6229455369003825`, -0.09755385922040935]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.9999890099846525`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309258502946614, 1.1666334563353578`], 
                Complex[7.622952835953341, -0.09483652966635159]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.9999890099846525`}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309258502946614`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1666334563353578`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622952835953341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09483652966635159`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309258502946614, 1.1666334563353578`], 
                Complex[7.622952835953341, -0.09483652966635159]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.999990311184866}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30926244553551, 1.1696531548443287`], 
                Complex[7.622959875234723, -0.09213750902438231]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.999990311184866}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30926244553551`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1696531548443287`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622959875234723`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.09213750902438231`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30926244553551, 1.1696531548443287`], 
                Complex[7.622959875234723, -0.09213750902438231]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.999991460626152}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.8, "C", 
             Association[1 -> {
                Complex[9.309266233866467, 1.1726535322072742`], 
                Complex[7.62296666009513, -0.08945655490745465]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.999991460626152}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309266233866467`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1726535322072742`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62296666009513`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08945655490745465`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.8, "C", 
             Association[1 -> {
                Complex[9.309266233866467, 1.1726535322072742`], 
                Complex[7.62296666009513, -0.08945655490745465]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.99999247571742}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {33.9, "C", 
             Association[1 -> {
                Complex[9.309269871795374, 1.1756348399245429`], 
                Complex[7.6229731957414195`, -0.08679342975340713]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.99999247571742}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309269871795374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1756348399245429`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6229731957414195`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.08679342975340713`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {33.9, "C", 
             Association[1 -> {
                Complex[9.309269871795374, 1.1756348399245429`], 
                Complex[7.6229731957414195`, -0.08679342975340713]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34., -6.999993371906956}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34., "C", 
             Association[1 -> {
                Complex[9.309273363064712, 1.178597324542335], 
                Complex[7.622979487241573, -0.0841479006964717]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34., -6.999993371906956}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309273363064712`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.178597324542335`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622979487241573`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0841479006964717`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34., "C", 
             Association[1 -> {
                Complex[9.309273363064712, 1.178597324542335], 
                Complex[7.622979487241573, -0.0841479006964717]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.999994162898704}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.1, "C", 
             Association[1 -> {
                Complex[9.309276711307533, 1.1815412277835524`], 
                Complex[7.622985539529303, -0.08151973944306835]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.999994162898704}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309276711307533`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1815412277835524`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622985539529303`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.08151973944306835`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.1, "C", 
             Association[1 -> {
                Complex[9.309276711307533, 1.1815412277835524`], 
                Complex[7.622985539529303, -0.08151973944306835]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.99999486084525}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.2, "C", 
             Association[1 -> {
                Complex[9.309279920051315, 1.18446678667431], 
                Complex[7.622991357408528, -0.0789087221517155]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.99999486084525}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309279920051315`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.18446678667431`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622991357408528`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0789087221517155`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.2, "C", 
             Association[1 -> {
                Complex[9.309279920051315, 1.18446678667431], 
                Complex[7.622991357408528, -0.0789087221517155]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.999995476519942}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.3, "C", 
             Association[1 -> {
                Complex[9.30928299272165, 1.1873742336662831`], 
                Complex[7.622996945557652, -0.0763146293168978]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.999995476519942}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30928299272165`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1873742336662831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.622996945557652`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0763146293168978`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.3, "C", 
             Association[1 -> {
                Complex[9.30928299272165, 1.1873742336662831`], 
                Complex[7.622996945557652, -0.0763146293168978]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.999996019470352}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.39999999999999, "C", 
             Association[1 -> {
                Complex[9.309285932645754, 1.1902637967550587`], 
                Complex[7.623002308533652, -0.07373724565672798]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.999996019470352}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309285932645754`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1902637967550587`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623002308533652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07373724565672798`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.39999999999999, "C", 
             Association[1 -> {
                Complex[9.309285932645754, 1.1902637967550587`], 
                Complex[7.623002308533652, -0.07373724565672798]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.999996498155038}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309288743055875, 1.193135699594645], 
                Complex[7.623007450776044, -0.07117636000425508]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.999996498155038}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309288743055875`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.193135699594645`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623007450776044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.07117636000425508`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309288743055875, 1.193135699594645], 
                Complex[7.623007450776044, -0.07117636000425508]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -6.99999692006539}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309291427092525, 1.195990161608288], 
                Complex[7.623012376610668, -0.06863176520228108]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -6.99999692006539}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309291427092525`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.195990161608288`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623012376610668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06863176520228108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309291427092525, 1.195990161608288], 
                Complex[7.623012376610668, -0.06863176520228108]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -6.999997291834125}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309293987807608, 1.1988273980957402`], 
                Complex[7.623017090253322, -0.06610325800154515]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -6.999997291834125}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309293987807608`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.1988273980957402`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623017090253322`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06610325800154515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309293987807608, 1.1988273980957402`], 
                Complex[7.623017090253322, -0.06610325800154515]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -6.999997619331883}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.8, "C", 
             Association[1 -> {
                Complex[9.309296428167405, 1.201647620337122], 
                Complex[7.623021595813277, -0.06359063896214531]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -6.999997619331883}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309296428167405`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.201647620337122`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623021595813277`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.06359063896214531`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.8, "C", 
             Association[1 -> {
                Complex[9.309296428167405, 1.201647620337122], 
                Complex[7.623021595813277, -0.06359063896214531]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -6.99999790775318}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {34.9, "C", 
             Association[1 -> {
                Complex[9.309298751055461, 1.204451035693495], 
                Complex[7.623025897296652, -0.061093712358079366`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -6.99999790775318}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309298751055461`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.204451035693495`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623025897296652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.061093712358079366`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {34.9, "C", 
             Association[1 -> {
                Complex[9.309298751055461, 1.204451035693495], 
                Complex[7.623025897296652, -0.061093712358079366`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35., -6.9999981616928615`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35., "C", 
             Association[1 -> {
                Complex[9.30930095927532, 1.2072378477042842`], 
                Complex[7.62302999860963, -0.05861228608478186]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35., -6.9999981616928615`}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30930095927532`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2072378477042842`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62302999860963`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05861228608478186`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35., "C", 
             Association[1 -> {
                Complex[9.30930095927532, 1.2072378477042842`], 
                Complex[7.62302999860963, -0.05861228608478186]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -6.999998385214099}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.1, "C", 
             Association[1 -> {
                Complex[9.309303055553212, 1.2100082561816605`], 
                Complex[7.6230339035616055`, -0.0561461715695423]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -6.999998385214099}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309303055553212`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2100082561816605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230339035616055`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.0561461715695423`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.1, "C", 
             Association[1 -> {
                Complex[9.309303055553212, 1.2100082561816605`], 
                Complex[7.6230339035616055`, -0.0561461715695423]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -6.999998581908814}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309305042540569, 1.212762457302003], 
                Complex[7.623037615868166, -0.05369518368470496]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -6.999998581908814}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309305042540569`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.212762457302003`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623037615868166`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.05369518368470496`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309305042540569, 1.212762457302003], 
                Complex[7.623037615868166, -0.05369518368470496]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -6.999998754951393}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.3, "C", 
             Association[1 -> {
                Complex[9.30930692281649, 1.2155006436945397`], 
                Complex[7.623041139153995, -0.051259140663536505`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -6.999998754951393}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30930692281649`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2155006436945397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623041139153995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.051259140663536505`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.3, "C", 
             Association[1 -> {
                Complex[9.30930692281649, 1.2155006436945397`], 
                Complex[7.623041139153995, -0.051259140663536505`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -6.9999989071463755`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.048837864018669234`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.4, "C", 
             Association[1 -> {
                Complex[9.309308698890094, 1.2182230045272866`], 
                Complex[7.623044476955635, -0.048837864018669234`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -6.9999989071463755`}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309308698890094`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2182230045272866`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044476955635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.048837864018669234`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.4, "C", 
             Association[1 -> {
                Complex[9.309308698890094, 1.2182230045272866`], 
                Complex[7.623044476955635, -0.048837864018669234`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -6.99999904097082}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309310373202791, 1.2209297255903702`], 
                Complex[7.623047632724201, -0.0464311784630234]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -6.99999904097082}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309310373202791`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2209297255903702`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623047632724201`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0464311784630234`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309310373202791, 1.2209297255903702`], 
                Complex[7.623047632724201, -0.0464311784630234]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -6.999999158611898}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309311948130448, 1.2236209893768368`], 
                Complex[7.62305060982792, -0.04403891183311752]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -6.999999158611898}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309311948130448`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2236209893768368`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62305060982792`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.04403891183311752`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309311948130448, 1.2236209893768368`], 
                Complex[7.62305060982792, -0.04403891183311752]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -6.999999262000254}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30931342598549, 1.2262969751610369`], 
                Complex[7.623053411554656, -0.041660895014681676`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -6.999999262000254}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931342598549`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2262969751610369`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053411554656`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.041660895014681676`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30931342598549, 1.2262969751610369`], 
                Complex[7.623053411554656, -0.041660895014681676`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -6.9999993528396045`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.8, "C", 
             Association[1 -> {
                Complex[9.309314809018922, 1.2289578590746733`], 
                Complex[7.623056041114284, -0.03929696187048912]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -6.9999993528396045`}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309314809018922`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2289578590746733`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623056041114284`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03929696187048912`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.8, "C", 
             Association[1 -> {
                Complex[9.309314809018922, 1.2289578590746733`], 
                Complex[7.623056041114284, -0.03929696187048912]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -6.9999994326329755`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.9, "C", 
             Association[1 -> {
                Complex[9.309316099422276, 1.2316038141805976`], 
                Complex[7.623058501641021, -0.03694694917032467]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -6.9999994326329755`}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309316099422276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2316038141805976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623058501641021`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.03694694917032467`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.9, "C", 
             Association[1 -> {
                Complex[9.309316099422276, 1.2316038141805976`], 
                Complex[7.623058501641021, -0.03694694917032467]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -6.999999502705963}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.034610696523021345`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309317299329457, 1.2342350105444317`], 
                Complex[7.623060796195637, -0.034610696523021345`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -6.999999502705963}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309317299329457`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2342350105444317`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623060796195637`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.034610696523021345`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309317299329457, 1.2342350105444317`], 
                Complex[7.623060796195637, -0.034610696523021345`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -6.999999564227353}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.30931841081857, 1.2368516153040952`], 
                Complex[7.6230629277676165`, -0.03228804631048309]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -6.999999564227353}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931841081857`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2368516153040952`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230629277676165`", "\[VeryThinSpace]"}], "-", 
                    
                    
                    RowBox[{
                    "0.03228804631048309`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.30931841081857, 1.2368516153040952`], 
                Complex[7.6230629277676165`, -0.03228804631048309]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -6.999999618227375}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309319435913645, 1.2394537927373108`], 
                Complex[7.623064899277239, -0.029978843623626066`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -6.999999618227375}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319435913645`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2394537927373108`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623064899277239`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.029978843623626066`", " ", "\[ImaginaryI]"}]}]}
                    ], "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {36.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309319435913645, 1.2394537927373108`], 
                Complex[7.623064899277239, -0.029978843623626066`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -6.999999665613876}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.3, "C", 
             Association[1 -> {
                Complex[9.309320376586301, 1.2420417043271583`], 
                Complex[7.62306671357756, -0.027682936200179965`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -6.999999665613876}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309320376586301`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2420417043271583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62306671357756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.027682936200179965`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.3, "C", 
             Association[1 -> {
                Complex[9.309320376586301, 1.2420417043271583`], 
                Complex[7.62306671357756, -0.027682936200179965`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -6.999999707186639}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.4, "C", 
             Association[1 -> {
                Complex[9.309321234757373, 1.2446155088257416`], 
                Complex[7.623068373456371, -0.02540017436427072]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -6.999999707186639}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309321234757373`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2446155088257416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068373456371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02540017436427072`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.4, "C", 
             Association[1 -> {
                Complex[9.309321234757373, 1.2446155088257416`], 
                Complex[7.623068373456371, -0.02540017436427072]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -6.999999743650046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.5, "C", 
             Association[1 -> {
                Complex[9.30932201229845, 1.247175362316046], 
                Complex[7.623069881638048, -0.02313041096773061]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -6.999999743650046}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932201229845`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.247175362316046`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069881638048`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.02313041096773061`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.5, "C", 
             Association[1 -> {
                Complex[9.30932201229845, 1.247175362316046], 
                Complex[7.623069881638048, -0.02313041096773061]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -6.999999775624294}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.6, "C", 
             Association[1 -> {
                Complex[9.309322711033374, 1.2497214182720298`], 
                Complex[7.62307124078535, -0.020873501333080847`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -6.999999775624294}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309322711033374`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2497214182720298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307124078535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.020873501333080847`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.6, "C", 
             Association[1 -> {
                Complex[9.309322711033374, 1.2497214182720298`], 
                Complex[7.62307124078535, -0.020873501333080847`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -6.999999803655304}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309323332739702, 1.2522538276170265`], 
                Complex[7.623072453501181, -0.018629303198118775`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -6.999999803655304}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323332739702`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2522538276170265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072453501181`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.018629303198118775`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309323332739702, 1.2522538276170265`], 
                Complex[7.623072453501181, -0.018629303198118775`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -6.999999828223487}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.79999999999999, "C", 
             Association[1 -> {
                Complex[9.309323879150051, 1.254772738780499], 
                Complex[7.623073522330233, -0.016397676662069878`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -6.999999828223487}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323879150051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.254772738780499`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623073522330233`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.016397676662069878`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.79999999999999, "C", 
             Association[1 -> {
                Complex[9.309323879150051, 1.254772738780499], 
                Complex[7.623073522330233, -0.016397676662069878`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -6.999999849751493}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.014178484133219656`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 
             Association[1 -> {
                Complex[9.309324351953519, 1.2572782977532362`], 
                Complex[7.623074449760668, -0.014178484133219656`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -6.999999849751493}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324351953519`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2572782977532362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623074449760668`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.014178484133219656`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"UA\""}], "}"}]],
           Annotation[#, {36.89999999999999, "C", 
             Association[1 -> {
                Complex[9.309324351953519, 1.2572782977532362`], 
                Complex[7.623074449760668, -0.014178484133219656`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -6.999999868611054}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309324752796902, 1.2597706481409692`], 
                Complex[7.623075238225624, -0.01197159027804566]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -6.999999868611054}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324752796902`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2597706481409692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075238225624`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.01197159027804566`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309324752796902, 1.2597706481409692`], 
                Complex[7.623075238225624, -0.01197159027804566]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -6.999999885129037}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309325083285957, 1.26224993121657], 
                Complex[7.623075890104745, -0.009776861971693968]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -6.999999885129037}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325083285957`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.26224993121657`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075890104745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.009776861971693968`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309325083285957, 1.26224993121657], 
                Complex[7.623075890104745, -0.009776861971693968]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -6.999999899592775}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309325344986703, 1.2647162859707826`], 
                Complex[7.623076407725729, -0.007594168249853738]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -6.999999899592775}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325344986703`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2647162859707826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623076407725729`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.007594168249853738`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309325344986703, 1.2647162859707826`], 
                Complex[7.623076407725729, -0.007594168249853738]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -6.99999991225479}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.3, "C", 
             Association[1 -> {
                Complex[9.30932553942646, 1.2671698491615646`], 
                Complex[7.62307679336563, -0.005423380261944406]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -6.99999991225479}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932553942646`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2671698491615646`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307679336563`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.005423380261944406`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.3, "C", 
             Association[1 -> {
                Complex[9.30932553942646, 1.2671698491615646`], 
                Complex[7.62307679336563, -0.005423380261944406]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -6.999999923336948}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.4, "C", 
             Association[1 -> {
                Complex[9.309325668095038, 1.2696107553621176`], 
                Complex[7.623077049252295, -0.003264371225554161]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -6.999999923336948}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325668095038`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2696107553621176`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077049252295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.003264371225554161`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.4, "C", 
             Association[1 -> {
                Complex[9.309325668095038, 1.2696107553621176`], 
                Complex[7.623077049252295, -0.003264371225554161]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -6.999999933034132}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{
                    "0.0011170163821173382`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.5, "C", 
             Association[1 -> {
                Complex[9.309325732445826, 1.2720391370076072`], 
                Complex[7.623077177565682, -0.0011170163821173382`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -6.999999933034132}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325732445826`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2720391370076072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077177565682`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.0011170163821173382`", " ", 
                    "\[ImaginaryI]"}]}]}], "}"}]}], "\[RightAssociation]"}], 
                ",", "\"UA\""}], "}"}]],
           Annotation[#, {37.5, "C", 
             Association[1 -> {
                Complex[9.309325732445826, 1.2720391370076072`], 
                Complex[7.623077177565682, -0.0011170163821173382`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -6.999999941517479}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.6, "C", 
             Association[1 -> {
                Complex[9.309325733896824, 1.2744551244406346`], 
                Complex[7.623077180439138, 0.0010188070462170521`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -6.999999941517479}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325733896824`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2744551244406346`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623077180439138`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.0010188070462170521`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.6, "C", 
             Association[1 -> {
                Complex[9.309325733896824, 1.2744551244406346`], 
                Complex[7.623077180439138, 0.0010188070462170521`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -6.999999948937235}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.7, "C", 
             Association[1 -> {
                Complex[9.309325673831674, 1.2768588459554961`], 
                Complex[7.62307705996065, 0.003143219898572241]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -6.999999948937235}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325673831674`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2768588459554961`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307705996065`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.003143219898572241`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.7, "C", 
             Association[1 -> {
                Complex[9.309325673831674, 1.2768588459554961`], 
                Complex[7.62307705996065, 0.003143219898572241]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -6.999999955425276}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.8, "C", 
             Association[1 -> {
                Complex[9.30932555360063, 1.2792504278412689`], 
                Complex[7.62307681817404, 0.005256341116210763]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -6.999999955425276}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932555360063`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2792504278412689`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307681817404`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.005256341116210763`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.8, "C", 
             Association[1 -> {
                Complex[9.30932555360063, 1.2792504278412689`], 
                Complex[7.62307681817404, 0.005256341116210763]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -6.9999999610973145`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.89999999999999, "C", 
             Association[1 -> {
                Complex[9.30932537452151, 1.2816299944237615`], 
                Complex[7.62307645708013, 0.007358287782327438]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -6.9999999610973145`}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932537452151`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2816299944237615`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307645708013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.007358287782327438`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.89999999999999, "C", 
             Association[1 -> {
                Complex[9.30932537452151, 1.2816299944237615`], 
                Complex[7.62307645708013, 0.007358287782327438]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -6.999999966054866}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309325137880622, 1.2839976681063674`], 
                Complex[7.623075978637889, 0.009449175160798235]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -6.999999966054866}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309325137880622`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2839976681063674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623075978637889`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.009449175160798235`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309325137880622, 1.2839976681063674`], 
                Complex[7.623075978637889, 0.009449175160798235]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -6.9999999703869635`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309324844933629, 1.286353569409846], 
                Complex[7.6230753847654915`, 0.01152911673391317]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -6.9999999703869635`}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324844933629`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.286353569409846`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230753847654915`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.01152911673391317`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309324844933629, 1.286353569409846], 
                Complex[7.6230753847654915`, 0.01152911673391317]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -6.999999974171673}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309324496906415, 1.2886978170110814`], 
                Complex[7.62307467734139, 0.013598224239136788`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -6.999999974171673}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324496906415`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2886978170110814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307467734139`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.013598224239136788`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309324496906415, 1.2886978170110814`], 
                Complex[7.62307467734139, 0.013598224239136788`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -6.9999999774774295`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.3, "C", 
             Association[1 -> {
                Complex[9.309324094995942, 1.291030527780833], 
                Complex[7.62307385820537, 0.015656607704910973`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -6.9999999774774295`}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309324094995942`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.291030527780833`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.62307385820537`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.015656607704910973`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.3, "C", 
             Association[1 -> {
                Complex[9.309324094995942, 1.291030527780833], 
                Complex[7.62307385820537, 0.015656607704910973`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -6.9999999803642075`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.4, "C", 
             Association[1 -> {
                Complex[9.309323640371, 1.2933518168205271`], 
                Complex[7.623072929159484, 0.017704375485551985`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -6.9999999803642075`}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323640371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2933518168205271`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623072929159484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.017704375485551985`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.4, "C", 
             Association[1 -> {
                Complex[9.309323640371, 1.2933518168205271`], 
                Complex[7.623072929159484, 0.017704375485551985`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -6.999999982884558}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.5, "C", 
             Association[1 -> {
                Complex[9.309323134173042, 1.2956617974980962`], 
                Complex[7.623071891969081, 0.019741634295234595`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -6.999999982884558}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309323134173042`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2956617974980962`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623071891969081`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.019741634295234595`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.5, "C", 
             Association[1 -> {
                Complex[9.309323134173042, 1.2956617974980962`], 
                Complex[7.623071891969081, 0.019741634295234595`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -6.999999985084512}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309322577516868, 1.2979605814829327`], 
                Complex[7.623070748363671, 0.02176848924114553]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -6.999999985084512}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309322577516868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.2979605814829327`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623070748363671`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02176848924114553`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.309322577516868, 1.2979605814829327`], 
                Complex[7.623070748363671, 0.02176848924114553]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -6.999999987004383}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309321971491423, 1.300248278779899], 
                Complex[7.623069500037891, 0.023785043855733365`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -6.999999987004383}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309321971491423`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.300248278779899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623069500037891`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.023785043855733365`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.309321971491423, 1.300248278779899], 
                Complex[7.623069500037891, 0.023785043855733365`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -6.999999988679468}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.8, "C", 
             Association[1 -> {
                Complex[9.30932131716045, 1.3025249977626072`], 
                Complex[7.623068148652344, 0.02579140012826888]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -6.999999988679468}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30932131716045`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3025249977626072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623068148652344`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02579140012826888`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.8, "C", 
             Association[1 -> {
                Complex[9.30932131716045, 1.3025249977626072`], 
                Complex[7.623068148652344, 0.02579140012826888]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -6.999999990140664}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.9, "C", 
             Association[1 -> {
                Complex[9.309320615563188, 1.3047908452057129`], 
                Complex[7.623066695834459, 0.02778765853546761]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -6.999999990140664}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309320615563188`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3047908452057129`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623066695834459`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02778765853546761`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.9, "C", 
             Association[1 -> {
                Complex[9.309320615563188, 1.3047908452057129`], 
                Complex[7.623066695834459, 0.02778765853546761]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -6.99999999141501}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309319867715043, 1.3070459263165168`], 
                Complex[7.623065143179328, 0.02977391807145791]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -6.99999999141501}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319867715043`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3070459263165168`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623065143179328`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.02977391807145791`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.99999999999999, "C", 
             Association[1 -> {
                Complex[9.309319867715043, 1.3070459263165168`], 
                Complex[7.623065143179328, 0.02977391807145791]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -6.9999999925261625`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309319074608208, 1.3092903447657454`], 
                Complex[7.623063492250484, 0.03175027627696571]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -6.9999999925261625`}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309319074608208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3092903447657454`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623063492250484`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03175027627696571`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.099999999999994`, "C", 
             Association[1 -> {
                Complex[9.309319074608208, 1.3092903447657454`], 
                Complex[7.623063492250484, 0.03175027627696571]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -6.999999993494815}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309318237212295, 1.311524202717574], 
                Complex[7.623061744580699, 0.03371682926778386]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -6.999999993494815}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309318237212295`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.311524202717574`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623061744580699`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03371682926778386`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.199999999999996`, "C", 
             Association[1 -> {
                Complex[9.309318237212295, 1.311524202717574], 
                Complex[7.623061744580699, 0.03371682926778386]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -6.999999994339065}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.3, "C", 
             Association[1 -> {
                Complex[9.309317356474933, 1.3137476008589228`], 
                Complex[7.623059901672726, 0.03567367176254808]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -6.999999994339065}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309317356474933`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3137476008589228`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623059901672726`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.03567367176254808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.3, "C", 
             Association[1 -> {
                Complex[9.309317356474933, 1.3137476008589228`], 
                Complex[7.623059901672726, 0.03567367176254808]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -6.9999999950747345`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.4, "C", 
             Association[1 -> {
                Complex[9.309316433322348, 1.3159606384280351`], 
                Complex[7.6230579650000365`, 0.037620897109835086`]}], "SPA"},
             "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -6.9999999950747345`}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309316433322348`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3159606384280351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230579650000365`", "\[VeryThinSpace]"}], "+", 
                    
                    
                    RowBox[{
                    "0.037620897109835086`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.4, "C", 
             Association[1 -> {
                Complex[9.309316433322348, 1.3159606384280351`], 
                Complex[7.6230579650000365`, 0.037620897109835086`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -6.999999995715656}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {39.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309315468659923, 1.3181634132423605`], 
                Complex[7.623055936007521, 0.0395585973145974]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -6.999999995715656}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309315468659923`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3181634132423605`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623055936007521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0395585973145974`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {39.49999999999999, "C", 
             Association[1 -> {
                Complex[9.309315468659923, 1.3181634132423605`], 
                Complex[7.623055936007521, 0.0395585973145974]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -6.999999996273914}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.30931446337276, 1.3203560217257788`], 
                Complex[7.623053816112197, 0.04148686306397394]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -6.999999996273914}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931446337276`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3203560217257788`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623053816112197`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04148686306397394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.599999999999994`, "C", 
             Association[1 -> {
                Complex[9.30931446337276, 1.3203560217257788`], 
                Complex[7.623053816112197, 0.04148686306397394]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -6.999999996760072}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30931341832617, 1.3225385589351384`], 
                Complex[7.623051606703843, 0.04340578375245147]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -6.999999996760072}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.30931341832617`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3225385589351384`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623051606703843`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04340578375245147`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.699999999999996`, "C", 
             Association[1 -> {
                Complex[9.30931341832617, 1.3225385589351384`], 
                Complex[7.623051606703843, 0.04340578375245147]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -6.999999997183353}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.8, "C", 
             Association[1 -> {
                Complex[9.309312334366247, 1.3247111185862175`], 
                Complex[7.6230493091457, 0.04531544750647416]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -6.999999997183353}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309312334366247`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3247111185862175`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.6230493091457`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04531544750647416`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.8, "C", 
             Association[1 -> {
                Complex[9.309312334366247, 1.3247111185862175`], 
                Complex[7.6230493091457, 0.04531544750647416]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -6.999999997551814}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.9, "C", 
             Association[1 -> {
                Complex[9.309311212320324, 1.3268737930790047`], 
                Complex[7.623046924775063, 0.047215941208410626`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -6.999999997551814}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309311212320324`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3268737930790047`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623046924775063`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.047215941208410626`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.9, "C", 
             Association[1 -> {
                Complex[9.309311212320324, 1.3268737930790047`], 
                Complex[7.623046924775063, 0.047215941208410626`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{40., -6.999999997872491}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {40., "C", 
             Association[1 -> {
                Complex[9.309310052997454, 1.3290266735224268`], 
                Complex[7.623044454903904, 0.04910735051999668]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0], 
          TagBox[
           TooltipBox[PointBox[{40., -6.999999997872491}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"C\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"9.309310052997454`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"1.3290266735224268`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"7.623044454903904`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{
                    "0.04910735051999668`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {40., "C", 
             Association[1 -> {
                Complex[9.309310052997454, 1.3290266735224268`], 
                Complex[7.623044454903904, 0.04910735051999668]}], "UA"}, 
            "Tooltip"]& ]}}}, {{
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.058871140825799}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {15.999999999999998`, "A", 
             Association[1 -> {
                Complex[0.6980000948375882, -0.6433017314670934], 
                Complex[1.7951626777960403`, -2.1401483895471043`]}, 2 -> {
                Complex[4.6944263543752545`, 0.006645071137818129], 
                Complex[6.196232266214944, -1.1633793876684915`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{15.999999999999998`, -6.066415891076372}],
            RowBox[{"{", 
              RowBox[{"15.999999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.6980000948375882`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6433017314670934`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.7951626777960403`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.1401483895471043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.6944263543752545`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.006645071137818129`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.196232266214944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633793876684915`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {15.999999999999998`, "A", 
             Association[1 -> {
                Complex[0.6980000948375882, -0.6433017314670934], 
                Complex[1.7951626777960403`, -2.1401483895471043`]}, 2 -> {
                Complex[4.6944263543752545`, 0.006645071137818129], 
                Complex[6.196232266214944, -1.1633793876684915`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.011802555877524}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.099999999999998`, "A", 
             Association[1 -> {
                Complex[0.7333882582665036, -0.6165221792948049], 
                Complex[1.8301368298409664`, -2.112021181971959]}, 2 -> {
                Complex[4.654309125631486, 0.006712510785854934], 
                Complex[6.155525231634676, -1.1633781485602357`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.099999999999998`, -6.019351810330981}],
            RowBox[{"{", 
              RowBox[{"16.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7333882582665036`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6165221792948049`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8301368298409664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.112021181971959`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.654309125631486`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006712510785854934`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.155525231634676`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633781485602357`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.099999999999998`, "A", 
             Association[1 -> {
                Complex[0.7333882582665036, -0.6165221792948049], 
                Complex[1.8301368298409664`, -2.112021181971959]}, 2 -> {
                Complex[4.654309125631486, 0.006712510785854934], 
                Complex[6.155525231634676, -1.1633781485602357`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -5.983083149147442}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.2, "A", 
             Association[1 -> {
                Complex[0.7629774456127986, -0.5952855745698065], 
                Complex[1.8593666135298341`, -2.0894057490922227`]}, 2 -> {
                Complex[4.621891868208896, 0.006786025025047798], 
                Complex[6.122517060306257, -1.163371113059422]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.2, -5.99062615110485}],
            RowBox[{"{", 
              RowBox[{"16.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7629774456127986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5952855745698065`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8593666135298341`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0894057490922227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.621891868208896`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006786025025047798`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.122517060306257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163371113059422`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.2, "A", 
             Association[1 -> {
                Complex[0.7629774456127986, -0.5952855745698065], 
                Complex[1.8593666135298341`, -2.0894057490922227`]}, 2 -> {
                Complex[4.621891868208896, 0.006786025025047798], 
                Complex[6.122517060306257, -1.163371113059422]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -5.9641716071966275`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0068633365731448895`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.299999999999997`, "A", 
             Association[1 -> {
                Complex[0.7891581377234371, -0.5773156862277916], 
                Complex[1.8852354657886545`, -2.0700333477056216`]}, 2 -> {
                Complex[4.593955318850742, 0.0068633365731448895`], 
                Complex[6.093988110787665, -1.1633606215314776`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.299999999999997`, -5.9717196128447245`}],
            RowBox[{"{", 
              RowBox[{"16.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.7891581377234371`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5773156862277916`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.8852354657886545`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.0700333477056216`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.593955318850742`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0068633365731448895`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"6.093988110787665`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633606215314776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.299999999999997`, "A", 
             Association[1 -> {
                Complex[0.7891581377234371, -0.5773156862277916], 
                Complex[1.8852354657886545`, -2.0700333477056216`]}, 2 -> {
                Complex[4.593955318850742, 0.0068633365731448895`], 
                Complex[6.093988110787665, -1.1633606215314776`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -5.9516316878113775`}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.4, "A", 
             Association[1 -> {
                Complex[0.813020240902394, -0.5615718710865851], 
                Complex[1.908828689419144, -2.052868131119601]}, 2 -> {
                Complex[4.569036631840206, 0.006943461497604872], 
                Complex[6.068475300453683, -1.163347697400969]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.4, -5.95919638673076}],
            RowBox[{"{", 
              RowBox[{"16.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.813020240902394`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5615718710865851`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.908828689419144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.052868131119601`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.569036631840206`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.006943461497604872`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.068475300453683`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163347697400969`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.4, "A", 
             Association[1 -> {
                Complex[0.813020240902394, -0.5615718710865851], 
                Complex[1.908828689419144, -2.052868131119601]}, 2 -> {
                Complex[4.569036631840206, 0.006943461497604872], 
                Complex[6.068475300453683, -1.163347697400969]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -5.943537003038906}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.499999999999996`, "A", 
             Association[1 -> {
                Complex[0.835170145892391, -0.5474736791133877], 
                Complex[1.9307493118589267`, -2.037333072756486]}, 2 -> {
                Complex[4.5463246331431195`, 0.007025882918871681], 
                Complex[6.045167287063116, -1.1633328856106508`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.499999999999996`, -5.951122233514465}],
            RowBox[{"{", 
              RowBox[{"16.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.835170145892391`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5474736791133877`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9307493118589267`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.037333072756486`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5463246331431195`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007025882918871681`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.045167287063116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1633328856106508`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.499999999999996`, "A", 
             Association[1 -> {
                Complex[0.835170145892391, -0.5474736791133877], 
                Complex[1.9307493118589267`, -2.037333072756486]}, 2 -> {
                Complex[4.5463246331431195`, 0.007025882918871681], 
                Complex[6.045167287063116, -1.1633328856106508`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.938507444516816}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.599999999999998`, "A", 
             Association[1 -> {
                Complex[0.8559867126628703, -0.5346576120369388], 
                Complex[1.9513735684640627`, -2.023067278104828]}, 2 -> {
                Complex[4.5253142371097725`, 0.007110298008162873], 
                Complex[6.023558855884933, -1.163316510563181]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.599999999999998`, -5.946104963663235}],
            RowBox[{"{", 
              RowBox[{"16.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8559867126628703`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5346576120369388`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9513735684640627`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.023067278104828`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5253142371097725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007110298008162873`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.023558855884933`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.163316510563181`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.599999999999998`, "A", 
             Association[1 -> {
                Complex[0.8559867126628703, -0.5346576120369388], 
                Complex[1.9513735684640627`, -2.023067278104828]}, 2 -> {
                Complex[4.5253142371097725`, 0.007110298008162873], 
                Complex[6.023558855884933, -1.163316510563181]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.935388226208859}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.7, "A", 
             Association[1 -> {
                Complex[0.8757255721593927, -0.52287788641464], 
                Complex[1.9709549506972748`, -2.009827028796298]}, 2 -> {
                Complex[4.5056658326490995`, 0.007196517077880139], 
                Complex[6.003310291269154, -1.1632987794618457`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.7, -5.942976105277693}],
            RowBox[{"{", 
              RowBox[{"16.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8757255721593927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.52287788641464`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9709549506972748`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.009827028796298`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.5056658326490995`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.007196517077880139`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"6.003310291269154`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632987794618457`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.7, "A", 
             Association[1 -> {
                Complex[0.8757255721593927, -0.52287788641464], 
                Complex[1.9709549506972748`, -2.009827028796298]}, 2 -> {
                Complex[4.5056658326490995`, 0.007196517077880139], 
                Complex[6.003310291269154, -1.1632987794618457`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.9331582538746295`}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.799999999999997`, "A", 
             Association[1 -> {
                Complex[0.8945689747906652, -0.5119589442981493], 
                Complex[1.9896739101964132`, -1.9974384540079684`]}, 2 -> {
                Complex[4.487138168550514, 0.007284416332243672], 
                Complex[5.984180253839812, -1.1632798309089607`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.799999999999997`, -5.940702130326528}],
            RowBox[{"{", 
              RowBox[{"16.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.8945689747906652`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5119589442981493`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"1.9896739101964132`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9974384540079684`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.487138168550514`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007284416332243672`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.984180253839812`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632798309089607`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.799999999999997`, "A", 
             Association[1 -> {
                Complex[0.8945689747906652, -0.5119589442981493], 
                Complex[1.9896739101964132`, -1.9974384540079684`]}, 2 -> {
                Complex[4.487138168550514, 0.007284416332243672], 
                Complex[5.984180253839812, -1.1632798309089607`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.930944784144151}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {16.9, "A", 
             Association[1 -> {
                Complex[0.9126523619522108, -0.5017701062164057], 
                Complex[2.007664340945304, -1.9857722832958542`]}, 2 -> {
                Complex[4.469552623884141, 0.007373913179256361], 
                Complex[5.965990045977094, -1.1632597604074917`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{16.9, -5.9384023807932}],
            RowBox[{"{", 
              RowBox[{"16.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9126523619522108`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5017701062164057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.007664340945304`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9857722832958542`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.469552623884141`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007373913179256361`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.965990045977094`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632597604074917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {16.9, "A", 
             Association[1 -> {
                Complex[0.9126523619522108, -0.5017701062164057], 
                Complex[2.007664340945304, -1.9857722832958542`]}, 2 -> {
                Complex[4.469552623884141, 0.007373913179256361], 
                Complex[5.965990045977094, -1.1632597604074917`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17., -5.9280875124678705`}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17., "A", 
             Association[1 -> {
                Complex[0.9300797102089358, -0.4922109148816913], 
                Complex[2.02502886467753, -1.9747292562304524`]}, 2 -> {
                Complex[4.452772601155936, 0.007464952252033912], 
                Complex[5.948603001807257, -1.1632386348615993`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17., -5.935416062221219}],
            RowBox[{"{", 
              RowBox[{"17.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9300797102089358`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4922109148816913`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.02502886467753`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9747292562304524`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.452772601155936`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007464952252033912`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.948603001807257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632386348615993`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17., "A", 
             Association[1 -> {
                Complex[0.9300797102089358, -0.4922109148816913], 
                Complex[2.02502886467753, -1.9747292562304524`]}, 2 -> {
                Complex[4.452772601155936, 0.007464952252033912], 
                Complex[5.948603001807257, -1.1632386348615993`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.924207517275232}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.099999999999998`, "A", 
             Association[1 -> {
                Complex[0.9469329539089921, -0.48320212310888055`], 
                Complex[2.0418482129451156`, -1.964231155946584]}, 2 -> {
                Complex[4.436690887655669, 0.007557496991163237], 
                Complex[5.931911846413443, -1.1632165013453923`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.099999999999998`, -5.931372427322857}],
            RowBox[{"{", 
              RowBox[{"17.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9469329539089921`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.48320212310888055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0418482129451156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.964231155946584`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.436690887655669`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007557496991163237`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.931911846413443`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1632165013453923`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.099999999999998`, "A", 
             Association[1 -> {
                Complex[0.9469329539089921, -0.48320212310888055`], 
                Complex[2.0418482129451156`, -1.964231155946584]}, 2 -> {
                Complex[4.436690887655669, 0.007557496991163237], 
                Complex[5.931911846413443, -1.1632165013453923`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.919242081271416}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0076515243225991425`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.2, "A", 
             Association[1 -> {
                Complex[0.9632780610078037, -0.47467987499817715`], 
                Complex[2.0581872738940445`, -1.9542150231143458`]}, 2 -> {
                Complex[4.421221515937318, 0.0076515243225991425`], 
                Complex[5.91583055481642, -1.1631933926704505`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.2, -5.92622423527507}],
            RowBox[{"{", 
              RowBox[{"17.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9632780610078037`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.47467987499817715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0581872738940445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9542150231143458`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.421221515937318`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0076515243225991425`", " ", 
                    "\[ImaginaryI]"}]}], ",", 
                    RowBox[{
                    RowBox[{"5.91583055481642`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631933926704505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.2, "A", 
             Association[1 -> {
                Complex[0.9632780610078037, -0.47467987499817715`], 
                Complex[2.0581872738940445`, -1.9542150231143458`]}, 2 -> {
                Complex[4.421221515937318, 0.0076515243225991425`], 
                Complex[5.91583055481642, -1.1631933926704505`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.913422992753072}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.299999999999997`, "A", 
             Association[1 -> {
                Complex[0.9791691098460469, -0.46659179640833603`], 
                Complex[2.0740991475740485`, -1.9446292707044912`]}, 2 -> {
                Complex[4.406294309063904, 0.007747021157202576], 
                Complex[5.900288896133161, -1.1631693310632665`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.299999999999997`, -5.920222408692802}],
            RowBox[{"{", 
              RowBox[{"17.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9791691098460469`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.46659179640833603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.0740991475740485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.9446292707044912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.406294309063904`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007747021157202576`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.900288896133161`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631693310632665`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.299999999999997`, "A", 
             Association[1 -> {
                Complex[0.9791691098460469, -0.46659179640833603`], 
                Complex[2.0740991475740485`, -1.9446292707044912`]}, 2 -> {
                Complex[4.406294309063904, 0.007747021157202576], 
                Complex[5.900288896133161, -1.1631693310632665`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.90720191278963}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.4, "A", 
             Association[1 -> {
                Complex[0.9946511165926878, -0.45889427989730874`], 
                Complex[2.089627957098805, -1.9354309873904427`]}, 2 -> {
                Complex[4.391851102143664, 0.007843982012263403], 
                Complex[5.885228654304801, -1.1631443306747422`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.4, -5.913837016365632}],
            RowBox[{"{", 
              RowBox[{"17.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"0.9946511165926878`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.45889427989730874`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.089627957098805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9354309873904427`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.391851102143664`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007843982012263403`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.885228654304801`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631443306747422`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.4, "A", 
             Association[1 -> {
                Complex[0.9946511165926878, -0.45889427989730874`], 
                Complex[2.089627957098805, -1.9354309873904427`]}, 2 -> {
                Complex[4.391851102143664, 0.007843982012263403], 
                Complex[5.885228654304801, -1.1631443306747422`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.901147663489281}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.5, "A", 
             Association[1 -> {
                Complex[1.009762051806893, -0.45155054573492875`], 
                Complex[2.1048108525831113`, -1.926584012895829]}, 2 -> {
                Complex[4.377843050837108, 0.007942407351021055], 
                Complex[5.870600935988343, -1.1631183993398404`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.5, -5.907651165207799}],
            RowBox[{"{", 
              RowBox[{"17.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.009762051806893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.45155054573492875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1048108525831113`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.926584012895829`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.377843050837108`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.007942407351021055`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.870600935988343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1631183993398404`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.5, "A", 
             Association[1 -> {
                Complex[1.009762051806893, -0.45155054573492875`], 
                Complex[2.1048108525831113`, -1.926584012895829]}, 2 -> {
                Complex[4.377843050837108, 0.007942407351021055], 
                Complex[5.870600935988343, -1.1631183993398404`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.895845377242692}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.024534313536096, -0.4445292235923795], 
                Complex[2.119679474265541, -1.918057531021162]}, 2 -> {
                Complex[4.3642286676832285`, 0.00804230239670521], 
                Complex[5.856364206404795, -1.1630915398400685`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.599999999999998`, -5.9022585997013035`}],
            RowBox[{"{", 
              RowBox[{"17.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.024534313536096`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4445292235923795`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.119679474265541`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.918057531021162`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.3642286676832285`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00804230239670521`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.856364206404795`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630915398400685`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.024534313536096, -0.4445292235923795], 
                Complex[2.119679474265541, -1.918057531021162]}, 2 -> {
                Complex[4.3642286676832285`, 0.00804230239670521], 
                Complex[5.856364206404795, -1.1630915398400685`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.891817730308461}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.7, "A", 
             Association[1 -> {
                Complex[1.0389958259885552`, -0.43780329333443724`], 
                Complex[2.134261043168297, -1.9098250195461783`]}, 2 -> {
                Complex[4.350972359395372, 0.008143676269233574], 
                Complex[5.842482826256841, -1.1630637508268273`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.7, -5.8981850171857015`}],
            RowBox[{"{", 
              RowBox[{"17.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0389958259885552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43780329333443724`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.134261043168297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9098250195461783`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.350972359395372`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008143676269233574`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.842482826256841`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630637508268273`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.7, "A", 
             Association[1 -> {
                Complex[1.0389958259885552`, -0.43780329333443724`], 
                Complex[2.134261043168297, -1.9098250195461783`]}, 2 -> {
                Complex[4.350972359395372, 0.008143676269233574], 
                Complex[5.842482826256841, -1.1630637508268273`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.889474043400313}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.0531708739791161`, -0.43134927949335167`], 
                Complex[2.148579189013272, -1.9018634521265043`]}, 2 -> {
                Complex[4.338043317353644, 0.008246541346654037], 
                Complex[5.828925941917192, -1.1630350275077863`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.799999999999997`, -5.89583811119107}],
            RowBox[{"{", 
              RowBox[{"17.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0531708739791161`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.43134927949335167`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.148579189013272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9018634521265043`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.338043317353644`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008246541346654037`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.828925941917192`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630350275077863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.0531708739791161`, -0.43134927949335167`], 
                Complex[2.148579189013272, -1.9018634521265043`]}, 2 -> {
                Complex[4.338043317353644, 0.008246541346654037], 
                Complex[5.828925941917192, -1.1630350275077863`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.8890825156237225`}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.9, "A", 
             Association[1 -> {
                Complex[1.0670807469468007`, -0.42514662876555165`], 
                Complex[2.1626545888502187`, -1.8941526819126022`]}, 2 -> {
                Complex[4.325414662407916, 0.008350912786611275], 
                Complex[5.815666629983418, -1.1630053621640044`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.9, -5.895480869879718}],
            RowBox[{"{", 
              RowBox[{"17.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0670807469468007`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.42514662876555165`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.1626545888502187`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8941526819126022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.325414662407916`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008350912786611275`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.815666629983418`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1630053621640044`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.9, "A", 
             Association[1 -> {
                Complex[1.0670807469468007`, -0.42514662876555165`], 
                Complex[2.1626545888502187`, -1.8941526819126022`]}, 2 -> {
                Complex[4.325414662407916, 0.008350912786611275], 
                Complex[5.815666629983418, -1.1630053621640044`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.890756849407042}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {17.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.0807442431495686`, -0.4191772220375579], 
                Complex[2.176505466752442, -1.8866749586802045`]}, 2 -> {
                Complex[4.3130627762344576`, 0.00845680816400054], 
                Complex[5.802681228429218, -1.1629747445437837`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{17.999999999999996`, -5.897218955919933}],
            RowBox[{"{", 
              RowBox[{"17.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0807442431495686`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4191772220375579`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.176505466752442`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8866749586802045`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.3130627762344576`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.00845680816400054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.802681228429218`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629747445437837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {17.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.0807442431495686`, -0.4191772220375579], 
                Complex[2.176505466752442, -1.8866749586802045`]}, 2 -> {
                Complex[4.3130627762344576`, 0.00845680816400054], 
                Complex[5.802681228429218, -1.1629747445437837`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.894449429230231}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.0941780694739518`, -0.41342498695323976`], 
                Complex[2.19014798983231, -1.8794145456947622`]}, 2 -> {
                Complex[4.300966771833883, 0.008564247194411541], 
                Complex[5.789948806930199, -1.1629431621652235`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.099999999999998`, -5.900994213654657}],
            RowBox[{"{", 
              RowBox[{"18.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.0941780694739518`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41342498695323976`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.19014798983231`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8794145456947622`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.300966771833883`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008564247194411541`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.789948806930199`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1629431621652235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.0941780694739518`, -0.41342498695323976`], 
                Complex[2.19014798983231, -1.8794145456947622`]}, 2 -> {
                Complex[4.300966771833883, 0.008564247194411541], 
                Complex[5.789948806930199, -1.1629431621652235`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.899946649053208}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.2, "A", 
             Association[1 -> {
                Complex[1.107397162145414, -0.4078755867501416], 
                Complex[2.203596585722576, -1.8723574121967355`]}, 2 -> {
                Complex[4.289108069365748, 0.008673251522090971], 
                Complex[5.777450742552286, -1.162910600549928]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.2, -5.906580013555232}],
            RowBox[{"{", 
              RowBox[{"18.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.107397162145414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4078755867501416`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.203596585722576`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8723574121967355`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.289108069365748`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008673251522090971`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.777450742552286`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162910600549928`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.2, "A", 
             Association[1 -> {
                Complex[1.107397162145414, -0.4078755867501416], 
                Complex[2.203596585722576, -1.8723574121967355`]}, 2 -> {
                Complex[4.289108069365748, 0.008673251522090971], 
                Complex[5.777450742552286, -1.162910600549928]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.906866466619177}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.1204149466885311`, -0.40251616773611126`], 
                Complex[2.216864199765705, -1.8654909840009626`]}, 2 -> {
                Complex[4.277470052807503, 0.008783844556995735], 
                Complex[5.765170376285118, -1.162877043404163]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.299999999999997`, -5.913578804477371}],
            RowBox[{"{", 
              RowBox[{"18.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1204149466885311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251616773611126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.216864199765705`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8654909840009626`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.277470052807503`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008783844556995735`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.765170376285118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162877043404163`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.1204149466885311`, -0.40251616773611126`], 
                Complex[2.216864199765705, -1.8654909840009626`]}, 2 -> {
                Complex[4.277470052807503, 0.008783844556995735], 
                Complex[5.765170376285118, -1.162877043404163]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.914663173167995}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.1332435506568057`, -0.39733515240586337`], 
                Complex[2.2299625053481065`, -1.8588039393045301`]}, 2 -> {
                Complex[4.266037789390484, 0.008896051349858974], 
                Complex[5.75309273236891, -1.1628424727592266`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.399999999999995`, -5.921427315292739}],
            RowBox[{"{", 
              RowBox[{"18.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1332435506568057`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.39733515240586337`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2299625053481065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8588039393045301`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.266037789390484`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.008896051349858974`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.75309273236891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628424727592266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.1332435506568057`, -0.39733515240586337`], 
                Complex[2.2299625053481065`, -1.8588039393045301`]}, 2 -> {
                Complex[4.266037789390484, 0.008896051349858974], 
                Complex[5.75309273236891, -1.1628424727592266`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.92264897467411}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.1458939792326737`, -0.3923220684765709], 
                Complex[2.242902077414907, -1.8522860400567256`]}, 2 -> {
                Complex[4.254797798340199, 0.009009898497034034], 
                Complex[5.74120428693884, -1.1628068690797755`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.499999999999996`, -5.929419562637355}],
            RowBox[{"{", 
              RowBox[{"18.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1458939792326737`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3923220684765709`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.242902077414907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8522860400567256`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.254797798340199`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009009898497034034`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.74120428693884`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1628068690797755`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.1458939792326737`, -0.3923220684765709], 
                Complex[2.242902077414907, -1.8522860400567256`]}, 2 -> {
                Complex[4.254797798340199, 0.009009898497034034], 
                Complex[5.74120428693884, -1.1628068690797755`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.930044289374025}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.1583762613396105`, -0.38746740648134814`], 
                Complex[2.2556925367556313`, -1.8459279915891424`]}, 2 -> {
                Complex[4.243737858735289, 0.009125414068990397], 
                Complex[5.729492775798816, -1.162770211346653]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.599999999999998`, -5.936760019545452}],
            RowBox[{"{", 
              RowBox[{"18.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1583762613396105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.38746740648134814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.2556925367556313`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8459279915891424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.243737858735289`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009125414068990397`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.729492775798816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162770211346653`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.1583762613396105`, -0.38746740648134814`], 
                Complex[2.2556925367556313`, -1.8459279915891424`]}, 2 -> {
                Complex[4.243737858735289, 0.009125414068990397], 
                Complex[5.729492775798816, -1.162770211346653]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.936064980797324}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.7, "A", 
             Association[1 -> {
                Complex[1.1706995721155862`, -0.382762500281366], 
                Complex[2.268342670868865, -1.8397213249141577`]}, 2 -> {
                Complex[4.232846848694921, 0.009242627557842213], 
                Complex[5.717947033532342, -1.1627324771191423`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.7, -5.942655040697979}],
            RowBox[{"{", 
              RowBox[{"18.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1706995721155862`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.382762500281366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.268342670868865`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8397213249141577`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.232846848694921`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009242627557842213`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.717947033532342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1627324771191423`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.7, "A", 
             Association[1 -> {
                Complex[1.1706995721155862`, -0.382762500281366], 
                Complex[2.268342670868865, -1.8397213249141577`]}, 2 -> {
                Complex[4.232846848694921, 0.009242627557842213], 
                Complex[5.717947033532342, -1.1627324771191423`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.940041640524292}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.8, "A", 
             Association[1 -> {
                Complex[1.1828723362728408`, -0.378199426130277], 
                Complex[2.280860535897551, -1.8336582973639248`]}, 2 -> {
                Complex[4.222114609872632, 0.009361569840391626], 
                Complex[5.706556857926958, -1.1626936425804282`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.8, -5.9464364565183985`}],
            RowBox[{"{", 
              RowBox[{"18.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1828723362728408`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.378199426130277`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.280860535897551`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8336582973639248`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.222114609872632`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009361569840391626`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.706556857926958`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626936425804282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.8, "A", 
             Association[1 -> {
                Complex[1.1828723362728408`, -0.378199426130277], 
                Complex[2.280860535897551, -1.8336582973639248`]}, 2 -> {
                Complex[4.222114609872632, 0.009361569840391626], 
                Complex[5.706556857926958, -1.1626936425804282`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.9415455812009945`}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.9, "A", 
             Association[1 -> {
                Complex[1.1949023158791763`, -0.3737709168766501], 
                Complex[2.293253543143009, -1.8277318081869505`]}, 2 -> {
                Complex[4.211531832555506, 0.009482273153986658], 
                Complex[5.695312895009785, -1.162653682569165]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.9, -5.947689801974513}],
            RowBox[{"{", 
              RowBox[{"18.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.1949023158791763`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3737709168766501`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.293253543143009`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8277318081869505`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.211531832555506`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009482273153986658`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.695312895009785`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162653682569165`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.9, "A", 
             Association[1 -> {
                Complex[1.1949023158791763`, -0.3737709168766501], 
                Complex[2.293253543143009, -1.8277318081869505`]}, 2 -> {
                Complex[4.211531832555506, 0.009482273153986658], 
                Complex[5.695312895009785, -1.162653682569165]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.940480282986906}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {18.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.2067966853478913`, -0.369470288610321], 
                Complex[2.30552853292255, -1.8219353264340092`]}, 2 -> {
                Complex[4.201089957665183, 0.009604771083122505], 
                Complex[5.684206540989641, -1.1626125705993822`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{18.999999999999996`, -5.946343972137975}],
            RowBox[{"{", 
              RowBox[{"18.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2067966853478913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.369470288610321`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.30552853292255`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8219353264340092`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.201089957665183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009604771083122505`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.684206540989641`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1626125705993822`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {18.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.2067966853478913`, -0.369470288610321], 
                Complex[2.30552853292255, -1.8219353264340092`]}, 2 -> {
                Complex[4.201089957665183, 0.009604771083122505], 
                Complex[5.684206540989641, -1.1626125705993822`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.9371016039243285`}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.2185620958524552`, -0.36529137760862845`], 
                Complex[2.317691837968342, -1.816262829010749]}, 2 -> {
                Complex[4.190781092718281, 0.009729098555121772], 
                Complex[5.67322985816244, -1.1625702788705317`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.099999999999998`, -5.942685662762227}],
            RowBox[{"{", 
              RowBox[{"19.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2185620958524552`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.36529137760862845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.317691837968342`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.816262829010749`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.190781092718281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009729098555121772`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.67322985816244`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625702788705317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.2185620958524552`, -0.36529137760862845`], 
                Complex[2.317691837968342, -1.816262829010749]}, 2 -> {
                Complex[4.190781092718281, 0.009729098555121772], 
                Complex[5.67322985816244, -1.1625702788705317`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.931958491951907}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.2, "A", 
             Association[1 -> {
                Complex[1.2302047309418311`, -0.3612284858628565], 
                Complex[2.329749338128147, -1.8107087471951664`]}, 2 -> {
                Complex[4.180597939390085, 0.00985529184370446], 
                Complex[5.662375502422985, -1.1625267782689677`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.2, -5.937292820731881}],
            RowBox[{"{", 
              RowBox[{"19.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2302047309418311`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3612284858628565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.329749338128147`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8107087471951664`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.180597939390085`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.00985529184370446`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.662375502422985`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1625267782689677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.2, "A", 
             Association[1 -> {
                Complex[1.2302047309418311`, -0.3612284858628565], 
                Complex[2.329749338128147, -1.8107087471951664`]}, 2 -> {
                Complex[4.180597939390085, 0.00985529184370446], 
                Complex[5.662375502422985, -1.1625267782689677`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.925780306661813}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.2417303547902065`, -0.3572763337954378], 
                Complex[2.3417065077888246`, -1.8052679202454833`]}, 2 -> {
                Complex[4.170533730780807, 0.009983388579384763], 
                Complex[5.65163666048189, -1.1624820383620078`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.299999999999997`, -5.930916423054207}],
            RowBox[{"{", 
              RowBox[{"19.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2417303547902065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3572763337954378`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3417065077888246`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8052679202454833`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.170533730780807`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.009983388579384763`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.65163666048189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1624820383620078`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.2417303547902065`, -0.3572763337954378], 
                Complex[2.3417065077888246`, -1.8052679202454833`]}, 2 -> {
                Complex[4.170533730780807, 0.009983388579384763], 
                Complex[5.65163666048189, -1.1624820383620078`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.919353391502627}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.4, "A", 
             Association[1 -> {
                Complex[1.253144354246581, -0.35343001903737564`], 
                Complex[2.3535684571772366`, -1.799935554980541]}, 2 -> {
                Complex[4.16058217684066, 0.010113427765967319`], 
                Complex[5.6410069952433215`, -1.1624360273853815`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.4, -5.924354935409415}],
            RowBox[{"{", 
              RowBox[{"19.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.253144354246581`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.35343001903737564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3535684571772366`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.799935554980541`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.16058217684066`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010113427765967319`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.6410069952433215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1624360273853815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.4, "A", 
             Association[1 -> {
                Complex[1.253144354246581, -0.35343001903737564`], 
                Complex[2.3535684571772366`, -1.799935554980541]}, 2 -> {
                Complex[4.16058217684066, 0.010113427765967319`], 
                Complex[5.6410069952433215`, -1.1624360273853815`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.913421412370323}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.2644517756377363`, -0.34968498034029766`], 
                Complex[2.3653399684829135`, -1.7947071904178555`]}, 2 -> {
                Complex[4.1507374166916415`, 0.010245449802525813`], 
                Complex[5.630480598081044, -1.1623887122247345`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.499999999999996`, -5.918355552795542}],
            RowBox[{"{", 
              RowBox[{"19.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.2644517756377363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.34968498034029766`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3653399684829135`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7947071904178555`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.1507374166916415`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.010245449802525813`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.630480598081044`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1623887122247345`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.2644517756377363`, -0.34968498034029766`], 
                Complex[2.3653399684829135`, -1.7947071904178555`]}, 2 -> {
                Complex[4.1507374166916415`, 0.010245449802525813`], 
                Complex[5.630480598081044, -1.1623887122247345`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.908623512965413}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.275657357109484, -0.34603696586050564`], 
                Complex[2.3770255275795726`, -1.7895786667158637`]}, 2 -> {
                Complex[4.140993976808082, 0.01037949651040012], 
                Complex[5.620051946974447, -1.162340058391703]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.599999999999998`, -5.913554750333723}],
            RowBox[{"{", 
              RowBox[{"19.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.275657357109484`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34603696586050564`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.3770255275795726`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7895786667158637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.140993976808082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01037949651040012`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.620051946974447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162340058391703`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.275657357109484, -0.34603696586050564`], 
                Complex[2.3770255275795726`, -1.7895786667158637`]}, 2 -> {
                Complex[4.140993976808082, 0.01037949651040012], 
                Complex[5.620051946974447, -1.162340058391703]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.905466859299081}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.7, "A", 
             Association[1 -> {
                Complex[1.286765557155954, -0.34248200518323674`], 
                Complex[2.388629351988557, -1.7845460977964305`]}, 2 -> {
                Complex[4.131346734197311, 0.010515611164854463`], 
                Complex[5.609715869645587, -1.162290029994955]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.7, -5.910453315981828}],
            RowBox[{"{", 
              RowBox[{"19.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.286765557155954`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.34248200518323674`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.388629351988557`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7845460977964305`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.131346734197311`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010515611164854463`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.609715869645587`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.162290029994955`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.7, "A", 
             Association[1 -> {
                Complex[1.286765557155954, -0.34248200518323674`], 
                Complex[2.388629351988557, -1.7845460977964305`]}, 2 -> {
                Complex[4.131346734197311, 0.010515611164854463`], 
                Complex[5.609715869645587, -1.162290029994955]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.904322059655149}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.297780579877745, -0.33901638456087957`], 
                Complex[2.4001554156192917`, -1.7796058471281258`]}, 2 -> {
                Complex[4.121790883866403, 0.010653838531129443`], 
                Complex[5.599467510982897, -1.1622385897064982`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.799999999999997`, -5.9094136011886125`}],
            RowBox[{"{", 
              RowBox[{"19.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.297780579877745`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.33901638456087957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4001554156192917`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7796058471281258`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.121790883866403`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010653838531129443`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.599467510982897`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1622385897064982`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.297780579877745, -0.33901638456087957`], 
                Complex[2.4001554156192917`, -1.7796058471281258`]}, 2 -> {
                Complex[4.121790883866403, 0.010653838531129443`], 
                Complex[5.599467510982897, -1.1622385897064982`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.9054294682152335`}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {19.9, "A", 
             Association[1 -> {
                Complex[1.3087063974214082`, -0.33563662492447366`], 
                Complex[2.4116074707342525`, -1.774754506235453]}, 2 -> {
                Complex[4.11232190997813, 0.010794224904694102`], 
                Complex[5.58930230415447, -1.1621856987234667`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{19.9, -5.910666810898417}],
            RowBox[{"{", 
              RowBox[{"19.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3087063974214082`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33563662492447366`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4116074707342525`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.774754506235453`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.11232190997813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010794224904694102`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.58930230415447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621856987234667`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {19.9, "A", 
             Association[1 -> {
                Complex[1.3087063974214082`, -0.33563662492447366`], 
                Complex[2.4116074707342525`, -1.774754506235453]}, 2 -> {
                Complex[4.11232190997813, 0.010794224904694102`], 
                Complex[5.58930230415447, -1.1621856987234667`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.908907319617819}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20., "A", 
             Association[1 -> {
                Complex[1.319546769980594, -0.3323394622978922], 
                Complex[2.4229890675144987`, -1.7699888755685143`]}, 2 -> {
                Complex[4.102935560194785, 0.010936818155564383`], 
                Complex[5.579215944909336, -1.1621313167255454`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20., -5.914321379029946}],
            RowBox[{"{", 
              RowBox[{"20.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.319546769980594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3323394622978922`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4229890675144987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7699888755685143`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.102935560194785`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.010936818155564383`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.579215944909336`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1621313167255454`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20., "A", 
             Association[1 -> {
                Complex[1.319546769980594, -0.3323394622978922], 
                Complex[2.4229890675144987`, -1.7699888755685143`]}, 2 -> {
                Complex[4.102935560194785, 0.010936818155564383`], 
                Complex[5.579215944909336, -1.1621313167255454`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.914756034681902}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.1, "A", 
             Association[1 -> {
                Complex[1.3303052636801032`, -0.3291218303014382], 
                Complex[2.434303571543257, -1.7653059474242632`]}, 2 -> {
                Complex[4.093627822786881, 0.011081667776607964`], 
                Complex[5.569204368643545, -1.1620754018281332`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.1, -5.92036694539692}],
            RowBox[{"{", 
              RowBox[{"20.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3303052636801032`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3291218303014382`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.434303571543257`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7653059474242632`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.093627822786881`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011081667776607964`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.569204368643545`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620754018281332`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.1, "A", 
             Association[1 -> {
                Complex[1.3303052636801032`, -0.3291218303014382], 
                Complex[2.434303571543257, -1.7653059474242632`]}, 2 -> {
                Complex[4.093627822786881, 0.011081667776607964`], 
                Complex[5.569204368643545, -1.1620754018281332`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.922855768125003}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.3409852666152733`, -0.32598084447903347`], 
                Complex[2.4455541794767472`, -1.76070289065742]}, 2 -> {
                Complex[4.084394906148223, 0.011228824935798519`], 
                Complex[5.559263729872352, -1.1620179105312722`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.199999999999996`, -5.928671173577402}],
            RowBox[{"{", 
              RowBox[{"20.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3409852666152733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.32598084447903347`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4455541794767472`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.76070289065742`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.084394906148223`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011228824935798519`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.559263729872352`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1620179105312722`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.3409852666152733`, -0.32598084447903347`], 
                Complex[2.4455541794767472`, -1.76070289065742]}, 2 -> {
                Complex[4.084394906148223, 0.011228824935798519`], 
                Complex[5.559263729872352, -1.1620179105312722`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.932956441184807}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.351590003278767, -0.32291378822242217`], 
                Complex[2.45674393313144, -1.7561770369578598`]}, 2 -> {
                Complex[4.075233220412342, 0.01137834253242333], 
                Complex[5.549390383803343, -1.1619587976643724`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.299999999999997`, -5.938968828038033}],
            RowBox[{"{", 
              RowBox[{"20.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.351590003278767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.32291378822242217`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.45674393313144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7561770369578598`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.075233220412342`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01137834253242333`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.549390383803343`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1619587976643724`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.351590003278767, -0.32291378822242217`], 
                Complex[2.45674393313144, -1.7561770369578598`]}, 2 -> {
                Complex[4.075233220412342, 0.01137834253242333], 
                Complex[5.549390383803343, -1.1619587976643724`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.944661802887896}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.4, "A", 
             Association[1 -> {
                Complex[1.362122547573207, -0.319918100098616], 
                Complex[2.4678757321837086`, -1.7517258685037105`]}, 2 -> {
                Complex[4.066139360909642, 0.01153027525727997], 
                Complex[5.539580869749673, -1.1618980163266774`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.4, -5.95084491693045}],
            RowBox[{"{", 
              RowBox[{"20.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.362122547573207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.319918100098616`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4678757321837086`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7517258685037105`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.066139360909642`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01153027525727997`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.539580869749673`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618980163266774`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.4, "A", 
             Association[1 -> {
                Complex[1.362122547573207, -0.319918100098616], 
                Complex[2.4678757321837086`, -1.7517258685037105`]}, 2 -> {
                Complex[4.066139360909642, 0.01153027525727997], 
                Complex[5.539580869749673, -1.1618980163266774`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.957412363574071}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.5, "A", 
             Association[1 -> {
                Complex[1.3725858345799593`, -0.31699136241415216`], 
                Complex[2.478952345649963, -1.7473470068263863`]}, 2 -> {
                Complex[4.057110093241812, 0.011684679656931263`], 
                Complex[5.529831896159836, -1.1618355178234179`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.5, -5.963717215718034}],
            RowBox[{"{", 
              RowBox[{"20.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3725858345799593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31699136241415216`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.478952345649963`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7473470068263863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.057110093241812`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011684679656931263`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.529831896159836`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1618355178234179`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.5, "A", 
             Association[1 -> {
                Complex[1.3725858345799593`, -0.31699136241415216`], 
                Complex[2.478952345649963, -1.7473470068263863`]}, 2 -> {
                Complex[4.057110093241812, 0.011684679656931263`], 
                Complex[5.529831896159836, -1.1618355178234179`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -5.970476945355608}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.599999999999994`, "A", 
             Association[1 -> {
                Complex[1.382982671230815, -0.31413129087274266`], 
                Complex[2.4899764222920577`, -1.7430382027464781`]}, 2 -> {
                Complex[4.04814233978115, 0.011841614202115778`], 
                Complex[5.520140327071446, -1.1617712515975434`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.599999999999994`, -5.976828697773703}],
            RowBox[{"{", 
              RowBox[{"20.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.382982671230815`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.31413129087274266`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.4899764222920577`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7430382027464781`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.04814233978115`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.011841614202115778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.520140327071446`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1617712515975434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.599999999999994`, "A", 
             Association[1 -> {
                Complex[1.382982671230815, -0.31413129087274266`], 
                Complex[2.4899764222920577`, -1.7430382027464781`]}, 2 -> {
                Complex[4.04814233978115, 0.011841614202115778`], 
                Complex[5.520140327071446, -1.1617712515975434`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -5.982968478093198}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.3933157460094145`, -0.3113357252023996], 
                Complex[2.500950500073134, -1.7387973272586896`]}, 2 -> {
                Complex[4.039233167428713, 0.012001139360437396`], 
                Complex[5.510503169822832, -1.161705165156914]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.699999999999996`, -5.989266506073881}],
            RowBox[{"{", 
              RowBox[{"20.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.3933157460094145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3113357252023996`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.500950500073134`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7387973272586896`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.039233167428713`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012001139360437396`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.510503169822832`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161705165156914`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.3933157460094145`, -0.3113357252023996], 
                Complex[2.500950500073134, -1.7387973272586896`]}, 2 -> {
                Complex[4.039233167428713, 0.012001139360437396`], 
                Complex[5.510503169822832, -1.161705165156914]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -5.9939031276932555`}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.4035876377924137`, -0.3086026206444544], 
                Complex[2.511877014772337, -1.7346223632600892`]}, 2 -> {
                Complex[4.030379776487371, 0.012163317673485264`], 
                Complex[5.500917563878367, -1.1616372039967815`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.799999999999997`, -6.000027227448364}],
            RowBox[{"{", 
              RowBox[{"20.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4035876377924137`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3086026206444544`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.511877014772337`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7346223632600892`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.030379776487371`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012163317673485264`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.500917563878367`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1616372039967815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.4035876377924137`, -0.3086026206444544], 
                Complex[2.511877014772337, -1.7346223632600892`]}, 2 -> {
                Complex[4.030379776487371, 0.012163317673485264`], 
                Complex[5.500917563878367, -1.1616372039967815`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.002315871346328}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {20.9, "A", 
             Association[1 -> {
                Complex[1.4138008239261344`, -0.3059300402110024], 
                Complex[2.522758307852828, -1.730511398029892]}, 2 -> {
                Complex[4.021579490524692, 0.012328213838552492`], 
                Complex[5.491380770642325, -1.1615673115173932`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{20.9, -6.0081407766675206`}],
            RowBox[{"{", 
              RowBox[{"20.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4138008239261344`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3059300402110024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.522758307852828`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.730511398029892`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.021579490524692`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012328213838552492`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.491380770642325`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1615673115173932`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {20.9, "A", 
             Association[1 -> {
                Complex[1.4138008239261344`, -0.3059300402110024], 
                Complex[2.522758307852828, -1.730511398029892]}, 2 -> {
                Complex[4.021579490524692, 0.012328213838552492`], 
                Complex[5.491380770642325, -1.1615673115173932`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21., -6.007423395114715}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21., "A", 
             Association[1 -> {
                Complex[1.4239576876222573`, -0.3033161476291157], 
                Complex[2.5335966336654483`, -1.726462616380607]}, 2 -> {
                Complex[4.012829747116558, 0.012495894795164358`], 
                Complex[5.4818901641520625`, -1.1614954289364903`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21., -6.01284043956516}],
            RowBox[{"{", 
              RowBox[{"21.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4239576876222573`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3033161476291157`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5335966336654483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.726462616380607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.012829747116558`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012495894795164358`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4818901641520625`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614954289364903`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21., "A", 
             Association[1 -> {
                Complex[1.4239576876222573`, -0.3033161476291157], 
                Complex[2.5335966336654483`, -1.726462616380607]}, 2 -> {
                Complex[4.012829747116558, 0.012495894795164358`], 
                Complex[5.4818901641520625`, -1.1614954289364903`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.008790838335313}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.434060524745711, -0.30075920090048514`], 
                Complex[2.544394166060117, -1.7224742944105478`]}, 2 -> {
                Complex[4.004128089376173, 0.012666429816627254`], 
                Complex[5.4724432225550075`, -1.1614214951964699`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.099999999999998`, -6.013730636486791}],
            RowBox[{"{", 
              RowBox[{"21.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.434060524745711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.30075920090048514`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.544394166060117`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7224742944105478`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"4.004128089376173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012666429816627254`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.4724432225550075`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1614214951964699`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.434060524745711, -0.30075920090048514`], 
                Complex[2.544394166060117, -1.7224742944105478`]}, 2 -> {
                Complex[4.004128089376173, 0.012666429816627254`], 
                Complex[5.4724432225550075`, -1.1614214951964699`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.0064360001300905`}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.2, "A", 
             Association[1 -> {
                Complex[1.4441115500589816`, -0.29825754641387064`], 
                Complex[2.5551530044682607`, -1.7185447937963199`]}, 2 -> {
                Complex[3.995472158184808, 0.012839890606854708`], 
                Complex[5.463037520285709, -1.161345446865949]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.2, -6.010883160927502}],
            RowBox[{"{", 
              RowBox[{"21.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4441115500589816`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29825754641387064`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5551530044682607`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7185447937963199`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.995472158184808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.012839890606854708`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.463037520285709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.161345446865949`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.2, "A", 
             Association[1 -> {
                Complex[1.4441115500589816`, -0.29825754641387064`], 
                Complex[2.5551530044682607`, -1.7185447937963199`]}, 2 -> {
                Complex[3.995472158184808, 0.012839890606854708`], 
                Complex[5.463037520285709, -1.161345446865949]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.000821299416501}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.3, "A", 
             Association[1 -> {
                Complex[1.454112902979397, -0.29580961355530405`], 
                Complex[2.5658751795119747`, -1.7146725565713103`]}, 2 -> {
                Complex[3.986859685050743, 0.013016351402742245`], 
                Complex[5.45367072086924, -1.1612672180354269`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.3, -6.004815039568092}],
            RowBox[{"{", 
              RowBox[{"21.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.454112902979397`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.29580961355530405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5658751795119747`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7146725565713103`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.986859685050743`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013016351402742245`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.45367072086924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1612672180354269`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.3, "A", 
             Association[1 -> {
                Complex[1.454112902979397, -0.29580961355530405`], 
                Complex[2.5658751795119747`, -1.7146725565713103`]}, 2 -> {
                Complex[3.986859685050743, 0.013016351402742245`], 
                Complex[5.45367072086924, -1.1612672180354269`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -5.9927377893299}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.4, "A", 
             Association[1 -> {
                Complex[1.4640666528993398`, -0.29341390976756415`], 
                Complex[2.5765626581891587`, -1.710856100342704]}, 2 -> {
                Complex[3.9782884855315257`, 0.013195889082391367`], 
                Complex[5.444340570285955, -1.1611867402067302`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.4, -5.996359514935998}],
            RowBox[{"{", 
              RowBox[{"21.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4640666528993398`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29341390976756415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5765626581891587`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.710856100342704`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9782884855315257`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.013195889082391367`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.444340570285955`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611867402067302`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.4, "A", 
             Association[1 -> {
                Complex[1.4640666528993398`, -0.29341390976756415`], 
                Complex[2.5765626581891587`, -1.710856100342704]}, 2 -> {
                Complex[3.9782884855315257`, 0.013195889082391367`], 
                Complex[5.444340570285955, -1.1611867402067302`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -5.983136229481887}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.4739748041135785`, -0.29106901601605945`], 
                Complex[2.587217348678115, -1.70709401390507]}, 2 -> {
                Complex[3.9697564531622382`, 0.01337858327951261], 
                Complex[5.435044890840143, -1.1611039421758809`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.499999999999996`, -5.986490929460047}],
            RowBox[{"{", 
              RowBox[{"21.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4739748041135785`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29106901601605945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.587217348678115`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.70709401390507`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9697564531622382`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01337858327951261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.435044890840143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1611039421758809`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.4739748041135785`, -0.29106901601605945`], 
                Complex[2.587217348678115, -1.70709401390507]}, 2 -> {
                Complex[3.9697564531622382`, 0.01337858327951261], 
                Complex[5.435044890840143, -1.1611039421758809`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -5.972970555462042}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.483839300392978, -0.2887735826232169], 
                Complex[2.5978411048003482`, -1.7033849532134366`]}, 2 -> {
                Complex[3.961261553838926, 0.013564516504362838`], 
                Complex[5.425781575481578, -1.1610187499090083`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.599999999999998`, -5.976169392537099}],
            RowBox[{"{", 
              RowBox[{"21.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.483839300392978`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2887735826232169`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.5978411048003482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7033849532134366`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.961261553838926`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013564516504362838`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.425781575481578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1610187499090083`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.483839300392978, -0.2887735826232169], 
                Complex[2.5978411048003482`, -1.7033849532134366`]}, 2 -> {
                Complex[3.961261553838926, 0.013564516504362838`], 
                Complex[5.425781575481578, -1.1610187499090083`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -5.963092620012544}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.7, "A", 
             Association[1 -> {
                Complex[1.4936620292395204`, -0.28652632543776696`], 
                Complex[2.608435730175939, -1.699727637683005]}, 2 -> {
                Complex[3.952801820612012, 0.013753774271608805`], 
                Complex[5.416548582534638, -1.1609310864108733`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.7, -5.966240824345805}],
            RowBox[{"{", 
              RowBox[{"21.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.4936620292395204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28652632543776696`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.608435730175939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699727637683005`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.952801820612012`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.013753774271608805`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.416548582534638`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1609310864108733`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.7, "A", 
             Association[1 -> {
                Complex[1.4936620292395204`, -0.28652632543776696`], 
                Complex[2.608435730175939, -1.699727637683005]}, 2 -> {
                Complex[3.952801820612012, 0.013753774271608805`], 
                Complex[5.416548582534638, -1.1609310864108733`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -5.954203366794505}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.503444825853813, -0.28432602230905957`], 
                Complex[2.61900298210226, -1.6961208467863342`]}, 2 -> {
                Complex[3.9443753488495013`, 0.01394644523553293], 
                Complex[5.407343930794649, -1.1608408715855623`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.799999999999997`, -5.957393948007303}],
            RowBox[{"{", 
              RowBox[{"21.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.503444825853813`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.28432602230905957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.61900298210226`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6961208467863342`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9443753488495013`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01394644523553293`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.407343930794649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1608408715855623`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.503444825853813, -0.28432602230905957`], 
                Complex[2.61900298210226, -1.6961208467863342`]}, 2 -> {
                Complex[3.9443753488495013`, 0.01394644523553293], 
                Complex[5.407343930794649, -1.1608408715855623`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -5.946845756257354}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.899999999999995`, "A", 
             Association[1 -> {
                Complex[1.513189476842979, -0.2821715098398555], 
                Complex[2.6295445751835302`, -1.6925634169220722`]}, 2 -> {
                Complex[3.9359802917339604`, 0.01414262133304412], 
                Complex[5.398165694955262, -1.1607480220888433`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.899999999999995`, -5.950157591519135}],
            RowBox[{"{", 
              RowBox[{"21.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.513189476842979`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2821715098398555`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6295445751835302`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6925634169220722`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9359802917339604`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01414262133304412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.398165694955262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1607480220888433`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.899999999999995`, "A", 
             Association[1 -> {
                Complex[1.513189476842979, -0.2821715098398555], 
                Complex[2.6295445751835302`, -1.6925634169220722`]}, 2 -> {
                Complex[3.9359802917339604`, 0.01414262133304412], 
                Complex[5.398165694955262, -1.1607480220888433`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -5.941420659112044}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {21.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.5228977236939458`, -0.280061680393945], 
                Complex[2.640062184735898, -1.6890542385321856`]}, 2 -> {
                Complex[3.927614856061183, 0.014342397934981635`], 
                Complex[5.389012001334582, -1.1606524511716514`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{21.999999999999996`, -5.944919122061765}],
            RowBox[{"{", 
              RowBox[{"21.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5228977236939458`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.280061680393945`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.640062184735898`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6890542385321856`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.927614856061183`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014342397934981635`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.389012001334582`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1606524511716514`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {21.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.5228977236939458`, -0.280061680393945], 
                Complex[2.640062184735898, -1.6890542385321856`]}, 2 -> {
                Complex[3.927614856061183, 0.014342397934981635`], 
                Complex[5.389012001334582, -1.1606524511716514`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -5.93821113603826}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.5325712660346489`, -0.2779954793374565], 
                Complex[2.650557449990277, -1.685592253447088]}, 2 -> {
                Complex[3.9192772983115907`, 0.014545874006250778`], 
                Complex[5.379881023870964, -1.160554068514124]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.099999999999998`, -5.941949808054106}],
            RowBox[{"{", 
              RowBox[{"22.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5325712660346489`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2779954793374565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.650557449990277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.685592253447088`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9192772983115907`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014545874006250778`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.379881023870964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160554068514124`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.5325712660346489`, -0.2779954793374565], 
                Complex[2.650557449990277, -1.685592253447088]}, 2 -> {
                Complex[3.9192772983115907`, 0.014545874006250778`], 
                Complex[5.379881023870964, -1.160554068514124]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -5.937406375098767}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.2, "A", 
             Association[1 -> {
                Complex[1.5422117647034572`, -0.2759719024950626], 
                Complex[2.6610319771130446`, -1.682176452440394]}, 2 -> {
                Complex[3.910965920968408, 0.014753152275367222`], 
                Complex[5.3707709803622485`, -1.1604527800495485`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.2, -5.9414289055493175`}],
            RowBox[{"{", 
              RowBox[{"22.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5422117647034572`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2759719024950626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.6610319771130446`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.682176452440394`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.910965920968408`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.014753152275367222`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.3707709803622485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1604527800495485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.2, "A", 
             Association[1 -> {
                Complex[1.5422117647034572`, -0.2759719024950626], 
                Complex[2.6610319771130446`, -1.682176452440394]}, 2 -> {
                Complex[3.910965920968408, 0.014753152275367222`], 
                Complex[5.3707709803622485`, -1.1604527800495485`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -5.9391210356528035`}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.3, "A", 
             Association[1 -> {
                Complex[1.5518208446451707`, -0.27398999380419353`], 
                Complex[2.671487342062719, -1.678805872976879]}, 2 -> {
                Complex[3.9026790690591686`, 0.014964339414034983`], 
                Complex[5.36168012892486, -1.1603484877775456`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.3, -5.943462620699496}],
            RowBox[{"{", 
              RowBox[{"22.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5518208446451707`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27398999380419353`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.671487342062719`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.678805872976879`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.9026790690591686`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.014964339414034983`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.36168012892486`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1603484877775456`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.3, "A", 
             Association[1 -> {
                Complex[1.5518208446451707`, -0.27398999380419353`], 
                Complex[2.671487342062719, -1.678805872976879]}, 2 -> {
                Complex[3.9026790690591686`, 0.014964339414034983`], 
                Complex[5.36168012892486, -1.1603484877775456`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -5.943408332802917}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.4, "A", 
             Association[1 -> {
                Complex[1.5614000976502447`, -0.27204884315225314`], 
                Complex[2.68192509329917, -1.675479597139089]}, 2 -> {
                Complex[3.894415126899331, 0.015179546227436329`], 
                Complex[5.352606764651277, -1.1602410895657407`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.4, -5.948096512596099}],
            RowBox[{"{", 
              RowBox[{"22.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5614000976502447`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27204884315225314`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.68192509329917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.675479597139089`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.894415126899331`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.015179546227436329`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.352606764651277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1602410895657407`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.4, "A", 
             Association[1 -> {
                Complex[1.5614000976502447`, -0.27204884315225314`], 
                Complex[2.68192509329917, -1.675479597139089]}, 2 -> {
                Complex[3.894415126899331, 0.015179546227436329`], 
                Complex[5.352606764651277, -1.1602410895657407`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -5.9502663363130734`}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.5709510849523987`, -0.27014758438335246`], 
                Complex[2.692346754360388, -1.6721967497195438`]}, 2 -> {
                Complex[3.8861725150187785`, 0.015398887855965335`], 
                Complex[5.343549216446447, -1.1601304789391282`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.499999999999996`, -5.955320900727629}],
            RowBox[{"{", 
              RowBox[{"22.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5709510849523987`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.27014758438335246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.692346754360388`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6721967497195438`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8861725150187785`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015398887855965335`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.343549216446447`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1601304789391282`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.5709510849523987`, -0.27014758438335246`], 
                Complex[2.692346754360388, -1.6721967497195438`]}, 2 -> {
                Complex[3.8861725150187785`, 0.015398887855965335`], 
                Complex[5.343549216446447, -1.1601304789391282`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -5.959637226621168}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.5804753396984255`, -0.26828539346253044`], 
                Complex[2.702753826320577, -1.668956496466899]}, 2 -> {
                Complex[3.8779496872537016`, 0.015622483989198204`], 
                Complex[5.334505844025381, -1.160016544856252]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.599999999999998`, -5.965069016971934}],
            RowBox[{"{", 
              RowBox[{"22.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5804753396984255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26828539346253044`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.702753826320577`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.668956496466899`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8779496872537016`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015622483989198204`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.334505844025381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.160016544856252`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.5804753396984255`, -0.26828539346253044`], 
                Complex[2.702753826320577, -1.668956496466899]}, 2 -> {
                Complex[3.8779496872537016`, 0.015622483989198204`], 
                Complex[5.334505844025381, -1.160016544856252]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -5.971399099409826}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.7, "A", 
             Association[1 -> {
                Complex[1.5899743693028523`, -0.26646148678673565`], 
                Complex[2.7131477901421976`, -1.6657580424757248`]}, 2 -> {
                Complex[3.8697451279879247`, 0.015850459092959818`], 
                Complex[5.325475035055748, -1.1598991714712619`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.7, -5.977207441502274}],
            RowBox[{"{", 
              RowBox[{"22.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5899743693028523`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26646148678673565`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7131477901421976`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6657580424757248`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8697451279879247`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.015850459092959818`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.325475035055748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1598991714712619`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.7, "A", 
             Association[1 -> {
                Complex[1.5899743693028523`, -0.26646148678673565`], 
                Complex[2.7131477901421976`, -1.6657580424757248`]}, 2 -> {
                Complex[3.8697451279879247`, 0.015850459092959818`], 
                Complex[5.325475035055748, -1.1598991714712619`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -5.985349697365345}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.5994496576990789`, -0.26467511963294016`], 
                Complex[2.7235301089335913`, -1.6626006307106493`]}, 2 -> {
                Complex[3.861557349529051, 0.01608294265041592], 
                Complex[5.316455202430543, -1.1597782378808235`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.799999999999997`, -5.991518150386582}],
            RowBox[{"{", 
              RowBox[{"22.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.5994496576990789`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26467511963294016`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7235301089335913`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6626006307106493`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.861557349529051`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01608294265041592`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.316455202430543`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1597782378808235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.5994496576990789`, -0.26467511963294016`], 
                Complex[2.7235301089335913`, -1.6626006307106493`]}, 2 -> {
                Complex[3.861557349529051, 0.01608294265041592], 
                Complex[5.316455202430543, -1.1597782378808235`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.0011815753644795`}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.9, "A", 
             Association[1 -> {
                Complex[1.6089026674977167`, -0.2629255847348713], 
                Complex[2.733902230122971, -1.6594835406566912`]}, 2 -> {
                Complex[3.8533848896060525`, 0.0163200694182023], 
                Complex[5.307444781657183, -1.1596536178547647`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.9, -6.007671716997782}],
            RowBox[{"{", 
              RowBox[{"22.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6089026674977167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2629255847348713`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.733902230122971`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6594835406566912`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8533848896060525`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0163200694182023`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.307444781657183`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1596536178547647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.9, "A", 
             Association[1 -> {
                Complex[1.6089026674977167`, -0.2629255847348713], 
                Complex[2.733902230122971, -1.6594835406566912`]}, 2 -> {
                Complex[3.8533848896060525`, 0.0163200694182023], 
                Complex[5.307444781657183, -1.1596536178547647`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.018449299101462}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {22.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.6183348420620054`, -0.2612122109807513], 
                Complex[2.7442655875587194`, -1.6564060870885489`]}, 2 -> {
                Complex[3.8452263089759486`, 0.01656197969868379], 
                Complex[5.2984422283503445`, -1.1595251795492592`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{22.999999999999996`, -6.025192551390702}],
            RowBox[{"{", 
              RowBox[{"22.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6183348420620054`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2612122109807513`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7442655875587194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6564060870885489`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8452263089759486`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01656197969868379`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.2984422283503445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1595251795492592`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {22.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.6183348420620054`, -0.2612122109807513], 
                Complex[2.7442655875587194`, -1.6564060870885489`]}, 2 -> {
                Complex[3.8452263089759486`, 0.01656197969868379], 
                Complex[5.2984422283503445`, -1.1595251795492592`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.036532334509598}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.6277476075095596`, -0.2595343622253301], 
                Complex[2.7546216035454134`, -1.653367618952437]}, 2 -> {
                Complex[3.837080189128189, 0.016808819629533064`], 
                Complex[5.289446015816816, -1.159392785201224]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.099999999999998`, -6.043420638290112}],
            RowBox[{"{", 
              RowBox[{"23.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6277476075095596`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2595343622253301`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7546216035454134`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.653367618952437`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.837080189128189`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.016808819629533064`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.289446015816816`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159392785201224`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.6277476075095596`, -0.2595343622253301], 
                Complex[2.7546216035454134`, -1.653367618952437]}, 2 -> {
                Complex[3.837080189128189, 0.016808819629533064`], 
                Complex[5.289446015816816, -1.159392785201224]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.054603533961739}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.637142374648998, -0.2578914362102892], 
                Complex[2.7649716908242405`, -1.6503675183549187`]}, 2 -> {
                Complex[3.8289451300761326`, 0.017060741491919426`], 
                Complex[5.280454632721417, -1.159256290802515]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.199999999999996`, -6.061481323248733}],
            RowBox[{"{", 
              RowBox[{"23.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.637142374648998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2578914362102892`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7649716908242405`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6503675183549187`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8289451300761326`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017060741491919426`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.280454632721417`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.159256290802515`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.637142374648998, -0.2578914362102892], 
                Complex[2.7649716908242405`, -1.6503675183549187`]}, 2 -> {
                Complex[3.8289451300761326`, 0.017060741491919426`], 
                Complex[5.280454632721417, -1.159256290802515]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.071622941515521}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.6465205408595256`, -0.2562828635878306], 
                Complex[2.7753172545061173`, -1.6474051996538635`]}, 2 -> {
                Complex[3.820819748225798, 0.01731790403871422], 
                Complex[5.271466580823749, -1.1591155457523543`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.299999999999997`, -6.078285373526786}],
            RowBox[{"{", 
              RowBox[{"23.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6465205408595256`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2562828635878306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7753172545061173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6474051996538635`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.820819748225798`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01731790403871422`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.271466580823749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1591155457523543`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.6465205408595256`, -0.2562828635878306], 
                Complex[2.7753172545061173`, -1.6474051996538635`]}, 2 -> {
                Complex[3.820819748225798, 0.01731790403871422], 
                Complex[5.271466580823749, -1.1591155457523543`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.086386673082809}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.4, "A", 
             Association[1 -> {
                Complex[1.6558834919210377`, -0.25470810704296915`], 
                Complex[2.7856596939652984`, -1.644480108647397]}, 2 -> {
                Complex[3.812702674312651, 0.0175804728442376], 
                Complex[5.262480372776144, -1.158970392486303]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.4, -6.092591313397598}],
            RowBox[{"{", 
              RowBox[{"23.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6558834919210377`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25470810704296915`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.7856596939652984`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.644480108647397`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.812702674312651`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0175804728442376`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.262480372776144`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158970392486303`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.4, "A", 
             Association[1 -> {
                Complex[1.6558834919210377`, -0.25470810704296915`], 
                Complex[2.7856596939652984`, -1.644480108647397]}, 2 -> {
                Complex[3.812702674312651, 0.0175804728442376], 
                Complex[5.262480372776144, -1.158970392486303]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.097659990753362}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.5, "A", 
             Association[1 -> {
                Complex[1.6652326038019236`, -0.2531666605106765], 
                Complex[2.796000404700961, -1.6415917218573375`]}, 2 -> {
                Complex[3.8045925513977634`, 0.017848620677213583`], 
                Complex[5.253494529973697, -1.1588206660799292`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.5, -6.1031580371919585`}],
            RowBox[{"{", 
              RowBox[{"23.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6652326038019236`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2531666605106765`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.796000404700961`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6415917218573375`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.8045925513977634`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.017848620677213583`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.253494529973697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1588206660799292`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.5, "A", 
             Association[1 -> {
                Complex[1.6652326038019236`, -0.2531666605106765], 
                Complex[2.796000404700961, -1.6415917218573375`]}, 2 -> {
                Complex[3.8045925513977634`, 0.017848620677213583`], 
                Complex[5.253494529973697, -1.1588206660799292`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.104395944158584}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.6, "A", 
             Association[1 -> {
                Complex[1.6745692444113933`, -0.251658048484637], 
                Complex[2.8063407801738802`, -1.6387395459042156`]}, 2 -> {
                Complex[3.796488032915171, 0.018122527898744724`], 
                Complex[5.244507580447731, -1.158666193825158]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.6, -6.108980911999646}],
            RowBox[{"{", 
              RowBox[{"23.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6745692444113933`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.251658048484637`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8063407801738802`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6387395459042156`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.796488032915171`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018122527898744724`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.244507580447731`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158666193825158`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.6, "A", 
             Association[1 -> {
                Complex[1.6745692444113933`, -0.251658048484637], 
                Complex[2.8063407801738802`, -1.6387395459042156`]}, 2 -> {
                Complex[3.796488032915171, 0.018122527898744724`], 
                Complex[5.244507580447731, -1.158666193825158]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.105982868676933}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.6838947753228468`, -0.25018182541497563`], 
                Complex[2.816682213625116, -1.635923116971627]}, 2 -> {
                Complex[3.7883877807626547`, 0.018402382887287773`], 
                Complex[5.235518056794404, -1.1585067947770962`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.699999999999996`, -6.1095409437121875`}],
            RowBox[{"{", 
              RowBox[{"23.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6838947753228468`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.25018182541497563`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.816682213625116`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.635923116971627`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7883877807626547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018402382887287773`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.235518056794404`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1585067947770962`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.6838947753228468`, -0.25018182541497563`], 
                Complex[2.816682213625116, -1.635923116971627]}, 2 -> {
                Complex[3.7883877807626547`, 0.018402382887287773`], 
                Complex[5.235518056794404, -1.1585067947770962`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.102412391420586}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.6932105534745874`, -0.2487375751928472], 
                Complex[2.8270260998834287`, -1.6331420003581567`]}, 2 -> {
                Complex[3.7802904634285417`, 0.018688382492788227`], 
                Complex[5.226524494130514, -1.158342279268929]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.799999999999997`, -6.104950656353609}],
            RowBox[{"{", 
              RowBox[{"23.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.6932105534745874`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2487375751928472`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8270260998834287`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6331420003581567`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7802904634285417`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.018688382492788227`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.226524494130514`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.158342279268929`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.6932105534745874`, -0.2487375751928472], 
                Complex[2.8270260998834287`, -1.6331420003581567`]}, 2 -> {
                Complex[3.7802904634285417`, 0.018688382492788227`], 
                Complex[5.226524494130514, -1.158342279268929]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.094276055015946}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {23.9, "A", 
             Association[1 -> {
                Complex[1.7025179328539397`, -0.2473249107203387], 
                Complex[2.8373738371679282`, -1.6303957901157322`]}, 2 -> {
                Complex[3.772194754147412, 0.018980732522336802`], 
                Complex[5.217525428068778, -1.1581724483922544`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{23.9, -6.095914246298608}],
            RowBox[{"{", 
              RowBox[{"23.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7025179328539397`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2473249107203387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8373738371679282`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6303957901157322`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.772194754147412`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.018980732522336802`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.217525428068778`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1581724483922544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {23.9, "A", 
             Association[1 -> {
                Complex[1.7025179328539397`, -0.2473249107203387], 
                Complex[2.8373738371679282`, -1.6303957901157322`]}, 2 -> {
                Complex[3.772194754147412, 0.018980732522336802`], 
                Complex[5.217525428068778, -1.1581724483922544`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24., -6.082592343494434}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24., "A", 
             Association[1 -> {
                Complex[1.711818266170711, -0.24594347356467736`], 
                Complex[2.8477268288924487`, -1.627684108773821]}, 2 -> {
                Complex[3.7640993290778377`, 0.019279648259930993`], 
                Complex[5.208519392705085, -1.1579970934399617`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24., -6.0835252165069615`}],
            RowBox[{"{", 
              RowBox[{"24.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.711818266170711`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24594347356467736`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8477268288924487`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.627684108773821`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7640993290778377`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.019279648259930993`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.208519392705085`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1579970934399617`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24., "A", 
             Association[1 -> {
                Complex[1.711818266170711, -0.24594347356467736`], 
                Complex[2.8477268288924487`, -1.627684108773821]}, 2 -> {
                Complex[3.7640993290778377`, 0.019279648259930993`], 
                Complex[5.208519392705085, -1.1579970934399617`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.068558104968078}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.099999999999994`, "A", 
             Association[1 -> {
                Complex[1.7211129065258053`, -0.2445929336962447], 
                Complex[2.8580864854780335`, -1.6250066071493976`]}, 2 -> {
                Complex[3.7560028654954856`, 0.01958535502317048], 
                Complex[5.199504918610364, -1.1578159953084994`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.099999999999994`, -6.069009415285336}],
            RowBox[{"{", 
              RowBox[{"24.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7211129065258053`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2445929336962447`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8580864854780335`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6250066071493976`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7560028654954856`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.01958535502317048`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.199504918610364`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1578159953084994`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.099999999999994`, "A", 
             Association[1 -> {
                Complex[1.7211129065258053`, -0.2445929336962447], 
                Complex[2.8580864854780335`, -1.6250066071493976`]}, 2 -> {
                Complex[3.7560028654954856`, 0.01958535502317048], 
                Complex[5.199504918610364, -1.1578159953084994`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.053332127089529}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.7304032090806973`, -0.24327298931041993`], 
                Complex[2.8684542261798467`, -1.6223629642431867`]}, 2 -> {
                Complex[3.747904039995082, 0.01989808875998759], 
                Complex[5.190480530819805, -1.1576289238560522`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.199999999999996`, -6.053518259880649}],
            RowBox[{"{", 
              RowBox[{"24.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7304032090806973`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24327298931041993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8684542261798467`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6223629642431867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.747904039995082`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.01989808875998759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.190480530819805`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1576289238560522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.7304032090806973`, -0.24327298931041993`], 
                Complex[2.8684542261798467`, -1.6223629642431867`]}, 2 -> {
                Complex[3.747904039995082, 0.01989808875998759], 
                Complex[5.190480530819805, -1.1576289238560522`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.037905643654194}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.739690532733481, -0.24198336673385532`], 
                Complex[2.8788314809349784`, -1.6197528872232836`]}, 2 -> {
                Complex[3.739801526694796, 0.020218096688815523`], 
                Complex[5.181444746812216, -1.157435637212811]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.299999999999997`, -6.038015373874929}],
            RowBox[{"{", 
              RowBox[{"24.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.739690532733481`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.24198336673385532`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8788314809349784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6197528872232836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.739801526694796`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020218096688815523`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.181444746812216`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.157435637212811`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.739690532733481, -0.24198336673385532`], 
                Complex[2.8788314809349784`, -1.6197528872232836`]}, 2 -> {
                Complex[3.739801526694796, 0.020218096688815523`], 
                Complex[5.181444746812216, -1.157435637212811]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.023056887736619}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.4, "A", 
             Association[1 -> {
                Complex[1.7489762418071482`, -0.24072382041628856`], 
                Complex[2.889219692237537, -1.6171761114978094`]}, 2 -> {
                Complex[3.7316939954367316`, 0.020545637985933], 
                Complex[5.1723960744723065`, -1.1572358810391412`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.4, -6.023244823278472}],
            RowBox[{"{", 
              RowBox[{"24.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7489762418071482`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24072382041628856`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.889219692237537`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6171761114978094`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7316939954367316`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.020545637985933`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1723960744723065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1572358810391412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.4, "A", 
             Association[1 -> {
                Complex[1.7489762418071482`, -0.24072382041628856`], 
                Complex[2.889219692237537, -1.6171761114978094`]}, 2 -> {
                Complex[3.7316939954367316`, 0.020545637985933], 
                Complex[5.1723960744723065`, -1.1572358810391412`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.00936006144887}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.758261707755823, -0.23949413300958816`], 
                Complex[2.8996203170476376`, -1.6146324008788797`]}, 2 -> {
                Complex[3.723580109977185, 0.020880984524095002`], 
                Complex[5.163333010028643, -1.1570293877270226`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.499999999999996`, -6.009748359452839}],
            RowBox[{"{", 
              RowBox[{"24.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.758261707755823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23949413300958816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.8996203170476376`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6146324008788797`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.723580109977185`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.020880984524095002`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.163333010028643`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1570293877270226`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.758261707755823, -0.23949413300958816`], 
                Complex[2.8996203170476376`, -1.6146324008788797`]}, 2 -> {
                Complex[3.723580109977185, 0.020880984524095002`], 
                Complex[5.163333010028643, -1.1570293877270226`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -5.9972191517721996`}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.7675483108947163`, -0.2382941155363085], 
                Complex[2.910034828740952, -1.6121215478408175`]}, 2 -> {
                Complex[3.7154585261603414`, 0.021224421666976207`], 
                Complex[5.1542540359599105`, -1.156815875539666]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.599999999999998`, -5.997902876931906}],
            RowBox[{"{", 
              RowBox[{"24.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7675483108947163`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2382941155363085`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.910034828740952`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6121215478408175`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.7154585261603414`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021224421666976207`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.1542540359599105`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.156815875539666`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.7675483108947163`, -0.2382941155363085], 
                Complex[2.910034828740952, -1.6121215478408175`]}, 2 -> {
                Complex[3.7154585261603414`, 0.021224421666976207`], 
                Complex[5.1542540359599105`, -1.156815875539666]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -5.986907324200818}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.7, "A", 
             Association[1 -> {
                Complex[1.776837442159661, -0.23712360765068694`], 
                Complex[2.920464719105737, -1.6096433738762477`]}, 2 -> {
                Complex[3.707327890069032, 0.02157624912441267], 
                Complex[5.145157618862019, -1.156595047683686]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.7, -5.9879606143573}],
            RowBox[{"{", 
              RowBox[{"24.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.776837442159661`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23712360765068694`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.920464719105737`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6096433738762477`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.707327890069032`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02157624912441267`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.145157618862019`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.156595047683686`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.7, "A", 
             Association[1 -> {
                Complex[1.776837442159661, -0.23712360765068694`], 
                Complex[2.920464719105737, -1.6096433738762477`]}, 2 -> {
                Complex[3.707327890069032, 0.02157624912441267], 
                Complex[5.145157618862019, -1.156595047683686]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -5.978602484680225}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.8, "A", 
             Association[1 -> {
                Complex[1.7861305049022496`, -0.23598247799562685`], 
                Complex[2.930911500394467, -1.6071977299543905`]}, 2 -> {
                Complex[3.6991868361460636`, 0.021936781873947247`], 
                Complex[5.136042207268361, -1.1563665913076095`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.8, -5.98008416803477}],
            RowBox[{"{", 
              RowBox[{"24.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7861305049022496`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23598247799562685`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.930911500394467`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6071977299543905`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6991868361460636`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.021936781873947247`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.136042207268361`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1563665913076095`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.8, "A", 
             Association[1 -> {
                Complex[1.7861305049022496`, -0.23598247799562685`], 
                Complex[2.930911500394467, -1.6071977299543905`]}, 2 -> {
                Complex[3.6991868361460636`, 0.021936781873947247`], 
                Complex[5.136042207268361, -1.1563665913076095`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -5.97241584290643}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.9, "A", 
             Association[1 -> {
                Complex[1.7954289167267061`, -0.23487062465998598`], 
                Complex[2.9413767074374184`, -1.6047844970867333`]}, 2 -> {
                Complex[3.6910339852795406`, 0.022306351154756415`], 
                Complex[5.126906229415363, -1.1561301764198544`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.9, -5.97437403905265}],
            RowBox[{"{", 
              RowBox[{"24.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.7954289167267061`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23487062465998598`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9413767074374184`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6047844970867333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6910339852795406`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022306351154756415`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.126906229415363`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1561301764198544`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.9, "A", 
             Association[1 -> {
                Complex[1.7954289167267061`, -0.23487062465998598`], 
                Complex[2.9413767074374184`, -1.6047844970867333`]}, 2 -> {
                Complex[3.6910339852795406`, 0.022306351154756415`], 
                Complex[5.126906229415363, -1.1561301764198544`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -5.9684133925013345`}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {24.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.8047341113748927`, -0.23378797574120985`], 
                Complex[2.9518618998259756`, -1.6024035870060647`]}, 2 -> {
                Complex[3.6828679428453777`, 0.022685305540684448`], 
                Complex[5.117748090945093, -1.1558854547185569`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{24.999999999999996`, -5.970889060812424}],
            RowBox[{"{", 
              RowBox[{"24.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8047341113748927`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23378797574120985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9518618998259756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6024035870060647`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6828679428453777`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.022685305540684448`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.117748090945093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1558854547185569`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {24.999999999999996`, "A", 
             Association[1 -> {
                Complex[1.8047341113748927`, -0.23378797574120985`], 
                Complex[2.9518618998259756`, -1.6024035870060647`]}, 2 -> {
                Complex[3.6828679428453777`, 0.022685305540684448`], 
                Complex[5.117748090945093, -1.1558854547185569`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -5.9666313864981095`}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.814047540666005, -0.23273449001922963`], 
                Complex[2.962368664173644, -1.6000549429658453`]}, 2 -> {
                Complex[3.6746872967000694`, 0.0230740120998302], 
                Complex[5.1085661725364995`, -1.155632058324808]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.099999999999998`, -5.969660948423622}],
            RowBox[{"{", 
              RowBox[{"25.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.814047540666005`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23273449001922963`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.962368664173644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6000549429658453`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6746872967000694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0230740120998302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.1085661725364995`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.155632058324808`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.814047540666005, -0.23273449001922963`], 
                Complex[2.962368664173644, -1.6000549429658453`]}, 2 -> {
                Complex[3.6746872967000694`, 0.0230740120998302], 
                Complex[5.1085661725364995`, -1.155632058324808]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -5.967087101533331}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.8233706764978728`, -0.2317101577484136], 
                Complex[2.9728986164633167`, -1.5977385406678668`]}, 2 -> {
                Complex[3.6664906151164782`, 0.023472857648944835`], 
                Complex[5.099358827456356, -1.1553695984099268`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.199999999999996`, -5.9707042919291675`}],
            RowBox[{"{", 
              RowBox[{"25.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8233706764978728`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2317101577484136`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9728986164633167`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5977385406678668`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6664906151164782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023472857648944835`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.099358827456356`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1553695984099268`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.199999999999996`, "A", 
             Association[1 -> {
                Complex[1.8233706764978728`, -0.2317101577484136], 
                Complex[2.9728986164633167`, -1.5977385406678668`]}, 2 -> {
                Complex[3.6664906151164782`, 0.023472857648944835`], 
                Complex[5.099358827456356, -1.1553695984099268`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -5.9697860115385355`}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.8327050129169915`, -0.23071500157543248`], 
                Complex[2.983453404489649, -1.5954543893273732`]}, 2 -> {
                Complex[3.6582764446551637`, 0.023882250111808095`], 
                Complex[5.090124379020649, -1.1550976637063444`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.299999999999997`, -5.974023082785633}],
            RowBox[{"{", 
              RowBox[{"25.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8327050129169915`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23071500157543248`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.983453404489649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5954543893273732`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6582764446551637`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.023882250111808095`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.090124379020649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1550976637063444`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.8327050129169915`, -0.23071500157543248`], 
                Complex[2.983453404489649, -1.5954543893273732`]}, 2 -> {
                Complex[3.6582764446551637`, 0.023882250111808095`], 
                Complex[5.090124379020649, -1.1550976637063444`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -5.974726200508385}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.8420520682648396`, -0.22974907759194238`], 
                Complex[2.9940347104060323`, -1.5932025328859922`]}, 2 -> {
                Complex[3.6500433079634345`, 0.02430261999177399], 
                Complex[5.080861117956597, -1.15481581889049]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.399999999999995`, -5.979614546354129}],
            RowBox[{"{", 
              RowBox[{"25.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8420520682648396`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22974907759194238`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"2.9940347104060323`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5932025328859922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6500433079634345`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02430261999177399`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.080861117956597`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.15481581889049`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.8420520682648396`, -0.22974907759194238`], 
                Complex[2.9940347104060323`, -1.5932025328859922`]}, 2 -> {
                Complex[3.6500433079634345`, 0.02430261999177399], 
                Complex[5.080861117956597, -1.15481581889049]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -5.981900540424588}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.8514133874083418`, -0.22881247653229805`], 
                Complex[3.0046442533860986`, -1.5909830513843415`]}, 2 -> {
                Complex[3.64178970149396, 0.024734421969833987`], 
                Complex[5.071567299655017, -1.154523602824754]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.499999999999996`, -5.987470735786609}],
            RowBox[{"{", 
              RowBox[{"25.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8514133874083418`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22881247653229805`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0046442533860986`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5909830513843415`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.64178970149396`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.024734421969833987`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.071567299655017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.154523602824754`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.8514133874083418`, -0.22881247653229805`], 
                Complex[3.0046442533860986`, -1.5909830513843415`]}, 2 -> {
                Complex[3.64178970149396, 0.024734421969833987`], 
                Complex[5.071567299655017, -1.154523602824754]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -5.99129687114047}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.860790544062835, -0.2279053251278246], 
                Complex[3.0152837924104205`, -1.58879606250765]}, 2 -> {
                Complex[3.633514093134369, 0.025178136640842893`], 
                Complex[5.0622411413021275`, -1.1542205266440742`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.599999999999998`, -5.9975780385517}],
            RowBox[{"{", 
              RowBox[{"25.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.860790544062835`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2279053251278246`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0152837924104205`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.58879606250765`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.633514093134369`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025178136640842893`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.0622411413021275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1542205266440742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.860790544062835, -0.2279053251278246], 
                Complex[3.0152837924104205`, -1.58879606250765]}, 2 -> {
                Complex[3.633514093134369, 0.025178136640842893`], 
                Complex[5.0622411413021275`, -1.1542205266440742`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.002896134175796}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.7, "A", 
             Association[1 -> {
                Complex[1.8701851432162653`, -0.22702778763077072`], 
                Complex[3.0259551291896356`, -1.586641723319602]}, 2 -> {
                Complex[3.625214919738834, 0.025634272402031196`], 
                Complex[5.052880818879211, -1.1539060716710012`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.7, -6.009914438695185}],
            RowBox[{"{", 
              RowBox[{"25.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8701851432162653`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22702778763077072`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0259551291896356`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.586641723319602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.625214919738834`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.025634272402031196`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.052880818879211`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1539060716710012`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.7, "A", 
             Association[1 -> {
                Complex[1.8701851432162653`, -0.22702778763077072`], 
                Complex[3.0259551291896356`, -1.586641723319602]}, 2 -> {
                Complex[3.625214919738834, 0.025634272402031196`], 
                Complex[5.052880818879211, -1.1539060716710012`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.016668106183902}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.8795988236639012`, -0.22618006752276323`], 
                Complex[3.036660111236013, -1.5845202322015446`]}, 2 -> {
                Complex[3.6168905845521655`, 0.0261033675095845], 
                Complex[5.043484464017904, -1.1535796871411728`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.799999999999997`, -6.024444035049388}],
            RowBox[{"{", 
              RowBox[{"25.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8795988236639012`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22618006752276323`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.036660111236013`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5845202322015446`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6168905845521655`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.0261033675095845`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.043484464017904`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1535796871411728`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.8795988236639012`, -0.22618006752276323`], 
                Complex[3.036660111236013, -1.5845202322015446`]}, 2 -> {
                Complex[3.6168905845521655`, 0.0261033675095845], 
                Complex[5.043484464017904, -1.1535796871411728`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.032564018752915}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {25.9, "A", 
             Association[1 -> {
                Complex[1.8890332606633722`, -0.22536240942454516`], 
                Complex[3.047400635096297, -1.582431831016463]}, 2 -> {
                Complex[3.6085394545164045`, 0.026585992320965875`], 
                Complex[5.034050160698048, -1.1532407877189192`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{25.9, -6.04110790394123}],
            RowBox[{"{", 
              RowBox[{"25.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8890332606633722`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22536240942454516`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.047400635096297`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.582431831016463`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6085394545164045`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.026585992320965875`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.034050160698048`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1532407877189192`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {25.9, "A", 
             Association[1 -> {
                Complex[1.8890332606633722`, -0.22536240942454516`], 
                Complex[3.047400635096297, -1.582431831016463]}, 2 -> {
                Complex[3.6085394545164045`, 0.026585992320965875`], 
                Complex[5.034050160698048, -1.1532407877189192`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26., -6.050504912034974}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26., "A", 
             Association[1 -> {
                Complex[1.8984901687203608`, -0.2245751012259816], 
                Complex[3.0581786497594123`, -1.580376807519702]}, 2 -> {
                Complex[3.6001598574493725`, 0.027082751742796535`], 
                Complex[5.024575941774229, -1.1528887507802408`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26., -6.059809891570299}],
            RowBox[{"{", 
              RowBox[{"26.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.8984901687203608`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2245751012259816`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0581786497594123`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.580376807519702`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.6001598574493725`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.027082751742796535`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"5.024575941774229`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1528887507802408`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26., "A", 
             Association[1 -> {
                Complex[1.8984901687203608`, -0.2245751012259816], 
                Complex[3.0581786497594123`, -1.580376807519702]}, 2 -> {
                Complex[3.6001598574493725`, 0.027082751742796535`], 
                Complex[5.024575941774229, -1.1528887507802408`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.070364050718319}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.9079713045159428`, -0.22381847645779898`], 
                Complex[3.0689961602536635`, -1.5783554980412648`]}, 2 -> {
                Complex[3.5917500790840515`, 0.02759428790654434], 
                Complex[5.015059785316232, -1.1525229134375576`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.099999999999998`, -6.0803953498807255`}],
            RowBox[{"{", 
              RowBox[{"26.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9079713045159428`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22381847645779898`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0689961602536635`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5783554980412648`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5917500790840515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02759428790654434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.015059785316232`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1525229134375576`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.099999999999998`, "A", 
             Association[1 -> {
                Complex[1.9079713045159428`, -0.22381847645779898`], 
                Complex[3.0689961602536635`, -1.5783554980412648`]}, 2 -> {
                Complex[3.5917500790840515`, 0.02759428790654434], 
                Complex[5.015059785316232, -1.1525229134375576`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.091941217311784}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.2, "A", 
             Association[1 -> {
                Complex[1.9174784699871426`, -0.22309291692935715`], 
                Complex[3.0798552314489034`, -1.5763682904678329`]}, 2 -> {
                Complex[3.583308359957026, 0.02812128309705336], 
                Complex[5.005499610747706, -1.1521425692773901`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.2, -6.102620348100833}],
            RowBox[{"{", 
              RowBox[{"26.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9174784699871426`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22309291692935715`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0798552314489034`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5763682904678329`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.583308359957026`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.02812128309705336`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"5.005499610747706`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1521425692773901`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.2, "A", 
             Association[1 -> {
                Complex[1.9174784699871426`, -0.22309291692935715`], 
                Complex[3.0798552314489034`, -1.5763682904678329`]}, 2 -> {
                Complex[3.583308359957026, 0.02812128309705336], 
                Complex[5.005499610747706, -1.1521425692773901`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.114926491086043}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.927013515572947, -0.22239885565995451`], 
                Complex[3.0907579920802752`, -1.57441562755638]}, 2 -> {
                Complex[3.5748328921336294`, 0.02866446296210389], 
                Complex[4.99589327476625, -1.151746964778438]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.299999999999997`, -6.126108982416845}],
            RowBox[{"{", 
              RowBox[{"26.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.927013515572947`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22239885565995451`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.0907579920802752`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.57441562755638`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5748328921336294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.02866446296210389`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.99589327476625`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.151746964778438`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.299999999999997`, "A", 
             Association[1 -> {
                Complex[1.927013515572947, -0.22239885565995451`], 
                Complex[3.0907579920802752`, -1.57441562755638]}, 2 -> {
                Complex[3.5748328921336294`, 0.02866446296210389], 
                Complex[4.99589327476625, -1.151746964778438]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.138851997322265}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.9365783436386594`, -0.22173678013483558`], 
                Complex[3.1017066390111165`, -1.572498010615533]}, 2 -> {
                Complex[3.566321815756732, 0.029224600034819154`], 
                Complex[4.986238567027153, -1.1513352953732716`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.399999999999995`, -6.150298223325576}],
            RowBox[{"{", 
              RowBox[{"26.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9365783436386594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22173678013483558`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1017066390111165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.572498010615533`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.566321815756732`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029224600034819154`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.986238567027153`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1513352953732716`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.399999999999995`, "A", 
             Association[1 -> {
                Complex[1.9365783436386594`, -0.22173678013483558`], 
                Complex[3.1017066390111165`, -1.572498010615533]}, 2 -> {
                Complex[3.566321815756732, 0.029224600034819154`], 
                Complex[4.986238567027153, -1.1513352953732716`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.163033709672638}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.9461749120921603`, -0.22110723592124693`], 
                Complex[3.112703441753819, -1.5706160035957246`]}, 2 -> {
                Complex[3.557773215405521, 0.029802517604874564`], 
                Complex[4.976533205571878, -1.1509067011120162`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.499999999999996`, -6.1743755375733995`}],
            RowBox[{"{", 
              RowBox[{"26.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9461749120921603`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22110723592124693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.112703441753819`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5706160035957246`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.557773215405521`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.029802517604874564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.976533205571878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1509067011120162`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.499999999999996`, "A", 
             Association[1 -> {
                Complex[1.9461749120921603`, -0.22110723592124693`], 
                Complex[3.112703441753819, -1.5706160035957246`]}, 2 -> {
                Complex[3.557773215405521, 0.029802517604874564`], 
                Complex[4.976533205571878, -1.1509067011120162`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.186514414615617}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.9558052382062334`, -0.22051083068468325`], 
                Complex[3.123750747268464, -1.5687702376348136`]}, 2 -> {
                Complex[3.5491851162499515`, 0.030399093979211273`], 
                Complex[4.966774831981249, -1.1504602618808104`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.599999999999998`, -6.197227484328735}],
            RowBox[{"{", 
              RowBox[{"26.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9558052382062334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22051083068468325`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.123750747268464`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5687702376348136`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5491851162499515`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.030399093979211273`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.966774831981249`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1504602618808104`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.599999999999998`, "A", 
             Association[1 -> {
                Complex[1.9558052382062334`, -0.22051083068468325`], 
                Complex[3.123750747268464, -1.5687702376348136`]}, 2 -> {
                Complex[3.5491851162499515`, 0.030399093979211273`], 
                Complex[4.966774831981249, -1.1504602618808104`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.208035909969014}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.965471402661748, -0.21994823865092936`], 
                Complex[3.1348509850602824`, -1.56696141611226]}, 2 -> {
                Complex[3.540555479985998, 0.031015267178413904`], 
                Complex[4.956961006232221, -1.149994992121425]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.699999999999996`, -6.217438849910937}],
            RowBox[{"{", 
              RowBox[{"26.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.965471402661748`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21994823865092936`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1348509850602824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56696141611226`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.540555479985998`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031015267178413904`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.956961006232221`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149994992121425`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.699999999999996`, "A", 
             Association[1 -> {
                Complex[1.965471402661748, -0.21994823865092936`], 
                Complex[3.1348509850602824`, -1.56696141611226]}, 2 -> {
                Complex[3.540555479985998, 0.031015267178413904`], 
                Complex[4.956961006232221, -1.149994992121425]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.226090224358992}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.9751755538269593`, -0.21942020556585135`], 
                Complex[3.1460066725980353`, -1.5651903202724227`]}, 2 -> {
                Complex[3.531882200536309, 0.031652040121196476`], 
                Complex[4.947089201235956, -1.149509834990993]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.799999999999997`, -6.233402166666104}],
            RowBox[{"{", 
              RowBox[{"26.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9751755538269593`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21942020556585135`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.1460066725980353`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5651903202724227`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.531882200536309`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.031652040121196476`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.947089201235956`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.149509834990993`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.799999999999997`, "A", 
             Association[1 -> {
                Complex[1.9751755538269593`, -0.21942020556585135`], 
                Complex[3.1460066725980353`, -1.5651903202724227`]}, 2 -> {
                Complex[3.531882200536309, 0.031652040121196476`], 
                Complex[4.947089201235956, -1.149509834990993]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.239106544421606}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {26.9, "A", 
             Association[1 -> {
                Complex[1.984919912288591, -0.2189275542121152], 
                Complex[3.157220421076432, -1.563457815486074]}, 2 -> {
                Complex[3.5231630995005294`, 0.03231048635665899], 
                Complex[4.937156797033987, -1.1490036558923022`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{26.9, -6.2435853552228116`}],
            RowBox[{"{", 
              RowBox[{"26.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.984919912288591`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2189275542121152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.157220421076432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.563457815486074`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5231630995005294`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03231048635665899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.937156797033987`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1490036558923022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {26.9, "A", 
             Association[1 -> {
                Complex[1.984919912288591, -0.2189275542121152], 
                Complex[3.157220421076432, -1.563457815486074]}, 2 -> {
                Complex[3.5231630995005294`, 0.03231048635665899], 
                Complex[4.937156797033987, -1.1490036558923022`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27., -6.245784651828904}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27., "A", 
             Association[1 -> {
                Complex[1.9947067756505623`, -0.21847119055042036`], 
                Complex[3.168494941546649, -1.561764858229167]}, 2 -> {
                Complex[3.5143959213393177`, 0.03299175641234993], 
                Complex[4.927161074628285, -1.1484752352951793`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27., -6.246921439937249}],
            RowBox[{"{", 
              RowBox[{"27.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1.9947067756505623`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21847119055042036`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.168494941546649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.561764858229167`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.5143959213393177`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03299175641234993`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.927161074628285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1484752352951793`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27., "A", 
             Association[1 -> {
                Complex[1.9947067756505623`, -0.21847119055042036`], 
                Complex[3.168494941546649, -1.561764858229167]}, 2 -> {
                Complex[3.5143959213393177`, 0.03299175641234993], 
                Complex[4.927161074628285, -1.1484752352951793`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.245472095625256}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.1, "A", 
             Association[1 -> {
                Complex[2.004538523616137, -0.21805211056251306`], 
                Complex[3.179833051439644, -1.5601125038693653`]}, 2 -> {
                Complex[3.505578328276208, 0.03369708483581626], 
                Complex[4.917099209420432, -1.1479232607580627`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.1, -6.243152314646189}],
            RowBox[{"{", 
              RowBox[{"27.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.004538523616137`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21805211056251306`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.179833051439644`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5601125038693653`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.505578328276208`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03369708483581626`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.917099209420432`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1479232607580627`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.1, "A", 
             Association[1 -> {
                Complex[2.004538523616137, -0.21805211056251306`], 
                Complex[3.179833051439644, -1.5601125038693653`]}, 2 -> {
                Complex[3.505578328276208, 0.03369708483581626], 
                Complex[4.917099209420432, -1.1479232607580627`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.238383365820953}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.2, "A", 
             Association[1 -> {
                Complex[2.014417623368864, -0.21767140788446343`], 
                Complex[3.191237681507362, -1.5585019153641586`]}, 2 -> {
                Complex[3.4967078949018573`, 0.03442779801852968], 
                Complex[4.9069682642347, -1.147346318045541]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.2, -6.232915188069872}],
            RowBox[{"{", 
              RowBox[{"27.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.014417623368864`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21767140788446343`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.191237681507362`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5585019153641586`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4967078949018573`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03442779801852968`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.9069682642347`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.147346318045541`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.2, "A", 
             Association[1 -> {
                Complex[2.014417623368864, -0.21767140788446343`], 
                Complex[3.191237681507362, -1.5585019153641586`]}, 2 -> {
                Complex[3.4967078949018573`, 0.03442779801852968], 
                Complex[4.9069682642347, -1.147346318045541]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.225515765939542}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.0243466352667068`, -0.21733028233169743`], 
                Complex[3.2027118832068138`, -1.556934372989885]}, 2 -> {
                Complex[3.4877821024662152`, 0.035185322904060734`], 
                Complex[4.896765181899932, -1.1467428812221832`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.299999999999997`, -6.217511049077753}],
            RowBox[{"{", 
              RowBox[{"27.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0243466352667068`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21733028233169743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2027118832068138`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.556934372989885`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4877821024662152`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.035185322904060734`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.896765181899932`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1467428812221832`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.0243466352667068`, -0.21733028233169743`], 
                Complex[3.2027118832068138`, -1.556934372989885]}, 2 -> {
                Complex[3.4877821024662152`, 0.035185322904060734`], 
                Complex[4.896765181899932, -1.1467428812221832`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.208318966107456}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.4, "A", 
             Association[1 -> {
                Complex[2.034328218862186, -0.2170300494324249], 
                Complex[3.2142588365513363`, -1.5554112852390447`]}, 2 -> {
                Complex[3.478798332845711, 0.03597119669747849], 
                Complex[4.886486777365878, -1.1461113015849471`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.4, -6.198509561484616}],
            RowBox[{"{", 
              RowBox[{"27.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.034328218862186`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2170300494324249`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2142588365513363`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5554112852390447`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.478798332845711`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03597119669747849`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.886486777365878`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1461113015849471`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.4, "A", 
             Association[1 -> {
                Complex[2.034328218862186, -0.2170300494324249], 
                Complex[3.2142588365513363`, -1.5554112852390447`]}, 2 -> {
                Complex[3.478798332845711, 0.03597119669747849], 
                Complex[4.886486777365878, -1.1461113015849471`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.18831841354781}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.499999999999993`, "A", 
             Association[1 -> {
                Complex[2.0443651392587743`, -0.2167721511036576], 
                Complex[3.225881858451649, -1.5539342010442934`]}, 2 -> {
                Complex[3.469753862175173, 0.036787077710537186`], 
                Complex[4.876129729331248, -1.1454497952754266`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.499999999999993`, -6.177403537287092}],
            RowBox[{"{", 
              RowBox[{"27.499999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0443651392587743`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2167721511036576`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.225881858451649`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5539342010442934`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.469753862175173`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.036787077710537186`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.876129729331248`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1454497952754266`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.499999999999993`, "A", 
             Association[1 -> {
                Complex[2.0443651392587743`, -0.2167721511036576], 
                Complex[3.225881858451649, -1.5539342010442934`]}, 2 -> {
                Complex[3.469753862175173, 0.036787077710537186`], 
                Complex[4.876129729331248, -1.1454497952754266`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.166854055005772}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.054460273810074, -0.2165581676245985], 
                Complex[3.2375844115665666`, -1.5525048235121883`]}, 2 -> {
                Complex[3.460645854137856, 0.03763475749771081], 
                Complex[4.8656905713635386`, -1.1447564293886006`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.599999999999994`, -6.155419143120504}],
            RowBox[{"{", 
              RowBox[{"27.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.054460273810074`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2165581676245985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2375844115665666`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5525048235121883`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.460645854137856`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03763475749771081`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.8656905713635386`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1447564293886006`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.054460273810074, -0.2165581676245985], 
                Complex[3.2375844115665666`, -1.5525048235121883`]}, 2 -> {
                Complex[3.460645854137856, 0.03763475749771081], 
                Complex[4.8656905713635386`, -1.1447564293886006`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.14497120165936}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.0646166191629156`, -0.21638983108607387`], 
                Complex[3.2493701136786943`, -1.5511250253784847`]}, 2 -> {
                Complex[3.4514713529124292`, 0.03851617446207811], 
                Complex[4.855165682495277, -1.144029106365958]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.699999999999996`, -6.133467661278743}],
            RowBox[{"{", 
              RowBox[{"27.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0646166191629156`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21638983108607387`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2493701136786943`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5511250253784847`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4514713529124292`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.03851617446207811`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.855165682495277`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.144029106365958`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.0646166191629156`, -0.21638983108607387`], 
                Complex[3.2493701136786943`, -1.5511250253784847`]}, 2 -> {
                Complex[3.4514713529124292`, 0.03851617446207811], 
                Complex[4.855165682495277, -1.144029106365958]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.1234191614875995`}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.0748372986380015`, -0.2162690405227275], 
                Complex[3.261242747603761, -1.5497968664306097`]}, 2 -> {
                Complex[3.442227275783197, 0.03943342913804209], 
                Complex[4.844551277287891, -1.1432655464271397`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.799999999999997`, -6.112177851958151}],
            RowBox[{"{", 
              RowBox[{"27.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0748372986380015`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2162690405227275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.261242747603761`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5497968664306097`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.442227275783197`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.03943342913804209`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.844551277287891`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1432655464271397`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.0748372986380015`, -0.2162690405227275], 
                Complex[3.261242747603761, -1.5497968664306097`]}, 2 -> {
                Complex[3.442227275783197, 0.03943342913804209], 
                Complex[4.844551277287891, -1.1432655464271397`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.102700153732991}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.9, "A", 
             Association[1 -> {
                Complex[2.0851255699314044`, -0.21619787896744103`], 
                Complex[3.2732062716325756`, -1.5485226131825367`]}, 2 -> {
                Complex[3.4329104054302233`, 0.04038880139063529], 
                Complex[4.833843395364207, -1.142463267754563]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.9, -6.091956808108058}],
            RowBox[{"{", 
              RowBox[{"27.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0851255699314044`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21619787896744103`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2732062716325756`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5485226131825367`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4329104054302233`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04038880139063529`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.833843395364207`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.142463267754563`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.9, "A", 
             Association[1 -> {
                Complex[2.0851255699314044`, -0.21619787896744103`], 
                Complex[3.2732062716325756`, -1.5485226131825367`]}, 2 -> {
                Complex[3.4329104054302233`, 0.04038880139063529], 
                Complex[4.833843395364207, -1.142463267754563]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.083129814026744}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {27.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.0954848331061537`, -0.21617863270584692`], 
                Complex[3.2852648304909695`, -1.5473047611339121`]}, 2 -> {
                Complex[3.423517381930075, 0.04138476980950441], 
                Complex[4.823037890424123, -1.141619564099015]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{27.999999999999996`, -6.073050651344367}],
            RowBox[{"{", 
              RowBox[{"27.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.0954848331061537`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21617863270584692`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.2852648304909695`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5473047611339121`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.423517381930075`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04138476980950441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.823037890424123`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.141619564099015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {27.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.0954848331061537`, -0.21617863270584692`], 
                Complex[3.2852648304909695`, -1.5473047611339121`]}, 2 -> {
                Complex[3.423517381930075, 0.04138476980950441], 
                Complex[4.823037890424123, -1.141619564099015]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.064891160614043}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.1059186388242215`, -0.21621381305374038`], 
                Complex[3.297422766784158, -1.5461460599999757`]}, 2 -> {
                Complex[3.4140446945168277`, 0.042424033620649226`], 
                Complex[4.812130418776984, -1.1407314794193448`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.099999999999998`, -6.055594178214522}],
            RowBox[{"{", 
              RowBox[{"28.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1059186388242215`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21621381305374038`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.297422766784158`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5461460599999757`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4140446945168277`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.042424033620649226`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.812130418776984`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1407314794193448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.1059186388242215`, -0.21621381305374038`], 
                Complex[3.297422766784158, -1.5461460599999757`]}, 2 -> {
                Complex[3.4140446945168277`, 0.042424033620649226`], 
                Complex[4.812130418776984, -1.1407314794193448`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.048076617050576}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.2, "A", 
             Association[1 -> {
                Complex[2.116430696743796, -0.21630618103294583`], 
                Complex[3.3096846328660456`, -1.545049542363364]}, 2 -> {
                Complex[3.4044886731783923`, 0.043509537491681564`], 
                Complex[4.801116427450052, -1.1397957791050333`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.2, -6.039647772940703}],
            RowBox[{"{", 
              RowBox[{"28.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.116430696743796`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21630618103294583`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3096846328660456`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545049542363364`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.4044886731783923`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.043509537491681564`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.801116427450052`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1397957791050333`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.2, "A", 
             Association[1 -> {
                Complex[2.116430696743796, -0.21630618103294583`], 
                Complex[3.3096846328660456`, -1.545049542363364]}, 2 -> {
                Complex[3.4044886731783923`, 0.043509537491681564`], 
                Complex[4.801116427450052, -1.1397957791050333`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.03271849076245}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.3, "A", 
             Association[1 -> {
                Complex[2.127024883972908, -0.21645877538292152`], 
                Complex[3.3220552030387194`, -1.5440185562746338`]}, 2 -> {
                Complex[3.3948454801970804`, 0.044644499668114825`], 
                Complex[4.78999114196779, -1.1388089172545464`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.3, -6.025223445823083}],
            RowBox[{"{", 
              RowBox[{"28.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.127024883972908`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21645877538292152`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3220552030387194`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5440185562746338`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3948454801970804`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.044644499668114825`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.78999114196779`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1388089172545464`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.3, "A", 
             Association[1 -> {
                Complex[2.127024883972908, -0.21645877538292152`], 
                Complex[3.3220552030387194`, -1.5440185562746338`]}, 2 -> {
                Complex[3.3948454801970804`, 0.044644499668114825`], 
                Complex[4.78999114196779, -1.1388089172545464`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.018810193348809}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.399999999999995`, "A", 
             Association[1 -> {
                Complex[2.137705253425444, -0.21667494441768215`], 
                Complex[3.3345394859397897`, -1.5430568024175473`]}, 2 -> {
                Complex[3.3851111017883304`, 0.045832443950466685`], 
                Complex[4.778749553944276, -1.1377669993932331`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.399999999999995`, -6.012302638038501}],
            RowBox[{"{", 
              RowBox[{"28.399999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.137705253425444`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21667494441768215`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3345394859397897`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5430568024175473`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3851111017883304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.045832443950466685`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.778749553944276`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1377669993932331`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.399999999999995`, "A", 
             Association[1 -> {
                Complex[2.137705253425444, -0.21667494441768215`], 
                Complex[3.3345394859397897`, -1.5430568024175473`]}, 2 -> {
                Complex[3.3851111017883304`, 0.045832443950466685`], 
                Complex[4.778749553944276, -1.1377669993932331`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.006320648020628}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.499999999999996`, "A", 
             Association[1 -> {
                Complex[2.1484760418658873`, -0.21695838232209172`], 
                Complex[3.347142736911111, -1.54216837655994]}, 2 -> {
                Complex[3.3752813400511936`, 0.04707723610641603], 
                Complex[4.767386408695089, -1.1366657399097988`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.499999999999996`, -6.000848158766205}],
            RowBox[{"{", 
              RowBox[{"28.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1484760418658873`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21695838232209172`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.347142736911111`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54216837655994`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3752813400511936`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.04707723610641603`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.767386408695089`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1366657399097988`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.499999999999996`, "A", 
             Association[1 -> {
                Complex[2.1484760418658873`, -0.21695838232209172`], 
                Complex[3.347142736911111, -1.54216837655994]}, 2 -> {
                Complex[3.3752813400511936`, 0.04707723610641603], 
                Complex[4.767386408695089, -1.1366657399097988`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -5.995203906971244}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.15934167735015, -0.21731317057992383`], 
                Complex[3.359870470056671, -1.5413578181336938`]}, 2 -> {
                Complex[3.365351805523236, 0.04838312541060397], 
                Complex[4.755896193160949, -1.1355004133676159`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.599999999999998`, -5.99081207698479}],
            RowBox[{"{", 
              RowBox[{"28.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.15934167735015`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21731317057992383`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.359870470056671`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5413578181336938`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.365351805523236`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.04838312541060397`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.755896193160949`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1355004133676159`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.15934167735015, -0.21731317057992383`], 
                Complex[3.359870470056671, -1.5413578181336938`]}, 2 -> {
                Complex[3.365351805523236, 0.04838312541060397], 
                Complex[4.755896193160949, -1.1355004133676159`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -5.985405485592725}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.170306785665302, -0.21774382534019746`], 
                Complex[3.3727284695824946`, -1.5406301659307429`]}, 2 -> {
                Complex[3.3553179107369844`, 0.049754792118764775`], 
                Complex[4.744273124550122, -1.1342657987037832`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.699999999999996`, -5.982140876029164}],
            RowBox[{"{", 
              RowBox[{"28.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.170306785665302`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.21774382534019746`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3727284695824946`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5406301659307429`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3553179107369844`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.049754792118764775`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.744273124550122`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1342657987037832`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.170306785665302, -0.21774382534019746`], 
                Complex[3.3727284695824946`, -1.5406301659307429`]}, 2 -> {
                Complex[3.3553179107369844`, 0.049754792118764775`], 
                Complex[4.744273124550122, -1.1342657987037832`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -5.976866478996161}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.799999999999994`, "A", 
             Association[1 -> {
                Complex[2.181376195232895, -0.2182553516597405], 
                Complex[3.3857227998582564`, -1.539991022068634]}, 2 -> {
                Complex[3.345174865313174, 0.0511974018142957], 
                Complex[4.7325111402598825`, -1.1329561151622776`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.799999999999994`, -5.9747787758839594`}],
            RowBox[{"{", 
              RowBox[{"28.799999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.181376195232895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2182553516597405`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.3857227998582564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.539991022068634`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.345174865313174`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0511974018142957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.7325111402598825`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1329561151622776`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.799999999999994`, "A", 
             Association[1 -> {
                Complex[2.181376195232895, -0.2182553516597405], 
                Complex[3.3857227998582564`, -1.539991022068634]}, 2 -> {
                Complex[3.345174865313174, 0.0511974018142957], 
                Complex[4.7325111402598825`, -1.1329561151622776`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -5.9695261934875194`}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.1925549397581063`, -0.21885330570991673`], 
                Complex[3.398859813435927, -1.5394466255711594`]}, 2 -> {
                Complex[3.3349176733086154`, 0.052716667715368405`], 
                Complex[4.720603889841739, -1.1315649486154922`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.899999999999995`, -5.968669836980629}],
            RowBox[{"{", 
              RowBox[{"28.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.1925549397581063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.21885330570991673`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.398859813435927`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5394466255711594`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3349176733086154`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.052716667715368405`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.720603889841739`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1315649486154922`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.1925549397581063`, -0.21885330570991673`], 
                Complex[3.398859813435927, -1.5394466255711594`]}, 2 -> {
                Complex[3.3349176733086154`, 0.052716667715368405`], 
                Complex[4.720603889841739, -1.1315649486154922`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -5.963323789470528}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {28.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.2038482576658165`, -0.2195438662043097], 
                Complex[3.4121461559885473`, -1.5390039371286066`]}, 2 -> {
                Complex[3.3245411337774544`, 0.05431892219952697], 
                Complex[4.70854473004717, -1.130085166709498]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{28.999999999999996`, -5.963759257410014}],
            RowBox[{"{", 
              RowBox[{"28.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2038482576658165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2195438662043097`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4121461559885473`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5390039371286066`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3245411337774544`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05431892219952697`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.70854473004717`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.130085166709498`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {28.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.2038482576658165`, -0.2195438662043097], 
                Complex[3.4121461559885473`, -1.5390039371286066`]}, 2 -> {
                Complex[3.3245411337774544`, 0.05431892219952697], 
                Complex[4.70854473004717, -1.130085166709498]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -5.958199269933873}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.2152615870464745`, -0.2203339164903331], 
                Complex[3.4255887667699536`, -1.538670736847748]}, 2 -> {
                Complex[3.314039845823023, 0.05601119898888117], 
                Complex[4.696326724353138, -1.12850882102276]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.099999999999998`, -5.959994138564444}],
            RowBox[{"{", 
              RowBox[{"29.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2152615870464745`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2203339164903331`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4255887667699536`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.538670736847748`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.314039845823023`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.05601119898888117`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.696326724353138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.12850882102276`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.2152615870464745`, -0.2203339164903331], 
                Complex[3.4255887667699536`, -1.538670736847748]}, 2 -> {
                Complex[3.314039845823023, 0.05601119898888117], 
                Complex[4.696326724353138, -1.12850882102276]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -5.954094039125011}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.2, "A", 
             Association[1 -> {
                Complex[2.2268005544144556`, -0.22123113894674887`], 
                Complex[3.4391948727143977`, -1.5384557370705048`]}, 2 -> {
                Complex[3.3034082198375003`, 0.05780132763801396], 
                Complex[4.683942648848311, -1.1268270341592392`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.2, -5.957323902416937}],
            RowBox[{"{", 
              RowBox[{"29.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2268005544144556`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.22123113894674887`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4391948727143977`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5384557370705048`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.3034082198375003`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.05780132763801396`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.683942648848311`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1268270341592392`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.2, "A", 
             Association[1 -> {
                Complex[2.2268005544144556`, -0.22123113894674887`], 
                Complex[3.4391948727143977`, -1.5384557370705048`]}, 2 -> {
                Complex[3.3034082198375003`, 0.05780132763801396], 
                Complex[4.683942648848311, -1.1268270341592392`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -5.950951182889128}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.23847095502768, -0.2222441235311438], 
                Complex[3.452971973654928, -1.5383687126232317`]}, 2 -> {
                Complex[3.292640497180628, 0.059698042168788046`], 
                Complex[4.671385007001143, -1.1250298694138172`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.299999999999997`, -5.955700482391617}],
            RowBox[{"{", 
              RowBox[{"29.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.23847095502768`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2222441235311438`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.452971973654928`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5383687126232317`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.292640497180628`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.059698042168788046`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.671385007001143`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1250298694138172`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.23847095502768, -0.2222441235311438], 
                Complex[3.452971973654928, -1.5383687126232317`]}, 2 -> {
                Complex[3.292640497180628, 0.059698042168788046`], 
                Complex[4.671385007001143, -1.1250298694138172`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -5.94871557379185}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.4, "A", 
             Association[1 -> {
                Complex[2.250278721787946, -0.22338249250843553`], 
                Complex[3.466927815290494, -1.5384206511375549`]}, 2 -> {
                Complex[3.2817307812779952`, 0.061711105883242925`], 
                Complex[4.658646056679823, -1.1231061803689852`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.4, -5.955078368973664}],
            RowBox[{"{", 
              RowBox[{"29.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.250278721787946`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22338249250843553`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.466927815290494`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5384206511375549`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2817307812779952`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.061711105883242925`", " ", "\[ImaginaryI]"}]}],
                     ",", 
                    RowBox[{
                    RowBox[{"4.658646056679823`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1231061803689852`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.4, "A", 
             Association[1 -> {
                Complex[2.250278721787946, -0.22338249250843553`], 
                Complex[3.466927815290494, -1.5384206511375549`]}, 2 -> {
                Complex[3.2817307812779952`, 0.061711105883242925`], 
                Complex[4.658646056679823, -1.1231061803689852`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -5.947333872549308}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.5, "A", 
             Association[1 -> {
                Complex[2.2622298787838817`, -0.2246570435317342], 
                Complex[3.4810703454089253`, -1.5386239263253452`]}, 2 -> {
                Complex[3.270673084076976, 0.06385145452602974], 
                Complex[4.645717853916905, -1.1210434375401022`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.5, -5.9554145640087075`}],
            RowBox[{"{", 
              RowBox[{"29.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2622298787838817`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2246570435317342`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.4810703454089253`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5386239263253452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.270673084076976`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.06385145452602974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.645717853916905`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1210434375401022`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.5, "A", 
             Association[1 -> {
                Complex[2.2622298787838817`, -0.2246570435317342], 
                Complex[3.4810703454089253`, -1.5386239263253452`]}, 2 -> {
                Complex[3.270673084076976, 0.06385145452602974], 
                Complex[4.645717853916905, -1.1210434375401022`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -5.946754477109811}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.274330474286138, -0.22607991328743204`], 
                Complex[3.49540764739327, -1.538992497237254]}, 2 -> {
                Complex[3.2594613930506555`, 0.06613136000835836], 
                Complex[4.6325923193910725`, -1.1188275290397074`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.599999999999998`, -5.95666847948443}],
            RowBox[{"{", 
              RowBox[{"29.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.274330474286138`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.22607991328743204`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.49540764739327`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.538992497237254`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2594613930506555`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06613136000835836`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.6325923193910725`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.1188275290397074`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.274330474286138, -0.22607991328743204`], 
                Complex[3.49540764739327, -1.538992497237254]}, 2 -> {
                Complex[3.2594613930506555`, 0.06613136000835836], 
                Complex[4.6325923193910725`, -1.1188275290397074`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -5.946927458449443}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.2865864863773204`, -0.2276647637711871], 
                Complex[3.5099478431009334`, -1.5395421364907365`]}, 2 -> {
                Complex[3.2480897655672782`, 0.06856461676025145], 
                Complex[4.619261335536663, -1.1164425322748186`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.699999999999996`, -5.958801804442413}],
            RowBox[{"{", 
              RowBox[{"29.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2865864863773204`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2276647637711871`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5099478431009334`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5395421364907365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2480897655672782`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.06856461676025145`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.619261335536663`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1164425322748186`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.2865864863773204`, -0.2276647637711871], 
                Complex[3.5099478431009334`, -1.5395421364907365`]}, 2 -> {
                Complex[3.2480897655672782`, 0.06856461676025145], 
                Complex[4.619261335536663, -1.1164425322748186`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -5.947804515471551}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.2990036923040837`, -0.2294269927942462], 
                Complex[3.524698954687548, -1.5402906900657316`]}, 2 -> {
                Complex[3.23655245953774, 0.07116675231062944], 
                Complex[4.605716884708899, -1.1138704540789917`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.799999999999997`, -5.961778355531184}],
            RowBox[{"{", 
              RowBox[{"29.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.2990036923040837`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2294269927942462`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.524698954687548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5402906900657316`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.23655245953774`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07116675231062944`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.605716884708899`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1138704540789917`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.2990036923040837`, -0.2294269927942462], 
                Complex[3.524698954687548, -1.5402906900657316`]}, 2 -> {
                Complex[3.23655245953774, 0.07116675231062944], 
                Complex[4.605716884708899, -1.1138704540789917`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -5.949338978844817}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.311587489979285, -0.23138396931833907`], 
                Complex[3.539668711719687, -1.54125837029078]}, 2 -> {
                Complex[3.2248441119132174`, 0.07395526269357484], 
                Complex[4.591951242060749, -1.1110909376562412`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.899999999999995`, -5.965563921253229}],
            RowBox[{"{", 
              RowBox[{"29.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.311587489979285`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.23138396931833907`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.539668711719687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.54125837029078`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.2248441119132174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.07395526269357484`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.591951242060749`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1110909376562412`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.311587489979285, -0.23138396931833907`], 
                Complex[3.539668711719687, -1.54125837029078]}, 2 -> {
                Complex[3.2248441119132174`, 0.07395526269357484], 
                Complex[4.591951242060749, -1.1110909376562412`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -5.951485894151492}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {29.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.324342656755631, -0.2335552923600304], 
                Complex[3.554864285859265, -1.5424680817046263`]}, 2 -> {
                Complex[3.212959979911501, 0.07694987142173919], 
                Complex[4.577957240848535, -1.1080809366516995`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{29.999999999999996`, -5.970126106297937}],
            RowBox[{"{", 
              RowBox[{"29.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.324342656755631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.2335552923600304`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.554864285859265`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5424680817046263`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.212959979911501`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.07694987142173919`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.577957240848535`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1080809366516995`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {29.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.324342656755631, -0.2335552923600304], 
                Complex[3.554864285859265, -1.5424680817046263`]}, 2 -> {
                Complex[3.212959979911501, 0.07694987142173919], 
                Complex[4.577957240848535, -1.1080809366516995`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -5.95420221749358}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.3372730266129884`, -0.2359630690132302], 
                Complex[3.5702919304393554`, -1.543945776013632]}, 2 -> {
                Complex[3.20089626382986, 0.0801728075757009], 
                Complex[4.563728632846572, -1.1048143601285867`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.099999999999998`, -5.975434179900576}],
            RowBox[{"{", 
              RowBox[{"30.099999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3372730266129884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2359630690132302`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5702919304393554`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.543945776013632`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.20089626382986`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.0801728075757009`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.563728632846572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1048143601285867`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.099999999999998`, "A", 
             Association[1 -> {
                Complex[2.3372730266129884`, -0.2359630690132302], 
                Complex[3.5702919304393554`, -1.543945776013632]}, 2 -> {
                Complex[3.20089626382986, 0.0801728075757009], 
                Complex[4.563728632846572, -1.1048143601285867`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -5.957447160720965}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.3503810623577226`, -0.23863220192231419`], 
                Complex[3.5859564964599824`, -1.545720826549354]}, 2 -> {
                Complex[3.18865053484601, 0.08364909334179278], 
                Complex[4.549260572342168, -1.1012616980470777`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.199999999999996`, -5.98145893053187}],
            RowBox[{"{", 
              RowBox[{"30.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3503810623577226`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.23863220192231419`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.5859564964599824`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.545720826549354`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.18865053484601`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08364909334179278`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.549260572342168`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.1012616980470777`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.3503810623577226`, -0.23863220192231419`], 
                Complex[3.5859564964599824`, -1.545720826549354]}, 2 -> {
                Complex[3.18865053484601, 0.08364909334179278], 
                Complex[4.549260572342168, -1.1012616980470777`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -5.961182727125078}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.3636672947096224`, -0.24159066834690415`], 
                Complex[3.6018607902943125`, -1.547826403307316]}, 2 -> {
                Complex[3.176222295931689, 0.08740682313953917], 
                Complex[4.534550258420687, -1.0973896461639485`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.299999999999997`, -5.988172528138998}],
            RowBox[{"{", 
              RowBox[{"30.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3636672947096224`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24159066834690415`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6018607902943125`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.547826403307316`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.176222295931689`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.08740682313953917`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.534550258420687`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0973896461639485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.3636672947096224`, -0.24159066834690415`], 
                Complex[3.6018607902943125`, -1.547826403307316]}, 2 -> {
                Complex[3.176222295931689, 0.08740682313953917], 
                Complex[4.534550258420687, -1.0973896461639485`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -5.965374479017715}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.4, "A", 
             Association[1 -> {
                Complex[2.3771295961517165`, -0.24486976056502352`], 
                Complex[3.6180047326806646`, -1.5502998152929637`]}, 2 -> {
                Complex[3.1636137080034565`, 0.09147740408549974], 
                Complex[4.519597775965093, -1.093160763626926]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.4, -5.995548394449048}],
            RowBox[{"{", 
              RowBox[{"30.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3771295961517165`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24486976056502352`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6180047326806646`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5502998152929637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1636137080034565`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09147740408549974`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.519597775965093`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.093160763626926`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.4, "A", 
             Association[1 -> {
                Complex[2.3771295961517165`, -0.24486976056502352`], 
                Complex[3.6180047326806646`, -1.5502998152929637`]}, 2 -> {
                Complex[3.1636137080034565`, 0.09147740408549974], 
                Complex[4.519597775965093, -1.093160763626926]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -5.969992571267522}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.5, "A", 
             Association[1 -> {
                Complex[2.3907622559358295`, -0.24850423935263424`], 
                Complex[3.634384275397017, -1.5531827657019448`]}, 2 -> {
                Complex[3.1508305149179034`, 0.09589570953158899], 
                Complex[4.504407178973381, -1.0885332177365603`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.5, -6.003561081389463}],
            RowBox[{"{", 
              RowBox[{"30.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.3907622559358295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.24850423935263424`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.634384275397017`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5531827657019448`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1508305149179034`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.09589570953158899`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.504407178973381`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0885332177365603`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.5, "A", 
             Association[1 -> {
                Complex[2.3907622559358295`, -0.24850423935263424`], 
                Complex[3.634384275397017, -1.5531827657019448`]}, 2 -> {
                Complex[3.1508305149179034`, 0.09589570953158899], 
                Complex[4.504407178973381, -1.0885332177365603`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -5.975013061668264}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.404554826889628, -0.25253232740394693`], 
                Complex[3.6509900350811173`, -1.5565214356849029`]}, 2 -> {
                Complex[3.137883196665494, 0.10070007254234226`], 
                Complex[4.488987856730723, -1.083460700125328]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.599999999999998`, -6.012186157395117}],
            RowBox[{"{", 
              RowBox[{"30.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.404554826889628`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.25253232740394693`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6509900350811173`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5565214356849029`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.137883196665494`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.10070007254234226`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.488987856730723`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.083460700125328`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.404554826889628, -0.25253232740394693`], 
                Complex[3.6509900350811173`, -1.5565214356849029`]}, 2 -> {
                Complex[3.137883196665494, 0.10070007254234226`], 
                Complex[4.488987856730723, -1.083460700125328]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -5.980419458037957}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.4184907299124174`, -0.2569954375693104], 
                Complex[3.66780561916792, -1.560366273382241]}, 2 -> {
                Complex[3.124788364875778, 0.1059320141880026], 
                Complex[4.473356207864622, -1.0778926376684699`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.699999999999996`, -6.021400101202558}],
            RowBox[{"{", 
              RowBox[{"30.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4184907299124174`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2569954375693104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.66780561916792`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.560366273382241`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.124788364875778`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1059320141880026`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.473356207864622`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0778926376684699`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.4184907299124174`, -0.2569954375693104], 
                Complex[3.66780561916792, -1.560366273382241]}, 2 -> {
                Complex[3.124788364875778, 0.1059320141880026], 
                Complex[4.473356207864622, -1.0778926376684699`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -5.986204367625939}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.4325456359616355`, -0.26193749411720374`], 
                Complex[3.6848056561525757`, -1.564771318831329]}, 2 -> {
                Complex[3.1115703808320068`, 0.11163556486001101`], 
                Complex[4.4575376100748025`, -1.071774867524016]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.799999999999997`, -6.031180202640658}],
            RowBox[{"{", 
              RowBox[{"30.799999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4325456359616355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.26193749411720374`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.6848056561525757`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.564771318831329`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.1115703808320068`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.11163556486001101`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.4575376100748025`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.071774867524016`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.799999999999997`, "A", 
             Association[1 -> {
                Complex[2.4325456359616355`, -0.26193749411720374`], 
                Complex[3.6848056561525757`, -1.564771318831329]}, 2 -> {
                Complex[3.1115703808320068`, 0.11163556486001101`], 
                Complex[4.4575376100748025`, -1.071774867524016]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -5.992370961419108}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.9, "A", 
             Association[1 -> {
                Complex[2.4466857074528354`, -0.2674036718059935], 
                Complex[3.7019536132591475`, -1.56979285088015]}, 2 -> {
                Complex[3.098263114072366, 0.11785600339463051`], 
                Complex[4.44156860245767, -1.0650509901679486`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.9, -6.041504469887779}],
            RowBox[{"{", 
              RowBox[{"30.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4466857074528354`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2674036718059935`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7019536132591475`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.56979285088015`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.098263114072366`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.11785600339463051`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.44156860245767`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0650509901679486`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.9, "A", 
             Association[1 -> {
                Complex[2.4466857074528354`, -0.2674036718059935], 
                Complex[3.7019536132591475`, -1.56979285088015]}, 2 -> {
                Complex[3.098263114072366, 0.11785600339463051`], 
                Complex[4.44156860245767, -1.0650509901679486`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -5.998933750438886}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {30.999999999999993`, "A", 
             Association[1 -> {
                Complex[2.4608658796691665`, -0.2734383645589258], 
                Complex[3.719199600336585, -1.5754871190552318`]}, 2 -> {
                Complex[3.084911660981808, 0.1246378257982292], 
                Complex[4.425499081603797, -1.0576646374765921`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{30.999999999999993`, -6.052351542660813}],
            RowBox[{"{", 
              RowBox[{"30.999999999999993`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4608658796691665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2734383645589258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.719199600336585`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5754871190552318`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.084911660981808`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1246378257982292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.425499081603797`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0576646374765921`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {30.999999999999993`, "A", 
             Association[1 -> {
                Complex[2.4608658796691665`, -0.2734383645589258], 
                Complex[3.719199600336585, -1.5754871190552318`]}, 2 -> {
                Complex[3.084911660981808, 0.1246378257982292], 
                Complex[4.425499081603797, -1.0576646374765921`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.005917922932756}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.4750284976365355`, -0.28008223230347307`], 
                Complex[3.736478521301466, -1.58190695616248]}, 2 -> {
                Complex[3.071573707918281, 0.1320217921353984], 
                Complex[4.409394150148913, -1.0495628600775766`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.099999999999994`, -6.063700610818933}],
            RowBox[{"{", 
              RowBox[{"31.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4750284976365355`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.28008223230347307`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.736478521301466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.58190695616248`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.071573707918281`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1320217921353984`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.409394150148913`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0495628600775766`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.4750284976365355`, -0.28008223230347307`], 
                Complex[3.736478521301466, -1.58190695616248]}, 2 -> {
                Complex[3.071573707918281, 0.1320217921353984], 
                Complex[4.409394150148913, -1.0495628600775766`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.013356304791173}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.4891027727434665`, -0.2873682998621285], 
                Complex[3.7537091204741744`, -1.5890972039111015`]}, 2 -> {
                Complex[3.0583200745943513`, 0.1400410254670661], 
                Complex[4.393335070431694, -1.040700701679103]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.199999999999996`, -6.075531337896993}],
            RowBox[{"{", 
              RowBox[{"31.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.4891027727434665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.2873682998621285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.7537091204741744`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.5890972039111015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0583200745943513`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.1400410254670661`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.393335070431694`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.040700701679103`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.4891027727434665`, -0.2873682998621285], 
                Complex[3.7537091204741744`, -1.5890972039111015`]}, 2 -> {
                Complex[3.0583200745943513`, 0.1400410254670661], 
                Complex[4.393335070431694, -1.040700701679103]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.021283058370846}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.5030056270697787`, -0.29531732776612113`], 
                Complex[3.770794613325989, -1.5970891666976441`]}, 2 -> {
                Complex[3.0452338697500734`, 0.14871638271009868`], 
                Complex[4.377418633740917, -1.0310467452404806`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.299999999999997`, -6.087823789124525}],
            RowBox[{"{", 
              RowBox[{"31.299999999999997`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5030056270697787`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.29531732776612113`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.770794613325989`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.5970891666976441`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0452338697500734`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.14871638271009868`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.377418633740917`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0310467452404806`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.299999999999997`, "A", 
             Association[1 -> {
                Complex[2.5030056270697787`, -0.29531732776612113`], 
                Complex[3.770794613325989, -1.5970891666976441`]}, 2 -> {
                Complex[3.0452338697500734`, 0.14871638271009868`], 
                Complex[4.377418633740917, -1.0310467452404806`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.0297237482281725`}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.4, "A", 
             Association[1 -> {
                Complex[2.5166444532991594`, -0.3039330313949986], 
                Complex[3.787625571970204, -1.605894733710108]}, 2 -> {
                Complex[3.032407731242035, 0.1580516738214428], 
                Complex[4.361754274818786, -1.0205889908238692`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.4, -6.100558363532632}],
            RowBox[{"{", 
              RowBox[{"31.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5166444532991594`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3039330313949986`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.787625571970204`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.605894733710108`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.032407731242035`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1580516738214428`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.361754274818786`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0205889908238692`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.4, "A", 
             Association[1 -> {
                Complex[2.5166444532991594`, -0.3039330313949986], 
                Complex[3.787625571970204, -1.605894733710108]}, 2 -> {
                Complex[3.032407731242035, 0.1580516738214428], 
                Complex[4.361754274818786, -1.0205889908238692`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.038682488921336}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.499999999999996`, "A", 
             Association[1 -> {
                Complex[2.5299220300509884`, -0.31319809514055186`], 
                Complex[3.8040854242836235`, -1.615501270452578]}, 2 -> {
                Complex[3.0199389107132126`, 0.16802967600526134`], 
                Complex[4.34645857273412, -1.0093399640268068`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.499999999999996`, -6.113715729800701}],
            RowBox[{"{", 
              RowBox[{"31.499999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5299220300509884`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.31319809514055186`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8040854242836235`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.615501270452578`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.0199389107132126`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.16802967600526134`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.34645857273412`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.0093399640268068`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.499999999999996`, "A", 
             Association[1 -> {
                Complex[2.5299220300509884`, -0.31319809514055186`], 
                Complex[3.8040854242836235`, -1.615501270452578]}, 2 -> {
                Complex[3.0199389107132126`, 0.16802967600526134`], 
                Complex[4.34645857273412, -1.0093399640268068`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.048128321915701}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.5427432708771702`, -0.3230721172560292], 
                Complex[3.8200582761098674`, -1.6258686488669851`]}, 2 -> {
                Complex[3.007922524597889, 0.17861007860412123`], 
                Complex[4.331647428673965, -0.9973396858188015]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.599999999999998`, -6.127276765546234}],
            RowBox[{"{", 
              RowBox[{"31.599999999999998`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5427432708771702`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3230721172560292`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8200582761098674`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6258686488669851`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"3.007922524597889`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.17861007860412123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.331647428673965`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9973396858188015`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.599999999999998`, "A", 
             Association[1 -> {
                Complex[2.5427432708771702`, -0.3230721172560292], 
                Complex[3.8200582761098674`, -1.6258686488669851`]}, 2 -> {
                Complex[3.007922524597889, 0.17861007860412123`], 
                Complex[4.331647428673965, -0.9973396858188015]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.057984069176398}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.7, "A", 
             Association[1 -> {
                Complex[2.5550227978429705`, -0.33349241406049857`], 
                Complex[3.8354379364471782`, -1.6369295948434275`]}, 2 -> {
                Complex[2.996443980542599, 0.1897302873440814], 
                Complex[4.317427040750872, -0.984655324990569]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.7, -6.141222499813174}],
            RowBox[{"{", 
              RowBox[{"31.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5550227978429705`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.33349241406049857`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8354379364471782`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6369295948434275`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.996443980542599`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.1897302873440814`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.317427040750872`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.984655324990569`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.7, "A", 
             Association[1 -> {
                Complex[2.5550227978429705`, -0.33349241406049857`], 
                Complex[3.8354379364471782`, -1.6369295948434275`]}, 2 -> {
                Complex[2.996443980542599, 0.1897302873440814], 
                Complex[4.317427040750872, -0.984655324990569]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.0681208573364245`}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.8, "A", 
             Association[1 -> {
                Complex[2.5666918389490667`, -0.3443779449095298], 
                Complex[3.8501363909766324`, -1.648593781537542]}, 2 -> {
                Complex[2.9855720799859258`, 0.20130934934494918`], 
                Complex[4.303885430470007, -0.971377104797334]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.8, -6.15553405856704}],
            RowBox[{"{", 
              RowBox[{"31.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5666918389490667`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3443779449095298`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8501363909766324`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.648593781537542`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9855720799859258`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.20130934934494918`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.303885430470007`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.971377104797334`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.8, "A", 
             Association[1 -> {
                Complex[2.5666918389490667`, -0.3443779449095298], 
                Complex[3.8501363909766324`, -1.648593781537542]}, 2 -> {
                Complex[2.9855720799859258`, 0.20130934934494918`], 
                Complex[4.303885430470007, -0.971377104797334]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.078360003387103}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.5777029731444694`, -0.35563571212946193`], 
                Complex[3.864089926301709, -1.6607550217891218`]}, 2 -> {
                Complex[2.9753542731474694`, 0.21325435309295854`], 
                Complex[4.291086318485069, -0.9576111105020115]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.899999999999995`, -6.170192613057899}],
            RowBox[{"{", 
              RowBox[{"31.899999999999995`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5777029731444694`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.35563571212946193`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.864089926301709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6607550217891218`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9753542731474694`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.21325435309295854`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.291086318485069`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9576111105020115`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.899999999999995`, "A", 
             Association[1 -> {
                Complex[2.5777029731444694`, -0.35563571212946193`], 
                Complex[3.864089926301709, -1.6607550217891218`]}, 2 -> {
                Complex[2.9753542731474694`, 0.21325435309295854`], 
                Complex[4.291086318485069, -0.9576111105020115]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.08848167572687}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {31.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.588031851130083, -0.3671682712416466], 
                Complex[3.8772617652382886`, -1.6733000146368147`]}, 2 -> {
                Complex[2.965814938226205, 0.22546793870233256`], 
                Complex[4.2790664893039665`, -0.9434705428233618]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{31.999999999999996`, -6.1851793309654735`}],
            RowBox[{"{", 
              RowBox[{"31.999999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.588031851130083`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3671682712416466`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.8772617652382886`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.6733000146368147`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.965814938226205`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.22546793870233256`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2790664893039665`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9434705428233618`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {31.999999999999996`, "A", 
             Association[1 -> {
                Complex[2.588031851130083, -0.3671682712416466], 
                Complex[3.8772617652382886`, -1.6733000146368147`]}, 2 -> {
                Complex[2.965814938226205, 0.22546793870233256`], 
                Complex[4.2790664893039665`, -0.9434705428233618]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.098237938864388}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.5976759196164494`, -0.3788808057418005], 
                Complex[3.889641123048907, -1.6861168153853223`]}, 2 -> {
                Complex[2.9569566571447035`, 0.2378553727309031], 
                Complex[4.267836735050403, -0.9290672478326643]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.099999999999994`, -6.200475330294084}],
            RowBox[{"{", 
              RowBox[{"32.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.5976759196164494`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.3788808057418005`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.889641123048907`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.6861168153853223`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9569566571447035`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2378553727309031`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.267836735050403`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9290672478326643`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.5976759196164494`, -0.3788808057418005], 
                Complex[3.889641123048907, -1.6861168153853223`]}, 2 -> {
                Complex[2.9569566571447035`, 0.2378553727309031], 
                Complex[4.267836735050403, -0.9290672478326643]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.206416363551537}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.606650933262854, -0.3906866010723904], 
                Complex[3.901239519558195, -1.699101588537602]}, 2 -> {
                Complex[2.9487637036120304`, 0.25033002218771455`], 
                Complex[4.257385543344473, -0.9145049639864019]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.199999999999996`, -6.216061636038467}],
            RowBox[{"{", 
              RowBox[{"32.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.606650933262854`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.3906866010723904`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.901239519558195`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.699101588537602`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9487637036120304`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.25033002218771455`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.257385543344473`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9145049639864019`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.606650933262854, -0.3906866010723904], 
                Complex[3.901239519558195, -1.699101588537602]}, 2 -> {
                Complex[2.9487637036120304`, 0.25033002218771455`], 
                Complex[4.257385543344473, -0.9145049639864019]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.221008621690028}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.3, "A", 
             Association[1 -> {
                Complex[2.6149863657999486`, -0.40251041678372024`], 
                Complex[3.912085621903242, -1.7121629626858925`]}, 2 -> {
                Complex[2.9412066320031385`, 0.2628167267283543], 
                Complex[4.247684254548457, -0.8998749672010703]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.3, -6.231919139695372}],
            RowBox[{"{", 
              RowBox[{"32.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6149863657999486`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.40251041678372024`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.912085621903242`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7121629626858925`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9412066320031385`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.2628167267283543`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.247684254548457`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8998749672010703`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.3, "A", 
             Association[1 -> {
                Complex[2.6149863657999486`, -0.40251041678372024`], 
                Complex[3.912085621903242, -1.7121629626858925`]}, 2 -> {
                Complex[2.9412066320031385`, 0.2628167267283543], 
                Complex[4.247684254548457, -0.8998749672010703]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.236280487019719}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.4, "A", 
             Association[1 -> {
                Complex[2.6227207308158538`, -0.41428986426444875`], 
                Complex[3.9222198214979063`, -1.7252240340035678`]}, 2 -> {
                Complex[2.93424695657482, 0.27525317641875774`], 
                Complex[4.2386924847988485`, -0.8852540673280815]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.4, -6.248028561749506}],
            RowBox[{"{", 
              RowBox[{"32.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6227207308158538`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.41428986426444875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9222198214979063`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7252240340035678`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.93424695657482`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.27525317641875774`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2386924847988485`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8852540673280815`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.4, "A", 
             Association[1 -> {
                Complex[2.6227207308158538`, -0.41428986426444875`], 
                Complex[3.9222198214979063`, -1.7252240340035678`]}, 2 -> {
                Complex[2.93424695657482, 0.27525317641875774`], 
                Complex[4.2386924847988485`, -0.8852540673280815]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.252123949662032}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.49999999999999, "A", 
             Association[1 -> {
                Complex[2.629897485254924, -0.42597525546826037`], 
                Complex[3.9316893781660758`, -1.738222515211657]}, 2 -> {
                Complex[2.927841247969024, 0.28758976049421764`], 
                Complex[4.230362981869568, -0.8707044591549228]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.49999999999999, -6.264370417315903}],
            RowBox[{"{", 
              RowBox[{"32.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.629897485254924`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.42597525546826037`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9316893781660758`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.738222515211657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.927841247969024`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.28758976049421764`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.230362981869568`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8707044591549228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.49999999999999, "A", 
             Association[1 -> {
                Complex[2.629897485254924, -0.42597525546826037`], 
                Complex[3.9316893781660758`, -1.738222515211657]}, 2 -> {
                Complex[2.927841247969024, 0.28758976049421764`], 
                Complex[4.230362981869568, -0.8707044591549228]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.268444071035216}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.636561822697944, -0.4375284851167467], 
                Complex[3.9405445393067433`, -1.7511096707348455`]}, 2 -> {
                Complex[2.921944339934747, 0.2997884495937316], 
                Complex[4.222645506003507, -0.856274787217682]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.599999999999994`, -6.280924985173601}],
            RowBox[{"{", 
              RowBox[{"32.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.636561822697944`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4375284851167467`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9405445393067433`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7511096707348455`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.921944339934747`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.2997884495937316`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.222645506003507`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.856274787217682`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.636561822697944, -0.4375284851167467], 
                Complex[3.9405445393067433`, -1.7511096707348455`]}, 2 -> {
                Complex[2.921944339934747, 0.2997884495937316], 
                Complex[4.222645506003507, -0.856274787217682]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.285158844495673}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.6427583897826854`, -0.4489214364481581], 
                Complex[3.948835712532859, -1.7638486148780157`]}, 2 -> {
                Complex[2.9165116129095963`, 0.31182120153934106`], 
                Complex[4.2154896572704255`, -0.842001847593885]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.699999999999996`, -6.297672280477458}],
            RowBox[{"{", 
              RowBox[{"32.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6427583897826854`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.4489214364481581`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.948835712532859`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7638486148780157`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9165116129095963`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.31182120153934106`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.2154896572704255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.842001847593885`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.6427583897826854`, -0.4489214364481581], 
                Complex[3.948835712532859, -1.7638486148780157`]}, 2 -> {
                Complex[2.9165116129095963`, 0.31182120153934106`], 
                Complex[4.2154896572704255`, -0.842001847593885]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.302197987989391}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.8, "A", 
             Association[1 -> {
                Complex[2.648529805818011, -0.4601342612759221], 
                Complex[3.9566115778779483`, -1.7764123973101795`]}, 2 -> {
                Complex[2.911500474407813, 0.323668241424401], 
                Complex[4.208846763357217, -0.8279125023887512]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.8, -6.3145920314842705`}],
            RowBox[{"{", 
              RowBox[{"32.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.648529805818011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4601342612759221`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9566115778779483`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.7764123973101795`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.911500474407813`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.323668241424401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.208846763357217`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8279125023887512`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.8, "A", 
             Association[1 -> {
                Complex[2.648529805818011, -0.4601342612759221], 
                Complex[3.9566115778779483`, -1.7764123973101795`]}, 2 -> {
                Complex[2.911500474407813, 0.323668241424401], 
                Complex[4.208846763357217, -0.8279125023887512]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.319501271034918}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {32.9, "A", 
             Association[1 -> {
                Complex[2.653915808537619, -0.4711537472500261], 
                Complex[3.963917947183657, -1.7887821416602485`]}, 2 -> {
                Complex[2.90687121326868, 0.33531642890390234`], 
                Complex[4.202671020177384, -0.8140255411104018]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{32.9, -6.331663660676509}],
            RowBox[{"{", 
              RowBox[{"32.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.653915808537619`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.4711537472500261`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.963917947183657`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.7887821416602485`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.90687121326868`", "\[VeryThinSpace]"}], "+", 
                    RowBox[{"0.33531642890390234`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.202671020177384`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8140255411104018`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {32.9, "A", 
             Association[1 -> {
                Complex[2.653915808537619, -0.4711537472500261], 
                Complex[3.963917947183657, -1.7887821416602485`]}, 2 -> {
                Complex[2.90687121326868, 0.33531642890390234`], 
                Complex[4.202671020177384, -0.8140255411104018]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33., -6.337016755757702}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33., "A", 
             Association[1 -> {
                Complex[2.6589528500918, -0.48197187877303665`], 
                Complex[3.9707971711833534`, -1.8009453770853803`]}, 2 -> {
                Complex[2.9025874036669044`, 0.3467578191386486], 
                Complex[4.196920084784548, -0.8003533490732543]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33., -6.3488662707090215`}],
            RowBox[{"{", 
              RowBox[{"33.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6589528500918`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.48197187877303665`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9707971711833534`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8009453770853803`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.9025874036669044`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3467578191386486`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.196920084784548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8003533490732543`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33., "A", 
             Association[1 -> {
                Complex[2.6589528500918, -0.48197187877303665`], 
                Complex[3.9707971711833534`, -1.8009453770853803`]}, 2 -> {
                Complex[2.9025874036669044`, 0.3467578191386486], 
                Complex[4.196920084784548, -0.8003533490732543]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.354699159595178}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.6636739953559614`, -0.49258462786579826`], 
                Complex[3.977287922300882, -1.8128946175014522`]}, 2 -> {
                Complex[2.8986160068062667`, 0.3579884536883491], 
                Complex[4.1915552925709445`, -0.7869033281400255]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.099999999999994`, -6.366178635641037}],
            RowBox[{"{", 
              RowBox[{"33.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6636739953559614`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.49258462786579826`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.977287922300882`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8128946175014522`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8986160068062667`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3579884536883491`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1915552925709445`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7869033281400255`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.6636739953559614`, -0.49258462786579826`], 
                Complex[3.977287922300882, -1.8128946175014522`]}, 2 -> {
                Complex[2.8986160068062667`, 0.3579884536883491], 
                Complex[4.1915552925709445`, -0.7869033281400255]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.37250843265049}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.668109009751523, -0.50299097090211], 
                Complex[3.9834252194900266`, -1.8246261926386431`]}, 2 -> {
                Complex[2.8949272831009005`, 0.36900737727295585`], 
                Complex[4.1865416324253255`, -0.7736790656393452]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.199999999999996`, -6.383579197944703}],
            RowBox[{"{", 
              RowBox[{"33.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.668109009751523`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.50299097090211`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.9834252194900266`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"1.8246261926386431`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8949272831009005`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.36900737727295585`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1865416324253255`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7736790656393452`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.668109009751523, -0.50299097090211], 
                Complex[3.9834252194900266`, -1.8246261926386431`]}, 2 -> {
                Complex[2.8949272831009005`, 0.36900737727295585`], 
                Complex[4.1865416324253255`, -0.7736790656393452]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.3904085746978}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.3, "A", 
             Association[1 -> {
                Complex[2.6722845561748567`, -0.5131921073476409], 
                Complex[3.989240598169983, -1.836139309119696]}, 2 -> {
                Complex[2.8914945952485174`, 0.37981585653752775`], 
                Complex[4.1818475767949295`, -0.7606812732613812]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.3, -6.401046071800994}],
            RowBox[{"{", 
              RowBox[{"33.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6722845561748567`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5131921073476409`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.989240598169983`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.836139309119696`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8914945952485174`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.37981585653752775`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1818475767949295`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7606812732613812`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.3, "A", 
             Association[1 -> {
                Complex[2.6722845561748567`, -0.5131921073476409], 
                Complex[3.989240598169983, -1.836139309119696]}, 2 -> {
                Complex[2.8914945952485174`, 0.37981585653752775`], 
                Complex[4.1818475767949295`, -0.7606812732613812]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.408366681073635}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.39999999999999, "A", 
             Association[1 -> {
                Complex[2.67622444669189, -0.5231908494724435], 
                Complex[3.994762358551031, -1.847435309214209]}, 2 -> {
                Complex[2.8882941565379943`, 0.3904167697900055], 
                Complex[4.177444833357386, -0.7479085282781004]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.39999999999999, -6.4185570532015115`}],
            RowBox[{"{", 
              RowBox[{"33.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.67622444669189`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5231908494724435`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"3.994762358551031`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.847435309214209`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8882941565379943`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.3904167697900055`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.177444833357386`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7479085282781004`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.39999999999999, "A", 
             Association[1 -> {
                Complex[2.67622444669189, -0.5231908494724435], 
                Complex[3.994762358551031, -1.847435309214209]}, 2 -> {
                Complex[2.8882941565379943`, 0.3904167697900055], 
                Complex[4.177444833357386, -0.7479085282781004]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.426352190849823}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.49999999999999, "A", 
             Association[1 -> {
                Complex[2.679949913999627, -0.5329911517598123], 
                Complex[4.000015848490728, -1.8585170930917838`]}, 2 -> {
                Complex[2.8853047593900265`, 0.4008141364346624], 
                Complex[4.173308062162179, -0.735357851265334]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.49999999999999, -6.43608963736834}],
            RowBox[{"{", 
              RowBox[{"33.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.679949913999627`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5329911517598123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.000015848490728`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8585170930917838`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8853047593900265`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4008141364346624`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.173308062162179`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.735357851265334`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.49999999999999, "A", 
             Association[1 -> {
                Complex[2.679949913999627, -0.5329911517598123], 
                Complex[4.000015848490728, -1.8585170930917838`]}, 2 -> {
                Complex[2.8853047593900265`, 0.4008141364346624], 
                Complex[4.173308062162179, -0.735357851265334]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.444336306080401}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.683479881251108, -0.5425977517885688], 
                Complex[4.005023753334011, -1.8693886729252434`]}, 2 -> {
                Complex[2.8825075055343556`, 0.41101275787833075`], 
                Complex[4.169414585788292, -0.7230251519753936]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.599999999999994`, -6.453621043980958}],
            RowBox[{"{", 
              RowBox[{"33.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.683479881251108`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5425977517885688`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.005023753334011`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.8693886729252434`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8825075055343556`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.41101275787833075`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.169414585788292`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7230251519753936`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.683479881251108, -0.5425977517885688], 
                Complex[4.005023753334011, -1.8693886729252434`]}, 2 -> {
                Complex[2.8825075055343556`, 0.41101275787833075`], 
                Complex[4.169414585788292, -0.7230251519753936]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.462291552023001}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.6868312180069145`, -0.5520158986267104], 
                Complex[4.009806376364359, -1.880054831501801]}, 2 -> {
                Complex[2.8798855500604437`, 0.42101794594737985`], 
                Complex[4.165744108890901, -0.7109055707023496]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.699999999999996`, -6.471128250657372}],
            RowBox[{"{", 
              RowBox[{"33.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6868312180069145`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5520158986267104`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.009806376364359`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.880054831501801`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8798855500604437`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.42101794594737985`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.165744108890901`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7109055707023496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.6868312180069145`, -0.5520158986267104], 
                Complex[4.009806376364359, -1.880054831501801]}, 2 -> {
                Complex[2.8798855500604437`, 0.42101794594737985`], 
                Complex[4.165744108890901, -0.7109055707023496]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.480191451815838}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.8, "A", 
             Association[1 -> {
                Complex[2.6900189760399855`, -0.5612511491377956], 
                Complex[4.01438190088909, -1.890520862682429]}, 2 -> {
                Complex[2.8774238656148396`, 0.4308353192168015], 
                Complex[4.162278456114006, -0.6989937377997083]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.8, -6.488588035073183}],
            RowBox[{"{", 
              RowBox[{"33.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.6900189760399855`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5612511491377956`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.01438190088909`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.890520862682429`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8774238656148396`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4308353192168015`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.162278456114006`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6989937377997083`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.8, "A", 
             Association[1 -> {
                Complex[2.6900189760399855`, -0.5612511491377956], 
                Complex[4.01438190088909, -1.890520862682429]}, 2 -> {
                Complex[2.8774238656148396`, 0.4308353192168015], 
                Complex[4.162278456114006, -0.6989937377997083]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.498010293386255}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {33.9, "A", 
             Association[1 -> {
                Complex[2.693056602464925, -0.5703092165540393], 
                Complex[4.018766629721939, -1.900792375423005]}, 2 -> {
                Complex[2.8751090292740487`, 0.4404706516054349], 
                Complex[4.159001332605871, -0.6872839696368801]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{33.9, -6.505977026015971}],
            RowBox[{"{", 
              RowBox[{"33.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.693056602464925`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5703092165540393`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.018766629721939`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.900792375423005`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8751090292740487`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4404706516054349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.159001332605871`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6872839696368801`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {33.9, "A", 
             Association[1 -> {
                Complex[2.693056602464925, -0.5703092165540393], 
                Complex[4.018766629721939, -1.900792375423005]}, 2 -> {
                Complex[2.8751090292740487`, 0.4404706516054349], 
                Complex[4.159001332605871, -0.6872839696368801]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34., -6.5157229705026145`}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34., "A", 
             Association[1 -> {
                Complex[2.695956129918709, -0.5791958590266285], 
                Complex[4.022975200759234, -1.9108751468578677`]}, 2 -> {
                Complex[2.8729290323659913`, 0.4499297609478434], 
                Complex[4.155898108440934, -0.6757704154937819]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34., -6.523271763561462}],
            RowBox[{"{", 
              RowBox[{"34.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.695956129918709`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5791958590266285`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.022975200759234`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9108751468578677`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8729290323659913`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4499297609478434`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.155898108440934`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6757704154937819`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34., "A", 
             Association[1 -> {
                Complex[2.695956129918709, -0.5791958590266285], 
                Complex[4.022975200759234, -1.9108751468578677`]}, 2 -> {
                Complex[2.8729290323659913`, 0.4499297609478434], 
                Complex[4.155898108440934, -0.6757704154937819]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.533304883485762}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.1, "A", 
             Association[1 -> {
                Complex[2.698728344803272, -0.5879167986060275], 
                Complex[4.02702077908128, -1.9207750130848582`]}, 2 -> {
                Complex[2.8708731122295896`, 0.4592184279956057], 
                Complex[4.152955626516613, -0.664447166754532]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.1, -6.540448768421518}],
            RowBox[{"{", 
              RowBox[{"34.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.698728344803272`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.5879167986060275`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.02702077908128`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9207750130848582`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8708731122295896`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4592184279956057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.152955626516613`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.664447166754532`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34.1, "A", 
             Association[1 -> {
                Complex[2.698728344803272, -0.5879167986060275], 
                Complex[4.02702077908128, -1.9207750130848582`]}, 2 -> {
                Complex[2.8708731122295896`, 0.4592184279956057], 
                Complex[4.152955626516613, -0.664447166754532]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.550731888060824}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.2, "A", 
             Association[1 -> {
                Complex[2.7013829352654026`, -0.5964776632911527], 
                Complex[4.030915226970466, -1.9304977888211983`]}, 2 -> {
                Complex[2.8689316042370305`, 0.4683423384869718], 
                Complex[4.150162032533434, -0.6533083372307825]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.2, -6.55748462035302}],
            RowBox[{"{", 
              RowBox[{"34.2`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7013829352654026`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.5964776632911527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.030915226970466`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9304977888211983`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8689316042370305`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.4683423384869718`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.150162032533434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6533083372307825`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34.2, "A", 
             Association[1 -> {
                Complex[2.7013829352654026`, -0.5964776632911527], 
                Complex[4.030915226970466, -1.9304977888211983`]}, 2 -> {
                Complex[2.8689316042370305`, 0.4683423384869718], 
                Complex[4.150162032533434, -0.6533083372307825]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.567980283174104}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.3, "A", 
             Association[1 -> {
                Complex[2.7039286208715065`, -0.6048839465011073], 
                Complex[4.034669253707697, -1.9400492091033885`]}, 2 -> {
                Complex[2.8670958121211547`, 0.477307042638535], 
                Complex[4.147506625196923, -0.642348121441579]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.3, -6.574356045331486}],
            RowBox[{"{", 
              RowBox[{"34.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7039286208715065`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6048839465011073`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.034669253707697`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9400492091033885`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8670958121211547`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.477307042638535`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147506625196923`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.642348121441579`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34.3, "A", 
             Association[1 -> {
                Complex[2.7039286208715065`, -0.6048839465011073], 
                Complex[4.034669253707697, -1.9400492091033885`]}, 2 -> {
                Complex[2.8670958121211547`, 0.477307042638535], 
                Complex[4.147506625196923, -0.642348121441579]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.5850268303988955`}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.39999999999999, "A", 
             Association[1 -> {
                Complex[2.7063732659882276`, -0.613140979653751], 
                Complex[4.038292547177894, -1.9494348877721928`]}, 2 -> {
                Complex[2.8653578945969786`, 0.48611792774323803`], 
                Complex[4.144979724610491, -0.631560836108617]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.39999999999999, -6.591040010987559}],
            RowBox[{"{", 
              RowBox[{"34.39999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7063732659882276`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.613140979653751`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.038292547177894`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9494348877721928`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8653578945969786`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.48611792774323803`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.144979724610491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.631560836108617`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34.39999999999999, "A", 
             Association[1 -> {
                Complex[2.7063732659882276`, -0.613140979653751], 
                Complex[4.038292547177894, -1.9494348877721928`]}, 2 -> {
                Complex[2.8653578945969786`, 0.48611792774323803`], 
                Complex[4.144979724610491, -0.631560836108617]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.60184879889878}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.49999999999999, "A", 
             Association[1 -> {
                Complex[2.708723978803601, -0.6212539145605391], 
                Complex[4.041793889306879, -1.958660288701135]}, 2 -> {
                Complex[2.8637107663426793`, 0.49478020058417876`], 
                Complex[4.1425725568370115`, -0.6209409489084496]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.49999999999999, -6.607513829581488}],
            RowBox[{"{", 
              RowBox[{"34.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.708723978803601`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6212539145605391`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.041793889306879`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.958660288701135`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], ",", 
                    RowBox[{"2", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.8637107663426793`", "\[VeryThinSpace]"}], "+", 
                    
                    RowBox[{"0.49478020058417876`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1425725568370115`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6209409489084496`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}]}], "\[RightAssociation]"}], ",", "\"UA\""}], 
              "}"}]],
           Annotation[#, {34.49999999999999, "A", 
             Association[1 -> {
                Complex[2.708723978803601, -0.6212539145605391], 
                Complex[4.041793889306879, -1.958660288701135]}, 2 -> {
                Complex[2.8637107663426793`, 0.49478020058417876`], 
                Complex[4.1425725568370115`, -0.6209409489084496]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -5.877928461171593}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.710987197779323, -0.6292277131331433], 
                Complex[4.045181257244431, -1.9677307066670986`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.599999999999994`, -5.877928461171593}],
            RowBox[{"{", 
              RowBox[{"34.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.710987197779323`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6292277131331433`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.045181257244431`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9677307066670986`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.710987197779323, -0.6292277131331433], 
                Complex[4.045181257244431, -1.9677307066670986`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -5.85928212292715}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7131687671511795`, -0.6370671424983351], 
                Complex[4.048461912051173, -1.9766512554854927`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.699999999999996`, -5.85928212292715}],
            RowBox[{"{", 
              RowBox[{"34.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7131687671511795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6370671424983351`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.048461912051173`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9766512554854927`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7131687671511795`, -0.6370671424983351], 
                Complex[4.048461912051173, -1.9766512554854927`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -5.8401551790416715`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.8, "A", 
             Association[1 -> {
                Complex[2.71527400291423, -0.6447767740762022], 
                Complex[4.051642476470395, -1.9854268615885537`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.8, -5.8401551790416715`}],
            RowBox[{"{", 
              RowBox[{"34.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.71527400291423`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6447767740762022`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.051642476470395`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9854268615885537`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.8, "A", 
             Association[1 -> {
                Complex[2.71527400291423, -0.6447767740762022], 
                Complex[4.051642476470395, -1.9854268615885537`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -5.82055551459949}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {34.9, "A", 
             Association[1 -> {
                Complex[2.717307750554921, -0.6523609855265123], 
                Complex[4.054729003187752, -1.9940622616524228`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{34.9, -5.82055551459949}],
            RowBox[{"{", 
              RowBox[{"34.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.717307750554921`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6523609855265123`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.054729003187752`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"1.9940622616524228`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {34.9, "A", 
             Association[1 -> {
                Complex[2.717307750554921, -0.6523609855265123], 
                Complex[4.054729003187752, -1.9940622616524228`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35., -5.800490898581647}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35., "A", 
             Association[1 -> {
                Complex[2.7192744356306133`, -0.6598239647344449], 
                Complex[4.057727034812088, -2.002562003206256]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35., -5.800490898581647}],
            RowBox[{"{", 
              RowBox[{"35.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7192744356306133`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6598239647344449`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.057727034812088`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.002562003206256`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35., "A", 
             Association[1 -> {
                Complex[2.7192744356306133`, -0.6598239647344449], 
                Complex[4.057727034812088, -2.002562003206256]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -5.779968986459502}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.1, "A", 
             Association[1 -> {
                Complex[2.7211781081510784`, -0.6671697152100743], 
                Complex[4.060641656654434, -2.01093044740819]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.1, -5.779968986459502}],
            RowBox[{"{", 
              RowBox[{"35.1`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7211781081510784`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6671697152100743`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.060641656654434`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.01093044740819`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.1, "A", 
             Association[1 -> {
                Complex[2.7211781081510784`, -0.6671697152100743], 
                Complex[4.060641656654434, -2.01093044740819]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -5.758997322878874}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7230224815870465`, -0.6744020624307276], 
                Complex[4.063477543241718, -2.0191717733661476`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.199999999999996`, -5.758997322878874}],
            RowBox[{"{", 
              RowBox[{"35.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7230224815870465`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6744020624307276`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.063477543241718`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0191717733661476`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7230224815870465`, -0.6744020624307276], 
                Complex[4.063477543241718, -2.0191717733661476`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -5.737583344119423}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.3, "A", 
             Association[1 -> {
                Complex[2.724810967217476, -0.6815246607732999], 
                Complex[4.066238999377148, -2.0272899835297706`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.3, -5.737583344119423}],
            RowBox[{"{", 
              RowBox[{"35.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.724810967217476`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.6815246607732999`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.066238999377148`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0272899835297706`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.3, "A", 
             Association[1 -> {
                Complex[2.724810967217476, -0.6815246607732999], 
                Complex[4.066238999377148, -2.0272899835297706`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -5.715734380138605}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.4, "A", 
             Association[1 -> {
                Complex[2.7265467044285883`, -0.6885410007735716], 
                Complex[4.06892999644998, -2.0352889097939637`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.4, -5.715734380138605}],
            RowBox[{"{", 
              RowBox[{"35.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7265467044285883`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6885410007735716`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.06892999644998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0352889097939637`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.4, "A", 
             Association[1 -> {
                Complex[2.7265467044285883`, -0.6885410007735716], 
                Complex[4.06892999644998, -2.0352889097939637`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -5.693457656099856}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.49999999999999, "A", 
             Association[1 -> {
                Complex[2.7282325874925664`, -0.6954544165180527], 
                Complex[4.07155420460227, -2.0431722200421385`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.49999999999999, -5.693457656099856}],
            RowBox[{"{", 
              RowBox[{"35.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7282325874925664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.6954544165180527`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.07155420460227`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0431722200421385`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.49999999999999, "A", 
             Association[1 -> {
                Complex[2.7282325874925664`, -0.6954544165180527], 
                Complex[4.07155420460227, -2.0431722200421385`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -5.6707602933489385`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.729871289280439, -0.7022680930260651], 
                Complex[4.074115021277763, -2.0509434249247764`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.599999999999994`, -5.6707602933489385`}],
            RowBox[{"{", 
              RowBox[{"35.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.729871289280439`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7022680930260651`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.074115021277763`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0509434249247764`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.729871289280439, -0.7022680930260651], 
                Complex[4.074115021277763, -2.0509434249247764`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -5.64764930984729}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7314652823007664`, -0.7089850735194753], 
                Complex[4.076615596606935, -2.0586058847208237`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.699999999999996`, -5.64764930984729}],
            RowBox[{"{", 
              RowBox[{"35.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7314652823007664`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7089850735194753`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.076615596606935`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0586058847208237`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7314652823007664`, -0.7089850735194753], 
                Complex[4.076615596606935, -2.0586058847208237`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -5.624131620101327}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {35.8, "A", 
             Association[1 -> {
                Complex[2.733016857401756, -0.7156082665076033], 
                Complex[4.079058856020895, -2.0661628161692955`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.8, -5.624131620101327}],
            RowBox[{"{", 
              RowBox[{"35.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.733016857401756`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7156082665076033`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.079058856020895`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.0661628161692955`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {35.8, "A", 
             Association[1 -> {
                Complex[2.733016857401756, -0.7156082665076033], 
                Complex[4.079058856020895, -2.0661628161692955`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -5.600214034646043}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.9, "A", 
             Association[1 -> {
                Complex[2.734528140428245, -0.7221404526376912], 
                Complex[4.081447520434109, -2.07361729918916]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.9, -5.600214034646043}],
            RowBox[{"{", 
              RowBox[{"35.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.734528140428245`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7221404526376912`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.081447520434109`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.07361729918916`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.9, "A", 
             Association[1 -> {
                Complex[2.734528140428245, -0.7221404526376912], 
                Complex[4.081447520434109, -2.07361729918916]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -5.575903259152508}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {35.99999999999999, "A", 
             Association[1 -> {
                Complex[2.736001107085408, -0.7285842912785057], 
                Complex[4.0837841242905935`, -2.080972283429037]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{35.99999999999999, -5.575903259152508}],
            RowBox[{"{", 
              RowBox[{"35.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.736001107085408`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7285842912785057`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.0837841242905935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.080972283429037`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {35.99999999999999, "A", 
             Association[1 -> {
                Complex[2.736001107085408, -0.7285842912785057], 
                Complex[4.0837841242905935`, -2.080972283429037]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -5.551205893233947}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.7374375962271382`, -0.7349423268176083], 
                Complex[4.086071031729208, -2.088230594606227]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.099999999999994`, -5.551205893233947}],
            RowBox[{"{", 
              RowBox[{"36.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7374375962271382`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7349423268176083`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.086071031729208`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.088230594606227`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.7374375962271382`, -0.7349423268176083], 
                Complex[4.086071031729208, -2.088230594606227]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -5.526128429026181}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7388393217580846`, -0.7412169946624545], 
                Complex[4.088310451090251, -2.095394940608318]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.199999999999996`, -5.526128429026181}],
            RowBox[{"{", 
              RowBox[{"36.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7388393217580846`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7412169946624545`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.088310451090251`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.095394940608318`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7388393217580846`, -0.7412169946624545], 
                Complex[4.088310451090251, -2.095394940608318]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -5.500677249615846}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {36.3, "A", 
             Association[1 -> {
                Complex[2.7402078833132797`, -0.7474106269426312], 
                Complex[4.090504447956572, -2.1024679173410123`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.3, -5.500677249615846}],
            RowBox[{"{", 
              RowBox[{"36.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7402078833132797`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7474106269426312`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.090504447956572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1024679173410123`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {36.3, "A", 
             Association[1 -> {
                Complex[2.7402078833132797`, -0.7474106269426312], 
                Complex[4.090504447956572, -2.1024679173410123`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -5.47485862738555}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.4, "A", 
             Association[1 -> {
                Complex[2.7415447758580713`, -0.7535254579157126], 
                Complex[4.092654956897793, -2.109452014313655]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.4, -5.47485862738555}],
            RowBox[{"{", 
              RowBox[{"36.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7415447758580713`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7535254579157126`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.092654956897793`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.109452014313655`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.4, "A", 
             Association[1 -> {
                Complex[2.7415447758580713`, -0.7535254579157126], 
                Complex[4.092654956897793, -2.109452014313655]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -5.448678722339273}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.5, "A", 
             Association[1 -> {
                Complex[2.742851398332544, -0.7595636290829759], 
                Complex[4.094763792064631, -2.11634961995984]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.5, -5.448678722339273}],
            RowBox[{"{", 
              RowBox[{"36.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.742851398332544`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7595636290829759`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.094763792064631`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.11634961995984`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.5, "A", 
             Association[1 -> {
                Complex[2.742851398332544, -0.7595636290829759], 
                Complex[4.094763792064631, -2.11634961995984]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -5.422143580464781}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {36.6, "A", 
             Association[1 -> {
                Complex[2.744129061448893, -0.7655271940238008], 
                Complex[4.096832656761998, -2.1231630266947916`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.6, -5.422143580464781}],
            RowBox[{"{", 
              RowBox[{"36.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.744129061448893`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7655271940238008`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.096832656761998`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1231630266947916`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {36.6, "A", 
             Association[1 -> {
                Complex[2.744129061448893, -0.7655271940238008], 
                Complex[4.096832656761998, -2.1231630266947916`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -5.39525913218259}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {36.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.745378994736478, -0.7714181229593412], 
                Complex[4.098863152113465, -2.1298944357144087`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.699999999999996`, -5.39525913218259}],
            RowBox[{"{", 
              RowBox[{"36.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.745378994736478`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7714181229593412`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.098863152113465`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1298944357144087`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {36.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.745378994736478, -0.7714181229593412], 
                Complex[4.098863152113465, -2.1298944357144087`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -5.3680311909239595`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.79999999999999, "A", 
             Association[1 -> {
                Complex[2.746602352917594, -0.7772383070571701], 
                Complex[4.100856784915977, -2.136545961543077]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.79999999999999, -5.3680311909239595`}],
            RowBox[{"{", 
              RowBox[{"36.79999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.746602352917594`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7772383070571701`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.100856784915977`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.136545961543077`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.79999999999999, "A", 
             Association[1 -> {
                Complex[2.746602352917594, -0.7772383070571701], 
                Complex[4.100856784915977, -2.136545961543077]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -5.3404654518730785`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {36.89999999999999, "A", 
             Association[1 -> {
                Complex[2.7478002216867257`, -0.7829895624892164], 
                Complex[4.102814974771636, -2.143119636338954]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.89999999999999, -5.3404654518730785`}],
            RowBox[{"{", 
              RowBox[{"36.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7478002216867257`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.7829895624892164`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.102814974771636`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.143119636338954`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {36.89999999999999, "A", 
             Association[1 -> {
                Complex[2.7478002216867257`, -0.7829895624892164], 
                Complex[4.102814974771636, -2.143119636338954]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -5.312567490901927}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {36.99999999999999, "A", 
             Association[1 -> {
                Complex[2.748973622957287, -0.7886736342555815], 
                Complex[4.104739060573037, -2.1496174139664057`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{36.99999999999999, -5.312567490901927}],
            RowBox[{"{", 
              RowBox[{"36.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.748973622957287`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7886736342555815`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.104739060573037`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1496174139664057`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {36.99999999999999, "A", 
             Association[1 -> {
                Complex[2.748973622957287, -0.7886736342555815], 
                Complex[4.104739060573037, -2.1496174139664057`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -5.284342763719775}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.750123519632142, -0.794292199786831], 
                Complex[4.106630306409572, -2.156041173845927]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.099999999999994`, -5.284342763719775}],
            RowBox[{"{", 
              RowBox[{"37.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.750123519632142`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.794292199786831`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.106630306409572`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.156041173845927`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.750123519632142, -0.794292199786831], 
                Complex[4.106630306409572, -2.156041173845927]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -5.255796605253312}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {37.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.751250819947598, -0.7998468723371362], 
                Complex[4.108489906954296, -2.1623927245921424`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.199999999999996`, -5.255796605253312}],
            RowBox[{"{", 
              RowBox[{"37.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.751250819947598`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.7998468723371362`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.108489906954296`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1623927245921424`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {37.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.751250819947598, -0.7998468723371362], 
                Complex[4.108489906954296, -2.1623927245921424`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -5.226934229267913}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.3, "A", 
             Association[1 -> {
                Complex[2.7523563814347085`, -0.8053392041803537], 
                Complex[4.11031899238399, -2.168673807450607]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.3, -5.226934229267913}],
            RowBox[{"{", 
              RowBox[{"37.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7523563814347085`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8053392041803537`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.11031899238399`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.168673807450607`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.3, "A", 
             Association[1 -> {
                Complex[2.7523563814347085`, -0.8053392041803537], 
                Complex[4.11031899238399, -2.168673807450607]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -5.197760728235796}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.4, "A", 
             Association[1 -> {
                Complex[2.7534410145367234`, -0.8107706896206492], 
                Complex[4.112118632879193, -2.174886099543967]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.4, -5.197760728235796}],
            RowBox[{"{", 
              RowBox[{"37.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7534410145367234`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8107706896206492`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.112118632879193`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.174886099543967`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.4, "A", 
             Association[1 -> {
                Complex[2.7534410145367234`, -0.8107706896206492], 
                Complex[4.112118632879193, -2.174886099543967]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -5.168281073452294}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {37.5, "A", 
             Association[1 -> {
                Complex[2.7545054859170786`, -0.8161427678288303], 
                Complex[4.113889842745602, -2.1810312169378863`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.5, -5.168281073452294}],
            RowBox[{"{", 
              RowBox[{"37.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7545054859170786`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8161427678288303`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.113889842745602`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1810312169378863`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {37.5, "A", 
             Association[1 -> {
                Complex[2.7545054859170786`, -0.8161427678288303], 
                Complex[4.113889842745602, -2.1810312169378863`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -5.138500115397959}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {37.6, "A", 
             Association[1 -> {
                Complex[2.7555505214884586`, -0.8214568255150109], 
                Complex[4.115633584193734, -2.1871107175367754`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.6, -5.138500115397959}],
            RowBox[{"{", 
              RowBox[{"37.6`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7555505214884586`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8214568255150109`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.115633584193734`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.1871107175367754`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {37.6, "A", 
             Association[1 -> {
                Complex[2.7555505214884586`, -0.8214568255150109], 
                Complex[4.115633584193734, -2.1871107175367754`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -5.108422584340677}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.7, "A", 
             Association[1 -> {
                Complex[2.7565768091900997`, -0.8267141994476596], 
                Complex[4.117350770809639, -2.193126103819013]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.7, -5.108422584340677}],
            RowBox[{"{", 
              RowBox[{"37.7`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7565768091900997`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8267141994476596`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.117350770809639`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.193126103819013`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.7, "A", 
             Association[1 -> {
                Complex[2.7565768091900997`, -0.8267141994476596], 
                Complex[4.117350770809639, -2.193126103819013]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -5.0780530911695045`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.8, "A", 
             Association[1 -> {
                Complex[2.7575850015374925`, -0.8319161788285991], 
                Complex[4.119042270745964, -2.199078825420972]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.8, -5.0780530911695045`}],
            RowBox[{"{", 
              RowBox[{"37.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7575850015374925`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8319161788285991`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.119042270745964`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.199078825420972`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.8, "A", 
             Association[1 -> {
                Complex[2.7575850015374925`, -0.8319161788285991], 
                Complex[4.119042270745964, -2.199078825420972]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -5.047396128449668}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {37.89999999999999, "A", 
             Association[1 -> {
                Complex[2.7585757179660733`, -0.8370640075328957], 
                Complex[4.120708909659479, -2.204970281578657]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.89999999999999, -5.047396128449668}],
            RowBox[{"{", 
              RowBox[{"37.89999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7585757179660733`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8370640075328957`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.120708909659479`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.204970281578657`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {37.89999999999999, "A", 
             Association[1 -> {
                Complex[2.7585757179660733`, -0.8370640075328957], 
                Complex[4.120708909659479, -2.204970281578657]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -5.016456071686121}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {37.99999999999999, "A", 
             Association[1 -> {
                Complex[2.759549546988155, -0.8421588862221198], 
                Complex[4.122351473418491, -2.2108018234353835`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{37.99999999999999, -5.016456071686121}],
            RowBox[{"{", 
              RowBox[{"37.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.759549546988155`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8421588862221198`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.122351473418491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2108018234353835`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {37.99999999999999, "A", 
             Association[1 -> {
                Complex[2.759549546988155, -0.8421588862221198], 
                Complex[4.122351473418491, -2.2108018234353835`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -4.98523718078211}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.760507048180339, -0.8472019743388879], 
                Complex[4.123970710601056, -2.2165747562234497`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.099999999999994`, -4.98523718078211}],
            RowBox[{"{", 
              RowBox[{"38.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.760507048180339`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8472019743388879`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.123970710601056`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2165747562234497`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.760507048180339, -0.8472019743388879], 
                Complex[4.123970710601056, -2.2165747562234497`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -4.953743601677721}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7614487540168455`, -0.8521943919901349], 
                Complex[4.12556733480281, -2.222290341327314]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.199999999999996`, -4.953743601677721}],
            RowBox[{"{", 
              RowBox[{"38.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7614487540168455`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8521943919901349`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.12556733480281`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.222290341327314`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.7614487540168455`, -0.8521943919901349], 
                Complex[4.12556733480281, -2.222290341327314]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -4.921979368153064}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.3, "A", 
             Association[1 -> {
                Complex[2.762375171562624, -0.8571372217260823], 
                Complex[4.127142026771301, -2.2279497982353837`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.3, -4.921979368153064}],
            RowBox[{"{", 
              RowBox[{"38.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.762375171562624`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8571372217260823`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.127142026771301`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2279497982353837`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.3, "A", 
             Association[1 -> {
                Complex[2.762375171562624, -0.8571372217260823], 
                Complex[4.127142026771301, -2.2279497982353837`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -4.889948403780032}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.4, "A", 
             Association[1 -> {
                Complex[2.7632867840386814`, -0.8620315102214068], 
                Complex[4.128695436382012, -2.2335543063870658`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.4, -4.889948403780032}],
            RowBox[{"{", 
              RowBox[{"38.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7632867840386814`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8620315102214068`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.128695436382012`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2335543063870658`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.4, "A", 
             Association[1 -> {
                Complex[2.7632867840386814`, -0.8620315102214068], 
                Complex[4.128695436382012, -2.2335543063870658`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -4.857654524006771}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.5, "A", 
             Association[1 -> {
                Complex[2.764184052270831, -0.8668782698647187], 
                Complex[4.130228184469746, -2.239105006921373]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.5, -4.857654524006771}],
            RowBox[{"{", 
              RowBox[{"38.5`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.764184052270831`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8668782698647187`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.130228184469746`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.239105006921373`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.5, "A", 
             Association[1 -> {
                Complex[2.764184052270831, -0.8668782698647187], 
                Complex[4.130228184469746, -2.239105006921373]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -4.825101438358711}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.765067416031943, -0.8716784802620265], 
                Complex[4.131740864527742, -2.2446030043329674`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.599999999999994`, -4.825101438358711}],
            RowBox[{"{", 
              RowBox[{"38.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.765067416031943`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8716784802620265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.131740864527742`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2446030043329674`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.765067416031943, -0.8716784802620265], 
                Complex[4.131740864527742, -2.2446030043329674`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -4.792292752740544}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7659372952868275`, -0.8764330896595155], 
                Complex[4.133234044285656, -2.25004936804117]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.699999999999996`, -4.792292752740544}],
            RowBox[{"{", 
              RowBox[{"38.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7659372952868275`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8764330896595155`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.133234044285656`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.25004936804117`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7659372952868275`, -0.8764330896595155], 
                Complex[4.133234044285656, -2.25004936804117]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -4.759231971823873}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.8, "A", 
             Association[1 -> {
                Complex[2.7667940913479225`, -0.8811430162906054], 
                Complex[4.134708267176491, -2.2554451338771337`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.8, -4.759231971823873}],
            RowBox[{"{", 
              RowBox[{"38.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7667940913479225`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8811430162906054`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.134708267176491`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2554451338771337`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.8, "A", 
             Association[1 -> {
                Complex[2.7667940913479225`, -0.8811430162906054], 
                Complex[4.134708267176491, -2.2554451338771337`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -4.7259225015056305`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {38.9, "A", 
             Association[1 -> {
                Complex[2.7676381879492564`, -0.8858091496519156], 
                Complex[4.136164053701611, -2.260791305494017]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.9, -4.7259225015056305`}],
            RowBox[{"{", 
              RowBox[{"38.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7676381879492564`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8858091496519156`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.136164053701611`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.260791305494017`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {38.9, "A", 
             Association[1 -> {
                Complex[2.7676381879492564`, -0.8858091496519156], 
                Complex[4.136164053701611, -2.260791305494017]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -4.692367651423338}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {38.99999999999999, "A", 
             Association[1 -> {
                Complex[2.768469952245414, -0.8904323517124777], 
                Complex[4.137601902702118, -2.2660888557047376`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{38.99999999999999, -4.692367651423338}],
            RowBox[{"{", 
              RowBox[{"38.99999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.768469952245414`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8904323517124777`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.137601902702118`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2660888557047376`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {38.99999999999999, "A", 
             Association[1 -> {
                Complex[2.768469952245414, -0.8904323517124777], 
                Complex[4.137601902702118, -2.2660888557047376`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -4.658570637513677}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.7692897357415935`, -0.8950134580602265], 
                Complex[4.139022292544098, -2.271338727751554]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.099999999999994`, -4.658570637513677}],
            RowBox[{"{", 
              RowBox[{"39.099999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7692897357415935`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.8950134580602265`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.139022292544098`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.271338727751554`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.099999999999994`, "A", 
             Association[1 -> {
                Complex[2.7692897357415935`, -0.8950134580602265], 
                Complex[4.139022292544098, -2.271338727751554]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -4.624534584601913}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {39.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.770097875160309, -0.8995532789895441], 
                Complex[4.1404256822245795`, -2.2765418365114742`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.199999999999996`, -4.624534584601913}],
            RowBox[{"{", 
              RowBox[{"39.199999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.770097875160309`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.8995532789895441`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1404256822245795`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2765418365114742`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {39.199999999999996`, "A", 
             Association[1 -> {
                Complex[2.770097875160309, -0.8995532789895441], 
                Complex[4.1404256822245795`, -2.2765418365114742`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -4.590262529010211}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {39.3, "A", 
             Association[1 -> {
                Complex[2.770894693249766, -0.9040526005333875], 
                Complex[4.141812512404396, -2.2816990696412365`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.3, -4.590262529010211}],
            RowBox[{"{", 
              RowBox[{"39.3`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.770894693249766`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9040526005333875`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.141812512404396`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.2816990696412365`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {39.3, "A", 
             Association[1 -> {
                Complex[2.770894693249766, -0.9040526005333875], 
                Complex[4.141812512404396, -2.2816990696412365`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -4.555757421174059}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.4, "A", 
             Association[1 -> {
                Complex[2.771680499538499, -0.9085121854432784], 
                Complex[4.143183206373633, -2.286811288665357]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.4, -4.555757421174059}],
            RowBox[{"{", 
              RowBox[{"39.4`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.771680499538499`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9085121854432784`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.143183206373633`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.286811288665357`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.4, "A", 
             Association[1 -> {
                Complex[2.771680499538499, -0.9085121854432784], 
                Complex[4.143183206373633, -2.286811288665357]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -4.521022128256681}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.49999999999999, "A", 
             Association[1 -> {
                Complex[2.772455591040422, -0.9129327741202401], 
                Complex[4.1445381709548, -2.291879330010544]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.49999999999999, -4.521022128256681}],
            RowBox[{"{", 
              RowBox[{"39.49999999999999`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.772455591040422`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9129327741202401`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1445381709548`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.291879330010544`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.49999999999999, "A", 
             Association[1 -> {
                Complex[2.772455591040422, -0.9129327741202401], 
                Complex[4.1445381709548, -2.291879330010544]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -4.48605943675225}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {39.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.773220252914124, -0.9173150854995425], 
                Complex[4.1458777973484535`, -2.2969040059895236`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.599999999999994`, -4.48605943675225}],
            RowBox[{"{", 
              RowBox[{"39.599999999999994`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.773220252914124`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9173150854995425`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.1458777973484535`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"2.2969040059895236`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {39.599999999999994`, "A", 
             Association[1 -> {
                Complex[2.773220252914124, -0.9173150854995425], 
                Complex[4.1458777973484535`, -2.2969040059895236`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -4.450872055069479}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {39.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7739747590798687`, -0.9216598178919512], 
                Complex[4.147202461925569, -2.3018861057371836`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.699999999999996`, -4.450872055069479}],
            RowBox[{"{", 
              RowBox[{"39.699999999999996`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.7739747590798687`", "\[VeryThinSpace]"}], "-", 
                    
                    RowBox[{"0.9216598178919512`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.147202461925569`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3018861057371836`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {39.699999999999996`, "A", 
             Association[1 -> {
                Complex[2.7739747590798687`, -0.9216598178919512], 
                Complex[4.147202461925569, -2.3018861057371836`]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -4.415462616088088}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.8, "A", 
             Association[1 -> {
                Complex[2.774719372797445, -0.9259676497839711], 
                Complex[4.148512526970578, -2.306826396101705]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.8, -4.415462616088088}],
            RowBox[{"{", 
              RowBox[{"39.8`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.774719372797445`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9259676497839711`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.148512526970578`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.306826396101705`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.8, "A", 
             Association[1 -> {
                Complex[2.774719372797445, -0.9259676497839711], 
                Complex[4.148512526970578, -2.306826396101705]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -4.379833679681526}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], "}"}]],
           Annotation[#, {39.9, "A", 
             Association[1 -> {
                Complex[2.775454347207829, -0.9302392405994732], 
                Complex[4.149808341378721, -2.311725622493254]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{39.9, -4.379833679681526}],
            RowBox[{"{", 
              RowBox[{"39.9`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.775454347207829`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9302392405994732`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.149808341378721`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.311725622493254`", " ", "\[ImaginaryI]"}]}]}], 
                    "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           
           Annotation[#, {39.9, "A", 
             Association[1 -> {
                Complex[2.775454347207829, -0.9302392405994732], 
                Complex[4.149808341378721, -2.311725622493254]}], "UA"}, 
            "Tooltip"]& ]}}, {
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{40., -4.343987735199813}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"SPA\""}], 
              "}"}]],
           Annotation[#, {40., "A", 
             Association[1 -> {
                Complex[2.776179925841262, -0.9344752314248258], 
                Complex[4.151090241310992, -2.3165845096925235`]}], "SPA"}, 
            "Tooltip"]& ]}, 
         {GrayLevel[0], 
          TagBox[
           TooltipBox[PointBox[{40., -4.343987735199813}],
            RowBox[{"{", 
              RowBox[{"40.`", ",", "\"A\"", ",", 
                RowBox[{"\[LeftAssociation]", 
                  RowBox[{"1", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"2.776179925841262`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"0.9344752314248258`", " ", "\[ImaginaryI]"}]}], 
                    ",", 
                    RowBox[{
                    RowBox[{"4.151090241310992`", "\[VeryThinSpace]"}], "-", 
                    RowBox[{"2.3165845096925235`", " ", "\[ImaginaryI]"}]}]}],
                     "}"}]}], "\[RightAssociation]"}], ",", "\"UA\""}], "}"}]],
           Annotation[#, {40., "A", 
             Association[1 -> {
                Complex[2.776179925841262, -0.9344752314248258], 
                Complex[4.151090241310992, -2.3165845096925235`]}], "UA"}, 
            "Tooltip"]& ]}}}},
      AspectRatio->0.5555555555555556,
      Axes->True,
      Frame->True,
      FrameLabel->{
        FormBox["\"\[CapitalOmega]/\[Omega]\"", TraditionalForm], 
        FormBox["\"harmonic dipole\"", TraditionalForm]},
      ImageSize->800,
      PlotRange->{Automatic, {-7.1, -5.3}},
      PlotRangeClipping->True,
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, Open  ]],

Cell["\<\
The spectrum for this saddle-point classification is very ugly, but it does \
exactly what it needs to be doing.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[LessTilde]", 
    RowBox[{"19.5", "\[Omega]"}]}], TraditionalForm]]],
 ", the C set gets a third saddle from what ought to be B, and UAdipole \
surrenders the calculation to SPAdipole, so the two match at low \
\[CapitalOmega] for the green curve."
}], "Item"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[LessTilde]", 
    RowBox[{"19.5", "\[Omega]"}]}], TraditionalForm]]],
 " on the C set, there is a third saddle contributing to SPAdipole, so it\
\[CloseCurlyQuote]s displaying a bigger dipole with more contributions (and \
also more interference). This saddle gets dropped after ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "=", 
    RowBox[{"19.4", "\[Omega]"}]}], TraditionalForm]]],
 ", which gives the discontinuity there."
}], "Item"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[GreaterTilde]", 
    RowBox[{"35", "\[Omega]"}]}], TraditionalForm]]],
 ", the wanted root (A,1) is no longer present. The UAdipole call surrenders \
the calculation to SPA dipole and the two match on the black curve after ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "=", 
    RowBox[{"34.6", "\[Omega]"}]}], TraditionalForm]]],
 "."
}], "Item"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[GreaterTilde]", 
    RowBox[{"35", "\[Omega]"}]}], TraditionalForm]]],
 " on the SPA branch it\[CloseCurlyQuote]s getting a malformed input so it \
ignores the Stokes transition and evaluates the saddle it\[CloseCurlyQuote]s \
been given, which is the divergent one at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"Im", "(", "t", ")"}], "<", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"Im", "(", 
      RowBox[{"S", "(", "t", ")"}], ")"}], "<", "0"}]}], TraditionalForm]]],
 ", and this gives the exponential growth after ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "=", 
    RowBox[{"34.6", "\[Omega]"}]}], TraditionalForm]]]
}], "Item"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[GreaterTilde]", 
    RowBox[{"21.5", "\[Omega]"}]}], TraditionalForm]]],
 ", the C set loses the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Im", "(", "t", ")"}], "<", "0"}], TraditionalForm]]],
 " root, which is the unwanted ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Im", "(", 
     RowBox[{"S", "(", "t", ")"}], ")"}], "<", "0"}], TraditionalForm]]],
 " one, so everything is mostly fine. Here the SPAdipole call has a single \
saddle so it issues a warning that it\[CloseCurlyQuote]s reverting to \
unstructured evaluation, but this does not change the outcome."
}], "Item"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "\[GreaterTilde]", 
    RowBox[{"21.5", "\[Omega]"}]}], TraditionalForm]]],
 " on the C set, the UAdipole call has a single saddle so it reverts to \
unstructured SPAdipole, which is a good approximation here, but this causes a \
slight discontinuity at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "=", 
    RowBox[{"21.5", "\[Omega]"}]}], TraditionalForm]]],
 "; both curves match after that."
}], "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1863, 1056},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"~/Desktop/print.pdf",
"PrintingMargins"->{{19.84251968503, 19.84251968503}, {72., 72.}}},
PrivateNotebookOptions->{"FileOutlineCache"->False},
ShowSelection->True,
TrackCellChangeTimes->False,
FrontEndVersion->"10.0 for Linux x86 (64-bit) (December 4, 2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Code"], FontWeight -> "Plain", FontSlant -> "Plain", 
    FontTracking -> "Plain", 
    FontVariations -> {
     "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False, 
      "Underline" -> False}]}, Visible -> False, FrontEndVersion -> 
  "10.0 for Linux x86 (64-bit) (December 4, 2014)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]

